SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;


DELIMITER $$
CREATE PROCEDURE `closest_members_optimized`(IN `units` VARCHAR(5), IN `lat` DECIMAL(10,7), IN `lon` DECIMAL(10,7), IN `max_distance` SMALLINT, IN `gender` TINYINT UNSIGNED, IN `look_for` TINYINT UNSIGNED, IN `age_beginning` TINYINT UNSIGNED, IN `age_end` TINYINT UNSIGNED, IN `last_connection` MEDIUMINT UNSIGNED, IN `rows_limit` MEDIUMINT, IN `rows_offset` MEDIUMINT)
BEGIN
   DECLARE ONE_DEGREE_CONSTANT TINYINT;
   DECLARE EARTH_RADIUS_CONSTANT SMALLINT;
   DECLARE lon1, lon2, lat1, lat2 float;  

  IF units = 'miles' THEN
     SET ONE_DEGREE_CONSTANT   = 69;
     SET EARTH_RADIUS_CONSTANT = 3959;
   ELSE 
     SET ONE_DEGREE_CONSTANT   = 111;
     SET EARTH_RADIUS_CONSTANT = 6371;
   END IF;  

  SET lon1 = lon-max_distance/abs(cos(radians(lat))*ONE_DEGREE_CONSTANT);
   SET lon2 = lon+max_distance/abs(cos(radians(lat))*ONE_DEGREE_CONSTANT);
   SET lat1 = lat-(max_distance/ONE_DEGREE_CONSTANT);
   SET lat2 = lat+(max_distance/ONE_DEGREE_CONSTANT);

  SELECT members.id, members.picture, members.pseudonym, members.birthdate, continents.name as contient_name, countries.name as country_name, cities.name as city_name, members.description, members.non_smoker, members.religion,
          ROUND((EARTH_RADIUS_CONSTANT * acos( cos( radians(lat) ) 
               * cos( radians(cities.latitude) ) 
               * cos( radians(cities.longitude) - radians(lon)) + sin(radians(lat)) 
               * sin( radians(cities.latitude)))
          ), 3) AS distance
   FROM members
   INNER JOIN continents ON members.continent = continents.id
   INNER JOIN countries ON members.country = countries.id
   INNER JOIN cities ON members.city = cities.id
   WHERE members.gender = gender
   AND members.look_for = look_for
   AND members.birthdate BETWEEN DATE_SUB(CURDATE(), INTERVAL age_end YEAR) AND DATE_SUB(CURDATE(), INTERVAL age_beginning YEAR)
   AND members.last_connection > DATE_SUB(NOW(), INTERVAL last_connection MINUTE)
   AND cities.longitude between lon1 and lon2 
   AND cities.latitude between lat1 and lat2
   ORDER BY distance ASC
   LIMIT rows_limit OFFSET rows_offset;
 END$$

CREATE PROCEDURE `number_of_closest_members_optimized`(IN `units` VARCHAR(5), IN `lat` DECIMAL(10,7), IN `lon` DECIMAL(10,7), IN `max_distance` SMALLINT, IN `gender` TINYINT UNSIGNED, IN `look_for` TINYINT UNSIGNED, IN `age_beginning` TINYINT UNSIGNED, IN `age_end` TINYINT UNSIGNED, IN `last_connection` MEDIUMINT UNSIGNED)
BEGIN
   DECLARE ONE_DEGREE_CONSTANT TINYINT;
   DECLARE EARTH_RADIUS_CONSTANT SMALLINT;
   DECLARE lon1, lon2, lat1, lat2 float;  

  IF units = 'miles' THEN
     SET ONE_DEGREE_CONSTANT   = 69;
     SET EARTH_RADIUS_CONSTANT = 3959;
   ELSE 
     SET ONE_DEGREE_CONSTANT   = 111;
     SET EARTH_RADIUS_CONSTANT = 6371;
   END IF;  

  SET lon1 = lon-max_distance/abs(cos(radians(lat))*ONE_DEGREE_CONSTANT);
   SET lon2 = lon+max_distance/abs(cos(radians(lat))*ONE_DEGREE_CONSTANT);
   SET lat1 = lat-(max_distance/ONE_DEGREE_CONSTANT);
   SET lat2 = lat+(max_distance/ONE_DEGREE_CONSTANT);

  SELECT COUNT(members.id) as number_of_members
   FROM members
   INNER JOIN continents ON members.continent = continents.id
   INNER JOIN countries ON members.country = countries.id
   INNER JOIN cities ON members.city = cities.id
   WHERE members.gender = gender
   AND members.look_for = look_for
   AND members.birthdate BETWEEN DATE_SUB(CURDATE(), INTERVAL age_end YEAR) AND DATE_SUB(CURDATE(), INTERVAL age_beginning YEAR)
   AND members.last_connection > DATE_SUB(NOW(), INTERVAL last_connection MINUTE)
   AND cities.longitude between lon1 and lon2 
   AND cities.latitude between lat1 and lat2;
 END$$

DELIMITER ;

CREATE TABLE IF NOT EXISTS `cities` (
  `id` int(10) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) DEFAULT NULL,
  `asciiname` varchar(255) DEFAULT NULL,
  `alternatenames` varchar(10000) DEFAULT NULL,
  `latitude` decimal(10,7) DEFAULT NULL,
  `longitude` decimal(10,7) DEFAULT NULL,
  `country_code` char(2) DEFAULT NULL,
  `modification_date` date DEFAULT NULL,
  `country_id` int(10) unsigned DEFAULT '0'
) DEFAULT CHARSET=utf8;

INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25, 'Zorkot', 'Zorkot', 'Vulusvali-Zorkot,Woludwali Zorkot,Woludwālī Zōṟkōt,Woluswali Zorkot,Woluswali Zurkowt,Woluswalī Zūrkowt,Woluswālī Zōṟkōt,Wuleswali Zor Kot,Wulêswālī Zōr Kōṯ,Zarkot,Zor Kot,Zorkot,Zowr Kowt,Zowṟ Kowṯ,Zur Kowt,Zurkot,Zōr Kōṯ,Zūr Kowṯ,Zūrkōt,زور کوټ', 33.5414900, 69.7344600, 'AF', '2013-04-03', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26, 'Wulêswālī Bihsūd', 'Wuleswali Bihsud', 'Behsud,Behsūd,Markaz-e Bihsud,Markaz-e Bihsūd,Olusvali Behsowd,Olusvālī Behsowd,Oluswali Behsud,Oluswālī Behsūḏ,Ulusvali-Bikhsud,Wuleswali Bihsud,Wuluswali Bihsud,Wuluswālī Bihsūd,Wulêswālī Bihsūd,mrkz bhswd,wlswaly bhswd,مرکز بهسود,ولسوالی بهسود', 34.3436000, 67.9056700, 'AF', '2012-08-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27, 'Kuhsān', 'Kuhsan', 'Kohistan,Kohsan,Kohsān,Koshan,Kuhestan,Kuhsan,Kuhsān,Kōhistān,Kūhestān,khsan,kwhstan,Кошан,کهسان,کوهستان', 34.6538900, 61.1977800, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28, 'Lāsh', 'Lash', 'Kohestan,Kohestān,Laorlash,Laorlush,Las,Lash,Las̄,Laurlas,Laurlash,Lawlas,Lawlash,Lawlāsh,Lawlās̄,Lowlash,Lowlāsh,Lowr Lash,Lowr Lāsh,Lāorlash,Lāorlush,Lāsh,lash,lwlash,لاش,لولاش', 35.3782000, 64.7745700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29, 'Tukzār', 'Tukzar', 'Kala Sangcharak,Kala Sangchārak,Qal`eh Sangcharek,Qala Sangcharak,Qal‘eh Sangchārek,Sangcarak,Sangcharak,Sangcārak,Takzar,Tokzar,Tokzār,Tuksar,Tukzar,Tukzār,Tākzār,Tūkzār,tkzar,twkzar,Токзар,توکزار,تکزار', 35.9483100, 66.4213200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30, 'Mīray', 'Miray', 'Miray,Miri,Miṟay,Mīray,Mīrī,Salgar,Shalgar,S̄algaṟ,myry,ميری', 33.3246200, 68.4406800, 'AF', '2013-03-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31, 'Āq Kupruk', 'Aq Kupruk', 'Ak Kuprak,Ak Kupruk,Aq Kubruk,Aq Kupruk,Keshendah,Keshende,Keshendeh,Keshindeh,Keshīndeh,aq kbrk,aq kprk,Āq Kubruk,Āq Kupruk,آق کبرک,آق کپرک', 36.0835200, 66.8402900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32, 'Zurmat', 'Zurmat', 'Bazar-e Zurmat,Bāzār-e Zurmat,Zarmal,Zormat,Zurmat,Zuṟmat,bazar zrmt,zrmt,بازار زرمت,زرمت', 33.4377800, 69.0277400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33, 'Zaybāk', 'Zaybak', 'Zaybak,Zaybāk,Zebak,Zeybak,Zeybāk,Zibak,Zēbāk,Zībāk,zybak,زیباک', 36.5294700, 71.3441000, 'AF', '2013-12-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34, 'Zīārat-e Shāh Maqşūd', 'Ziarat-e Shah Maqsud', 'Sah Agha,Shab Maqsud,Shah Agha,Shah Maksud,Shah Maqsud,Shakhaga,Shāb Maqsūd,Shāh Maqsūd,Shāh Āghā,Ziarat Shah Maqsud,Ziarat-Shakh-Maksud,Ziarat-e Shah Maqsud,Ziārat Shāh Maqsūd,Zyarate Sah Maqsud,Zyārate Šāh Maqsūd,Zīārat-e Shāh Maqşūd,shah agha,zyart shah mqswd,Šah Āghā,زيارتٔ شاه مقصود,زیارت شاه مقصود,شاه آغا', 31.9848000, 65.4736000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35, 'Zindah Jān', 'Zindah Jan', 'Fusanj,Fushanj,Fus̄anj,Fūshanj,Zendajan,Zendeh Jan,Zendeh Jān,Zenḏajān,Zindah Jan,Zindah Jān,Zindajan,Zindajān,zndh jan,زنده جان', 34.3426400, 61.7467500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36, 'Zarghūn Shahr', 'Zarghun Shahr', 'Katawaz,Katāwāz,Khayr Kot,Khayr Kut,Khayr Kūṯ,Khayṟ Kot,Zaraghun Sahr,Zaraghūn S̄ahr,Zarghun Sahr,Zarghun Shahr,Zarghūn Shahr,Zargun Shahr,Zargunsahr,Zaṟghun Sahr,Zaṟgūns̄ahr,zrghwn shhr,زرغون شهر', 32.8473400, 68.4457300, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37, 'Zaṟah Sharan', 'Zarah Sharan', 'Sharan,Sharnah,Sherana,Sheranna,Zara Saran,Zara Šaran,Zara-Sharan,Zarah Sharan,Zareh Sharan,Zaṟah Sharan,زړه شرن', 33.1464100, 68.7921300, 'AF', '2014-02-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38, 'Zaranj', 'Zaranj', 'Sarandsch,ZAJ,Zaranas,Zarandj,Zarandz,Zarandzas,Zarandzh,Zarandż,Zarandžas,Zarang,Zarani,Zaranj,Zaranĝ,Zerenc,Zhazang,Zərənc,zaranja,zha lan ji,zrnj,Зарандж,Зарани,Заранҷ,زرنج,ज़रंज,扎兰季', 30.9596200, 61.8603700, 'AF', '2013-10-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39, 'Zamtō Kêlay', 'Zamto Kelay', 'Zamto,Zamto Kalay,Zamto Kelay,Zamtukalay,Zamtō,Zamtō Kêlay,zmtw,zmtw kly,زمتو,زمتو کلی', 32.3726000, 66.1770800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40, 'Yangī Qal‘ah', 'Yangi Qal`ah', 'Yangi Kala,Yangi Qal`ah,Yangi Qal`eh,Yangi Qala,Yangī Qal‘ah,Yangī Qal‘eh,Yengi Qal`eh,Yengī Qal‘eh,ینگی قلعه', 37.4657200, 69.6113100, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41, 'Yaḩyá Khēl', 'Yahya Khel', 'Ya Khel,Yahya Khel,Yahya Kheyl,Yahyakhel,Yakh''yakheyl'',Yakh’yakheyl’,Yaḩyá Khēl,Yaḩyā Kheyl,Yaḩyākhēl,Yehyakhel,Yeḩyākhēl,یحیى خېل', 32.9374200, 68.6462200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42, 'Wāshēr', 'Washer', 'Vashir,Vāshīr,Waser,Washar,Washayr,Washer,Washār,Wāshayr,Wāshēr,Wāsēṟ,washyr,واشیر', 32.2512200, 63.8555300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43, 'Tōrmay', 'Tormay', 'Qal''ah-ye Tormay,Qal’ah-ye Tōrmay,Tormay,Turmay,Tōrmay,Tōṟmay,Tūrmay,twrmy,تورمی,قلعه تورمی', 33.6884700, 68.4020500, 'AF', '2013-01-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44, 'Tūlak', 'Tulak', 'Tulak,Tūlak,twlk,تولک', 33.9750900, 63.7286800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45, 'Tītān', 'Titan', 'Deh Titan,Deh Titān,Saghar,Sāghar,Titan,Tītān,saghr,tytan,تیتان,ساغر', 33.6903200, 63.8636100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46, 'Tīr Pul', 'Tir Pul', 'Tir Pol,Tir Pul,Tirpul,Tīr Pol,Tīr Pul,tyr pl,تیر پل', 34.5943100, 61.2689500, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47, 'Taywarah', 'Taywarah', 'Qal`eh-i-Ghor,Qal‘eh-i-Ghor,Taiwara,Taiwāra,Taywarah,Teyvareh,tywrh,تيوره', 33.5211800, 64.4211600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48, 'Bāzār-e Tashkān', 'Bazar-e Tashkan', 'Bazar-e Tagan,Bazar-e Tashgan,Bazar-e Tashkan,Bazar-i-Teskan,Bāzār-e Tagān,Bāzār-e Tashgān,Bāzār-e Tashkān,Bāzāṟ-i-Tēs̄kān,Tashkan,Tashkān,Taskan,Tas̄kān,Teshkan,Teshkān,bazar tshkan,tshkan,بازار تشکان,تشکان', 36.8816800, 70.2767400, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49, 'Tarinkot', 'Tarinkot', 'TII,Tareen,Tarin Kowt,Tarinkot,Tarīn Kowt,Tirin,Tirinkot,tryn kwt,ترين كوت', 32.6299800, 65.8780600, 'AF', '2013-08-02', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50, 'Taloqan', 'Taloqan', 'Khanabad,TQN,Taikhan,Taleqan,Talikan,Talikhan,Taliqan,Talkan,Talokan,Taloqan,Talugan,Talukan,Talukanas,Taluqan,Tologan,Tâloqân,Tāleqān,Tāloqān,Tāluqān,Tālīqān,ta lu kan,talokam,talokuvan,taloqana,talqan,Таликан,Талукан,تالقان,तालोक़ान,तालोकां,தலோகுவான்,თალიკანი,塔卢坎', 36.7360500, 69.5345100, 'AF', '2013-05-11', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51, 'Tagāw-Bāy', 'Tagaw-Bay', 'Bai,Bay,Bāy,Tagaw-Bay,Tagaw-bay,Tagaw-bāy,Tagow Bay,Tagow Bāy,Tagāw-Bāy,tgaw bay,تگاو بای', 35.6994100, 66.0616400, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52, 'Tagāb', 'Tagab', 'Pagab,Tagab,Tagao,Tagāb,tgab,تگاب', 34.8550100, 69.6491700, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53, 'Markaz-e Ḩukūmat-e Sulţān-e Bakwāh', 'Markaz-e Hukumat-e Sultan-e Bakwah', 'Bakva,Bakvā,Bakwah,Bakwāh,Markaz-e Hokumat-e Soltan-e Bakva,Markaz-e Hukumat-e Sultan-e Bakwa,Markaz-e Hukumat-e Sultan-e Bakwah,Markaz-e Ḩokūmat-e Solţān-e Bakvā,Markaz-e Ḩukūmat-e Sulţān-e Bakwā,Markaz-e Ḩukūmat-e Sulţān-e Bakwāh,Markaze Hokumate Sultane Bakwa,Markazi-Khukumati-Sultani-Bakva,Maṟkaze Ḩokūmate Sulṯāne Bakwā,Soltan Bakvah,Soltan-e Bakva,Solţān Bakvāh,Solţān-e Bakvā,Sultan Bakhwa,Sultan Bakwa,Sultan-e Bakwah,Sultane Bakwa,Sultān Bakhwa,Sultān Bakwa,Sulţān-e Bakwāh,Sulţāne Bakwā,mrkz hkwmt sltan bkwa,mrkz hkwmt sltan bkwah,sltan bkwah,سلطان بکواه,مرکز حکومت سلطان بکوا,مرکز حکومت سلطان بکواه', 32.2413900, 62.9493600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54, 'Spīn Bōldak', 'Spin Boldak', 'Spin Baldak,Spin Boldak,Spin Buldak,Spīn Baldak,Spīn Bōldak,Spīn Būldak,spyn bwldk,سپین بولدک', 31.0057500, 66.4000100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55, 'Spērah', 'Sperah', 'Spera,Sperah,Speyrah,Spērah,Spēṟa,spyrh,سپيره,سپېره', 33.2020400, 69.5152000, 'AF', '2014-04-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56, 'Sōzmah Qal‘ah', 'Sozmah Qal`ah', 'Saozma Kala,Saozma Qala,Sowzmeh Qal`eh,Sowzmeh Qal‘eh,Sozmah Qal`ah,Sāozma Kala,Sōzmah Qal‘ah,سوزمه قلعه', 36.0991600, 66.2082300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57, 'Siyāhgird', 'Siyahgird', 'Siah Gerd,Siah Gird,Siakhgird,Siyahgird,Siyāhgird,Siāh Gird,Syahgerd,Syāhgerd,Sīāh Gerd,syah grd,سیاه گرد', 35.0055300, 68.8557800, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58, 'Sheywah', 'Sheywah', 'Kuz Konar,Kūz Konar,Sewa,Sheva,Shewa,Shewah,Sheywah,Shiveh,Shēwah,Shīveh,S̲h̲ēwah,shywh,Šēwa,شيوه,ښېوه', 34.5716900, 70.5885900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59, 'Shīnḏanḏ', 'Shindand', 'Asfazar,Asfazār,OAH,Sabzavar,Sabzavār,Sabzawar,Sabzevar,Sabzevār,Shindand,Shīndand,Shīnḏanḏ,Sindand,shyndnd,Šīndand,Шинданд,شيندند,شیندند,شینډنډ', 33.3029400, 62.1474000, 'AF', '2017-02-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60, 'Shaykh Amīr Kêlay', 'Shaykh Amir Kelay', 'Sekhamir Kalay,Shaykh Amir,Shaykh Amir Kelay,Shaykh Amīr,Shaykh Amīr Kêlay,Shekh Amir Kelay,Sheykh Amir Kalay,Sheykh Amīr Kalay,Sheykhamirkalay,Shēkh Amīr Kêlay,shykh amyr,shykh amyr kly,Šēkhāmir Kalay,شیخ امیر,شیخ امیر کلی,قريۀ شيخ امير', 33.2874400, 69.9128300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61, 'Qāshqāl', 'Qashqal', 'Kakshal,Kashkal'',Kashkal’,Qaqshal,Qaryah-ye Qashqal,Qaryah-ye Qāshqāl,Qashqal,Qasqal,Qāqshāl,Qāshqāl,Qāšqal,Senwari,Shenvari,Shenvārī,Shenwari,Shenwārī,Shinvari,Shinwari,Shinwārī,Sinwar,S̄inwāṟ,qashqal,qryh qashqal,shnwary,Šenwāri,شنواری,قاشقال,قريه قاشقال', 35.0397500, 69.0068500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62, 'Shibirghān', 'Shibirghan', 'Markaz-e Wilayat-e Shibirghan,Markaz-e Wilāyat-e Shibirghan,Seberghan,Sebeṟghān,Shahr-e Sheberghan,Shahr-e Sheberghān,Shayurgan,Shebergan,Sheberghan,Sheberghān,Sheberkhan,Shefrogan,Shibarghan,Shibarghān,Shibergan,Shibirghan,Shibirghān,mrkz wlayt shbrghan,shbrghan,shbrghn,Шеберган,شبرغان,شبرغن,مرکز ولايت شبرغان', 36.6675700, 65.7529000, 'AF', '2013-06-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63, 'Shwāk', 'Shwak', 'Shavak,Shavāk,Shvak,Shwak,Shwāk,Swak,S̲h̲wāk,shwak,Šwāk,شواک,ښواک', 33.4238600, 69.3768400, 'AF', '2012-06-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64, 'Shahr-e Şafā', 'Shahr-e Safa', 'Sahre Safa,Schachri Ssafa,Shahr-e Safa,Shahr-e Şafā,Shahr-i-Safa,Shahr-i-Sāfa,Shakhri-Safa,shhr sfa,Šahre Şafā,شهر صفا', 31.8034700, 66.3237600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65, 'Shahrān', 'Shahran', 'Sahran,Sahṟān,Shaharan,Shaharān,Shahran,Shahrān,shhran,شهران', 36.9798400, 70.7392800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66, 'Shahrak', 'Shahrak', 'Bati Dara,Kala Shaharak,Kala Shahrak,Kala Shahārak,Markaz-e Shahrak,Qal`eh Shaharak,Qal`eh-ye Bati Darrah,Qala Bati Dara,Qala Batī Dara,Qala Shaharak,Qala Shahārak,Qala Sharak,Qal‘eh Shahārak,Qal‘eh-ye Bati Darrah,Sahrak,Shahrag,Shahrak,Shakhrak,Sharak,Shāhrag,Shāhrak,Wala Shahrak,shhrk,Šahrak,شهرک', 34.1073700, 64.3052000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67, '‘Alāqahdārī Shāh Jōy', '`Alaqahdari Shah Joy', 'Alakadari-Shakhdzhoy,Alaqadari Sahjoy,Alāqadārī Šāhjoy,Sahjoy,Sha Joi,Shah Joy,Shah Juy,Shahjui,Shajuy,Shāh Jōy,Shāh Jūy,Shāhjui,Shājūy,S̄āhjōy,`Alaqahdari Shah Joy,shah jwy,شاه جوی,علاقه داری شاه جوی,‘Alāqahdārī Shāh Jōy', 32.5215400, 67.4131500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68, 'Wulêswālī Sayyid Karam', 'Wuleswali Sayyid Karam', 'Sayd Karam,Sayed Karam,Sayḏ Kaṟam,Seyyed Karam,Vulusvali Saidkaram,Woluswali Saydkaram,Woluswali Seyyed Karam,Woluswāli Sayḏkaṟam,Woluswālī Seyyed Karam,Wuleswali Sayyid Karam,Wulêswālī Sayyid Karam,wlswaly syd krm,wlwswly syd krm,ولسوالی سید کرم,ولوسولی سيد كرم', 33.6905600, 69.3688100, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69, 'Markaz-e Sayyidābād', 'Markaz-e Sayyidabad', 'Markaz-e Sayyidabad,Markaz-e Sayyidābād,Markaz-e Seyydabad,Markaz-e Seyydābād,Markaz-e Seyyedabad,Markaz-e Seyyedābād,Markaze Saydabad,Markazi-Saidabad,Maṟkaze Sayḏābāḏ,Saydabad,Sayyidabad,Sayyidābād,Sayḏābāḏ,Seyyedabad,Seyyedābād,mrkz syd abad,syd abad,سيد آباد,مرکز سيد آباد', 34.0003700, 68.7134600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70, 'Şayād', 'Sayad', 'Saiad,Saiyid,Sayad,Seyyed,syad,Şayād,صیاد', 36.1352900, 65.8297000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71, 'Sidqābād', 'Sidqabad', 'Makhmudraki,Qal''eh-i-Wazir,Qal`a Wazir,Qal`ah-ye Wazir,Qal‘a Wazīṟ,Qal‘ah-ye Wazīr,Qal’eh-i-Wazīr,Sedgabad,Sedgābād,Sedqabad,Seḏqābāḏ,Sidqabad,Sidqābād,sdg abad,sdq abad,سدق آباد,سدگ آباد,قلعۀ وزیر', 35.0229800, 69.3511200, 'AF', '2013-08-02', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72, 'Sāyagaz', 'Sayagaz', 'Sagaz,Sayagaz,Sāgaz,Sāyagaz,sagz,saygz,ساگز,سایگز', 32.5652100, 67.0332400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73, 'Sar-e Tayghān', 'Sar-e Tayghan', 'Sar Teghan,Sar-e Tayghan,Sar-e Tayghān,Saṟ Tēghān,sr tyghan,سر تیغان', 33.5099800, 65.6763200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74, 'Sarōbī', 'Sarobi', 'Markaz-e Sorubi,Markaz-e Sorūbī,Sarobi,Sarowbi,Sarowbī,Sarubi,Sarōbī,Sorubay,Sorubi,Sorūbay,Sorūbī,Surawbi,Surobay,Surubay,Surūbay,Sūrāwbī,Sūṟōbay,srwby,سروبی', 34.5896200, 69.7600500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75, 'Sar Kāṉī', 'Sar Kani', 'Sar Kani,Sar Kāṉī,Sarkani,Sarkanu,Sarkānī,Sarkānū,Serkani,Seṟkāṉi,Sirkhani,Sirkhānī,srkany,سركانی,سرکاڼی', 34.7902300, 71.1096200, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76, 'Sarfirāz Kalā', 'Sarfiraz Kala', 'Qal''ah-ye Sar Firaz,Qal’ah-ye Sar Firāz,Sarferaz Kala,Sarferāz Kalā,Sarfiraz Kala,Sarfirazkala,Sarfirāz Kalā,srfraz kla,سرفراز کلا,قلعه سر فراز', 32.9833300, 67.9651700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77, 'Sar-e Pul', 'Sar-e Pul', 'Sar-e Pol,Sar-e Pul,Sar-i-Pul,Sari-Pul'',sr pl,Сари-Пуль,سر پل', 36.2154400, 65.9324900, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78, 'Sar Chakān', 'Sar Chakan', 'Sar Cakan,Sar Chakan,Sar Chakān,Saṟ Cakān,sr chkan,سر چکان', 35.7017700, 65.2305500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79, 'Sangīn', 'Sangin', 'Sandzhin,Sangin,Sangīn,Sarban Qal`eh,Sārbān Qal‘eh,sngyn,Санджин,سنگین', 32.0727500, 64.8359000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80, 'Sang-e Māshah', 'Sang-e Mashah', 'Sang-e Mashah,Sang-e Masheh,Sang-e Māshah,Sang-e Māsheh,Sang-i-Macha,Sang-i-Masha,Sang-i-Māsha,Sange Masa,Sange Māša,sng mashh,سنگ ماشه', 33.1396000, 67.4404600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81, 'Sang-e Chārak', 'Sang-e Charak', 'Sang-e Charak,Sang-e Chārak', 35.8497200, 66.4369400, 'AF', '2016-03-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82, 'Sang Atesh', 'Sang Atesh', 'Sang Ates Mamaka,Sang Atesh Mamakah,Sang Atish Mamakah,Sang Ātesh Māmākah,Sang Ātes̄ Māmāka,Sang Ātish Māmākah,sng atsh mamakh,سنگ آتش ماماکه', 35.2480000, 63.0044000, 'AF', '2010-08-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83, 'Sangar Sarāy', 'Sangar Saray', 'Sang-i-Sarai,Sang-i-Sarāi,Sangar,Sangar Sarai,Sangar Saray,Sangar Sarāy,Sangar Sarāī,Sangarsaray,sngr sray,سنگر سرای', 34.4074400, 70.6393700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84, 'Aībak', 'Aibak', 'Aibak,Aybak,Aībak,Eybak,Haibak,Samagan,Samangan,Samangān,aybk,smngan,Āybak,Саманган,آیبک,ایبک,سمنگان', 36.2646800, 68.0155100, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85, 'Rū-ye Sang', 'Ru-ye Sang', 'Roysang,Ru-ye Sang,Ruisang,Ruy Sang,Rū-ye Sang,Rūisang,Rūy Sang,rwy sng,روی سنگ,Ṟōysang', 35.3199900, 67.6338700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86, 'Rūdbār', 'Rudbar', '', 30.1500000, 62.6000000, 'AF', '2006-01-17', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87, 'Rustāq', 'Rustaq', 'Rostaq,Rostāq,Rustak,Rustaq,Rustāq,rstaq,رستاق,Ṟustāq', 37.1260400, 69.8304500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88, 'Rabāţ-e Sangī-ye Pā’īn', 'Rabat-e Sangi-ye Pa''in', 'Rabat-e Sangi,Rabat-e Sangi-ye Pa''in,Rabat-i-Sangi-Pa''in,Rabati-Sangiyi-Pain,Rabāţ-e Sangī,Rabāţ-e Sangī-ye Pā’īn,Rabāṯ-i-Sangi-Pā’īn,Robat-e Sangi-ye Pa''in,Robāţ-e Sangī-ye Pā’īn,rbat sngy,rbat sngy payyn,رباط سنگی,رباط سنگی پائین', 34.7995100, 62.1391700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89, 'Rāmak', 'Ramak', 'Rahmak,Ramak,Rāmak,ramk,رامک', 33.5223400, 68.6264000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90, 'Qurghān', 'Qurghan', 'Bazar-e Qurghan,Bāzār-e Qurghān,Kurghan,Kurghān,Qorghan,Qorghān,Qurghan,Qurghān,Quṟghān,bazar qrghan,qrghan,بازار قرغان,قرغان', 36.9193900, 65.0649000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91, 'Quchanghī', 'Quchanghi', 'Kuchangi,Qocanghi,Qocangli,Qochanghi,Qochanghī,Qochangi,Qochangī,Qočanghi,Quchanghi,Quchanghī,Qōchanghī,qchnghy,qwchnghy,قوچنغی,قچنغی', 34.0618300, 66.2780100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92, 'Sangalak-i-Kaisar', 'Sangalak-i-Kaisar', 'Qaisar,Qaysar,Qaysāṟ,Qaīşār,Qeysar,Qeyşār,Sangalak-i-Kaisar,qysar,قیصار', 35.6874700, 64.2931800, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93, 'Qarqīn', 'Qarqin', 'Karkin,Karkin Bazar,Kkhanika,Qarkin,Qarqin,Qarqīn,Quarkin,qrqyn,Кханика,قرقین', 37.4185300, 66.0435800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94, 'Qarghah’ī', 'Qarghah''i', 'Deh Mazang,Dekhmazang,Kargay,Karghai,Qargha''i,Qarghah,Qarghah''i,Qarghah’ī,Qaṟghah’ī,Qaṟgha’i,dh mzng,qrghh yy,ده مزنگ,قرغه ئی', 34.5540200, 70.2429200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95, 'Qarchī Gak', 'Qarchi Gak', 'Qarchi Gak,Qarchī Gak,qrchy gk,قرچی گک', 37.0399900, 66.7889100, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96, 'Qarāwul', 'Qarawul', 'Hazrat Imam,Hazrat Imam Saiyid,Hazrat Imām,Karaul,Qaravol,Qarawul,Qarāvol,Qarāwul,Qaṟāwul,qrawl,قراول', 37.2195900, 68.7802000, 'AF', '2013-09-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97, 'Qarah Bāgh', 'Qarah Bagh', 'Karabagh,Karabāgh,Kharabagh,Qara Baqh,Qarabagh,Qarabāgh,Qarah Bagh,Qarah Bāgh,Qareh Bagh,Qareh Bāgh,Qaṟa Bāqh,qrh bagh,قره باغ', 34.9402300, 61.7758900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98, 'Qarah Bāgh', 'Qarah Bagh', 'Karabag,Qarabagh,Qarah Bagh,Qarah Bāgh,Qarehbagh,Qarehbāgh,Qaṟabāgh,qrh bagh,قره باغ', 33.1980100, 68.1079800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99, 'Qala i Naw', 'Qala i Naw', 'Kala Nao,Kalai-Naw,Kalayi-Nau,LQN,Qal''eh Now,Qal`a-i-Naw,Qal`ah-ye Now,Qal`eh Nau,Qal`eh-ye Now,Qala Nau,Qala Naw,Qala i Naw,Qala-e-Nau,Qala-i-Nau,Qalaenaw,Qal‘a-i-Naw,Qal‘ah-ye Now,Qal‘eh Nau,Qal‘eh-ye Now,Qal’eh Now,Qula-i-nau,Shehr Qaleh,Shehr Qeleh,qlʿە nw,قلعۀ نو', 34.9873500, 63.1289100, 'AF', '2013-10-26', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100, 'Qal‘ah-ye Kūf', 'Qal`ah-ye Kuf', 'Kala Kuf,Qal''a-i-Kuf,Qal`ah-ye Kuf,Qal`eh-ye Kuf,Qala-i-Kof,Qala-i-Kot,Qal‘ah-ye Kūf,Qal‘eh-ye Kūf,Qal’a-i-Kūf,قلعۀ کوف', 38.0411900, 70.4729800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101, 'Qal‘ah-ye Kuhnah', 'Qal`ah-ye Kuhnah', 'Qal`a-i- Kuhna,Qal`ah-ye Kuhnah,Qal`eh-ye Kohneh,Qal‘a-i- Kuhna,Qal‘ah-ye Kuhnah,Qal‘eh-ye Kohneh,قلعۀ کهنه', 32.6159100, 63.6668100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102, 'Qal‘ah-ye Shahr', 'Qal`ah-ye Shahr', 'Faoghan,Fāoghān,Kala Shahar,Kala Shāhar,Qal`a-i-Sahr,Qal`ah-ye Shahr,Qal`eh Shahar,Qal`eh Shahr,Qala Sahr,Qala Shahar,Qala Shāhār,Qala S̄ahṟ,Qal‘a-i-S̄ahṟ,Qal‘ah-ye Shahr,Qal‘eh Shahr,Qal‘eh Shāhār,قلعۀ شهر', 35.5472900, 65.5676000, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103, 'Qalāt', 'Qalat', 'Kalat,Kalat-i-Ghilzai,Kalāt-i-Ghilzai,Qalat,Qalāt,qlat,قلات', 32.1057500, 66.9083300, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104, 'Qal‘ah-ye Shāhī', 'Qal`ah-ye Shahi', 'Kalashakhi,Qal`a Sahi,Qal`ah-ye Shahi,Qal`eh-ye Shahi,Qalla-ISahi,Qalła-IŠāhi,Qal‘a S̄āhi,Qal‘a Šāhi,Qal‘ah-ye Shāhī,Qal‘eh-ye Shāhī,قلعۀ شاهی', 34.6492100, 70.5914000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105, 'Qādis', 'Qadis', 'Kadis,Qaddis,Qades,Qadis,Qādes,Qādis,Qāḏis,qads,قادس', 34.8085000, 63.4300300, 'AF', '2010-08-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106, 'Pārūn', 'Parun', 'Parun,Poruns,Prasun,Prasungul,Prasûn,Puruns,Pārūn,parwn,prns,پارون,پرنس', 35.4206400, 70.9226100, 'AF', '2014-01-08', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107, 'Pul-e Khumrī', 'Pul-e Khumri', 'Pol-e Khomri,Pol-e Khomrī,Pul-e Khumri,Pul-e Khumrī,Pul-i-Khomri,Pul-i-Khumri,Pule Khumri,Pule Khumṟi,Puli-Khumri,pl khmry,Пули-Хумри,پل خمری', 35.9445800, 68.7151200, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108, 'Pul-e ‘Alam', 'Pul-e `Alam', 'Pol-e `Alam,Pol-e ‘Alam,Pul-e `Alam,Pul-e ‘Alam,Pul-i-Alam,Pule Alam,پل علم', 33.9952900, 69.0227400, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109, 'Pasnay', 'Pasnay', 'Kohistanat,Kōhistānāt,Pasnay,kwhstanat,psny,پسنی,کوهستانات', 35.7666400, 65.7648600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110, 'Pāshmūl', 'Pashmul', 'Pashmol,Pashmul,Pasmul,Pašmūl,Pāshmūl,pashmwl,pshmwl,پاشمول,پشمول', 31.5572000, 65.4343000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111, 'Pasāband', 'Pasaband', 'Pasaband,Pasāband,psabnd,پسابند', 33.6895600, 64.8531000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112, 'Panjāb', 'Panjab', 'Pandzhab,Pandzhau,Panjab,Panjao,Panjaw,Panjāb,pnjab,Панджаб,پنجاب', 34.3879500, 67.0232700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113, 'Paghmān', 'Paghman', 'Paghman,Paghman Palace,Paghmān,Pagman,pghman,Пагман,پغمان', 34.5878700, 68.9509100, 'AF', '2012-08-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114, 'Ōmnah', 'Omnah', 'Omna,Omnah,Owmneh,awmnh,Ōmna,Ōmnah,اومنه', 32.9002900, 68.7962700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115, 'Qaryeh-ye Owbeh', 'Qaryeh-ye Owbeh', 'Caharmahale Obe,Cahāṟmahale Ōbē,Chahar Mahall-e Obeh,Chahār Maḩall-e Obeh,Obe,Obeh,Owbey,Owbi,Owbī,Qaryeh-ye Owbeh,awbh,Ōbêh,Ōbē,اوبه', 34.3697200, 63.1763900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116, 'Uruzgān', 'Uruzgan', 'Orozgan,Orozgān,Oruzgan,Orūzgān,Qala-i-Hazar Qadam,Qala-i-Hazār Qadam,URZ,Uruzgan,Uruzgān,arwzgan,arzgan,ارزگان,اروزگان', 32.9277500, 66.6325300, 'AF', '2017-02-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117, 'Urgūn', 'Urgun', 'Orgun,Orgūn,Urgun,Urgūn,argwn,ارگون', 32.9411100, 69.1800000, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118, 'Nūsay', 'Nusay', 'Kusai,Nesay Darwaz,Nesay Ḏaṟwāz,Nusai,Nusay,Nūsay,Qaryah-ye Nusay,nwsy,qryh nsy,قريه نسی,نوسی', 38.4435000, 70.8041300, 'AF', '2013-09-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119, 'Nūrgal', 'Nurgal', 'Nur Gol,Nurgal,Nurgal'',Nurgal’,Nurgul,Nuṟgal,Nūr Gol,Nūrgal,Nūrgul,nwr gl,نور گل', 34.6134100, 70.7649800, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120, 'Now Zād', 'Now Zad', 'Naozad,Nau-Zad,Nauzad,Nauzād,Naw Zad,Naw Zāḏ,Now Zad,Now Zād,Nozad,Nāozād,nw zad,نو زاد', 32.4031500, 64.4695900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121, 'Nīlī', 'Nili', 'Nili,Nīlī,Qaryah-e Nili,Qaryah-e Nīlī,nyly,نیلی', 33.7217800, 66.1302300, 'AF', '2014-01-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122, 'Nayak', 'Nayak', 'Naiak,Naik,Nayak,Neyak,Nāik,Nāyak,nayk,nyk,نايک,نيک', 34.7341400, 66.9529200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123, 'Nāyak', 'Nayak', 'Nayak,Nāyak,nayk,نایک', 32.5723000, 66.7740300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124, 'Now Dahānak', 'Now Dahanak', 'Navadanak,Naw Danak,Nawdanak,Nawdānak,Now Dahanak,Now Dahānak,Now Danak,Now Dānak,Nāw Dānak,nw dank,nw dhank,نو دانک,نو دهانک', 35.6239800, 70.0051100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125, 'Ōkak', 'Okak', 'Navar,Navor,Nawur,Nāvar,Nāvor,Nāwuṟ,Okak,Owkak,awkk,Ōkak,Окак,اوکک', 33.8979300, 67.9565200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126, 'Nāṟay', 'Naray', 'Narai,Naray,Naray Kelay,Nari,Nāray,Nāraī,Nāṟay,Nāṟay Kelay,nry,ناړی,نری', 35.2199500, 71.5228400, 'AF', '2014-01-08', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127, 'Narang', 'Narang', 'Narang,Naṟang,nrng,نرنگ', 34.7600900, 71.0473800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128, 'Nīkêh', 'Nikeh', 'Naka,Nakah,Nekah,Nikeh,Nīkêh,nkh,nykh,نيکه,نکه', 33.1893400, 69.2717900, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129, 'Nahrīn', 'Nahrin', 'Nahrin,Nahrīn,Nakhrin,Narain,Narin,Narīn,nhryn,Нахрин,نهرین', 36.0649000, 69.1334300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130, 'Ḩukūmat-e Nād ‘Alī', 'Hukumat-e Nad `Ali', 'Hokumat-e Nad `Ali,Hokumat-e Nad-e `Ali,Hokumati Nad-e `Ali,Hukumat-e Nad `Ali,Khukumati-Nadi-Ali,Nad `Ali,Nad-e `Ali,Nad-i-Ali,Nad`ali,Nade Ali,Nād ‘Alī,Nād-e ‘Alī,Nād-i-Alī,Nāde Ali,Nād‘alī,حكومت ناد علی,حكومتٔ نادٔ علی,حکومتی ناد علی,ناد علی,Ḩokūmat-e Nād ‘Alī,Ḩokūmat-e Nād-e ‘Alī,Ḩokūmatī Nād-e ‘Ali,Ḩokūmatī Nād-e ‘Alī,Ḩukūmat-e Nād ‘Alī', 31.6428600, 64.2398200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131, 'Mūsá Qal‘ah', 'Musa Qal`ah', 'De Musa Qal`eh,De Mūsá Qal‘eh,Musa Kala,Musa Qal`a,Musa Qal`ah,Musa Qal`eh,Musa Qala,Musa Qaleh,Musakala,Mūsa Qal‘a,Mūsá Qal‘ah,Mūsá Qal‘eh,Mūsā Qal‘ah,Takhta Pul,موسى قلعه', 32.4456500, 64.7448600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132, 'Bala Murghab', 'Bala Murghab', 'Bala Murghab,Bālā Murghāb,Bālā Muṟghāb,Morghab,Morghāb,bala mrghab,بالا مرغاب', 35.5840800, 63.3288600, 'AF', '2010-08-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133, 'Muqêr', 'Muqer', 'Moqor,Moqur,Moquṟ,Mukar,Mukur,Muqer,Muqur,Muqêr,Qala-i-Sarkari,Qala-i-Sarkāri,mqr,مقر', 32.8200900, 67.7693400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134, 'Muḩammad Āghah Wuluswālī', 'Muhammad Aghah Wuluswali', 'Deh-e Muhammad Aghah,Deh-e Muḩammad Āghah,Mohammad Agha,Mohammad Aghah,Moḩammad Āghah,Moḩammad Āghā,Muhammad Agha,Muhammad Aghah Wuluswali,Muhammad Āgha,Muḩammad Āghah Wuluswālī,mhmd aghh wlswaly,محمد آغه ولسوالی', 34.2142200, 69.1002600, 'AF', '2012-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135, 'Mīzān ‘Alāqahdārī', 'Mizan `Alaqahdari', 'Mizan,Mizan `Alaqadari,Mizan `Alaqahdari,Mizan-Alakadari,Mizani,Mizān ‘Alāqadārī,Mizān ‘Alāqahdārī,Mīzān,Mīzān ‘Alāqahdārī,Mīzānī,`Alaqadari,myzan,ميزان,ميزان علاقه داری,‘Alāqadārī', 32.1763500, 66.5127100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136, 'Mīr Bachah Kōṯ', 'Mir Bachah Kot', 'Mir Bachah Kot,Mir Bachcheh Kowt,Mir Bachcheh Kut,Mir Bachchen Kut,Mir Bacheh Kowt,Mir Bacheh Kut,Mir Dacha Kote,Mirbaca Kot,Mirbachakot,Mīr Bachah Kōṯ,Mīr Bachcheh Kowt,Mīr Bachcheh Kūt,Mīr Bachchen Kūt,Mīr Bacheh Kowt,Mīr Bacheh Kūt,Mīrbača Kot,Sara-ye Khvajeh,Sara-ye Khwajah,Sarai Khwaja,Saray Khvajah,Saray-Khwaja,Saraykhodzha,Sarā-ye Khvājeh,Sarā-ye Khwājah,Sarāi Khwāja,Sarāy Khvājah,Saṟāy-Khwāja,myr bchh kwt,sray khwajh,سرای خواجه,مير بچه كوت,میر بچه کوټ', 34.7499900, 69.1189900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137, 'Mīrān', 'Miran', 'Miran,Mīrān,myran,ميران', 34.2203700, 68.3125900, 'AF', '2012-10-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138, 'Mīrābād', 'Mirabad', 'Mirabad,Mirabad-e Mohammad Akbar,Mīrābād,Mīrābād-e Moḩammad Akbar,myr abad,میر آباد', 30.4362400, 61.8383000, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139, 'Maymana', 'Maymana', 'Daerah Maymana,MMZ,Maimana,Maimanah,Maimāna,Majmana,Maymana,Maymanah,Maïmana,Maīmanah,Meimana,Mejmene,Meymaneh,Meymene,Mimana,Quan Maymana,Quận Maymana,mai ma na,meyamana,mymnh,Меймене,ضلع میمنہ,ميمنه ولسوالۍ,میمنه,میمنہ,मेयमना,迈马纳', 35.9213900, 64.7836100, 'AF', '2013-09-21', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140, 'Maīdān Khūlah', 'Maidan Khulah', 'Maidan Khulah,Maydan Kholeh,Maydankhula,Mayḏān Kholeh,Maīdān Khūlah,Meydan Kholeh,Meydan Khvolah,Meydān Kholeh,Meydān Khvolah,mydan khwlh,میدان خوله', 33.6491600, 69.7812000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141, 'Mingajik', 'Mingajik', 'Mengajik,Mengajīk,Mengeh Jek,Mingajek,Mingajik,Mungajik,mngjk,منگجک', 37.0279000, 66.1281700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142, 'Mehtar Lām', 'Mehtar Lam', 'Laghman,Mehtar Lam,Mehtar Lām,Mekhtarlam,Metarlam,Mir Talam Saheb Ziarat,Mitarlam,Miterlam,Mīr Talām Şāḩeb Zīārat,Nawar Lam,Nāwar Lam,mhtr lam,Митарлам,مهتر لام', 34.6713900, 70.2094400, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143, 'Mazār-e Sharīf', 'Mazar-e Sharif', 'MZR,Masar-e Scharif,Mazar-e Sarif,Mazar-e Sharif,Mazar-e Šarif,Mazar-e-Sharif,Mazar-i Szarif,Mazar-i-Sharif,Mazare Srif,Mazari Sharif,Mazari-Sharif,Mazār-e Sharīf,Mazār-e Šarīf,Mazār-i-Sharīf,Mazāre S̄rīf,majaleu-isyalipeu,mazarisharifu,mzar shryf,Мазари-Шариф,مزار شريف,مزار شریف,マザーリシャリーフ,마자르이샤리프', 36.7090400, 67.1108700, 'AF', '2017-02-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144, 'Māymay', 'Maymay', 'Mah Mayk,Mahmai,Mahmey,Maymay,Maymey,Māh Mayk,Māymay,Māymey,Māymāy,maymy,مایمی', 38.4085600, 71.0383900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145, 'Mutā Khān', 'Muta Khan', 'Mata Khan,Matā Khān,Metakhan,Metākhān,Motakhan,Motākhān,Muta Khan,Mutakhan,Mutā Khān,mta khan,متا خان', 33.2400100, 68.8663000, 'AF', '2014-02-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146, 'Mashhad', 'Mashhad', 'Mashad,Mashhad,mshhd,مشهد', 36.8166500, 70.1021100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147, 'Mardīān', 'Mardian', 'Mardian,Mardyan,Mardīān,Maṟḏyān,Mordian,Mordīān,Murdian,Murdīān,mrdyan,مردیان', 36.9925200, 66.2965400, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148, 'Mandōl', 'Mandol', 'Mandol,Mandul,Mandōl,Mandūl,Manḏōl,Mundol,Mundol'',Mundol’,Mundul,Mundūl,Munḏōl,mndwl,مندول,منډول', 35.2840300, 70.1701700, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149, 'Māmā Khēl', 'Mama Khel', 'Hashem Kheyl,Hasim Khel,Hāsim Khel,Mama Khel,Mamakheyl,Mamakheyl'',Mamakheyl’,Māmā Khēl,Māmākheyl,Sheyrzad,Sheyrzād,mama khyl,ماما خيل,ماما خېل', 34.2449400, 69.9968000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(150, 'Lashkar Gāh', 'Lashkar Gah', 'BST,Bist,Bost,Bust,Lashkar Gah,Lashkar Gāh,Lashkargah Bust,Lashkargakh,Laskargah,Las̲h̲kargāh Busṯ,Laškargāh,Nawab City,lshkr gah,Лашкаргах,لشكر گاه,لښکرگاه بسټ', 31.5938200, 64.3716100, 'AF', '2013-10-31', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(151, 'Lāsh-e Juwayn', 'Lash-e Juwayn', 'Jawain,Joveyn,Juwain,Juwayn,Juwāin,Lase Jowayn,Lash,Lash Jovayn,Lash-e Joveyn,Lash-e Joway,Lash-e Juwayn,Laso-joayn,Lāsh,Lāsh Jovayn,Lāsh-e Joveyn,Lāsh-e Joway,Lāsh-e Juwayn,Lās̄e Jowayn,Lās̄o-joayn,jwyn,lash jwy,lashi chwyn,جوين,لاش جوی,لاشِ چوين', 31.7138200, 61.6227200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(152, 'Larkird', 'Larkird', 'Lar Gerd,Largird,Largirid,Larkerd,Larkird,lrkrd,Лар Герд,لرکرد', 35.4893600, 66.6640900, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(153, 'La‘l', 'La`l', 'La`l,La`l va Sar Jangal,La`l wa Sar Jangal,La`losarjangal,Lal'',Lal’,La‘l,La‘l va Sar Jangal,La‘l wa Sar Jangal,La‘losaṟjangal,Qaryeh-ye La`l,Qaryeh-ye La‘l,لعل,لعل و سر جنگل', 34.5014100, 66.2799700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(154, 'Kushk', 'Kushk', 'Kushk,Kusk,Kus̄k,Kūshk,kshk,Кушк,کشک', 33.2956500, 61.9522100, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(155, 'Kōṯowāl', 'Kotowal', 'Kotaval'',Kotaval’,Kotawal,Kotowal,Kowtawal,Kowtawāl,Kōtawāl,Kōṯowāl,kwtwal,کوتوال,کوټوال', 34.1031900, 70.4607300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(156, 'Kushk-e Kuhnah', 'Kushk-e Kuhnah', 'Koshk,Koshk-e Kohneh,Kushk,Kushk-e Kuhnah,Kusk,Kusk-i-Kohna,Kuske Kuhna,Kus̄k-i-Kohna,Kus̄ke Kuhna,kshk khnh,کشک کهنه', 34.8711000, 62.5476200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(157, 'Kuran wa Munjan', 'Kuran wa Munjan', '''Alaqehdari-ye Koran va Monjan,KUR,Kerana va Manjah,Kiran wa Munjan,Kirān wa Munjān,Koran va Monjan,Koranomunjan,Korān va Monjān,Koṟānomunjān,Kuran wa Munjan,ʿlaqh dary kran w mnjan,علاقه داری کران و منجان,‘Alāqehdārī-ye Korān va Monjān', 36.0286600, 70.7725800, 'AF', '2017-02-25', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(158, 'Kunduz', 'Kunduz', 'Kondoz,Konduz,Kondôz,Kondūz,Kundus,Kunduz,Kunduz khot,Kunduzas,Kundúz,Kundūz,Kundūzas,Qonduz,Qondūz,Qunduz,Qundūz,Qunḏūz,Shahr-e Qondoz,UND,kantacu,kndwz,kndz,kuduza,kun dou shi,kundo~uzu,kunduja,kundujeu,kundus,kunduza,qndwz,qndz,Кундуз,Кундуз хот,قندز,قندوز,كندز,کندوز,कुंदुज़,কুন্দুজ,ਕੁੰਦੂਜ਼,கண்டசு,കുന്ദൂസ്,ყუნდუზი,クンドゥーズ,昆都士,쿤두즈', 36.7289500, 68.8570000, 'AF', '2014-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(159, 'Khōshī', 'Khoshi', 'Khoshi,Khosi,Khoši,Khushi,Khvoshi,Khvoshī,Khōshī,Kushi,khwshy,خوشی', 33.9991600, 69.2158200, 'AF', '2013-03-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(160, 'Khōshāmand', 'Khoshamand', 'Khosamand,Khoshamand,Khos̄āmanḏ,Khus Amad,Khusamand,Khush Amad,Khushamand,Khus̄ Āmad,Khus̄āmand,Khvosh Amad,Khvosh Mand,Khvosh Āmad,Khvoshamand,Khvoshāmand,Khōshāmand,Khūsh Āmad,khwsh amd,khwshamnd,خوش آمد,خوشامند', 32.6856700, 68.2380100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(161, 'Khwājah Ghār', 'Khwajah Ghar', 'Khodzhagar,Khoja-i-Gar,Khvajeh Ghar,Khvājeh Ghar,Khwaja Gar,Khwaja Ghar,Khwaja-i-Gar,Khwaja-i-Ghar,Khwajah Ghar,Khwāja-i-Gar,Khwāja-i-Ghar,Khwājah Ghār,khwajh ghar,خواجه غار', 37.0658800, 69.4212600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(162, 'Khwājah Dū Kōh', 'Khwajah Du Koh', 'Khodja-Bunak,Khodzha-Dokukh,Khvajeh Do Kuh,Khvājeh Do Kūh,Khwaja Do Koh,Khwaja Du Koh,Khwajah Do Koh,Khwajah Du Koh,Khwajah-ye Do Ku,Khwajah-ye Do Kū,Khwāja Do Koh,Khwājah Dō Kōh,Khwājah Dū Kōh,Khwājā Du Koh,khwajh dw kwh,خواجه دو کوه', 36.8288100, 65.6243200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(163, 'Deh Khwāhān', 'Deh Khwahan', 'Deh Khahan,Deh Khwahan,Deh Khwāhān,Deh Khāhān,KWH,Khvahan,Khvāhān,Khwahan,Khwāhān,Qala Khwahan,dh khahan,dh khwahan,khwahan,خواهان,ده خاهان,ده خواهان,Ḏeh Khāhān', 37.8896500, 70.2187500, 'AF', '2017-02-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(164, 'Khulbisāt', 'Khulbisat', 'Khalbesat,Kholbesat,Kholbesāt,Kholbisat,Khul''besat,Khulbesat,Khulbesāt,Khulbisat,Khulbisāt,Khul’besat,Khālbêsāt,Khōlbisāt,khlbsat,khwlbsat,خلبسات,خولبسات', 33.4948000, 70.0060500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(165, 'Khūgyāṉī', 'Khugyani', 'Khug''yani,Khugyani,Khug’yani,Khukyani,Khūgyānī,Khūgyāṉi,Khūgyāṉī,Khūkyānī,khwgyany,خوگیانی,خوگیاڼی', 31.5626700, 66.5814000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(166, 'Khōst', 'Khost', 'KHT,Khost,Khowst,Khōst,Matun,Matūn,khwst,mtwn,Хост,خوست,متون', 33.3395100, 69.9204100, 'AF', '2017-02-17', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(167, 'Khulm', 'Khulm', 'Bazar-e Khulm,Bāzār-e Khulm,Kholm,Khulm,Tashkurgan,Tashkurghan,Tashqorghan,Tashqurghan,Tāshkurghān,Tāshqorghān,Tāshqurghān,bazar khlm,khlm,tashqrghan,Ташкурган,بازار خلم,تاشقرغان,خلم', 36.6973600, 67.6982600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(168, 'Khudāydād Khēl', 'Khudaydad Khel', 'Khodaydad Khel,Khodaydad Kheyl,Khodaydadkhel,Khodāydād Kheyl,Khodāydād Khēl,Khoḏāyḏāḏkhēl,Khuda Dad Khel,Khudaydad Khel,Khudā Dād Khēl,Khudāydād Khēl,خدا داد خېل,خدایداد خېل', 35.1783500, 67.6875800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(169, 'Khinjān', 'Khinjan', 'Khenjan,Khenjān,Khindzhan,Khinjan,Khinjān,khnjan,خنجان', 35.5890800, 68.9009300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(170, 'Khinj', 'Khinj', 'Khenj,Khindzh,Khinj,khnj,Хиндж,خنج', 35.4289800, 69.7348200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(171, 'Khāsh', 'Khash', 'Khas,Khash,Khāsh,Khās̄,khash,خاش', 31.5291900, 62.7905500, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(172, 'Khān Neshīn', 'Khan Neshin', 'Khan Nashim,Khan Nashin,Khan Neshin,Khan Nishin,Khaneshin,Khannesin,Khān Nashīn,Khān Neshīn,Khān Nishīn,Khāneshīn,Khānnešīn,khan nshyn,خان نشین', 30.5488000, 63.7888000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(173, 'Khānaqāh', 'Khanaqah', 'Khanaka,Khanaqa,Khanaqah,Khanega,Khanehqah,Khaneqa,Khānaqā,Khānaqāh,Khānegā,Khānehqāh,Khāneqā,khanhqah,khanqah,Ханака,خانقاه,خانهقاه', 36.6258700, 69.5369500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(174, 'Chahār Bāgh', 'Chahar Bagh', 'Chahar Bagh,Chahār Bāgh,Char Bagh,Chār Bāgh,Khan Chahar Bagh,Khan''-charbag'',Khan-Chekhar-Bar,Khan-e Chahar Bagh,Khan-e Char Bagh,Khancarbagh,Khan’-charbag’,Khān Chahār Bāgh,Khān-e Chahār Bāgh,Khān-e Chār Bāgh,Khāncārbāgh,Qani Chahar Bagh,Qanī Chahār Bāgh,chhar bagh,چهار باغ', 37.0010800, 65.2239200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(175, 'Khandūd', 'Khandud', 'Khandud,Khandut,Khandūd,Khanḏūḏ,khndwd,خندود', 36.9512700, 72.3180000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(176, 'Khānaqāh', 'Khanaqah', 'Khanaka,Khananqa,Khanaqa,Khanaqah,Khaneqah,Khānaka,Khānanqā,Khānaqā,Khānaqāh,Khāneqāh,khanqah,khanqh,خانقاه,خانقه', 36.8627900, 66.1665600, 'AF', '2013-10-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(177, 'Khanabad', 'Khanabad', 'Khanabad,Khānābād,khan abad,Ханабад,خان آباد', 36.6825000, 69.1155600, 'AF', '2009-03-03', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(178, 'Khamyāb', 'Khamyab', 'Kham Ab,Kham-e Ab,Kham-e Āb,Kham-i-Ab,Kham-i-Āb,Khamyab,Khamyāb,Khām Āb,kham ab,khmyab,خام آب,خمياب', 37.5275000, 65.7583300, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(179, 'Khākirān', 'Khakiran', 'Khakeran,Khakiran,Khākerān,Khākirān,khakran,خاکران', 32.8385000, 67.0737700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(180, 'Kaz̲h̲ah', 'Kazhah', 'Kaga,Kagd,Kaza,Kazhah,Kaz̲h̲ah,Kaža,Khazha,Khowgiani,Khowgīānī,Nawe Kaza,Nawē Kaža,kzhh,كژه,کږه', 34.2408800, 70.1827400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(181, 'Kishk-e Nakhūd', 'Kishk-e Nakhud', 'Kashk-e Nokhowd,Keshk-e Nakhud,Keshk-e Nakhūd,Keskenakhud,Keškenakhud,Kishk-e Nakhud,Kishk-e Nakhūd,Kishkinakhud,Kishkinakhūd,Kuchki-Nalud,Kushk-e Nakhud,Kushk-e Nakhūd,Kuske Nakhud,Kus̄ke Nakhuḏ,kshk nkhwd,کشک نخود', 31.6251900, 65.0551100, 'AF', '2012-02-01', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(182, 'Karukh', 'Karukh', 'Karokh,Karrukh,Karukh,Kaṟukh,krkh,کرخ', 34.4810800, 62.5863000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(183, 'Kanḏay', 'Kanday', 'Kanday,Kanḏay,kndy,كندی,کنډی', 34.9536000, 70.7789700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(184, 'Kandahār', 'Kandahar', 'Candahar,Gorad Kandagar,KDH,Kandagar,Kandahar,Kandaharo,Kandahār,Kandehar,Kandhar,Qandahar,Qandahār,Qanḏahāṟ,kan da ha,kandaharu,kndhar,qndhar,qndhʼr,Горад Кандагар,Кандагар,קנדהאר,قندهار,كندهار,カンダハール,坎大哈', 31.6133200, 65.7101300, 'AF', '2014-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(185, 'Kalān Deh', 'Kalan Deh', 'Kalan Deh,Kalan-Dekh,Kalān Deh,dh klan,klan dh,دهٔ كلان,کلان ده', 33.8367600, 68.4023300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(186, 'Kalakān', 'Kalakan', 'Bazar-e Kalakan,Bāzār-e Kalakān,Kala Chan,Kala Khan,Kala Khān,Kalakan,Kalakān,Qal`eh-ye Khan,Qala Khan,Qala Khān,Qal‘eh-ye Khān,bazar klkan,klkan,بازار کلکان,کلکان', 34.7837100, 69.1500100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(187, 'Kalafgān', 'Kalafgan', 'Kalafgan,Kalafgān,Kalefgan,Kalefgān,Kalifgan,Kalifgān,klfgan,کلفگان', 36.7722600, 69.9448900, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(188, 'Kajrān', 'Kajran', 'Kadzhiran,Kajiran,Kajran,Kajrān,Kajīrān,kjran,Каджиран,کجران', 33.2035700, 65.4731100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(189, 'Kai', 'Kai', 'Ka''i,Kahi,Kahī,Kai,Ka’i,Kāhī,Kā’ī,kayy,khy,کائی,کهی', 34.1281900, 70.7182800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(190, 'Kabul', 'Kabul', 'Cabool,Caboul,Cabul,Cabul - kabl,Cabul - کابل,Cabura,Cabúl,Caubul,Gorad Kabul,KBL,Kabil,Kaboel,Kabol,Kaboul,Kabul,Kabula,Kabulas,Kabuli,Kabulo,Kabura,Kabúl,Kabûl,Kampoul,Kobul,Kubha,Kábul,Kâbil,Kābol,ka bu er,kabl,kabul,kabula,kabuli,kaburu,kabwl,kapul,ke bu er,khabul,Καμπούλ,Горад Кабул,Кабул,Кобул,Քաբուլ,קאבול,كابل,كابۇل,کابل,کابول,काबुल,কাবুল,ਕਾਬੁਲ,କାବୁଲ,காபூல்,ಕಾಬುಲ್,കാബൂൾ,කාබුල්,คาบูล,ཁ་པལ།,ཁ་པུལ།,ქაბული,ካቡል,ទីក្រុងកាបូល,カブール,カーブル,喀布尔,喀布爾,카불', 34.5281300, 69.1723300, 'AF', '2014-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(191, 'Jurm', 'Jurm', 'Jarm,Jorm,Jurm,Jurn,Shahr-e Jorm,jrm,جرم', 36.8647700, 70.8342100, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(192, 'Jawand', 'Jawand', 'Javand,Jawand,Jowand,jwnd,جوند', 35.0636100, 64.1491700, 'AF', '2011-11-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(193, 'Jānī Khēl', 'Jani Khel', 'Dzhanikheyl'',Dzhanikheyl’,Jani Khel,Jani Kheyl,Janikhel,Jānikhēl,Jānī Kheyl,Jānī Khēl,جانی خېل', 32.7631500, 68.3972200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(194, 'Jalrēz', 'Jalrez', 'Dzhalez,Jalez,Jaliz,Jalrayz,Jalreyz,Jalrez,Jalriz,Jalrēz,Jalrīz,Jalēz,Jalīz,jlryz,جلريز,جلرېز', 34.4708000, 68.6543800, 'AF', '2012-08-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(195, 'Jalālābād', 'Jalalabad', 'Djelalabad,Dschalalabad,Dzalalabad,Dzhelalabad,Dżalalabad,JAA,Jalakot,Jalal-Kut,Jalalabad,Jalalkoat,Jalalkot,Jalālkot,Jalālābād,Jelalabad,Tarun City,jalalabada,jlal abad,Джелалабад,جلال آباد,جلال‌آباد,জালালাবাদ', 34.4264700, 70.4515300, 'AF', '2017-02-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(196, 'Jabal os Saraj', 'Jabal os Saraj', 'Djabal-ul-Seradj,Dzhabal''-Ussaradzh,Dzhabal’-Ussaradzh,Jabal Saraj,Jabal os Saraj,Jabal os Sarāj,Jabal us Siraj,Jabal us Sirāj,Jabal-us-Sirai,Jabalussaraj,Jabalussaṟāj,Jabl-us-Seraj,Jabl-us-Siraj,Jabul Saraj,Jibal-as-Seraj,Parwan,jbl alsraj,جبل السراج', 35.1183300, 69.2377800, 'AF', '2010-03-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(197, 'Ḩukūmat-e Shīnkaī', 'Hukumat-e Shinkai', 'Hokumat-e Shinkay,Hokumate Sinkay,Hokūmate Šinkay,Hukumat-e Shinkai,Hukumat-e Shinkay,Khukumati-Shinkay,Shinkai,Shīnkaī,hkwmt shynky,shynky,حکومت شینکی,شینکی,Ḩokūmat-e Shinkay,Ḩukūmat-e Shīnkay,Ḩukūmat-e Shīnkaī', 31.9830300, 67.3355800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(198, 'Herāt', 'Herat', 'Gerat,Gorad Gerat,HEA,Herat,Herāt,Hérat,Kherat,Shahr-e Herat,Shahr-e Herāt,he la te,herato,hrat,Герат,Горад Герат,Херат,هراة,هرات,ヘラート,赫拉特', 34.3481700, 62.1996700, 'AF', '2013-05-18', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(199, 'Ḩājī Khēl', 'Haji Khel', 'Haji Khel,Hajikhel,Hajjikheyl,Khadzhikheyl'',Khadzhikheyl’,hajy khyl,حاجی خيل,حاجی خېل,Ḩājikhēl,Ḩājjīkheyl,Ḩājī Khēl', 35.1092200, 69.4334100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(200, 'Ḩāfiz̧ Moghul', 'Hafiz Moghul', 'Hafez Moghol,Hafez Mughul,Hafiz Moghul,Hāfeẕ Mughul,hafz mghl,حافظ مغل,Ḩāfez̧ Moghol,Ḩāfiz̧ Moghul', 37.0564300, 70.4006100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(201, 'Khafizan', 'Khafizan', 'Hafezan,Hafizan,Khafizan,hafzan,حافظان,Ḩāfez̧ān,Ḩāfiz̧ān', 34.2866500, 70.3724700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(202, 'Guz̄arah', 'Guzarah', 'Gozara,Gozareh,Goz̄areh,Goz̄aṟa,Guzarah,Guz̄arah,gdhrh,گذره', 34.2122300, 62.2123500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(203, 'Gōshtah', 'Goshtah', 'Goshta,Goshtah,Goshteh,Gosta,Gowshtah,Gošta,Gōshtah,gwshth,گوشته', 34.3582200, 70.7626400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(204, 'Gōmal Kêlay', 'Gomal Kelay', 'Gomal,Gomal Kalay,Gomal Katay,Gomal Kelay,Gowmal,Gumal,Gumal''kalay,Gumal’kalay,Gōmal Kalay,Gōmal Katay,Gōmal Kêlay,Qashlah `Askari Gowmol,Qashlah ‘Askarī Gowmol,Zor Domandi,gwml kly,گومل کلی', 32.5098900, 68.8559800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(205, '‘Alāqahdārī Gēlān', '`Alaqahdari Gelan', 'Alakadari-Gelan,Gelan,Gilan,Gēlān,Gīlān,Janda,Jaṉda,`Alaqadari Gelan,`Alaqahdari Gelan,`Alaqahdari Jandah,علاقه داری جڼډه,علاقه داری گېلان,گېلان,‘Alāqahdārī Gēlān,‘Alāqahdārī Jaṉḏah,‘Alāqaḏāṟī Gēlān', 32.7269200, 67.6369600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(206, 'Ghōriyān', 'Ghoriyan', 'Ghorian,Ghoriyan,Ghoriān,Ghoryan,Ghurian,Ghuriyan,Ghuryan,Ghōriyān,Ghōṟyān,Ghūriyān,Ghūryān,Ghūrīān,Gorian,ghwryan,غوریان', 34.3448000, 61.4932100, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(207, 'Ghormach', 'Ghormach', 'Garmak,Ghormac,Ghormach,Ghormāch,Ghowrmach,Ghowrmāch,Ghōrmāc,Ghōrmāch,ghwrmach,ghwrmch,غورماچ,غورمچ', 35.7306200, 63.7826400, 'AF', '2011-12-21', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(208, 'Ghurayd Gharamē', 'Ghurayd Gharame', 'Garm,Gharmai,Gharmi,Gharmī,Ghoraydgharame,Ghowrayd Gharami,Ghowrayd Gharamī,Ghoṟayḏghaṟamē,Ghurayd Gharame,Ghurayd Gharamē,Ghurmay,ghrmy,غرمی,غرید غرمې', 36.5222000, 70.7906300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(209, 'Ghazni', 'Ghazni', 'GZI,Gazni,Ghazni,Ghaznī,Shahr-e Ghazni,Shahr-e Ghaznī,gazni,gazuni,ghznt,ghzny,ghznyn,Газни,غزنة,غزنی,غزنین,ガズニー', 33.5539100, 68.4209600, 'AF', '2013-05-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(210, 'Gereshk', 'Gereshk', 'Gereshk,Geresk,Gerešk,Girishk,Nahr-e Saraj,Nahr-e Sarāj,grshk,Герешк,گرشک', 31.8208900, 64.5700500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(211, 'Gardez', 'Gardez', 'GRG,Gardeyz,Gardez,Gardiz,Gardêz,Gardēz,Gardīz,Gaṟḏēz,grdyz,Гардез,گرديز', 33.5974400, 69.2259200, 'AF', '2016-11-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(212, 'Fayzabad', 'Fayzabad', 'FBD,Faizabad,Faizābād,Fajzabad,Faydz Abad,Fayzabad,Fayḏẕ Ābāḏ,Fazelabad,Faīẕābād,Feyzabad,Feyẕābād,fyd abad,Файзабад,فیض آباد', 37.1166400, 70.5800200, 'AF', '2013-09-21', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(213, 'Faīẕābād', 'Faizabad', 'Faizabad,Faizābād,Faydzabad,Fayḏẕābāḏ,Fazilabad,Faīẕābād,Feyzabad,Feyẕābād,Fāzilābād,fyd abad,فیض آباد', 36.8209100, 66.4592100, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(214, 'Fayẕābād', 'Fayzabad', 'Faizabad,Faizābād,Faydz Abad,Fayzabad,Fayḏz Ābād,Fayẕābād,Feyzabad,Feyẕābād,qyd abad,قيض آباد', 36.2911100, 64.8622200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(215, 'Qal‘ah-ye Fārsī', 'Qal`ah-ye Farsi', 'Farsi,Farsī,Kalafarsi,Qal`a Farsi,Qal`a-i-Farsi,Qal`ah-ye Farsi,Qal`eh Farsi,Qal`eh-ye Farsi,Qal‘a Fāṟsi,Qal‘a-i-Fāṟsi,Qal‘ah-ye Farsī,Qal‘ah-ye Fārsī,Qal‘eh Fāṟsi,Qal‘eh-ye Farsī,قلعۀ فارسی,قلعۀ فرسی', 33.7852900, 63.2473500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(216, 'Farkhār', 'Farkhar', 'Farkhar,Farkhār,frkhar,فرخار', 36.5728800, 69.8578300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(217, 'Farah', 'Farah', 'FAH,Farah,Farahas,Farakh,Farâh,Farāh,Ferah,fa la,faraha,frah,pala,para,Фарах,فراه,فراہ,फ़राह,பாரா,法拉,파라', 32.3745100, 62.1163800, 'AF', '2013-09-21', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(218, 'Istālif', 'Istalif', 'Estalef,Estālef,Istalef,Istalif,Istilif,Istālef,Istālif,Takht-e Istalif,Takht-e Istālif,astalf,tkht astalf,استالف,تخت استالف', 34.8326800, 69.0775600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(219, 'Kafir Qala', 'Kafir Qala', 'Eslam Qal`eh,Eslamqal`a,Eslamqal‘a,Eslām Qal‘eh,Islam Kala,Islam Killa,Islam Qal`ah,Islam Qala,Islām Kala,Islām Qala,Islām Qal‘ah,Kafar Qal`eh,Kafir Kala,Kafir Qala,Kāfar Qal‘eh', 34.6666700, 61.0666700, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(220, 'Injīl', 'Injil', 'Enjeel,Enjil,Enjīl,Injil,Injīl,anjyl,انجيل', 34.3015700, 62.2465000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(221, 'Imām Şāḩib', 'Imam Sahib', 'Emam Saheb,Emām Şāḩeb,Hazrat,Imam Saheb,Imam Sahib,Imamsakhib,Imām Sāẖeb,Imām Şāḩib,Khwaja,Khwaja Imam Saiyid,Khwaja Iman Saiyid,Khwāja Imām Saiyid,Khwāja Imān Saiyid,amam sahb,امام صاحب', 37.1889700, 68.9364400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(222, 'Dōshī', 'Doshi', 'Doshi,Dosi,Dowshi,Dowshī,Doši,Dōshī,dwshy,دوشی', 35.6091800, 68.6847300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(223, 'Dowlatyār', 'Dowlatyar', 'Daolat Yar,Daulat Yar,Daulat Yār,Dawlatyar,Dawtatyar,Dowlat Yar,Dowlat Yār,Dowlatyar,Dowlatyār,Dāolat Yar,Taht-e Dowlatyar,Taḩt-e Dowlatyār,dwlt yar,dwltyar,دولت یار,دولتیار,Ḏawlatyāṟ,Ḏawtatyāṟ', 34.5513200, 65.7930200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(224, 'Dowlat Shāh', 'Dowlat Shah', 'Daulat Shah,Daulat Shāh,Daulatshakh,Dawlat Shah,Dawlat Shāh,Dawlatsah,Dawlatšāh,Dowlat Shah,Dowlat Shāh,dwlt shah,دولت شاه', 34.9504000, 70.0710200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(225, 'Dowlatābād', 'Dowlatabad', 'Daulatabad,Daulatābād,Davletabad,Dawlatabad,Dawlatābād,Dowlatabad,Dowlatābād,dwlt abad,Даулатабад,دولت آباد', 36.9882100, 66.8206900, 'AF', '2013-10-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(226, 'Dowlatābād', 'Dowlatabad', 'Danlatabad,Danlatābād,Daolatabad,Daulatabad,Daulatābād,Dawlatabad,Dowlatabad,Dowlatābād,Shirin Tagao,Shīrīn Tagāo,dwlt abad,دولت آباد,Ḏawlatābād', 36.4325900, 64.9207100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(227, 'Dū Qal‘ah', 'Du Qal`ah', 'Do Qal`eh,Do Qal‘eh,Doqal`a,Du Qal`ah,Dū Qal‘ah,Kala-i-Kah,Kala-i-Kāh,Qal`ah-ye Kah,Qal`eh Kah,Qal`eh-ye Ka,Qala-i-Kah,Qala-i-Kāh,Qal‘ah-ye Kāh,Qal‘eh Kāh,Qal‘eh-ye Kā,دو قلعه,قلعه کاه,Ḏoqal‘a', 32.1423700, 61.4469000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(228, 'Dūāb', 'Duab', 'Do Ab,Do Āb,Doab-i-Shahpasand,Dow Ab-e Shah Pasand,Dow Āb-e Shāh Pasand,Doāb-i-Shāhpasand,Duab,Dūāb,Tatar,Tātār,Tātāṟ,dwab,tatar,تاتار,دواب', 35.5627700, 67.8219100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(229, 'Dê Nārkhēl Kêlay', 'De Narkhel Kelay', 'De Narkhel Kalay,De Narkhel Kelay,De Narkheyl Kalay,De Nārkheyl Kalay,Dinarkhil,Dê Nārkhēl Kêlay,Dīnārkhīl,Narkheyl''kalay,Narkheyl’kalay,d nar khyl kly,dynarkhyl,د نار خيل كلی,د نارخېل کلی,دينارخيل,Ḏe Nāṟkhēl Kalay', 32.4320500, 65.6348400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(230, 'Dehī', 'Dehi', 'Dehi,Dehī,dhy,دهی', 35.9580600, 67.2799800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(231, 'Deh-e Şalāḩ', 'Deh-e Salah', 'Deh Salah,Deh Saleh,Deh Sāleh,Deh Şalāḩ,Deh-e Salah,Deh-e Şalāḩ,dh slah,ده صلاح', 35.6903100, 69.3151100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(232, 'Deh-e Now', 'Deh-e Now', 'Dakhi-Nau,Deh-e Now,Dehe Naw,dh nw,ده نو,دهٔ نو,Ḏehe Naw', 34.7476700, 69.0478400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(233, 'Dehdādī', 'Dehdadi', 'Chahar Sarakah-ye Dehdadi,Chahār Sarakah-ye Dehdādī,Dehdadi,Dehdādī,Dekhdadi,chhar srkh dhdady,dhdady,Дехдади,دهدادی,چهار سرکه دهدادی', 36.6631900, 66.9933900, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(234, 'Dwah Manḏay', 'Dwah Manday', 'Davamandi,Davamandī,Domandao,Domandi,Dowmandi,Dowmandī,Du Mandah,Dvamanday,Dwah Manday,Dwah Manḏay,Dwamanday,Dū Mandah,dw mndh,dwh mndy,dwh mnډy,dwmndy,دو منده,دومندی,دوه مندی,دوه منډی,Ḏwamanday', 33.2815900, 69.5853100, 'AF', '2014-04-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(235, 'Dasht-e Qal‘ah', 'Dasht-e Qal`ah', 'Dasht Qala,Dasht-e Qal`ah,Dasht-e Qal`eh,Dasht-e Qal‘ah,Dasht-e Qal‘eh,Dashti-Kala,Dast-i-Qal''a,Daste Qal`a,Shahr-e Dasht-e Qal`eh,Shahr-e Dasht-e Qal‘eh,دشت قلعه,Ḏas̄t-i-Qal’a,Ḏas̄te Qal‘a', 37.1539000, 69.4435000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(236, 'Dasht-e Qal‘ah', 'Dasht-e Qal`ah', 'Dasht-e Qal`ah,Dasht-e Qal`eh,Dasht-e Qal‘ah,Dasht-e Qal‘eh,Daste Qal`a,دشت قلعه,Ḏas̄te Qal‘a', 33.0297800, 63.8395000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(237, 'Dasht-e Archī', 'Dasht-e Archi', '', 37.1333300, 69.1666700, 'AF', '2006-01-27', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(238, 'Darzāb', 'Darzab', 'Darzab,Darzāb,Darẕāb,Durzab,Durzāb,drz ab,درز آب', 35.9774400, 65.3782800, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(239, 'Markaz-e Ḩukūmat-e Darwēshān', 'Markaz-e Hukumat-e Darweshan', 'Darvishan,Darvīshān,Darwesan,Markaz-e Hukumat-e Darwayshan,Markaz-e Hukumat-e Darweshan,Markaz-e Hukumati Darwayshan,Markaz-e Ḩukūmat-e Darwayshān,Markaz-e Ḩukūmat-e Darwēshān,Markaz-e Ḩukūmatī Darwayshān,Markaze Hokumati Darwesan,Maṟkaze Hokūmatī Darwēsān,mrkz hkwmty drwyshan,mrkzi hkwmti drwyshan,مرکز حکومتی درویشان,مرکزِ حکومتِ درويشان,Ḏaṟwes̄ān', 31.1323100, 64.1934000, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(240, 'Darqad', 'Darqad', 'Darkat,Darqad,Qeshlaq-e Darqad,Qeshlāq-e Darqad,drqd,درقد', 37.3841400, 69.4529400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(241, 'Darāyim', 'Darayim', 'Daraim,Darayim,Darāyim,draym,درايم', 36.8666700, 70.3833300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(242, 'Dāngām', 'Dangam', 'Dangam,Dāngām,dangam,دانگام,ډانگام,Ḏāngām', 34.9924900, 71.4193500, 'AF', '2014-01-08', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(243, 'Ḏanḏar', 'Dandar', 'Dandar,Qaryah-ye Dandar,Qaryah-ye Danḏar,dndar,دندار,قريه دنډر,ډنډر,Ḏanḏar', 34.7909500, 69.4750400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(244, 'Ḩukūmatī Dahanah-ye Ghōrī', 'Hukumati Dahanah-ye Ghori', 'Dahana,Dahana Ghori,Dahana-i-Ghori,Dahanae Ghori,Dahaneh-ye Ghowri,Dahaneh-ye Ghowṟī,Dahna,Dahāna,Dananeh-ye Ghowri,Dananeh-ye Ghowrī,Hokumati Dahana-i-Ghori Dahana,Hokūmatī Ḏahana-i-Ghōṟi Dahana,Hukumati Dahanah-ye Ghori,hkwmty dhnh ghwry,حکومتی دهنه غوری,Ḏahana-i-Ghōṟi,Ḏahanae Ghōṟi,Ḩukūmatī Dahanah-ye Ghōrī', 35.9061700, 68.4886900, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(245, 'Tsowkêy', 'Tsowkey', 'Cawkae,Cawkay,Chaukai,Chauki,Chowkay,Chowkey,Chowki,Chowkī,Tsowkey,Tsowkêy,chwky,Čawkae,څوکۍ,چوكی', 34.6924600, 70.9268800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(246, 'Chīras', 'Chiras', 'Chiras,Chīras,Ciras,Cīras', 35.4167400, 65.9823400, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(247, 'Chisht-e Sharīf', 'Chisht-e Sharif', 'Ceste Sarif,Ces̄te S̄aṟīf,Chesht-e Sharif,Chesht-e Sharīf,Chest-e Sharif,Chisht-e Sharif,Chisht-e Sharīf,Chusht-e Sharif,Chusht-e Sharīf,Khvajeh Chesht,Khvājeh Chesht,Khwaja Chist,Qaryeh-ye Chest-e Sharif,Qaryeh-ye Chest-e Sharīf,chsht shryf,چشت شریف', 34.3473100, 63.7396600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(248, 'Chinār', 'Chinar', 'Cenar,Chenar,Chenār,Chinar,Chinār,Chīnār,chnar,chynar,Čenār,چنار,چینار', 32.0158300, 65.1072100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(249, 'Chimtāl', 'Chimtal', 'Ahan Qal`eh,Cemtal,Cemtāl,Chemtal,Chemtāl,Chimtal,Chimtal'',Chimtāl,chmtal,chmtl,Āhan Qal‘eh,Чимталь,چمتال,چمتل', 36.6781800, 66.8032500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(250, 'Charkh', 'Charkh', 'Carkh,Charkh,chrkh,Čarkh,چرخ', 33.7971200, 68.9374900, 'AF', '2013-03-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(251, 'Charikar', 'Charikar', 'Caharikar,Carikar,Carikaras,Chaharikar,Chahārīkār,Chairkar,Charekar,Charikar,Chāirkār,Chārīkār,Czarikar,Cāṟikāṟ,Tscharikar,carikar,carikara,charikari,charykar,qia li ka er,Çarikar,Ĉarikar,Čahārikār,Čarikaras,Чарикар,چاريكار,چاریکار,चारीकार,চরিকর,சாரிகார்,ჩარიქარი,恰里卡尔', 35.0136100, 69.1713900, 'AF', '2010-01-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(252, 'Dowr-e Rabāţ', 'Dowr-e Rabat', 'Cardara,Chahar Darreh,Chahār Darreh,Char Darah,Char Darreh,Chār Darah,Chār Darreh,Cāṟḏaṟa,Davri-Rabat,Dawr-i-Rabat,Dawṟ-i-Ṟabāṯ,Dowr-e Rabat,Dowr-e Rabāţ,Ribat,Ribāt,char drh,dwr rbat,Даври-Рабат,دور رباط,دورٔ رباط,چار دره', 36.6913200, 68.7909300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(253, 'Tsapêraī', 'Tsaperai', 'Capare,Capaṟē,Chapare,Chapray,Chhapri,Tsapare,Tsaparē,Tsaperai,Tsapêraī,څپری,څپرې', 33.8300300, 69.9192000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(254, 'Tsamkanī', 'Tsamkani', 'Camkani,Chakmani,Chamkani,Chamkanī,Dzamkani,Dzamkanī,Pir Sarai,Pir Serai,Pīr Sarāi,Qal`eh-ye Chamkani,Qal‘eh-ye Chamkanī,Sakmanni Parao,Tsamkani,Tsamkanī,chmkny,Čamkani,څمکنی,چمکنی', 33.8029800, 69.8167100, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(255, 'Chakaray', 'Chakaray', 'Cakaray,Chakarai,Chakaray,Chakari,Chakarī,Chakaṟaī,Charkari,Dasht-e Chakaray,chkry,dsht chkry,Čakaray,دشت چکری,چکری', 34.3409900, 69.4377000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(256, 'Chākarān', 'Chakaran', 'Cakaran,Chakaran,Chākarān,Cākaṟān,Khakaran,Khākarān,chakran,چاکران', 36.9111200, 71.0688000, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(257, 'Chahār Qal‘ah', 'Chahar Qal`ah', 'Caharqal`a,Chahar Qal`ah,Chahar Qal`eh,Chahār Qal‘ah,Chahār Qal‘eh,Chakharkala,Čahārqal‘a,چهار قلعه', 33.5526700, 68.2982800, 'AF', '2013-03-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(258, 'Chahār Burj', 'Chahar Burj', 'Car Burj,Chahar Borj,Chahar Burj,Chahar Burjak,Chahār Borj,Chahār Burj,Chahār Burjak,Char Burj,Charburdzh,Chār Burj,chhar brj,Čār Burj,چهار برج', 34.2447500, 62.1916500, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(259, 'Chāh Āb', 'Chah Ab', 'Cah Ab,Cah-i-Ab,Chah Ab,Chah-e Ab,Chah-i-Ab,Chayab,Chāh Āb,Chāh-e Āb,Chāh-i-Āb,Cāh Āb,Cāh-i-Āb,chah ab,چاه آب', 37.3977300, 69.8146400, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(260, 'Fayrōz Kōh', 'Fayroz Koh', 'CCN,Caghcaran,Caghcaṟān,Cakhcaran,Cakhcaṟān,Chaghcharan,Chaghcharān,Chakcharan,Chakhcharan,Chekcheran,Fayroz Koh,Fayrōz Kōh,chghchran,fyrwz kwh,فيروز کوه,چغچران', 34.5195200, 65.2509300, 'AF', '2017-02-17', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(261, 'Bulōlah', 'Bulolah', 'Bolola,Bolowleh,Boluleh,Bolōla,Bolūleh,Bulola,Bulolah,Bulōlah,blwlh,بلوله', 34.8770600, 68.0879000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(262, 'Bal Chirāgh', 'Bal Chiragh', 'Bal Chiragh,Bal Chirāgh,Belceragh,Belcheragh,Belcherāgh,Belchirag,Belchiragh,Belchirāg,Belchirāgh,Bilchiragh,Bilchirāgh,Bēlceṟāgh,Bēlchirāgh,bl chragh,بل چراغ,بېل چراغ', 35.8402600, 65.2309000, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(263, 'Bāzār-e Tālah', 'Bazar-e Talah', 'Bazar-e Talah,Bazar-e Taleh,Bazare Tala,Bāzār-e Tālah,Bāzār-e Tāleh,Bāzāṟe Tāla,Tala,Tala Barfaq,bazar talh,بازار تاله', 35.3920500, 68.2231700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(264, 'Bāsawul', 'Basawul', 'Basavul'',Basavul’,Basawul,Basowl,Bāsawul,Bāsowl,Mohmand Darrah,baswl,باسول', 34.2474900, 70.8721800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(265, 'Būrkah', 'Burkah', 'Barkah,Borkeh,Burka,Burkah,Buṟka,Būrkah,bwrkh,بورکه', 36.2224200, 69.1503700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(266, 'Barg-e Matāl', 'Barg-e Matal', 'Barg-e Matal,Barg-e Matāl,Barg-e Maṯāl,Barge Matal,Bargi-Matal'',Bargi-Matal’,Baṟge Matāl,Bragamata,Bragamatal,Lutdeh,brg mtal,برگ متال', 35.6728300, 71.3433900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(267, 'Baraki Barak', 'Baraki Barak', 'Barah Ki Barak,Barah Kī Barak,Baraki Barak,Baraki Burak,Barakibarak,Barakī Barak,Barqi Barq,OAA,brh ky brk,brky brk,بره کی برک,برکی برک', 33.9674400, 68.9492000, 'AF', '2017-01-14', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(268, 'Banū', 'Banu', 'Andarab,Andarāb,Banow,Banu,Banū,bnw,بنو', 35.6334800, 69.2601900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(269, 'Bāmyān', 'Bamyan', 'BIN,Bamian,Bamiyan,Bamyan,Bāmyān,Bāmīān,Kala Sarkari,Qal`a Sarkarit,Qala Sarkari,Qala Sarkāri,Qal‘a Sarkārit,bamyan,باميان', 34.8215600, 67.8273400, 'AF', '2017-02-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(270, 'Balkh', 'Balkh', 'Bactra,Bactresh,Bakhtar,Balch,Balchas,Balh,Balhika,Balho,Balj,Balkh,Balx,Balĥo,Bamik,Bazirabad,Belh,Belx,Bkahdi,Bākhtar,Daerah Balkh,Quan Balkh,Quận Balkh,Vazirabad,ba er he,balheu,barufu,blk,blkh,Μπαλχ,Балх,Вазирабад,Բալխ,בלך,بلخ,বাল্‌খ,ബൽഖ്,バルフ,巴尔赫,발흐', 36.7563500, 66.8972000, 'AF', '2014-11-21', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(271, 'Bahārak', 'Baharak', 'Bagorak,Baharak,Baharestan,Baharistan,Bahārak,Bahārestān,Bahāristān,Bakharak,Barak,Becharek,Bekharek,bhark,بهارک', 37.0025400, 70.9066400, 'AF', '2013-11-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(272, 'Bagrāmī', 'Bagrami', 'Bagrame,Bagrami,Bagrāmē,Bagrāmī,Bigrami,Bigrāmī,Qaryeh-ye Bagrami,Qaryeh-ye Bagrāmī,bgramy,بگرامی', 34.4937600, 69.2742700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(273, 'Baghlān', 'Baghlan', 'Baghlan,Baghlan - bghlan,Baghlan - بغلان,Baghlan-e Jadid,Baghlin,Baghlān,Baghlān-e Jadīd,Baglan,Bagolaggo,Sana `Ati,Sana`ati,bghlan,bghlan jdyd,Şanā ‘Ati,Şanā‘atī,Баглан,بغلان,بغلان جديد,صناعتی', 36.1306800, 68.7082900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(274, 'Ḩukūmatī Azrah', 'Hukumati Azrah', 'Azra,Azrah,Azraw,Azreh,Azrow,Azru,Azrū,Azṟa,Azṟaw,Hazrah,Hazro,Hokumati Azraw,Hokumati Azrow,Hukumati Azrah,Khukumati-Azrau,azrh,azrw,hkwmty azrh,Āzreh,ازره,ازرو,حکومتی ازره,Ḩokūmatī Azṟaw,Ḩokūmatī Āzrow,Ḩukūmatī Azrah', 34.1735500, 69.6457300, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(275, 'Ārt Khwājah', 'Art Khwajah', 'Art Khvajeh (1),Art Khwajah,At Khvajeh,At Khwaja,art khwajh,Ārt Khwājah,Āt Khvājeh,Āt Khwāja,Āṟt Khvājeh (1),آرت خواجه', 37.0857100, 69.4795800, 'AF', '2012-01-16', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(276, '‘Alāqahdārī Aṯghar', '`Alaqahdari Atghar', 'Alakadari-Atgar,Arghar,Ataghar,Atghar,Aţghar,Aṯaghaṟ,`Alaqadari Atghar,`Alaqahdari Atghar,`Alaqehdari-ye Atghar,atghr,اتغر,اطغر,علاقهدارئ اټغر,‘Alāqahdārī Aṯghar,‘Alāqaḏāri Aṯghar,‘Alāqehḏārī-ye Aţghar', 31.7350600, 67.3574000, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(277, 'Āsmār', 'Asmar', 'Asma,Asmar,Asmār,asmar,Āsmā,Āsmār,آسمار,اسمار', 35.0333300, 71.3580900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(278, 'Ashkāsham', 'Ashkasham', '', 36.6833300, 71.5333300, 'AF', '2006-01-27', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(279, 'Asadābād', 'Asadabad', 'Asadabad,Asadābād,Assad-Abad,Caghasaray,Chagha Serai,Chagha-Sari,Chaghah Saray,Chaghah Sarāy,Chaghasarai,Chaghasaray,Chaghasarāy,Chagsarai,Chegheh Saray,Chegheh Sarāy,Chigha Sarai,Chigha Sarāi,Chigha Serai,Chigkhasaray,asd abad,chghh sray,Čaghasarāy,Асадабад,اسد آباد,چغه سرای', 34.8731100, 71.1469700, 'AF', '2012-02-24', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(280, 'Āqchah', 'Aqchah', 'Ag Chah,Akcha,Akcheh,Aqca,Aqcha,Aqchah,Aqcheh,aqchh,Āg Chāh,Ākchā,Āqca,Āqchah,Āqcheh,آقچه', 36.9050000, 66.1834100, 'AF', '2013-10-04', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(281, 'Andkhōy', 'Andkhoy', 'Andkhoi,Andkhoy,Andkhui,Andkhvoy,Andkhōy,Andkhōī,Andkhūi,Ankhoi,andkhwy,اندخوی', 36.9529300, 65.1237600, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(282, '’Unābah', '''Unabah', '''Unabah,Anava,Anawa,Anawah,anawh,Ānāwa,Ānāwah,آناوه,عنابه,’Unābah', 35.2325100, 69.3771900, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(283, 'Anār Darah', 'Anar Darah', 'Anar Dara,Anar Darah,Anar Darrah,Anar Darreh,Anardara,Anardarra,Anār Darah,Anār Darrah,Anār Darreh,Anārdarra,Saykh Abad,Shaykh Abad,Shaykh Ābād,S̄aykh Ābāḏ,anar drh,shykh abad,Анар Дара,انار دره,شیخ آباد', 32.7587000, 61.6539700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(284, 'Amānzī', 'Amanzi', 'Amanzai,Amanzey,Amanzi,Amin Za''i,Amin Za’ī,Amānzaī,Amānzey,Amānzi,Amānzī,amanzy,amn zyy,امانزی,امن زئی', 30.2114400, 66.0476500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(285, '‘Alāqahdārī-ye Almār', '`Alaqahdari-ye Almar', 'Alaqadari-i-Almar,Almar,Almar Bazar,Almar Bāzār,Almār,Alāqaḏāṟi-i-Almāṟ,`Alaqahdari-ye Almar,almar,المار,علاقه داری المار,‘Alāqahdārī-ye Almār', 35.8461600, 64.5307400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(286, '‘Alī Shēr ‘Alāqahdārī', '`Ali Sher `Alaqahdari', 'Aliser ''Alaqadari,Alishahr,Alisheralakadari,Ališēr ’Alāqadāri,Alīshahr,`Ali Sher,`Ali Sher `Alaqahdari,`Ali Shir `Alaqehdari,علی شير علاقهداری,علی شېر,علی شېر علاقه داری,‘Alī Shēr,‘Alī Shēr ‘Alāqahdārī,‘Alī Shīr ‘Alāqehdārī', 33.4362000, 70.0671100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(287, 'Wuluswālī ‘Alīngār', 'Wuluswali `Alingar', 'Oluswali Alingar,Oluswāli Alīngāṟ,Ulusvali-Alingar,Wuluswali `Alingar,Wuluswālī ‘Alīngār,`Alingar,ولسوالی علینگار,‘Alīngār', 34.8352900, 70.3593000, 'AF', '2014-01-08', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(288, '‘Alī Khēl', '`Ali Khel', 'Alikheyl'',Alikheyl’,`Ali Khel,`Ali Kheyl,`Alikhel,علی خېل,‘Alikhēl,‘Alī Kheyl,‘Alī Khēl', 33.9425300, 69.7190800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(289, '‘Alāqahdārī Yōsuf Khēl', '`Alaqahdari Yosuf Khel', 'Alakadari-Yusufkheyl'',Alakadari-Yusufkheyl’,Yosuf Khel,Yōsuf Khēl,`Aaqadari Yosufkhel,`Alaqadari Yosufkhel,`Alaqahdari Yosuf Khel,`Alaqehdari Yusofkheyl,`Alaqehdari-ye Yusof Kheyl,علاقه داری یوسف خېل,‘Alāqahdārī Yōsuf Khēl,‘Alāqaḏāṟī Yōsufkhēl,‘Alāqehdārī Yūsofkheyl,‘Alāqehdārī-ye Yūsof Kheyl,‘Aāqaḏāṟī Yōsufkhēl', 33.0519500, 68.6500000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(290, '‘Alāqahdārī Dīshū', '`Alaqahdari Dishu', 'Dishu,Dīshū,`Alaqadari Dehe Su,`Alaqahdari Deh-e Shu,`Alaqahdari Dishu,`Alaqehdari Deh-e Shu,علاقهداری ده شو,علاقهداری ديشو,‘Alāqahdārī Deh-e Shū,‘Alāqahdārī Dīshū,‘Alāqaḏāṟī Dehe S̄u,‘Alāqehdārī Deh-e Shū', 30.4320600, 63.2980200, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(291, 'Alah Sāy', 'Alah Say', 'Alah Say,Alah Sāy,Alasay,Alasāy,alh say,اله سای,شيلۀ اله', 34.8965000, 69.7204900, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(292, 'Pachīr wa Āgām', 'Pachir wa Agam', 'Agam,Agām,Pachier Agam,Pachir Agam,Pachir Aw Agam,Pachir wa Agam,Pachiro Agam,Pachiro Agām,Pachīer Agam,Pachīr Aw Āgām,Pachīr wa Āgām,Pachīr Āgām,Pachīrō Agām,Paciro Agam,Pačīro Agām,agam,pchyr w agam,pchyrw agam,اگام,پچير و آگام,پچیرو اگام', 34.2001100, 70.2780600, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(293, 'Afaki', 'Afaki', 'Afaki,Afaqi,afaqy,Āfāqī,Афаки,آفاقی', 36.6617200, 69.3509500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(294, 'Adraskan', 'Adraskan', 'Adraskan,Adraskand,Adreskan,Adriskan,Aḏṟeskan,Gala,Gala Adraskan,Kala Adraskan,Kala Adrāskan,Qal`eh Adraskand,Qala Adraskan,Qala Adrāskān,Qal‘eh Adraskand,adrskn,ادرسکن', 33.6457300, 62.2695900, 'AF', '2012-05-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(295, 'Āb-e Kamarī', 'Ab-e Kamari', 'Ab-e Kamari,Ab-i-Kamari,ab kmry,Āb-e Kamarī,Āb-i-Kamaṟi,آب کمری', 35.0879600, 63.0678000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(296, 'Khadīr', 'Khadir', 'Khadir,Khadīr,khdyr,خدیر', 33.9223200, 65.9339800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(297, 'Ghulām ‘Alī', 'Ghulam `Ali', 'Gholam `Ali,Gholām ‘Alī,Ghulam `Ali,Ghulām ‘Alī,Gulyamali,Qaryah-ye Shahr-e Now Ghulam ''Ali,Qaryah-ye Shahr-e Now Ghulām ’Alī,Vulusvaliyi-Bagram,Woluswali-i-Bagram,Woluswali-ye Bagram,Woluswālī-i-Bagṟām,Woluswālī-ye Bagrām,wlswaly bgram,غلام علی,قريه شهر نو غلام علی,ولسوالی بگرام', 34.9507600, 69.2287000, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(298, 'Qarah Bāgh Bāzār', 'Qarah Bagh Bazar', 'Bazar-e Qarah Bagh,Bāzār-e Qarah Bāgh,Karabagbazar,Qarabagh Bazar,Qarah Bagh Bazar,Qarah Bāgh Bāzār,Qareh Bagh Bazar,Qareh Bāgh Bāzār,Qaṟabāgh Bāzāṟ,bazar qrh bagh,qrh bagh bazar,بازار قره باغ,قره باغ بازار', 34.8529000, 69.1706200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(299, 'Zargarān', 'Zargaran', 'Zargaran,Zargarān,zrgran,زرگران', 34.7876400, 69.0587800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(300, 'Surkh Bilandī', 'Surkh Bilandi', 'Sorkh Bilandi,Sorkh Bilandī,Sorkh Bolandi,Sorkh Bolandī,Surkh Bilandi,Surkh Bilandī,Surkh-Belandi,Surkhbilandi,Suṟkh-Belanḏi,srkh blndy,سرخ بلندی', 34.6847400, 69.0286300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(301, 'Pul-e Sangī', 'Pul-e Sangi', 'Pol-e Sangi,Pol-e Sangī,Pul-e Sangi,Pul-e Sangī,Pule Sangi,Puli-Sangi,Qaryah-ye Sangi,Qaryah-ye Sangī,pl sngy,qryh sngy,قریه سنگی,پل سنگی,پلٔ سنگی', 34.5997200, 69.2599300, 'AF', '2014-02-10', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(302, 'Langar', 'Langar', 'Langar,Qaryah-ye Langar,lngr,qryh lngr,قريه لنگر,لنگر', 35.9947400, 68.0508100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(303, 'Bāgh-e Maīdān', 'Bagh-e Maidan', 'Bagh-e Maidan,Bagh-e Meydan,Bagh-e Meydān,Baghe Maydan,Bagi-Maydan,Bāgh-e Maīdān,Bāghe Mayḏān,bagh mydan,bgh mydan,باغ میدان,بغ ميدان', 35.2215600, 69.2139700, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(304, 'Ibrāhīm Khān', 'Ibrahim Khan', 'Ebrahimkhan,Ebrāhīmkhān,Ibrahim Khan,Ibrakhimkhan,Ibrāhīm Khān,Qaryah-ye Ibrahim Khel,Qaryah-ye Ibrāhīm Khēl,abrahym khan,ابراهيم خان,ابراهیم خان,قريه ابراهيم خېل', 35.0535200, 69.2565400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(305, 'Qaranghū Tōghaī', 'Qaranghu Toghai', 'Karankutugay,Qaranghu Toghai,Qaranghū Tōghaī,Qaryah-ye Qaran Toghai,Qaryah-ye Qaran Tōghaī,qrnghw twghy,qryh qrn twghy,قرنغو توغی,قريه قرن توغی', 37.2152800, 67.6397200, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(306, 'Bāzārak', 'Bazarak', 'Bazarak,Bāzārak,bazark,Базарак,بازارك,بازارک', 35.3129200, 69.5151900, 'AF', '2013-08-02', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(307, 'Shērwānī-ye Bālā', 'Sherwani-ye Bala', 'Serwani Bala,Shayrwan-e Bala,Shayrwani,Shayrwani-ye Bala,Shayrwān-e Bālā,Shayrwānī,Shayrwānī-ye Bālā,Shervani-Bala,Sherwani-ye Bala,Shirvani Bala,Shērwānī-ye Bālā,Shīrvānī Bālā,shyrwan bala,shyrwany,shyrwany bala,Šērwāni Bālā,Шервани-Бала,شيروانی,شيروانی بالا,شیروان بالا', 35.0146800, 69.5993400, 'AF', '2013-05-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(308, 'Kirāmān', 'Kiraman', 'Keraman,Kerāmān,Kiraman,Kirāmān,kraman,Кираман,کرامان', 35.2973000, 69.6812500, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(309, '‘Alāqahdārī Saṟōbī', '`Alaqahdari Sarobi', 'Alakadari-Sarobi,Sarobi,Saṟōbī,`Alaqadari Sarobi,`Alaqadari-ye Sarubi,`Alaqahdari Sarobi,`Alaqahdari-ye Sarobi,علاقه داری سړوبی,‘Alāqadārī-ye Saṟūbī,‘Alāqahdārī Saṟōbī,‘Alāqahdārī-ye Saṟōbī,‘Alāqaḏārī Saṟōbi', 32.7933100, 69.0866000, 'AF', '2012-05-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(310, 'Zerok-Alakadari', 'Zerok-Alakadari', 'Zerok Alagadari,Zerok Alaqadari,Zerok `Alaqahdari,Zerok-Alakadari,Zeruk `Alaqahdari,Ziruk,Ziruk `Alaqahdari,Ziruk `Alaqehdari,Zērōk Alāgaḏāṟī,Zērōk Alāqaḏāṟi,Zērūk ‘Alāqahdārī,Zēṟōk ‘Alāqahdārī,Zīṟūk,Zīṟūk ‘Alāqahdārī,Zīṟūk ‘Alāqehdārī,زیړوک,زیړوک علاقه داری', 33.1580600, 69.3127800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(311, 'Kushkak', 'Kushkak', 'Kushkak,Kuskak,Kuškak,Kūshkak,kshkk,کشکک', 32.2899100, 61.5219400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(312, 'Khayr Kōṯ', 'Khayr Kot', 'Khayr Kot,Khayr Kōṯ,Khayrkot,Kheyr Kut,Kheyr Kūt,khyr kwt,خیر کوت,خیر کوټ', 32.8535500, 68.4497100, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(313, 'Chowṉêy', 'Chowney', 'Cawnay,Chawnay,Chowney,Chowṉêy,Čawnay,چوڼۍ', 33.3827800, 66.2723300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(314, 'Wuṯahpūr', 'Wutahpur', 'Votapur,Watahpur,Waṯahpūr,Wotapur,Wotapūr,Wutahpur,Wuṯahpūr,wtpwr,وتپور,وټه پور', 34.9191400, 71.0986300, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(315, 'Karbori', 'Karbori', 'Karbori,Karburi,Karbōṟī,Karbūri,Kaṟbōri,كربوړی', 34.9659700, 71.2746000, 'AF', '2014-01-15', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(316, 'Sulţānpūr-e ‘Ulyā', 'Sultanpur-e `Ulya', 'Soltanpur-e `Olya,Soltānpūr-e ‘Olyā,Sultan Pur,Sultanpur-e `Ulya,Sultanpure `Ulya,Sultanpuri-Ulia,Sulţān Pūr,Sulţānpūr-e ‘Ulyā,Sūltānpūṟe ‘Ulyā,sltan pwr,سلطان پور,سلطانپور علیا,سلطانپورٔ علیا', 34.4120400, 70.2963400, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(317, 'Babasakhib', 'Babasakhib', 'Baba Saheb,Baba Sahib,Babasakhib,Bābā Şāḩeb,Bābā Şāḩib,baba sahb,بابا صاحب', 31.6614400, 65.6609800, 'AF', '2012-02-28', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(318, 'Chandal Bā’ī', 'Chandal Ba''i', 'Candalba''i,Chandal Ba''i,Chandal Bā’ī,Chandalba''e,Chandalba''i,Chandalbā’e,Chandalbā’i,chndl bayy,Čandalbā’i,چندل بائی', 34.5846900, 68.9552400, 'AF', '2012-08-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(319, 'Dahan-e Jarf', 'Dahan-e Jarf', 'Dahan-e Jarf,Dakhani-Dzharf,dhn jrf,دهن جرف', 34.9289100, 68.4627300, 'AF', '2012-05-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(320, 'Maydanshakhr', 'Maydanshakhr', 'Maidan Shahr,Maidan Shar,Maydanshakhr,Maīdān Shahr,Maīdān S̲h̲ār,Meydan Shahr,Meydān Shahr,mydan shhr,ميدان شهر', 34.3956100, 68.8661800, 'AF', '2012-10-07', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(321, 'Dū Laīnah', 'Du Lainah', 'Dolayna,Dolaynah,Dorahi Ghor,Du Lainah,Dulaynah,Durahi Ghor,Durāhī Ghōr,Dū Laīnah,dlynh,drahy ghwr,dw lynh,دراهی غور,دلینه,دو لينه,Ḏolayna,Ḏoṟāhī Ghōṟ', 34.1559900, 64.7856600, 'AF', '2012-05-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(322, 'Qaram Qōl', 'Qaram Qol', 'Qaram Qol,Qaram Qōl,Qaramqol,Qaramqul,Qaramqūl,qrm qwl,قرم قول', 36.8300600, 65.0429900, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(323, 'Pul-e Ḩişār', 'Pul-e Hisar', 'Pol-e Hesar,Pol-e Ḩeşār,Pul-e Hisar,Pul-e Ḩişār,Pule Hesar,Pule Hesāṟ,pl hsar,پل حصار', 35.6179400, 69.4713400, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(324, 'Lab-Sar', 'Lab-Sar', '', 36.0263400, 66.8379900, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(325, 'Ţāqchah Khānah', 'Taqchah Khanah', 'Taqca Khana,Taqchah Khanah,Taqcheh Khaneh,Tāqchah Khānah,Tāqcheh Khāneh,Tāqča Khāna,taqchh khanh,Ţāqchah Khānah,تاقچه خانه,طاقچه خانه', 36.6192200, 69.6280500, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(326, 'March', 'March', 'Marc,March,Maṟc,Qaryah-ye Murch,mrch,qryh mrch,قريه مرچ,مرچ', 37.5284500, 70.4482000, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(327, 'Zīrakī', 'Ziraki', 'Ziraki,Zīrakī,Zīṟakī,zyrky,زیرکی', 37.5923300, 70.5581400, 'AF', '2013-09-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(328, 'Aliabad', 'Aliabad', 'Aliabad,`Ali Abad,`Aliabad,Алиабад,علی آباد,‘Alī Ābād,‘Alīābād', 36.5211500, 68.8998500, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1, 'El Tarter', 'El Tarter', 'Ehl Tarter,Эл Тартер', 42.5795200, 1.6536200, 'AD', '2012-11-03', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2, 'Sant Julià de Lòria', 'Sant Julia de Loria', 'San Julia,San Julià,Sant Julia de Loria,Sant Julià de Lòria,Sant-Zhulija-de-Lorija,sheng hu li ya-de luo li ya,Сант-Жулия-де-Лория,サン・ジュリア・デ・ロリア教区,圣胡利娅-德洛里亚,圣胡利娅－德洛里亚', 42.4637200, 1.4912900, 'AD', '2013-11-23', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3, 'Pas de la Casa', 'Pas de la Casa', 'Pas de la Kasa,Пас де ла Каса', 42.5427700, 1.7336100, 'AD', '2008-06-09', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4, 'Ordino', 'Ordino', 'Ordino,ao er di nuo,orudino jiao qu,Ордино,オルディノ教区,奥尔迪诺', 42.5562300, 1.5331900, 'AD', '2009-12-11', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5, 'les Escaldes', 'les Escaldes', 'Ehskal''des-Ehndzhordani,Escaldes,Escaldes-Engordany,Les Escaldes,esukarudesu=engorudani jiao qu,lai sai si ka er de-en ge er da,Эскальдес-Энджордани,エスカルデス＝エンゴルダニ教区,萊塞斯卡爾德-恩戈爾達,萊塞斯卡爾德－恩戈爾達', 42.5072900, 1.5341400, 'AD', '2008-10-15', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6, 'la Massana', 'la Massana', 'La Macana,La Massana,La Maçana,La-Massana,la Massana,ma sa na,Ла-Массана,ラ・マサナ教区,马萨纳', 42.5449900, 1.5148300, 'AD', '2008-10-15', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7, 'Encamp', 'Encamp', 'Ehnkam,Encamp,en kan pu,enkanpu jiao qu,Энкам,エンカンプ教区,恩坎普', 42.5347400, 1.5801400, 'AD', '2012-04-13', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8, 'Canillo', 'Canillo', 'Canillo,Kanil''o,ka ni e,kaniryo jiao qu,Канильо,カニーリョ教区,卡尼略', 42.5676000, 1.5975600, 'AD', '2012-12-24', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9, 'Arinsal', 'Arinsal', 'Arinsal,Arinsal'',Arinsalis,arynsal,Аринсал,Аринсаль,آرینسال', 42.5720500, 1.4845300, 'AD', '2010-01-29', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10, 'Andorra la Vella', 'Andorra la Vella', 'ALV,Ando-la-Vyey,Andora,Andora la Vela,Andora la Velja,Andora lja Vehl''ja,Andoro Malnova,Andorra,Andorra Tuan,Andorra a Vella,Andorra la Biella,Andorra la Vella,Andorra la Vielha,Andorra-a-Velha,Andorra-la-Vel''ja,Andorra-la-Vielye,Andorre-la-Vieille,Andò-la-Vyèy,Andòrra la Vièlha,an dao er cheng,andolalabeya,andwra la fyla,Ανδόρρα,Андора ла Веля,Андора ла Веља,Андора ля Вэлья,Андорра-ла-Велья,אנדורה לה וולה,أندورا لا فيلا,አንዶራ ላ ቬላ,アンドラ・ラ・ヴェリャ,安道爾城,안도라라베야', 42.5077900, 1.5210900, 'AD', '2010-05-30', 6);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11, 'Umm al Qaywayn', 'Umm al Qaywayn', 'Oumm al Qaiwain,Oumm al Qaïwaïn,Um al Kawain,Um al Quweim,Umm al Qaiwain,Umm al Qawain,Umm al Qaywayn,Umm al-Quwain,Umm-ehl''-Kajvajn,Yumul al Quwain,am alqywyn,Умм-эль-Кайвайн,أم القيوين', 25.5647300, 55.5551700, 'AE', '2014-10-07', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12, 'Ras al-Khaimah', 'Ras al-Khaimah', 'Julfa,Khaimah,RKT,Ra''s al Khaymah,Ra''s al-Chaima,Ras al Khaimah,Ras al-Khaimah,Ras el Khaimah,Ras el Khaïmah,Ras el-Kheima,Ras-ehl''-Khajma,Ra’s al Khaymah,Ra’s al-Chaima,ras alkhymt,Рас-эль-Хайма,رأس الخيمة', 25.7895300, 55.9432000, 'AE', '2015-12-05', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13, 'Muzayri‘', 'Muzayri`', 'Mezaira''a,Mezaira’a,Mizeir`ah,Mizeir‘ah,Mozayri`,Mozayri‘,Muzairi,Muzayri`,Muzayri‘,Музаири', 23.1435500, 53.7881000, 'AE', '2013-10-24', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14, 'Khawr Fakkān', 'Khawr Fakkan', 'Fakkan,Fakkān,Khawr Fakkan,Khawr Fakkān,Khawr al Fakkan,Khawr al Fakkān,Khor Fakhan,Khor Fakkan,Khor Fakkān,Khor al Fakhan,Khor al Fakkan,Khor al Fākhān,Khor''fakkan,Khor-Fakkan,Khorfakan,Khorfakhan,Port Khor Fakkan,Хор-Факкан', 25.3313200, 56.3419900, 'AE', '2013-10-25', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15, 'Dubai', 'Dubai', 'DXB,Dabei,Dibai,Dibay,Doubayi,Dubae,Dubai,Dubai emiraat,Dubaija,Dubaj,Dubajo,Dubajus,Dubay,Dubayy,Dubaï,Dubái,Dúbæ,Ehmirat Dubaj,Fort Dabei,Ntoumpai,dby,dbyy,di bai,dobai,du bai,duba''i,dubai,dubay,dubi,dwbyy,tupai,Ντουμπάι,Дубаи,Дубай,Эмірат Дубай,Դուբայի Էմիրություն,דובאי,דוביי,دبئی,دبى,دبي,دبی,دوبەی,دۇبائى,दुबई,দুবাই,துபை,దుబాయ్,ದುಬೈ,ദുബായ്,ดูไบ,დუბაი,ドバイ,杜拜,迪拜,두바이', 25.0657000, 55.1712800, 'AE', '2014-12-02', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16, 'Dibba Al-Fujairah', 'Dibba Al-Fujairah', 'Al-Fujairah,BYB,Dibba Al-Fujairah,dba alfjyrt,دبا الفجيرة', 25.5924600, 56.2617600, 'AE', '2014-08-12', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17, 'Dibba Al-Hisn', 'Dibba Al-Hisn', 'BYB,Daba,Daba al-Hisn,Dabā,Dabā al-Ḥiṣn,Diba,Diba al Hisn,Dibah,Dibba,Dibba Al''-Khisn,Dibba Al-Hisn,Dibbah,Dibā,Dībā al Ḩişn,Hisn Diba,Husn Dibba,Дибба Аль-Хисн,Ḩişn Dibā', 25.6195500, 56.2729100, 'AE', '2014-04-21', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18, 'Sharjah', 'Sharjah', 'Al Sharjah,Ash ''Mariqah,Ash Shariqa,Ash Shariqah,Ash Shāriqa,Ash Shāriqah,Ash ’Mariqah,Ash-Shariqah emiraat,Ash-Shāriqah emiraat,Charjah,Ch·ardj·a,Gorad Shardzha,SHJ,Sardza,Sardzsa,Sarika,Sarja,Sarjo,Sarza,Schardscha,Shardza,Shardzha,Shardzha kuorat,Sharga,Sharijah,Shariqah,Sharja,Sharjah,Shārijah,Shāriqah,Shārja,Szardza,Szardża,Xarja,Xarjah,alsharqt,amart alsharqt,carja,charc ah,saraja,sarajaha,sarja,sharja,sharjh,sharuja,syaleuja,sʼrgh,xia er jia,Ŝarĵo,Şarika,Şarja,Šardža,Šardžá,Горад Шарджа,Шарджа,Шарджа куорат,Шарџа,Шарҗә,Շարժա,שארגה,إمارة الشارقة,الشارقة,شارجه,شارجہ,शारजा,शारजाह,ਸ਼ਾਰਜਾ,சார்ஜா,షార్జా,ಶಾರ್ಜ,ഷാർജ,ชาร์จาห์,შარჯა,シャールジャ,夏尔迦,샤르자', 25.3373700, 55.4120600, 'AE', '2013-03-05', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19, 'Ar Ruways', 'Ar Ruways', 'Ar Ru''ays,Ar Ruways,Ar Ru’ays,Ar-Ruvais,Ruwais,Ар-Руваис', 24.1102800, 52.7305600, 'AE', '2012-11-03', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20, 'Al Fujayrah', 'Al Fujayrah', 'Al Fujayrah,Al-Fudjayra,Al-Fujayrah'' emiraat,FJR,Fudschaira,Fudzhejra,Fujaira,Fujairah,Fujajro,Fujayrah,Fuĵajro,alfjyrt,fjyrt,fu ji la,fujaira,Фуджейра,الفجيرة,فجيرة,フジャイラ,富吉拉', 25.1164100, 56.3414100, 'AE', '2016-12-18', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21, 'Al Ain', 'Al Ain', 'AAN,Ainas,Al Ain,Al Ajn,Al Ayn,Al `Ayn,Al Ɛayn,Al ‘Ayn,Al-Ain,Al-Ajn,Al-Ayin,Al-Ayn,Al-Aïn,Ehl''-Ajn,El Ain,El-Ajn,ai yin,al ain,al-ain,al-aini,alʿyn,ela ena,Ел Аин,Эль-Айн,Ալ-Ային,אל-עין,العين,العین,एल एन,அல் ஐன்,അൽ ഐൻ,ალ-აინი,アル・アイン,艾因,알아인', 24.1916700, 55.7605600, 'AE', '2013-03-17', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22, 'Ajman', 'Ajman', 'Ajman,Al Ajman,QAJ,Ujman,ʿjman,عجمان', 25.4111100, 55.4350400, 'AE', '2013-03-24', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23, 'Adh Dhayd', 'Adh Dhayd', 'Adh Dhaid,Adh Dhayd,Al Daid,Al-Dhayd,Dayd,Dhaid,Dhayd,Duhayd,Ihaid,aldhyd,الذيد,Ḑayd', 25.2881200, 55.8815700, 'AE', '2012-01-18', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24, 'Abu Dhabi', 'Abu Dhabi', 'A-pu-that-pi,AEbu Saby,AUH,Aboe Dhabi,Abou Dabi,Abu Dabi,Abu Dabis,Abu Daby,Abu Daibi,Abu Dhabi,Abu Dhabi emiraat,Abu Zabi,Abu Zaby,Abu Zabye,Abu Zabyo,Abu Ḍabi,Abu Ḑabi,Abu-Dabi,Abu-Dabi khot,Abu-Dabio,Abu-Dzabi,Abú Dabí,Abú Daibí,Abú Zabí,Abû Daby,Abū Dabī,Abū Z̧aby,Abū Z̧abye,Abū Z̧abyo,Abū Z̧abī,Ampou Ntampi,Ebu Dabi,Ebu Dhabi,Gorad Abu-Dabi,a bu zha bi,abu dhabi,abu-dabi,abudabi,abudhabi,abw zby,abwzby,aputapi,xa bud abi,Â-pu-tha̍t-pí,Äbu Saby,Əbu-Dabi,Άμπου Ντάμπι,Αμπου Νταμπι,Αμπού Ντάμπι,Абу Даби,Абу-Даби,Абу-Даби хот,Абу-Дабі,Горад Абу-Дабі,Әбу-Даби,Աբու Դաբի,אבו דאבי,أبوظبي,ئەبووزەبی,ابو ظبى,ابوظبی,ابوظہبی,अबु धाबी,अबू धाबी,আবুধাবি,ਅਬੂ ਧਾਬੀ,ଆବୁଧାବି,அபுதாபி,ಅಬು ಧಾಬಿ,അബുദാബി,අබුඩාබි,อาบูดาบี,ཨ་པོའུ་དྷ་པེ།,အဘူဒါဘီမြို့,აბუ-დაბი,አቡ ዳቢ,アブダビ,阿布扎比,아부다비', 24.4666700, 54.3666700, 'AE', '2016-06-03', 234);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(329, 'Pas Pul', 'Pas Pul', 'Pas Pol,Pas Pul,ps pl,پس پل', 37.4735500, 70.6161700, 'AF', '2013-09-09', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(330, 'Qal‘ah-ye Na‘īm', 'Qal`ah-ye Na`im', 'Kalanaim,Qal`ah-ye Na`im,Qal`eh Na`im,Qal`eh-ye Na`im,Qal‘ah-ye Na‘īm,Qal‘eh Na‘īm,Qal‘eh-ye Na‘īm,قلعه نعيم', 34.3995100, 69.1670500, 'AF', '2013-06-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(331, 'Markaz-e Woluswalī-ye Āchīn', 'Markaz-e Woluswali-ye Achin', 'Achin,Achin-Ulusvali,Acin Oluswali,Markaz-e Woluswali-ye Achin,Markaz-e Woluswalī-ye Āchīn,achyn,Āchīn,Āčīn Oluswāli,آچين', 34.1258300, 70.7077800, 'AF', '2010-08-10', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(332, 'Manogay', 'Manogay', 'Manogay,Manugay,Mānūgay,Māṉōgay,manwgy,مانوگی,ماڼوگی', 34.9901500, 70.9130200, 'AF', '2012-02-29', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(333, 'Stêr Giyān', 'Ster Giyan', 'Gayan,Gayān,Ster Gian,Ster Giyan,Ster Gyan,Ster Gyān,Sterg''yan,Sterg’yan,Stêr Giyān,Stêr Gīān,gyan,str gyan,ستر گیان,گیان', 32.9770400, 69.3730800, 'AF', '2012-05-06', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(334, 'Sharan', 'Sharan', 'OAS,Sharan,Sharan Woluswali,Sharan Woluswālī,Sharan Wuleswali,Sharan Wulêswālī,Sharana,shrn,شرن', 33.1756800, 68.7304500, 'AF', '2017-02-17', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(335, 'Salām Khēl', 'Salam Khel', 'Salam Khel,Salām Khēl,slam khېl,سلام خېل', 33.6706700, 69.3298300, 'AF', '2013-06-05', 1);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(359, 'Xarrë', 'Xarre', 'Cara,Qare,Qarë,Xara,Xare,Xarja,Xarra,Xarre,Xarrë,Xarë', 39.7283300, 20.0544400, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(360, 'Sarandë', 'Sarande', 'Agioi,Agioi Saranta,Ayii Saranda,Hagios Saranta,Onchesmus,Porto Edda,Santa Quaranta,Santi Quaranta,Saranda,Sarande,Sarandë,Sarandė,Saranta,Zogaj,sa lan da,salandeo,saranda,sarandh,srndh,Άγιοι Σαράντα,Саранда,Սարանդա,סרנדה,سارانده,ساراندہ,サランダ,萨兰达,사란더', 39.8755600, 20.0052800, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(361, 'Mesopotam', 'Mesopotam', 'Mesapotami,Mesopotam,Mesopotam i Poshter,Mesopotam i Poshtër,Mesopotami,Mesopotamo,Mesopótamo', 39.9102800, 20.0922200, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(362, 'Markat', 'Markat', 'Markat,Markati', 39.7327800, 20.1952800, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(363, 'Livadhja', 'Livadhja', 'Hoxha,Hoxhaj,Hoxhe,Hoxhë,Livadh,Livadhe,Livadhja,Livadhjaja,Livadhjaje,Livadhjajë,Livadhje', 39.7891700, 20.1219400, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(364, 'Konispol', 'Konispol', 'Conispolis,Konispoje,Konispol,Konispol'',Konispoli,Konispolis,ke ni si bo er,Кониспол,Конисполь,Конісполь,Կոնիսպոլ,科尼斯波尔', 39.6588900, 20.1813900, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(365, 'Kakavijë', 'Kakavije', 'Cacavia,Kakavi,Kakavia,Kakavija,Kakavije,Kakavijë,Kakavja', 39.9077800, 20.3583300, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(366, 'Finiq', 'Finiq', 'Eniki,Fenichi,Finik,Finiq,Finiqi,Firiq', 39.9063900, 20.0583300, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(367, 'Dhivër', 'Dhiver', 'Dhiver,Dhivre,Dhivri,Dhivrë,Dhivër,Kallarati,Kulurat,Kulurica', 39.8361100, 20.1686100, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(368, 'Delvinë', 'Delvine', 'Del''vina,Delvina,Delvine,Delvino,Delvinon,Delvinë,Zelvinou,Дельвина', 39.9511100, 20.0977800, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(369, 'Aliko', 'Aliko', 'Alicu,Alikaj,Aliko,Alikoja,Alikoje,Alikojë,Alikon', 39.8586100, 20.0791700, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(370, 'Buçimas', 'Bucimas', 'Bucimas,Bucimasi,Buçimas,Buçimasi,Starova,Starove,Starovë', 40.8913900, 20.6813900, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(371, 'Zhepë', 'Zhepe', 'Xhepa,Xhepe,Xhepë,Zhepa,Zhepe,Zhepë', 40.6777800, 20.2869400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(372, 'Zerqan', 'Zerqan', 'Arta,Zergjan,Zergjani,Zerqan,Zerqani,Zrkjan', 41.5022200, 20.3605600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(373, 'Zavalinë', 'Zavaline', 'Zavalin,Zavalina,Zavaline,Zavalinë', 40.9808300, 20.2808300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(374, 'Zapod', 'Zapod', 'Zagoti,Zapod,Zapodi,Zapot,Zapoti', 42.0505600, 20.5525000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(375, 'Zall-Reç', 'Zall-Rec', 'Rec,Reci,Reç,Reçi,Zali,Zall,Zall-Rec,Zall-Reci,Zall-Reç,Zall-Reçi,Zalli', 41.8761100, 20.3200000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(376, 'Zall-Dardhë', 'Zall-Dardhe', 'Zali,Zall i Dardhes,Zall i Dardhës,Zall-Dardha,Zall-Dardhe,Zall-Dardhë,Zalli i Dardes,Zalli i Dardhes,Zalli i Dardhës', 41.8066700, 20.3361100, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(377, 'Xibër-Murrizë', 'Xiber-Murrize', 'Murrize,Murrizë,Xiber,Xiber-Muriza,Xiber-Murize,Xiber-Murr,Xiber-Murriz,Xiber-Murriza,Xiber-Murrize,Xiber-Murrizia,Xiberr-Murrize,Xibri,Xibër,Xibër-Murizë,Xibër-Murr,Xibër-Murriz,Xibër-Murriza,Xibër-Murrizia,Xibër-Murrizë,Xibërr-Murrizë,Ziber-Murize,Zibër-Murizë', 41.4547200, 20.0255600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(378, 'Vreshtas', 'Vreshtas', 'Vreshtas,Vreshtasi', 40.7969400, 20.7769400, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(379, 'Voskopojë', 'Voskopoje', 'Moscopole,Moskhopolis,Moskopole,Voskopoi,Voskopoj,Voskopoja,Voskopoje,Voskopojë', 40.6330600, 20.5888900, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(380, 'Voskop', 'Voskop', 'Voskop,Voskopi', 40.6119400, 20.6902800, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(381, 'Vithkuq', 'Vithkuq', 'Vithkuq,Vithkuqi', 40.5250000, 20.5825000, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(382, 'Vithkuq', 'Vithkuq', 'Bithyq,Bityq,Buthuq,Bythyci,Bythyq,Bythyçi,Vithkuq,Vithuq,Vithuqi,Zagor,Zagori,Zagorie', 40.2047200, 20.2594400, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(383, 'Vërtop', 'Vertop', 'Vertop,Vertopi,Vërtop', 40.6288900, 20.0538900, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(384, 'Vergo', 'Vergo', 'Vergo,Vergoja,Vergoje,Vergojë', 40.0066700, 20.0088900, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(385, 'Vendresha e Vogël', 'Vendresha e Vogel', 'Vendresha e Vogel,Vendresha e Vogël,Vendreshe e Vogel,Vëndreshë e Vogël', 40.5072200, 20.1347200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(386, 'Velçan', 'Velcan', 'Velcan,Velcan Mokra,Velcan Mokrra,Velcan i Mokres,Velcan i Mokrres,Velcani,Velcani i Mokres,Velçan,Velçan i Mokrrës,Velçan i Mokrës,Velçani,Velçani i Mokrës', 40.9547200, 20.4622200, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(387, 'Ujmisht', 'Ujmisht', 'Mem,Ujmisht,Ujmishte,Ujmishte e Gurit,Ujmishti,Ujmishtë,Ujmishtë e Gurit,Ymishte-e Gurit,Ymishtë-e Gurit', 41.9083300, 20.3469400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(388, 'Udënisht', 'Udenisht', 'Hodonishta,Hodonishti,Hodonista,Hodoništa,Hudenisht,Hudenishta,Hudenishti,Hudënishta,Udenisht,Udenishte,Udenishti,Udënisht,Udënishtë', 40.9633300, 20.6391700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(389, 'Tunjë', 'Tunje', 'Tune,Tunia,Tunja,Tunje,Tunjë', 40.8341700, 20.1119400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(390, 'Tregan', 'Tregan', 'Tregan,Tregani', 41.0247200, 20.0783300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(391, 'Trebisht-Muçinë', 'Trebisht-Mucine', 'Trebisht-Mucina,Trebisht-Mucine,Trebisht-Muçina,Trebisht-Muçinë', 41.4111100, 20.5355600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(392, 'Trebinjë', 'Trebinje', 'Trebinja,Trebinje,Trebinjë', 40.9133300, 20.5530600, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(393, 'Topojan', 'Topojan', 'Tapaiani,Topaiani,Topajan,Topojan,Topojani,Topoyani', 40.3772200, 20.2133300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(394, 'Tomin', 'Tomin', 'Tomin,Tomini,Tonun,Tumini', 41.6908300, 20.4216700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(395, 'Tepelenë', 'Tepelene', 'Tepelen,Tepelena,Tepelene,Tepeleni,Tepelenë,Tepelenė,tai pei lai na,tepelleneo,tplnh,Τεπελένι,Тепелена,Тепелєна,تپلنه,تپلنہ,台佩莱纳,테펠레너', 40.2958300, 20.0191700, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(396, 'Surroj', 'Surroj', 'Serroj,Suroj,Surroj,Surroji', 41.9922200, 20.3441700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(397, 'Sult', 'Sult', 'Sul,Suli,Sult,Sulta,Sulte,Sulti,Sultë', 40.8847200, 20.0994400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(398, 'Sukë', 'Suke', 'Suka,Suke,Sukë', 40.3752800, 20.1547200, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(399, 'Suç', 'Suc', 'Suc,Suci,Suç,Suçi', 41.5769400, 20.0513900, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(400, 'Stravaj', 'Stravaj', 'Lira,Stovanit,Stravaj,Stravaje,Stravaji,Stravan,Stravani,Strevan', 41.0052800, 20.4230600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(401, 'Steblevë', 'Stebleve', 'Slinza,Stebilova,Steblev,Stebleva,Stebleve,Steblevë,Stebljeva,Stebllova,Sterbleva,Stërbleva,Šlinza', 41.3372200, 20.4700000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(402, 'Sllovë', 'Sllove', 'Slleva,Sllova,Sllove,Sllovë', 41.8011100, 20.4083300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(403, 'Skore', 'Skore', 'Shkore,Shkorë,Shore,Shorë,Skore,Skorea,Skoreja', 40.1072200, 20.3663900, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(404, 'Skënderbegas', 'Skenderbegas', 'Shemberdhej i Poshtem,Shemberdhenj i Poshtem,Shemberthej i Poshtem,Shemerdhej i Poshtme,Shemerdhenj i Poshtem,Shemerdhenj i Poshtëm,Shenmerllag,Shëmberdhej i Poshtëm,Shëmberdhenj i Poshtëm,Shëmbërthej i Poshtëm,Shëmerdhej i Poshtme,Shënmerllag,Skenderbegas,Skenderbegasi,Skënderbegas,Skënderbegasi', 40.7761100, 20.2405600, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(405, 'Shushicë', 'Shushice', 'Scuscitsa,Shushica,Shushice,Shushicë', 41.0975000, 20.1483300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(406, 'Shupenzë', 'Shupenze', 'Sciupentse,Shepenze,Shtepenz,Shtupenza,Shtëpenz,Shupenz,Shupenza,Shupenze,Shupenzë,Shëpenzë', 41.5300000, 20.4236100, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(407, 'Shtiqën', 'Shtiqen', 'Shticen,Shtiger,Shtigjen,Shtigër,Shtiqen,Shtiqeni,Shtiqën,Shtiqëni,Stidden,Štidđen', 42.0405600, 20.4341700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(408, 'Shishtavec', 'Shishtavec', 'Scishnevitc,Scishnevitć,Shishtavec,Shishtaveci,Shishtevec,Sistevac,Šištevac', 41.9800000, 20.6058300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(409, 'Shirgjan', 'Shirgjan', 'Shirgjan,Shirgjani', 41.0519400, 20.0533300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(410, 'Shëngjin', 'Shengjin', 'Shen Gjini,Shengin,Shengjin,Shingjin,Shingjini,Shëngjin,Шенгин', 41.9261100, 20.1883300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(411, 'Shënmëri', 'Shenmeri', 'Shemeri,Shemeria,Shemri,Shemria,Shemrija,Shenmeri,Shenmric,Shmria,Shëmri,Shëmria,Shëmrija,Shëmëri,Shënmëri', 42.1041700, 20.2383300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(412, 'Selishtë', 'Selishte', 'Selishta,Selishta e Poshtme,Selishte,Selishtë', 41.6275000, 20.2791700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(413, 'Saraqinishtë', 'Saraqinishte', 'Sarachinista,Sarakinista,Saranishte,Saraqinisht,Saraqinishta,Saraqinishte,Saraqinishtë', 40.1052800, 20.2294400, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(414, 'Rukaj', 'Rukaj', 'Rukaj', 41.6836100, 20.0191700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(415, 'Rajcë', 'Rajce', 'Raica,Rajca,Rajce,Rajcë,Rrajca,Rrajce,Rrajcë,Sula', 41.0902800, 20.5763900, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(416, 'Roshnik', 'Roshnik', 'Fikaj,Roshnic,Roshnik,Roshniku,Rosniki,Rroshniku', 40.7327800, 20.0394400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(417, 'Qukës-Skënderbe', 'Qukes-Skenderbe', 'Qukes-Skenderbe,Qukes-Skenderbej,Qukes-Skenderbeu,Qukës-Skënderbe,Qukës-Skënderbej,Qukës-Skënderbeu', 41.0838900, 20.4380600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(418, 'Qestorat', 'Qestorat', 'Chiesarat,Khiesarat,Qesarat,Qestorat,Qestorati', 40.1175000, 20.1997200, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(419, 'Qafëmal', 'Qafemal', 'Chafamalit,Qaf Mal,Qaf Mali,Qafa e Malit,Qafamal,Qafe Mali,Qafe e Malit,Qafemal,Qafë Mali,Qafë e Malit,Qafëmal', 42.0933300, 20.0905600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(420, 'Përrenjas-Fshat', 'Perrenjas-Fshat', 'Perrenjas-Fshat,Prrenjas-Fshat,Prrenjasi,Përrenjas-Fshat', 41.0666700, 20.5352800, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(421, 'Përrenjas', 'Perrenjas', 'Fshat Perrenjasi,Fshat Përrenjasi,Perren''jas,Perrenjas,Perrenjasi,Perrenjes,Prenjas,Prenjasi,Prenjesi,Prenjs,Prenjësi,Prrenjas,Prrenjasi,Përrenjas,Përrenjasi,Përrenjës,Перреньяс', 41.0730600, 20.5488900, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(422, 'Proptisht', 'Proptisht', 'Propishte,Propishtë,Proptisht,Proptishta,Proptishte,Proptishti,Proptishtë', 40.9861100, 20.5025000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(423, 'Progër', 'Proger', 'Proger,Progeri,Progri,Progër,Progëri', 40.6941700, 20.9402800, 'AL', '2012-06-09', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(424, 'Potom', 'Potom', 'Podhom,Potom,Potomi', 40.4883300, 20.3733300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(425, 'Poroçan', 'Porocan', 'Porocan,Porocani,Poroçan,Poroçani', 40.9419400, 20.2986100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(426, 'Polis-Gostimë', 'Polis-Gostime', 'Polis,Polis i-Madh,Polis-Gostime,Polis-Gostimë,Polisi,Polisi Mazi,Xhamia e Siperme,Xhamia e Sipërme', 41.1333300, 20.2583300, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(427, 'Poliçan', 'Polican', 'Polican,Policani,Polichan,Poliçan,Poliçani,Поличан', 40.6122200, 20.0980600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(428, 'Pojan', 'Pojan', 'Poiani,Pojan,Pojani', 40.7258300, 20.8375000, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(429, 'Pogradec', 'Pogradec', 'Pogradec,Pogradeci,Pogradecis,Pogradets,bo ge la de ci,pogeuladecheu,poguradetsu,pwgradts,pwgrdz,Πόγραδετς,Поградец,פוגרדץ,پوگرادتس,ポグラデツ,波格拉德茨,포그라데츠', 40.9025000, 20.6525000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(430, 'Pishaj', 'Pishaj', 'Pishaj', 40.8811100, 20.1827800, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(431, 'Pirg', 'Pirg', 'Pirg,Pirgu,Pirk', 40.7850000, 20.7061100, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(432, 'Gjinkar', 'Gjinkar', 'Gjinakar,Gjinkan-Petrani,Gjinkar,Gjinkar-Petran,Petran,Petrani,Petrani-Gjinkari,Petranit', 40.1994400, 20.4061100, 'AL', '2013-05-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(433, 'Petran', 'Petran', 'Pertran,Petran,Qender,Qendra,Qendër', 40.2094400, 20.4183300, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(434, 'Peshkopi', 'Peshkopi', 'Dibra,Dibre,Dibrë,Episkopi,Peshkepija,Peshkepije,Peshkopeja,Peshkopi,Peshkopia,Peshkopie,Peshkopija,Peshkopije,Peshkopië,Peshkopla,Peshkëpijë,Peskopia,Peskopija,Peškopija,Piscopeia,Pishcopeja,Pishkopeja,pei shen ke bi,peshukopi,pesyukopi,pshkwpy,pshkwpya,Επισκοπή,Пешкопеја,Пешкопи,Пешкопия,Пешкопія,Пишкопеја,Պեշկոպիա,پشکوپی,پشکوپیا,ペシュコピ,佩什科比,페슈코피', 41.6850000, 20.4288900, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(435, 'Përmet', 'Permet', 'Permet,Permeti,Permetis,Premet,Premete,Premeti,Premetē,Prëmet,Purmet,Përmet,Përmeti,brmt,pei er mei te,prmt,Πρεμετή,Пермет,Пермети,Пърмет,برمت,پرمت,佩爾梅特', 40.2336100, 20.3516700, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(436, 'Ostreni i Math', 'Ostreni i Math', 'Ostren,Ostren i Madh,Ostren i Math,Ostren i madhe,Ostren i madhë,Ostreni,Ostreni i Madh,Ostreni i Math,Ostrenimaze,Pljakoni i Mal', 41.4308300, 20.4555600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(437, 'Orosh', 'Orosh', 'Orosh,Oroshi', 41.8333300, 20.0833300, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(438, 'Orenjë', 'Orenje', 'Oreja,Orenja,Orenje,Orenjë,Orhenja,Orhenje,Orhenjë', 41.2847200, 20.2119400, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(439, 'Odrie', 'Odrie', 'Odria', 40.1333300, 20.1666700, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(440, 'Novoselë', 'Novosele', 'Navosele,Novasela,Novosela,Novosele,Novoselë,Piskal-Novosele,Piskal-Novoselë', 40.7613900, 20.6983300, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(441, 'Picar', 'Picar', 'Novace,Novacë,Picar,Picari', 40.1666700, 20.0483300, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(442, 'Mollas', 'Mollas', 'Maulas,Mollas,Mollasi,Motas', 40.9269400, 20.0036100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(443, 'Mollas', 'Mollas', 'Mollas,Mollasi', 40.4255600, 20.6744400, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(444, 'Mollaj', 'Mollaj', 'Dooran,Dvoran,Dvorani,Mollaj,Tepexhik', 40.5602800, 20.7402800, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(445, 'Miras', 'Miras', 'Bozhigra,Bozhigrad,Bozhigradi,Bozhigrat,Bozigrad,Miras,Mirasi', 40.5091700, 20.9283300, 'AL', '2012-06-09', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(446, 'Melan', 'Melan', 'Melan,Melani', 41.6541700, 20.4652800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(447, 'Martanesh', 'Martanesh', 'Kaptina,Martaneshi', 41.4000000, 20.2000000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(448, 'Maqellarë', 'Maqellare', 'Magellara,Magellare,Magellarë,Makelare,Makelari,Maqellara,Maqellare,Maqellari,Maqellarë,Maqllara,Макеларе,Макелари', 41.5888900, 20.4830600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(449, 'Maliq', 'Maliq', 'Malik,Maliq,Maliqi,Малик', 40.7058300, 20.6997200, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(450, 'Macukull', 'Macukull', 'Macuklli,Macukuli,Macukull,Macukulli', 41.6886100, 20.1102800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(451, 'Lunik', 'Lunik', 'Ljumnik,Lumnik,Lunik,Lunike,Luniku,Lunikë', 41.2891700, 20.3236100, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(452, 'Llugaj', 'Llugaj', 'Llugaj,Lugat', 42.3413900, 20.1086100, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(453, 'Lis', 'Lis', 'Lis,Lisa,Lise,Lisi,Lisë', 41.6275000, 20.0852800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(454, 'Liqenas', 'Liqenas', 'Liqenas,Liqenasi,Postec,Pushteci,Pustec,Pusteci', 40.7866700, 20.9022200, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(455, 'Librazhd', 'Librazhd', 'Labrazhd,Libohov,Libohovo,Libokhovon,Libradzh,Librash,Librazdi,Librazdis,Librazhd,Librazhdi,Librazhet,Libraždi,Libraždis,li bu la shen de,lybrajd,lybrazhd,Либрадж,Либражд,Лібражд,ليبراجد,لیبراژد,利布拉什德', 41.1794400, 20.3150000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(456, 'Libonik', 'Libonik', 'Libonik,Liboniku,Libovnik', 40.7044400, 20.7086100, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(457, 'Libohovë', 'Libohove', 'Libhova,Libohov,Libohova,Libohova Qender,Libohova Qendër,Libohove,Libohovo,Libohovë,Libokhova,Libokhovo,Libokhovon,li bo huo wa,Либохова,Либохово,Лібохова,利博霍瓦', 40.0311100, 20.2630600, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(458, 'Leskovik', 'Leskovik', 'Leskovik,Leskoviku,Leskoviqi,Liascovik,Liascovitsi,Liaskoviki,Ljakovici,Лесковик', 40.1513900, 20.5972200, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(459, 'Leshnjë', 'Leshnje', 'Leshnja,Leshnje,Leshnjë,Lesnia', 40.5369400, 20.3133300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(460, 'Lenias', 'Lenias', 'Lenias,Leniasi,Lenie,Schinapremtja,Scinapremte,Shenapremte,Shenapremtja,Shenaprende,Shenepremte,Shenepremtja,Shenpremtja,Shinapremta,Shinapremte,Shinepremtja,Shënapremte,Shënapremtja,Shënepremtja,Shëneprëmte,Shënpremtja', 40.7666700, 20.3913900, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(461, 'Lekas', 'Lekas', 'Lekas,Lekasi', 40.6022200, 20.5125000, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(462, 'Lazarat', 'Lazarat', 'Lazarat,Lazarati,Liazarati,Linzarates', 40.0466700, 20.1475000, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(463, 'Labinot-Mal', 'Labinot-Mal', 'Labinot,Labinot e-siperm,Labinot e-sipërm,Labinot i Siperm,Labinot i Sipërm,Labinot-Mal,Labinoti i Siperm,Labinoti i Sipërm,Labinoti i siperme,Labinoti i sipermë,Labinoti-Mal,Labinotie i Siperme,Labinotie i Sipermë,Ljabinoti sipermi', 41.2008300, 20.1522200, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(464, 'Labinot-Fushë', 'Labinot-Fushe', 'Labinot,Labinot i Poshtem,Labinot i Poshtëm,Labinot-Fushe,Labinot-Fushë,Labinoti,Labinoti i Poshtem,Labinoti-Fushe,Labinoti-Fushë', 41.1405600, 20.1461100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(465, 'Kushovë', 'Kushove', 'Kushova,Kushove,Kushovë,Shaltura', 40.7888900, 20.1888900, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(466, 'Kurbnesh', 'Kurbnesh', 'Kurbnesh,Kurbnesha,Kurbneshi,Курбнеш', 41.7797200, 20.0836100, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(467, 'Kukur', 'Kukur', 'Kuker,Kukeri,Kukur,Kukuri,Kukër,Kukëri', 40.8677800, 20.3636100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(468, 'Kukës', 'Kukes', 'Cucus,Kukes,Kukesi,Kuks,Kuksi,Kukuch,Kukus,Kukës,Kukësi,Кукес,Кукъс', 42.0769400, 20.4219400, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(469, 'Kthella e Epërme', 'Kthella e Eperme', 'Kethella e Eper,Ktelle e eper,Ktellë e eper,Kthella Eper,Kthella Epër,Kthella e Eperme,Kthella e Epërme,Kthella e eper,Kthella e epër,Kthelle e Eper,Kthelle e Eperme,Kthelle e Siperme,Kthellë e Epër,Kthellë e Epërme,Kthellë e Sipërme', 41.8119400, 20.0588900, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(470, 'Krumë', 'Krume', 'Kruma,Krume,Krumë,Крума', 42.1969400, 20.4133300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(471, 'Korçë', 'Korce', 'Corce,Corcë,Coritsa,Coritza,Coriza,Corizza,Corriza,Ghiortsa Corcia,Goerice,Gorica,Goritsa,Görice,Korca,Korce,Korcha,Korche,Korcza,Korica,Korice,Koritsa,Koritza,Korrca,Korrce,Korrça,Korrçë,Korytsa,Korça,Korçë,Korča,Korčė,Körice,ke er cha,koleucheo,korucha,kwrchh,qwrzh,Κορυτσά,Горица,Корча,Կորչա,קורצה,کورچه,کورچہ,コルチャ,科尔察,코르처', 40.6186100, 20.7808300, 'AL', '2012-11-26', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(472, 'Kolsh', 'Kolsh', 'Kalshi,Klosh,Koljsi,Koljši,Kolsh,Kolshi', 42.0780600, 20.3419400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(473, 'Kodovjat', 'Kodovjat', 'Kodoviati,Kodovjat,Kodovjati,Lidaj', 40.8055600, 20.2511100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(474, 'Klos', 'Klos', 'Dullinjasi,Klos,Klosi,Клос', 41.5069400, 20.0866700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(475, 'Klos', 'Klos', 'Klos,Klosi,Клос', 40.9461100, 20.0097200, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(476, 'Këlcyrë', 'Kelcyre', 'Kel''cira,Kelcyra,Kelcyre,Kelcyres,Kelcyrës,Kleisoura,Klisura,Këlcyra,Këlcyrë,Кельцира', 40.3130600, 20.1894400, 'AL', '2015-08-26', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(477, 'Kastriot', 'Kastriot', 'Kastriot,Kastriota,Kastrioti', 41.7294400, 20.3772200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(478, 'Kardhiq', 'Kardhiq', 'Gardiki,Kardhiq,Kardhiqi', 40.1216700, 20.0275000, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(479, 'Kalis', 'Kalis', 'Kalis,Kalisi,Kallashi,Kalles,Kallës', 41.8388900, 20.3666700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(480, 'Iballë', 'Iballe', 'Ibalja,Iballe,Iballja,Iballje,Iballjë,Iballë,Jballje', 42.1875000, 20.0025000, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(481, 'Hotolisht', 'Hotolisht', 'Baldreti,Hodolishti,Hotolisht,Hotolishta,Hotolishti,Kotolishta,Otolisht', 41.1566700, 20.3972200, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(482, 'Hoçisht', 'Hocisht', 'Hochishte,Hocisht,Hocishte,Hocishti,Hocishtit,Hoçisht,Hoçishti,Hoçishtë', 40.6083300, 20.9141700, 'AL', '2012-06-09', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(483, 'Gramsh', 'Gramsh', 'Gramish,Gramsci,Gramsh,Gramshi,Gramsis,Gramšis,ge la mu shen,gramsh,Грамш,Грамши,Грамші,گرامش,格拉姆什', 40.8697200, 20.1844400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(484, 'Gostimë', 'Gostime', 'Gostim-Mal,Gostim-Mali,Gostima,Gostime,Gostime-Mal,Gostimë,Gostimë-Mal', 41.1455600, 20.2400000, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(485, 'Golaj', 'Golaj', 'Golai,Golaj,Goljai', 42.2475000, 20.3802800, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(486, 'Gjorica e Sipërme', 'Gjorica e Siperme', 'Gjorica,Gjorica e Eperme,Gjorica e Epërme,Gjorica e Siperme,Gjorica e Sipërme,Gjorice,Gjorice e Eper,Gjorice e Eperme,Gjorice e Siperme,Gjoricë,Gjoricë e Epër,Gjoricë e Epërme,Gjoricë e Sipërme,Gorice,Goricë', 41.5344400, 20.4500000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(487, 'Gjirokastër', 'Gjirokaster', 'Agirocastro,Arghirocastru,Arghyrocastro,Argirocastro,Argirokastro,Argyrocastrum,Argyrokastro,Argyrokastron,Aryirokastro,Aryirokastron,Ergheni,Ergiri,GJirokastra,Ghinokastre,Girokasteris,Girokastra,Girokastro,Gjinokaster,Gjinokastra,Gjinokastre,Gjinokastrer,Gjinokastër,Gjirokaster,Gjirokastra,Gjirokastre,Gjirokastro,Gjirokastrë,Gjirokastër,arjyr,gyrwqstrh,ji nuo ka si te,jilokaseuteoleu,jirokasutora,jyrwkastr,Đirokastra,Αργυρόκαστρο,Ђирокастра,Ѓирокастро,Аргирокастро,Гирокастра,Гирокастро,Гірокастра,גירוקסטרה,ارجیر,جیروکاستر,გიროკასტრა,ジロカストラ,吉诺卡斯特,지로카스터르', 40.0758300, 20.1388900, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(488, 'Gjinar', 'Gjinar', 'Giniari,Gjinar,Gjinari', 41.0225000, 20.1888900, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(489, 'Gjinaj', 'Gjinaj', 'Dinai,Gjinai,Gjinaj,Ðinai', 42.1180600, 20.4358300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(490, 'Gjergjan', 'Gjergjan', 'Gjergjan,Gjergjani,Gjergjenj', 41.0430600, 20.0297200, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(491, 'Gjegjan', 'Gjegjan', 'Gjegjan,Gjegjani,Zhezhan', 41.9377800, 20.0111100, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(492, 'Fushë-Muhurr', 'Fushe-Muhurr', 'Fush-Muhur,Fushe-Muhri,Fushe-Muhur,Fushe-Muhuri,Fushe-Muhurr,Fushe-Muhurri,Fushe-Mukheri,Fushe-Mukhuri,Fushë-Muhri,Fushë-Muhur,Fushë-Muhuri,Fushë-Muhurr,Fushë-Muhurri,Muherr,Muhur,Muhuri,Muhurr,Mukur', 41.6797200, 20.3313900, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(493, 'Fushë-Lurë', 'Fushe-Lure', 'Fush'' e Lures,Fusha Lures,Fusha Lurës,Fusha e Lures,Fusha e Lurës,Fushe-Lura,Fushe-Lure,Fushë-Lura,Fushë-Lurë,Fush’ e Lurës,Lure e eper,Lurë e epër', 41.8061100, 20.2319400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(494, 'Fushë-Çidhnë', 'Fushe-Cidhne', 'Fush'' e Alijajt,Fusha Ali,Fusha Alijaj,Fushaj,Fushe Alija,Fushe-Alia,Fushe-Alie,Fushe-Cidhen,Fushe-Cidhna,Fushe-Cidhne,Fushë-Alia,Fushë-Alië,Fushë-Çidhna,Fushë-Çidhnë,Fushë-Çidhën,Fush’ e Alijajt', 41.7605600, 20.3411100, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(495, 'Fushë-Bulqizë', 'Fushe-Bulqize', 'Bulqize Fusha,Bulqizë Fusha,Fushaj,Fushe-Bulqiza,Fushe-Bulqize,Fushë-Bulqiza,Fushë-Bulqizë', 41.5219400, 20.2822200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(496, 'Fushë-Arrëz', 'Fushe-Arrez', 'Arres,Arrës,Arsi,Arst,Fusha e Arezit,Fusha e Arrezit,Fusha e Arrëzit,Fusha e Arsit,Fusha e Arëzit,Fusha-Arres,Fusha-e-Arresit,Fushe Arrezi,Fushe e Arrezit,Fushe-Ares,Fushe-Aresi,Fushe-Arezi,Fushe-Arezit,Fushe-Arresi,Fushe-Arrez,Fushë e Arrëzit,Fushë-Arrësi,Fushë-Arrëz,Fushë-Arëzi,Fushë-Arëzit,Фуша-Аррес', 42.0622200, 20.0166700, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(497, 'Frashër', 'Frasher', 'Frasceri,Frasher,Frasheri,Frashër,Frashëri,Phrasare,Phrasarë', 40.3688900, 20.4244400, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(498, 'Fierzë', 'Fierze', 'Fiera,Fierza,Fierze,Fierzë,Firez,Firza,Firëz,Фиерза', 42.2605600, 20.0169400, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(499, 'Fajzë', 'Fajze', 'Fajza,Fajze,Fajzë', 42.1669400, 20.3508300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(500, 'Ersekë', 'Erseke', 'Colonia,Ehrseka,Erseg Giatseg,Ersek,Erseka,Erseke,Ersekë,Ersekė,Kolonija,Kolonije,Kolonijë,Kolonja,Kolonje,Kolonjë,ai er sai ke,arska,Ερσέκα,Ерсека,Эрсека,ارسکا,愛爾塞克', 40.3377800, 20.6788900, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(501, 'Elbasan', 'Elbasan', 'Ehl''basan,Elbasan,Elbasani,Elbassan,Эльбасан', 41.1125000, 20.0822200, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(502, 'Drenovë', 'Drenove', 'Drenova,Drenove,Drenovo,Drenovë', 40.5833300, 20.7922200, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(503, 'Dishnicë', 'Dishnice', 'Deshnica,Dishnica,Dishnice,Dishnicë,Tishnica', 40.6513900, 20.8136100, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(504, 'Derviçian', 'Dervician', 'Dervican,Dervicani,Dervician,Derviciani,Dervisciani,Derviçan,Derviçani,Derviçian', 40.0325000, 20.1733300, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(505, 'Derjan', 'Derjan', 'Derjan,Derjani', 41.6736100, 20.0583300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(506, 'Gjerbës', 'Gjerbes', 'David,Davidh,Davidhi,Devidhi,Gjerbes,Gjerbesi,Gjerbës,Gjerbësi', 40.6291700, 20.2511100, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(507, 'Çorovodë', 'Corovode', 'Cerevoda,Cerevode,Cerevodë,Chorovoda,Corovoda,Corovode,Gjavan,Zhaban,qiao luo wo da,Çorovoda,Çorovodë,Čorovodė,Чоровода,Չորովոդա,سوروودہ,乔罗沃达', 40.5041700, 20.2272200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(508, 'Çlirim', 'Clirim', 'Clirim,Clirimi,Shenmertir,Shënmërtir,Çlirim,Çlirimi', 40.4175000, 20.5502800, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(509, 'Cerava', 'Cerava', 'Cerav,Cerava,Cerave,Cerrava,Cerrave,Çëravë,Çërrava,Çërravë', 40.8513900, 20.7250000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(510, 'Çepan', 'Cepan', 'Cepan,Cepani,Çepan,Çepani', 40.4205600, 20.2605600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(511, 'Çarshovë', 'Carshove', 'Carcova,Carcove,Carshova,Carshove,Çarshova,Çarshovë,Çarçova,Çarçovë', 40.1180600, 20.5408300, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(512, 'Kokaj', 'Kokaj', 'Caj,Caja,Caje,Cajhen,Kokaj,Matraxhi i Cajes,Matraxhi i Çajes,Çaja,Çajhen,Çajë', 41.8783300, 20.5047200, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(513, 'Buz', 'Buz', 'Busi,Buz,Buz i Madh,Buz i Math,Buze,Buzi,Buzi i Madh,Buzi i Math,Buzë', 40.4450000, 20.0047200, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(514, 'Bushtricë', 'Bushtrice', 'Bushtrice,Bushtricë,Bustrica', 41.8786100, 20.4219400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(515, 'Burrel', 'Burrel', 'Burel,Burela,Burele,Bureli,Burelis,Burelë,Burrel,Burrel'',Burrele,Burreli,Burrelë,bu lei li,bulel,bureru,bwrly,Бурел,Буррели,Буррель,بورلی,ブレル,布雷利,부렐', 41.6102800, 20.0088900, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(516, 'Bulqizë', 'Bulqize', 'Bul''kiza,Bulchica,Bulcica,Bulciza,Bulkiza,Bulkize,Bulkizė,Bulqiza,Bulqize,Bulqizë,Bulquize,Bulćiza,Bulčica,bu er qi cha,bulakiza,Булкиза,Булчица,Булькиза,Булькіза,بولچیزہ,ਬੁਲਕੀਜ਼,布爾奇察', 41.4916700, 20.2219400, 'AL', '2013-03-15', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(517, 'Bujan', 'Bujan', 'Bajani,Bujan,Bujani,Bunjaj,Bunjan', 42.3263900, 20.0763900, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(518, 'Bradashesh', 'Bradashesh', 'Bradashesh,Bradasheshi,Bradosheshi', 41.1050000, 20.0225000, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(519, 'Blinisht', 'Blinisht', 'Blinisht,Blinishti', 41.8613900, 20.0000000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(520, 'Blerim', 'Blerim', 'Blerim,Sakat,Sakat-Kullumbri,Sakati', 42.1605600, 20.1919400, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(521, 'Bilisht', 'Bilisht', 'Biclishta,Biglista,Biklishta,Biklista,Bilishha,Bilisht,Bilishta,Bilishte,Bilishti,Bilishtë,Bilista,Bilisthi,Bilistis,Bilišta,Bilištis,Billisht,Viglista,balshty,bi li shen te,bylysht,Βίγλιστα,Μπίγλιστα,Билишта,Билишти,Билища,بالشتی,بيليشت,بیلیشت,比利什特', 40.6275000, 20.9900000, 'AL', '2014-08-25', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(522, 'Bicaj', 'Bicaj', 'Bicaj,Bisagni,Bitsan', 41.9947200, 20.4125000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(523, 'Dardhas', 'Dardhas', 'Beragozhd,Beragozhda,Beragozhde,Beragozhdi,Beragozhdë,Bragozhati,Bragozhde,Bragozhdë,Bëragozhda,Dardhas,Dardhasi', 40.8458300, 20.6572200, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(524, 'Barmash', 'Barmash', 'Barmash,Barmashi', 40.2777800, 20.6183300, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(525, 'Ballaban', 'Ballaban', 'Balaban,Ballaban,Ballabani', 40.4166700, 20.1344400, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(526, 'Arrën', 'Arren', 'Arn,Arni,Arren,Arreni,Arrn,Arrni,Arrën,Arrëni', 41.9130600, 20.2883300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(527, 'Arras', 'Arras', 'Arras,Arrasi', 41.7358300, 20.3241700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(528, 'Fierzë', 'Fierze', 'Fierza,Fierze,Fierzë,Фиерза', 42.2647200, 20.0269400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(529, 'Bytyç', 'Bytyc', 'Bitici,Bitiči', 42.3100000, 20.2027800, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(530, 'Librazhd-Qendër', 'Librazhd-Qender', 'Hala,Librazhd Qendre,Librazhd Qëndre,Librazhd-Qender,Librazhd-Qendër', 41.1969400, 20.3355600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(531, 'Funarë', 'Funare', 'Funar,Funari', 41.1963900, 20.0597200, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(532, 'Moglicë', 'Moglice', 'Moglica,Moglice,Moglicë', 40.7180600, 20.4380600, 'AL', '2012-06-10', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(533, 'Bogovë', 'Bogove', 'Bogova,Bogove,Bogovë', 40.5711100, 20.1500000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(534, 'Piskovë', 'Piskove', 'Piskova,Piskove,Piskovë', 40.2791700, 20.2725000, 'AL', '2012-06-06', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(535, 'Lukovë', 'Lukove', 'Lucova,Lukova,Lukove,Lukovo,Lukovë', 39.9922200, 19.9138900, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(536, 'Zharrëz', 'Zharrez', 'Shareza,Sharreza,Zarez,Zhareza,Zhareze,Zharres,Zharresa,Zharresi,Zharrez,Zharreza,Zharrës,Zharrësa,Zharrësi,Zharrëz,Zharrëza,Zharëzë,Žarez', 40.7091700, 19.6497200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(537, 'Zejmen', 'Zejmen', 'Zejmani,Zejmen,Zejmeni,Zojmen,Zojmendi', 41.7077800, 19.6891700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(538, 'Zall-Herr', 'Zall-Herr', 'Zall i Herrit,Zall-Herr,Zall-Herri,Zalle-Herraj,Zallherraj,Zalli i Herit,Zallë-Herraj', 41.3894400, 19.8275000, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(539, 'Zall-Bastar', 'Zall-Bastar', 'Zall-Bastar,Zall-Bastari', 41.4297200, 19.9302800, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(540, 'Xhafzotaj', 'Xhafzotaj', 'Dzevzotaj,Xhafe Zotaj,Xhaftozaj,Xhafzotaj,Xhafë Zotaj,Xhavzotaj,Xherezotaj,Xherëzotaj', 41.3444400, 19.5475000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(541, 'Vukatanë', 'Vukatane', 'Vukatan,Vukatana,Vukatane,Vukatanë', 42.0280600, 19.5477800, 'AL', '2013-02-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(542, 'Vranisht', 'Vranisht', 'Vranisht,Vranishta,Vranishte,Vranishti,Vranishtë', 40.2097200, 19.6908300, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(543, 'Vorë', 'Vore', 'Vora,Vore,Vorra,Vorre,Vorrë,Vorë,Вора', 41.3908300, 19.6550000, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(544, 'Vlorë', 'Vlore', 'Au''lon,Au’lon,Avlon,Avlona,Avlonas,Avlonya,Vallona,Valona,Vl''ora,Vliore,Vliorė,Vljora,Vlona,Vlone,Vlonë,Vlora,Vlore,Vlorë,Vlyora,Vļora,Wlora,beulloleo,fa luo la,flwrh,vurora,wlo rex,wlwrh,Αυλώνας,Валона,Вльора,Влёра,Վլորա,ולורה,فلوره,ولوره,ولورہ,วโลเรอ,ヴロラ,发罗拉,블로러', 40.4666700, 19.4897200, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(545, 'Velipojë', 'Velipoje', 'Qerret,Velipoja,Velipoje,Velipojë,Velipolja', 41.8783300, 19.4055600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(546, 'Velabisht', 'Velabisht', 'Velabisht,Velabishti', 40.7016700, 19.9322200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(547, 'Vaqarr', 'Vaqarr', 'Vagari,Vaqar,Vaqari,Vaqarr,Vaqarri,Vasqarr', 41.2991700, 19.7441700, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(548, 'Ura Vajgurore', 'Ura Vajgurore', 'Ur''e Hasan Beut,Ura Asan Beut,Ura Vajgurore,Ura e Hasan Beut,Ura-Khasan-Beut,Ura-Vaygurore,Ure-Vajgurore,Urë-Vajgurore,Ur’e Hasan Beut,Yefira Hassan Beut', 40.7688900, 19.8777800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(549, 'Ungrej', 'Ungrej', 'Ungrei,Ungrej,Ungreji', 41.8752800, 19.7947200, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(550, 'Ulëz', 'Ulez', 'Ulez,Uleza,Ulza,Ulze,Ulzë,Ulëz,Ulëza', 41.6827800, 19.8933300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(551, 'Topojë', 'Topoje', 'Topoja,Topoje,Topojë', 40.7630600, 19.4327800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(552, 'Tirana', 'Tirana', 'Gorad Tyrana,TIA,Terana,Theranda,Tiorana,Tiorána,Tiran,Tiran khot,Tiran-a,Tirana,Tiranae,Tirane,Tirano,Tiranë,Tirāna,Tyranna,Tírana,Tîrana,Tėrana,de la na,tilana,tirana,tyrana,tyrnh,Τίρανα,Горад Тырана,Тиран хот,Тиранæ,Тирана,Тиране,Տիրանա,טיראנא,טירנה,تىرانا,تيرانا,تیرانا,तिराना,তিরানা,ਤਿਰਾਨਾ,ଟିରାନା,டிரானா,ടിറാന,ติรานา,ཐིས་རན།,ტირანა,ቲራና,ティラナ,地拉那,티라나', 41.3275000, 19.8188900, 'AL', '2014-09-17', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(553, 'Thumanë', 'Thumane', 'Thumana,Thumane,Thumani,Thumanë,Tuman', 41.5475000, 19.6777800, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(554, 'Tërbuf', 'Terbuf', 'Terbuf,Terbufi,Tërbuf,Tërbufi', 41.0400000, 19.6141700, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(555, 'Synej', 'Synej', 'Sinej,Synej,Syneji', 41.1800000, 19.5425000, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(556, 'Sukth', 'Sukth', 'Sucsi,Sukf,Sukth,Sukth i Vjeter,Sukth i Vjetër,Sukthi', 41.3805600, 19.5377800, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(557, 'Strum', 'Strum', 'Ciflik-Struma,Strubi,Strum,Strume,Strumi,Strumë,Çiflik-Struma', 40.7511100, 19.7375000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(558, 'Sinjë', 'Sinje', 'Signa,Sinja,Sinje,Sinjë', 40.6480600, 19.8680600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(559, 'Sinaballaj', 'Sinaballaj', 'Sinaballaj,Sinaballej,Sinabella,Sinanaj,Sinebala,Sineballa', 41.0688900, 19.6994400, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(560, 'Shkodër', 'Shkoder', 'Iskodra,Scutari,Shkoder,Shkodra,Shkodër,Skadar,Skodra,Szkodra,sqwdr,İşkodra,Škodra,Скадар,Шкодер,Шкодра,שקודר', 42.0682800, 19.5125800, 'AL', '2013-01-03', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(561, 'Shijak', 'Shijak', 'Bazar Sciak,San Giacomo,Shejak,Shejaku,Shijak,Shijaku,Shjak,Shyaku,Shëjaku,Sijak,Sijaku,Sjak,shyjakw,xi ya ke,Šijak,Šijaku,Šjak,Шияк,Шияку,Шијак,شیجاکو,希亞克', 41.3455600, 19.5672200, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(562, 'Shezë', 'Sheze', 'Seza,Sheza,Sheze,Sheze e Madhe,Shezë,Shezë e Madhe,Ujeza', 41.0241700, 19.8161100, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(563, 'Shënkoll', 'Shenkoll', 'Shenkoll,Shenkolle,Shenkolli,Shinkolli,Shënkoll,Shënkolli,Shënkollë,Snkoli', 41.6908300, 19.6533300, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(564, 'Shëngjin', 'Shengjin', 'Komuna e Shengjinit,Komuna e Shëngjinit,Saint Giovanni di Medua,San Giovanni di Medua,San Njin,Sen Dovani di Medua,Sengin,Sh''njini,Shen Ghen,Shengin,Shengjin,Shengjini,Shëngjin,Shëngjini,Sh’njini,Sveti Jovan,Sveti Jovan Medovski,sheng jin,Šen Ðovani di Medua,Šenđin,Свети Јован,Шенгин,Шенѓин,聖金', 41.8136100, 19.5938900, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(565, 'Shëngjergj', 'Shengjergj', 'Senderd,Shengjergi,Shengjergji,Shingjergj,Shingjergji,Shëngjergji,Šenđerđ', 41.1833300, 19.5333300, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(566, 'Shalës', 'Shales', 'Scials,Shales,Shalesi,Shalës,Shalësi', 40.9986100, 19.9477800, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(567, 'Nicaj-Shalë', 'Nicaj-Shale', 'Nicaj,Nicaj-Shalaj,Nicaj-Shale,Nicaj-Shalë,Shale,Shalë', 42.2994400, 19.8050000, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(568, 'Sevaster', 'Sevaster', 'Kudhes,Kudhës,Sevaster,Sevaster Cuds,Sevaster-Kudhes,Sevasteri,Stevaster,Stevaster Kudhes,Stevaster Kuls,Sëvastër-Kudhës', 40.3963900, 19.7297200, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(569, 'Selitë', 'Selite', 'Selit e Kece,Selit e Keće,Selita,Selite,Selite e Keqe,Selite-Delbinishtaj,Selitë,Selitë e Keqe', 41.6352800, 19.7550000, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(570, 'Valbonë', 'Valbone', 'Selimaj,Valbona,Valbone,Valbonë', 42.4513900, 19.8916700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(571, 'Selenicë', 'Selenice', 'Selenic,Selenica,Selenice,Selenicë,Selenitsa,Selenitza,Seleniza,Selenizza,Селеница', 40.5305600, 19.6358300, 'AL', '2014-08-25', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(572, 'Ruzhdie', 'Ruzhdie', 'Piekaj,Rozhdia,Rushdie,Rushdije,Rushdijë,Ruzhdie,Ruzhdija,Ruzhdije,Ruzhdijë', 40.6708300, 19.6983300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(573, 'Rubik', 'Rubik', 'Rrubig,Rrubigu,Rrumbiku,Rubig,Rubik,Rubiku,Рубик', 41.7744400, 19.7861100, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(574, 'Rrogozhinë', 'Rrogozhine', 'Rogozhina,Rogozhine,Rogozhinë,Rogozin,Rogozina,Rogozine,Rogožin,Rogožinė,Rrogozesa,Rrogozhina,Rrogozhine,Rrogozhinë,Rrogozësa,Rrogzhine,luo ge ri nei,Рогожина,羅戈日內', 41.0763900, 19.6652800, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(575, 'Rrëshen', 'Rreshen', 'Resenis,Reshen,Resheni,Rešenis,Rreshen,Rresheni,Rrshen,Rrsheni,Rrëshen,Rrësheni,Rshen,Rsheni,Rushen,Rëshen,Rëshëni,lei shen,ryshny,Решен,Ръшен,ریشنی,勒申', 41.7675000, 19.8755600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(576, 'Rrashbull', 'Rrashbull', 'Rashbulle,Rezbul,Režbul,Rrashbull,Rrashbulle,Rrashbulli,Rrashbulli Arapaj,Rrashbullë', 41.3227800, 19.5102800, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(577, 'Rrasa e Sipërme', 'Rrasa e Siperme', 'Rasa e Siperme,Rasa e Sipërme,Rrasa e Siperme,Rrasa e Sipërme,Rrase e Siperme,Rrasë e Sipërme', 40.9677800, 19.8211100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(578, 'Rrapë', 'Rrape', 'Rapje,Rrapa,Rrapaj,Rrape,Rrapja,Rrapë,Rrype,Rrypë', 42.0444400, 19.9705600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(579, 'Roskovec', 'Roskovec', 'Roscovec,Roskovec,Roskoveci,Rroskoveci,Treg i Frasherit,Tregu-Frasherit,Росковец', 40.7375000, 19.7022200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(580, 'Remas', 'Remas', 'Remas,Remas Pervas,Remasi,Rremas,Rremasi', 40.8863900, 19.5113900, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(581, 'Qerret', 'Qerret', 'Cereti-eper,Qereti i Eperme,Qereti i Epërmë,Qerret,Qerret i Eper,Qerret i Eperm,Qerret i Epër,Qerret i Epërm,Qerret i Madh,Qerret-ieperme,Qerreti,Qerreti i Eperme,Qerreti i Epërmë,Qerreti i Madh,Qerreti i-eper,Qerreti i-epër,Čereti-eper', 42.0530600, 19.8372200, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(582, 'Qelëz', 'Qelez', 'Lellza,Qelez,Qeleza,Qellza,Qellze,Qellzë,Qelza,Qelze,Qelzë,Qelëz,Qelëza', 42.0897200, 19.8950000, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(583, 'Pukë', 'Puke', 'Puca,Puka,Puka Katund,Puke,Pukë,Pukė,pu ke,pwkh,Пука,پوکه,پوکہ,普克', 42.0444400, 19.8997200, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(584, 'Progonat', 'Progonat', 'Progonat,Progonati', 40.2133300, 19.9447200, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(585, 'Prezë', 'Preze', 'Preza,Preze,Prezë', 41.4272200, 19.6727800, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(586, 'Poshnje', 'Poshnje', 'Poshnja,Poshnje', 40.7802800, 19.8441700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(587, 'Portëz', 'Portez', 'Portez,Porteza,Porteze,Portëz,Portëza,Portëzë', 40.6991700, 19.5744400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(588, 'Peza e Madhe', 'Peza e Madhe', 'Hodzaj,Hodžaj,Hoxhaj,Peza e Madhe,Peze,Peze e Madhe,Pezë,Pezë e Madhe', 41.2175000, 19.6961100, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(589, 'Petrelë', 'Petrele', 'Petrela,Petrele,Petrelë', 41.2530600, 19.8530600, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(590, 'Përparim', 'Perparim', 'Perparim,Perparimi,Përparim', 41.0500000, 19.7991700, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(591, 'Perondi', 'Perondi', 'Perhond,Perhondi,Perhondia,Perhondija,Perondi,Perondia,Perondija', 40.7788900, 19.9230600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(592, 'Peqin', 'Peqin', 'Pecin,Pekin,Pekini,Pekinis,Pekinj,Peqin,Peqini,Peqinj,Pequini,pchyn,pechin,pei jin,Пекин,Пеќин,پچین,ペチン,佩今,페친', 41.0461100, 19.7511100, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(593, 'Patos Fshat', 'Patos Fshat', 'Patos Fshat,Patosi Fshat', 40.6427800, 19.6508300, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(594, 'Patos', 'Patos', 'Pahtosa,Pahtosi,Patos,Patosi,Patosis,pa tu si,Патос,帕圖斯', 40.6833300, 19.6194400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(595, 'Paskuqan', 'Paskuqan', 'Kuqan,Kuqon,Packuqan,Packuqani,Paskuqan,Paskuqani,Patza,Patza Kucane,Patza Kućane,Patza-Kuqane,Patza-Kuqani', 41.3538900, 19.8066700, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(596, 'Papër', 'Paper', 'Kulej-Paper,Kulej-Paperi,Kulej-Papër,Kulej-Papëri,Kull'' e Paprit,Kulla Paprit,Kull’ e Paprit,Paper,Paperi,Papri,Papër,Papëri', 41.0516700, 19.9608300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(597, 'Pajovë', 'Pajove', 'Pajova,Pajove,Pajovë,Perpajsi', 41.0547200, 19.8375000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(598, 'Otllak', 'Otllak', 'Otllak,Otllaku', 40.7438900, 19.9352800, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(599, 'Orikum', 'Orikum', 'Orik,Oriku,Orikum,Orikumi,Орикум', 40.3252800, 19.4713900, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(600, 'Novoselë', 'Novosele', 'Novosel,Novosela,Novosele,Novoselj,Novosella,Novoselë', 40.6250000, 19.4669400, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(601, 'Nikël', 'Nikel', 'Menga,Menikll,Meniklli,Monikelj,Monikle,Moniklë,Mënikll,Mëniklli,Nikel,Nikla,Niklla,Niklle,Nikllë,Nikël', 41.4441700, 19.7483300, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(602, 'Nicaj-Shosh', 'Nicaj-Shosh', 'Nicaj-Shosh,Nikaj', 42.2444400, 19.7580600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(603, 'Ngraçan', 'Ngracan', 'Gracan,Graqani,Graçan,Ngracan,Ngracani,Ngraçan,Ngraçani', 40.6444400, 19.7925000, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(604, 'Ndroq', 'Ndroq', 'Ndrogi,Ndroki,Ndroq,Ndroqi,Ndroqi Pazari', 41.2638900, 19.6558300, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(605, 'Milot', 'Milot', 'Milet,Miljoti,Milot,Miloti,Милет', 41.6838900, 19.7155600, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(606, 'Memaliaj', 'Memaliaj', 'Mamaliaga,Mamaliaj,Memaliaj,Memalianji,Мемалиай', 40.3516700, 19.9802800, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(607, 'Mbrostar-Urë', 'Mbrostar-Ure', 'Brostar,Brostar Ferko,Brostari-Ferkaj,Brustar Fioko,Mbrostar,Mbrostar Ferko,Mbrostar-Ure,Mbrostar-Urë,Mbrostari,Mbrotja e Siperme,Mbrotja e Sipërme', 40.7536100, 19.5794400, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(608, 'Manzë', 'Manze', 'Manes,Manesi,Manez,Maneza,Maneze,Mansmins,Mansmyns,Manxit,Manza,Manze,Manzë,Manës,Manësi,Manëz,Manëza,Manëzë', 41.4286100, 19.5930600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(609, 'Mamurras', 'Mamurras', 'Mamuras,Mamurasi,Mamuraz,Mamurras,Mamurrasi,Murrizaj,Мамуррас', 41.5775000, 19.6922200, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(610, 'Maminas', 'Maminas', 'Maminas,Maminasi,Meminas,Meminasi,Meminosi,Veminasi', 41.3791700, 19.6075000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(611, 'Luzi i Vogël', 'Luzi i Vogel', 'Ljuz i vogel,Luz i Vogel,Luz i Vogël,Luzi i Vogel,Luzi i Vogël', 41.1275000, 19.5738900, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(612, 'Lushnjë', 'Lushnje', 'Liusne,Liušnė,Ljushna Cod a Gomares,Ljushnja,Ljusnje,Ljušnje,Lousnia,Lushne,Lushnja,Lushnje,Lushnjë,Lusnje,Lušnje,lu shen nie,lusyunyeo,lwshnyh,rushunya,Лушње,Люшня,لوشنيه,لوشنیہ,ルシュニャ,卢什涅,루슈녀', 40.9419400, 19.7050000, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(613, 'Luftinjë', 'Luftinje', 'Luftinia,Luftinja,Luftinje,Luftinjë', 40.4427800, 19.9544400, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(614, 'Libofshë', 'Libofshe', 'Libofsha,Libofshe,Libofshë,Libovfs,Libovfš,Libovshe,Libovshë,Resh Libovtsa,Tregishte', 40.8344400, 19.5522200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(615, 'Lezhë', 'Lezhe', 'Alessio,Les,Lesh,Leshe,Leshi,Leze,Lezh,Lezha,Lezhe,Lezhë,Leş,Ležė,Lisi,Ljes,Ljesh,Lješ,Lyesh,lai shen,lejeo,lezha,lzhh,Љеш,Леж,Лежа,لژه,لژہ,ლეჟა,莱什,레저', 41.7836100, 19.6436100, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(616, 'Levan', 'Levan', 'Levan,Levan-Samaraj,Levan-Samari,Levani,Levani Samar,Levani Samares,Levani Samarit,Levani Samarës,Levani i Madh', 40.6761100, 19.4897200, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(617, 'Lekbibaj', 'Lekbibaj', 'Lekbibaj', 42.2947200, 19.9316700, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(618, 'Lekaj', 'Lekaj', 'Lekaj,Ljekaj', 41.1144400, 19.6097200, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(619, 'Laç', 'Lac', 'Lac,Lach,Lachi,Laci,Lak,Latsch,Laç,Laçi,Liacis,Liačis,Ljach,la qi,lasy,Лак,Лач,Лачі,Ляч,لاسی,拉奇', 41.6355600, 19.7130600, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(620, 'Kutë', 'Kute', 'Cuta,Kuta,Kute,Kutë', 40.4733300, 19.7663900, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(621, 'Kutalli', 'Kutalli', 'Kutaj,Kutali,Kutalli,Kutallia,Kutallija', 40.7838900, 19.7866700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(622, 'Kurjan', 'Kurjan', 'Kurian,Kuriani,Kurjan,Kurjani,Kurjanj', 40.7175000, 19.7455600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(623, 'Kuman', 'Kuman', 'Cumani,Kuman,Kumani', 40.7266700, 19.6866700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(624, 'Kuçovë', 'Kucove', 'Kuchova,Kucova,Kucove,Kuçova,Kuçovë,Petrolia,Qyteti Stalin,Stalin,Кучова', 40.8002800, 19.9166700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(625, 'Kuç', 'Kuc', 'Kuc,Kuci,Kuç,Kuçi', 42.0397200, 19.5252800, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(626, 'Kryevidh', 'Kryevidh', 'Krievil,Kruevith,Kryevidh,Kryevidhe,Kryevidhi,Kryevidhë', 41.1005600, 19.5275000, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(627, 'Krutja e Poshtme', 'Krutja e Poshtme', 'Kruati i Poshtem,Kruati i Poshtëm,Kruatje e Poshteme,Kruatje e Poshtme,Kruatje e Poshtëme,Krutja e Poshteme,Krutja e Poshtme,Krutja e Poshtëme,Krutje e Poshtme,Krutje e Posteme,Krutje e Postëme,Post Kruati', 40.8719400, 19.6808300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(628, 'Krujë', 'Kruje', 'Akcehisar,Akçehisar,Croia,Cruja,Krna,Kroia,Kroja,Kroya,Kroïa,Krue,Krueja,Kruja,Kruje,Krujë,Круе', 41.5091700, 19.7927800, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(629, 'Krrabë', 'Krrabe', 'Kerraba,Kerrabe,Kraba e Vogel,Kraba e Vogël,Krraba,Krraba Vogel,Krraba e Vogel,Krraba e Vogël,Krrabe,Krrabe e Vog,Krrabë,Kërraba,Kërrabë', 41.2155600, 19.9713900, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(630, 'Krahës', 'Krahes', 'Krahes,Krahes Numer Nje,Krahesi,Krahesi Numer Nje,Krahës,Krahës Numër Një,Krahësi,Krahësi Numër Një', 40.4386100, 19.8444400, 'AL', '2012-06-07', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(631, 'Kozarë', 'Kozare', 'Kozara,Kozare,Kozarja,Kozarë', 40.8308300, 19.9005600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(632, 'Kotë', 'Kote', 'Kota,Kote,Kotta,Kotë', 40.3894400, 19.6022200, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(633, 'Koplik', 'Koplik', 'Koplik,Koplik Poster,Koplik Pošter,Koplik i Poshtem,Koplik i Poshtëm,Kopliku,Kopliku i Poshtem,Kopliku i Poshtëm,Kopliku-e Poshtem,Kopliku-e Poshtëm,ke pu li ku,kwplykw,Коплик,کوپلیکو,科普利庫', 42.2136100, 19.4363900, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(634, 'Kombësi', 'Kombesi', 'Kombesi,Kombesia,Kombesit,Kombësi,Kombësia,Komesi,Komesia,Komsi,Komësi,Komësia', 41.5816700, 19.9855600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(635, 'Kolonjë', 'Kolonje', 'Colonia,Koljonja,Kolonj,Kolonja,Kolonje,Kolonjë,Колёня', 40.8241700, 19.6038900, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(636, 'Kolç', 'Kolc', 'Kolc,Kolc-Logorec,Kolc-Logoreci,Kolci,Koljs,Kolsh,Kolç,Kolç-Logorec,Kolç-Logoreci,Kolçi,Logoreci', 41.7866700, 19.6761100, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(637, 'Kavajë', 'Kavaje', 'Cavaia,Cavaja,Kavaia,Kavaj,Kavaja,Kavaje,Kavajë,Kavajė,Kavalye,Kavaya,Kavaïa,Kawaja,ka wa ya,kabayeo,kawayh,Кавайе,Кавая,Каваја,کاوایه,کاوایہ,卡瓦亚,카바여', 41.1855600, 19.5569400, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(638, 'Katundi i Ri', 'Katundi i Ri', 'Katund i Ri,Katundi,Katundi i Ri', 41.4030600, 19.5180600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(639, 'Kastrat', 'Kastrat', 'Kastrat,Kastrati,Vukpalaj,Vukpalaj-Kastrat', 42.3525000, 19.4891700, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(640, 'Kashar', 'Kashar', 'Kashar,Kashari', 41.3497200, 19.7102800, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(641, 'Karinë', 'Karine', 'Karina,Karina Kosenj,Karine,Karinë', 41.0630600, 19.7161100, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(642, 'Karbunara e Vogël', 'Karbunara e Vogel', 'Karbunara e Poshteme,Karbunara e Poshtme,Karbunara e Poshtëme,Karbunara e Vogel,Karbunara e Vogël,Karbunare e Poshteme,Karbunare e Poshtme,Karbunare e Vogel,Karbunarë e Poshtme,Karbunarë e Poshtëme,Karbunarë e Vogël', 40.9219400, 19.7177800, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(643, 'Kamëz', 'Kamez', 'Camza,Kambeza,Kambëza,Kamez,Kamza,Kamze,Kamzë,Kamzė,Kamëz,ka mu zha,kamza,Камза,کامزا,卡姆扎', 41.3816700, 19.7602800, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(644, 'Kallmeti i Madh', 'Kallmeti i Madh', 'Calmeti,Kallheti i Math,Kallmet,Kallmet i Madh,Kallmet i Math,Kallmeti,Kallmeti i Madh,Kallmeti i Math,Kalmet', 41.8488900, 19.6869400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(645, 'Kallmet', 'Kallmet', 'Kaljmet,Kallmet,Kallmeti,Kalmeti', 41.4180600, 19.8213900, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(646, 'Kalenjë', 'Kalenje', 'Kahlenja,Kalenj,Kalenja,Kalenje,Kalenjë', 40.5900000, 19.7783300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(647, 'Kajan', 'Kajan', 'Kajan,Kajani,Shkembi,Shkëmbi', 40.9141700, 19.8894400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(648, 'Kaçinar', 'Kacinar', 'Kacinar,Kacinari,Kaçinar,Kisha e-Simonit', 41.8933300, 19.8986100, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(649, 'Ishëm', 'Ishem', 'Ishem,Ishm,Ishmi,Ishëm', 41.5452800, 19.6000000, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(650, 'Hysgjokaj', 'Hysgjokaj', 'Dzokaj,Džokaj,Hysaj,Hysgjokaj,Xhokaj', 40.9716700, 19.7897200, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(651, 'Hot', 'Hot', 'Hot,Hoti', 42.3619400, 19.4441700, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(652, 'Himarë', 'Himare', 'Chimara,Cimarre,Himara,Himare,Himarë,Imara,Kheimara,Khimara,Химара', 40.1016700, 19.7447200, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(653, 'Helmas', 'Helmas', 'Elmasi,Heljmas,Helmas,Helmasi,Helmes,Helmesi,Helmës,Helmësi', 41.1802800, 19.6069400, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(654, 'Hekal', 'Hekal', 'Hecali,Hekal,Hekali,Hekalj', 40.5619400, 19.7358300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(655, 'Hasan', 'Hasan', 'Hasan,Hasanaj,Hasani', 41.4827800, 19.6997200, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(656, 'Hajmel', 'Hajmel', 'Ajmeli,Guragi,Hajmel,Hajmeli,Hajmelj', 41.9530600, 19.6377800, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(657, 'Gurra e Vogël', 'Gurra e Vogel', 'Gura Vogel,Gura Vogël,Gurr'' e Vogel,Gurra Vogel,Gurra e Vogel,Gurra e Vogël,Gurre e Vogel,Gurrë e Vogël,Gurr’ e Vogel', 41.5361100, 19.9908300, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(658, 'Guri i Zi', 'Guri i Zi', 'Gur i Zi,Guri i Zi', 42.0450000, 19.5747200, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(659, 'Gruemirë', 'Gruemire', 'Gruemira,Gruemire,Gruemirë', 42.1591700, 19.5188900, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(660, 'Greshicë', 'Greshice', 'Greshica,Greshice,Greshicë,Gresic,Grešic', 40.5519400, 19.7783300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(661, 'Grekan', 'Grekan', 'Grekan,Grekani', 40.9294400, 19.9475000, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(662, 'Gradishtë', 'Gradishte', 'Gradisht,Gradishta,Gradishte,Gradishti,Gradishtë,Gradista,Gradiza,Gradišta,Qyteze,Qytezë', 40.8880600, 19.5858300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(663, 'Gracen', 'Gracen', 'Gracen,Graceni,Grrecen,Grreceni', 41.1519400, 19.9636100, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(664, 'Grabjan', 'Grabjan', 'Grabian,Grabiani,Grabijan,Grabijani,Grabjan,Grabjani,Grobia,Grunasi', 40.9530600, 19.5808300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(665, 'Gosë e Madhe', 'Gose e Madhe', 'Gosa e Madhe', 41.0905600, 19.6247200, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(666, 'Golem', 'Golem', 'Cela i Madh,Golem,Golem i Madh,Golem i Math,Golemi,Golemi i Madh,Çela i Madh', 40.9677800, 19.6852800, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(667, 'Gjoçaj', 'Gjocaj', 'Djocaj,Gjocaj,Gjocej,Gjoçaj,Ðjocaj', 41.0255600, 19.7238900, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(668, 'Gjepalaj', 'Gjepalaj', 'Depale,Gjepalaj,Gjepale,Gjepalie,Gjopalaj,Ðepale', 41.3330600, 19.5780600, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(669, 'Fushëkuqe', 'Fushekuqe', 'Fush-Kuqe,Fusha e Kuge,Fusha e Kuqe,Fushe-Kuqja,Fushekuqe,Fushekuqeja,Fushë-Kuqja,Fushëkuqe,Fushëkuqeja', 41.6502800, 19.6200000, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(670, 'Fushë-Krujë', 'Fushe-Kruje', 'Fus e Krujs,Fush'' e Krujes,Fush-Kruja,Fusha-Kruja,Fushe Kruja,Fushe e Krujes,Fushe-Kruje,Fushë Kruja,Fushë e Krujës,Fushë-Krujë,Fush’ e Krujës,Fuš e Krujs,Teke Fuscia Crujs,Фуша-Круя', 41.4783300, 19.7177800, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(671, 'Fratar', 'Fratar', 'Fratari', 40.5000000, 19.8166700, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(672, 'Frakulla e Madhe', 'Frakulla e Madhe', 'Frakula,Frakula e Pasajit,Frakula e Pašajit,Frakull e Madhe,Frakull'' e Pashajt,Frakulla e Madhe,Frakulla e Pashajit,Frakulle,Frakulle e Madhe,Frakulle e Pashajt,Frakullë,Frakullë e Madhe,Frakullë e Pashajt,Frakull’ e Pashajt,Frankulle Pashajt', 40.6558300, 19.5025000, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(673, 'Fier-Shegan', 'Fier-Shegan', 'Fier Shegeni,Fier-Shegan,Fier-Shegani,Fieri Shegani', 40.8672200, 19.7852800, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(674, 'Fier-Çifçi', 'Fier-Cifci', '', 40.7166700, 19.5666700, 'AL', '2007-05-30', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(675, 'Fier', 'Fier', 'Fearica,Fier,Fieri,Fieris,Fijer,Fjer,Fjeri,a pha''ira,fei xia er,fieru,fyr,pieleu,Фиер,Фиери,Фієрі,Фјер,فیر,अ फाइर,フィエル,非夏爾,피에르', 40.7238900, 19.5561100, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(676, 'Farka e Madhe', 'Farka e Madhe', 'Farka,Farka e Madhe,Farke,Farke e Madhe,Farkë,Farkë e Madhe', 41.3055600, 19.8669400, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(677, 'Durrës', 'Durres', 'Drac,Drach,Drač,Duraso,Durazo,Durazzo,Durazzu,Dures,Duresi,Duresis,Durrazo,Durres,Durresa,Durresi,Durrsi,Durrës,Durrësi,Durts,Durus,Durz,Durësi,Dyrrachio,Dyrrachium,Dyrrakhion,Dyrrhachium,Epidamnos,Gorad Durehs,dou la si,do~urasu,draj,dras,duleoseu,duresi,durres,dwrs,Δυρράχιο,Горад Дурэс,Драч,Дуррес,Дуръс,דורס,دراج,دراس,ดูร์เรส,დურესი,ドゥラス,都拉斯,두러스', 41.3230600, 19.4413900, 'AL', '2012-01-19', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(678, 'Drenovë', 'Drenove', 'Drenova,Drenove,Drenovë,Drnova', 40.6005600, 19.7008300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(679, 'Divjakë', 'Divjake', 'Diviaka,Divjaca,Divjak,Divjaka,Divjake,Divjakë,Duvijaka,Pisha', 40.9966700, 19.5294400, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(680, 'Dërmënas', 'Dermenas', 'Dermena,Dermenas,Dermenasi,Dermënasi,Drmanas,Dërmënas', 40.7455600, 19.4938900, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(681, 'Vau i Dejës', 'Vau i Dejes', 'Danski Brod,Dejas,Vai Dejes,Vai Dejës,Vau Dejes,Vau Dejës,Vau i Dejes,Vau i Dejës,Vau-Deja,Vau-Dejas,Vau-Dejes,Vau-Dejs,Vau-Dejës,wayw djs,Вау-Деяс,Дањски Брод,وائو دجس', 42.0100000, 19.6247200, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(682, 'Dajt', 'Dajt', 'Dajt,Dajti,Njesia administrative Dajt,Njësia administrative Dajt', 41.3936100, 19.9158300, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(683, 'Dajç', 'Dajc', 'Dajc,Dajci,Dajç,Dajçi', 41.9916700, 19.4105600, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(684, 'Dajç', 'Dajc', 'Dajc,Dajci,Dajç', 41.9155600, 19.6044400, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(685, 'Cukalat', 'Cukalat', 'Cukakat,Cukala,Cukalat,Cukalati,Cukaljat,Cukelat,Cukelati', 40.7302800, 19.7905600, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(686, 'Cudhi Zall', 'Cudhi Zall', 'Cedhin,Cedhini,Cudhi Zall,Cudhija,Cudhin,Cudhini,Cudhuni,Cuvija,Çedhini', 41.5094400, 19.8458300, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(687, 'Cërrik', 'Cerrik', 'Cerik,Cerrik,Cerriku,Curik,Cërrik,Cërriku,Valasi,ce li ke,srykw,Церик,Церрик,Церрік,Църик,سریکو,策里克', 41.0316700, 19.9758300, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(688, 'Cakran', 'Cakran', 'Cakran,Cakrani,Cakrrani,Zakran', 40.6033300, 19.6261100, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(689, 'Bushat', 'Bushat', 'Busciala,Bushat,Bushati', 42.1194400, 19.8997200, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(690, 'Bubullimë', 'Bubullime', 'Bubullima,Bubullime,Bubullimë,Bubulmani,Buhullime,Buhullimë,Bumlulim', 40.8180600, 19.6408300, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(691, 'Bubq', 'Bubq', 'Bubc,Bubesi,Bubge,Bubgë,Bubq,Bubqe,Bubqi,Bubqë,Bubsi,Bubësi,Bubć', 41.4741700, 19.6516700, 'AL', '2012-06-01', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(692, 'Brataj', 'Brataj', 'Brataj,Bratraj', 40.2677800, 19.6691700, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(693, 'Bërzhitë', 'Berzhite', 'Berzhita,Berzhite,Bregishte,Bregjshte,Bërzhitë', 41.2452800, 19.9011100, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(694, 'Bërxull', 'Berxull', 'Berxull,Berxulla,Berxulle,Berxulli,Berzulla,Berzulle,Brzula,Bërxull,Bërxulli,Bërxullë,Bërzullë', 41.3800000, 19.6875000, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(695, 'Bërdica e Madhe', 'Berdica e Madhe', 'Berdica e Madhe,Berdice,Berdice e Madhe,Bërdica e Madhe,Bërdicë,Bërdicë e Madhe', 42.0152800, 19.4816700, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(696, 'Berat', 'Berat', 'Belgrad,Beligrad,Berat,Berati,Beration,Beratis,Berta,Bərat,Lezskigrad,Verati,Veration,belateu,berato,brat,byrat,pei la te,Μπεράτ,Белград,Берат,Բերատ,בראט,برات,بیرات,ბერატი,ベラト,培拉特,베라트', 40.7058300, 19.9522200, 'AL', '2012-06-03', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(697, 'Belsh', 'Belsh', 'Belesh,Beleshi,Beleshit,Belsh,Belshi,Belësh,Belëshi,Belëshit', 40.9750000, 19.8819400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(698, 'Baz', 'Baz', 'Baz,Baza,Baze,Bazi,Bazja,Bazje,Bazjë,Bazë', 41.6319400, 19.9291700, 'AL', '2012-06-02', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(699, 'Banaj', 'Banaj', 'Banaj,Banani,Bananj,Beran', 40.8247200, 19.8391700, 'AL', '2013-05-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(700, 'Ballsh', 'Ballsh', 'Bal''shi,Baleri,Ballesh,Balleshi,Ballsh,Ballsha,Ballshi,Ballësh,Ballëshi,Bals,Balsh,Balshi,Balsis,Balš,Balšis,ba er shen,balshy,Балш,Балши,Бальши,بالشی,巴爾什', 40.5988900, 19.7347200, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(701, 'Ballagat', 'Ballagat', 'Balagati,Ballagat,Ballagati,Ballajgati', 40.9952800, 19.7652800, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(702, 'Baldushk', 'Baldushk', 'Baldushk,Baldushke,Baldushku,Baldushkë,Baldushuku,Balije,Balja,Balldushk,Balldushku,Bulldushku', 41.2138900, 19.7969400, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(703, 'Armen', 'Armen', 'Armen,Armeni', 40.5363900, 19.5961100, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(704, 'Aranitas', 'Aranitas', 'Aranitas,Aranitasi,Aranitesi,Aranitësi,Arositani', 40.5944400, 19.8066700, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(705, 'Allkaj', 'Allkaj', 'Alikaj,Allkaj,Hallkani,Rrethi', 40.8575000, 19.7552800, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(706, 'Golem', 'Golem', 'Golem,Golemasi,Mali Robit', 41.2458300, 19.5347200, 'AL', '2012-06-13', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(707, 'Balldreni i Ri', 'Balldreni i Ri', 'Balldran,Balldren i Ri,Balldreni,Balldreni i Ri', 41.8191700, 19.6402800, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(708, 'Grudë-Fushë', 'Grude-Fushe', 'Grude-Fusha,Grude-Fushe,Grudë-Fusha,Grudë-Fushë', 42.1622200, 19.4966700, 'AL', '2012-06-12', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(709, 'Fierzë', 'Fierze', 'Fierza,Fierze,Fierzë,Фиерза', 40.9205600, 19.8469400, 'AL', '2012-05-31', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(710, 'Dushk', 'Dushk', 'Dushk,Dushku', 40.7266700, 19.7572200, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(711, 'Selitë', 'Selite', 'Selita,Selite,Selitë', 40.5475000, 19.8480600, 'AL', '2012-06-05', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(712, 'Vllahinë', 'Vllahine', 'Vllahina,Vllahine,Vllahinë', 40.4569400, 19.6436100, 'AL', '2012-06-14', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(713, 'Bajram Curri', 'Bajram Curri', 'Bairam Curis,Bajram Curi,Bajram Curr,Bajram-Curri,ba yi la mu chu li cheng,bjram kwry,Байрам Цури,Байрам-Цурри,Бајрам Цури,Բայրամ Ցուրի,بجرام کوری,巴依拉姆楚里城', 42.3573400, 20.0767900, 'AL', '2012-06-11', 3);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(345, 'West End Village', 'West End Village', '', 18.1719100, -63.1494100, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(346, 'The Valley', 'The Valley', 'De Balei,El Valle,Gorad Vali,La-Valo,The Valley,Vali,Valis,Valley,Valli,bare,d wly,deobaelli,dy wyly,hwwʼly,ti velli,vali,wa li,Δε Βάλεϊ,Вали,Валли,Валлі,Горад Валі,הוואלי,د ولی,دی ویلی,தி வேல்லி,เดอะแวลลีย์,ვალი,バレー,瓦利,더밸리', 18.2170400, -63.0578300, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(347, 'The Quarter', 'The Quarter', 'The Quarter', 18.2079900, -63.0417800, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(348, 'Farrington', 'Farrington', 'The Farrington', 18.2150000, -63.0223800, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(349, 'Stoney Ground', 'Stoney Ground', 'Stoney Ground', 18.2202600, -63.0460700, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(350, 'South Hill Village', 'South Hill Village', '', 18.1920100, -63.0877900, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(351, 'Sandy Ground Village', 'Sandy Ground Village', 'Sandy Ground Village', 18.2011800, -63.0899800, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(352, 'North Side', 'North Side', 'North Side', 18.2291900, -63.0440100, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(353, 'North Hill Village', 'North Hill Village', '', 18.2054200, -63.0784700, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(354, 'Island Harbour', 'Island Harbour', '', 18.2560100, -63.0102000, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(355, 'George Hill', 'George Hill', 'George Hill', 18.1993900, -63.0665000, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(356, 'East End Village', 'East End Village', 'East End,East End Village', 18.2333300, -63.0000000, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(357, 'Blowing Point Village', 'Blowing Point Village', 'Blowing Point Village', 18.1764800, -63.0937500, 'AI', '2016-08-07', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(358, 'Sandy Hill', 'Sandy Hill', '', 18.2210400, -63.0132900, 'AI', '2016-07-31', 8);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(336, 'Saint John’s', 'Saint John''s', 'Saint John,Saint John''s,Saint John’s,Sent Dzonsas,Sent Džonsas,Sent Tzons,Sent-Dzhons,St Johns,St. John''s,St.John.s,seinteujonseu,sentojonzu,sheng yue han,sheng yue han shi,snt g''wns,Σεντ Τζονς,Сент-Джонс,סנט ג''ונס,ሴንት ጆንስ፥ አንቲጋ እና ባርቡዳ,セントジョンズ,圣约翰,圣约翰市,세인트존스', 17.1209600, -61.8432900, 'AG', '2017-05-24', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(337, 'Potters Village', 'Potters Village', 'Potters,Potters Village,Potters village,Potters-Villadzh,Поттерс-Вилладж', 17.0833300, -61.8166700, 'AG', '2016-06-26', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(338, 'Piggotts', 'Piggotts', 'Piggotts,Saint Mark''s,Saint Marks Village,Saint Mark’s', 17.1166700, -61.8000000, 'AG', '2013-08-02', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(339, 'Parham', 'Parham', 'Parham,Parkhehm,Пархэм', 17.0968200, -61.7704600, 'AG', '2016-06-26', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(340, 'Liberta', 'Liberta', 'Liberta,Liberta Village,Либерта', 17.0333300, -61.7833300, 'AG', '2016-06-26', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(341, 'Falmouth', 'Falmouth', 'Falmouth', 17.0274100, -61.7813600, 'AG', '2013-08-02', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(342, 'Codrington', 'Codrington', 'Codrington,Codrington Village,Kodrington,Kodringtonas,ke de ling dun,kodeulingteon,kodorinton,qwdryngtwn,Кодрингтон,קודרינגטון,کوڈرنگٹن، باربوڈا,コドリントン,科德灵顿,코드링턴', 17.6333300, -61.8333300, 'AG', '2014-08-18', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(343, 'Bolands', 'Bolands', 'Boland Village,Bolands,Bolans', 17.0656500, -61.8746600, 'AG', '2016-06-26', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(344, 'All Saints', 'All Saints', 'All Saints,All Saints Village', 17.0667100, -61.7930300, 'AG', '2016-06-26', 10);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(714, 'Zarrit’ap’', 'Zarrit''ap''', 'Azizbekov,Pashaghu,Pashalu,Zaritap,Zarrit''ap'',Zarrit’ap’,Զառիթափ', 39.6389200, 45.5111100, 'AM', '2016-07-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(715, 'Zangakatun', 'Zangakatun', 'Chanakhchi,Nizhniye Chanakhchi,Sovetashen,Zangakatun,Зангакатун,Զանգակատուն', 39.8223300, 45.0416900, 'AM', '2015-08-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(716, 'Goravan', 'Goravan', 'Goravan,Gorovan,Yenikend', 39.9083200, 44.7332800, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(717, 'Yeghegnavan', 'Yeghegnavan', 'Egegnavan,Ekhegnavan,Shidlu,Yeghegnavan,Ехегнаван,Եղեգնավան', 39.8389300, 44.6195100, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(718, 'Yeghegnadzor', 'Yeghegnadzor', 'Egegnajor,Eghegnazor,Ehegnadzor,Ekhegnadzor,Jechegnadzor,Jeghegnadsor,Jeghegnadzor,Jeghegnadzoras,Jekhegnadzor,Keshishkend,Keshishkent,Keşişkənd,Mikoyan,Yegegnadzor,Yeghegik,Yeghegnadzor,Yekhegnadzor,Yeğegnadzor,eghegnadzori,ye hai ge na zuo er,yegeganadajora,yghghnadzwr,yghgnadzwr,yghgndzwr,Єхегнадзор,Јехегнаџор,Ехегнадзор,Եղեգնաձոր,يغغنادزور,یغگنادزور,یغگندزور,ਯੇਗੇਗਨਾਦਜੋਰ,ეღეგნაძორი,葉海格納佐爾', 39.7638900, 45.3323900, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(719, 'Vostan', 'Vostan', 'Bedzhazlu,Ostan,Vostan,Востан,Ոստան', 39.9651500, 44.5593700, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(720, 'Vosketap’', 'Vosketap''', 'Shiraz,Shirazlu,Vosketap'',Vosketap’,Ոսկետափ', 39.8811400, 44.6491700, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(721, 'Vernashen', 'Vernashen', 'Bashkend,Vernashen,Вернашен', 39.7923600, 45.3638900, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(722, 'Verishen', 'Verishen', 'Verisen,Verishen,Վերիշեն', 39.5354300, 46.3206300, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(723, 'Vedi', 'Vedi', 'Beyuk-Vedi,Biyuk-Vedi,Vedi,Веди,Վեդի', 39.9138800, 44.7251000, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(724, 'Vayk’', 'Vayk''', 'Azizbekov,Soylan,Vajk,Vayk'',Vayk’,Вайк,Վայք', 39.6889000, 45.4666800, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(725, 'Tegh', 'Tegh', 'Dyg,Lekh,Teg,Tegh,Tekh,Тех,Տեղ', 39.5582600, 46.4805400, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(726, 'Surenavan', 'Surenavan', 'Surenavan,Սուրենավան', 39.7944900, 44.7750800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(727, 'Sisavan', 'Sisavan', 'Sisavan,Yengidzha,Сисаван,Սիսավան', 39.9080200, 44.6672100, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(728, 'Shinuhayr', 'Shinuhayr', 'Shinuair,Shinuajr,Shinuayr,Shinuhayr,Sinuayr,Sinuhayr,Şinuayr,Шинуайр,Շինուհայր', 39.4367000, 46.3178700, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(729, 'Shahumyan', 'Shahumyan', 'Sahumyan,Shahumian,Shahumyan,Shaumjan,Shaumyan,Yuva,Шаумян,Շահումյան', 39.9417100, 44.5723300, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(730, 'Shatin', 'Shatin', 'Gasankend,Hasankand,Hesan Kand,Satin,Shatik,Shatin,Шатин,Շատին', 39.8361200, 45.3029200, 'AM', '2016-07-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(731, 'Shaghat', 'Shaghat', 'Sagat,Shagat,Shaghat,Շաղատ', 39.5582900, 45.9166900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(732, 'Rrind', 'Rrind', 'Rind,Rrind,Ռինդ', 39.7611100, 45.1779200, 'AM', '2015-08-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(733, 'Noyakert', 'Noyakert', 'Khalisa,Nojakert,Noyakert,Ноякерт,Նոյակերտ', 39.8306900, 44.6694900, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(734, 'Mrgavan', 'Mrgavan', 'Gedaklu,Mgravan,Mrgavan,Мграван,Մրգավան', 39.9725100, 44.5356500, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(735, 'Meghri', 'Meghri', 'Meghri,Megri,Megris,Megry,Mergi,Meğri,Mogri,meghri,mei ge li,mghry,Мегри,Мегрі,Մեղրի,مغری,მეღრი,梅格里', 38.9029200, 46.2445800, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(736, 'Malishka', 'Malishka', 'Malishka,Maliska,Մալիշկա', 39.7473100, 45.4057000, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(737, 'Khndzoresk', 'Khndzoresk', 'Khndzoresk,Xnjoresk,Խնձորեսկ', 39.5056800, 46.4361000, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(738, 'Kapan', 'Kapan', 'Ghap''an,Ghapan,Ghap’an,Kafan,Kafin,Kapan,Kapanas,Katan,Madan,Qafan,Zangezur,ka pan,kapan,kapana,Капан,Կապան,کاپان,ਕਪਾਨ,კაპანი,カパン,卡潘,카판', 39.2075500, 46.4057600, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(739, 'Jermuk', 'Jermuk', 'Dzhermuk,Jermuk,Джермук,Ջերմուկ', 39.8416800, 45.6694900, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(740, 'Goris', 'Goris', 'Geryusy,Goris,Горис,Գորիս', 39.5111100, 46.3416800, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(741, 'Gladzor', 'Gladzor', 'Gladzor,Glajor,Ortakend,Гладзор,Գլաձոր', 39.7807000, 45.3472900, 'AM', '2016-07-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(742, 'Getap’', 'Getap''', 'Getap'',Getap’,Ghyotur,Koytur,Գետափ', 39.7639200, 45.3082900, 'AM', '2016-07-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(743, 'Dzorastan', 'Dzorastan', 'Akhtakhana,Dzorastan,Jorastan,Khlatag,Ձորաստան', 39.2705900, 46.3572000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(744, 'Dalar', 'Dalar', 'Dalar,Dalular,Далар,Դալար', 39.9765300, 44.5264900, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(745, 'Burastan', 'Burastan', 'Burastan,Karagamzalu,Tamamlu,Բուրաստան', 39.9915700, 44.4968100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(746, 'Akner', 'Akner', 'Akner,Brun,Ակներ,Բրուն', 39.5349100, 46.3073200, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(747, 'Brrnakot’', 'Brrnakot''', 'Brnakot,Brrnakot'',Brrnakot’,Բռնակոթ', 39.4974200, 45.9724100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(748, 'Berk’anush', 'Berk''anush', 'Berk''anush,Berkanush,Berk’anush,Ogurbeklu,Բերքանուշ', 39.9779000, 44.5167200, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(749, 'Aygezard', 'Aygezard', 'Ajgezard,Anastasavan,Aygedzor,Aygezard,Dargalu,Айгезард,Այգեզարդ', 39.9543600, 44.6022900, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(750, 'Aygepat', 'Aygepat', 'Ajgepat,Aygepat,Dargalu Verkhniy,Masumlu,Verkhniy Dargalu,Айгепат,Այգեպատ', 39.9584500, 44.5998100, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(751, 'Aygavan', 'Aygavan', 'Ajgavan,Aygavan,Reganlu,Айгаван,Այգավան', 39.8732700, 44.6698400, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(752, 'Avshar', 'Avshar', 'Avsar,Avshar,Ավշար', 39.8555300, 44.6583200, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(753, 'Hats’avan', 'Hats''avan', 'Acavan,Atsavan,Hats''avan,Hats’avan,Sisian,Ацаван,Հացավան', 39.4640500, 45.9704700, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(754, 'Artashat', 'Artashat', 'Artachat,Artasat,Artasatas,Artasato,Artaschat,Artashat,Artasjat,Artaszat,Artaxat,Artaxata,Artaŝato,Artaşat,Artašat,Artašatas,Artașat,Kamarl,Kamarlu,Kamarlyu,Qəmərli,a er ta sha te,aratasata,artashat,artashat  armynya,Арташат,Արտաշատ,آرتاشات,آرتاشات، آرمینیا,أرتاشات,ਅਰਤਾਸ਼ਤ,არტაშატი,阿爾塔沙特', 39.9614400, 44.5444700, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(755, 'Yeghegis', 'Yeghegis', 'Alagyaz,Alayaz,Artabuynk,Egegis,Erdapin,Yeghegis,Yekhegis,Եղեգիս', 39.8723100, 45.3501000, 'AM', '2016-07-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(756, 'Armash', 'Armash', 'Armas,Armash,Արմաշ', 39.7667200, 44.8111000, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(757, 'Areni', 'Areni', 'Areni,Arpa,Арени,Արենի', 39.7166800, 45.1832900, 'AM', '2015-08-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(758, 'Ararat', 'Ararat', 'Ararat,Araratas,Ararato,Davalinskiy Tsemzavod,Davalu,alalateu,ararat,ararat  armnstan,ararata,ararato,ya la la,Арарат,Արարատ,אררט,آرارات، ارمنستان,أرارات,ਅਰਾਰਤ,არარატი,アララト,亞拉臘,아라라트', 39.8306900, 44.7056900, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(759, 'Angeghakot’', 'Angeghakot''', 'Angeghakot'',Angeghakot’,Angekhakot,Angelaut,Անգեղակոթ', 39.5695200, 45.9445200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(760, 'Aghavnadzor', 'Aghavnadzor', 'Agavnadzor,Agavnajor,Aghavnadzor,Akhavnadzor,Aynadzor,Агавнадзор,Աղավնաձոր', 39.7860700, 45.2279000, 'AM', '2015-08-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(761, 'Agarakadzor', 'Agarakadzor', 'Agarakadzor,Agarakajor,Ayar,Агаракадзор,Ագարակաձոր', 39.7360800, 45.3555300, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(762, 'Agarak', 'Agarak', 'Agarak,Aqarak,Агарак,Ագարակ', 39.2068400, 46.5446000, 'AM', '2016-06-04', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(763, 'Aralez', 'Aralez', 'Aralek,Aralez,Արալեզ', 39.9000800, 44.6557000, 'AM', '2016-02-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(764, 'Horrom', 'Horrom', 'Horom,Horrom,Orom,Ором,Հոռոմ', 40.6597300, 43.8903200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(765, 'Margara', 'Margara', 'Margara,Markara,Маргара,Маркара,Մարգարա', 40.0333200, 44.1804800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(766, 'Zovuni', 'Zovuni', 'Molla Kasum,Zovuni,Зовуни,Զովունի', 40.5111100, 44.4389000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(767, 'Zovaber', 'Zovaber', 'Yaydzhi,Zovaber,Зовабер,Զովաբեր', 40.5667100, 44.7902800, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(768, 'Zorak', 'Zorak', 'Donguzyan,Zangilar,Zorak,Зорак,Զորակ', 40.0916800, 44.3944700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(769, 'Zarr', 'Zarr', 'Zar,Zarr,Зар,Զառ', 40.2584800, 44.7332800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(770, 'Yerevan', 'Yerevan', 'Ayrivan,Djerevan,EVN,Eireavan,Eireaván,Ereban,Ereun,Erevan,Erevan osh,Erevana,Erevano,Erevanum,Erevàn,Ereván,Erevāna,Erewan,Erivan,Eriwan,Erywan,Erywań,Gierevan,Gorad Erehvan,Ierevan,Iereván,Iravan,Jerevan,Jerevanas,Jerevani,Jereván,Jerewan,Jerjewan,Revan,Yerevan,Yervandavan,Yerêvan,Yiriwan,Yèrèvan,Yérévan,ayrwan,ereban,erevani,iyerebhana,shhr ayrwan,ye li wen,yeleban,yeravana pranta,yere wan,yerevan,yerevana,yerevhana,yryfan,yrywan,Èrevan,Êrîvan,İrəvan,Γιερεβάν,Ερεβάν,Єреван,Јереван,Горад Ерэван,Ереван,Ереван ош,Երեվան,Երևան,יערעוואן,ירוואן,ایروان,شهر ایروان,يريفان,يېرېۋان,یریوان,یەریڤان,येरवान प्रान्त,येरेवान,येरेव्हान,ইয়েরেভান,யெரெவான்,เยเรวาน,ཡེ་རེ་ཝན།,ერევანი,ዬሬቫን,エレバン,葉里溫,예레반', 40.1811100, 44.5136100, 'AM', '2016-03-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(771, 'Yerazgavors', 'Yerazgavors', 'Aralykh,Erazgavors,Yerazgavors,Еразгаворс', 40.6950500, 43.7472200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(772, 'Yeraskhahun', 'Yeraskhahun', 'Erasxahun,Kuru-Araz,Yeraskhahun,Yeraskhaun,Երասխահուն', 40.0723300, 44.2194800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(773, 'Yeranos', 'Yeranos', 'Eranos,Yeranos,Еранос,Երանոս', 40.2042800, 45.1920900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(774, 'Yeghegnut', 'Yeghegnut', 'Egegnut,Ekheknut,Kamyshkut,Yegegnut,Yeghegnut,Yekhegnut,Yekheknut,Ехекнут,Եղեգնուտ', 40.9030200, 44.6315500, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(775, 'Yeghegnut', 'Yeghegnut', 'Badal,Egegnut,Ekhegnut,Molla Badal,Yeghegnut,Yekheknut,Ехегнут,Եղեգնուտ', 40.0889300, 44.1666900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(776, 'Ejmiatsin', 'Ejmiatsin', 'Artemed,Avan Vardgesi,Echmiadzin,Echmiatsin,Ecmiadzin,Ejmiatsin,Etchmiadzin,Etjmiadzin,Etschmiadsin,Ečmiadzin,Iejmiatsin,Kaynepolis,Kayrak''aghak'',Kayrak’aghak’,Norak''aghak'',Norak’aghak’,Uch''k''ilisa,Uch’k’ilisa,Uckilise,Vagarsapat,Vagarshapat,Vagharsapat,Vagharshapat,Vagharšapat,Valeroktista,Vardgesavan,Wagharszapat,ehchmiadzin,vagharshapʼatʼi,wagharshapat,Üçkilise,Вагаршапат,Эчмиадзин,Վաղարշապատ,واغارشاپات,ვაღარშაპატი', 40.1655700, 44.2946200, 'AM', '2014-03-15', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(777, 'Yeghvard', 'Yeghvard', 'Eghvard,Egvard,Ehvard,Jeghward,Jegvard,Jegvardas,Jegward,Yeghvard,Yegvard,Yegvart,Yevgard,eghvardi,yghward,yghwrd,Єгвард,Егвард,Եղվարդ,يغوارد,یغوارد,یغورد,ეღვარდი', 40.3250700, 44.4860800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(778, 'Voskevaz', 'Voskevaz', 'Kiziltamur,Oskevaz,Voskevaz,Воскеваз,Ոսկեվազ', 40.2750800, 44.3001100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(779, 'Voskevan', 'Voskevan', 'Koshkotan,Oskevan,Voskevan,Воскеван,Ոսկեվան', 41.1208100, 45.0638100, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(780, 'Voskehask', 'Voskehask', 'Molla Musa,Musakan,Oskehask,Voskeask,Voskehask,Воскеаск,Ոսկեհասկ', 40.7642600, 43.7747400, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(781, 'Verin Getashen', 'Verin Getashen', 'Nerkin Getashen,Verin Adyaman,Verin Getasen,Verin Getashen,Verkhniy Adyaman,Неркин Геташен,Վերին Գետաշեն', 40.1306800, 45.2529300, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(782, 'Verin Dvin', 'Verin Dvin', 'Aysori Dvin,Verin Dvin,Verkhniy Dvin,Верин Двин,Վերին Դվին', 40.0243400, 44.5903800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(783, 'Verin Artashat', 'Verin Artashat', 'Ardashar,Artashat,Verin Artasat,Verin Artashat,Verkhniy Artashat,Верин Арташат,Վերին Արտաշատ', 39.9973100, 44.5889300, 'AM', '2016-02-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(784, 'Akht’ala', 'Akht''ala', 'Akht''ala,Akht’ala,Verin Akhtala,Verkhnyaya Akhtala,Ախթալա', 41.1683800, 44.7581100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(785, 'Varser', 'Varser', 'Chirchir,Varser,Варсер,Վարսեր', 40.5554800, 44.9083200, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(786, 'Vardenis', 'Vardenis', 'Basargech''ar,Basargech’ar,Basarkeçər,Vardenis,Vardenisas,Wardenis,vardenisi,wa er dai ni si,wardnys,wrdnys,Варденис,Варденіс,Վարդենիս,ורדניס,واردنيس,واردنیس,ვარდენისი,瓦爾代尼斯', 40.1832900, 45.7305300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(787, 'Vardenik', 'Vardenik', 'Gezeldara,Nerkin Gezaldara,Nizhnyaya Gezaldara,Vardenik,Варденик,Վարդենիկ', 40.1334800, 45.4431100, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(788, 'Vahan', 'Vahan', 'Ordzhonikidze,Vahan,Орджоникидзе,Վահան', 40.5754900, 45.3976900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(789, 'Vaghashen', 'Vaghashen', 'Avdalagalu,Vagasen,Vagashen,Vaghashen,Vakhashen,Вахашен,Վաղաշեն', 40.1361100, 45.3306900, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(790, 'Vahagni', 'Vahagni', 'Shagali,Vaagni,Vahagni,Ваагни,Վահագնի', 40.9069800, 44.6087300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(791, 'Ushi', 'Ushi', 'Owsi,Ushi,Ուշի', 40.3472900, 44.3751200, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(792, 'Urrut', 'Urrut', 'Owrut,Urrut,Urut,Урут,Ուռուտ', 41.0677800, 44.3962800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(793, 'Tsovinar', 'Tsovinar', 'Covinar,Kolakran,Tsovinar,Цовинар,Ծովինար', 40.1595900, 45.4678600, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(794, 'Tsovazard', 'Tsovazard', 'Covazard,Gadzhi Mukhan,Mukhan,Tsovazard,covazard,Цовазард,ծովազարդ', 40.4751000, 45.0501100, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(795, 'Tsovak', 'Tsovak', 'Covak,Nerkin Zagalu,Nizhniy Zagalu,Tsovak,Цовак,Ծովակ', 40.1825400, 45.6328600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(796, 'Tsovagyugh', 'Tsovagyugh', 'Chabukhly,Chibukhly,Chubukhly,Chubuli,Chubuliki,Covagjukh,Covagyug,Tsovagyugh,Tsovagyukh,Tzovagyugh,Цовагюх,Ծովագյուղ', 40.6334800, 44.9611200, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(797, 'Tsaghkunk’', 'Tsaghkunk''', 'Tsaghkunk'',Tsaghkunk’,Tsakhkunk,Verin Aylanlu,Verkhnyaya Aylanlu,Ծաղկունք', 40.1804800, 44.2722800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(798, 'Tsaghkahovit', 'Tsaghkahovit', 'Cagkahovit,Cakhkaovit,Gadzhi-Khalil,Tsaghkahovit,Tsakhkaovit,Tzaghkahovit,Цахкаовит,Ծաղկահովիտ', 40.6342800, 44.2224100, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(799, 'Tsaghkaber', 'Tsaghkaber', 'Avdibek,Cagkaber,Cakhkaber,Tsaghkaber,Tsakhkaber,Tsakhkashen,Tzaghkaber,Цахкабер,Ծաղկաբեր', 40.7984900, 44.1014400, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(800, 'Tsaghkadzor', 'Tsaghkadzor', 'Cachkadzor,Cachkadzoras,Cagkadzor,Cagkajor,Cakhkadzor,Darachichag,Dərəçiçək,Tahkadzor,Tsachkadzor,Tsaghkadzor,Tsakhkadzor,Zaghkadsor,tsaghkadzwr,Țahkadzor,Цагкадзор,Цахкадзор,Ծաղկաձոր,تساغکادزور,წაღკაძორი', 40.5325900, 44.7202500, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(801, 'Tsovasar', 'Tsovasar', 'Covasar,T''azagyugh,Tazagyukh,Tsovasar,T’azagyugh,Ծովասար', 40.1382000, 45.1909600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(802, 'Tashir', 'Tashir', 'Kaliniko,Kalinin,Kalinino,Tashir,Tasir,Vorontsovka,Ташир,Տաշիր', 41.1207200, 44.2846200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(803, 'Tandzut', 'Tandzut', 'Armutlu,Tandzut,Tanjut,Тандзут,Տանձուտ', 40.0695200, 44.0778800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(804, 'T’alin', 'T''alin', 'T''alin,Talin,T’alin,Verin Talin,Verkhniy Talin,Талин,Թալին', 40.3917200, 43.8779300, 'AM', '2017-02-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(805, 'Step’anavan', 'Step''anavan', 'Dzhalalogly,Dzhelaloglu,Step''anavan,Stepahavan,Stepanavan,Stepanawan-Lori,Step’anavan,Степанаван,Ստեփանավան', 41.0099500, 44.3853100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(806, 'Spitak', 'Spitak', 'Amamlu,Amamth,Spitak,Спитак,Սպիտակ', 40.8322100, 44.2673100, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(807, 'Spandaryan', 'Spandaryan', 'Kulidzhan,Spandarjan,Spandaryan,Спандарян,Սպանդարյան', 40.6610500, 44.0155100, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(808, 'Alashkert', 'Alashkert', 'Alashkert,Alaskert,Kyarimarkh,Sovetakan,Советакан,Ալաշկերտ', 40.1071200, 44.0510800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(809, 'Solak', 'Solak', 'Solak,Солак,Սոլակ', 40.4625200, 44.7070900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(810, 'Sis', 'Sis', 'Sarvanlar,Sis,Uliya Sarvanlar,Сис,Սիս', 40.0582900, 44.3889200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(811, 'Shnogh', 'Shnogh', 'Shnogh,Shnokh,Snog,Шнох,Շնող', 41.1469300, 44.8404300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(812, 'Shirak', 'Shirak', 'Konakhkran,Kunakhkran,Shirak,Sirak,Ширак,Շիրակ', 40.8404200, 43.9158200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(813, 'Shenavan', 'Shenavan', 'Blkher,Senavan,Shenavan,Шенаван,Շենավան', 40.4832800, 44.3834800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(814, 'Shenavan', 'Shenavan', 'Kyalagarkh,Senavan,Shenavan,Шенаван,Շենավան', 40.0554800, 43.9304800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(815, 'Sevan', 'Sevan', 'Sevan,Sevanas,Sewan,Ssewan,Yelenovka,sai fan,sevani,swan,Севан,Սևան,سوان,სევანი,塞凡', 40.5473000, 44.9417100, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(816, 'Sarukhan', 'Sarukhan', 'Dalikardash,Sarukhan,Saruxan,Сарухан,Սարուխան', 40.2916900, 45.1306800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(817, 'Sarigyugh', 'Sarigyugh', 'Sariguh,Sarigyug,Sarigyugh,Sarigyukh,Sarıgüh,Srigekh,Srygekh,Սարիգյուղ', 41.0353100, 45.1448600, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(818, 'Saratak', 'Saratak', 'Imrkhan,Saratak,Саратак,Սարատակ', 40.6709000, 43.8723100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(819, 'Saramej', 'Saramej', 'Chotur,Saramech,Saramej,Сарамеч,Սարամեջ', 40.7748700, 44.2222000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(820, 'Sarahart’', 'Sarahart''', 'Gyullidzha,Saraart,Sarahart'',Sarahart’,Սարահարթ', 40.8704300, 44.2140700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(821, 'Geghakert', 'Geghakert', 'Gegakert,Geghakert,Gekhakert,Samagar,Samaghar,Samakhar,Самахар,Գեղակերտ', 40.1851600, 44.2433100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(822, 'Ptghni', 'Ptghni', 'Ptghni,Ptgni,Ptkhni,Ptykhni,Птхни,Պտղնի', 40.2556800, 44.5861200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(823, 'Ptghunk’', 'Ptghunk''', 'Ptghunk'',Ptghunk’,Ptkhunk,Պտղունք', 40.1638800, 44.3638900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(824, 'P’shatavan', 'P''shatavan', 'Igdalu,P''shatavan,Pshatavan,P’shatavan,Пшатаван,Փշատավան', 40.0388800, 44.0667100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(825, 'Prroshyan', 'Prroshyan', 'Proshian,Proshyan,Prosyan,Prroshyan,Պռոշյան', 40.2473100, 44.4194900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(826, 'P’ok’r Mant’ash', 'P''ok''r Mant''ash', 'Malyy Mantash,P''ok''r Mant''ash,Pokr Arkhvali,Pokr Mantash,P’ok’r Mant’ash,Покр Манташ,Փոքր Մանթաշ', 40.6402600, 44.0466600, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(827, 'Zoravan', 'Zoravan', 'Kargavank,Pokravan,Zoravan,Зораван,Զորավան', 40.3555300, 44.5222800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(828, 'Pemzashen', 'Pemzashen', 'Magmudzhuk,Mahmutcuk,Makhmudzhug,Pemzasen,Pemzashen,Пемзашен,Պեմզաշեն', 40.5861200, 43.9431100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(829, 'Parravak’ar', 'Parravak''ar', 'Paravakar,Paravaker,Parravak''ar,Parravak’ar,Паравакар,Պառավաքար', 40.9824800, 45.3669600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(830, 'Oshakan', 'Oshakan', 'Ochakan,Osakan,Oschakan,Oshakan,Osjakan,Oszakan,Oŝakan,Oşakan,awshakan,Ошакан,Օշական,أوشاكان,اوشاکان,ოშაკანი', 40.2639200, 44.3167100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(831, 'Sardarapat', 'Sardarapat', 'Hoktember,Oktember,Oktemberjan,Sardarapat,Октемберян,Սարդարապատ', 40.1320600, 44.0096900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(832, 'Odzun', 'Odzun', 'Dzun,Odzun,Ojun,Usuklyar,Uzunlar,Одзун,Օձուն', 41.0532100, 44.6134100, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(833, 'Noyemberyan', 'Noyemberyan', 'Baran,Barana,Noemberjan,Noiemberian,Nojemberianas,Nojemberjan,Noyemberian,Noyemberyan,noemberiani,nwymbryan,Ноемберян,Նոյեմբերյան,نويمبريان,نویمبریان,ნოემბერიანი', 41.1724400, 44.9991700, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(834, 'Nor Gyugh', 'Nor Gyugh', 'Nor Gyug,Nor Gyugh,Nor Gyukh,Tazagyukh,Նոր Գյուղ', 40.2667200, 44.6583200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(835, 'Nor Geghi', 'Nor Geghi', 'Bazmavan,Chatkran,Nor Geghi,Nor Gegi,Nor Gekhi,Нор Гехи,Նոր Գեղի', 40.3223300, 44.5833100, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(836, 'Norashen', 'Norashen', 'Bogdanovka,Norasen,Norashen,Норашен,Նորաշեն', 41.1888600, 44.3333600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(837, 'Norashen', 'Norashen', 'Norasen,Norashen,Verin Kurdkend,Норашен,Նորաշեն', 40.0013000, 44.5929600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(838, 'Nor Armavir', 'Nor Armavir', 'Nor Armavir,Նոր Արմավիր', 40.0861200, 43.9945100, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(839, 'Noramarg', 'Noramarg', 'Abilkend,Ablkend,Bulagli,Bulakhly,Imeni Kalinina,Kalinin,Noramarg,Poselok Imeni Kalinina,Posëlok Imeni Kalinina,Норамарг,Նորամարգ', 40.0222800, 44.4251100, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(840, 'Norakert', 'Norakert', 'Norakert,Նորակերտ', 40.1973300, 44.3501000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(841, 'Noratus', 'Noratus', 'Noraduz,Noratus,Норадуз,Նորատուս', 40.3779300, 45.1804800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(842, 'Nerk’in Getashen', 'Nerk''in Getashen', 'Nerk''in Getashen,Nerkin Adyaman,Nerk’in Getashen,Nizhniy Adyaman,Ներքին Գետաշեն', 40.1417200, 45.2708700, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(843, 'Navur', 'Navur', 'Navur,Навур,Նավուր', 40.8669500, 45.3417900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(844, 'Nalbandyan', 'Nalbandyan', 'Mets Shagriar,Nalbandjan,Nalbandyan,Shagriar,Shagriar Bol''shoy,Shagriar Bol’shoy,Налбандян,Նալբանդյան', 40.0639000, 43.9888900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(845, 'Basen', 'Basen', 'Basen,Mets Kyapanak,Musaeljan,Musayelyan,Мусаелян,Բասեն', 40.7576700, 43.9927400, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(846, 'Hovtamej', 'Hovtamej', 'Hovtamej,Mugan,Ovtamech,Հովտամեջ', 40.1832900, 44.2584800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(847, 'Mrgashen', 'Mrgashen', 'Mrgasen,Mrgashen,Մրգաշեն', 40.2860700, 44.5444900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(848, 'Mrgashat', 'Mrgashat', 'Gecherlau,Gechrlu,Mrgasat,Mrgashat,Мргашат,Մրգաշատ', 40.1306800, 44.0806900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(849, 'Mrganush', 'Mrganush', 'Mrganush,Zograblu,Мргануш', 40.0285700, 44.5583100, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(850, 'Mosesgegh', 'Mosesgegh', 'Mosesgeg,Mosesgegh,Mosesgekh,Mosesgex,Movses,Мосесгех,Մոսեսգեղ', 40.9053400, 45.4883800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(851, 'Mets Parni', 'Mets Parni', 'Bekyand,Mec Parni,Mec-Parni,Mets Parni,Parni,Мец-Парни,Մեծ Պարնի', 40.8347200, 44.1110800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(852, 'Mets Masrik', 'Mets Masrik', 'Bol''shaya Mazra,Bol’shaya Mazra,Mazra,Mec Masrik,Mec Mazra,Mets Masrik,Mets-Mazra,Мец Мазра,Մեծ Մասրիկ', 40.2194800, 45.7639100, 'AM', '2015-11-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(853, 'Mets Mant’ash', 'Mets Mant''ash', 'Bol''shoy Mantash,Bol’shoy Mantash,Mantash,Mec-Mantash,Mets Arikhvali,Mets Mant''ash,Mets Mant’ash,Metz Mantash,Мец-Манташ,Մեծ Մանթաշ', 40.6437600, 44.0565300, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(854, 'Metsavan', 'Metsavan', 'Mecavan,Metsavan,Shakhnazar,Мецаван,Մեծավան', 41.2015600, 44.2287700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(855, 'Metsamor', 'Metsamor', 'Kamarlu,Mecamor,Metsamor,Мецамор,Մեծամոր', 40.0723300, 44.2916900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(856, 'Merdzavan', 'Merdzavan', 'Merdzavan,Merjavan,Mertsavan,Мердзаван,Մերձավան', 40.1814000, 44.4003300, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1025, 'Saurimo', 'Saurimo', 'Henrique de Carvalho,Saurimo,Saurimu,VHC,Vila Henrique de Carvalho,Сауримо', -9.6607800, 20.3915500, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1026, 'Lucapa', 'Lucapa', 'LBZ,Lucapa,Lukapa,Лукапа', -8.4191500, 20.7446600, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1027, 'Lumeje', 'Lumeje', 'Cameia,Lumege,Lumeje,Lumeji,Lumezhe,Лумеже', -11.5500000, 20.7833300, 'AO', '2015-08-30', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1028, 'Luau', 'Luau', 'Luao,Luau,Teixeira de Sousa,Teixera de Sousa,Texeira-de Susa,UAL,Vila Teixeira de Sousa,Vila Teixeira de Souza,Vila Teixera de Souza,Vila Texeira de Sousa,Луау', -10.7072700, 22.2246600, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1029, 'Léua', 'Leua', 'Leua,Léua,Sandando', -11.6500000, 20.4500000, 'AO', '2013-06-04', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1030, 'Cazaji', 'Cazaji', 'Cazage,Cazaje,Cazaji,Kazagi', -11.0671500, 20.7014800, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1031, 'Uíge', 'Uige', 'Carmona,UGO,Uige,Uije,Uizhe,Uíge,Vila Marchel Carmona,Уиже', -7.6087400, 15.0613100, 'AO', '2017-05-07', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1032, 'Soio', 'Soio', 'SZA,Saint Antonio do Zaire,San Antonio,Santo Antoni,Santo Antonio do Zaire,Santo António do Zaire,Santo-Antonio,Santo-António,Sao Antonio,Sazaire,Soio,Soju,Soyo,São Antônio,Сойу', -6.1349000, 12.3689400, 'AO', '2017-05-07', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1033, 'N''zeto', 'N''zeto', 'ARZ,Ambrisette,Ambrizete,Ambrizette,Nzeto,Нзето', -7.2311600, 12.8666000, 'AO', '2017-07-07', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1034, 'N’dalatando', 'N''dalatando', 'Dalatando,N''dalatando,NDF,Ndalatanda,N’dalatando,Salazar,Vila Salazar,Villa Salazar', -9.2978200, 14.9116200, 'AO', '2017-05-07', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1035, 'Mbanza Congo', 'Mbanza Congo', 'Mbanza Congo,Mbanza Kongo,San Salvador,Sao Salvador,Sao Salvador do Congo,São Salvador,São Salvador do Congo', -6.2670300, 14.2401000, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1036, 'Malanje', 'Malanje', 'MEG,Malandje,Malange,Malanje,Malanzhe,Маланже', -9.5401500, 16.3409600, 'AO', '2014-06-23', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1037, 'Luanda', 'Luanda', 'Gorad Luanda,LAD,Loanda,Louanda,Louanta,Luand,Luanda,Luandae,Luando,Lwanda,Lúanda,Saint Paul de Loanda,Sao Paolo de Loanda,Sao Paulo da Assuncao de Luanda,Sao Paulo de Loanda,Sao Paulo de Luanda,St Paul de Loanda,São Paolo de Loanda,São Paulo da Assunção de Luanda,São Paulo de Loanda,São Paulo de Luanda,lu''anda,luanda,luo an da,luvanta,luxanda,luyanda,lwanda,ruanda,Λουάντα,Горад Луанда,Луандæ,Луанда,Լուանդա,לואנדה,לואנדע,لوآندا,لواندا,لونڈا,लुआंडा,लुआण्डा,লুয়ান্ডা,ਲੁਆਂਦਾ,லுவாண்டா,ลูอันดา,ལའུན་ཌ།,ლუანდა,ሏንዳ,ルアンダ,罗安达,루안다', -8.8368200, 13.2343200, 'AO', '2014-10-08', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1038, 'Caxito', 'Caxito', 'Caxito,Kashito,Kaxito,Кашито', -8.5784800, 13.6642500, 'AO', '2011-10-28', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1039, 'Camabatela', 'Camabatela', 'Ambaca,Camabatela,Kamabatela,Камабатела', -8.1881200, 15.3749500, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1040, 'Cabinda', 'Cabinda', 'CAB,Cabinda,Kabinda,Кабинда', -5.5500000, 12.2000000, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1041, 'Uacu Cungo', 'Uacu Cungo', 'CEO,Santa Comba,Santa Comba Dao,Santa Comba Dão,Uacu Cungo,Vaku Kungu,Vila de Santa Comba Dao,Vila de Santa Comba Dão,Waco-Kungo,Waku-Kungo,Ваку Кунгу', -11.3566900, 15.1171900, 'AO', '2015-04-24', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1042, 'Sumbe', 'Sumbe', 'Angungescapolo,NDD,Ngunza,Nova Redonda,Nova Redondo,Novo Redondo,Sumbe,Sumbė,sun bei,sunbe,swmbh  angwla,Сумбе,سومبه، آنگولا,سومبے,スンベ,孫貝', -11.2060500, 13.8437100, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1043, 'Quibala', 'Quibala', 'Kibala,Quibala,Кибала', -10.7336600, 14.9799500, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1044, 'Ondjiva', 'Ondjiva', 'N''Giva,N''Jiva,N’Giva,N’Jiva,Ondjiva,Ondyiva,Ondzhiva,Ondziva,Ondživa,Ongiva,Onjiva,Pereira d''Eca,Pereira de Eca,Pereira d’Eca,VPE,Vila Pereira d''Eca,Vila Pereira de Eca,Vila Pereira de Eco,Vila Pereira de Eça,Vila Pereira d’Eça,andjywa,andzhywa  angwla,weng ji wa,Онджива,اندجیوا,اندژیوا، آنگولا,翁吉瓦', -17.0666700, 15.7333300, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1045, 'Namibe', 'Namibe', 'MSZ,Mocamedes,Mossamedes,Moçâmedes,Namibe,Namibė,na mi bei,namibe,namibeu,namybh  angwla,Намибе,Намібе,نامیبه، آنگولا,نامیبے,ナミベ,納米貝,나미브', -15.1961100, 12.1522200, 'AO', '2014-03-05', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1046, 'Menongue', 'Menongue', 'Menonge,Menongve,Menongė,SPP,Serpa Pinto,Vila Serpa Pinto,mei nong gai,menong-geu,menongue,mnngw  angwla,mnwngh,mynwngw,Менонгве,Менонге,מנונגה,مننگو، آنگولا,مینونگو,ሜኖንጉዌ,メノングエ,梅農蓋,메농그', -14.6585000, 17.6909900, 'AO', '2014-06-23', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1047, 'Luena', 'Luena', 'LUO,Luehna,Luena,Luene,Luso,Luzo,Vila Luso,Vila Luzo,Vila Luzu,Villa Luso,lu ai na,luena,lwna  angwla,Луена,Луэна,לואנה,لوئنا، موشیکو صوبہ,لونا، آنگولا,盧埃納,루에나', -11.7833300, 19.9166700, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1048, 'Lubango', 'Lubango', 'Lubangas,Lubango,SDD,Sa da Bandeira,Sá da Bandeira,lu ban ge,lubang-gu,lwbanghw,lwbngw  angwla,rubango,Лубанго,لوبانغو,لوبنگو، آنگولا,ルバンゴ,盧班戈,루방구', -14.9171700, 13.4925000, 'AO', '2014-06-23', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1049, 'Longonjo', 'Longonjo', 'Congonjo,Logonzhu,Longonjo,Логонжу', -12.9066700, 15.2533300, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1050, 'Lobito', 'Lobito', 'LLT,Lobitas,Lobito,Lobitu,Lubitu,lbytw  angwla,lobitu,luo bi tuo,robito,Лобито,Лобиту,Лобіту,لبیتو، آنگولا,ロビト,洛比托,로비투', -12.3644000, 13.5360100, 'AO', '2013-06-09', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1051, 'Cuito', 'Cuito', 'Bie,Bihe,Bihé,Bié,Cuito,Kuito,SVP,Silva Porto,Vila Salva Porto,Куито', -12.3833300, 16.9333300, 'AO', '2013-06-04', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1052, 'Huambo', 'Huambo', 'Huambas,Huambo,Huamdo,Khuambo,NOV,Nova Lisboa,Uambo,hu''ambo,hwambw  angwla,uambu,uanbo,wambu,wan bo,Вилояти Ҳвамбо,Уамбо,Хуамбо,הואמבו,هوامبو، آنگولا,ہوامبو,ਹੁਆਂਬੋ,วัมบู,ウアンボ,万博,우암부', -12.7761100, 15.7391700, 'AO', '2013-06-04', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1053, 'Chissamba', 'Chissamba', 'Chissamba', -12.1666700, 17.3333300, 'AO', '2014-04-06', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1054, 'Catumbela', 'Catumbela', 'Asseiceira,CBT,Catumbela,Catumbella,Katumbela,Катумбела', -12.4300200, 13.5467700, 'AO', '2013-11-08', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1055, 'Catabola', 'Catabola', 'Catabola,Katabola,Катабола', -12.1500000, 17.2833300, 'AO', '2013-06-04', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1056, 'Camacupa', 'Camacupa', 'Camacupa,General Machado,General Machado Villa,General Mathado,Kamakupa,Machado,Vila General Machado,Камакупа', -12.0166700, 17.4833300, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1057, 'Caluquembe', 'Caluquembe', 'Caluquembe,Caluquembo,Caluquemo,Kalukembe,Калукембе', -13.7833300, 14.6833300, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1058, 'Caconda', 'Caconda', 'Caconda,Kakonda,Каконда', -13.7333300, 15.0666700, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1059, 'Caála', 'Caala', 'Caala,Cahala,Caála,Kaala,Kaale,Robert Williams,Roberto Williams,Vila Robert Williams,Каале', -12.8525000, 15.5605600, 'AO', '2012-01-17', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1060, 'Benguela', 'Benguela', 'BUG,Bengela,Benguela,Benguella,Sao Felipe de Benguela,São Félipe de Benguela,ben ji la,Бенгела,本吉拉', -12.5762600, 13.4054700, 'AO', '2011-10-28', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1061, 'Chela', 'Chela', '', -12.3026100, 15.4335800, 'AO', '2014-08-15', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1062, 'Chinjenje', 'Chinjenje', '', -12.9324400, 14.9923800, 'AO', '2014-08-16', 7);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1063, 'McMurdo Station', 'McMurdo Station', 'Base McMurdo,Base antarctique McMurdo,Estacao McMurdo,Estacio McMurdo,Estació McMurdo,Estação McMurdo,Mak-Merdo,Makmerdo,McMurdo,McMurdo Statschoon,McMurdo basea,McMurdo-Station,McMurdo-stasjonen,Polarni stanice McMurdo,Polusa stacio McMurdo,Polární stanice McMurdo,Station McMurdo,Stazione McMurdo,maegmeodo giji,mai ke mo duo zhan,makumado ji de,thnt mq-mrdw,Мак-Мердо,Макмөрдо,תחנת מק-מרדו,قاعدة ماك موردو,マクマード基地,麥克默多站,맥머도 기지', -77.8460000, 166.6760000, 'AQ', '2012-07-11', 9);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1064, 'Zárate', 'Zarate', 'General J.F. Uriburu,General Jose F. Uriburu,General José F. Uriburu,General Uriburu,Sarate,Saratė,Zarate,Zárate,sa la te,srath,zaraty  bwyns ayrs,Зарате,زاراتي، بوينس آيرس,سراته,სარატე,萨拉特', -34.0981400, -59.0285800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1065, 'Yataity Calle', 'Yataity Calle', 'Yataity Calle,Yatayti Calle,Yataytí Calle', -29.0191300, -58.9084600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1066, 'Yapeyú', 'Yapeyu', 'San Martin,Yapeyu,Yapeyú', -29.4691400, -56.8184100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1067, 'Villa Paranacito', 'Villa Paranacito', 'Paranacito,Villa Paranacito', -33.7220700, -58.6579800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1068, 'Villa Ortúzar', 'Villa Ortuzar', 'Villa Ortuzar,Villa Ortúzar', -34.5797300, -58.4682900, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1069, 'Villa Ocampo', 'Villa Ocampo', 'Ocampo,Villa Ocampo', -28.4875200, -59.3551500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1070, 'Villa María Grande', 'Villa Maria Grande', 'Maria Grande,María Grande,Villa Maria Grande,Villa María Grande', -31.6656500, -59.9018200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1071, 'Villa Mantero', 'Villa Mantero', 'Mantero,Villa Mantero', -32.3972700, -58.7459600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1072, 'Villa Lugano', 'Villa Lugano', 'Vilja Luganas,Villa Lugano,ビジャ・ルガーノ', -34.6790700, -58.4726300, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1073, 'Villa Hernandarias', 'Villa Hernandarias', 'Hernandarias,Villa Hernandarias', -31.2310100, -59.9850000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1074, 'Villaguay', 'Villaguay', 'Villaguay', -31.8653000, -59.0268900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1075, 'Villa Gesell', 'Villa Gesell', 'VLG,Vil''ja-Khesel'',Вилья-Хесель', -37.2639400, -56.9730400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1076, 'Villa Escolar', 'Villa Escolar', 'Villa Escobar Navegacion Rio Bermejo,Villa Escobar Navegación Río Bermejo,Villa Escolar', -26.6220900, -58.6713400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1077, 'Villa Elisa', 'Villa Elisa', 'Villa Elisa', -32.1632000, -58.4008200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1078, 'Villa del Rosario', 'Villa del Rosario', 'Villa Rosario,Villa del Rosario', -30.7956700, -57.9125700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1079, 'Verónica', 'Veronica', 'Veronica,Verónica', -35.3879600, -57.3369100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1080, 'Veinticinco de Mayo', 'Veinticinco de Mayo', '25 de Mayo,Veinticinco de Mayo', -27.3767900, -54.7431200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1081, 'Urdinarrain', 'Urdinarrain', 'Urdinarrain', -32.6857300, -58.8932300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1082, 'Ubajay', 'Ubajay', 'Ubajay', -31.7935800, -58.3135000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1083, 'Tres Capones', 'Tres Capones', 'Tres Capones', -28.0064100, -55.6047100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1084, 'Tigre', 'Tigre', 'Las Conchas,Tigre,Тигре', -34.4260300, -58.5796200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1085, 'Tandil', 'Tandil', 'TDL,Tandil,Tandil'',Tandilis,tan di er,tandil,tandiru,tandyl,tndyl,Тандил,Тандиль,טנדיל,تانديل,تاندیل,ტანდილი,タンディル,坦迪爾,탄딜', -37.3216700, -59.1331600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1086, 'Tacuarendí', 'Tacuarendi', '', -28.4126500, -59.2600000, 'AR', '2016-03-20', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1087, 'Tabossi', 'Tabossi', 'Tabossi,Tobosy', -31.8013500, -59.9347700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1088, 'Suipacha', 'Suipacha', 'Suipacha', -34.7702000, -59.6878300, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1089, 'Sauce de Luna', 'Sauce de Luna', 'Sauce de Luna', -31.2379400, -59.2187200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1090, 'Sauce', 'Sauce', 'Sauce', -30.0867100, -58.7877700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1091, 'San Vicente', 'San Vicente', 'San Vicente', -35.0250000, -58.4227600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1092, 'San Vicente', 'San Vicente', '', -26.6166700, -54.1333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1093, 'Santo Tomé', 'Santo Tome', 'Santo Tome,Santo Tomé', -28.5493900, -56.0407700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1094, 'Santo Pipó', 'Santo Pipo', 'Colonia Santo Pipo,Colonia Santo Pipó,San Pipo,Santo Pipo,Santo Pipó', -27.1413200, -55.4086700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1095, 'Santa Rosa', 'Santa Rosa', 'Colonia Santa Rosa,Colonia Tabay,Santa Rosa,Santa-Rosa,Санта-Роса', -28.2631800, -58.1189100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1096, 'Santa María', 'Santa Maria', 'Colonia Santa Maria,Colonia Santa María,Hubbart,Santa Maria,Santa María', -27.9035700, -55.3854100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1097, 'Santa Lucía', 'Santa Lucia', 'Santa Lucia,Santa Lucía', -28.9874600, -59.1028700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1098, 'Santa Elena', 'Santa Elena', 'Santa Elena', -30.9476800, -59.7869600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1099, 'Santa Anita', 'Santa Anita', 'Aldea Santa Anita,Santa Anita', -32.1747600, -58.7862200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1100, 'Santa Ana', 'Santa Ana', 'Santa Ana', -30.9000400, -57.9316200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1101, 'Santa Ana', 'Santa Ana', 'Sant'' Ana,Santa Ana,Sant’ Ana', -27.3674000, -55.5809100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1102, 'San Salvador', 'San Salvador', 'San Salvador,sheng sa er wa duo,聖薩爾瓦多', -31.6248700, -58.5052400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1103, 'San Roque', 'San Roque', 'San Roque', -28.5745700, -58.7081700, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1104, 'San Pedro', 'San Pedro', 'San Pedro', -33.6791300, -59.6666300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1105, 'San Pedro', 'San Pedro', 'San Pedro', -26.6220700, -54.1084200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1106, 'San Miguel del Monte', 'San Miguel del Monte', 'San M. del Monte,San Miguel de Monte,San Miguel del Monte', -35.4396200, -58.8067500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1107, 'San Miguel', 'San Miguel', 'San Miguel', -27.9958500, -57.5896400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1108, 'San Luis del Palmar', 'San Luis del Palmar', 'San Luis del Palmar', -27.5079000, -58.5545400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1109, 'San Lorenzo', 'San Lorenzo', '', -28.1330600, -58.7673300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1110, 'San Justo', 'San Justo', 'San Justo', -34.6766000, -58.5605800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1111, 'San Justo', 'San Justo', 'San Justo,Villa San Justo', -32.4465400, -58.4356900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1112, 'San José de Feliciano', 'San Jose de Feliciano', 'San Jose de Feliciano,San José de Feliciano', -30.3845200, -58.7516700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1113, 'San José', 'San Jose', 'San Jose,San José', -27.7697900, -55.7826000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1114, 'San Javier', 'San Javier', 'San Javier', -30.5778100, -59.9317000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1115, 'San Javier', 'San Javier', 'San Javier', -27.8742700, -55.1350900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1116, 'San Isidro', 'San Isidro', 'San Isidro,san aysydrw,sheng yi xi de luo,Сан Исидро,سان إيسيدرو,سان ایسیدرو,圣伊西德罗', -34.4721000, -58.5270800, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1117, 'San Ignacio', 'San Ignacio', 'San Ignacio', -27.2558600, -55.5339000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1118, 'San Gustavo', 'San Gustavo', '', -30.6896100, -59.3984000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1119, 'San Francisco de Laishí', 'San Francisco de Laishi', 'La Mision,La Mision San Francisco de Laishi,La Misión,La Misión San Francisco de Laishi,Mision San Francisco de Laishi,Misión San Francisco de Laishi,San Francisco de Laishi,San Francisco de Laishí', -26.2426200, -58.6303900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1120, 'San Cosme', 'San Cosme', '', -27.3712300, -58.5121400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1121, 'San Clemente del Tuyú', 'San Clemente del Tuyu', 'Balneario San Clemente,Balneario San Clemente del Tuyu,Balneario San Clemente del Tuyú,San Clemente del Tuyu,San Clemente del Tuyú,San-Klemente-del''-Tuju,Сан-Клементе-дель-Тую', -36.3569400, -56.7235100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1122, 'San Cayetano', 'San Cayetano', 'San Cayetano', -38.3465300, -59.6095400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1123, 'San Carlos', 'San Carlos', '', -27.7458600, -55.8973100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1124, 'San Antonio de Areco', 'San Antonio de Areco', 'San A. de Areco,San Antonio de Areco', -34.2503000, -59.4716300, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1125, 'San Andrés de Giles', 'San Andres de Giles', 'San A. de Giles,San Andres de Giles,San Andrés de Giles', -34.4472100, -59.4445100, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1126, 'Saladillo', 'Saladillo', 'Saladillo', -35.6370800, -59.7778800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1127, 'Saladas', 'Saladas', 'Saladas', -28.2538400, -58.6259100, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1128, 'Ruiz de Montoya', 'Ruiz de Montoya', 'Ruiz de Montoya', -26.9833300, -55.0500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1129, 'Rosario del Tala', 'Rosario del Tala', 'Rosario Tala,Rosario de Tala,Rosario del Tala,Tala,luo sa li ao de er ta la,羅薩里奧德爾塔拉', -32.3028600, -59.1454500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1130, 'Roque Pérez', 'Roque Perez', 'R. Perez,R. Pérez,Roque Perez,Roque Pérez', -35.3979400, -59.3327100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1131, 'Riachuelo', 'Riachuelo', '', -27.5775400, -58.7394500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1132, 'Riacho Eh-Eh', 'Riacho Eh-Eh', 'Riacho Eh-Eh,Riacho He He', -25.3620900, -58.2775000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1133, 'Retiro', 'Retiro', 'Retiras,Retiro,lei di luo,retiro,Ретиро,Ретіро,レティーロ,雷蒂罗', -34.5833300, -58.3833300, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1134, 'Resistencia', 'Resistencia', 'Ciudad de Resistencia,RES,Resistancia,Resistencia,Resistenseje,Resistensia,Resistensija,Resistensėjė,Resistentia,Resistência,lei xi si teng xi ya,lesiseutensia,re si s ten seiy,reshisutenshia,rsystnsyh,rysystyna,rysystynsya,rzystnsya,rzystnsya  chakw,Ресистенсия,Ресистенсија,Ресістенсія,Ռեսիստենսիա,רסיסטנסיה,رزیستنسیا,رزیستنسیا، چاکو,ريسيستينسيا,ریسیستینا,เรซิสเตนเซีย,რესისტენსია,レシステンシア,雷西斯滕西亚,레시스텐시아', -27.4605600, -58.9838900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1135, 'Reconquista', 'Reconquista', 'RCQ,Reconquista,Rekonkista,Реконкиста', -29.1500000, -59.6500000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1136, 'Rauch', 'Rauch', 'Rauch', -36.7745000, -59.0897300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1137, 'Ranchos', 'Ranchos', 'General Paz,Ranchos', -35.5161900, -58.3173300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1138, 'Quilmes', 'Quilmes', 'Kil''mes,Kilmes,Kilmesas,Quilmes,ji er mei si,kilmeseu,kirumesu,kwylms,kylms,qylms,Килмес,Кильмес,Кільмес,Կիլմես,קילמס,كويلمس,کیلمس,კილმესი,キルメス,基尔梅斯,킬메스', -34.7290400, -58.2637400, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1139, 'Puerto Yeruá', 'Puerto Yerua', 'Puerto Yerua,Puerto Yeruá,Punta Yerua', -31.5371300, -58.0152700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1140, 'Puerto Vilelas', 'Puerto Vilelas', 'Puerto Vilelas', -27.5141400, -58.9390600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1141, 'Puerto Tirol', 'Puerto Tirol', 'Puerto Tirol', -27.3721800, -59.0820600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1142, 'Puerto Rico', 'Puerto Rico', 'Libertador General San Martin,Libertador General San Martín,Puerto Libertador General San Martin,Puerto Libertador General San Martín,Puerto Rico,Puerto San Alberto', -26.7959800, -55.0240200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1143, 'Puerto Piray', 'Puerto Piray', 'Puerto Piray', -26.4677900, -54.7147600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1144, 'Puerto Libertad', 'Puerto Libertad', 'Puerto Libertad', -25.9164100, -54.6208900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1145, 'Puerto Leoni', 'Puerto Leoni', 'Leoni,Puerto Leoni', -26.9606900, -55.1657000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1146, 'Puerto Iguazú', 'Puerto Iguazu', 'Eva Peron,Eva Perón,IGR,Iguassu,Iguazu,Iguazú,Puehrto-Iguasu,Puerto Aguirre,Puerto Iguasu,Puerto Iguazu,Puerto Iguazú,Puerto Igvasu,Puerto-Iguasu,bwyrtw jwasyw,pueleutoigwasu,pwrtw ywasw,yi gua su gang,Пуерто-Іґуасу,Пуэрто-Игуасу,Պուերտո Իգուասու,פוארטו איגואסו,بويرتو جواسيو,پورتو یواسو,پوێرتۆ ئیگواسوو,プエルト・イグアス,伊瓜蘇港,푸에르토이과수', -25.5991200, -54.5735500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1147, 'Puerto Ibicuy', 'Puerto Ibicuy', 'Puerto Ibicuy,Punta Ibicuy', -33.7333300, -59.1833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1148, 'Puerto Esperanza', 'Puerto Esperanza', 'Esperanza,Puerto Esperanza', -26.0151700, -54.6730600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1149, 'Puerto Eldorado', 'Puerto Eldorado', 'Eldorado,Puerto Eldorado', -26.4084300, -54.6946300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1150, 'Puerto Bermejo', 'Puerto Bermejo', 'Bermejo,Puerto Bermejo', -26.9317300, -58.5053800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1151, 'Pueblo Libertador', 'Pueblo Libertador', 'Colonia Bahia de Astrada,Colonia Bahía de Astrada,Colonia Beron de Astrada,Colonia Berón de Astrada,Pueblo Libertador', -30.2208700, -59.3898100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1152, 'Pronunciamiento', 'Pronunciamiento', 'Pronunciamiento', -32.3461700, -58.4328700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1153, 'Presidencia Roca', 'Presidencia Roca', 'Presidencia Roca,Presidente Roca', -26.1409000, -59.5954100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1154, 'Presidencia de la Plaza', 'Presidencia de la Plaza', 'Presidencia de la Plaza,Presidente de la Plaza,Puerto de la Plaza', -27.0014700, -59.8424300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1155, 'Posadas', 'Posadas', 'PSS,Posadas,Posadasa,Posadasas,bo sa da si,bwsadas  mysywnys,pasadas  mysywns,posadaseu,posadasu,pwsadas,Посадас,Պոսադաս,פוסאדאס,بوساداس، ميسيونيس,پاساداس، میسیونس,پوساداس,პოსადასი,ポサーダス,波萨达斯,포사다스', -27.3670800, -55.8960800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1156, 'Pontevedra', 'Pontevedra', 'Pontevedra,bwntyfydra,peng te wei de la,بونتيفيدرا,پونته‌ودرا,蓬特韋德拉', -34.7478500, -58.7007200, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1157, 'Pirané', 'Pirane', 'Pirane,Pirané', -25.7323900, -59.1087900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1158, 'Pinamar', 'Pinamar', 'Balneario Pinamar,Pinamar,QPQ', -37.1079500, -56.8614000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1159, 'Pilar', 'Pilar', 'Pilar', -34.4586600, -58.9142000, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1160, 'Pila', 'Pila', 'Pila', -36.0005800, -58.1439100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1161, 'Piedras Blancas', 'Piedras Blancas', '', -31.1862300, -59.9595700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1162, 'Picada Gobernador López', 'Picada Gobernador Lopez', 'Gobernador Lopez,Gobernador López,Picada Gobernador Lopez,Picada Gobernador López,Picada Lopez,Picada López', -27.6706900, -55.2458500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1163, 'Perugorría', 'Perugorria', 'Perrugorria,Perrugorría,Perugorria,Perugorría,Perugurria', -29.3413200, -58.6105900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1164, 'Pedro R. Fernández', 'Pedro R. Fernandez', 'Manuel F. Mantilla,Morro Furo Mantilla,Pedro R. Fernandez,Pedro R. Fernández,San Diego', -28.7509700, -58.6558300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1165, 'Paso de los Libres', 'Paso de los Libres', 'AOL,Paso de los Libres', -29.7125100, -57.0877100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1166, 'Paso de la Patria', 'Paso de la Patria', '', -27.3167600, -58.5719700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1167, 'Panambí', 'Panambi', 'Panambi,Panambí,Puerto Panambi', -27.7236900, -54.9151500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1168, 'Pampa del Indio', 'Pampa del Indio', 'Pampa del Indio', -26.0646800, -59.9189800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1169, 'Pampa Almirón', 'Pampa Almiron', 'Pampa Almiron,Pampa Almirón', -26.7000000, -59.1333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1170, 'Palo Santo', 'Palo Santo', '', -25.5633200, -59.3378100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1171, 'Palmar Grande', 'Palmar Grande', '', -27.9419500, -57.9005700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1172, 'Olivos', 'Olivos', 'Olivos,QLV,ao li wo si,awlyfws  bwyns ayrs,awlywws,olivosi,Оливос,Олівос,اوليفوس، بوينس آيرس,اولیووس,ოლივოსი,奧利沃斯', -34.5074700, -58.4870300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1173, 'Oberá', 'Obera', 'Obera,Oberá,Yerbal Viejo,ao wei la,awbra,awbyra,Обера,אוברה,اوبرا,اوبيرا,奧韋拉', -27.4870600, -55.1199400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1174, 'Nueve de Julio', 'Nueve de Julio', '9 de Julio,Nueve de Julio', -28.8405100, -58.8265000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1175, 'Nuestra Señora del Rosario de Caa Catí', 'Nuestra Senora del Rosario de Caa Cati', 'Caa Cati,Caa Catí,General Paz,Nuestra Senora del Rosario de Caa Cati,Nuestra Señora del Rosario de Caa Catí', -27.7507200, -57.6207300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1176, 'Nogoyá', 'Nogoya', 'Nogoya,Nogoyá,nuo ge ya,諾戈亞', -32.3938700, -59.7895300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1177, 'Necochea', 'Necochea', 'NEC,Necochea,Nekoceja,Nekočėja,nei ke qie a,nkwchya,nykwtshya,نيكوتشيا,نکوچئا,ნეკოჩეა,內科切阿', -38.5545000, -58.7396100, 'AR', '2016-01-27', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1178, 'Navarro', 'Navarro', 'Navarro', -35.0055900, -59.2769900, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1179, 'Morón', 'Moron', '6 de Septiembre,Moron,Morón,Seis de Septiembre,mo long,molon,moron,moroni,mwrwn,mwrwn  bwyns ayrs,Морон,مورون,مورون، بوينس آيرس,მორონი,モロン,莫龙,모론', -34.6509000, -58.6195600, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1180, 'Monte Caseros', 'Monte Caseros', 'MCS,Monte Caseros,Monte Kaserosas,meng te ka sai luo si,蒙特卡塞羅斯', -30.2535900, -57.6362600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1181, 'Montecarlo', 'Montecarlo', 'Montecarlo,Puerto Montecarlo', -26.5662000, -54.7570000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1182, 'Mojón Grande', 'Mojon Grande', 'Mojon Grande,Mojón Grande', -27.7116500, -55.1563100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1183, 'Mocoretá', 'Mocoreta', '', -30.6189100, -57.9634400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1184, 'Miramar', 'Miramar', 'MJR,Miramar', -38.2716100, -57.8389000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1185, 'Merlo', 'Merlo', 'Merlo,mei luo,meleullo,meruro,mrlw,myrlw  bwyns ayrs,Мерло,Մերլո,مرلو,ميرلو، بوينس آيرس,メルロ,梅洛,메를로', -34.6662700, -58.7292700, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1186, 'Mercedes', 'Mercedes', 'Mercedes,Mercedo,Mersedes,Mersedesas,mei sai de si,mrsds  bwynws ayrs,Мерседес,مرسدس، بوئنوس آیرس,مرسيدس، مقاطعة بوينس آيرس,梅塞德斯', -34.6514500, -59.4306800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1187, 'Mercedes', 'Mercedes', 'MDX,Mercedes,Mersedes,Mersedesas,mei er sai de si,mrsds,Мерседес,مرسدس,梅爾塞德斯', -29.1841600, -58.0751900, 'AR', '2015-06-15', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1188, 'Mburucuyá', 'Mburucuya', 'Mburucuya,Mburucuyá', -28.0453200, -58.2283500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1189, 'Mártires', 'Martires', 'Martires,Mártires', -27.4333300, -55.3833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1190, 'Mariano I. Loza', 'Mariano I. Loza', 'Justino Solari,Mariano I. Loza,Solari', -29.3766700, -58.1943600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1191, 'Margarita Belén', 'Margarita Belen', 'M. Belen,M. Belén,Margarita BeTen,Margarita BeTén,Margarita Belen,Margarita Belén', -27.2616000, -58.9721900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1192, 'Mar del Tuyú', 'Mar del Tuyu', 'Mar del Tuyu,Mar del Tuyú', -36.5753100, -56.6888300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1193, 'Mar del Plata', 'Mar del Plata', 'Gorad Mar-dehl''-Plata,MDQ,Mar Del Plat,Mar de Plata,Mar del Plata,Mar ntel Plata,Mar-del''-Plata,Mar-del''-Platae,Mar-del-Plata,Mar-del-plata,ma de pu la ta,maleudelpeullata,mar del pla ta,mar dl plata,mara dela plata,maryh dyl blata,Μαρ ντελ Πλάτα,Горад Мар-дэль-Плата,Мар дел Плата,Мар-дель-Платæ,Мар-дель-Плата,Մար-դել-Պլատա,מאר דל פלאטה,مار دل پلاتا,ماريه ديل بلاتا,মার ডেল প্লাটা,มาร์เดลปลาตา,მარ-დელ-პლატა,マル・デル・プラタ,马德普拉塔,마르델플라타', -38.0022800, -57.5575400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1194, 'Marcos Paz', 'Marcos Paz', 'M. Paz,Marcos Paz,Markos-Pas,markws baz,Маркос-Пас,ماركوس باز', -34.7806300, -58.8379000, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1195, 'Malabrigo', 'Malabrigo', 'Colonia Ella,Malabrigo', -29.3463600, -59.9695700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1196, 'Makallé', 'Makalle', 'Makalle,Makallé', -27.2068700, -59.2869600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1197, 'Maipú', 'Maipu', 'Maipu,Maipú', -36.8627400, -57.8809400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1198, 'Magdalena', 'Magdalena', 'Magdalena', -35.0806500, -57.5130100, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1199, 'Maciá', 'Macia', 'Macia,Maciá', -32.1722000, -59.3994700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1200, 'Luján', 'Lujan', 'Lujan,Luján,Lukhan,Luxan,lu han,lukhani,lwkhan,Лухан,Լուխան,لوخان,لوخان، مقاطعة بوينس آيرس,ლუხანი,盧漢', -34.5702800, -59.1050000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1201, 'Lucas González', 'Lucas Gonzalez', 'L. Gonzalez,L. González,Lucas Gonzalez,Lucas González', -32.3843000, -59.5301300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1202, 'Los Helechos', 'Los Helechos', 'Los Helechos', -27.5576000, -55.0768300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1203, 'Los Conquistadores', 'Los Conquistadores', '', -30.5908000, -58.4677300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1204, 'Los Charrúas', 'Los Charruas', 'Los Charruas,Los Charrúas', -31.1754800, -58.1877400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1205, 'Loreto', 'Loreto', '', -27.7683400, -57.2753100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1206, 'Loreto', 'Loreto', 'Loreto', -27.3363500, -55.5222500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1207, 'Lomas de Zamora', 'Lomas de Zamora', 'L. de Zamora,Lomas de Zamora', -34.7608800, -58.4063200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1208, 'Lomas de Vallejos', 'Lomas de Vallejos', '', -27.7350100, -57.9185000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1209, 'Lobos', 'Lobos', 'Lobos,lwbws,لوبوس', -35.1828600, -59.0897500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1210, 'Lobería', 'Loberia', 'Loberia,Lobería', -38.1557400, -58.7913000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1211, 'Libertad', 'Libertad', 'Colonia Libertad,Libertad', -30.0430000, -57.8202000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1212, 'Leandro N. Alem', 'Leandro N. Alem', 'L.H. Alem Leandro,Leandro N. Alem', -27.6034100, -55.3249100, 'AR', '2016-01-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1213, 'La Verde', 'La Verde', 'La Verde', -27.1263400, -59.3735200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1214, 'Las Toscas', 'Las Toscas', 'Las Tocas,Las Toscas', -28.3529000, -59.2579500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1215, 'Las Garcitas', 'Las Garcitas', 'Colonia Las Garcitas,Las Garcitas', -26.5833300, -59.8000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1216, 'Las Flores', 'Las Flores', 'Las Flores', -36.0140300, -59.0998400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1217, 'Larroque', 'Larroque', 'Larrogue,Larroque,Villa Larroque', -33.0359500, -59.0012500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1218, 'La Plata', 'La Plata', 'Eva Peron,Eva Perón,Gorad La-Plata,LPG,La Plat,La Plata,La-Plata,La-Plata shaary,La-Platae,Laplata,Urbs Platensis,la plata,la pu la ta,lablata,lap lata,lapeullata,rapurata,Λα Πλάτα,Горад Ла-Плата,Ла Плата,Ла-Платæ,Ла-Плата,Ла-Плата шаары,לא פלאטא,לה פלאטה,لا پلاتا,لابلاتا,ला प्लाटा,ला प्लाता,লা প্লাতা,ลาปลาตา,ლა-პლატა,ラプラタ,拉普拉塔,라플라타', -34.9214500, -57.9545300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1219, 'La Paz', 'La Paz', 'La Paz', -30.7448500, -59.6456600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1220, 'Lapachito', 'Lapachito', 'Lapachito', -27.1599700, -59.3860500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1221, 'Lanús', 'Lanus', 'Lanus,Lanusas,Lanús,la nu si,lanuseu,lanusi,lanws,ranusu,Ланус,Լանուս,لانوس,ლანუსი,ラヌース,拉努斯,라누스', -34.7025200, -58.3955000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1222, 'La Leonesa', 'La Leonesa', 'La Leonesa', -27.0378600, -58.7034700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1223, 'Laguna Naick-Neck', 'Laguna Naick-Neck', 'Laguna Naick-Neck,Laguna Naineck', -25.2476900, -58.0938300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1224, 'Laguna Limpia', 'Laguna Limpia', 'Laguna Limpia', -26.4956500, -59.6808300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1225, 'La Escondida', 'La Escondida', 'Desvio La Escondida,La Escondida', -27.1072400, -59.4478400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1226, 'La Eduvigis', 'La Eduvigis', 'La Eduvigis', -26.8554500, -59.0684200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1227, 'La Cruz', 'La Cruz', 'La Cruz', -29.1744300, -56.6432600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1228, 'La Criolla', 'La Criolla', '', -31.2690400, -58.1055800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1229, 'Juan Pujol', 'Juan Pujol', '', -30.4187300, -57.8561200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1230, 'Jardín América', 'Jardin America', 'Chardin Amerika,jrdyn amyrka,جردین امیرکا', -27.0434600, -55.2269800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1231, 'Ituzaingó', 'Ituzaingo', 'Ituzaingo,Ituzaingó,aytwsayngw,yi tu sa yin ge,ایتوساینگو,იტუსაინგო,伊圖薩因戈', -34.6580300, -58.6631700, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1232, 'Ituzaingó', 'Ituzaingo', 'Ituzaingo,Ituzaingó', -27.5816200, -56.6823100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1233, 'Itatí', 'Itati', 'Itati,Itatí', -27.2704300, -58.2445800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1234, 'Itá Ibaté', 'Ita Ibate', 'Ita Ibate,Italbate,Ite-Ibata,Itá Ibaté,Ité-Ibata', -27.4257300, -57.3375800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1235, 'Ibarreta', 'Ibarreta', 'Ibarreta', -25.2143800, -59.8585100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1236, 'Hurlingham', 'Hurlingham', '28 de Septiembre,Hurlingham', -34.5916800, -58.6460800, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1237, 'Herrera', 'Herrera', 'Herrera,Villa San Miguel', -32.4351600, -58.6246200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1238, 'Herradura', 'Herradura', 'Colonia Herradura,Herradura', -26.4870500, -58.3119800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1239, 'Herlitzka', 'Herlitzka', '', -27.5651600, -58.2555700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1240, 'Hasenkamp', 'Hasenkamp', 'Hasenkamp', -31.5122600, -59.8354500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1241, 'Guaraní', 'Guarani', 'Guarani,Guaraní,Pueblo Guarani,Pueblo Guaraní', -27.5166700, -55.1666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1242, 'Gualeguaychú', 'Gualeguaychu', 'GHU,Gualeguaicu,Gualeguaiču,Gualeguajchu,Gualeguaychu,Gualeguaychú,gua lai gua yi qiu,gualeguaichu,gwalgwaychw,jywlyjyashw  antry ryws,Гуалегуайчу,גואלגואיצו,جيوليجياشو، انتري ريوس,گوالگوایچو,გუალეგუაიჩუ,瓜萊瓜伊丘', -33.0093700, -58.5172200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1243, 'Gualeguay', 'Gualeguay', 'Gualeguajus,Gualeguay,gua lai gua yi,gwalgway,גואלגואי,گوالگوای,瓜萊瓜伊', -33.1415600, -59.3096600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1244, 'Goya', 'Goya', 'Goja,Gojja,Goya,OYA,Гойя', -29.1439500, -59.2651000, 'AR', '2015-06-24', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1245, 'Gobernador Roca', 'Gobernador Roca', 'Colonia Corpus,Gobernador Roca', -27.1863600, -55.4643300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1246, 'Gobernador Mansilla', 'Gobernador Mansilla', 'Gobernador Mansilla,Mansilla', -32.5445300, -59.3548000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1247, 'Gobernador Juan E. Martínez', 'Gobernador Juan E. Martinez', 'Gobernador J.F. Martinez,Gobernador J.F. Martínez,Gobernador Juan E. Martinez,Gobernador Juan E. Martínez,Gobernador Martinez,Gobernador Martínez,Golfo Martinez,Yatay', -28.9170500, -58.9329200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1248, 'Gobernador Ingeniero Valentín Virasoro', 'Gobernador Ingeniero Valentin Virasoro', 'Gobernador Ingeniero Valentin Virasoro,Gobernador Ingeniero Valentín Virasoro,Vuelta del Ombu,Vuelta del Ombú', -28.0500000, -56.0333300, 'AR', '2016-02-02', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1249, 'General Vedia', 'General Vedia', 'General Vedia,General Verde', -26.9338200, -58.6604000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1250, 'General San Martín', 'General San Martin', 'General San Martin,General San Martín,San Martin,San Martín', -34.5742400, -58.5349600, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1251, 'General Rodríguez', 'General Rodriguez', 'General Rodriguez,General Rodríguez', -34.6083800, -58.9525300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1252, 'General Lavalle', 'General Lavalle', 'Ajo,Ajó,General Lavalle,Lavalle', -36.4063300, -56.9432900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1253, 'General Las Heras', 'General Las Heras', 'General Las Heras', -34.9272600, -58.9462100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1254, 'General Juan Madariaga', 'General Juan Madariaga', 'General J. Madariaga,General Juan Madariaga,General Madariaga', -36.9972500, -57.1395100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1255, 'General José de San Martín', 'General Jose de San Martin', 'Cheneral Chose de San Martinas,Colonia Zapallar,El Zapallar,General Jose de San Martin,General José de San Martín,General San Martin,General San Martín,Zapallar,aljnral khwsyh dy san martyn,sheng ma ding jiang jun zhen,الجنرال خوسيه دي سان مارتين,聖馬丁將軍鎮', -26.5374300, -59.3415800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1256, 'General Guido', 'General Guido', 'General Guido,Guido', -36.6407400, -57.7917400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1257, 'General Galarza', 'General Galarza', 'Galarza,General Galarza', -32.7203400, -59.3961500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1258, 'General Conesa', 'General Conesa', 'General Conesa', -36.5201300, -57.3253700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1259, 'General Campos', 'General Campos', 'Campos,Colonia General Campos,General Campos', -31.5231100, -58.4049000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1260, 'General Belgrano', 'General Belgrano', 'General Belgrano', -35.7695200, -58.4934100, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1261, 'General Alvear', 'General Alvear', 'General Alvear', -27.4333300, -55.1666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1262, 'Garupá', 'Garupa', 'Garupa,Garupá', -27.4817100, -55.8292100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1263, 'Garuhapé', 'Garuhape', 'Garuape,Garuapé,Garuhape,Garuhapé', -26.8176800, -54.9566500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1264, 'Garruchos', 'Garruchos', '', -28.1851400, -55.6394700, 'AR', '2011-04-19', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1265, 'Formosa', 'Formosa', 'Ciudad de Formosa,FMA,Formosa,Formoza,farmwsa,forumosa,fu mo sa,fwrmwza,poleumosa,pormosa,pwrmwsh,Формоза,Формоса,Ֆորմոսա,פורמוסה,فارموسا,فورموزا,فورموسا، ارجنٹائن,ფორმოსა,フォルモーサ,福莫萨,포르모사', -26.1775300, -58.1781400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1266, 'Fontana', 'Fontana', 'Fontana', -27.4181300, -59.0239200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1267, 'Florentino Ameghino', 'Florentino Ameghino', 'Florentino Ameghino', -27.5666700, -55.1333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1268, 'Florencio Varela', 'Florencio Varela', 'F. Varela,Florencio Varela', -34.8272200, -58.3955600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1269, 'Felipe Yofré', 'Felipe Yofre', 'Felipe Yofre,Felipe Yofré,Yofre,Yofré', -29.1022600, -58.3377200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1270, 'Federal', 'Federal', 'Federal,Villa Federal', -30.9546500, -58.7832600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1271, 'Federación', 'Federacion', 'Federacion,Federación', -31.0062100, -57.8996200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1272, 'José María Ezeiza', 'Jose Maria Ezeiza', 'Ezeiza,Jose Maria Ezeiza,José María Ezeiza,Ministro Pistarini,ai sai sa,asysa,ayzyza,Езеиза,إيزيزا,اسیسا,埃塞薩', -34.8478700, -58.5286900, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1273, 'Esquina', 'Esquina', 'Esquina', -30.0144400, -59.5271900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1274, 'Espinillo', 'Espinillo', '', -24.9813200, -58.5521000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1275, 'Ensenada', 'Ensenada', 'Ensenada', -34.8618600, -57.9112600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1276, 'Empedrado', 'Empedrado', 'Empedrado', -27.9512500, -58.8054200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1277, 'El Soberbio', 'El Soberbio', 'El Soberbio', -27.2984700, -54.1987700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1278, 'Eldorado', 'Eldorado', 'ELO,Eldorado', -26.4048400, -54.6247800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1279, 'El Colorado', 'El Colorado', 'El Colorado', -26.3080800, -59.3729100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1280, 'El Alcázar', 'El Alcazar', 'El Alcazar,El Alcázar', -26.7145900, -54.8152300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1281, 'Dos de Mayo', 'Dos de Mayo', '2 de Mayo,Dos de Mayo', -27.0227700, -54.6866900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1282, 'Dos Arroyos', 'Dos Arroyos', 'Dos Arroyos', -27.7078400, -55.2336400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1283, 'Domínguez', 'Dominguez', 'Colonia Clara,Dominguez,Domínguez,Villa Dominguez,Villa Domínguez', -31.9871000, -58.9619700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1284, 'Dolores', 'Dolores', 'Dolores', -36.3132100, -57.6791800, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1285, 'Curuzú Cuatiá', 'Curuzu Cuatia', 'Curuzu Cuatia,Curuzú Cuatiá,Kurusu Kuatia,Kurusu Kvatija,UZU,ku lu su kua di ya,kwrwsw kwatya,کوروسو کواتیا,庫魯蘇夸蒂亞', -29.7917100, -58.0546000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1286, 'Cruz de los Milagros', 'Cruz de los Milagros', '', -28.8364600, -59.0047600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1287, 'Coté-Lai', 'Cote-Lai', '', -27.5000000, -59.6000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1288, 'Corrientes', 'Corrientes', 'CNQ,Ciudad de Corrientes,Corrientes,Gorad Karyentehs,Korientes,Korijentes,Korjentesas,Korrientes,Taragui,ke lian te si,kolienteseu,korientesu,koriyentesa,kwrynts,kwryynts,qwryynts,Горад Карыентэс,Кориентес,Коријентес,Корриентес,Коррієнтес,קוריינטס,كورينتس,کوریئنتس,کورینتس,कोरियेन्टेस,კორიენტესი,コリエンテス,科连特斯,코리엔테스', -27.4806000, -58.8341000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1289, 'Coronel Vidal', 'Coronel Vidal', 'Coronel Vidal', -37.4460400, -57.7286500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1290, 'Conscripto Bernardi', 'Conscripto Bernardi', 'Conscripto Bernardi,Kilometro 101,Kilómetro 101', -31.0483700, -59.0843500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1291, 'Concordia', 'Concordia', 'COC,Concordia,Konkordia,Konkordija,kang ke di ya,kongkoleudia,konkorudia,kwnkwrdya,kwnkwrdya  antry ryws,qwnqwrdyh,Конкордия,Конкордија,Կոնկորդիա,קונקורדיה,كونكورديا، انتري ريوس,کونکوردیا,コンコルディア,康科迪亚,콩코르디아', -31.3929600, -58.0208900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1292, 'Concepción del Uruguay', 'Concepcion del Uruguay', 'Concepcion del Uruguay,Concepción del Uruguay,Konseps''jon-del''-Urugvaj,Konseps''on-del''-Urugvaj,Konsepsion del Urugvajus,knspsywn dl awrwgway,kwnsbsywn dyl awrwghway,wu la gui he pan kang sai pu xi weng,Консепсьйон-дель-Уругвай,Консепсьон-дель-Уругвай,קונספסיון דל אורוגוואי,كونسبسيون ديل أوروغواي,کنسپسیون دل اوروگوای,კონსეპსიონ-დელ-ურუგვაი,乌拉圭河畔康塞普西翁', -32.4824900, -58.2372200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1293, 'Concepción de la Sierra', 'Concepcion de la Sierra', 'Concepcion de la Sierra,Concepción de la Sierra', -27.9831100, -55.5203100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1294, 'Concepción', 'Concepcion', 'Concepcion,Concepción', -28.3917500, -57.8877700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1295, 'Comandante Fontana', 'Comandante Fontana', 'Comandante Fontana', -25.3345300, -59.6821200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1296, 'Colonia Wanda', 'Colonia Wanda', '', -25.9740800, -54.4280600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1297, 'Colonias Unidas', 'Colonias Unidas', 'Colonia Unidas,Colonias Unidas', -26.6982500, -59.6315400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1298, 'Colonia Elisa', 'Colonia Elisa', 'Colonia Elisa', -26.9304100, -59.5186100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1299, 'Colonia Elía', 'Colonia Elia', '', -32.6662500, -58.3214800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1300, 'Colonia Benítez', 'Colonia Benitez', 'Benitez,Benítez,Colonia Benitez,Colonia Benítez', -27.3309900, -58.9462200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1301, 'Colonia Aurora', 'Colonia Aurora', 'Colonia Aurora', -27.4742800, -54.5249800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1302, 'Colón', 'Colon', 'Colon,Colón', -32.2233700, -58.1434100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1303, 'Colegiales', 'Colegiales', 'Colegiales', -34.5736500, -58.4492400, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1304, 'Clorinda', 'Clorinda', 'CLX,Clorinda,Klorinda,Клоринда', -25.2848100, -57.7185100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1305, 'Ciervo Petiso', 'Ciervo Petiso', 'Ciervo Petiso,Ciervo Petizo', -26.5804100, -59.6309400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1306, 'Chavarría', 'Chavarria', 'Chavarria,Chavarría', -28.9548900, -58.5727700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1307, 'Chascomús', 'Chascomus', 'Chascomus,Chascomús', -35.5729700, -58.0080900, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1308, 'Charadai', 'Charadai', 'Charadai,Charaday', -27.6333300, -59.9000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1309, 'Chajarí', 'Chajari', 'Chajari,Chajarí', -30.7504800, -57.9796200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1310, 'Cerro Corá', 'Cerro Cora', 'Cerro Cora,Cerro Corá,Colonia Cerro Cora,Colonia Cerro Corá', -27.5131000, -55.6089600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1311, 'Cerro Azul', 'Cerro Azul', 'Cerro Azul', -27.6331000, -55.4962000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1312, 'Ceibas', 'Ceibas', 'Ceibas', -33.4333300, -58.7500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1313, 'Castelli', 'Castelli', 'Castelli', -36.0894900, -57.8039300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1314, 'Caseros', 'Caseros', 'Caseros,ka sai luo si,kasrws,kasyrws,كاسيروس,کاسروس,კასეროსი,卡塞羅斯', -34.6033300, -58.5640900, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1315, 'Caseros', 'Caseros', 'Caseros,Colonia Caseros', -32.4632500, -58.4787200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1316, 'Carmen de Areco', 'Carmen de Areco', 'C. de Areco,Carmen de Areco', -34.3774300, -59.8239500, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1317, 'Caraguatay', 'Caraguatay', 'Caraguatay,Puerto Caraguatay', -26.6058700, -54.7809300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1318, 'Capitán Solari', 'Capitan Solari', 'Capitan Solari,Capitán Solari', -26.8021500, -59.5608900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1319, 'Capitán Sarmiento', 'Capitan Sarmiento', 'Capitan Sarmiento,Capitán Sarmiento', -34.1723800, -59.7904800, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1320, 'Capioví', 'Capiovi', 'Capiovi,Capioví', -26.9299800, -55.0608400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1321, 'Capilla del Señor', 'Capilla del Senor', 'Capilla,Capilla del Senor,Capilla del Señor', -34.2920700, -59.1017900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1322, 'Cañuelas', 'Canuelas', 'Canuelas,Cañuelas', -35.0518400, -58.7606100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1323, 'Candelaria', 'Candelaria', 'Candelaria', -27.4595000, -55.7453600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1324, 'Campo Viera', 'Campo Viera', 'Campo Viera', -27.3833300, -55.0333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1325, 'Campo Ramón', 'Campo Ramon', 'Campo Ramon,Campo Ramón', -27.4610800, -55.0190100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1326, 'Campo Grande', 'Campo Grande', 'Campo Grande', -27.2077000, -54.9797700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1327, 'Campana', 'Campana', 'Campana,Kampana,Кампана', -34.1687400, -58.9591400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1328, 'Buenos Aires', 'Buenos Aires', 'BUE,Baires,Bonaero,Bonaeropolis,Bonaëropolis,Bos Aires,Bouenos Aires,Bouonezar,Bouonézâr,Buehnos Ajres,Buehnos-Ajres,Buehnos-Ajres osh,Buenos Aires,Buenos Airės,Buenos Ajres,Buenos Ayres,Buenos-Aires,Buenos-Ajres,Buenos-Ayres,Buenos-Aýres,Buenosairesa,Buénos Ayrés,Bwenoze,Bwènozè,Búenos Aíres,Ciudad Autonoma de Buenos Aires,Ciudad Autónoma de Buenos Aires,Ciudad de La Santisima Trinidad y Puerto de Santa Maria del Buen Ayre,Ciudad de La Santísima Trinidad y Puerto de Santa María del Buen Ayre,Gorad Buehnas-Ajrehs,Lungsod ng Buenos Aires,Santa Maria del Buen Ayre,Santa María del Buen Ayre,bawnosxires,bu yi nuo si ai li si,bu''enosa a''iresa,buenos-airesi,buenosaires,buenoseuaileseu,buenosuairesu,buraenosa a''iresa,buyenosa a''iresa,bwyns ayrs,bwynws ayrs,bwynws ayrys,byu''enosa erisa,byunas airis,byunas ayels,bywns ayrs,puvenas airis,Μπουένος ΄Aιρες,Μπουένος Άιρες,Буенос Аирес,Буенос Айрес,Буенос Аірес,Буенос Ајрес,Буенос-Аирес,Буенос-Айрес,Буэнос Айрес,Буэнос-Айрес,Буэнос-Айрес ош,Горад Буэнас-Айрэс,Բուենոս Այրես,בואנוס איירס,בוענאס איירעס,بوئنوس آیرس,بوينس آيرس,بوينوس ايريس,بۆینس ئایرس,بیونس آئرس,बुएनोस आइरेस,ब्युएनॉस एरीस,বুয়েনোস আইরেস,বুৱেনোস আইরেস,புவெனஸ் ஐரிஸ்,ಬ್ಯೂನಸ್ ಐರಿಸ್,ബ്യൂണസ് അയേഴ്സ്,บัวโนสไอเรส,པུ་ཨེ་ནོ་སི་ཨས་རི་སི།,ဗျူနိုအေးရိစ်မြို့,ბუენოს-აირესი,ብዌኖስ አይሬስ,ブエノスアイレス,布宜諾斯艾利斯,布宜诺斯艾利斯,부에노스아이레스', -34.6131500, -58.3772300, 'AR', '2017-05-28', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1329, 'Brandsen', 'Brandsen', 'Brandsen,Coronel Brandsen', -35.1684200, -58.2342700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1330, 'Bovril', 'Bovril', 'Bovril', -31.3431100, -59.4451200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1331, 'Bonpland', 'Bonpland', 'Bompland,Bonpland', -29.8170800, -57.4297400, 'AR', '2015-06-15', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1332, 'Bonpland', 'Bonpland', '', -27.4821800, -55.4775600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1333, 'Berón de Astrada', 'Beron de Astrada', '', -27.5506700, -57.5346000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1334, 'Bernardo de Irigoyen', 'Bernardo de Irigoyen', 'Barracon,Bernardo de Irigoyen', -26.2552000, -53.6458100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1335, 'Berisso', 'Berisso', 'Berisas,Beriso,Berisso,byrysw,Берисо,Беріссо,بيريسو', -34.8735000, -57.8830300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1336, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez,Juarez,Juárez', -37.6718800, -59.8065300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1337, 'Bella Vista', 'Bella Vista', 'Bella Vista', -28.5091800, -59.0400900, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1338, 'Belén de Escobar', 'Belen de Escobar', 'Belen,Belen de Escobar,Belén,Belén de Escobar,Escobar', -34.3483300, -58.7926500, 'AR', '2016-05-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1339, 'Basail', 'Basail', 'Basail', -27.8666700, -59.3000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1340, 'Barranqueras', 'Barranqueras', 'Barranqueras,ba lan ke la si,barankywras,بارانكيوراس,巴蘭克拉斯', -27.4813200, -58.9392500, 'AR', '2015-06-24', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1341, 'Baradero', 'Baradero', 'Baradero', -33.8110500, -59.5080700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1342, 'Balcarce', 'Balcarce', 'Balcarce,ba er ka sai,balkarsh,balkarsy,بالكارسي,بالکارسه,巴爾卡塞', -37.8461600, -58.2552200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1343, 'Azul', 'Azul', 'Asulis,Azul,a su er,aswl,Азул,آسول,أزول، مقاطعة بوينس آيرس,阿蘇爾', -36.7769800, -59.8585400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1344, 'Azara', 'Azara', 'Azara', -28.0616000, -55.6779700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1345, 'Ayacucho', 'Ayacucho', 'Ayacucho', -37.1518500, -58.4869100, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1346, 'Avellaneda', 'Avellaneda', 'Avellaneda,Estacion Ewald,Estación Ewald', -29.1176100, -59.6583400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1347, 'Arroyo del Medio', 'Arroyo del Medio', 'Arroyo del Medio', -27.7000000, -55.4166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1348, 'Aristóbulo del Valle', 'Aristobulo del Valle', 'Aristobulo del Valle,Aristóbulo del Valle', -27.0962500, -54.8962600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1349, 'Apóstoles', 'Apostoles', 'Apostoles,Apóstoles', -27.9142100, -55.7535500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1350, 'Alvear', 'Alvear', 'Alvear', -29.0968300, -56.5504300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1351, 'Almafuerte', 'Almafuerte', 'Almafuerte', -27.5051800, -55.3949700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1352, 'Aldea San Antonio', 'Aldea San Antonio', 'Aldea San Antonio,San Antonio', -32.6237600, -58.7033300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1353, 'Alba Posse', 'Alba Posse', 'Alba Posse', -27.5697800, -54.6826200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1354, 'Guernica', 'Guernica', 'Guernica', -34.9172200, -58.3869400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1355, 'Villa Basilio Nievas', 'Villa Basilio Nievas', 'Villa Basilio Nievas,Zonda', -31.5500000, -68.7333300, 'AR', '2015-05-01', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1356, 'Zapala', 'Zapala', 'APZ,Sapala,Zapala,sa pa la,sapala,Сапала,Սապալա,ساپالا,薩帕拉', -38.8991600, -70.0544200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1357, 'Yuto', 'Yuto', '', -23.6434200, -64.4719400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1358, 'Yerba Buena', 'Yerba Buena', 'Yerba Buena', -26.8166700, -65.3166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1359, 'Yacimiento Río Turbio', 'Yacimiento Rio Turbio', 'Rio Turbio,Río Turbio,Yacimiento Rio Turbio,Yacimiento Río Turbio,Yacimientos de Rio Turbio,Yacimientos de Río Turbio', -51.5732100, -72.3508000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1360, 'Winifreda', 'Winifreda', 'Winifreda', -36.2264300, -64.2338800, 'AR', '2016-02-02', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1361, 'Wenceslao Escalante', 'Wenceslao Escalante', 'Escalante,Medanos de las Canas,Médanos de las Cañas,Wenceslao Escalante', -33.1730300, -62.7707800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1362, 'Vista Alegre', 'Vista Alegre', 'Colonia Vista Alegre,Vista Alegre', -38.7500000, -68.1833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1363, 'Vinchina', 'Vinchina', '', -28.7596400, -68.2069200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1364, 'Villa Valeria', 'Villa Valeria', '', -34.3409300, -64.9203000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1365, 'Villa Urquiza', 'Villa Urquiza', 'Villa Urquiza', -31.6473100, -60.3748000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1366, 'Villa Unión', 'Villa Union', 'Union,Unión,Villa Union,Villa Unión', -29.4134700, -62.7882200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1367, 'Villa Unión', 'Villa Union', 'Villa Union,Villa Unión', -29.3159500, -68.2265800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1368, 'Villa Tulumba', 'Villa Tulumba', 'Tulumba,Villa Tulumba', -30.3955200, -64.1224100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1369, 'Villa Trinidad', 'Villa Trinidad', '', -30.2132900, -61.8759700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1370, 'Villa Santa Rosa', 'Villa Santa Rosa', '', -31.7443400, -68.3141100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1371, 'Villa Rumipal', 'Villa Rumipal', 'Rumipal,Villa Rumipal', -32.1879000, -64.4802700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1372, 'Villa Regina', 'Villa Regina', 'Villa Regina', -39.1000000, -67.0666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1373, 'Villa Reducción', 'Villa Reduccion', 'Reduccion,Reducción,Villa Reduccion,Villa Reducción', -33.2010500, -63.8623400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1374, 'Villa Paula de Sarmiento', 'Villa Paula de Sarmiento', 'Paula A. de Sarmiento,Villa Paula de Sarmiento', -31.4933000, -68.5383800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1375, 'Villa Ojo de Agua', 'Villa Ojo de Agua', 'Ojo de Agua,Villa Ojo de Agua', -29.5000300, -63.6937700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1376, 'Villa Nueva', 'Villa Nueva', 'Guaymallen,Guaymallén,Villa Nueva,Villa Nueva de Guaymallen,Villa Nueva de Guaymallén', -32.8972200, -68.7803800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1377, 'Villa Nueva', 'Villa Nueva', '', -32.4329300, -63.2476300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1378, 'Villa Media Agua', 'Villa Media Agua', 'Media Agua,Villa Media Agua', -31.9826700, -68.4239400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1379, 'Villa María', 'Villa Maria', 'Vilja Marija,Villa Maria,Villa María,fyla marya,ma li ya zhen,vilia-maria,wyya marya,wyzh mryh,ויזה מריה,فيلا ماريا,وییا ماریا,ვილია-მარია,瑪麗亞鎮', -32.4075100, -63.2401600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1380, 'Villa Las Rosas', 'Villa Las Rosas', 'Las Rosas,Villa Las Rosas,Villa de Las Rosas', -31.9502100, -65.0535400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1381, 'Villa La Angostura', 'Villa La Angostura', 'Vilja La Angostura,Villa La Angostura,Villa la Angostura,la an ge si tu la zhen,ויזה לה אנגוסטורה,拉安戈斯圖拉鎮', -40.7617300, -71.6463100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1382, 'Villa Krause', 'Villa Krause', 'Villa Krause,Villa Krausse', -31.5666700, -68.5333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1383, 'Villa Huidobro', 'Villa Huidobro', 'Canada Verde,Cañada Verde,Villa Huidobro', -34.8382600, -64.5868600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1384, 'Villa Giardino', 'Villa Giardino', 'Villa Giardino', -31.0333300, -64.4833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1385, 'Villa General Roca', 'Villa General Roca', 'General Roca,Villa General Roca', -32.6653500, -66.4505200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1386, 'Villa General Mitre', 'Villa General Mitre', 'General Mitre,Pinto,Villa General Mitre', -29.1431000, -62.6524800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1387, 'Villa General Belgrano', 'Villa General Belgrano', 'Villa General Belgrano', -31.9754200, -64.5559000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1388, 'Villa Dolores', 'Villa Dolores', 'Dolores,VDR,Villa Dolores,duo luo lei si zhen,fyla dwlwrys,فيلا دولوريس,多洛雷斯鎮', -31.9458500, -65.1895800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1389, 'Villa de Soto', 'Villa de Soto', 'Soto,Villa de Soto', -30.8552300, -64.9994700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1390, 'Villa de María', 'Villa de Maria', 'Rio Seco,Río Seco,Villa de Maria,Villa de María', -29.9019500, -63.7228900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1391, 'Villa del Totoral', 'Villa del Totoral', 'Totoral,Villa del Totoral', -30.8166700, -63.7166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1392, 'Villa del Salvador', 'Villa del Salvador', '', -31.4415500, -68.3974500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1393, 'Villa del Rosario', 'Villa del Rosario', 'Villa de Rosario,Villa del Rosario,luo sa li ao zhen,羅薩里奧鎮', -31.5566000, -63.5345200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1394, 'Villa del Dique', 'Villa del Dique', 'Villa Dique,Villa de Dique,Villa del Dique', -32.1766700, -64.4554300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1395, 'Villa Cura Brochero', 'Villa Cura Brochero', 'Transito,Transito de San Alberto,Tránsito de San Alberto,Villa Cura Brochero', -31.7057800, -65.0179600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1396, 'Villa Constitución', 'Villa Constitucion', 'Villa Constitucion,Villa Constitución,kong si di tu xi weng zhen,wyya kwnstytwsywn,وییا کونستیتوسیون,孔斯蒂圖西翁鎮', -33.2277800, -60.3297000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1397, 'Villa Concepción del Tío', 'Villa Concepcion del Tio', 'Concepcion,Concepción,Villa Concepcion,Villa Concepcion del Tio,Villa Concepción,Villa Concepción del Tío', -31.3225900, -62.8135400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1398, 'Chañar Ladeado', 'Chanar Ladeado', 'Chanar Ladeado,Chanar Ladeador,Chañar Ladeado,Chañar Ladeador,Villa Chanar Ladeado,Villa Chañar Ladeado', -33.3252400, -62.0383100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1399, 'Villa Castelli', 'Villa Castelli', 'Villa Castelli', -29.0029500, -68.2127700, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1400, 'Villa Carlos Paz', 'Villa Carlos Paz', 'Karlos-Paz,Vil''ja-Karlos-Pas,Vilja Karlos Pasas,Villa Carlos Paz,Vilya Karlos Pas,fyla karlws baz,ka luo si pa si zhen,wyya karlws pas,Вилья-Карлос-Пас,Карлос-Паз,Վիլյա Կառլոս Պաս,ויזה קרלוס פאס,فيلا كارلوس باز,وییا کارلوس پاس,ვილია-კარლოს-პასი,卡洛斯帕斯鎮', -31.4241400, -64.4977800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1401, 'Villa Cañás', 'Villa Canas', 'Villa Canas,Villa Cañás', -34.0056500, -61.6075700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1402, 'Villa Bustos', 'Villa Bustos', 'Sanagasta,Villa Bustos', -29.2848300, -67.0330800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1403, 'Villa Berthet', 'Villa Berthet', 'Villa Berthet', -27.2917400, -60.4126300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1404, 'Villa Atamisqui', 'Villa Atamisqui', 'Atamisqui,Villa Atamisqui', -28.4960900, -63.8160900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1405, 'Villa Ascasubi', 'Villa Ascasubi', 'Ascasubi,Villa Ascasubi', -32.1635100, -63.8915700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1406, 'Villa Ángela', 'Villa Angela', 'Vilja Anchela,Villa Angela,Villa Ángela,an ji la zhen,wyya ankhla,ויזה אנחלה,وییا آنخلا,安吉拉鎮', -27.5738300, -60.7152600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1407, 'Villa Allende', 'Villa Allende', 'Villa Allende', -31.2945800, -64.2953800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1408, 'Villa Aberastain', 'Villa Aberastain', 'Aberastain,Villa Aberastain', -31.6500000, -68.5833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1409, 'Viedma', 'Viedma', 'V''edma,V''edmae,VDM,Vedma,Viedma,Vjedma,beiyd ma,bie de ma,biedeuma,biedoma,fydma,viedma,wydma,wyydmh,Βιέδμα,Виедма,Вьедмæ,Вьедма,Вєдма,Վիեդմա,ויידמה,فيدما,ویدما,เบียดมา,ვიედმა,ビエドマ,別德馬,비에드마', -40.8134500, -62.9966800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1410, 'Vicuña Mackenna', 'Vicuna Mackenna', 'Mackenna,Vicuna Mackenna,Vicuña Mackenna', -33.9196500, -64.3921500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1411, 'Victorica', 'Victorica', 'Victorica', -36.2150500, -65.4358600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1412, 'Victoria', 'Victoria', 'Viktorija,wei duo li ya,Виктория,وکٹوریہ، انترے ریوس,維多利亞', -32.6184100, -60.1547800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1413, 'Viamonte', 'Viamonte', 'General Viamonte,Viamonte', -33.7464700, -63.0976400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1414, 'Viale', 'Viale', 'Viale', -31.8678200, -60.0072200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1415, 'Vera', 'Vera', 'Jobson,Vera', -29.4593000, -60.2126100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1416, 'Venado Tuerto', 'Venado Tuerto', 'Neuken,Venado Touerto,Venado Tuertas,Venado Tuerto,bei na duo tu ai tuo,fynadw tywrtw,wanadw twrtw,Βενάδο Τουέρτο,Неукен,ונדו טוארטו,فينادو تيورتو,وانادو تورتو,ვენადო-ტუერტო,貝納多圖埃托', -33.7455600, -61.9688500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1417, '28 de Noviembre', '28 de Noviembre', '28 de Noviembre,Veintiocho de Noviembre', -51.5839000, -72.2138200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1418, 'Veinticinco de Mayo', 'Veinticinco de Mayo', '25 de Mayo,Colonia Los Viejos,Colonia Veinticinco de Mayo,Veinticinco de Mayo', -37.7741000, -67.7163800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1419, 'Veinticinco de Mayo', 'Veinticinco de Mayo', '25 de Mayo,Veinticinco de Mayo', -35.4323000, -60.1727100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1420, 'Vedia', 'Vedia', 'Vedia', -34.4955800, -61.5413800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1421, 'Valle Hermoso', 'Valle Hermoso', 'Valle Hermoso', -31.1173200, -64.4808400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1422, 'Valle Grande', 'Valle Grande', '', -23.4773500, -64.9425000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1423, 'Valcheta', 'Valcheta', 'VCF,Valcheta', -40.7000000, -66.1500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1424, 'Ushuaia', 'Ushuaia', 'Gorad Ushuaja,Ousouaia,Owsuaya,USH,Ushuaia,Ushuaja,Ushuaïa,Usuaja,Usuaya,Usvaja,Uşuaya,Ušuaja,Ušvaja,awshwaya,awshwayya,awswaya,ushuaia,usuaia,usuviya,usuya''iya,wu si huai ya,xusaw ya,Ουσουάια,Горад Ушуая,Ушуая,Ушуаја,Ուշուայա,אושואיה,أوشوايا,اوسوایا,اوشوآئیا,উসুয়াইয়া,ಉಶುವಿಯಾ,อูซัวยา,უშუაია,ウシュアイア,乌斯怀亚,우수아이아', -54.8000000, -68.3000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(857, 'Meghrashen', 'Meghrashen', 'Kazanchi,Meghrashen,Megrasen,Megrashen,Меграшен,Մեղրաշեն', 40.6723000, 43.9583100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(858, 'Meghradzor', 'Meghradzor', 'Meghradzor,Megradzor,Megrajor,Taycharukh,Меградзор,Մեղրաձոր', 40.6061100, 44.6514700, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(859, 'Mayakovski', 'Mayakovski', 'Majakovskij,Mayakovski,Mayakovskiy,Shaab,Маяковский,Մայակովսկի', 40.2529300, 44.6389200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(860, 'Masis', 'Masis', 'Hrazdan,Masis,Narimanlu,Razdan,Takhanshalu,Tokhanshalu,Ulukhanlu,Zangibasar,Масис,Մասիս', 40.0654200, 44.4161800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(861, 'Martuni', 'Martuni', 'Karanlug,Martuki,Martuni,Martuny,Nerkin Karanlukh,Nizhniy-Karanlug,Мартуни,Մարտունի', 40.1389200, 45.3054800, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(862, 'Marmarashen', 'Marmarashen', 'Marmarasen,Marmarashen,Marmorashen,Мармарашен,Մարմարաշեն', 40.0582900, 44.4722900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(863, 'Marmashen', 'Marmashen', 'Kanlidzha,Marmasen,Marmashen,Verin Kanlidzha,Мармашен,Մարմաշեն', 40.8348600, 43.7779000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(864, 'Margahovit', 'Margahovit', 'Bozigekh,Gamzachemanskaya,Gamzachiman,Hamgach''iman,Hamgach’iman,Margahovit,Margaovit,Маргаовит,Մարգահովիտ', 40.7338100, 44.6847400, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(865, 'Maralik', 'Maralik', 'Maralik,Molla Gekcha,Molla Gëkcha,Маралик,Մարալիկ', 40.5750700, 43.8723100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(866, 'Mayisyan', 'Mayisyan', 'Maisian,Maisjan,Maisyan,Mayisyan,Ortakilisa,Маисян,Մայիսյան', 40.8471500, 43.8393800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(867, 'Madina', 'Madina', 'Madina,Мадина,Մադինա', 40.0763700, 45.2550700, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(868, 'Lukashin', 'Lukashin', 'Imeni Mikoyana,Lukashin,Лукашин', 40.1872600, 44.0039000, 'AM', '2013-08-05', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(869, 'Lorut', 'Lorut', 'Lorut,Лорут,Լորուտ', 40.9371700, 44.7714200, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(870, 'Lichk’', 'Lichk''', 'Gel,Gël,Lichk,Lichk'',Lichk’,Личк,Լիճք', 40.1593300, 45.2346700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(871, 'Lerrnavan', 'Lerrnavan', 'Kachagan,Lernavan,Lerrnavan,Лернаван,Լեռնավան', 40.7882000, 44.1602400, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(872, 'Lerrnapat', 'Lerrnapat', 'Gadzhikara,Lernapat,Lerrnapat,Makarashen,Լեռնապատ', 40.8153800, 44.3934400, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(873, 'Lerrnants’k’', 'Lerrnants''k''', 'Lernantsk,Lerrnants''k'',Lerrnants’k’,Spitak,Спитак,Լեռնանցք', 40.7953200, 44.2743500, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(874, 'Lerrnanist', 'Lerrnanist', 'Lernanist,Lerrnanist,Verin Akhta,Verkhnyaya Akhta,Лернанист,Լեռնանիստ', 40.4667600, 44.7924900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(875, 'Lerrnakert', 'Lerrnakert', 'Lernakert,Lerrnakert,Shirvan,Shirvandzhug,Լեռնակերտ', 40.5625000, 43.9389000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(876, 'Khoronk’', 'Khoronk''', 'Khoronk'',Khoronk’,Lenughi,Lenugi,Nerkin Aylanlu,Nizhniy Aylanlu,Խորոնք', 40.1361100, 44.2473100, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(877, 'Lchashen', 'Lchashen', 'Lcasen,Lchashen,Ordaklu,Лчашен,Լճաշեն', 40.5194700, 44.9304800, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(878, 'Lchap’', 'Lchap''', 'Agzibir,Lchap,Lchap'',Lchap’,Lehap,Лчап,Լճափ', 40.4556900, 45.0750700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(879, 'Lanjaghbyur', 'Lanjaghbyur', 'Kyuzadzhik,Landzhakhbjur,Landzhakhpyur,Lanjagbyur,Lanjaghbyur,Ланджахбюр,Լանջաղբյուր', 40.2694700, 45.1444700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(880, 'Kotayk’', 'Kotayk''', 'Kotayk'',Kotayk’,Yelgovan,Կոտայք', 40.2778900, 44.6638800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(881, 'Kosh', 'Kosh', 'Kos,Kosh,Кош,Կոշ', 40.3001100, 44.1610700, 'AM', '2016-05-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(882, 'Vanadzor', 'Vanadzor', 'Böyük Qarakilsə,Gharak''ilisa,Gharak’ilisa,Gorad Vanadzor,Karakhs,Karakilis,Karaklis,Kirovakan,Kirowakan,Korovakan,Mets Karakilisa,Vanadzor,Vanadzoras,Vanajor,Wanadsor,Wanadzor,banajoleu,vanadzori,vu~anazoru,wa na zuo er,wanadzwr,Ванадзор,Горад Ванадзор,Кировакан,Վանաձոր,وانادزور,ვანაძორი,ヴァナゾル,瓦纳佐尔,바나조르', 40.8045600, 44.4939000, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(883, 'Hnaberd', 'Hnaberd', 'Hnaberd,Khnaberd,Kirkhdagirman,Kyrkhdagirman,Хнаберд,Հնաբերդ', 40.6372100, 44.1405800, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(884, 'Khasht’arrak', 'Khasht''arrak', 'Hastarak,Həştərək,Khasht''arrak,Khashtarak,Khasht’arrak,Хаштарак,Խաշթառակ', 40.9366800, 45.1821000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(885, 'Kasakh', 'Kasakh', 'Chamrlu,Chamyrlu,Kasakh,Касах', 40.5369700, 44.4104600, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(886, 'Karchaghbyur', 'Karchaghbyur', 'Gedakbulag,Karcagbyur,Karchaghbyur,Karchaghpyur,Karchakhpjur,Karchakhpyur,Карчахпюр,Կարճաղբյուր', 40.1704800, 45.5778500, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(887, 'Karbi', 'Karbi', 'Karbi,Карби,Կարբի', 40.3306900, 44.3779300, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(888, 'Karanlukh', 'Karanlukh', 'Karanlukh,Verkhniy Karanlug', 40.1044400, 45.2897200, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(889, 'Kaputan', 'Kaputan', 'Geykilisa,Gëykilisa,Kaputan,Капутан,Կապուտան', 40.3250700, 44.7000700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(890, 'K’anak’erravan', 'K''anak''erravan', 'K''anak''erravan,Kanakeravan,Kenaker,Kenakeravan,K’anak’erravan,Murad Tapa,Քանաքեռավան', 40.2473900, 44.5351100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(891, 'Kamo', 'Kamo', 'Gadzhi Nazar,Kamo,Камо,Կամո', 40.8257200, 43.9507100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(892, 'Gavarr', 'Gavarr', 'Gavar,Gavarr,Kamo,Kyavar,Nor-Bajaset,Novo Bayazet,Гавар,Камо,Գավառ', 40.3539800, 45.1238600, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(893, 'Mayisyan', 'Mayisyan', 'Imeni Beriya,Imeni Zhdanova,Mayisyan,Zhdanov,Жданов,Մայիսյան', 40.1570100, 44.0919200, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(894, 'Shahumyan', 'Shahumyan', 'Imeni Shaumyana,Sahumyan,Shahumian,Shahumyan,Shahumyani Anvan Avazan,Shaumjan,Shaumyan,Шаумян,Շահումյան', 40.7748200, 44.5459600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(895, 'Ijevan', 'Ijevan', 'Icevan,Iczewan,Idjevan,Idschewan,Idzevan,Idzevanas,Idzhevan,Idževan,Idževanas,Igevano,Ijevan,Istibulagh,Iĝevano,K''aravansaray,K''arvansara,Karavan Savan,Karavansarai,Karvansara,Karvansaray,K’aravansaray,K’arvansara,ayjwan,ijeban,ijevana,ijevani,ijevu~an,yi jie wan,İcevan,Іджеван,Иджеван,Иџеван,Իջեվան,Իջևան,ایجوان,ਇਜੇਵਾਨ,იჯევანი,イジェヴァン,伊杰万,이제반', 40.8787700, 45.1485100, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(896, 'Hrazdan', 'Hrazdan', 'Akhta,Akhtala,Akhti,Asagi Axta,Aşağı Axta,Hrasdan,Hrazdan,Hrazdanas,Khrazdan,Nerkin Akhta,Nizhne Akhti,Nizhniye Akhty,Nizhnyaya Akhta,Razdan,harajadana,he la zi dan,heulajeudan,hrazdan,razdani,Раздан,Храздан,Հրազդան,הרזדאן,هرازدان,ہرازدان,ਹਰਾਜਦਾਨ,რაზდანი,赫拉茲丹,흐라즈단', 40.4974800, 44.7662000, 'AM', '2011-03-28', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(897, 'Armavir', 'Armavir', 'Armavir,Armaviras,Armaviro,Armawir,Armawîr,Hoktemberyan,Oktember,Oktemberyan,Sardar-Abad,Sardarapat,Sərdarabad,a er ma wei er,aleumabileu,armaviri,armawyr,arumavu~iru,Армавир,Армавір,Октембер,Արմավիր,آرماویر,არმავირი,アルマヴィル,阿爾馬維爾,아르마비르', 40.1544600, 44.0381500, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(898, 'Hayanist', 'Hayanist', 'Dostlug,Hayanist,Հայանիստ', 40.1223100, 44.3779300, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(899, 'Haghartsin', 'Haghartsin', 'Dzharkhech,Dzharkhedzh,Hagarcin,Haghardzin,Haghartsin,Kujbyshev,Kuybishev,Kuybyshev,Куйбышев,Հաղարծին', 40.7761400, 44.9684700, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(900, 'Gyumri', 'Gyumri', 'Alek''pol,Alek''sandrapol,Alek''sandrobol,Aleksandropol'',Aleksandropol’,Alek’pol,Alek’sandrapol,Alek’sandrobol,Alexandropol'',Alexandropol’,Ghiumri,Gimri,Giumri,Gjoemri,Gjumri,Gorad Gjumry,Guemrue,Gumri,Gumru,Gumry,Gyumri,Gümrü,Kumayri,Kumri,Kyumayri,Kyumri,Kümri,LWN,Leninakan,ghywmry,giumri,gyumeuli,gyumuri,gywmry,jiu mu li,Горад Гюмры,Гюмри,Гјумри,Ґюмрі,Գյումրի,غيومري,گیومری,გიუმრი,ギュムリ,久姆里,규므리', 40.7942000, 43.8452800, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(901, 'Gyulagarak', 'Gyulagarak', 'Gjulagarak,Gyulabarrak,Gyulagarak,Gyulagorak,Гюлагарак,Գյուլագարակ', 40.9671500, 44.4714400, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(902, 'Ghukasavan', 'Ghukasavan', 'Ghukasavan,Gukasavan,Kalara,Гукасаван,Ղուկասավան', 40.1279300, 44.4166900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(903, 'Geghamasar', 'Geghamasar', 'Gegamasar,Geghamasar,Gukarrich,Shishkaja,Shishkaya,Sisqaya,Şişqaya,Шишкая,Գեղամասար', 40.3109100, 45.6792400, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(904, 'Gugark’', 'Gugark''', 'Gugark,Gugark'',Gugark’,Meghrut,Megrut,Yagublu,Гугарк,Գուգարք', 40.8046000, 44.5402500, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(905, 'Tsiatsan', 'Tsiatsan', 'Ciacan,Grampa,Tsiatsan,Циацан,Ծիածան', 40.1861000, 44.2694700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(906, 'Goght’', 'Goght''', 'Goght'',Goght’,Gokht,Գողթ', 40.1347000, 44.7833200, 'AM', '2016-05-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(907, 'Gogaran', 'Gogaran', 'Geran,Gogaran,Gëran,Гогаран,Գոգարան', 40.8925500, 44.1991500, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(908, 'Getazat', 'Getazat', 'Agdzhakishlag,Getashen,Getazat,Гетазат,Գետազատ', 40.0384400, 44.5636900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(909, 'Getashen', 'Getashen', 'Dzhafarabat,Getasen,Getashen,Kalagar,Геташен,Գետաշեն', 40.0444900, 43.9417100, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(910, 'Geghanist', 'Geghanist', 'Geganist,Geghanist,Gekhanist,Getapnia,Geygmbet,Gëygmbet,Геханист,Գեղանիստ', 40.1458700, 44.4304800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(911, 'Geghamavan', 'Geghamavan', 'Gegamavan,Geghamavan,Shagriz,Гегамаван,Գեղամավան', 40.5625000, 44.8889200, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(912, 'Garrni', 'Garrni', 'Bash Gyarni,Garni,Garrni,Гарни,Գառնի', 40.1193100, 44.7344200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(913, 'Gagarin', 'Gagarin', 'Gagarin,Гагарин,Գագարին', 40.5402600, 44.8696200, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(914, 'Fantan', 'Fantan', 'Fantan,Fontan,Ֆանտան', 40.3944700, 44.6861000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(915, 'Fioletovo', 'Fioletovo', 'Fioletovo,Nikitino,Фиолетово,Ֆիոլետովո', 40.7224100, 44.7176900, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(916, 'Dzoraghbyur', 'Dzoraghbyur', 'Dzhorakhpyur,Dzoraghbyur,Dzoraghp''yur,Dzoraghp’yur,Dzorakhbjur,Dzorakhpyur,Joragbyur,Tedshirabad,Tedzhirabad,Tedzhrabak,Дзорахбюр,Ձորաղբյուր', 40.2041200, 44.6415000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(917, 'Dzoragyugh', 'Dzoragyugh', 'Dvoragyukh,Dzoraget,Dzoragyugh,Dzoragyukh,Joragyug,Vali Agalu,Дзорагет,Ձորագյուղ', 40.1695700, 45.1833700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(918, 'Dzit’hank’ov', 'Dzit''hank''ov', 'Bazirkhana,Dzit''hank''ov,Dzitankov,Dzitkhankov,Dzit’hank’ov,Дзитанков,Ձիթհանքով', 40.5084800, 43.8209200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(919, 'Jrashen', 'Jrashen', 'Dzhrashen,Jrasen,Jrashen,Vardnav,Vordnav,Vortnav,Джрашен,Ջրաշեն', 40.7902800, 44.1866400, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(920, 'Jrashen', 'Jrashen', 'Dzhrashen,Jrasen,Jrashen,Nor Dzhrashen,Джрашен,Ջրաշեն', 40.0527500, 44.5125900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(921, 'Jrahovit', 'Jrahovit', 'Dzhabachalu,Dzharovit,Dzhraovit,Jrahovit,Джаровит,Ջրահովիտ', 40.0473000, 44.4751000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(922, 'Janfida', 'Janfida', 'Dzhanfida,Janfida,Джанфида,Ջանֆիդա', 40.0444900, 44.0278900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(923, 'Dvin', 'Dvin', 'Dvin,Dvin Armyanskiy,Nerkin Dvin,Nizhniy Dvin,Двин,Դվին', 40.0198400, 44.5837600, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(924, 'Dsegh', 'Dsegh', 'Dseg,Dsegh,Dsekh,Tumanyan,Дсех,Դսեղ', 40.9617000, 44.6500300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(925, 'Drakhtik', 'Drakhtik', 'Drakhtik,Draxtik,Tokhludzha,Тохлуджа,Դրախտիկ', 40.5649700, 45.2367000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(926, 'Doghs', 'Doghs', 'Doghs,Dogs,Dokhs,Դողս', 40.2222900, 44.2722800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(927, 'Dilijan', 'Dilijan', 'Delijan,Delishan,Delizhan,Dili,Dili P''ok''r,Dili P’ok’r,Dilican,Dilichan,Dilidjan,Dilidschan,Dilidzan,Dilidzhan,Dilidżan,Dilidžan,Diligano,Dilijan,Dilishan,Dilizanas,Dilizhan,Diliĝano,Diližanas,Hin,Tili,Tilichan,di li ran,dilijani,dylyjan,Дилиджан,Дилижан,Дилиџан,Діліжан,Դիլիջան,دیلیجان,დილიჯანი,迪利然', 40.7417000, 44.8501000, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(928, 'Ddmashen', 'Ddmashen', 'Ddmasen,Ddmashen,Dodmashen,Totmashen,Ддмашен,Դդմաշեն', 40.5702800, 44.8229500, 'AM', '2016-09-08', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(929, 'Darpas', 'Darpas', 'Darbas,Darpas,Дарпас,Դարպաս', 40.8367400, 44.4249400, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(930, 'Dalarik', 'Dalarik', 'Dalarik,Mastara,Даларик,Դալարիկ', 40.2279000, 43.8779300, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(931, 'Chochkan', 'Chochkan', 'Chochkan,Cockan,Ճոճկան', 41.1811800, 44.8321700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(932, 'Chambarak', 'Chambarak', 'Chambarak,Kraside,Krasnosel''sk,Krasnosel’sk,Krasnoye,Mikhaylovka,Чамбарак', 40.5965500, 45.3549800, 'AM', '2014-06-26', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(933, 'Bjni', 'Bjni', 'Bjni,Bzhni,Բջնի', 40.4583100, 44.6500800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(934, 'Byureghavan', 'Byureghavan', 'Bjuregavan,Byuregavan,Byureghavan,Бюрегаван,Բյուրեղավան', 40.3141700, 44.5933300, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(935, 'Byurakan', 'Byurakan', 'Biurakan,Bjurakan,Burakan,Byurakan,Бюракан,Բյուրական', 40.3389400, 44.2727500, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(936, 'Buzhakan', 'Buzhakan', 'Babakishi,Buzakan,Buzhakan,Бужакан,Բուժական', 40.4556900, 44.5194700, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(937, 'Berd', 'Berd', 'Berd,Berrdagyugh,Berrdgyugh,Bert,Ghalak''yand,Ghalak’yand,Shlorut,T''auzk''end,T''auzkala,T''avuzghala,T''ous,T''ous Gale,T''ovuz,T''uzukala,Taua Kale,Taya-Kala,Tovuz,Tovuzkala,Tovuzqala,T’auzkala,T’auzk’end,T’avuzghala,T’ous,T’ous Gale,T’ovuz,T’uzukala,Volorut,Берд,Товуз,Բերդ', 40.8813500, 45.3890100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(938, 'Bazum', 'Bazum', 'Bazum,Bzovdal,Базум,Բազում', 40.8676300, 44.4397800, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(939, 'Byuravan', 'Byuravan', 'Bambakavan,Bjuravan,Byuravan,Verin Kuylasar,Verkhniy Kuylasar,Бюраван,Բյուրավան', 40.0160400, 44.5188900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(940, 'Bambakashat', 'Bambakashat', 'Bambakasat,Bambakashat,Molla Bayazet,Бамбакашат,Բամբակաշատ', 40.1082800, 44.0194700, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(941, 'Balahovit', 'Balahovit', 'Balahovit,Balakhovit,Balaovit,Mehub,Mekhub,Mgub,Балаовит,Балаховит,Բալահովիտ', 40.2515300, 44.6082800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(942, 'Bagratashen', 'Bagratashen', 'Bagratasen,Bagratashen,Debedashen,Debetashen,Lambalu,Баграташен,Բագրատաշեն', 41.2435800, 44.8173700, 'AM', '2013-11-29', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(943, 'Azatan', 'Azatan', 'Azatan,Karakhs,Karakilisa,Pokr Karakilisa,Азатан,Ազատան', 40.7195900, 43.8272700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(944, 'Haykavan', 'Haykavan', 'Ajkavan,Aykavan,Badzhogli,Haykavan,Айкаван', 40.8031200, 43.7517300, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(945, 'Aygestan', 'Aygestan', 'Ajgestan,Ayaslu,Aygestan,Айгестан,Այգեստան', 40.0029300, 44.5582900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(946, 'Aygeshat', 'Aygeshat', 'Ajgeshat,Aygesat,Aygeshat,Gadzhikara,Айгешат,Այգեշատ', 40.2360800, 44.2888800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(947, 'Aygeshat', 'Aygeshat', 'Ajgeshat,Aygesat,Aygeshat,Kuzigidan,Айгешат,Այգեշատ', 40.0750700, 44.0611000, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(948, 'Aknalich', 'Aknalich', 'Aknalic,Aknalich,Aygerlich,Акналич,Ակնալիճ', 40.1472800, 44.1666900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(949, 'Aygehovit', 'Aygehovit', 'Ajgeovit,Aygehovit,Aygeovit,Ayqeovit,Onut,Uzuntala,Айгеовит,Այգեհովիտ', 40.9795100, 45.2503300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(950, 'Artimet', 'Artimet', 'Alibeklu,Artimet,Atarbekyan,Артимет,Արտիմետ', 40.1500800, 44.2667200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(951, 'Astghadzor', 'Astghadzor', 'Alikrykh,Astgajor,Astghadzor,Astkhadzor,Астхадзор,Աստղաձոր', 40.1223100, 45.3555300, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(952, 'Ashtarak', 'Ashtarak', 'Achtarak,Aschtarak,Ashharak,Ashtarak,Ashtarakats'' Gyugh,Ashtarakats’ Gyugh,Astarak,Astarakas,Astarako,Asztarak,Aŝtarako,Aştarak,Aštarak,Aštarakas,Aștarak,a shen ta la ke,asataraka,ashtarak,ashutaraku,asyutalakeu,Əştərək,Аштарак,Ащарак,Աշտարակ,آشتاراك,آشتاراک,ਅਸ਼ਤਾਰਕ,აშტარაკი,アシュタラク,阿什塔拉克,아슈타라크', 40.2991000, 44.3620400, 'AM', '2016-10-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(953, 'Ashnak', 'Ashnak', 'Ashnak,Asnak,Ашнак,Աշնակ', 40.3306900, 43.9166900, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(954, 'Arzni', 'Arzni', 'Arzni,Арзни,Արզնի', 40.2973000, 44.5986900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(955, 'Arzakan', 'Arzakan', 'Arzakan,Arzakyand,Арзакан,Արզական', 40.4500700, 44.6082800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(956, 'Arteni', 'Arteni', 'Arteni,Bogutlu,Артени,Արտենի', 40.2973000, 43.7667200, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(957, 'Arshaluys', 'Arshaluys', 'Arsaluys,Arshalujs,Arshaluys,Kerpalu,Kërpalu,Аршалуйс,Արշալույս', 40.1694900, 44.2139300, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(958, 'Argel', 'Argel', 'Argel,Arkel,Lusakert,Аргел,Արգել', 40.3779300, 44.6001000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(959, 'Argavand', 'Argavand', 'Argavand,Dzhafarapat,Аргаванд,Արգավանդ', 40.1528900, 44.4389000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(960, 'Argavand', 'Argavand', 'Argavand,Uzunoba,Аргаванд,Արգավանդ', 40.0611000, 44.0944800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(961, 'Arevshat', 'Arevshat', 'Arevsat,Arevshat,Yekan,Yekanlar,Аревшат,Արևշատ', 40.6534500, 44.0441900, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(962, 'Arevshat', 'Arevshat', 'Arevsat,Arevshat,Arpavar,Lusakert,Nerkin Agbash,Nizhniy Agbash,Аревшат,Արևշատ', 40.0396300, 44.5417900, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(963, 'Arevik', 'Arevik', 'Arevik,Tapadolag,Tapadolak,Аревик,Արևիկ', 40.7417000, 43.9043000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(964, 'Arevik', 'Arevik', 'Agdzharkh,Arevik,Аревик,Արևիկ', 40.1001000, 44.0944800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(965, 'Arevashogh', 'Arevashogh', 'Arevashogh,Arevashokh,Arevasog,Chigdamal,Chikdamal,Аревашох,Արևաշող', 40.8603900, 44.2743800, 'AM', '2016-12-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(966, 'Arevashat', 'Arevashat', 'Arevasat,Arevashat,Arevashet,Varmaziar,Аревашат,Արևաշատ', 40.1444700, 44.3751200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(967, 'Archis', 'Archis', 'Archis,Arcis,Արճիս', 41.1635100, 44.8763100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(968, 'Arbat’', 'Arbat''', 'Arbat'',Arbat’,Արբաթ', 40.1389200, 44.4028900, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(969, 'Arazap’', 'Arazap''', 'Arazap,Arazap'',Arazap’,Evdzhilar,Аразап,Արազափ', 40.0416900, 44.1472800, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(970, 'Arrap’i', 'Arrap''i', 'Arapi,Arrap''i,Arrap’i,Odzhakhkuli,Առափի', 40.7827600, 43.8058300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(971, 'Aramus', 'Aramus', 'Aramus,Արամուս', 40.2509500, 44.6635100, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(972, 'Arak’s', 'Arak''s', 'Arak''s,Arak’s,Nerkin Karkhun,Nizhniy Karkhun,Արաքս', 40.0554800, 44.3029200, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(973, 'Aragats', 'Aragats', 'Aragac,Aragats,Kaznafar,Арагац,Արագած', 40.4888900, 44.3529000, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(974, 'Aparan', 'Aparan', 'Abaran,Abaran Verin,Aparan,Aparan Verin,Aparanas,Aparanbol,Aparanpol,Bash Abaran,Bash Aparan,Dash Abaron,K''asagh,K''asakh,K’asagh,K’asakh,P''araznavert,Pash Aparan,P’araznavert,a pa lan,abaran,aparan,Апаран,Ապարան,آپاران,أباران,აპარანი,阿帕蘭', 40.5932300, 44.3589000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(975, 'Apaga', 'Apaga', 'Apaga,Verin Turkmenlu,Апага,Ապագա', 40.0972900, 44.2529300, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(976, 'Anushavan', 'Anushavan', 'Anusavan,Anushavan,Parni,Pokr Parni,Анушаван,Անուշավան', 40.6500800, 43.9805300, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(977, 'Amasia', 'Amasia', 'Amasia,Amasija,Amasiya,Gukasyan,Амасия,Ամասիա', 40.9544200, 43.7872000, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(978, 'Alaverdi', 'Alaverdi', 'Alaverdi,Alaverdo,Alaverdy,Alawerdi,Alawerdy,Allahverdi,Allaverdy,Manes,a la wei er di,alaverdi,Алаверди,Алаверді,Ալավերդի,الله‌وردی,ალავერდი,阿拉韋爾迪', 41.0976600, 44.6731600, 'AM', '2011-01-29', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(979, 'Akunk’', 'Akunk''', 'Akunk'',Akunk’,Bashgyukh,Ակունք', 40.2667200, 44.6861000, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(980, 'Akunk’', 'Akunk''', 'Akunk'',Akunk’,Kirkhbulag,Ակունք', 40.1588600, 45.7256800, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(981, 'Akhuryan', 'Akhuryan', 'Akhurjan,Akhuryan,Axuryan,Duzk''end,Duzk''end Mets,Duzk''yand,Duzk’end,Duzk’end Mets,Duzk’yand,Ахурян,Ախուրյան', 40.7800300, 43.9002700, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(982, 'Aghavnatun', 'Aghavnatun', 'Agavnatun,Aghavnatun,Akhavnatukh,Akhavnatun,Агавнатун,Ахавнатун,Աղավնատուն', 40.2333000, 44.2529500, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(983, 'Aghavnadzor', 'Aghavnadzor', 'Agavnadzor,Aghavnadzor,Akhavnadzor,Babakishi,Агавнадзор', 40.5819500, 44.6958100, 'AM', '2012-01-17', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(984, 'Agarak', 'Agarak', 'Agarak,Ագարակ', 41.0107200, 44.4684500, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(985, 'Agarakavan', 'Agarakavan', 'Agarak,Agarakavan,Ագարակավան', 40.3306900, 44.0723300, 'AM', '2016-05-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(986, 'Abovyan', 'Abovyan', 'Abovian,Abovianas,Abovjan,Abovyan,Abowian,Abowjan,Abowyan,Elar,Ellər,a bo wei yang,aboviani,abwfyan  ararat,abwwyan,Абовян,Абовјан,Աբովյան,آبوویان,أبوفيان، أرارات,აბოვიანი,阿博維揚', 40.2736800, 44.6334800, 'AM', '2016-04-10', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(987, 'Abovyan', 'Abovyan', 'Abovjan,Abovyan,Agbash,Verin Agbash,Verkhniy Agbash,Абовян,Աբովյան', 40.0485100, 44.5474200, 'AM', '2016-11-22', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(988, 'Vardablur', 'Vardablur', 'Vardablur,Verdablur,Вардаблур', 40.9708300, 44.5088900, 'AM', '2012-01-19', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(989, 'Bardzrashen', 'Bardzrashen', 'Bardzrashen,Barjrasen,Bartsrashen,Բարձրաշեն', 40.0853300, 44.5795700, 'AM', '2016-11-23', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(990, 'Nshavan', 'Nshavan', 'Nsavan,Nshavan,Նշավան', 40.0278700, 44.5256500, 'AM', '2016-11-23', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(991, 'Norabats’', 'Norabats''', 'Norabats'',Norabats’,Norashen,Նորաբաց', 40.1055300, 44.4332900, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(992, 'Berdavan', 'Berdavan', 'Berdavan', 41.2050300, 44.9996700, 'AM', '2012-01-19', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(993, 'Shirakamut', 'Shirakamut', 'Shirakamut,Ширакамут', 40.8605600, 44.1527800, 'AM', '2012-01-19', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(994, 'Azatamut', 'Azatamut', 'Azanut,Azatamut,Азанут', 40.9820400, 45.1855100, 'AM', '2014-06-27', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(995, 'Getahovit', 'Getahovit', 'Getahovit,Getaovit', 40.8978400, 45.1397100, 'AM', '2013-09-09', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(996, 'Artsvaberd', 'Artsvaberd', 'Arcvaberd,Artsvaberd,Арцваберд', 40.8394700, 45.4703300, 'AM', '2013-09-09', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(997, 'Nor Yerznka', 'Nor Yerznka', 'Nor Erznka,Nor Yerznka,Նոր Երզնկա', 40.3001100, 44.3889200, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(998, 'Sasunik', 'Sasunik', 'Nor Sasunik,Sasunik,Սասունիկ', 40.2501200, 44.3444800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(999, 'Kamaris', 'Kamaris', 'Kamaris', 40.2353900, 44.6945900, 'AM', '2012-01-19', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1000, 'Gandzak', 'Gandzak', 'Gandzak', 40.3147200, 45.1113900, 'AM', '2012-05-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1001, 'Myasnikyan', 'Myasnikyan', 'Mjasnikjan,Myasnikyan,Мясникян,Մյասնիկյան', 40.1804800, 43.9194900, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1002, 'Lenughi', 'Lenughi', 'Lenughi,Lenugi,Լենուղի', 40.1251200, 43.9639300, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1003, 'Metsamor', 'Metsamor', 'Mecamor,Metsamor,Мецамор,Մեծամոր', 40.1444700, 44.1167000, 'AM', '2016-08-03', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1004, 'Gay', 'Gay', 'Gay', 40.0844400, 44.3052800, 'AM', '2013-08-07', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1005, 'Baghramyan', 'Baghramyan', 'Baghramyan,Bagramyan,Բաղրամյան', 40.1945200, 44.3695100, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1006, 'Musalerr', 'Musalerr', 'Musaler,Musalerr,Մուսալեռ', 40.1557000, 44.3779300, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1007, 'Darakert', 'Darakert', 'Darakert,Դարակերտ', 40.1055300, 44.4138800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1008, 'Dashtavan', 'Dashtavan', 'Dashtavan,Dastavan,Դաշտավան', 40.1001000, 44.3917200, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1009, 'Nizami', 'Nizami', 'Nizami,Նիզամի', 40.0916800, 44.4057000, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1010, 'Artsvanist', 'Artsvanist', 'Artsvanist', 40.1461700, 45.5171100, 'AM', '2015-09-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1011, 'Vardadzor', 'Vardadzor', 'Vardadzor', 40.1870100, 45.1921200, 'AM', '2012-05-06', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1012, 'Taronik', 'Taronik', 'Taronik', 40.1336700, 44.1995700, 'AM', '2012-01-20', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1013, 'Aknashen', 'Aknashen', 'Aknashen', 40.0955100, 44.2860400, 'AM', '2012-01-20', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1014, 'Haykashen', 'Haykashen', 'Aykashen,Haykasen,Haykashen,Հայկաշեն', 40.0723300, 44.3082900, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1015, 'Hovtashat', 'Hovtashat', 'Hovtasat,Hovtashat,Ovtashat,Հովտաշատ', 40.0972900, 44.3444800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1016, 'Sayat’-Nova', 'Sayat''-Nova', 'Sayat''-Nova,Sayat’-Nova,Սայաթ-Նովա', 40.0750700, 44.4000800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1017, 'Voskehat', 'Voskehat', 'Oskehat,Voskeat,Voskehat,Ոսկեհատ', 40.1417200, 44.3306900, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1018, 'Griboyedov', 'Griboyedov', 'Griboyedov', 40.1130700, 44.2716900, 'AM', '2012-01-20', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1019, 'Gmbet’', 'Gmbet''', 'Amberd,Gmbet'',Gmbet’,Ամբերդ', 40.2236900, 44.2540900, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1020, 'Aygek', 'Aygek', 'Aygek,Այգեկ', 40.1889000, 44.3861100, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1021, 'Hovtashen', 'Hovtashen', 'Hovtasen,Hovtashen,Ovtashen,Հովտաշեն', 40.0250800, 44.4500700, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1022, 'Dimitrov', 'Dimitrov', 'Dimitrov,Դիմիտրով', 40.0084800, 44.4917000, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1023, 'Mrgavet', 'Mrgavet', 'Mrgavet,Մրգավետ', 40.0278900, 44.4832800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1024, 'Arevabuyr', 'Arevabuyr', 'Arevabuyr,Արևաբույր', 40.0360700, 44.4694800, 'AM', '2016-04-11', 12);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2034, 'Aūa', 'Aua', 'Aua,`Ava Point', -14.2761100, -170.6638900, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2035, 'Vaitogi', 'Vaitogi', '', -14.3588900, -170.7347200, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2036, 'Vailoatai', 'Vailoatai', 'Vailoa', -14.3611100, -170.7822200, 'AS', '2014-10-08', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2037, 'Taulaga', 'Taulaga', '', -11.0552800, -171.0883300, 'AS', '2012-02-19', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2038, 'Ta`ū', 'Ta`u', 'Opoun,Ta`u,Ta`ue Village,Ta`ü Village,Tau', -14.2336100, -169.5144400, 'AS', '2013-08-02', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2039, 'Tāfuna', 'Tafuna', 'Tafuna,Тафуна', -14.3358300, -170.7200000, 'AS', '2010-09-05', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2040, 'Faleniu', 'Faleniu', '', -14.3325000, -170.7444400, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2041, 'Fagatogo', 'Fagatogo', 'Fagatogo,Fanga Tonga,Фагатого', -14.2825000, -170.6900000, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2042, 'Faleāsao', 'Faleasao', 'Faleasao,Faleasau', -14.2222000, -169.5127800, 'AS', '2012-02-02', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2043, 'Leone', 'Leone', '', -14.3438900, -170.7850000, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2044, 'Malaeimi', 'Malaeimi', '', -14.3227800, -170.7338900, 'AS', '2010-09-05', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2045, 'Mapusagafou', 'Mapusagafou', '', -14.3305600, -170.7527800, 'AS', '2010-10-12', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2046, 'Ofu', 'Ofu', 'OFU', -14.1752800, -169.6775000, 'AS', '2012-02-03', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2047, 'Pago Pago', 'Pago Pago', 'Gorad Paga-Paga,PPG,Pago Pago,Pago-Pago,PagoPago,Pagopago,Pagó Pagó,Panko Panko,Paqo Paqo,baghw baghw,pa guo pa guo,pa ko pa ko,pagopago,pagw pagw,pako pako,pango pango,Πάγκο Πάγκο,Горад Пага-Пага,Паго Паго,Паго-Паго,Пагопаго,Պագո Պագո,פאגו פאגו,باغو باغو,پاگو پاگو,पांगो पांगो,பாகோ பாகோ,ปาโกปาโก,პაგო-პაგო,パゴパゴ,帕果帕果,파고파고', -14.2780600, -170.7025000, 'AS', '2011-08-29', 5);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1425, 'Uriburu', 'Uriburu', 'Uriburu', -36.5068200, -63.8622500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1426, 'Unquillo', 'Unquillo', 'Unquillo', -31.2307300, -64.3161500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1427, 'Unión', 'Union', 'Union,Unión', -35.1528200, -65.9460200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1428, 'Ulapes', 'Ulapes', 'Ulapes', -31.5736200, -66.2365000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1429, 'Ucacha', 'Ucacha', '', -33.0320300, -63.5066600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1430, 'Tupungato', 'Tupungato', 'Tupungata,Tupungato,Villa Tupungato', -33.3714600, -69.1484500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1431, 'Tunuyán', 'Tunuyan', 'Tunuyan,Tunuyán', -33.5765300, -69.0153800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1432, 'Tumbaya', 'Tumbaya', 'Tumbaya', -23.8562600, -65.4574100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1433, 'Trevelin', 'Trevelin', 'Trevelin,Trevelina,Trevelinas,Trevelín', -43.0858000, -71.4638600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1434, 'Tres Lomas', 'Tres Lomas', 'Jose M. Blanco,Jose Maria Blanco,José M. Blanco,José María Blanco,Tres Lomas', -36.4572200, -62.8604700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1435, 'Tres Isletas', 'Tres Isletas', 'Tres Isletas', -26.3406700, -60.4320700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1436, 'Tres Arroyos', 'Tres Arroyos', 'OYO,Tres Arojosas,Tres Arroyos,te lei si a luo yue si,trs arwyws,trys arwyws,ترس آرویوس,تريس آرويوس,特雷斯阿羅約斯', -38.3739400, -60.2797800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1437, 'Tres Algarrobos', 'Tres Algarrobos', 'Tres Algarrobos', -35.1947100, -62.7739600, 'AR', '2016-11-29', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1438, 'Trenque Lauquen', 'Trenque Lauquen', 'T. Lauquen,Trenque Lauquen,te lun ke lao ken,trnkh laywkn,trynkyw laykywn,ترنکه لائوکن,ترينكيو لايكيون,特倫克勞肯', -35.9703500, -62.7343200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1439, 'Trenel', 'Trenel', 'Trenel', -35.6983700, -64.1321800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1440, 'Trelew', 'Trelew', 'REL,Trelew,Trelju,te lei li wu,teulelle-u,torereu,trlyw,trylyw,טרלאו,ترلئو,تريليو,ტრელევი,トレレウ,特雷利烏,트렐레우', -43.2489500, -65.3050500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1441, 'Trancas', 'Trancas', 'Trancas', -26.2157500, -65.2849200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1442, 'Totoras', 'Totoras', 'Santa Teresa,Totoras', -32.5844000, -61.1685200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1443, 'Tostado', 'Tostado', 'Tostado', -29.2320200, -61.7691700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1444, 'Tornquist', 'Tornquist', 'Tornquist,tuo en ji si te,托恩基斯特', -38.1012200, -62.2226700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1445, 'Toledo', 'Toledo', '', -31.5557400, -64.0094700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1446, 'Toay', 'Toay', 'Toay', -36.6733800, -64.3786000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1447, 'Tío Pujio', 'Tio Pujio', '', -32.2879000, -63.3559800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1448, 'Tintina', 'Tintina', 'Tintina', -27.0333300, -62.7166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1449, 'Tinogasta', 'Tinogasta', 'Tinogasta,di nuo jia si ta,Τινογάστα,蒂諾加斯塔', -28.0631900, -67.5648800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1450, 'Tilisarao', 'Tilisarao', 'Tilisarao', -32.7329200, -65.2910900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1451, 'Tilcara', 'Tilcara', 'Tilcara', -23.5775700, -65.3509000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1452, 'Ticino', 'Ticino', '', -32.6935000, -63.4360600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1453, 'Termas de Río Hondo', 'Termas de Rio Hondo', 'Banos,Baños,Las Termas,Las Termas de Rio Hondo,Las Termas de Río Hondo,RHD,Termas de Rio Hondo,Termas de Río Hondo,Termas del Rio Hondo,Termas del Río Hondo', -27.4936200, -64.8597200, 'AR', '2017-03-25', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1454, 'Telsen', 'Telsen', 'Telsen', -42.4355300, -66.9407800, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1455, 'Telén', 'Telen', 'Telen,Telén', -36.2642900, -65.5101800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1456, 'Tecka', 'Tecka', 'Tecka', -43.4948900, -70.8102000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1457, 'Tartagal', 'Tartagal', 'TTG,Tartagal,Tartagalis,ta ta jia er,tartagal,tartghal,trtgl,Ταρταγάλ,Тартагал,טרטגל,تارتاگال,تارتغال,塔塔加爾', -22.5163700, -63.8013100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1458, 'Tapalqué', 'Tapalque', 'Tapalque,Tapalquen,Tapalqué,Tapalquén', -36.3549300, -60.0264000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1459, 'Tancacha', 'Tancacha', '', -32.2430900, -63.9807000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1460, 'Tamberías', 'Tamberias', 'Tamberia,Tamberias,Tambería,Tamberías', -31.4664600, -69.4255000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1461, 'Tama', 'Tama', 'Rosario del Tama,Tama', -30.5079800, -66.5298000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1462, 'Tafí Viejo', 'Tafi Viejo', 'Tafi,Tafi Viejo,Tafí,Tafí Viejo', -26.7320100, -65.2592100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1463, 'Tafí del Valle', 'Tafi del Valle', 'Tafi,Tafi del Valle,Tafí,Tafí del Valle', -26.8527500, -65.7098300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1464, 'Taco Pozo', 'Taco Pozo', 'Taco Pozo', -25.6166700, -63.2833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1465, 'Susques', 'Susques', '', -23.3986400, -66.3670100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1466, 'Suncho Corral', 'Suncho Corral', 'Suncha Corral,Suncho Corral', -27.9335700, -63.4293800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1467, 'Sunchales', 'Sunchales', 'NCJ,Sunchales', -30.9440400, -61.5614800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1468, 'Sumampa', 'Sumampa', 'Sumampa', -29.3847000, -63.4690700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1469, 'Simoca', 'Simoca', 'Simoca', -27.2627200, -65.3564700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1470, 'Sierra Grande', 'Sierra Grande', 'SGV,Sierra Grande', -41.6060300, -65.3557400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1471, 'Sierra Colorada', 'Sierra Colorada', 'Sierra Colorada,Sierra Colorado', -40.5848700, -67.7567400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1472, 'Serrezuela', 'Serrezuela', '', -30.6376100, -65.3869200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1473, 'Serrano', 'Serrano', '', -34.4697100, -63.5384200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1474, 'Senillosa', 'Senillosa', '', -39.0141200, -68.4328100, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1475, 'Selva', 'Selva', 'Selva', -29.7677600, -62.0477000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1476, 'Seguí', 'Segui', 'Segui,Seguí', -31.9564200, -60.1248800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1477, 'Sebastián Elcano', 'Sebastian Elcano', '', -30.1610500, -63.5936000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1478, 'Saujil', 'Saujil', 'Saujil', -28.1744200, -66.2117700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1479, 'Saturnino M. Laspiur', 'Saturnino M. Laspiur', 'Santa Maria Laspiur,Saturnino M. Laspiur,Saturnio M. Laspiuro', -31.7028700, -62.4820200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1480, 'Sastre', 'Sastre', 'Sastre', -31.7676200, -61.8288700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1481, 'Sarmiento', 'Sarmiento', 'Colonia Sarmiento,OLN,Sarmiento,Sarmjentas,sa er mi en tuo,薩爾米恩托', -45.5881500, -69.0699600, 'AR', '2017-02-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1482, 'Santo Tomé', 'Santo Tome', 'Santo Tome,Santo Tomé,Santo Tomė', -31.6627400, -60.7653000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1483, 'Santiago Temple', 'Santiago Temple', 'Sagrado Temple,Santiago Temple', -31.3873100, -63.4182100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1484, 'Santiago del Estero', 'Santiago del Estero', 'Ciudad de Santiago del Estero,Gorad Santjaga-dehl''-Ehstehra,Provincia de Santiago del Estero,Província de Santiago del Estero,SDE,Sanctus Iacobus ad Uligines,Sant''jago-del''-Ehstero,Sant''jago-del''-Estero,Santiago del Estero,Santijago del Estero,Santjago del Esteras,Santjago del Estero,saintiyago dela estro,san teiy ko del xe s te ro,san tyagw dyl astyrw,santiagodel-eseutelo,santyaghw dyl astyrw,santyagw dl astrw,sheng de ya ge-de er ai si te luo,Горад Сантяга-дэль-Эстэра,Сантијаго дел Естеро,Сантьяго-дель-Естеро,Сантьяго-дель-Эстеро,Сантяго дел Естеро,Սանտիագո դել Էստերո,סנטיאגו דל אסטרו,سان تیاگو دیل استیرو,سانتياغو ديل استيرو,سانتیاگو دل استرو,सैन्टियागो डेल एस्त्रो,ซานเตียโกเดลเอสเตโร,სანტიაგო-დელ-ესტერო,サンティアゴ・デル・エステロ,圣地亚哥-德尔埃斯特罗,산티아고델에스테로', -27.7951100, -64.2614900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1485, 'Santa Victoria', 'Santa Victoria', 'Santa Victoria', -22.2500000, -64.9666700, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1486, 'Santa Sylvina', 'Santa Sylvina', 'Santa Silvina,Santa Sylvina', -27.8326100, -61.1374700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1487, 'Santa Rosa de Tastil', 'Santa Rosa de Tastil', 'Santa Rosa de Tastil,Tastil', -24.4516600, -65.9745200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1488, 'Santa Rosa de Río Primero', 'Santa Rosa de Rio Primero', 'Santa Rosa,Santa Rosa de Rio 1,Santa Rosa de Rio Primero,Santa Rosa de Río 1,Santa Rosa de Río Primero,Villa Santa Rosa', -31.1523100, -63.4019100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1489, 'Santa Rosa del Conlara', 'Santa Rosa del Conlara', 'Santa Rosa,Santa Rosa del Conlara', -32.3428600, -65.2032300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1490, 'Santa Rosa de Calamuchita', 'Santa Rosa de Calamuchita', 'Santa Rosa,Santa Rosa de Calamuchita,Santa Rosa de Calamuchito', -32.0690500, -64.5363100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1491, 'Santa Rosa', 'Santa Rosa', 'Ciudad de Santa Rosa,RSA,Sancta Rosa,Santa Rosa,Santa Rosa de Toaj,Santa Rosa de Toay,Santa-Rosa,santa rwsa,santa rwsa  la pampa,santa rwza,santa rwza  la bamba,santalosa,santarosa,sheng luo sha,snth rwsh,Санта Роса,Санта Роса де Тоај,Санта-Роса,Սանտա Ռոսա,סנטה רוסה,سانتا روزا,سانتا روزا، لا بامبا,سانتا روسا,سانتا روسا، لا پامپا,სანტა-როსა,サンタローサ,聖羅莎,산타로사', -36.6166700, -64.2833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1492, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa,Santa-Rosa,Villa Santa Rosa,Санта-Роса', -33.2540700, -68.1493700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1493, 'Santa María', 'Santa Maria', 'Santa Maria,Santa María', -26.6954700, -66.0473200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1494, 'Santa Magdalena', 'Santa Magdalena', 'Jovita,Santa Magdalena', -34.5177600, -63.9440900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1495, 'Santa Lucía', 'Santa Lucia', 'Santa Lucia,Santa Lucía', -31.5398700, -68.4950300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1496, 'Santa Isabel', 'Santa Isabel', 'Santa Isabel', -36.2272400, -66.9424000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1497, 'Santa Fe de la Vera Cruz', 'Santa Fe de la Vera Cruz', 'Ciudad de Santa Fe,SFN,Santa Fe,Santa Fė,Santa-Fe,Санта Фе,Санта-Фе', -31.6333300, -60.7000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1498, 'Santa Eufemia', 'Santa Eufemia', '', -33.1765900, -63.2828100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1499, 'Santa Clara', 'Santa Clara', 'Santa Clara', -24.3092100, -64.6625300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1500, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', -21.9446700, -66.0521900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1501, 'San Salvador de Jujuy', 'San Salvador de Jujuy', 'Gorad San-Sal''vador-deh-Zhuzhuj,JUJ,Jujuy,Khukhuj,San Sal''vador de Khukhuj,San Sal''vador de Zhuzhuj,San Salvador de Chuchujus,San Salvador de Jujuy,San Salvador de Khukhuj,San Salvador de Xuxuy,San-Sal''vador-de-Zhuzhuj,Sanctus Salvator Soteriae,san salwadwr dh khwkhwyy,san salwadwr dl khwkhwyy,san slfadwr dy khwkhwy,san-salvador-de-khukhui,sansalbadoleudehuhu-i,sheng sa er wa duo-de hu hu yi,sn slbdwr dh hwhwy,Горад Сан-Сальвадор-дэ-Жужуй,Сан Салвадор де Хухуй,Сан Салвадор де Хухуј,Сан Сальвадор де Жужуй,Сан Сальвадор де Хухуй,Сан-Сальвадор-де-Жужуй,Хухуй,Սան Սալվադոր դե Խուխույ,סן סלבדור דה חוחוי,سان سالوادور دل خوخوئی,سان سالوادور ده خوخوئی,سان سلفادور دي خوخوي,سان سلوادور دی جوجوئے,სან-სალვადორ-დე-ხუხუი,サン・サルバドール・デ・フフイ,圣萨尔瓦多-德胡胡伊,산살바도르데후후이', -24.1945700, -65.2971200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1502, 'San Ramón de la Nueva Orán', 'San Ramon de la Nueva Oran', 'ORA,Oran,Orán,San Ramon de la Nueva Oran,San Ramon de la Nueva Oranas,San Ramón de la Nueva Orán,San-Ramon-de-la-Nuehva-Oran,ao lan,san ramwn dh la nwywa awran,san-ramon-de-la-nueva-orani,sanlamondelanuebaolan,whran  salta,Сан Рамон де ла Нуева Оран,Сан-Рамон-де-ла-Нуэва-Оран,Սան Ռամոն դե լա Նուևա Օրան,סן רמון דה לה נואבה אוראן,سان رامون ده لا نوئوا اوران,وهران، سالتا,სან-რამონ-დე-ლა-ნუევა-ორანი,奧蘭,산라몬데라누에바오란', -23.1370500, -64.3242600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1503, 'San Rafael', 'San Rafael', 'AFA,San Rafael,San Rafaelis,San-Rafaehl'',San-Rafael'',san rafayl,san rafayyl  mndwza,san-rapaeli,sheng la fei er,Сан Рафаел,Сан-Рафаель,Сан-Рафаэль,סן רפאל,سان رافائل,سان رافائيل، مندوزا,სან-რაფაელი,聖拉斐爾', -34.6177200, -68.3300700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1504, 'San Pedro', 'San Pedro', 'San Pedro', -27.9538600, -65.1665100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1505, 'San Pedro', 'San Pedro', 'San Pedro', -24.2312700, -64.8661400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1506, 'Sañogasta', 'Sanogasta', 'Sanogasta,Sañogasta', -29.0952000, -67.1158600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1507, 'San Nicolás de los Arroyos', 'San Nicolas de los Arroyos', 'San Nicolas,San Nicolas de los Arroyos,San Nicolás,San Nicolás de los Arroyos,San Nikolas de los Arojos,San Nikolas de los Arojosas,san ni ko lasdelo sxar ro yos,san nykwlas dh lws arwys,san nykwlas dy lws arwyws,sheng ni gu la si,Сан Николас де лос Аройос,סן ניקולאס דה לוס ארוזוס,سان نيكولاس دي لوس آرويوس,سان نیکولاس ده لوس آرویس,ซานนีโกลาสเดโลสอาร์โรโยส,სან-ნიკოლას-დე-ლოს-აროიოსი,圣尼古拉斯', -33.3357800, -60.2252300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1508, 'San Miguel de Tucumán', 'San Miguel de Tucuman', 'Gorad San-Migel''-deh-Tukuman,San Migel De Tukuman,San Migel de Tukuman,San Miguel de Tucuman,San Miguel de Tucumán,San Minkel nte Toukouman,San-Migel''-de-Tukuman,Sanctus Michael Tucumanensis,TUC,Tucuman,Tucumán,Tukuman,Tukumanas,san mi kelde tu ku man,san myghyl dy twkwman,san mygwyyl dy twkwman,sanmigeldetukuman,santyagw dwtwkwman,sheng mi ge er-de tu ku man,Σαν Μιγκέλ ντε Τουκουμάν,Горад Сан-Мігель-дэ-Тукуман,Сан Мигел де Тукуман,Сан-Мигель-де-Тукуман,Сан-Мігель-де-Тукуман,Тукуман,Տուկուման,טוקומאן,سان ميغيل دي توكومان,سان میگوئیل دی توکومان,سانتیاگو دوتوکومان,ซานมีเกลเดตูกูมัน,სან-მიგელ-დე-ტუკუმანი,サン・ミゲル・デ・トゥクマン,圣米格尔-德图库曼,산미겔데투쿠만', -26.8241400, -65.2226000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1509, 'San Martín de los Andes', 'San Martin de los Andes', 'Andu San Martinas,Andų San Martinas,CPC,San Martin de Los Andes,San Martin de los Andes,San Martín de Los Andes,San Martín de los Andes,San-Martin-De-Los-Andes,sheng ma ding de luo si an di si,Сан-Мартин-Де-Лос-Андес,סן מרטין דה לוס אנדס,聖馬丁德洛斯安第斯', -40.1578900, -71.3533700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1510, 'San Martín', 'San Martin', 'General San Martin,General San Martín,San Martin,San Martín,san martyn,sheng ma ding,sn mrtyn,סן מרטין,سان مارتين,سان مارتین,聖馬丁', -33.0810300, -68.4681400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1511, 'San Martín', 'San Martin', 'San Martin,San Martín', -31.4295700, -68.5006500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1512, 'San Luis', 'San Luis', 'Ciudad de San Luis,LUQ,San Luis,San Luisas,San-Luis,Sanctus Ludovicus,san lwys,san lwyys,san-luisi,sanlu-iseu,sheng lu yi si,Сан Луис,Сан-Луис,Сан-Луїс,Սան Լուիս,סן לואיס,سان لوئیس,سان لوئیس، ارجنٹائن,سان لويس,სან-ლუისი,サン・ルイス,聖路易斯,산루이스', -33.2950100, -66.3356300, 'AR', '2016-09-05', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1513, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', -32.7434100, -60.7361300, 'AR', '2016-07-05', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1514, 'San Justo', 'San Justo', 'San Justo', -30.7891300, -60.5918900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1515, 'San Juan', 'San Juan', 'Ciudad de San Juan,Gorad San-Khuan,Lalawigan ng San Juan,San Chuanas,San Juan,San Juan de la Frontera,San Khuan,San Xuan,San-Khuan,Sanctus Ioannes a Cuio,UAQ,san jwan,san khwan  alarjntyn,san khwan  arzhantyn,san-khuani,sanfuan,sanhuan,sheng hu an,Горад Сан-Хуан,Сан Хуан,Сан-Хуан,Սան Խուան,סן חואן,سان جوآن,سان خوآن، آرژانتین,سان خوآن، ارجنٹائن,سان خوان، الأرجنتين,სან-ხუანი,サンフアン,圣胡安,산후안', -31.5375000, -68.5363900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1516, 'San José de la Dormida', 'San Jose de la Dormida', '', -30.3544000, -63.9487100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1517, 'San José de Jáchal', 'San Jose de Jachal', 'Jachal,Jáchal,San Chose de Chacalis,San Chose de Chačalis,San Jose de Jachal,San José de Jáchal,sheng he sai de ha cha er,聖何塞德哈查爾', -30.2405700, -68.7469300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1518, 'San José', 'San Jose', 'Piedra Blanca,San Jose,San Jose de Fray Mamerto Esquiu,San José,San José de Fray Mamerto Esquiú', -28.3833300, -65.7000000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1519, 'San Jorge', 'San Jorge', '', -31.8961800, -61.8598400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1520, 'San Isidro', 'San Isidro', 'San Isidro', -28.4626500, -65.7258500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1521, 'San Francisco del Monte de Oro', 'San Francisco del Monte de Oro', 'San Francisco,San Francisco del Monte de Oro', -32.5982500, -66.1253900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1522, 'San Francisco del Chañar', 'San Francisco del Chanar', 'San Francisco de Chanar,San Francisco de Chañar,San Francisco del Chanar,San Francisco del Chañar', -29.7899100, -63.9386100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1523, 'San Francisco', 'San Francisco', 'San Francisco,San Fransiskas,san fransyskw,san fransyskw  qrtbt,sheng fu lang xi si ke,sn prnsysqw,סן פרנסיסקו,سان فرانسيسكو، قرطبة,سان فرانسیسکو,聖弗朗西斯科', -31.4279700, -62.0826600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1524, 'San Fernando del Valle de Catamarca', 'San Fernando del Valle de Catamarca', 'CTC,Catamarca,Katamarka,San Fernando del Vale de Katamarka,San Fernando del Valle de Catamarca,San Fernando del Valye de Katamarka,San-Fernando-del''-Vaje-de-Katamarka,San-Fernando-del''-Val''e-de-Katamarka,San-Fernando-del''-Valle-de-Katamarkae,ka ta ma ka,qtmrqh,san frnandw dyl faly dy katamarka,san frnandw dyl wyla dy katamarka,san frnandwdl wlh dkatamarka,san-pernando-del-valie-de-kʼatʼamarkʼa,sanpeleunandodelbayedekatamaleuka,Катамарка,Сан Фернандо дел Вале де Катамарка,Сан-Фернандо-дель-Вайє-де-Катамарка,Сан-Фернандо-дель-Валле-де-Катамаркæ,Сан-Фернандо-дель-Валье-де-Катамарка,Սան Ֆերնանդո դել Վալյե դե Կատամարկա,קטמרקה,سان فرناندو دل والے دے کاتامارکا,سان فرناندو ديل فالي دي كاتاماركا,سان فرناندو دیل ویلا دی کاتامارکا,سان فرناندودل وله دکاتامارکا,სან-ფერნანდო-დელ-ვალიე-დე-კატამარკა,サン・フェルナンド・デル・バジェ・デ・カタマルカ,卡塔马卡,산페르난도델바예데카타마르카', -28.4695700, -65.7852400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1525, 'San Cristóbal', 'San Cristobal', 'San Cristobal,San Cristóbal', -30.3105300, -61.2372400, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1526, 'San Carlos de Bolívar', 'San Carlos de Bolivar', 'Bolivar,Bolívar,San Carlos de Bolivar,San Carlos de Bolívar', -36.2500000, -61.1000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1527, 'San Carlos Centro', 'San Carlos Centro', 'San Carlos Centro', -31.7286400, -61.0919200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1528, 'San Carlos', 'San Carlos', 'San Carlos,San Carlos Minas', -31.1776100, -65.1024500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1529, 'San Carlos', 'San Carlos', 'San Carlos', -25.8861800, -65.9294100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1530, 'San Blas de los Sauces', 'San Blas de los Sauces', 'San Blas,San Blas de los Sauces', -28.4105100, -67.0934100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1531, 'San Bernardo', 'San Bernardo', 'San Bernardo', -27.2878200, -60.7125200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1532, 'San Benito', 'San Benito', 'San Benito', -31.7837100, -60.4415600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1533, 'San Basilio', 'San Basilio', '', -33.4976300, -64.3149500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1534, 'San Antonio Oeste', 'San Antonio Oeste', 'OES,Puerto San Antonio Oeste,San Antonio Oeste,San Antonio Oestė,xi sheng an dong ni ao,西圣安东尼奥', -40.7319300, -64.9476900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1535, 'San Antonio de los Cobres', 'San Antonio de los Cobres', 'San Antonio de los Cobres,San Antonio de los Kobresas,sheng an dong ni ao de luo si ke bu lei si,סן אנטוניו דה לוס קוברס,聖安東尼奧德洛斯科布雷斯', -24.2180400, -66.3187700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1536, 'San Antonio de Litín', 'San Antonio de Litin', 'Capilla de San Antonio,San Antonio,San Antonio de Litin,San Antonio de Litín', -32.2137700, -62.6323700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1537, 'San Antonio', 'San Antonio', 'San Antonio', -28.0092700, -65.7121800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1538, 'San Antonio', 'San Antonio', 'San Antonio', -24.3675300, -65.3347100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1539, 'San Agustín de Valle Fértil', 'San Agustin de Valle Fertil', 'San Agustin,San Agustin de Valle Fertil,San Agustín,San Agustín de Valle Fértil,Villa San Agustin,Villa San Agustín', -30.6335300, -67.4682100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1540, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', -31.9768100, -64.3740000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1541, 'Samuhú', 'Samuhu', 'Samuhi,Samuhu,Samuhú', -27.5211600, -60.3916700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1542, 'Sampacho', 'Sampacho', '', -33.3839000, -64.7221100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1543, 'Salto', 'Salto', 'M. Ugarte,Marcelino Ugarte,Salto', -34.2929200, -60.2545500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1544, 'Salta', 'Salta', 'Ciudad de Salta,Gorad Sal''ta,SLA,Sal''ta,Salta,Salta llaqta,Saltaurbo,sa er ta,salta,saruta,slth,Σάλτα,Горад Сальта,Салта,Сальта,Սալտա,סלטה,سالتا,साल्टा,სალტა,サルタ,萨尔塔,살타', -24.7859000, -65.4116600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1545, 'Salsipuedes', 'Salsipuedes', '', -31.1372500, -64.2958900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1546, 'Salsacate', 'Salsacate', 'Salsacate', -31.3164900, -65.0852900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1547, 'Salliqueló', 'Salliquelo', 'Salliquelo,Salliqueló', -36.7521600, -62.9605300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1548, 'Saldán', 'Saldan', '', -31.3026200, -64.3070000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1549, 'Sacanta', 'Sacanta', '', -31.6630000, -63.0450500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1550, 'Rufino', 'Rufino', 'Rufino', -34.2682700, -62.7126200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1551, 'Rosario de Lerma', 'Rosario de Lerma', 'Rosario de Lerma', -24.9820600, -65.5789100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1552, 'Rosario de la Frontera', 'Rosario de la Frontera', 'Rosario de la Frontera', -25.7969300, -64.9709400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1553, 'Rosario', 'Rosario', 'ROS,Rasarya,Rosarijas,Rosario,Rosário,Rozariyo,Rozarîyo,Urbs Rosariensis,losalio,luo sa li ao,luo sha li ao,ro sa ri xo,rojhariyo,rosari''o,rosario,rwsaryw,rwsaryw  santa fh,Ροσάριο,Расарыа,Росарио,Росаріо,Ռոսարիո,רוסאריו,روساريو,روساریو، سانتا فه,روساریو، سانتا فے,रोझारियो,রোসারিও,โรซารีโอ,როსარიო,ロサリオ,罗萨里奥,羅沙里奧,로사리오', -32.9468200, -60.6393200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1554, 'Roldán', 'Roldan', 'Roldan,Roldán', -32.8984600, -60.9068100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1555, 'Rojas', 'Rojas', 'Rojas', -34.1952800, -60.7350000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1556, 'Rodeo', 'Rodeo', '', -30.2118600, -69.1366100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1557, 'Rivadavia', 'Rivadavia', 'Rivadavia', -33.1905100, -68.4608100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1558, 'Rivadavia', 'Rivadavia', 'Rivadavia', -31.5538900, -68.6525000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1559, 'Rivadavia', 'Rivadavia', 'Rivadavia', -24.1883200, -62.8902100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1560, 'Río Tercero', 'Rio Tercero', 'Rio Tercero,Río Tercero', -32.1730100, -64.1140500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1561, 'Río Segundo', 'Rio Segundo', '', -31.6526000, -63.9099000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1562, 'Río Pico', 'Rio Pico', 'Campo del Rio Pica,Campo del Río Pica,Estancia Campo del Pico,Rio Pica,Rio Pico,Río Pico', -44.1790500, -71.3684700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1563, 'Río Mayo', 'Rio Mayo', 'Paso Rio Mayo,Paso Rio de Mayo,Paso Río Mayo,ROY,Rio Majo,Rio Mayo,Rosa,Río Mayo,Рио Майо', -45.6857300, -70.2579700, 'AR', '2017-03-24', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1564, 'Río Grande', 'Rio Grande', 'RGA,Rio Grande,Rio Grande pa Eldlandet,Rio Grande på Eldlandet,Rio Grandė,Rio-Grande,Río Grande,li ao ge lan de,liogeulande,ryw ghrandy  tyyra dyl fwyghw,ryw grandh  tyra dl fwygw,Рио-Гранде,ריו גראנדה,ريو غراندي، تييرا ديل فويغو,ریو گرانده، تیرا دل فوئگو,リオ・グランデ,里奧格蘭德,리오그란데', -53.7876900, -67.7094600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1565, 'Río Gallegos', 'Rio Gallegos', 'Gallegos,Puerto Gallegos,Puerto Rio Gallegos,Puerto Río Gallegos,RGL,Rio Galegos,Rio Galjegosas,Rio Gallegos,Rio Galyegos,Rio-Gal''egos,Río Gallegos,li ao jia ye ge si,liogayegoseu,rio-galiegosi,ryw galygws,ryw galygws  santa krwz,ryw ghalyghws  santa krwz,ryw gzgws,rywgalgws,Рио Галегос,Рио-Гальегос,Ріо-Гальєгос,Ռիո Գալյեգոս,ריו גזגוס,ريو غاليغوس، سانتا كروز,ریو گالیگوس,ریو گالیگوس، سانتا کروز,ریوگالگوس,რიო-გალიეგოსი,リオ・ガジェゴス,里奥加耶戈斯,리오가예고스', -51.6226100, -69.2181300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1566, 'Río Cuarto', 'Rio Cuarto', 'Ciudad de Rio Cuarto,Ciudad de Río Cuarto,RCU,Rio Cuarto,Rio Kuartas,Rio Kuarto,Rio Kvarto,Rio-Kuarto,Rio-Kvarto,Río Cuarto,li ao kua er tuo,liokualeuto,ryw kwartw,ryw kwartw  qrtbt,Рио Кварто,Рио Куарто,Рио-Куарто,Ріо-Кварто,Ռիո Կուարտո,ריו קוארטו,ريو كوارتو، قرطبة,ریو کوارتو,რიო-კუარტო,リオ・クアルト,里奥夸尔托,리오쿠아르토', -33.1306700, -64.3499200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1567, 'Río Colorado', 'Rio Colorado', 'Pichi-Mauida,Rio Colorado,Río Colorado,li ao ke luo la duo,Пичи-Мауида,里奧科洛拉多', -38.9939700, -64.0929500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1568, 'Río Ceballos', 'Rio Ceballos', 'Rio Ceballos,Rio Zeballos,Río Ceballos,Río Zeballos', -31.1648600, -64.3224100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1569, 'Rinconada', 'Rinconada', 'Rinconada', -22.4408300, -66.1677900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1570, 'Recreo', 'Recreo', '', -31.4907600, -60.7329900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1571, 'Recreo', 'Recreo', 'Recreo,Rekreo,lei ke lei ao,lekeule-o,rekureo,Рекрео,Ռեկրեո,レクレオ,雷克雷奧,레크레오', -29.2818400, -65.0609600, 'AR', '2016-02-03', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1572, 'Realicó', 'Realico', 'Realico,Realicó', -35.0365800, -64.2447000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1573, 'Rawson', 'Rawson', 'Rausonopolis,Rawson,Roson,Rosona,Rosonas,Rouson,Ruosuons,lauson,luo sen,rauson,ravsoni,rawswn,rawswn  chwbwt,rwswn  tshwbwt,Росон,Роусон,Ռոսոն,ראוסון,راوسون,راوسون، چوبوت,روسون، تشوبوت,რავსონი,ラウソン,罗森,라우손', -43.3001600, -65.1022800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1574, 'Rancul', 'Rancul', 'Jardon,Jardón,Rancul', -35.0686200, -64.6810700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1575, 'Ramallo', 'Ramallo', 'Ramallo', -33.4848200, -60.0070700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1576, 'Rafaela', 'Rafaela', 'RAF,Rafaehla,Rafaela,la fei la,ra fa xela,rafayla,rafayyla,rapaela,Рафаэла,רפאלה,رافائلا,رافاييلا,ราฟาเอลา,რაფაელა,拉斐拉', -31.2503300, -61.4867000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1577, 'Rada Tilly', 'Rada Tilly', 'Rada Tili,Rada Tilli,Rada Tilly', -45.9333300, -67.5333300, 'AR', '2012-01-18', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1578, 'Quitilipi', 'Quitilipi', 'Quitilipi', -26.8691300, -60.2168300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1579, 'Quimilí', 'Quimili', 'Quimili,Quimilí', -27.6333300, -62.4166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1580, 'Quilino', 'Quilino', 'Quilino,Villa Quilino', -30.2139700, -64.5006300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1581, 'Quemú Quemú', 'Quemu Quemu', 'Quemu Quemu,Quemú Quemú', -36.0546300, -63.5642800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1582, 'Punta Alta', 'Punta Alta', 'Punta Alta,Punta-Al''ta,bwnta alta,peng ta a er ta,puntaalta,Пунта-Альта,بونتا ألتا,蓬塔阿尔塔,푼타알타', -38.8758800, -62.0735900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1583, 'Puerto Santa Cruz', 'Puerto Santa Cruz', 'Puerto Santa Cruz,Puerto Santa Krusas,RZA,Santa Cruz,sheng ke lu si gang,聖克魯斯港', -50.0191000, -68.5232100, 'AR', '2017-03-25', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1584, 'San Julián', 'San Julian', 'Puerto San Julian,Puerto San Julián,San Julian,San Julián,ULA', -49.3055400, -67.7274300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1585, 'Puerto Madryn', 'Puerto Madryn', 'Madryn,Madrynhyd,Madrynhȳð,PMY,Porth Madryn,Pouerto Madrin,Puehrto-Madrin,Puerto Madrinas,Puerto Madryn,Pureto Madrin,bwyrtw madryn,ma de lin gang,pwrtw madryn,Πουέρτο Μάδριν,Пуэрто-Мадрин,Պուրետո Մադրին,פוארטו מדרין,بويرتو مادرين,پورتو مادرین,馬德林港', -42.7692000, -65.0385100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1586, 'Puerto Deseado', 'Puerto Deseado', 'Deseado,PUD,Puerto Deseadas,Puerto Deseado,de sai a duo gang,פוארטו דסאדו,德塞阿多港', -47.7503400, -65.8938200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1587, 'Puerta de Corral Quemado', 'Puerta de Corral Quemado', 'Puerta,Puerta de Corral Quemado', -27.2300000, -66.9363500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1588, 'Puelches', 'Puelches', 'Curaco,Curacó,Puelches', -38.1456200, -65.9142600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1589, 'Puan', 'Puan', 'Puan', -37.5457600, -62.7672300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1590, 'Presidencia Roque Sáenz Peña', 'Presidencia Roque Saenz Pena', 'PRQ,Presidencia Roque Saenz Pena,Presidencia Roque Sáenz Peña,Presidensija Roke Saens Penja,Presidente Roque Saenz Pena,Presidente Roque Sáenz Peña,Roque Saenz Pena,Roque Sáenz Peña,SZQ,brysdns rwky saynz bynya,luo ke sa en si pei ni ya zong tong cheng,rwkh saynz pnya,פרסידנסיה רוקה סאנס פניה,بريسدنس روكي ساينز بينيا,روکه سائنز پنیا,პრესიდენსია-როკე-საენს-პენია,羅克薩恩斯培尼亞總統城', -26.7852200, -60.4387600, 'AR', '2016-10-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1591, 'Pozo Hondo', 'Pozo Hondo', 'Pozo Hondo', -27.1660700, -64.4900000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1592, 'Pozo del Tigre', 'Pozo del Tigre', 'Pozo del Tigre', -24.8968200, -60.3235900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1593, 'Pozo del Molle', 'Pozo del Molle', '', -32.0186000, -62.9198400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1594, 'Porteña', 'Portena', '', -31.0139100, -62.0665000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1595, 'Pomán', 'Poman', 'Peman,Poman,Pomán', -28.3945500, -66.2205200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1596, 'Pocito', 'Pocito', 'Pocito', -31.6833300, -68.5833300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1597, 'Plottier', 'Plottier', 'Plottier', -38.9666700, -68.2333300, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1598, 'Plaza Huincul', 'Plaza Huincul', 'Plaza Huincul', -38.9259800, -69.2086300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1599, 'Piquillín', 'Piquillin', 'Piquilin,Piquillin,Piquillín', -31.3015800, -63.7578800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1600, 'Pilcaniyeu', 'Pilcaniyeu', 'Estancia Pilcaniyeu,Pilcaniyeu', -41.1188100, -70.7291400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1601, 'Pilar', 'Pilar', 'Pilar', -31.6789000, -63.8796400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1602, 'Pigüé', 'Piguee', 'Pigue,Pigüé', -37.6050900, -62.4033300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1603, 'Piedra del Águila', 'Piedra del Aguila', 'Piedra de Aguila,Piedra del Aguila,Piedra del Águila', -40.0481100, -70.0741000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1604, 'Picún Leufú', 'Picun Leufu', 'Picun Leufu,Picún Leufú', -39.5235100, -69.2796600, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1605, 'Pico Truncado', 'Pico Truncado', 'Pico Troncado,Pico Truncado,Piko Trunkadas,Piko Trunkado,pyqw trwnqdw,Пико Трункадо,Պիկո Տրունկադո,פיקו טרונקדו', -46.7949000, -67.9573100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1606, 'Perito Moreno', 'Perito Moreno', 'Lago Buenos Aires,PMQ,Perito Moreno,Rio Fenix,Río Fénix,Перито Морено', -46.5899500, -70.9297500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1607, 'Pergamino', 'Pergamino', 'Pergamino,Пергамино', -33.8899500, -60.5735700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1608, 'Pérez', 'Perez', 'Perez,Pérez', -32.9983500, -60.7679100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1609, 'Pellegrini', 'Pellegrini', 'Carlos Pellegrini,Pellegrini', -36.2658400, -63.1655000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1610, 'Pehuajó', 'Pehuajo', 'PEH,Pehuajo,Pehuajó,Peouacho,pei wa huo,phwakhw,Πεουαχό,پهواخو,佩瓦霍', -35.8107700, -61.8968000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1611, 'Patquía', 'Patquia', 'Patquia,Patquía', -30.0468100, -66.8823100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1612, 'Paso de Indios', 'Paso de Indios', 'Paso de Indios,Paso de los Indios', -43.8622500, -69.0460300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1613, 'Pasco', 'Pasco', '', -32.7473300, -63.3423200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1614, 'Pascanas', 'Pascanas', 'Pascanas', -33.1255000, -63.0408400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1615, 'Parera', 'Parera', 'Parera', -35.1460000, -64.5008900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1616, 'Paraná', 'Parana', 'Cittae de Parana,PRA,Parana,Paranà,Paraná,ba la na,barana  antry ryws,palana,parana,prnh,Çittæ de Paraná,Παρανά,Парана,Պարանա,פרנה,بارانا، انتري ريوس,پارانا,پارانا، انترے ریوس,პარანა,パラナ,巴拉那,파라나', -31.7319700, -60.5238000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1617, 'Pampa de los Guanacos', 'Pampa de los Guanacos', 'Kilometro 325,Kilómetro 325,Pampa de los Guanacos', -26.2333300, -61.8500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1618, 'Pampa del Infierno', 'Pampa del Infierno', 'Pampa del Infierno', -26.5051700, -61.1743600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1619, 'Palpalá', 'Palpala', 'Palpala,Palpalá', -24.2564700, -65.2116300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1620, 'Palma Sola', 'Palma Sola', 'Palma Sola,Palma Sota', -23.9633600, -64.2987200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1621, 'Oro Verde', 'Oro Verde', 'Oro Verde', -31.8250800, -60.5174900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1622, 'Ordóñez', 'Ordonez', 'General Ordonez,Ordonez,Ordóñez', -32.8405700, -62.8655200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1623, 'Oncativo', 'Oncativo', 'Oncativo', -31.9135300, -63.6820100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1624, 'Olta', 'Olta', 'Olta', -30.6311700, -66.2630000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1625, 'Oliva', 'Oliva', 'Oliva,Olivia', -32.0415800, -63.5697800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1626, 'Olavarría', 'Olavarria', 'OVR,Olavarija,Olavarria,Olavarrija,Olavarría,ao la wa li ya,awlafarya,awlawarya,olavaria,xo la bar ri xa,Олаварија,Олаваррия,أولافاريا,اولاواریا,โอลาบาร์รีอา,ოლავარია,奧拉瓦里亞', -36.8927200, -60.3225400, 'AR', '2017-02-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1627, 'Obispo Trejo', 'Obispo Trejo', 'Obispo Trejo,San Antonio', -30.7812800, -63.4134900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1628, 'Nueve de Julio', 'Nueve de Julio', '9 de Julio,Nev-de-Khulio,Nueve de Julio,Нев-де-Хулио', -35.4443700, -60.8831300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1629, 'Nueve de Julio', 'Nueve de Julio', '9 de Julio,Nueve de Julio', -31.6691400, -68.3902300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1630, 'Nueva Esperanza', 'Nueva Esperanza', 'Nueva Esperanza', -26.1990700, -64.2379200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1631, 'Ñorquinco', 'Norquinco', 'Norquinco,Ñorquinco', -41.8507200, -70.9017300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1632, 'Noetinger', 'Noetinger', '', -32.3659700, -62.3112600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1633, 'Neuquén', 'Neuquen', 'Ciuda de Neuquen,Ciudad de Neuquen,Ciudad de Neuquén,Ciudá de Neuquén,Gorad Neuken,NQN,Nequen,Neuken,Neukenas,Neuquen,Neuquén,Vila de Neuquen,Vila de Neuquén,n''yukvina,ne-uken,nei wu ken,neuken,nywkn,nywkwyn,Горад Неўкен,Неукен,Նեուկեն,נאוקן,نئوکن,نيوكوين,نیوکوئن,نیوکوین,न्यूक्वीन,ნეუკენი,ネウケン,内乌肯,네우켄', -38.9516100, -68.0591000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1634, 'Naschel', 'Naschel', '', -32.9165600, -65.3753500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1635, 'Napenay', 'Napenay', 'Napenay', -26.7333300, -60.6166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1636, 'Mutquín', 'Mutquin', 'Mudquin,Mutquin,Mutquín', -28.3210400, -66.1425300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1637, 'Morteros', 'Morteros', 'Morteros', -30.7116400, -61.9986200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1638, 'Morrison', 'Morrison', '', -32.5948000, -62.8345500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1639, 'Monteros', 'Monteros', 'Monteros', -27.1674100, -65.4983200, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1640, 'Monte Quemado Airport', 'Monte Quemado Airport', 'Aeropuerto de Monte Quemado,Monte Quemado', -25.8056500, -62.8301900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1641, 'Monte Maíz', 'Monte Maiz', 'Monte Maiz,Monte Maize,Monte Maíz', -33.2046200, -62.6008500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1642, 'Monte Hermoso', 'Monte Hermoso', 'Balneario Monte Hermoso', -38.9825000, -61.2947200, 'AR', '2016-01-31', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1643, 'Monte Cristo', 'Monte Cristo', '', -31.3431200, -63.9443700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1644, 'Monte Buey', 'Monte Buey', '', -32.9164200, -62.4566900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1645, 'Molinos', 'Molinos', 'Molinos', -25.4395000, -66.2912600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1646, 'Miramar', 'Miramar', 'Miramar', -30.9185900, -62.6781400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1647, 'Mina Clavero', 'Mina Clavero', 'Mina Clavero', -31.7210100, -65.0061900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1648, 'Milagro', 'Milagro', 'El Milagro,Milagro', -31.0032600, -66.0009800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1649, 'Miguel Riglos', 'Miguel Riglos', 'M. Riglos,Miguel Riglos', -36.8539800, -63.6884200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1650, 'Metán', 'Metan', 'Metan,Metán', -25.4990500, -64.9738800, 'AR', '2016-02-02', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1651, 'Merlo', 'Merlo', 'Merlas,Merlo,RLO,Villa de Merlo', -32.3428800, -65.0139600, 'AR', '2015-06-07', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1652, 'Mendoza', 'Mendoza', 'Capital megye,Ciuda de Mendoza,Ciudad de Mendoza,Ciudá de Mendoza,Gorad Mendosa,MDZ,Mendos,Mendosa,Mendosae,Mendoza,Mentosa,Vila de Mendoza,men do sa,men duo sa,mendosa,mendoza,mndwsh,mndwza,myndwza,Μεντόσα,Горад Мендоса,Мендоза,Мендосæ,Мендоса,Մենդոսա,מנדוסה,مندوزا,مندوسا، ارجنٹائن,میندوزا,मेन्दोज़ा,เมนโดซา,მენდოსა,メンドーサ,门多萨,멘도사', -32.8908400, -68.8271700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1653, 'Mendiolaza', 'Mendiolaza', '', -31.2673800, -64.3008700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1654, 'Melincué', 'Melincue', 'Melincue,Melincué,San Urbano,Urbano', -33.6584700, -61.4545900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1655, 'Médanos', 'Medanos', '', -38.8280300, -62.6935500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1656, 'Mattaldi', 'Mattaldi', 'Mataldi,Mattaldi', -34.4819400, -64.1725500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1657, 'Marull', 'Marull', 'Kilometro 267,Kilómetro 267,Marull', -30.9947100, -62.8257600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1658, 'Mariano Moreno', 'Mariano Moreno', 'Covunco,Covunco Centro,M. Moreno,Mariano Moreno', -38.7502900, -70.0236700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1659, 'Marcos Juárez', 'Marcos Juarez', 'Marcos Juarez,Marcos Juárez', -32.6978000, -62.1067200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1660, 'Maquinchao', 'Maquinchao', 'MQD,Maquinchao', -41.2500000, -68.7333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1661, 'Malvinas Argentinas', 'Malvinas Argentinas', 'Malvinas Argentinas', -31.3833300, -64.0666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1662, 'Malargüe', 'Malarguee', 'LGS,Malargoue,Malargue,Malarguee,Malarguje,Malargujė,Malargüe,Villa Malargue,Villa Malargüe,ma la gui,Μαλάργουε,马拉圭', -35.4754500, -69.5842700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1663, 'Malanzán', 'Malanzan', 'Malanzan,Malanzán', -30.8039400, -66.6090800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1664, 'Malagueño', 'Malagueno', '', -31.4646700, -64.3584000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1665, 'Maipú', 'Maipu', 'Maipu,Maipú', -32.9796300, -68.7846100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1666, 'Mainque', 'Mainque', 'Mainque', -39.0666700, -67.3000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1667, 'Maimará', 'Maimara', 'Maimara,Maimará', -23.6239200, -65.4079700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1668, 'Machagai', 'Machagai', 'Machagai', -26.9261400, -60.0495500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1669, 'Macachín', 'Macachin', 'Macachin,Macachín', -37.1359800, -63.6665000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1670, 'San Isidro de Lules', 'San Isidro de Lules', 'Lules,San Isidro de Lules', -26.9277000, -65.3386900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1671, 'Luján de Cuyo', 'Lujan de Cuyo', 'Lujan,Lujan de Cuyo,Luján,Luján de Cuyo', -33.0354700, -68.8778200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1672, 'Luján', 'Lujan', 'Lujan,Luján', -32.3757000, -65.9296000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1673, 'Los Varela', 'Los Varela', 'Los Varela,Varela', -27.9548200, -65.8655000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1674, 'Los Telares', 'Los Telares', 'Los Telares', -28.9847900, -63.4488900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1675, 'Los Surgentes', 'Los Surgentes', '', -32.9845400, -62.0219100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1676, 'Los Menucos', 'Los Menucos', 'LMD,Los Menucos', -40.8440200, -68.0871800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1677, 'Los Juríes', 'Los Juries', 'Los Juries,Los Juríes', -28.4653900, -62.1086200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1678, 'Los Frentones', 'Los Frentones', 'Los Frentones,Los Frontones', -26.4077000, -61.4136700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1679, 'Los Cóndores', 'Los Condores', 'Condores,Cóndores,Los Condores,Los Cóndores', -32.3198300, -64.2775100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1680, 'Los Antiguos', 'Los Antiguos', 'Los Antiguos', -46.5497200, -71.6308600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1681, 'Los Altos', 'Los Altos', 'Altos,Los Altos', -28.0484500, -65.4994500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1682, 'Lonquimay', 'Lonquimay', 'Lonquimay,Pueblo Quintana', -36.4654600, -63.6242900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1683, 'Londres', 'Londres', 'Londres', -27.7143900, -67.1334900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1684, 'Loncopué', 'Loncopue', 'LCP,Loncopue,Loncopué', -38.0728400, -70.6160900, 'AR', '2017-03-25', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1685, 'Lincoln', 'Lincoln', 'Lincoln', -34.8664900, -61.5302000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1686, 'Limay Mahuida', 'Limay Mahuida', 'Limay Mahuida', -37.1595900, -66.6759500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1687, 'Libertador General San Martín', 'Libertador General San Martin', 'Libertador General San Martin,Libertador General San Martín,San Martin,San Martín', -32.4107400, -65.6758600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1688, 'Libertador General San Martín', 'Libertador General San Martin', 'General San Martin,Ledesma,Libertador General San Martin,Libertador General San Martín', -23.8064400, -64.7875700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1689, 'Leones', 'Leones', 'Leones,Peron,Perón', -32.6617400, -62.2967800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1690, 'Leleque', 'Leleque', 'Cholila,Leleque,Leteque', -42.4122500, -71.0679700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1691, 'La Viña', 'La Vina', 'La Vina,La Viña', -25.4664200, -65.5663000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1692, 'La Toma', 'La Toma', 'Cuatro de Junio,La Toma', -33.0525800, -65.6238500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1693, 'La Tigra', 'La Tigra', '', -27.1099600, -60.5871900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1694, 'Las Varillas', 'Las Varillas', '', -31.8720800, -62.7194600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1695, 'Las Varas', 'Las Varas', '', -31.8026000, -62.6165500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1696, 'Las Rosas', 'Las Rosas', 'Las Rosas', -32.4766100, -61.5804100, 'AR', '2016-06-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1697, 'Las Plumas', 'Las Plumas', 'Las Plumas', -43.7205800, -67.2831900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1698, 'Las Perdices', 'Las Perdices', '', -32.6979400, -63.7063400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1699, 'Las Parejas', 'Las Parejas', 'Las Parejas', -32.6847800, -61.5163700, 'AR', '2016-06-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1700, 'Las Ovejas', 'Las Ovejas', 'Las Ovejas', -36.9888100, -70.7499100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1701, 'Las Lomitas', 'Las Lomitas', 'LLS,Las Lomitas', -24.7095500, -60.5930300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1702, 'Las Lajitas', 'Las Lajitas', 'Las Lajitas', -24.6833300, -64.2500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1703, 'Las Lajas', 'Las Lajas', 'Las Lajas', -38.5232200, -70.3674500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1704, 'Las Junturas', 'Las Junturas', '', -31.8312500, -63.4501600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1705, 'Las Higueras', 'Las Higueras', '', -33.0923100, -64.2889900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1706, 'Las Heras', 'Las Heras', 'Colonia Las Heras,LHS,Las Heras', -46.5418600, -68.9359300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1707, 'Las Heras', 'Las Heras', 'Las Heras', -32.8527300, -68.8283700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1708, 'Las Coloradas', 'Las Coloradas', 'Las Coloradas,Las Koloradas,Las Koloradasas,Las-Koloradas,la si ke luo la da si,Лас-Колорадас,Լաս Կոլորադաս,拉斯科洛拉達斯', -39.5553400, -70.5949100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1709, 'Las Breñas', 'Las Brenas', 'Las Brenas,Las Breñas', -27.0896600, -61.0816100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1710, 'Las Acequias', 'Las Acequias', 'Las Acequias,Las Acequitas,Las Arequias', -33.2815500, -63.9761000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1711, 'La Rioja', 'La Rioja', 'A Rioxa,Ciudad de La Rioja,Gorad La-Ryjokha,IRJ,La Riocha,La Rioja,La Rioja llaqta,La Riokha,La Rioxa,La-Riokha,Larjoha,Rioja,Riokha,la li ao ha,la rywja,la rywkha,la rywkha  arzhantyn,la-riokha,lalioha,lh rywhh,Горад Ла-Рыёха,Ла Риоха,Ла-Риоха,Ла-Ріоха,Риоха,Լա Ռիոխա,לה ריוחה,لا ريوخا,لا ریؤجا,لا ریوجا، ارجنٹین,لا ریوخا، آرژانتین,ლა-რიოხა,ラ・リオハ,拉里奧哈,라리오하', -29.4110500, -66.8506700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1712, 'La Quiaca', 'La Quiaca', 'La Kiaka,La Quiaca,La-K''jaka,la ji ya ka,Ла-Кьяка,Լա Կիակա,לה קיאקה,拉基亞卡', -22.1023600, -65.5929900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1713, 'La Puerta de San José', 'La Puerta de San Jose', '', -27.5500000, -67.0166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1714, 'La Puerta', 'La Puerta', 'La Puerta', -28.1703600, -65.7901500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1715, 'Laprida', 'Laprida', 'Laprida', -37.5441500, -60.7996900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1716, 'La Poma', 'La Poma', 'La Poma,Poma', -24.7219600, -66.2010600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1717, 'La Playosa', 'La Playosa', '', -32.1000200, -63.0308800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1718, 'La Paz', 'La Paz', 'La Paz', -33.4609100, -67.5495600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1719, 'La Para', 'La Para', '', -30.8941600, -63.0010700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1720, 'La Merced', 'La Merced', 'La Merced,Merced', -28.1519500, -65.6602900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1721, 'La Mendieta', 'La Mendieta', 'La Mendieta', -24.3118700, -64.9637700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1722, 'La Maruja', 'La Maruja', 'La Maruja', -35.6736000, -64.9399700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1723, 'Lamarque', 'Lamarque', 'Lamarque', -39.4230400, -65.7020800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1724, 'Laguna Yema', 'Laguna Yema', 'Laguna Yema', -24.2539100, -61.2446600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1725, 'Laguna Paiva', 'Laguna Paiva', 'Laguna Paiva,Reynaldo Cullen', -31.3039100, -60.6589400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1726, 'Laguna Larga', 'Laguna Larga', '', -31.7765200, -63.8010400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1727, 'La Granja', 'La Granja', '', -31.0091900, -64.2686900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1728, 'Lago Puelo', 'Lago Puelo', 'Lago Puelo', -42.0809500, -71.6140500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1729, 'La Francia', 'La Francia', '', -31.4067500, -62.6339600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1730, 'La Falda', 'La Falda', 'La Falda,La-Fal''da,Ла-Фальда,لا فالڈا', -31.0884100, -64.4898700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1731, 'La Cumbre', 'La Cumbre', 'LCM,La Cumbre', -30.9820100, -64.4913900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1732, 'La Consulta', 'La Consulta', 'La Consulata,La Consulta', -33.7357900, -69.1218100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1733, 'La Cocha', 'La Cocha', 'La Cocha', -27.7772900, -65.5703500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1734, 'La Clotilde', 'La Clotilde', 'La Clotilde', -27.1333300, -60.6666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1735, 'La Cesira', 'La Cesira', '', -33.9511500, -62.9723800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1736, 'La Carlota', 'La Carlota', 'La Carlota,La Karlota,la ka er luo ta,لا کارلوٹا، ارجنٹائن,拉卡爾洛塔', -33.4199300, -63.2976900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1737, 'La Candelaria', 'La Candelaria', 'Candelaria,La Candelaria', -26.1270800, -65.0496000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1738, 'La Cañada', 'La Canada', 'La Canada,La Cañada', -27.7082600, -63.7736600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1739, 'La Calera', 'La Calera', '', -31.3437700, -64.3352900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1740, 'La Caldera', 'La Caldera', 'Caldera,La Caldera', -24.6015900, -65.3809800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1741, 'Laboulaye', 'Laboulaye', 'Laboulaye', -34.1266200, -63.3911900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1742, 'Laborde', 'Laborde', 'Laborde,Las Liebres', -33.1531900, -62.8566100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1743, 'La Banda', 'La Banda', 'La Banda', -27.7334800, -64.2427800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1744, 'Justo Daract', 'Justo Daract', 'Justo Daract,Justo Daraet', -33.8594000, -65.1827700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1745, 'Justiniano Posse', 'Justiniano Posse', 'J. Posse,Justiniano Posse', -32.8841100, -62.6778800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1746, 'Junín de los Andes', 'Junin de los Andes', 'Andu Chuninas,Andų Chuninas,Junin de los Andes,Junín de los Andes,hu ning de luo si an di si,胡寧德洛斯安第斯', -39.9504300, -71.0693600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1747, 'Junín', 'Junin', 'Chuninas,JNI,Junin,Junín,hu ning,khunini,khwnyn,جونين، مقاطعة بوينس آيرس,خونین,ხუნინი,胡寧', -34.5838200, -60.9433200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1748, 'Junín', 'Junin', 'Junin,Junín,Villa Junin,Villa Junín', -33.1476500, -68.4789900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1749, 'José de San Martín', 'Jose de San Martin', 'Colonia San Martin,Colonia San Martín,General J. de San Martin,General J. de San Martín,JSM,Jose de San Martin,José de San Martín,San Martin,San Martín', -44.0503200, -70.4696700, 'AR', '2017-03-25', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1750, 'Joaquín V. González', 'Joaquin V. Gonzalez', 'J.V. Gonzalez,J.V. González,Joaquin V. Gonzalez,Joaquín V. González', -25.0833300, -64.1833300, 'AR', '2016-02-02', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1751, 'Jesús María', 'Jesus Maria', 'Jesus Maria,Jesús María', -30.9815300, -64.0942400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1752, 'James Craik', 'James Craik', '', -32.1612000, -63.4668800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1753, 'Jacinto Arauz', 'Jacinto Arauz', 'J. Arauz,Jacinto Arauz', -38.0860600, -63.4316900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1754, 'Italó', 'Italo', '', -34.7923700, -63.7819900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1755, 'Isla Verde', 'Isla Verde', '', -33.2410400, -62.4029700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1756, 'Iruya', 'Iruya', 'Iruya,yi lu ya,伊魯亞', -22.7666700, -65.2333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1757, 'Intendente Alvear', 'Intendente Alvear', 'Intendente Alvear', -35.2338300, -63.5920500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1758, 'Inriville', 'Inriville', '', -32.9442400, -62.2302800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1759, 'Ingenio La Esperanza', 'Ingenio La Esperanza', 'Ingenio La Esperanza,La Esperanza', -24.2255400, -64.8389600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1760, 'Ingeniero Luis A. Huergo', 'Ingeniero Luis A. Huergo', 'Ingeniero Huergo,Ingeniero L.A. Huergo,Ingeniero Luis A. Huergo', -39.0833300, -67.2333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1761, 'Ingeniero Luiggi', 'Ingeniero Luiggi', 'Ingeniero Luiggi', -35.3858500, -64.4651900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1762, 'Ingeniero Jacobacci', 'Ingeniero Jacobacci', 'Hakobasi,IGB,Inchenjero Chakobacis,Inchenjero Chakobačis,Ingeniero Jacobacci', -41.3292000, -69.5501500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1763, 'Ingeniero Guillermo N. Juárez', 'Ingeniero Guillermo N. Juarez', 'Guillermo N. Juarez,Guillermo N. Juárez,Ingeniero G.N. Juarez,Ingeniero G.N. Juárez,Ingeniero Guillermo N. Juarez,Ingeniero Guillermo N. Juárez,Ingeniero Juarez', -23.9000000, -61.8500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1764, 'Idiazábal', 'Idiazabal', 'Ideazabal,Idiazabal,Idiazábal', -32.8141100, -63.0325200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1765, 'Icaño', 'Icano', 'Icano,Icaño', -28.9193400, -65.3281700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1766, 'Humahuaca', 'Humahuaca', 'Humahuaca', -23.2054400, -65.3504800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1767, 'Huinca Renancó', 'Huinca Renanco', 'Huinca Renanco,Huinca Renancó', -34.8403800, -64.3758000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1768, 'Huillapima', 'Huillapima', 'Huillapima', -28.7253300, -65.9787000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1769, 'Huerta Grande', 'Huerta Grande', '', -31.0752400, -64.4906300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1770, 'Huanchillas', 'Huanchillas', 'Huanchilla,Huanchillas', -33.6665300, -63.6370100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1771, 'Hualfín', 'Hualfin', 'Hualfin,Hualfín', -27.2289600, -66.8313100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1772, 'Hoyo de Epuyén', 'Hoyo de Epuyen', '', -42.0718900, -71.5081100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1773, 'Hersilia', 'Hersilia', '', -30.0044700, -61.8408000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1774, 'Herrera', 'Herrera', '', -28.4809400, -63.0677900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1775, 'Hernando', 'Hernando', 'Hernando', -32.4265700, -63.7333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1776, 'Hernández', 'Hernandez', '', -32.3373000, -60.0216000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1777, 'Hermoso Campo', 'Hermoso Campo', 'Hermoso Campo', -27.6081600, -61.3444100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1778, 'Henderson', 'Henderson', 'Henderson', -36.3000000, -61.7166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1779, 'Helvecia', 'Helvecia', 'Helvecia', -31.0983400, -60.0883000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1780, 'Guatraché', 'Guatrache', 'Guatrache,Guatraché', -37.6677600, -63.5302100, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1781, 'Guatimozín', 'Guatimozin', '', -33.4614900, -62.4384400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1782, 'Guaminí', 'Guamini', 'Guamini,Guaminí', -37.0333300, -62.4166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1783, 'Guachipas', 'Guachipas', 'Guachipas', -25.5203100, -65.5093700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1784, 'Graneros', 'Graneros', 'Graneros', -27.6493400, -65.4383000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1785, 'Granadero Baigorria', 'Granadero Baigorria', 'Granadero Baigorria,Granadero Baigorrio,Paganini', -32.8568300, -60.7175400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1786, 'Godoy Cruz', 'Godoy Cruz', 'Goday Cruz,Godoy Cruz', -32.9286300, -68.8351000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1787, 'Gobernador Gregores', 'Gobernador Gregores', 'Canadon Leon,Cañadón León,GGS,Gobernador Gregores', -48.7505700, -70.2474100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1788, 'Gobernador Gálvez', 'Gobernador Galvez', 'Galvez,Gobernador Galvez,Gobernador Gálvez,Villa Gobernador Galvez,Villa Gobernador Gálvez', -33.0301600, -60.6404500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1789, 'Gobernador Costa', 'Gobernador Costa', 'Gobernador Costa,Gobernor Costa', -44.0499200, -70.5979800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1790, 'General Villegas', 'General Villegas', 'General Villegas,Kheneral Vilegas,VGS,Хенерал Вилегас', -35.0328500, -63.0125200, 'AR', '2016-11-29', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1791, 'General Viamonte', 'General Viamonte', 'General Viamonte,Los Toldos', -35.0001400, -61.0350800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1792, 'General San Martín', 'General San Martin', 'General San Martin,General San Martín,Jose de San Martin,José de San Martín,Villa Alba', -37.9790400, -63.6044900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1793, 'General Roca', 'General Roca', 'Cheneral Roka,Ciudad de General Roca,Fuerte General Roca,GNR,General Roca,Kheneral'',hnrl rwqh,jnral rwka  ryw nyghrw,khnral rwka,luo ka jiang jun shi,Хенераль,חנרל רוקה,جنرال روكا، ريو نيغرو,خنرال روکا,ხენერალ-როკა,羅卡將軍市', -39.0333300, -67.5833300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1794, 'General Roca', 'General Roca', '', -32.7319600, -61.9159900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1795, 'General Ramírez', 'General Ramirez', 'General Ramirez,General Ramírez,Ramirez,Ramírez,Villa Ramirez,Villa Ramírez', -32.1760100, -60.2007900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1796, 'General Pinto', 'General Pinto', 'General Pinto,General Pintos', -34.7645900, -61.8909300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1797, 'General Pinedo', 'General Pinedo', 'General Pinedo,pi nei duo jiang jun zhen,皮內多將軍鎮', -27.3166700, -61.2833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1798, 'General Pico', 'General Pico', 'Cheneral Pikas,GPO,General Pico,Pico,hnrl pyqw,jynral bykw,khnral pykw,pi ke jiang jun zhen,חנרל פיקו,جينرال بيكو,خنرال پیکو,皮科將軍鎮', -35.6566200, -63.7568200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1799, 'General Martín Miguel de Güemes', 'General Martin Miguel de Gueemes', 'General Guemes,General Güemes,General Martin M. de Guemes,General Martin Miguel de Guemes,General Martín M. de Güemes,General Martín Miguel de Güemes,Guemes,Güemes', -24.6703400, -65.0476500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1800, 'General Manuel J. Campos', 'General Manuel J. Campos', 'General M.J. Campos,General Manuel Campos,General Manuel J. Campos', -37.4602500, -63.5853700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1801, 'General Levalle', 'General Levalle', '', -34.0147200, -63.9241300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1802, 'General Lavalle', 'General Lavalle', 'General Lavalle,Lavalle,Tulumaya,Villa Tulumaya', -32.7221800, -68.5913700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1803, 'General La Madrid', 'General La Madrid', '', -37.2475500, -61.2627300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1804, 'General Fernández Oro', 'General Fernandez Oro', 'General Fernandez Oro,General Fernández Oro', -38.9529700, -67.9248900, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1805, 'General Enrique Mosconi', 'General Enrique Mosconi', '', -23.2166700, -62.3000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1806, 'General Enrique Mosconi', 'General Enrique Mosconi', 'Ciro Echesortu,General Enrique Mosconi,General Mosconi,Vespucio', -22.5958800, -63.8125500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1807, 'General Enrique Godoy', 'General Enrique Godoy', 'General E. Godoy,General Enrique Godoy,Godoy', -39.0833300, -67.1500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1808, 'General Conesa', 'General Conesa', 'Conesa,General Conesa', -40.1000000, -64.4333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1809, 'General Cabrera', 'General Cabrera', 'Cabrera,General Cabrera', -32.8131300, -63.8724300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1810, 'General Baldissera', 'General Baldissera', 'Colonia General Baldissera,General Baldissera', -33.1224600, -62.3063000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1811, 'General Arenales', 'General Arenales', 'Arenales,General Arenales', -34.3026400, -61.3052200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1812, 'General Alvear', 'General Alvear', 'General Alvear', -36.0207800, -60.0145000, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1813, 'General Alvear', 'General Alvear', 'Colonia de General Alvear,General Alvear', -34.9769600, -67.6911600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1814, 'General Acha', 'General Acha', 'General Acha', -37.3769800, -64.6043100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1815, 'Gastre', 'Gastre', 'Gastre,Gastres', -42.2751400, -69.2196700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1816, 'Garza', 'Garza', 'Garsa,Garza', -28.1532100, -63.5393500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1817, 'Gancedo', 'Gancedo', 'Gancedo', -27.4903800, -61.6757100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1818, 'Gálvez', 'Galvez', 'Galvez,Gálvez', -32.0292700, -61.2210300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1819, 'Gaimán', 'Gaiman', 'Gaiman,Gaimán', -43.2897000, -65.4929000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1820, 'Funes', 'Funes', 'Funes', -32.9156800, -60.8099500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1821, 'Frías', 'Frias', 'Frias,Frías', -28.6359300, -65.1310200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1822, 'Fray Luis Beltrán', 'Fray Luis Beltran', 'Fray L. Beltran,Fray L. Beltrán,Fray Luis Beltran,Fray Luis Beltrán,Luis Beltran,Luis Beltrán', -39.3166700, -65.7666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1823, 'Fray Luis A. Beltrán', 'Fray Luis A. Beltran', 'Borghi,Fray Luis A. Beltran,Fray Luis A. Beltrán,Fray Luis Beltran,Fray Luís Beltrán', -32.7912200, -60.7281900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1824, 'Fraile Pintado', 'Fraile Pintado', 'Fraile Pintado', -23.9407900, -64.7994300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1825, 'Firmat', 'Firmat', 'Firmat', -33.4593700, -61.4832000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1826, 'Fiambalá', 'Fiambala', 'Fiambala,Fiambalá', -27.6870500, -67.6149000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1827, 'Fernández', 'Fernandez', 'Fernandez,Fernández', -27.9203700, -63.8934900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1828, 'Famatina', 'Famatina', 'Famatina', -28.9232200, -67.5225300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1829, 'Famaillá', 'Famailla', 'Famailla,Famaillá', -27.0541300, -65.4032900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1830, 'Etruria', 'Etruria', '', -32.9400800, -63.2466000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1831, 'Estanislao del Campo', 'Estanislao del Campo', 'Estancia del Campo,Estanislao del Campo', -25.0550400, -60.0921800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1832, 'Esquel', 'Esquel', 'EQS,Ehskel'',Eskelis,Esquel,ai si ke er,ayskywl,Эскель,אסקל,آيسكيول,埃斯克爾', -42.9114700, -71.3194700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1833, 'Esperanza', 'Esperanza', 'Esperanza', -31.4488000, -60.9317300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1834, 'Embarcación', 'Embarcacion', 'Embarcacion,Embarcación,ZAI', -23.2100300, -64.0996500, 'AR', '2015-05-23', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1835, 'Embalse', 'Embalse', 'Embalse', -32.1800000, -64.4180900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1836, 'Embajador Martini', 'Embajador Martini', 'Embajador Martini', -35.3863300, -64.2809200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1837, 'El Trébol', 'El Trebol', 'El Trebol,El Trébol', -32.2008000, -61.7014000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1838, 'El Tío', 'El Tio', '', -31.3835700, -62.8293800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1839, 'El Simbolar', 'El Simbolar', 'El Simbolar,Simbolar', -27.9716700, -64.8954400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1840, 'El Rodeo', 'El Rodeo', 'El Rodeo,Rodeo', -28.2151800, -65.8742000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1841, 'El Quebrachal', 'El Quebrachal', 'El Quebrachal', -25.2833300, -64.0666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1842, 'El Maitén', 'El Maiten', 'EMX,El Maiten,El Maitén,Estancia El Maiten,Estancia El Maitén', -42.0492400, -71.1669300, 'AR', '2017-03-25', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1843, 'El Huecú', 'El Huecu', 'El Huecu,El Huecú', -37.6452200, -70.5800600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1844, 'El Hoyo', 'El Hoyo', 'El Hoyo,Hoyo', -27.0287200, -63.2319700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1845, 'El Galpón', 'El Galpon', 'El Galpon,El Galpón', -25.3806900, -64.6525900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1846, 'Elena', 'Elena', '', -32.5720500, -64.3948100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1847, 'El Cuy', 'El Cuy', 'El Cuy', -39.9268500, -68.3420800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1848, 'El Carril', 'El Carril', 'Carril,El Carril', -25.0741000, -65.4917400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1849, 'El Carmen', 'El Carmen', 'Carmen,El Carmen', -24.3868200, -65.2617700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1850, 'El Calafate', 'El Calafate', 'Calafate,Caserio de Calafates,Caserío de Calafates,Ehl'' Kalafate,El Calafate,El Kalafate,El Kalafatė,El''-Kalafate,FTE,Lago Argentino,Pueblo Calafate,ai er ka la fa te,alkalafat,elkallapate,karafate,Ель-Калафате,Эль Калафате,אל קלפטה,الكالافات,エル・カラファテ,カラファテ,埃尔卡拉法特,엘칼라파테', -50.3407500, -72.2768200, 'AR', '2017-07-20', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1851, 'El Bolsón', 'El Bolson', 'EHL,El Bolson,El Bolsonas,El Bolsón,ai er bo er song,אל בולסון,埃爾博爾松', -41.9605100, -71.5333600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1852, 'El Arañado', 'El Aranado', '', -31.7412000, -62.8932200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1853, 'El Alto', 'El Alto', 'El Alto,Villa El Alto', -28.3112300, -65.3639700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1854, 'El Aguilar', 'El Aguilar', 'Aguilar,El Aguilar', -23.2258200, -65.6921300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1855, 'Eduardo Castex', 'Eduardo Castex', 'Castex,E. Castex,Eduardo Castex', -35.9150100, -64.2944800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1856, 'Dolavón', 'Dolavon', 'Colonia Dolavon,Colonia Dolavón,Dolavon,Dolavón', -43.3000000, -65.7000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1857, 'Doblas', 'Doblas', '', -37.1496700, -64.0118300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1858, 'Diamante', 'Diamante', 'Diamante', -32.0664100, -60.6383700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1859, 'Devoto', 'Devoto', '', -31.4043100, -62.3063400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1860, 'Despeñaderos', 'Despenaderos', '', -31.8162600, -64.2898900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1861, 'Del Campillo', 'Del Campillo', '', -34.3765900, -64.4950400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1862, 'Deán Funes', 'Dean Funes', 'Dean Funes,Deán Funes', -30.4203600, -64.3498400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1863, 'Darwin', 'Darwin', 'Darwin', -39.2000000, -65.7666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1864, 'Dalmacio Vélez Sársfield', 'Dalmacio Velez Sarsfield', 'D. Velez,D. Velez Sarsfield,D. Vélez,D. Vélez Sársfield,Dalmacio Velez,Dalmacio Velez Sarsfield,Dalmacio Vélez,Dalmacio Vélez Sársfield', -32.6107200, -63.5803800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1865, 'Daireaux', 'Daireaux', 'Caseros,Daireaux', -36.6000000, -61.7500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1866, 'Cutral-Có', 'Cutral-Co', 'CUT,Cutrai-Co,Cutrai-Có,Cutral-Co,Cutral-Có,Eva Peron,Eva Perón', -38.9342400, -69.2305200, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1867, 'Cuchillo Có', 'Cuchillo Co', '', -38.3334900, -64.6433100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1868, 'Cruz del Eje', 'Cruz del Eje', 'Cruz del Eje', -30.7264400, -64.8038700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1869, 'Cruz Alta', 'Cruz Alta', '', -33.0088700, -61.8074600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1870, 'Crespo', 'Crespo', 'Crespo', -32.0287300, -60.3065800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1871, 'Costa Sacate', 'Costa Sacate', '', -31.6477000, -63.7593500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1872, 'Cosquín', 'Cosquin', 'Cosquin,Cosquín,Koskinas,ke si jin,kwskywn,كوسكيون,科斯金', -31.2450800, -64.4656300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1873, 'Corzuela', 'Corzuela', 'Corzuela', -26.9537400, -60.9692800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1874, 'Corralito', 'Corralito', '', -32.0246200, -64.1921600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1875, 'Corral de Bustos', 'Corral de Bustos', 'Corral de Bustos', -33.2820500, -62.1846300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1876, 'Coronel Suárez', 'Coronel Suarez', 'CSZ,Coronel Suarez,Coronel Suárez,Koronel Suarez,Koronel''-Suarez,Коронел Суарез,Коронель-Суарез', -37.4546700, -61.9334300, 'AR', '2016-03-06', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1877, 'Coronel Pringles', 'Coronel Pringles', 'Coronel Pringles,Pringles', -37.9829500, -61.3561500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1878, 'Coronel Moldes', 'Coronel Moldes', 'Coronel Moldes,Moldes', -33.6227000, -64.5971100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1879, 'Coronel Du Graty', 'Coronel Du Graty', 'Coronel Du Graty', -27.6803800, -60.9146200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1880, 'Coronel Dorrego', 'Coronel Dorrego', 'Coronel Dorrego,Dorrego', -38.7186700, -61.2873300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1881, 'Coronel Belisle', 'Coronel Belisle', 'Coronel Belisle', -39.1833300, -65.9833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1882, 'Coronel Baigorria', 'Coronel Baigorria', '', -32.8477000, -64.3610700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1883, 'Coronda', 'Coronda', 'Cordona,Coronda', -31.9726300, -60.9198300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1884, 'Córdoba', 'Cordoba', 'COR,Ciudad de Cordoba,Ciudad de Córdoba,Cordoba,Cordoba i Argentina,Cordova,Corduba,Còrdoba,Córdoba,Córdoba i Argentina,Córdova,Gorad Kordava,Kordoba,Kordobo,Kordov,Kordova,Kordova khot,Kordovae,Kuorduoba,Vila de Cordoba,Vila de Córdoba,kardwba,ke er duo wa,koleudoba,kordoba,korudoba,kwrdwba,kwrdwba  arzhantyn,kxr do ba,qwrdwbh,Κόρδοβα,Горад Кордава,Кордоба,Кордовæ,Кордова,Кордова хот,Կորդովա,קארדאבע,קורדובה,قرطبہ، ارجنٹائن,كوردوبا,کاردوبا,کوردوبا، آرژانتین,कोर्दोबा,กอร์โดบา,კორდოვა,コルドバ,科尔多瓦,코르도바', -31.4135000, -64.1810500, 'AR', '2016-07-29', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1885, 'Contraalmirante Cordero', 'Contraalmirante Cordero', 'Contraalmirante Cordero,Contralmirante Cordero', -38.7242300, -68.1528400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1886, 'Concepción del Bermejo', 'Concepcion del Bermejo', 'Concepcion del Bermejo,Concepción del Bermejo', -26.5992600, -60.9461700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1887, 'Concepción', 'Concepcion', 'Concepcion,Concepción,Konsepsjonas,kang sai pu xi weng,knspsywn  twkwman,kwnsbsywn  twkwman,qwnspsywn,קונספסיון,كونسبسيون، توكومان,کنسپسیون، توکومان,康塞普西翁', -27.3412700, -65.5963600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1888, 'Concarán', 'Concaran', 'Concaran,Concarán,Concoran,Dolores,Villa Dolores', -32.5600900, -65.2427000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1889, 'Comodoro Rivadavia', 'Comodoro Rivadavia', 'CRD,Comodoro,Comodoro Rivadavia,Komodoro Rivadavija,Komodoro-Rivadavija,Komorodo Rivadavia,komodololibadabia,kwmwdwrw ryfadafya,kwmwdwrw rywadawya,li wa da wei ya hai jun zhun jiang cheng,qwmwdwrw rybdbyh,Комодоро Ривадавия,Комодоро Ривадавија,Комодоро-Ривадавия,Комодоро-Рівадавія,Կոմորոդո Ռիվադավիա,קומודורו ריבדביה,كومودورو ريفادافيا,کومودورو ریواداویا,コモドーロ・リバダビア,里瓦达维亚海军准将城,코모도로리바다비아', -45.8641300, -67.4965600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1890, 'Comandante Luis Piedra Buena', 'Comandante Luis Piedra Buena', 'Casa de Piedra,Comandante L. Piedrabuena,Comandante Luis Piedra Buena,El Paso,Piedra Buena', -49.9851300, -68.9146700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1891, 'Comallo', 'Comallo', 'Comallo', -41.0299300, -70.2678400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1892, 'Colonia San Bartolomé', 'Colonia San Bartolome', 'Colonia San Bartolome,Colonia San Bartolomé,San Bartolome,San Bartolomé', -31.5278000, -62.7243600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1893, 'Colonia La Tordilla', 'Colonia La Tordilla', '', -31.2374600, -63.0613400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1894, 'Colonia Dora', 'Colonia Dora', 'Colonia Dora', -28.6000000, -62.9500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1895, 'Colonia Barón', 'Colonia Baron', 'Colonia Baron,Colonia Barón', -36.1515200, -63.8540400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1896, 'Colón', 'Colon', 'Colon,Colón', -33.8951200, -61.1011000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1897, 'Clodomira', 'Clodomira', 'Clodomira', -27.5744000, -64.1310800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1898, 'Cipolletti', 'Cipolletti', 'CPZ,Chipolletti,Cipoletis,Cipoletti,Cipolleti,Cipolletti,kybwlyty,sypwyty,xi bo lie di,zypwlty,Čipoletis,Чиполлетти,Чіполлетті,Չիպոլետի,ציפולטי,سیپویتی,كيبوليتي,სიპოლიეტი,西波列蒂', -38.9339200, -67.9903200, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1899, 'Cintra', 'Cintra', '', -32.3067300, -62.6521400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1900, 'Cinco Saltos', 'Cinco Saltos', 'Cinco Saltos', -38.8222500, -68.0629300, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1901, 'Chumbicha', 'Chumbicha', 'Chumbicha', -28.8543000, -66.2350000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1902, 'Chos Malal', 'Chos Malal', 'Chos Malal,Chos-Malal'',Cos Malalis,HOS,qiao si ma la er,Čos Malalis,Чос-Малаль,Չոս Մալալ,喬斯馬拉爾', -37.3780900, -70.2708500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1903, 'Chorotis', 'Chorotis', 'Chorotis', -27.9157800, -61.3998200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1904, 'Choele Choel', 'Choele Choel', 'C. Choel,Choele Choel', -39.2666700, -65.6833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1905, 'Chivilcoy', 'Chivilcoy', 'Chivilcoy,chywylkwy,qi wei er ke yi,tshyfylkwy,تشيفيلكوي,چیویلکوی,奇維爾科伊', -34.8956600, -60.0166700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1906, 'Chimpay', 'Chimpay', 'Chimpay', -39.1648200, -66.1423600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1907, 'Chimbas', 'Chimbas', 'Chimbas', -31.4833300, -68.5333300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1908, 'Chilecito', 'Chilecito', 'Chilecito,Chilesito,Cilesitas,chylsytw,qi lai xi tuo,zylsytw,Čilesitas,Чилесито,Чілесіто,Չիլեսիտո,צילסיטו,چیلسیتو,奇萊西托', -29.1619500, -67.4974000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1909, 'Chicoana', 'Chicoana', 'Chicoana', -25.1008800, -65.5331000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1910, 'Chichinales', 'Chichinales', 'Chichinales,Chinchinales', -39.1150500, -66.9271400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1911, 'Chepes', 'Chepes', '', -31.3500000, -66.6000000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1912, 'Chazón', 'Chazon', '', -33.0787200, -63.2765700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1913, 'Charras', 'Charras', '', -33.0240000, -64.0471900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1914, 'Charata', 'Charata', 'CNT,Charata,Charatas,cha la ta,sharata,شاراتا,查拉塔', -27.2143800, -61.1879500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1915, 'Chamical', 'Chamical', 'Chamical,Gobernador Gordillo', -30.3600200, -66.3139900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1916, 'Chacabuco', 'Chacabuco', 'Chacabuco,Chakabuko,Чакабуко', -34.6416700, -60.4738900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1917, 'Cervantes', 'Cervantes', 'Cervantes', -39.0500000, -67.3833300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1918, 'Cerrillos', 'Cerrillos', 'Cerrillos', -24.8983300, -65.4870600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1919, 'Ceres', 'Ceres', 'CRR,Ceres', -29.8810000, -61.9450400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1920, 'Centenario', 'Centenario', 'Centenario,Colonia Centenario', -38.8295500, -68.1318000, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1921, 'Cavanagh', 'Cavanagh', '', -33.4760600, -62.3388800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1922, 'Caucete', 'Caucete', 'Caucete,Kausete,Kausetė,Villa Colon,Villa Colón,kao sai te,考塞特', -31.6517900, -68.2810500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1923, 'Catriló', 'Catrilo', 'Catrilo,Catriló', -36.4059700, -63.4216800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1924, 'Catriel', 'Catriel', 'CCT,Catriel', -37.8790700, -67.7956000, 'AR', '2016-03-06', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1925, 'Castro Barros', 'Castro Barros', 'Castro Barros', -30.5795200, -65.7269600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1926, 'Castelli', 'Castelli', 'Castelli,Colonia Castelli,J.J. Castelli,Juan Jose Castelli,Juan José Castelli', -25.9467900, -60.6194700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1927, 'Casilda', 'Casilda', 'Casilda', -33.0441700, -61.1680600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1928, 'Carrilobo', 'Carrilobo', '', -31.8729600, -63.1171500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1929, 'Carnerillo', 'Carnerillo', '', -32.9137100, -64.0217500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1930, 'Carmen de Patagones', 'Carmen de Patagones', 'CPG,Carmen de Patagones,Karmen de Patagones,Karmen-de-Patagones,Patagones,qrmn dh ptgwns,Кармен де Патагонес,Кармен-де-Патагонес,Կարմեն դե Պատագոնես,קרמן דה פטגונס', -40.7982800, -62.9809700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1931, 'Carlos Tejedor', 'Carlos Tejedor', 'C. Tejedor,Carlos Tejedor,Tejedor', -35.3926500, -62.4214600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1932, 'Carlos Casares', 'Carlos Casares', 'Antonio Maya,C. Casares,Carlos Casares', -35.6217100, -61.3616900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1933, 'Carhué', 'Carhue', 'Adolfo Alsina,Carhue,Carhué', -37.1766800, -62.7579200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1934, 'Carcarañá', 'Carcarana', 'Carcarana,Carcarañá', -32.8567900, -61.1533100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1935, 'Capitán Bermúdez', 'Capitan Bermudez', 'Capitan Bermudez,Capitán Bermúdez,Juan Ortiz,Juan Ortíz,Villa Cassini', -32.8226200, -60.7185200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1936, 'Capilla del Monte', 'Capilla del Monte', 'Capilla del Monte,Kapilja del Monte,Kapilja del Montė,ka pi ya de er meng te,卡皮亞德爾蒙特', -30.8608800, -64.5251500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1937, 'Capayán', 'Capayan', 'Capayan,Capayán', -28.7610500, -66.0502500, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1938, 'Candelaria', 'Candelaria', 'Candelaria', -32.0603600, -65.8247700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1939, 'Canals', 'Canals', '', -33.5654200, -62.8892700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1940, 'Cañada de Luque', 'Canada de Luque', '', -30.7334100, -63.7237500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1941, 'Cañada de Gómez', 'Canada de Gomez', 'Canada de Gomez,Cañada de Gómez,Ciudad Evita,Ciudad de Gomez,Ciudad de Gómez,Kanada-de-Gomes,Канада-де-Гомес', -32.8163600, -61.3949300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1942, 'Campo Quijano', 'Campo Quijano', 'Campo Quijano,Quijana,Quijano', -24.9098200, -65.6365600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1943, 'Campo Largo', 'Campo Largo', 'Campo Largo', -26.8007700, -60.8421500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1944, 'Campo Gallo', 'Campo Gallo', 'Campo Gallo', -26.5833300, -62.8500000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1945, 'Camilo Aldao', 'Camilo Aldao', 'Aldao,C. Aldao,Caldao,Camilo Aldao', -33.1274500, -62.0945300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1946, 'Camarones', 'Camarones', 'Camarones,Kamaronesas,ka ma luo nei si,卡馬羅內斯', -44.7970900, -65.7099400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1947, 'Calingasta', 'Calingasta', 'Calingasta', -31.3308400, -69.4078300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1948, 'Calilegua', 'Calilegua', 'Calilegua', -23.7736800, -64.7700200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1949, 'Caleufú', 'Caleufu', 'Caleufu,Caleufú', -35.5955900, -64.5577800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1950, 'Caleta Olivia', 'Caleta Olivia', 'CVI,Caleta Olivia,Kaleta Olivia,Kaleta Olivija,Kaleta-Olivija,ka lai ta ao li wei ya,kalta awlywya,Калета-Оливия,Կալետա Օլիվիա,קלטה אוליביה,کالتا اولیویا,卡萊塔奧利維亞', -46.4392900, -67.5281400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1951, 'Calchaquí', 'Calchaqui', 'Calchaqui,Calchaquí,Luis d''Abreu,Luis d’Abreu', -29.8876700, -60.2869700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1952, 'Caimancito', 'Caimancito', 'Caimancito', -23.7406900, -64.5937000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1953, 'Cafayate', 'Cafayate', 'Cafayate,Cafayete,Kafajat,Kafajate,Kafajatė,ka fa ya te,kafayath,Кафайат,קפזאטה,کافایاته,卡法亞特', -26.0728600, -65.9776600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1954, 'Cachí', 'Cachi', 'Cachi,Cachí', -25.1203300, -66.1651900, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1955, 'Buta Ranquil', 'Buta Ranquil', 'Buta Ranquil', -37.0522200, -69.8771300, 'AR', '2017-05-28', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1956, 'Burruyacú', 'Burruyacu', 'Burruyaco,Burruyacu,Burruyacú', -26.4991800, -64.7420600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1957, 'Buena Esperanza', 'Buena Esperanza', 'B. Esperanza,Buena Esperanza', -34.7564700, -65.2537900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1958, 'Buchardo', 'Buchardo', '', -34.7226300, -63.5092000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1959, 'Brinkmann', 'Brinkmann', 'Brinkman,Brinkmann', -30.8658900, -62.0374200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1960, 'Brea Pozo', 'Brea Pozo', 'Brea Pozo', -28.2438200, -63.9509100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1961, 'Bragado', 'Bragado', 'Bragado,QRF,bragadw,braghdw,bu la jia duo,براغدو,براگادو,布拉加多', -35.1191200, -60.4896600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1962, 'Berrotarán', 'Berrotaran', '', -32.4510000, -64.3886700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1963, 'Bernasconi', 'Bernasconi', '', -37.9045900, -63.7424000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1964, 'Bernardo Larroudé', 'Bernardo Larroude', 'B. Larroude,B. Larroudé,Benjamin Larroude,Bernardo Larroude,Bernardo Larroudé,Larroude', -35.0244900, -63.5825300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1965, 'Beltrán', 'Beltran', 'Beltran,Beltrán', -27.8291300, -64.0609800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1966, 'Bell Ville', 'Bell Ville', 'Bell Ville,bei er wei er,bl wyl,byl fyl,بل ویل,بيل فيل,貝爾維爾', -32.6259100, -62.6887300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1967, 'Bella Vista', 'Bella Vista', 'Bella Vista', -27.0342400, -65.3019600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1968, 'Belén', 'Belen', 'Belen,Belenas,Belén,bei lun,bln,בלן,貝倫', -27.6510300, -67.0286900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1969, 'Barrancas', 'Barrancas', 'Barrancas', -36.8166700, -69.9166700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1970, 'Bandera', 'Bandera', 'Bandera', -28.8884000, -62.2660000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1971, 'Banda del Río Salí', 'Banda del Rio Sali', 'Banda del Rio Sali,Banda del Río Salí', -26.8333300, -65.1666700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1972, 'Bañado de Ovanta', 'Banado de Ovanta', 'Banado,Banado de Ovanta,Bañado,Bañado de Ovanta', -28.1056400, -65.3188400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1973, 'Balnearia', 'Balnearia', '', -31.0088000, -62.6673300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1974, 'Bahía Blanca', 'Bahia Blanca', 'BHI,Bahia Blanca,Bahija Blanka,Bahía Blanca,Baija Blanka,Baija-Blanka,Baija-Blankae,Bajja-Blanka,bahya blanka,baiabeullangka,baiaburanka,bayya blanka,bu lan ka gang,Баия-Бланкæ,Баия-Бланка,Баија Бланка,Байя-Бланка,Баїя-Бланка,באיה בלנקה,باهيا بلانكا,باییا بلانکا,ბაია-ბლანკა,バイアブランカ,布兰卡港,바이아블랑카', -38.7195900, -62.2724300, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1975, 'Aviá Terai', 'Avia Terai', 'Avia Terai,Aviá Terai', -26.6853200, -60.7292000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1976, 'Arrufó', 'Arrufo', 'Arrufo,Arrufó,Arruto,Arrutó', -30.2328100, -61.7286200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1977, 'Arroyo Seco', 'Arroyo Seco', 'Aguirre,Arroyo Seco,Posta de San Martin,Posta de San Martín', -33.1548900, -60.5086300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1978, 'Arroyo Cabral', 'Arroyo Cabral', '', -32.4911900, -63.4012600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1979, 'Arroyito', 'Arroyito', 'Arroyito', -31.4202200, -63.0500200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1980, 'Arrecifes', 'Arrecifes', 'Arrecifes,Bartolome Mitre,Bartolomé Mitre', -34.0639000, -60.1035700, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1981, 'Arraga', 'Arraga', 'Arraga', -28.0497800, -64.2225400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1982, 'Armstrong', 'Armstrong', 'Armstrong', -32.7821500, -61.6022200, 'AR', '2016-06-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1983, 'Arias', 'Arias', 'Arias', -33.6441100, -62.4027200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1984, 'Arauco', 'Arauco', 'Arauca,Arauco', -28.5805000, -66.7943800, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1985, 'Arata', 'Arata', '', -35.6389500, -64.3562100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1986, 'Aranguren', 'Aranguren', 'Aranguren', -32.2425200, -60.1610700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1987, 'Apolinario Saravia', 'Apolinario Saravia', 'Apolinario Saravia', -24.4327600, -63.9953500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1988, 'Antofagasta de la Sierra', 'Antofagasta de la Sierra', 'Antofagasta de la Sierra', -26.0594000, -67.4063600, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1989, 'Anguil', 'Anguil', 'Anguil', -36.5256700, -64.0102500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1990, 'Añelo', 'Anelo', 'Anelo,Añelo', -38.3544100, -68.7884000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1991, 'Andalgalá', 'Andalgala', 'Andalgala,Andalgalá', -27.6001200, -66.3179400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1992, 'Andacollo', 'Andacollo', 'Andacollo', -37.1794500, -70.6691200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1993, 'Ancasti', 'Ancasti', 'Ancasti', -28.8124700, -65.5014500, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1994, 'Añatuya', 'Anatuya', 'Anatuya,Añatuya,Unatuya,Uñatuya', -28.4606400, -62.8347200, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1995, 'Aminga', 'Aminga', 'Aminga', -28.8426000, -66.9454600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1996, 'Florentino Ameghino', 'Florentino Ameghino', '', -34.8440500, -62.4670100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1997, 'Aluminé', 'Alumine', 'Alumine,Aluminé,Rucachoroi', -39.2368600, -70.9197000, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1998, 'Altos de Chipión', 'Altos de Chipion', '', -30.9559000, -62.3372700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(1999, 'Alto Río Senguer', 'Alto Rio Senguer', 'ARR,Alto Rio Senguer,Alto Rio Senguerr,Alto Río Senguer,Alto Río Senguerr,Brazo Norte', -45.0410500, -70.8198200, 'AR', '2017-03-24', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2000, 'Alta Italia', 'Alta Italia', '', -35.3335000, -64.1149600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2001, 'Alta Gracia', 'Alta Gracia', 'Al''ta-Gracija,Alta Gracia,Alta Grasija,alta ghrasya,alta grasya,shang ge la xi ya,Алта Грасия,Альта-Грация,آلتا گراسیا,ألتا غراسيا,上格拉西亞', -31.6529200, -64.4282600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2002, 'Alpachiri', 'Alpachiri', 'Alpachiri', -37.3770400, -63.7744500, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2003, 'Almafuerte', 'Almafuerte', '', -32.1929600, -64.2555900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2004, 'Allen', 'Allen', 'Allen,LLZ,alyn  ryw ngrw,الین، ریو نگرو', -38.9773600, -67.8271400, 'AR', '2015-12-09', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2005, 'Algarrobo del Águila', 'Algarrobo del Aguila', 'Algarrobo del Aguila,Algarrobo del Aguilla,Algarrobo del Águila,El Aguila,El Aguilla', -36.3996800, -67.1451100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2006, 'Alejo Ledesma', 'Alejo Ledesma', 'A. Ledesma,Alejo Ledesma,Ledesma', -33.6064300, -62.6230400, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2007, 'Alejandro Roca', 'Alejandro Roca', 'Alejandro,Alejandro Roca', -33.3536900, -63.7184900, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2008, 'Alderetes', 'Alderetes', 'Alderetes', -26.8166700, -65.1333300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2009, 'Alberti', 'Alberti', 'Alberti', -35.0269200, -60.2758700, 'AR', '2016-03-10', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2010, 'Albardón', 'Albardon', 'Albardon,Albardón', -31.4372200, -68.5255600, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2011, 'Aimogasta', 'Aimogasta', 'Aimogasta', -28.5609100, -66.8058800, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2012, 'Aguilares', 'Aguilares', 'Aguilares', -27.4338000, -65.6142700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2013, 'Agua de Oro', 'Agua de Oro', '', -31.0666100, -64.3001700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2014, 'Adelia María', 'Adelia Maria', '', -33.6315200, -64.0209700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2015, 'Achiras', 'Achiras', '', -33.1753800, -64.9933100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2016, 'Abra Pampa', 'Abra Pampa', 'Abra Pampa', -22.7204900, -65.6969700, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2017, 'Villa Santa Rita', 'Villa Santa Rita', '', -34.6108200, -58.4810000, 'AR', '2017-05-08', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2018, 'Bella Italia', 'Bella Italia', '', -31.2726800, -61.4239600, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2019, 'Cariló', 'Carilo', 'Karilo,Карило', -37.1652400, -56.8913300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2020, 'Villa Mercedes', 'Villa Mercedes', 'VME,Vila Mersedes,Vilja Mersedesas,biyameleusedeseu,fyla mrsyds  san lwys,mei sai de si zhen,vilia-mersedesi,wyya mrsds,wyzh mrsds,Виља Мерседес,ויזה מרסדס,فيلا مرسيدس، سان لويس,وییا مرسدس,ვილია-მერსედესი,ビジャ・メルセデス,梅塞德斯鎮,비야메르세데스', -33.6757100, -65.4578300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2021, 'La Punta', 'La Punta', '', -33.1836800, -66.3127000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2022, 'Villa Berna', 'Villa Berna', '', -31.9032100, -64.7565100, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2023, 'Cuesta Blanca', 'Cuesta Blanca', '', -31.4865800, -64.5715000, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2024, 'Avellaneda', 'Avellaneda', 'Avel''janeda,Avelaneda,Aveljaneda,a wei ya nei da,abejaneda,abeyaneda,avelianeda,awyanda,Авельянеда,Авелянеда,Авељанеда,אבזאנדה,آویاندا,აველიანედა,アベジャネーダ,阿韦亚内达,아베야네다', -34.6601800, -58.3674400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2025, 'San Carlos de Bariloche', 'San Carlos de Bariloche', 'BRC,Bariloce,Bariloche,Bariloĉe,San Carlos de Bariloche,San Karlos de Bariloce,San Karlos de Bariloche,San Karlos de Bariločė,San-Karlos-de-Bariloche,barylwchh,barylwtshy,bʼrylwzh,sankaleulloseudebalilloche,sheng ka luo si-de ba li luo qie,Сан Карлос де Барилоче,Сан-Карлос-де-Барилоче,Сан-Карлос-де-Барілоче,Սան Կառլոս դե Բարիլոչե,בארילוצה,باريلوتشي,باریلوچه,باریلۆچی,სან-კარლოს-დე-ბარილოჩე,サン・カルロス・デ・バリローチェ,圣卡洛斯-德巴里洛切,산카를로스데바릴로체', -41.1455700, -71.3082200, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2026, 'Santa Catalina - Dique Lujan', 'Santa Catalina - Dique Lujan', '', -34.3837500, -58.7067300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2027, 'Río Turbio', 'Rio Turbio', 'RYO,Rio Turbio,Río Turbio', -51.5358700, -72.3367300, 'AR', '2016-01-30', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2028, 'Adrogué', 'Adrogue', '', -34.8004100, -58.3838400, 'AR', '2015-04-22', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2029, 'Los Laureles', 'Los Laureles', '', -29.3684700, -59.7363400, 'AR', '2016-03-20', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2030, 'Gato Colorado', 'Gato Colorado', '', -28.0221900, -61.1866300, 'AR', '2016-03-20', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2031, 'Tolhuin', 'Tolhuin', '', -54.5108300, -67.1955000, 'AR', '2016-04-19', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2032, 'Villa General Guemes', 'Villa General Guemes', '', -24.7553000, -59.4894000, 'AR', '2016-04-21', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2033, 'Rincón de Los Sauces', 'Rincon de Los Sauces', 'RDS', -37.3984400, -68.9287400, 'AR', '2017-03-24', 11);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2048, 'Neu-Guntramsdorf', 'Neu-Guntramsdorf', '', 48.0642000, 16.3157300, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2049, 'Kleinarl', 'Kleinarl', '', 47.2772500, 13.3195500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2050, 'Edelstauden', 'Edelstauden', 'Edelstauden', 46.9833300, 15.6166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2051, 'Neuhaus am Klausenbach', 'Neuhaus am Klausenbach', 'Dobra,Neuhaus am Klausenbach,Nojkhaus-am-Klauzenbakh,Nojkhaus-na-Klauzenbakhe,Vas-Dobra,Vasdobra,ke lao sen ba he he pan nuo yi hao si,Нойхаус-ам-Клаузенбах,Нойхаус-на-Клаузенбахе,克劳森巴赫河畔诺伊豪斯', 46.8666700, 16.0333300, 'AT', '2013-12-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2052, 'Millstatt', 'Millstatt', 'Mil''shtatt,Millstatt,Millstatt am See,Мильштатт', 46.8041700, 13.5805600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2053, 'Zwölfaxing', 'Zwoelfaxing', '', 48.1099000, 16.4626700, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2054, 'Zwettl Stift', 'Zwettl Stift', 'Stift Zwettl,Zwettl Stift', 48.6166700, 15.2000000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2055, 'Zwettl an der Rodl', 'Zwettl an der Rodl', 'Zwettl,Zwettl an der Rodl', 48.4655200, 14.2713300, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2056, 'Zurndorf', 'Zurndorf', 'Curndorf,Zurany,Zurndorf,Zurány,Цурндорф', 47.9831400, 17.0031500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2057, 'Zöblen', 'Zoblen', 'Zoblen,Zöblen', 47.5077200, 10.4797100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2058, 'Zöbern', 'Zobern', '', 47.5145900, 16.1311100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2059, 'Zistersdorf', 'Zistersdorf', 'Cistejov,Cistersdorf,Zistersdorf,qi si te si duo fu,Čistejov,Цистерсдорф,齊斯特斯多夫', 48.5425200, 16.7613600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2060, 'Zirl', 'Zirl', 'Cirl,Zirl,Цирл', 47.2741000, 11.2396100, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2061, 'Zillingtal', 'Zillingtal', 'Celindrof,Cillingtal'',Voelgyfalva,Völgyfalva,Zillingtal,Циллингталь', 47.8144200, 16.4092800, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2062, 'Zillingdorf', 'Zillingdorf', 'Zillingdorf', 47.8500000, 16.3333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2063, 'Ziersdorf', 'Ziersdorf', 'Cirsdorf,Kiblic,qi si duo fu,Киблиц,Цирсдорф,齐斯多夫', 48.5303000, 15.9269100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2064, 'Zeutschach', 'Zeutschach', 'Zeutschach', 47.0666700, 14.3666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2065, 'Zettling', 'Zettling', 'Zettling', 46.9522000, 15.4342000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2066, 'Zerlach', 'Zerlach', 'Zerlach', 46.9459300, 15.6509300, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2067, 'Zeltweg', 'Zeltweg', 'Cel''tveg,Celtveg,Zeltweg,ce er te wei ge,Целтвег,Цельтвег,策尔特韦格', 47.1833300, 14.7500000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2068, 'Zellerndorf', 'Zellerndorf', '', 48.6965700, 15.9584100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2069, 'Zellberg', 'Zellberg', 'Zellberg', 47.2333300, 11.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2070, 'Zell an der Pram', 'Zell an der Pram', 'Zell,Zell an der Pram', 48.3162500, 13.6292300, 'AT', '2017-06-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2071, 'Zell am Ziller', 'Zell am Ziller', 'Cell''-am-Ciller,Cell''-na-Cillere,Zell,Zell am Ziller,Zell in Zillerthal,qi lei he gu cai er,Целль-ам-Циллер,Целль-ам-Ціллер,Целль-на-Циллере,齐勒河谷采尔', 47.2333300, 11.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2072, 'Zell am See', 'Zell am See', 'Cel am Ze,Cel am Zee,Cell''-am-Ze,Cell''-am-Zee,Zaei am See,Zell am See,Zell in the Pinzgau,Zäi am See,bin hu cai er,chel-amje,tsyl am zyh,Цел ам Зе,Цел ам Зее,Целль-ам-Зе,Целль-ам-Зее,تسيل أم زيه,ツェル・アム・ゼー,滨湖采尔,첼암제', 47.3255600, 12.7944400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2073, 'Zell am Pettenfirst', 'Zell am Pettenfirst', 'Zell am Pettenfirst', 48.0800900, 13.5993600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2074, 'Zell am Moos', 'Zell am Moos', 'Cell''-am-Mos,Cell''-na-Mose,Zell,Zell am Moos,zhao ze fu jin ce er,Целль-ам-Мос,Целль-на-Мосе,沼泽附近策尔', 47.9000000, 13.3166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2075, 'Zeillern', 'Zeillern', '', 48.1302900, 14.8076000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2076, 'Zederhaus', 'Zederhaus', '', 47.1557000, 13.5057600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2077, 'Zams', 'Zams', 'Cams,cha mu si,Цамс,察姆斯', 47.1584400, 10.5897000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2078, 'Zagersdorf', 'Zagersdorf', 'Cogrstof,Cogrštof,Zagersdorf,Zarany,Zárány,Загерсдорф', 47.7647100, 16.5138200, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2079, 'Ybbsitz', 'Ybbsitz', 'Ibzic,yi bu xi ci,Ибзиц,یببسٹز,伊布西茨', 47.9474500, 14.8918000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2080, 'Ybbs an der Donau', 'Ybbs an der Donau', 'Ibbs,Ibosa do Danubio,Ibs-an-der-Donau,Ibs-na-Dunae,Ipozonalco,Ips,Jivice na Dunavu,Ybbs,Ybbs an der Donau,duo nao he pan yi bu si,ybbs an dr dwnw,Íbosa do Danúbio,Îps,Īpozōnalco,İps,Ибс-ан-дер-Донау,Ибс-на-Дунае,یببس ان در دونو,多瑙河畔伊布斯', 48.1666700, 15.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2081, 'Würmla', 'Wurmla', '', 48.2549700, 15.8603100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2082, 'Würflach', 'Wurflach', '', 47.7764800, 16.0546300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2083, 'Wundschuh', 'Wundschuh', 'Wundschuh', 46.9263900, 15.4511100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2084, 'Wullersdorf', 'Wullersdorf', '', 48.6279200, 16.1008900, 'AT', '2013-07-30', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2085, 'Wulkaprodersdorf', 'Wulkaprodersdorf', 'Vul''kaprodersdorf,Vulkapordany,Vulkapordány,Vulkaprodrstof,Vulkaprodrštof,Wulkaprodersdorf,Вулькапродерсдорф', 47.7975300, 16.5044700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2086, 'Wörth an der Lafnitz', 'Woerth an der Lafnitz', 'Worth,Worth an der Lafnitz,Wörth,Wörth an der Lafnitz', 47.2136800, 16.0808100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2087, 'Wörterberg', 'Worterberg', '', 47.2166700, 16.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2088, 'Wörschach', 'Worschach', 'Worschach,Wörschach', 47.5500000, 14.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2089, 'Wörgl', 'Worgl', 'QXZ,V''orgul,Vergl,Vergl'',Vernkl,Vjorgl'',Woergl,Worgl,Wörgl,vergli,vu~eruguru,wo ge er,Βεργκλ,Вергл,Вергль,Вьоргъл,Вёргль,ვერგლი,ヴェルグル,沃格爾', 47.4890600, 12.0617400, 'AT', '2015-11-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2090, 'Wördern', 'Wordern', '', 48.3340000, 16.2101600, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2091, 'Wolkersdorf im Weinviertel', 'Wolkersdorf im Weinviertel', 'Vol''kersdorf-im-Vajnfirtel'',Wolkersdorf,Wolkersdorf im Weinviertel,wei yin de qu wo er ke er si duo fu,Волькерсдорф-им-Вайнфиртель,ವೊಲ್ಕರ್ಸ್ಡೊರ್ಫ್‌,韦因地区沃尔克尔斯多夫', 48.3833300, 16.5166700, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2092, 'Wolfurt', 'Wolfurt', 'Kirchdorf,Vol''furt,Volfurt,Wolfurt,wlfwrt,wo er fu te,Волфурт,Вольфурт,ولفورت,沃尔富特', 47.4666700, 9.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2093, 'Wolfsthal', 'Wolfsthal', 'Vol''fstal'',wo er fu shi ta er,Вольфсталь,וולפסטאל,沃尔夫施塔尔', 48.1333300, 17.0000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2094, 'Wolfsgraben', 'Wolfsgraben', 'Vol''fsgraben,wo er fu si ge la ben,Вольфсграбен,沃尔夫斯格拉本', 48.1587000, 16.1209800, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2095, 'Wolfsegg am Hausruck', 'Wolfsegg am Hausruck', 'Wolfsegg,Wolfsegg am Hausruck', 48.1066900, 13.6727400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2096, 'Wolfsberg im Schwarzautal', 'Wolfsberg im Schwarzautal', 'Wolfsberg,Wolfsberg im Schwarzautal', 46.8438900, 15.6588900, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2097, 'Wolfsberg', 'Wolfsberg', 'Wolfsberg', 46.8405600, 14.8441700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2098, 'Wolfsbach', 'Wolfsbach', '', 48.0666700, 14.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2099, 'Wolfpassing', 'Wolfpassing', '', 48.0778500, 15.0645300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2100, 'Wolfau', 'Wolfau', '', 47.2500000, 16.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2101, 'Winklern bei Oberwölz', 'Winklern bei Oberwoelz', 'Winklern,Winklern bei Oberwolz,Winklern bei Oberwölz', 47.2000000, 14.2333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2102, 'Winklern', 'Winklern', 'Vinklern,wen ke lei en,Винклерн,温克勒恩', 46.8736100, 12.8747200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2103, 'Winklarn', 'Winklarn', '', 48.0833300, 14.8333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2104, 'Windigsteig', 'Windigsteig', '', 48.7666700, 15.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2105, 'Winden am See', 'Winden am See', 'Binta,Sasony,Sásony,Vinden-am-Zee,Winden,Winden am See,Винден-ам-Зее', 47.9500000, 16.7500000, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2106, 'Wimpassing an der Leitha', 'Wimpassing an der Leitha', 'Vimpac,Vimpas,Vimpassing-na-Lajte,Vimpác,Wimpassing,Wimpassing an der Leitha,Вимпассинг-на-Лайте', 47.9166700, 16.4333300, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2107, 'Wimpassing im Schwarzatale', 'Wimpassing im Schwarzatale', '', 47.7029500, 16.0333400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2108, 'Willendorf am Steinfelde', 'Willendorf am Steinfelde', '', 47.7892900, 16.0568600, 'AT', '2012-01-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2109, 'Wilhelmsburg', 'Wilhelmsburg', '', 48.1057100, 15.6053900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2110, 'Wilfersdorf', 'Wilfersdorf', '', 48.5833300, 16.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2111, 'Wildon', 'Wildon', 'Vil''don,Wildon,wei er dong,Вильдон,维尔东', 46.8833300, 15.5166700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2112, 'Wildermieming', 'Wildermieming', '', 47.3166700, 11.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2113, 'Wildalpen', 'Wildalpen', 'Vil''dal''pen,Wildalpen,wei er da er peng,Вильдальпен,维尔达尔彭', 47.6500000, 14.9833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2114, 'Wiesmath', 'Wiesmath', '', 47.6166700, 16.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2115, 'Wiesing', 'Wiesing', '', 47.4048600, 11.7970800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2116, 'Wiesfleck', 'Wiesfleck', '', 47.3845800, 16.1455200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2117, 'Wiesen', 'Wiesen', 'Bizmet,Retfalu,Rétfalu', 47.7377600, 16.3379800, 'AT', '2015-12-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2118, 'Wieselburg', 'Wieselburg', 'Omatoyac,Viselburgo,Vizel''burg,Wieselburg,wei se er bao,Ōmātōyāc,Визельбург,维瑟尔堡', 48.1333300, 15.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2119, 'Wies', 'Wies', 'Vis,wei si,Вис,维斯', 46.7202800, 15.2719400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2120, 'Wiener Neustadt', 'Wiener Neustadt', 'Becko Novo Mjesto,Becsujhely,Becsujvaros,Bečko Novo Mjesto,Bécsújhely,Bécsújváros,Dunajsko Novo mesto,Nemet-Ujhely,Nova civitas Vindobonensis,Német-Újhely,Videnske Nove Mesto,Viedenske Nove Mesto,Viedenské Nové Mesto,Viner Noistat,Viner Nojshhat,Viner Nojshtat,Viner-Nojshtadt,Viner-Nojstadt,Vyner Noistatas,Vyner Noištatas,Vídeňské Nové Město,Weana Neistod,Wiener Neustadt,Wr. Neustadt,bineonoisyutateu,fynr nwyshtat,wei ye na xin cheng,wynr nwyshtat,wynr nwystt,Βίνερ Νόιστατ,Винер Нойщат,Винер Нојштат,Винер-Нойштадт,Вінер-Нойштадт,וינר נוישטט,فينر نويشتات,وینر نویشتات,وینر نیوشٹڈ,ვინერ-ნოიშტადტი,ウィーナー・ノイシュタット,維也納新城,비너노이슈타트', 47.8048500, 16.2319600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2121, 'Wiener Neudorf', 'Wiener Neudorf', 'Vienos Noidorfas,Viner-Nojdorf,wei ye na xin cun,Винер-Нойдорф,維也納新村', 48.0827800, 16.3138400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2122, 'Vienna', 'Vienna', 'Bec,Bech,Becs,Beç,Beč,Bienne,Bécs,Dunaj,VIE,Vena,Viden,Viden'',Vieden,Viedeň,Viena,Vienna,Vienne,Vieno,Viin,Vin,Vinarborg,Vindobona,Viyana,Vídeň,Vín,Vínarborg,Wenen,Wieden,Wiedeń,Wien,bienna,bin,fyyna,weiynna,Βιέννη,Беч,Вена,Виена,Відень,فيينا,เวียนนา,ቪየና,비엔나,빈', 48.2084900, 16.3720800, 'AT', '2017-06-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2123, 'Weyer', 'Weyer', 'Weyer,Weyer Markt,Weyer an der Enns', 47.8571700, 14.6640900, 'AT', '2012-05-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2124, 'Wetzelsdorf', 'Wetzelsdorf', 'Wetzelsdorf', 47.0529300, 15.3992300, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2125, 'Wettmannstätten', 'Wettmannstatten', 'Vettmannshtetten,Vettmannstetten,Wettmannstatten,Wettmannstätten,wei te man si te te en,Веттманнстеттен,Веттманнштеттен,韦特曼斯特特恩', 46.8305600, 15.3872200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2126, 'Westendorf', 'Westendorf', 'Vestendorf,Westendorf,wei shi teng duo fu,Вестендорф,韦施滕多夫', 47.4320800, 12.2140600, 'AT', '2014-07-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2127, 'Wernersdorf', 'Wernersdorf', '', 46.7159200, 15.2071800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2128, 'Werndorf', 'Werndorf', 'Werndorf', 46.9241700, 15.4908300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2129, 'Wernberg', 'Wernberg', '', 46.6166700, 13.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2130, 'Werfenweng', 'Werfenweng', 'Verfenveng,Weng,Werfenweng,Werfnweng,wei er fen weng,Верфенвенг,韦尔芬翁', 47.4620400, 13.2558200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2131, 'Werfen', 'Werfen', 'Verfen,Werfen,Werfm,wei er fen,Верфен,維爾芬', 47.4758500, 13.1902000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2132, 'Weppersdorf', 'Weppersdorf', 'Veperd,Veppersdorf,Veprstof,Veprštof,Verpstof,Verpštof,Wepperschduaf,wei po er si duo fu,Вепперсдорф,韦珀尔斯多夫', 47.5795400, 16.4267900, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2133, 'Wenns', 'Wenns', '', 47.1666700, 10.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2134, 'Wels', 'Wels', 'Ovilava,Vel''s,Wels,wls,Вельс,ולס', 48.1666700, 14.0333300, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2135, 'Weiz', 'Weiz', 'Vajc,Weiz,fayts,wei ci,Вайц,Вајц,فايتس,魏茨', 47.2166700, 15.6166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2136, 'Weitra', 'Weitra', 'Vajtra,Weitra,wei te la,Вайтра,魏特拉', 48.7000000, 14.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2137, 'Weitersfeld', 'Weitersfeld', '', 48.7809700, 15.8134500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2138, 'Weiten', 'Weiten', '', 48.2956400, 15.2601000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2139, 'Weistrach', 'Weistrach', '', 48.0500000, 14.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2140, 'Weißkirchen in Steiermark', 'Weisskirchen in Steiermark', 'Vajskirkhen,Vajskirkhen-in-Shtajermark,Weisskirchen,Weisskirchen in Steiermark,Weißkirchen,Weißkirchen in Steiermark,shi tai er ma ke de qu wei si ji xing,Вайскирхен,Вайскирхен-ин-Штайермарк,施泰尔马克地区魏斯基兴', 47.1500000, 14.7333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2141, 'Weißenbach bei Liezen', 'Weissenbach bei Liezen', 'Weissenbach,Weissenbach bei Liezen,Weißenbach bei Liezen', 47.5666700, 14.2166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2142, 'Weissenbach an der Triesting', 'Weissenbach an der Triesting', 'Vajsenbakh-an-der-Tristing,Weissenbach,Weissenbach an der Triesting,Weißenbach an der Triesting,te li shi ting he pan wei sen ba he,Вайсенбах-ан-дер-Тристинг,特里施廷河畔魏森巴赫', 47.9821100, 16.0393500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2143, 'Weinzierl bei Krems', 'Weinzierl bei Krems', 'Weinzierl,Weinzierl bei Krems', 48.4000000, 15.6000000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2144, 'Weinzierl am Walde', 'Weinzierl am Walde', 'Vajncirl''-am-Val''de,Vajncirl''-na-Val''de,Weinzierl,Weinzierl am Walde,lin pan wei yin qi er,Вайнцирль-ам-Вальде,Вайнцирль-на-Вальде,林畔韦因齐尔', 48.4321100, 15.4321000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2145, 'Weingraben', 'Weingraben', 'Bajngrob,Borosd,Vajngraben,Weingraben,Вайнграбен', 47.5139300, 16.3637500, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2146, 'Weinburg am Saßbach', 'Weinburg am Sassbach', 'Weinburg,Weinburg am Sassbach,Weinburg am Saßbach', 46.7536100, 15.7211100, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2147, 'Weinburg', 'Weinburg', '', 48.1135100, 15.5329500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2148, 'Weiler', 'Weiler', '', 47.2997200, 9.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2149, 'Weikersdorf am Steinfelde', 'Weikersdorf am Steinfelde', 'Weikersdorf', 47.8061200, 16.1438900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2150, 'Weikendorf', 'Weikendorf', '', 48.3443800, 16.7665100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2151, 'Weiden bei Rechnitz', 'Weiden bei Rechnitz', 'Bandol,Bandoly,Bándoly,Vajden-Rekhnic,Weiden,Weiden bei Rechnitz,Вайден-Рехниц', 47.3000000, 16.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2152, 'Weiden am See', 'Weiden am See', 'Vajden-am-Zee,Vedeny,Védeny,Weiden,Вайден-ам-Зее', 47.9253200, 16.8689900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2153, 'Weichselbaum', 'Weichselbaum', '', 46.9425000, 16.1875000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2154, 'Weer', 'Weer', 'Weer', 47.3000000, 11.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2155, 'Wattens', 'Wattens', 'Vatens,Vattens,Wattens,wa teng si,Ватенс,Ваттенс,瓦滕斯', 47.2941900, 11.5907000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2156, 'Wattenberg', 'Wattenberg', '', 47.2833300, 11.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2157, 'Wartmannstetten', 'Wartmannstetten', '', 47.6935900, 16.0750600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2158, 'Warth', 'Warth', '', 47.6500000, 16.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2159, 'Warth', 'Warth', 'Warth', 47.2500000, 10.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2160, 'Wartberg', 'Wartberg', 'St. Barbara,Wartberg,Wartberg im Murztal,Wartberg im Mürztal', 47.5271700, 15.4809500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2161, 'Wängle', 'Wangle', '', 47.4865800, 10.6899500, 'AT', '2012-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2162, 'Wang', 'Wang', '', 48.0453800, 15.0267200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2163, 'Walpersbach', 'Walpersbach', '', 47.7166700, 16.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2164, 'Wallern im Burgenland', 'Wallern im Burgenland', 'Valla,Vallern (Burgenland),Wallern,Wallern im Burgenland,Валлерн (Бургенланд)', 47.7284700, 16.9370600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2165, 'Waldzell', 'Waldzell', 'Val''dcell'',wa er de ce er,Вальдцелль,瓦尔德策尔', 48.1356200, 13.4270100, 'AT', '2014-09-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2166, 'Waldneukirchen', 'Waldneukirchen', 'Waldneukirchen', 47.9985400, 14.2587900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2167, 'Waldkirchen an der Thaya', 'Waldkirchen an der Thaya', 'Waldkirchen,Waldkirchen an der Thaya', 48.9333300, 15.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2168, 'Walding', 'Walding', 'Val''ding,Walding,Вальдинг', 48.3520900, 14.1576000, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2169, 'Wald im Pinzgau', 'Wald im Pinzgau', 'Val''d,Val''d-im-Pincgau,Wald,Wald im Pinzgau,ping ci gao gu de wa er de,Вальд,Вальд-им-Пинцгау,Вальд-ім-Пінцгау,平茨高谷地瓦尔德', 47.2500000, 12.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2170, 'Waldhausen', 'Waldhausen', '', 48.5218300, 15.2625000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2171, 'Waldenstein', 'Waldenstein', '', 48.7284500, 15.0141900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2172, 'Waldegg', 'Waldegg', '', 47.8685200, 16.0515400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2173, 'Wald am Schoberpaß', 'Wald am Schoberpass', 'Wald,Wald am Schoberpass,Wald am Schoberpaß', 47.4493600, 14.6756700, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2174, 'Walchsee', 'Walchsee', 'Val''khze,Val''kse,wa er xi sai,Вальксе,Вальхзе,瓦尔希塞', 47.6516300, 12.3186800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2175, 'Waidring', 'Waidring', '', 47.5833300, 12.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2176, 'Waidmannsfeld', 'Waidmannsfeld', '', 47.8704200, 15.9811600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2177, 'Waidhofen an der Ybbs', 'Waidhofen an der Ybbs', 'Stadt Waidhofen an der Ybbs,Vajdkhofen na Ibsu,Vajdkhofen-na- Ibbse,Vajdkhofen-na-Ibse,Waidhofen,Waidhofen-Ybbs,baiteuhopen-andeeoibseu,vaidhopen-an-der-ibsi,waydhwfn an dr ybs,yi bu si he pan wei de huo fen,Вайдхофен-на- Иббсе,Вайдхофен-на-Ибсе,Вајдхофен на Ибсу,ויידהופן אן דר איבס,وایدهوفن آن در یبس,ვაიდჰოფენ-ან-დერ-იბსი,ヴァイトホーフェン・アン・デア・イプス,伊布斯河畔魏德霍芬,바이트호펜안데어입스', 47.9600400, 14.7736100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2178, 'Waidhofen an der Thaya', 'Waidhofen an der Thaya', 'Vajdkhofen an der Taja,Vajdkhofen na Taji,Vajdkhofen-an-der-Tajja,Waidhofen,Waidhofen an der Thaya,ta ya he pan wei de huo fen,Вайдхофен ан дер Тая,Вайдхофен-ан-дер-Тайя,Вајдхофен на Таји,塔亞河畔魏德霍芬', 48.8166700, 15.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2179, 'Wagrain', 'Wagrain', 'Vagrajn,Wagrain,Wagrin,Wougroa,wa ge lai en,Ваграйн,瓦格赖恩', 47.3352800, 13.2988900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2180, 'Wagna', 'Wagna', 'Vagna,wa ge na,Вагна,瓦格纳', 46.7500000, 15.5500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2181, 'Vösendorf', 'Vosendorf', 'Fjozendorf,fu sen duo fu,Фёзендорф,弗森多夫', 48.1210700, 16.3403600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2182, 'Murau', 'Murau', 'Murau,Murau Vorstadt,Vorstadt Murau,mu lao,Мурау,穆劳', 47.1105600, 14.1694400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2183, 'Vordernberg', 'Vordernberg', 'Fordernberg,Vordernberg,Vordernberg-Markt,fu er deng bei ge,Фордернберг,福尔登贝格', 47.4880900, 14.9943600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2184, 'Vorderhornbach', 'Vorderhornbach', 'Vorderhornbach', 47.3700900, 10.5394700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2185, 'Vorchdorf', 'Vorchdorf', 'Forkhdorf,Vorchdorf,fu er xi duo fu,Форхдорф,福爾希多夫', 48.0038800, 13.9212200, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2186, 'Vorau', 'Vorau', 'Forau,fu lao,Форау,福劳', 47.4054800, 15.8875400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2187, 'Vomp', 'Vomp', 'Fomp,Vomp,fu mu pu,Фомп,福姆普', 47.3333300, 11.6833300, 'AT', '2014-05-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2188, 'Völs', 'Vols', '', 47.2500000, 11.3333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2189, 'Völkermarkt', 'Voelkermarkt', 'Felkermarkt,Fjol''kermarkt,Velikovec,Voelkermarkt,fu er ke ma ke te,fwlkrmarkt,Фелкермаркт,Фёлькермаркт,فولکرمارکت,弗爾克馬克特', 46.6622200, 14.6344400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2190, 'Volders', 'Volders', 'Fol''ders,fu er de er si,Фольдерс,福尔德尔斯', 47.2833300, 11.5666700, 'AT', '2016-03-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2191, 'Voitsberg', 'Voitsberg', 'Fojtsberg,Voitsberg,wo ci bo ge,Фойтсберг,Фојтсберг,沃茨伯格', 47.0333300, 15.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2192, 'Vöcklamarkt', 'Vocklamarkt', 'Fjoklamarkt,Vocklamarkt,Vocklamarkt-am Haushamerfeld,Vöcklamarkt,Vöcklamarkt-am Haushamerfeld,fu ke la ma ke te,Фёкламаркт,弗克拉马克特', 48.0025000, 13.4838300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2193, 'Vöcklabruck', 'Vocklabruck', 'Feklabruk,Fjoklabruk,Fjoklabrukk,Féklabruk,Vocklabruck,Vöcklabruck,fu ke la bu lu ke,fwklabrwk,Феклабрук,Фёклабрук,Фёклабрукк,فوکلابروک,ფეკლაბრუკი,弗克拉布魯克', 48.0027900, 13.6565200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2194, 'Vitis', 'Vitis', '', 48.7596400, 15.1825900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2195, 'Virgen', 'Virgen', 'Firgen,Virgen,fei er gen,frjn,Фирген,Фірген,فرجن,菲尔根', 47.0015900, 12.4566100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2196, 'Vils', 'Vils', 'Vils', 47.5500000, 10.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2197, 'Villach', 'Villach', 'Beljak,Filachas,Filakh,Fillach,Fillaha,Fillakh,Gorad Filakh,QVL,Santicum,Vilac,Villach,Villaco,fei la he,fil lakh,firahha,fylakh,pilakhi,pillaheu,pylʼk,wylakh,Φίλλαχ,Горад Філах,Филах,Филлах,Філлах,פילאך,فیلاخ,ویلاخ,ฟิลลาค,ფილახი,フィラッハ,菲拉赫,필라흐', 46.6102800, 13.8558300, 'AT', '2015-06-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2198, 'Viktorsberg', 'Viktorsberg', '', 47.3009200, 9.6748400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2199, 'Viehhofen', 'Viehhofen', '', 47.3666700, 12.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2200, 'Velden am Wörthersee', 'Velden am Woerthersee', 'Vel''den,Velden,Velden am Woerthersee,Velden am Wörthersee,Вельден', 46.6130100, 14.0413000, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2201, 'Veitsch', 'Veitsch', 'Fajch,fa yi qi,wytsch,Файч,ویتسچ,法伊奇', 47.5781500, 15.4945000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2202, 'Uttendorf', 'Uttendorf', '', 47.2833300, 12.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2203, 'Unterwart', 'Unterwart', 'Alsoor,Alsóor,Untervart,Unterwart,Унтерварт', 47.2500000, 16.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2204, 'Untertauern', 'Untertauern', '', 47.3000000, 13.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2205, 'Unterstinkenbrunn', 'Unterstinkenbrunn', '', 48.6677000, 16.3460700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2206, 'Untersiebenbrunn', 'Untersiebenbrunn', '', 48.2500000, 16.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2207, 'Rohrbach an der Gölsen', 'Rohrbach an der Goelsen', 'Unterrohrbach', 48.0469900, 15.7416900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2208, 'Unterpremstätten', 'Unterpremstaetten', 'Premstatten,Premstätten,Unterpremstatten,Unterpremstetten,Unterpremstätten,Унтерпремстеттен', 46.9647200, 15.4041700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2209, 'Unterperfuss', 'Unterperfuss', '', 47.2666700, 11.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2210, 'Unterlamm', 'Unterlamm', '', 46.9769400, 16.0638900, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2211, 'Unterkohlstätten', 'Unterkohlstatten', '', 47.3833300, 16.3166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2212, 'Grünburg', 'Gruenburg', 'Grjunburg,ge lin bao,Грюнбург,格林堡', 47.9723400, 14.2647200, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2213, 'Unterfrauenhaid', 'Unterfrauenhaid', 'Lok,Lók,Svetica', 47.5711600, 16.4988500, 'AT', '2012-11-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2214, 'Unterfladnitz', 'Unterfladnitz', 'Unterfladnitz', 47.1833300, 15.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2215, 'Unterbergla', 'Unterbergla', '', 46.8074600, 15.3151600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2216, 'Unterauersbach', 'Unterauersbach', 'Unterauersbach', 46.8655600, 15.7702800, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2217, 'Unken', 'Unken', '', 47.6496600, 12.7294600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2218, 'Ungerdorf', 'Ungerdorf', '', 47.0833300, 15.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2219, 'Ungenach', 'Ungenach', 'Ungenach', 48.0475600, 13.6147200, 'AT', '2017-07-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2220, 'Umhausen', 'Umhausen', 'Umgauzen,Umhausen,Umkhauzen,wu mu hao sen,Умгаузен,Умхаузен,امہاؤسن,乌姆豪森', 47.1350300, 10.9282600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2221, 'Ulrichsberg', 'Ulrichsberg', 'Ul''rikhsberg,Ul''riksberg,wu er li xi si bei ge,Ульриксберг,Ульрихсберг,乌尔里希斯贝格', 48.6749800, 13.9104900, 'AT', '2011-07-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2222, 'Uderns', 'Uderns', 'Uderns', 47.3166700, 11.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2223, 'Übersbach', 'UEbersbach', 'Ubersbach,Uebersbach,Übersbach', 47.0231800, 16.0551700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2224, 'Übersaxen', 'Ubersaxen', 'Ubersaxen,Uebersaxen,Übersaxen', 47.2528400, 9.6708000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2225, 'Übelbach', 'Ubelbach', 'Ibel''bakh,Markt-UEbelbach,Markt-Übelbach,Ubelbach,Ubelbach Markt,Uebelbach,abylbach,yu bo er ba he,Übelbach,Übelbach Markt,Ибельбах,ابیلباچ,于伯尔巴赫', 47.2253400, 15.2361500, 'AT', '2017-06-23', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2226, 'Tweng', 'Tweng', '', 47.1833300, 13.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2227, 'Türnitz', 'Turnitz', 'Ternitz,Tjurnic,di er ni ci,twrnytz,Тюрниц,تورنیتز,蒂尔尼茨', 47.9309500, 15.4929500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2228, 'Turnau', 'Turnau', '', 47.5577600, 15.3373900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2229, 'Tulln', 'Tulln', '', 48.3282900, 16.0585800, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2230, 'Tulfes', 'Tulfes', '', 47.2580600, 11.5333300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2231, 'Tulbing', 'Tulbing', '', 48.2933600, 16.1222600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2232, 'Tschanigraben', 'Tschanigraben', '', 47.0166700, 16.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2233, 'Tschagguns', 'Tschagguns', 'Chagguns,Tschagguns,cha gong si,Чаггунс,查贡斯', 47.0833300, 9.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2234, 'Trumau', 'Trumau', '', 47.9934800, 16.3426800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2235, 'Trössing', 'Troessing', 'Trossing,Trössing', 46.8166700, 15.8166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2236, 'Trofaiach', 'Trofaiach', 'Trofaiach,Trofajakh,te luo fa yi ya he,Трофайах,特罗法伊亚赫', 47.4252400, 15.0068100, 'AT', '2014-05-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2237, 'Tristach', 'Tristach', 'Trishtakh,Tristach,Tristakh,te li shi ta he,Тристах,Триштах,特里施塔赫', 46.8161100, 12.7897200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2238, 'Trins', 'Trins', 'Trins,te lin si,Тринс,特林斯', 47.0833300, 11.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2239, 'Triebendorf', 'Triebendorf', 'Triebendorf', 47.1166700, 14.2333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2240, 'Trieben', 'Trieben', 'Triben,Trieben,te li ben,Трибен,特里本', 47.4833300, 14.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2241, 'Treglwang', 'Treglwang', 'Treglwang', 47.4745800, 14.5908300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2242, 'Trebesing', 'Trebesing', '', 46.8863900, 13.5102800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2243, 'Trautmannsdorf in Oststeiermark', 'Trautmannsdorf in Oststeiermark', 'Trautmannsdorf,Trautmannsdorf in Oststeiermark', 46.8753000, 15.8845100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2244, 'Trautmannsdorf an der Leitha', 'Trautmannsdorf an der Leitha', 'Trautmannsdorf,Trautmannsdorf an der Leitha,Trautmansdorf-an-der-Lajta,Траутмансдорф-ан-дер-Лайта', 48.0235700, 16.6326600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2245, 'Trausdorf an der Wulka', 'Trausdorf an der Wulka', 'Darazsfalu,Darázsfalu,Trausdorf,Trausdorf an der Wulka,Trausdorf-an-der-Vul''ka,Траусдорф-ан-дер-Вулька', 47.8135000, 16.5576000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2246, 'Traunstein', 'Traunstein', '', 48.4333300, 15.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2247, 'Traun', 'Traun', '', 48.2265600, 14.2345900, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2248, 'Trattenbach', 'Trattenbach', '', 47.6000000, 15.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2249, 'Traismauer', 'Traismauer', 'Traismauer,Trajsmauehr,te lai si mao ai er,Трайсмауэр,特赖斯毛埃尔', 48.3500000, 15.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2250, 'Traiskirchen', 'Traiskirchen', '', 48.0148500, 16.2932400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2251, 'Traisen', 'Traisen', '', 48.0333300, 15.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2252, 'Trahütten', 'Trahuetten', 'Trahutten,Trahütten', 46.8250000, 15.1569400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2253, 'Traboch', 'Traboch', 'Traboch', 47.3770500, 14.9864700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2254, 'Tobaj', 'Tobaj', '', 47.0833300, 16.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2255, 'Tobadill', 'Tobadill', 'Tobadill', 47.1251300, 10.5140400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2256, 'Timelkam', 'Timelkam', 'Timel''kam,di mo er ka mu,Тимелькам,蒂默尔卡姆', 48.0039400, 13.6076000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2257, 'Tieschen', 'Tieschen', 'Tieschen', 46.7861100, 15.9422200, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2258, 'Tiefgraben', 'Tiefgraben', 'Mondsee,Tiefgraben,Tifgraben,di fu ge la ben,Тифграбен,蒂夫格拉本', 47.8738500, 13.3059100, 'AT', '2017-07-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2259, 'Thüringen', 'Thuringen', '', 47.2000000, 9.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2260, 'Thörl', 'Thoerl', 'Thorl,Thörl,Tjorl'',te er,Тёрль,特尔', 47.5195200, 15.2227600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2261, 'Thomatal', 'Thomatal', 'Thomatal,Thomathal', 47.0666700, 13.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2262, 'Thomasberg', 'Thomasberg', '', 47.5666700, 16.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2263, 'Theresienfeld', 'Theresienfeld', '', 47.8500000, 16.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2264, 'Thaya', 'Thaya', '', 48.8548900, 15.2890200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2265, 'Thaur', 'Thaur', 'Taur,tao er,Таур,陶尔', 47.3000000, 11.4666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2266, 'Thalheim bei Wels', 'Thalheim bei Wels', 'Tal''khajm-Vel''s,Tal''khajm-baj-Vel''s,Thalheim,Thalheim bei Wels,wei er si fu jin ta er hai mu,Тальхайм-Вельс,Тальхайм-бай-Вельс,韦尔斯附近塔尔海姆', 48.1500000, 14.0333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2267, 'Thalgau', 'Thalgau', 'Tal''gau,ta er gao,Тальгау,塔爾高', 47.8414200, 13.2532500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2268, 'Teufenbach', 'Teufenbach', '', 47.1287000, 14.3591300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2269, 'Ternitz', 'Ternitz', 'Ternic,tai er ni ci,trntyts,trnyz,Терниц,תרניץ,ترنتیتس,ტერნიცი,泰爾尼茨', 47.7156500, 16.0357500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2270, 'Ternberg', 'Ternberg', 'Ternberg,te en bei ge,Тернберг,特恩贝格', 47.9451800, 14.3587000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2271, 'Terfens', 'Terfens', 'Terfens', 47.3235500, 11.6438800, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2272, 'Telfs', 'Telfs', 'Tel''fs,Telfs,tai er fu si,tlfs,tlps,Телфс,Тельфс,טלפס,تلفس,ტელფსი,泰爾夫斯', 47.3070700, 11.0681700, 'AT', '2013-12-06', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2273, 'Telfes im Stubai', 'Telfes im Stubai', 'Tel''fes-im-Shtubaj,Telfes,Telfes im Stubai,shi tu bai gu de te er fei si,Тельфес-им-Штубай,Тельфес-ім-Штубай,ٹلفس,施图拜谷地特尔费斯', 47.1666700, 11.3666700, 'AT', '2012-09-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2274, 'Teesdorf', 'Teesdorf', '', 47.9500000, 16.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2275, 'Taxenbach', 'Taxenbach', 'Daxenbach,Taksenbakh,Taxenbach,Touxenbouch,ta ke sen ba he,Таксенбах,塔克森巴赫', 47.2911600, 12.9621500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2276, 'Tauplitz', 'Tauplitz', 'Tauplic,tao pu li ci,Тауплиц,陶普利茨', 47.5600500, 14.0129300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2277, 'Tattendorf', 'Tattendorf', '', 47.9500000, 16.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2278, 'Tarrenz', 'Tarrenz', 'Tarrenc,ta lun ci,Тарренц,塔伦茨', 47.2666700, 10.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2279, 'Tannheim', 'Tannheim', 'Tanngajm,Tannheim,Tannkhajm,tan hai mu,Таннгайм,Таннхайм,ٹینہیم,坦海姆', 47.4993400, 10.5164100, 'AT', '2016-01-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2280, 'Tamsweg', 'Tamsweg', 'Tambsweg,Tamsveg,ta mu si wei ge,Тамсвег,ტამსვეგი,塔姆斯韋格', 47.1280800, 13.8110200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2281, 'Tadten', 'Tadten', 'Mosonteteny,Mosontétény,Tadten,Тадтен', 47.7666700, 16.9833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2282, 'Sulzberg', 'Sulzberg', '', 47.5217800, 9.9135300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2283, 'Sulz', 'Sulz', '', 47.2872100, 9.6518300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2284, 'Sulztal an der Weinstraße', 'Sulztal an der Weinstrasse', 'Stolzl,Sulztal,Zul''c,Зульц', 46.6833300, 15.5500000, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2285, 'Stummerberg', 'Stummerberg', 'Stummerberg', 47.2833300, 11.9166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2286, 'Stumm', 'Stumm', 'Stumm', 47.2905200, 11.8875500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2287, 'Stuhlfelden', 'Stuhlfelden', '', 47.2876100, 12.5275500, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2288, 'Studenzen', 'Studenzen', 'Studenzen', 47.0058300, 15.7541700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2289, 'Stubenberg', 'Stubenberg', '', 47.2333300, 15.8000000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2290, 'Stronsdorf', 'Stronsdorf', '', 48.6515700, 16.2989000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2291, 'Strobl', 'Strobl', 'Shtrobl'',Shtrobl''-am-Vol''fgangze,Strobl,shi te luo bu er,Штробль,Штробль-ам-Вольфгангзе,سٹروبل,施特罗布尔', 47.7166700, 13.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2292, 'Strengen', 'Strengen', 'Strengen,Strengen am Arlberg', 47.1258900, 10.4619900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2293, 'Strengberg', 'Strengberg', '', 48.1468500, 14.6514700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2294, 'Strem', 'Strem', 'Shtrem,Strem,Stremm,Strém,Штрем', 47.0449800, 16.4142600, 'AT', '2013-04-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2295, 'Stratzing', 'Stratzing', '', 48.4500000, 15.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2296, 'Strasswalchen', 'Strasswalchen', 'Strasswalchen,Strasz Walchen', 47.9833300, 13.2500000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2297, 'Straß in Steiermark', 'Strass in Steiermark', 'Shtras,Shtras-in-Shtajermark,Strass,Strass in Steiermark,Straß in Steiermark,shi tai er ma ke de qu shi te la si,Штрас,Штрас-ин-Штайермарк,施泰尔马克地区施特拉斯', 46.7272200, 15.6244400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2298, 'Strasshof an der Nordbahn', 'Strasshof an der Nordbahn', 'Shtrasskhof-an-der-Nordban,Strasshof,Strasshof an der Nordbahn,Штрассхоф-ан-дер-Нордбан', 48.3166700, 16.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2299, 'Strassen', 'Strassen', 'Strassen', 46.7538900, 12.4841700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2300, 'Straßburg', 'Strassburg', 'Strassburg,Strassburg im Karnten,Strassburg in Karnten,Straßburg,Straßburg im Kärnten,Straßburg in Kärnten', 46.8944400, 14.3286100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2301, 'Strass im Zillertal', 'Strass im Zillertal', 'Strass,Strass bei Jenbach,Strass im Zillertal', 47.3955600, 11.8196600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2302, 'Strallegg', 'Strallegg', 'Strallegg', 47.4116500, 15.7253400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2303, 'Straden', 'Straden', 'Shtraden,Straden,shi te la deng,Штраден,施特拉登', 46.8091700, 15.8680600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2304, 'Stotzing', 'Stotzing', 'Lajtaszek,Lajtaszék,Stoczing', 47.9068800, 16.5458000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2305, 'Stössing', 'Stossing', '', 48.1226700, 15.8137900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2306, 'Stoob', 'Stoob', 'Csava,Csáva,Shtub,Stoob,Stuma,Štuma,Штуб', 47.5284500, 16.4776000, 'AT', '2012-11-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2307, 'Stockerau', 'Stockerau', 'Gorad Shtokerau,Shhokerau,Shtokerau,Shtokkerau,Stockerau,Stokerau,astwkrayw,shi tuo ke lao,Štokerau,Горад Штокерау,Штокерау,Штоккерау,Щокерау,שטוקראו,استوکرائو,შტოკერაუ,ስቶከራው,施托克勞', 48.3833300, 16.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2308, 'Stockenboi', 'Stockenboi', '', 46.7261100, 13.5230600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2309, 'Stiwoll', 'Stiwoll', 'Shtivoll'',Stiwoll,shi di wo er,Штиволль,施蒂沃尔', 47.1000000, 15.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2310, 'Steinbrunn', 'Steinbrunn', 'Buedoeskut,Büdöskút,Shtajnbrunn,Steinbrunn,Stikapron,Stinkenbrunn,Štikapron,Штайнбрунн', 47.8333300, 16.4166700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2311, 'Stinatz', 'Stinatz', 'Shtinac,Stinatz,Stinjaki,Штинац', 47.2026600, 16.1331200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2312, 'Steyregg', 'Steyregg', 'Shtajreg,Shtajrehgg,shi tai er ai ge,Штайрег,Штайрэгг,施泰尔埃格', 48.2851300, 14.3699500, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2313, 'Steyr', 'Steyr', 'Gorad Shtajr,Shhajr,Shtajr,Stagier,Steiras,Steyer,Steyr,Steyr Stadt,ashtayr,shi tai er,shutaia,styyr,syutaieo,Šteiras,Στάγιερ,Горад Штайр,Штайр,Штајр,Щайр,שטייר,اشتایر,შტაირი,シュタイアー,施泰爾,슈타이어', 48.0427400, 14.4212700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2314, 'Steuerberg', 'Steuerberg', 'Shtojerberg,shi tuo yi bei ge,Штойерберг,施托伊贝格', 46.7880400, 14.1129000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2315, 'Stetten', 'Stetten', '', 48.3666700, 16.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2316, 'Stetteldorf am Wagram', 'Stetteldorf am Wagram', 'Stetteldorf,Stetteldorf am Wagram', 48.4081500, 16.0186200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2317, 'Stenzengreith', 'Stenzengreith', 'Stenzengreith', 47.2000000, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2318, 'Steinhaus', 'Steinhaus', '', 48.1161400, 14.0189000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2319, 'Steinfeld', 'Steinfeld', '', 46.7581200, 13.2493400, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2320, 'Steindorf am Ossiacher See', 'Steindorf am Ossiacher See', 'Shtajndorf-am-Ossiakher-Zee,Steindorf,Steindorf am Ossiacher See,ao xi ya xie er hu pan shi tai yin duo fu,Штайндорф-ам-Оссиахер-Зее,奥西亚歇尔湖畔施泰因多夫', 46.6983300, 14.0091700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2321, 'Steinbach am Attersee', 'Steinbach am Attersee', 'Steinbach,Steinbach am Attersee', 47.8308700, 13.5461300, 'AT', '2013-11-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2322, 'Steinakirchen am Forst', 'Steinakirchen am Forst', 'Steinakirchen,Steinakirchen am Forst', 48.0696500, 15.0480100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2323, 'Steinach am Brenner', 'Steinach am Brenner', 'Shtajnakh-am-Brenner,Shtajnakh-na-Brennere,Steinach,Steinach am Brenner,Steinach um Brenner,bu lun na shan kou si tai na he,Штайнах-ам-Бреннер,Штайнах-на-Бреннере,布倫納山口斯泰納赫', 47.0833300, 11.4666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2324, 'Stein', 'Stein', '', 46.9977800, 16.0869400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2325, 'Stegersbach', 'Stegersbach', 'Santalek,Shtegersbakh,Shtegersbarkh,Stegersbach,Szentelek,shi te ge er si ba he,Штегерсбарх,Штегерсбах,施特格尔斯巴赫', 47.1666700, 16.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2326, 'Steeg', 'Steeg', '', 47.2439300, 10.2943600, 'AT', '2011-09-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2327, 'Statzendorf', 'Statzendorf', '', 48.3075200, 15.6412700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2328, 'Stattegg', 'Stattegg', 'Shtatteg,Stattegg,Штаттег', 47.1333300, 15.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2329, 'Stanz bei Landeck', 'Stanz bei Landeck', 'Stanz,Stanz bei Landeck', 47.1475800, 10.5534000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2330, 'Stanzach', 'Stanzach', 'Stanzach', 47.3833300, 10.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2331, 'Stans', 'Stans', 'Stans', 47.3666700, 11.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2332, 'Stams', 'Stams', 'Shtams,shi ta mu si,Штамс,施塔姆斯', 47.2760300, 10.9831500, 'AT', '2011-09-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2333, 'Stambach', 'Stambach', '', 47.3333300, 15.9333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2334, 'Stallhofen', 'Stallhofen', '', 47.0500000, 15.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2335, 'Stallhof', 'Stallhof', '', 46.8833300, 15.2833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2336, 'Stallehr', 'Stallehr', '', 47.1330600, 9.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2337, 'Stall', 'Stall', '', 46.8905600, 13.0369400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2338, 'Stainz bei Straden', 'Stainz bei Straden', 'Stainz,Stainz bei Straden', 46.8244400, 15.8922200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2339, 'Stainz', 'Stainz', 'Shtajnc,Stainz,shi tai yin ci,Штайнц,施泰因茨', 46.8944400, 15.2672200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2340, 'Stainach', 'Stainach', 'Shtajnakh,Steinach,shi tai na he,Штайнах,施泰纳赫', 47.5334300, 14.1087200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2341, 'Stadtschlaining', 'Stadtschlaining', 'Schlaining,Stadtschlaining', 47.3166700, 16.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2342, 'Stadl-Paura', 'Stadl-Paura', 'Shtadl''-Paura,Stadl-Paura,shi ta de er-bao la,Штадль-Паура,施塔德尔-保拉', 48.0833300, 13.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2343, 'Stadl an der Mur', 'Stadl an der Mur', 'Stadl,Stadl an der Mur', 47.0833300, 13.9666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2344, 'Staatz', 'Staatz', 'Shtac,Val''tersdorf,shi ta ci,Вальтерсдорф,Штац,施塔茨', 48.6761700, 16.4872600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2345, 'Spitz', 'Spitz', 'Spitz an der Donau', 48.3656000, 15.4141600, 'AT', '2014-10-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2346, 'Spittal an der Drau', 'Spittal an der Drau', 'Shpital,Shpittal''-an-der-Drau,Spital,Spital ob Dravi,Spittal,Spittal an der Drau,Spittal na Dravi,ashpytal an dr drayw,de lao he pan si pi ta er,Špital ob Dravi,Шпитал,Шпитталь-ан-дер-Драу,Шпітталь-ан-дер-Драу,اشپیتال آن در درائو,შპიტალ-ან-დერ-დრაუ,シュピッタル・アン・デア・ドラウ,德劳河畔斯皮塔尔', 46.8000000, 13.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2347, 'Spital am Semmering', 'Spital am Semmering', 'Shpital''-am-Zemmering,Spital,Spital am Semmering,sai mo ling fu jin shi pi ta er,Шпиталь-ам-Земмеринг,塞默灵附近施皮塔尔', 47.6134500, 15.7509600, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2348, 'Spillern', 'Spillern', '', 48.3833300, 16.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2349, 'Spielfeld', 'Spielfeld', 'Spielfeld', 46.7055600, 15.6372200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2350, 'Spielberg bei Knittelfeld', 'Spielberg bei Knittelfeld', 'Shpil''berg (Knittel''fel''d),Spielberg,Spielberg bei Knittelfeld,Шпильберг (Книттельфельд)', 47.2166700, 14.7833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2351, 'Spannberg', 'Spannberg', '', 48.4639300, 16.7364700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2352, 'Sonntagberg', 'Sonntagberg', 'Zontagberg,song ta ge bei ge,Зонтагберг,松塔格贝格', 47.9956100, 14.7606500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2353, 'Sommerein', 'Sommerein', '', 47.9833300, 16.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2354, 'Sollenau', 'Sollenau', 'Zollenau,suo lei nao,Золленау,索勒瑙', 47.8833300, 16.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2355, 'Söll', 'Soll', 'Zjoll'',Зёлль', 47.5037800, 12.1922100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2356, 'Sölden', 'Soelden', 'Soelden,Soeldeni vald,Solden,Sölden,Söldeni vald,Z''olden,Zel''den,Zelden,Zelnten,Zjol''den,Zyolden,suo er deng,zeruden,zwldn,Ζέλντεν,Зелден,Зельден,Зьолден,Зёльден,Զյոլդեն,זולדן,ゼルデン,索爾登', 46.9666700, 11.0000000, 'AT', '2013-11-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2357, 'Hall in Tirol', 'Hall in Tirol', 'Gall''-in-Tirol'',Hall,Hall en Tyrol,Hall in Tirol,Hall în Tirol,Khal in Tirol,Khal u Tirolu,Khall''-in-Tirol'',Salina in Aeni Valle,Solbad Hall,Solbad Hall in Tirol,di luo er zhou huo er,hal ayn tyrwl,hal-intilol,Галль-ін-Тіроль,Хал ин Тирол,Хал у Тиролу,Халль-ин-Тироль,هال این تیرول,ہال ان ٹیرول,ჰალ-ინ-ტიროლი,ハル・イン・チロル,蒂羅爾州霍爾,할인티롤', 47.2833300, 11.5166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2358, 'Södingberg', 'Soedingberg', '', 47.1070300, 15.1716900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2359, 'Söchau', 'Soechau', 'Sochau,Söchau', 47.0333300, 16.0166700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2360, 'Soboth', 'Soboth', 'Soboth', 46.6813900, 15.0783300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2361, 'Sitzendorf an der Schmida', 'Sitzendorf an der Schmida', 'Sitzendorf,Sitzendorf an der Schmida,Zitcendorf-an-der-Shmida,shi mi da he pan xi cen duo fu,Зитцендорф-ан-дер-Шмида,施米达河畔锡岑多夫', 48.5984100, 15.9425400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2362, 'Sittersdorf', 'Sittersdorf', 'Sittersdorf,Zitara vas,Zitaraves,Zittersdorf,xi te er si duo fu,Žitara vas,Žitaraves,Зиттерсдорф,锡特尔斯多夫', 46.5444400, 14.6058300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2363, 'Sistrans', 'Sistrans', '', 47.2333300, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2364, 'Sinabelkirchen', 'Sinabelkirchen', 'Sinabelkirchen,Zinabel''kirkhen,xi na bo er ji xing,Зинабелькирхен,锡纳伯尔基兴', 47.1020000, 15.8279500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2365, 'Silz', 'Silz', 'Silz,Zil''c,Зильц', 47.2666700, 10.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2366, 'Sillian', 'Sillian', 'Sillian,Zillian,xi li an,Зиллиан,Зілліан,锡利安', 46.7527800, 12.4211100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2367, 'Silbertal', 'Silbertal', 'Silbertal,Silberthal,Zil''bertal'',xi bei ta er,Зильберталь,Зільберталь,锡贝塔尔', 47.0936800, 9.9831400, 'AT', '2011-09-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2368, 'Sigmundsherberg', 'Sigmundsherberg', 'Zigmundskherberg,xi meng de si he er bei ge,Зигмундсхерберг,锡蒙德斯赫尔贝格', 48.6833300, 15.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2369, 'Sierning', 'Sierning', 'Zirning,xi er ning,Зирнинг,锡尔宁', 48.0434300, 14.3093500, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2370, 'Sierndorf', 'Sierndorf', 'Khjobersdorf,Zirndorf,xi en duo fu,Зирндорф,Хёберсдорф,锡恩多夫', 48.4302400, 16.1665800, 'AT', '2017-05-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2371, 'Sieghartskirchen', 'Sieghartskirchen', 'Zigkhartskirkhen,xi ge ha ci ji xing,Зигхартскирхен,锡格哈茨基兴', 48.2553100, 16.0122300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2372, 'Sieggraben', 'Sieggraben', 'Sieggraben,Szikra,Ziggraben,Zigraben,xi ge la ben,Зигграбен,Зиграбен,Зіграбен,锡格拉本', 47.6512800, 16.3799300, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2373, 'Siegersdorf bei Herberstein', 'Siegersdorf bei Herberstein', 'Siegersdorf,Siegersdorf bei Herberstein', 47.2000000, 15.7833300, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2374, 'Sibratsgfäll', 'Sibratsgfall', 'Dorf,Sibratsgfall,Sibratsgfäll', 47.4266700, 10.0380600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2375, 'Serfaus', 'Serfaus', 'Serfaus,Zerfaus,sai er fu si,zerpausi,Зерфаус,סרפהאוס,ზერფაუსი,塞尔福斯', 47.0401800, 10.6033900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2376, 'Senftenberg', 'Senftenberg', 'Imbakh,Senftenberg,Zenftenberg,sen fu teng bei ge,Зенфтенберг,Имбах,森夫滕贝格', 48.4333300, 15.5500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2377, 'Semriach', 'Semriach', 'Semriach,Zemriakh,sai mu li ya he,Земриах,塞姆里亚赫', 47.2166700, 15.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2378, 'Semmering', 'Semmering', 'Semmering,Zemeringas,Zemmering,sai mo ling,zmryng,Земмеринг,זמרינג,塞默灵', 47.6334700, 15.8299300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2379, 'Selzthal', 'Selzthal', 'Selzthal,Zel''ctal'',sai er ci ta er,Зельцталь,塞尔茨塔尔', 47.5498800, 14.3120100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2380, 'Seitenstetten Markt', 'Seitenstetten Markt', 'Seitenstetten,Seitenstetten Markt', 48.0333300, 14.6500000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2381, 'Seiersberg', 'Seiersberg', 'Zajersberg,sai er si bei ge,Зайерсберг,赛尔斯贝格', 47.0000000, 15.4000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2382, 'Seibersdorf', 'Seibersdorf', 'Zajbersdorf,sai bo er si duo fu,Зайберсдорф,赛伯尔斯多夫', 47.9585800, 16.5184200, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2383, 'Seggauberg', 'Seggauberg', 'Seggauberg', 46.7666700, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2384, 'Seewalchen', 'Seewalchen', '', 47.9524600, 13.5838200, 'AT', '2014-05-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2385, 'Seekirchen am Wallersee', 'Seekirchen am Wallersee', 'Seekirchen,Seekirchen Markt,Seekirer am Wollersee,Zeekirkhen-am-Vallerzee,Zekirkhen-am-Vallerze,sai ji xing,Зеекирхен-ам-Валлерзее,Зекирхен-ам-Валлерзе,Зекірхен-ам-Валлерзе,塞基興', 47.9000000, 13.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2386, 'Seeham', 'Seeham', '', 47.9674600, 13.0769900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2387, 'Seefeld in Tirol', 'Seefeld in Tirol', 'Seefeld,Seefeld in Tirol,Seefeld in Tyroli,Seefeld în Tirol,Zeefel''d,Zeefel''d (Tirol''),Zefel''d-in-Tirol'',di luo er zhou sai fu er de,zeferuto,zyfyld,Зеефельд,Зеефельд (Тироль),Зефельд-ин-Тироль,Зефельд-ін-Тіроль,زيفيلد,سیفیلڈ,ゼーフェルト,蒂罗尔州塞弗尔德', 47.3301600, 11.1878600, 'AT', '2016-06-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2388, 'Seeboden', 'Seeboden', 'Seeboden,Seeboden am Millstaetter See,Seeboden am Millstätter See', 46.8190900, 13.5143000, 'AT', '2016-05-23', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2389, 'Seebenstein', 'Seebenstein', '', 47.6833300, 16.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2390, 'See', 'See', 'Messnerhaus,See,See im Paznaun,See im Paznauntal,Zee,Зее', 47.0833300, 10.4666700, 'AT', '2016-12-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2391, 'Seckau', 'Seckau', 'Seccovia,Seckau,Zekkau,sai kao,Зеккау,塞考', 47.2666700, 14.7833300, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2392, 'Sebersdorf', 'Sebersdorf', 'Sebersdorf,sai bo si duo fu,塞博斯多夫', 47.1865000, 15.9936000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2393, 'Schwoich', 'Schwoich', '', 47.5460000, 12.1404900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2394, 'Schwendt', 'Schwendt', '', 47.6318200, 12.3926600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2395, 'Schwendau', 'Schwendau', 'Schwendau', 47.1975300, 11.8589700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2396, 'Schweiggers', 'Schweiggers', 'Klajnvol''fgers,Shvajggers,shi wei ge si,Клайнвольфгерс,Швайггерс,施韋格斯', 48.6666700, 15.0666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2397, 'Schwechat', 'Schwechat', 'Nova Schwechat,Schwechat,Shvekhat,shi wei xia te,shwkhat,Швехат,شوخات,შვეხატი,施韋夏特', 48.1333300, 16.4666700, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2398, 'Schwaz', 'Schwaz', 'Shvac,shi wa ci,shvatsi,shwats,syuwacheu,Швац,שוואץ,شواتس,შვაცი,施瓦茨,슈와츠', 47.3516900, 11.7101400, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2399, 'Schwarzenbach an der Pielach', 'Schwarzenbach an der Pielach', 'Schwarzenbach,Schwarzenbach an der Pielach', 47.9333300, 15.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2400, 'Schwarzenbach', 'Schwarzenbach', 'Ehppenshtajn,Feketevar,Feketevár,Schwarzenbach,Schwarzenbach Markt,Эппенштайн', 47.6354700, 16.3510900, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2401, 'Schwarzenau', 'Schwarzenau', '', 48.7443600, 15.2583800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2402, 'Schwarzau im Schwarzautal', 'Schwarzau im Schwarzautal', 'Schwarzau,Schwarzau im Schwarzautal', 46.8788600, 15.6642100, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2403, 'Schwarzau im Gebirge', 'Schwarzau im Gebirge', 'Schwarzau,Shvarcau-im-Gebirge,shan qu shi wa er cao,Шварцау-им-Гебирге,山区施瓦尔曹', 47.8122300, 15.7058100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2404, 'Schwarzach im Pongau', 'Schwarzach im Pongau', 'Schwarzach,Schwarzach im Pongau,Schwoschzach im Pongau,Shvarcakh,Shvarcakh (Pongau),Shvarcakh-im-Pongau,peng gao de qu shi wa cha he,Шварцах,Шварцах (Понгау),Шварцах-им-Понгау,Шварцах-ім-Понгау,蓬高地区施瓦察赫', 47.3204800, 13.1517100, 'AT', '2015-03-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2405, 'Schwarzach', 'Schwarzach', '', 47.4490400, 9.7621300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2406, 'Schwanenstadt', 'Schwanenstadt', 'Schwauna,Shvanenshtadt,Svanenstatas,shi wa nen shi ta te,Švanenštatas,Шваненштадт,施瓦嫩施塔特', 48.0553700, 13.7750500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2407, 'Schwanberg', 'Schwanberg', 'Schwanberg', 46.7583300, 15.2083300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2408, 'Schwadorf', 'Schwadorf', '', 48.0693600, 16.5795700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2409, 'Schützen am Gebirge', 'Schutzen am Gebirge', 'Cesno,Gschiess,Schutzen am Gebirge,Schützen am Gebirge,Serc,Shjutcen-am-Gebirge,Sérc,Česno,Шютцен-ам-Гебирге', 47.8523300, 16.6233400, 'AT', '2012-11-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2410, 'Schruns', 'Schruns', 'Schruns,Shruns,shi lun si,Шрунс,施伦斯', 47.0666700, 9.9166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2411, 'Schrems bei Frohnleiten', 'Schrems bei Frohnleiten', 'Schrems,Schrems bei Frohnleiten', 47.2810900, 15.3593200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2412, 'Schrems', 'Schrems', 'Schrems,Shrems,shi lei mu si,Шремс,施雷姆斯', 48.7833300, 15.0666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2413, 'Schrattenthal', 'Schrattenthal', '', 48.7000000, 15.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2414, 'Schrattenberg', 'Schrattenberg', '', 48.7235900, 16.7220100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2415, 'Schrattenbach', 'Schrattenbach', '', 47.7790200, 15.9906000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2416, 'Schottwien', 'Schottwien', 'Shotvin,shao te wen,Шотвин,绍特温', 47.6568300, 15.8725000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2417, 'Schoppernau', 'Schoppernau', 'Shoppernau,shao po nao,shwprnaw,Шоппернау,شوپرناؤ,绍珀瑙', 47.3120500, 10.0164600, 'AT', '2014-10-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2418, 'Schönwies', 'Schonwies', 'Schonwies,Schönwies', 47.1966500, 10.6574200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2419, 'Schönberg im Stubaital', 'Schoenberg im Stubaital', 'Schonberg,Schonberg im Stubaital,Schönberg,Schönberg im Stubaital,Shenberg-im-Shtubajtal'',Shjonberg,Shjonberg-im-Shtubajtal'',she en bo ge,Шенберг-ім-Штубайталь,Шёнберг,Шёнберг-им-Штубайталь,舍恩伯格', 47.1833300, 11.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2420, 'Schönbach', 'Schonbach', '', 48.4500000, 15.0333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2421, 'Schönau an der Triesting', 'Schonau an der Triesting', 'Schonau,Schönau', 47.9345200, 16.2537600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2422, 'Schöder', 'Schoder', '', 47.1833300, 14.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2423, 'Schnifis', 'Schnifis', '', 47.2166700, 9.7330600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2424, 'Schnepfau', 'Schnepfau', '', 47.3520600, 9.9452000, 'AT', '2014-08-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2425, 'Schmirn', 'Schmirn', '', 47.0833300, 11.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2426, 'Schlitters', 'Schlitters', 'Schlitters', 47.3804500, 11.8388800, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2427, 'Schlins', 'Schlins', '', 47.2000000, 9.7000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2428, 'Schleedorf', 'Schleedorf', '', 47.9500000, 13.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2429, 'Schlatt', 'Schlatt', '', 48.0717700, 13.7890400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2430, 'Schlägl', 'Schlaegl', 'Schlagl,Schlägl,Shlegl'',Шлегль', 48.6366500, 13.9656000, 'AT', '2013-06-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2431, 'Schladming', 'Schladming', 'Schlaming,Shladming,shi la de ming,Шладминг,Шладмінг,施拉德明', 47.3928900, 13.6869900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2432, 'Schiefling am See', 'Schiefling am See', 'Schiefling,Schiefling am See,Shifling-am-Zee,Шифлинг-ам-Зее', 46.6044400, 14.0975000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2433, 'Schenkenfelden', 'Schenkenfelden', 'Schenkenfelden', 48.5027300, 14.3618800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2434, 'Scheifling', 'Scheifling', 'Scheifling,Shajfling,sha yi fu ling,Шайфлинг,沙伊夫灵', 47.1504400, 14.4127800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2435, 'Scheibbs', 'Scheibbs', 'Shajbs,sha yi bu si,Шайбс,Шајбс,沙伊布斯', 48.0047400, 15.1681700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2436, 'Scheffau am Wilden Kaiser', 'Scheffau am Wilden Kaiser', 'Scheffau', 47.5294300, 12.2513900, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2437, 'Scheffau am Tennengebirge', 'Scheffau am Tennengebirge', 'Scheffau,Sheffau-am-Tennengebirge,teng nen shan lu she fu,Шеффау-ам-Тенненгебирге,Шеффау-ам-Тенненгебірге,شیفو ایم ٹیننگبریج,滕嫩山麓舍福', 47.5883100, 13.2202000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2438, 'Schattwald', 'Schattwald', 'Schattwald,Shattval''d,sha te wa er de,Шаттвальд,沙特瓦尔德', 47.5142700, 10.4614300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2439, 'Schattendorf', 'Schattendorf', 'Somfalva,Sundrof,Šundrof', 47.7097300, 16.5097900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2440, 'Scharnstein', 'Scharnstein', 'Scharnstein,Sharnshhajn,Sharnshtajn,sha en shi tai yin,Шарнштайн,Шарнщайн,沙恩施泰因', 47.9042600, 13.9613500, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2441, 'Scharnitz', 'Scharnitz', 'Sharnic,sha er ni ci,Шарниц,Шарніц,沙尔尼茨', 47.3889900, 11.2645500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2442, 'Scharndorf', 'Scharndorf', '', 48.0939900, 16.7988300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2443, 'Schärding', 'Scharding', 'Scharding,Scharing,Schärding,Sherding,xie er ding,Шердинг,謝爾丁', 48.4529400, 13.4372200, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2444, 'Schandorf', 'Schandorf', 'Cemba,Csem,Csém,Schandorf,Shandorf,Čemba,Шандорф', 47.2418300, 16.4226700, 'AT', '2012-11-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2445, 'Schäffern', 'Schaeffern', 'Schaffern,Schäffern', 47.4777100, 16.1095600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2446, 'Schachendorf', 'Schachendorf', 'Cajta,Csajta,Schachendorf,Shakhendorf,Čajta,Шахендорф', 47.2666700, 16.4333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2447, 'Sautens', 'Sautens', '', 47.2000000, 10.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2448, 'Bad Sauerbrunn', 'Bad Sauerbrunn', 'Savanyukut,Savanyúkút', 47.7743900, 16.3284100, 'AT', '2017-06-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2449, 'Sattledt', 'Sattledt', 'Sattledt,Zattledt,sa te lei te,Заттледт,萨特勒特', 48.0737200, 14.0547800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2450, 'Satteins', 'Satteins', '', 47.2166700, 9.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2451, 'Sankt Wolfgang im Salzkammergut', 'Sankt Wolfgang im Salzkammergut', 'Sankt Wolfgang,Sankt-Vol''fgang-im-Zal''ckammergut,sa er ci ka mo gu te de qu sheng wo er fu gang,Санкт-Вольфганг-им-Зальцкаммергут,萨尔茨卡默古特地区圣沃尔夫冈', 47.7393200, 13.4466600, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2452, 'Sankt Veit in Defereggen', 'Sankt Veit in Defereggen', 'Sankt Veit,Sankt Veit in Defereggen', 46.9272200, 12.4297200, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2453, 'Sankt Veit im Pongau', 'Sankt Veit im Pongau', 'Sankt Veit,Sankt Veit Pongau,Sankt Veit im Pongau,Sankt-Vajt (Pongau),St. Veit,St. Veit im Pongau,Санкт-Вайт (Понгау)', 47.3333300, 13.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2454, 'Sankt Veit an der Gölsen', 'Sankt Veit an der Golsen', 'Sankt-Fajt-an-der-Tristing,Sankt-Veit,Санкт-Файт-ан-дер-Тристинг', 48.0432000, 15.6694200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2455, 'Sankt Veit an der Glan', 'Sankt Veit an der Glan', 'Sankt Fajt an der Glan,Sankt Fajt na Glanu,Sankt Veit,Sankt Veit an der Glan,Sankt-Fajt-an-der-Glan,Sankt-Vajt-an-der-Glan,Sentvid ob Glini,ge lan he pan sheng fa yi te,znkt fayt an dr glan,Šentvid ob Glini,Санкт Файт ан дер Глан,Санкт Фајт на Глану,Санкт-Вайт-ан-дер-Глан,Санкт-Файт-ан-дер-Глан,Санкт-Файт-ан-дер-Ґлан,زنکت فایت آن در گلان,სანქტ-ფაიტ-ან-დერ-გლანი,格蘭河畔聖法伊特', 46.7680600, 14.3602800, 'AT', '2014-03-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2456, 'Sankt Veit am Vogau', 'Sankt Veit am Vogau', 'Sankt Veit,Sankt Veit am Vogau,Sankt-Fajt-am-Fogau,Санкт-Файт-ам-Фогау', 46.7404800, 15.6421700, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2457, 'Sankt Valentin', 'Sankt Valentin', 'Sankt Valentin', 48.1666700, 14.5166700, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2458, 'Sankt Ulrich bei Steyr', 'Sankt Ulrich bei Steyr', 'Sankt Ulrich,Sankt-Ul''rikh-Shtajr,Санкт-Ульрих-Штайр', 48.0211600, 14.4368500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2459, 'Sankt Ulrich am Waasen', 'Sankt Ulrich am Waasen', 'Sankt Ulrich,Sankt Ulrich am Waasen', 46.9333300, 15.5333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2460, 'Sankt Stefan ob Stainz', 'Sankt Stefan ob Stainz', 'Sankt Stefan,Sankt Stefan ob Stainz', 46.9286100, 15.2588900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2461, 'Sankt Stefan ob Leoben', 'Sankt Stefan ob Leoben', 'Sankt Stefan ob Leoben', 47.3167200, 14.9783100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2462, 'Sankt Stefan im Rosental', 'Sankt Stefan im Rosental', 'Sankt Stefan,Sankt Stefan im Rosental,Sankt Stefan im Rosenthal,Sankt Stefan im Rosenthale,Sankt-Shtefan,Sankt-Shtefan-im-Rozental'',luo sen gu de sheng si te fan,Санкт-Штефан,Санкт-Штефан-им-Розенталь,罗森谷地圣斯特凡', 46.9038900, 15.7100000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2463, 'Sankt Ruprecht an der Raab', 'Sankt Ruprecht an der Raab', 'Sankt Ruprecht', 47.1533600, 15.6625600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2464, 'Sankt Radegund bei Graz', 'Sankt Radegund bei Graz', 'Radegund bei Graz,Sankt Radegund,Sankt Radegund bei Graz,ge la ci fu jin sheng la de gong de,格拉茨附近圣拉德贡德', 47.1817200, 15.4919200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2465, 'Sankt Pölten', 'Sankt Poelten', 'Cetium,Gorad Sankt-Pjol''tehn,POK,Poelten,Pölten,Sankt P''olten,Sankt Pelten,Sankt Peltenas,Sankt Poelten,Sankt Polten,Sankt Polton,Sankt Pölten,Sankt Pölton,Sankt-Pel''ten,Sankt-Pjol''ten,Sankt-Pyolten,Sanktpeltene,St. Poelten,St. Poetn,St. Pölten,St. Pötn,Sveti Hipolit,Zan''kt Pelten,jangkeuteupoelten,jankta pyoltana,sang th pheil thein,sheng pa er teng,snqt pltn,zankt pwltn,Ζανκτ Πέλτεν,Горад Санкт-Пёльтэн,Санкт Пелтен,Санкт Пьолтен,Санкт-Пельтен,Санкт-Пёльтен,סנקט פלטן,زانکت پولتن,سینکت پولٹن,जांक्ट प्योल्टन,ซังท์เพิลเทิน,სანქტ-პელტენი,ザンクト・ペルテン,聖帕爾滕,장크트푈텐', 48.2000000, 15.6333300, 'AT', '2015-12-06', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2466, 'Sankt Peter ob Judenburg', 'Sankt Peter ob Judenburg', 'Sankt Peter,Sankt Peter ob Judenburg', 47.1841700, 14.5863900, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2467, 'Sankt Peter im Sulmtal', 'Sankt Peter im Sulmtal', 'Sankt Peter,Sankt Peter im Sulmtal,Sankt Peter im Sulmthale', 46.7500000, 15.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2468, 'Sankt Peter-Freienstein', 'Sankt Peter-Freienstein', 'Freyenstein,Sankt Peter,Sankt Peter-Freienstein,Sankt-Peter-Frajenshtajn,Санкт-Петер-Фрайенштайн', 47.3833300, 15.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2469, 'Sankt Peter am Ottersbach', 'Sankt Peter am Ottersbach', 'Sankt Peter,Sankt Peter am Ottersbach,Sankt-Peter-am-Ottersbakh,ao te er si ba he he pan sheng bi de,Санкт-Петер-ам-Оттерсбах,奥特尔斯巴赫河畔圣彼得', 46.7977800, 15.7591700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2470, 'Sankt Peter am Kammersberg', 'Sankt Peter am Kammersberg', 'Sankt Peter,Sankt Peter am Kammersberg', 47.1870600, 14.1846400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2471, 'Sankt Paul im Levanttal', 'Sankt Paul im Levanttal', 'Sankt Paul,Sankt Paul im Lavanttal,Sankt Paul im Levanttal', 46.7005600, 14.8755600, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2472, 'Sankt Oswald bei Plankenwarth', 'Sankt Oswald bei Plankenwarth', 'Sankt Oswald,Sankt Oswald bei Plankenwarth', 47.0870100, 15.2770300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2473, 'Sankt Nikolai ob Draßling', 'Sankt Nikolai ob Drassling', 'Sankt Nikolai,Sankt Nikolai ob Drassling,Sankt Nikolai ob Draßling', 46.8088900, 15.6508300, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2474, 'Sankt Nikolai im Sölktal', 'Sankt Nikolai im Soelktal', 'Sankt Nikolai,Sankt Nikolai im Solktal,Sankt Nikolai im Sölktal', 47.3166700, 14.0500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2475, 'Sankt Nikolai im Sausal', 'Sankt Nikolai im Sausal', 'Sankt Nikolai,Sankt Nikolai im Sausal', 46.8211100, 15.4519400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2476, 'Sankt Michael in Obersteiermark', 'Sankt Michael in Obersteiermark', 'Sankt Michael,Sankt Michael in Obersteiermark,Sankt-Mikhaehl''-in-Obershtajermark,Sankt-Mikhel'',Sankt-Mikhel'' (Verkhnjaja Shtirija),shang shi tai er ma ke de qu sheng mi xia ai er,Санкт-Михаэль-ин-Оберштайермарк,Санкт-Михель,Санкт-Михель (Верхняя Штирия),上施泰尔马克地区圣米夏埃尔', 47.3383900, 15.0178400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2477, 'Sankt Michael im Lungau', 'Sankt Michael im Lungau', 'Sankt Michael,Sankt Michael Lungau,Sankt Michael im Lungau,Sankt-Mikhaehl'' (Lungau),St Michael im Lungau,Санкт-Михаэль (Лунгау)', 47.1000000, 13.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2478, 'Sankt Michael im Burgenland', 'Sankt Michael im Burgenland', 'Michael,Sankt Michael,Sankt Michael an der Strem,Sankt Michael im Burgenland,Sankt Mikhel'' (Burgenland),Санкт Михель (Бургенланд)', 47.1285200, 16.2714800, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2479, 'Sankt Martin im Sulmtal', 'Sankt Martin im Sulmtal', 'Sankt Martin,Sankt Martin im Sulmtal,Sankt-Martin,Sankt-Martin-im-Zul''mtal'',su er mu gu de sheng ma ding,Санкт-Мартин,Санкт-Мартин-им-Зульмталь,苏尔姆谷地圣马丁', 46.7561100, 15.2972200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2480, 'Sankt Martin bei Lofer', 'Sankt Martin bei Lofer', 'Sankt Martin,Sankt Martin bei Lofer,St. Martin b. Lofer', 47.5666700, 12.7000000, 'AT', '2016-08-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2481, 'Sankt Martin an der Raab', 'Sankt Martin an der Raab', 'Sankt Martin,Sankt Martin an der Raab', 46.9225000, 16.1361100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2482, 'Sankt Martin am Grimming', 'Sankt Martin am Grimming', 'Sankt Martin,Sankt Martin an der Salza', 47.4887300, 13.9810500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2483, 'Sankt Marienkirchen bei Schärding', 'Sankt Marienkirchen bei Schaerding', 'Sankt Marienkirchen,Sankt Marienkirchen bei Schaerding,Sankt Marienkirchen bei Schärding', 48.3871000, 13.4507800, 'AT', '2013-04-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2484, 'Sankt Margarethen im Lungau', 'Sankt Margarethen im Lungau', 'Sankt Margarethen,Sankt Margarethen im Lungau', 47.0792700, 13.6961300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2485, 'Sankt Margarethen im Burgenland', 'Sankt Margarethen im Burgenland', 'Sankt Margarethen,Sankt-Margareten,Sankt-Margareten (Burgenland),Sankt-Margareten-im-Burgenland,Sveta Margareta,Szentmargitbanya,Szentmargitbánya,bu er gen lan zhou sheng ma er jia lei teng,Санкт-Маргаретен,Санкт-Маргаретен (Бургенланд),Санкт-Маргаретен-им-Бургенланд,布尔根兰州圣马尔加勒滕', 47.8033500, 16.6087500, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2486, 'Sankt Margarethen bei Knittelfeld', 'Sankt Margarethen bei Knittelfeld', 'Sankt Margarethen,Sankt Margarethen bei Knittelfeld', 47.2166700, 14.8666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2487, 'Sankt Margarethen an der Sierning', 'Sankt Margarethen an der Sierning', 'Margarethen,Margarethen an der Sierning', 48.1591000, 15.4905500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2488, 'Sankt Margarethen an der Raab', 'Sankt Margarethen an der Raab', 'Sankt Margarethen,Sankt Margarethen an der Raab,Sankt-Margareten-na-Rabe,Санкт-Маргаретен-на-Рабе', 47.0500000, 15.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2489, 'Sankt Marein im Mürztal', 'Sankt Marein im Muerztal', 'Sankt Marein,Sankt Marein im Murztal,Sankt Marein im Murztale,Sankt Marein im Murzthale,Sankt Marein im Mürztal,Sankt Marein im Mürztale,Sankt-Marajn (Mjurctal''),Санкт-Марайн (Мюрцталь)', 47.4666700, 15.3666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2490, 'Sankt Marein bei Neumarkt', 'Sankt Marein bei Neumarkt', 'Sankt Marein,Sankt Marein bei Neumarkt', 47.0659100, 14.4290800, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2491, 'Sankt Marein bei Knittelfeld', 'Sankt Marein bei Knittelfeld', 'Sankt Marein,Sankt Marein bei Knittelfeld', 47.2739600, 14.8608500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2492, 'Sankt Marein bei Graz', 'Sankt Marein bei Graz', 'Sankt Marein,Sankt Marein am Pickelbach,Sankt Marein bei Graz,Sankt-Marajn-Grac,Sankt-Marajn-baj-Grac,ge la ci fu jin sheng ma lai en,Санкт-Марайн-Грац,Санкт-Марайн-бай-Грац,格拉茨附近圣马赖恩', 47.0158300, 15.6838900, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2493, 'Sankt Lorenzen im Mürztal', 'Sankt Lorenzen im Muerztal', 'Sankt Lorenzen,Sankt Lorenzen im Murztal,Sankt Lorenzen im Mürztal,Sankt-Lorencen (Mjurctal''),Санкт-Лоренцен (Мюрцталь)', 47.4833300, 15.3666700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2494, 'Sankt Lorenzen bei Scheifling', 'Sankt Lorenzen bei Scheifling', 'Sankt Lorenzen,Sankt Lorenzen bei Scheifling', 47.1455600, 14.4058300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2495, 'Sankt Lorenzen bei Knittelfeld', 'Sankt Lorenzen bei Knittelfeld', 'Sankt Lorenzen,Sankt Lorenzen bei Knittelfeld', 47.2507800, 14.8954900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2496, 'Sankt Lorenzen am Wechsel', 'Sankt Lorenzen am Wechsel', 'Sankt Lorenzen,Sankt Lorenzen am Wechsel', 47.4415300, 15.9549800, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2497, 'Sankt Lorenz', 'Sankt Lorenz', '', 47.8324000, 13.3483900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2498, 'Sankt Leonhard am Forst', 'Sankt Leonhard am Forst', 'Sankt Leonhard,Sankt Leonhard am Forst,Sankt-Leonkhard-am-Forst,Санкт-Леонхард-ам-Форст', 48.1333300, 15.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2499, 'Sankt Lambrecht', 'Sankt Lambrecht', 'Sankt Lambrecht', 47.0666700, 14.3000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2500, 'Sankt Kathrein am Offenegg', 'Sankt Kathrein am Offenegg', 'Sankt Kathrein,Sankt Kathrein am Offenegg,St. Kathrein', 47.3000000, 15.5833300, 'AT', '2016-01-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2501, 'Sankt Kathrein am Hauenstein', 'Sankt Kathrein am Hauenstein', 'Sankt Kathrein,Sankt Kathrein am Hauenstein', 47.4894300, 15.6941400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2502, 'Sankt Katharein an der Laming', 'Sankt Katharein an der Laming', 'Katharein,Sankt Katharein,Sankt Katherein,Sankt Kathrein,Sankt Kathrein an der Laming', 47.4706900, 15.1631900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2503, 'Sankt Josef (Weststeiermark)', 'Sankt Josef (Weststeiermark)', '', 46.9091700, 15.3363900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2504, 'Sankt Johann in Tirol', 'Sankt Johann in Tirol', 'Sankt Johann,Sankt-Jokhann (Tirol''),St. Johann in Tirol,Санкт-Йоханн (Тироль)', 47.5233000, 12.4232000, 'AT', '2016-01-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2505, 'Sankt Johann in der Haide', 'Sankt Johann in der Haide', 'Sankt Johann,Sankt Johann in der Haide', 47.2808000, 16.0257900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2506, 'Sankt Johann im Saggautal', 'Sankt Johann im Saggautal', 'Sankt Johann,Sankt Johann im Saggautal,Sankt Johann im Saggauthale', 46.7038900, 15.4027800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2507, 'Sankt Johann im Pongau', 'Sankt Johann im Pongau', 'Sankt Johann,Sankt Johann im Pongau,Sankt Jokhan u Pongauu,Sankt-Iogann-im-Pongau,Sankt-Jogann-im-Pongau,Sankt-Jokhan,Sankt-Jokhann (Pongau),St Johann im Pongau,St. John''s im Pougau,St. John’s im Pougau,peng gao de qu sheng yue han,zankt ywhan aym pwngayw,Санкт Јохан у Понгауу,Санкт-Иоганн-им-Понгау,Санкт-Йоганн-ім-Понгау,Санкт-Йохан,Санкт-Йоханн (Понгау),زانکت یوهان ایم پونگائو,蓬高地區聖約翰', 47.3500000, 13.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2508, 'Sankt Johann bei Herberstein', 'Sankt Johann bei Herberstein', 'Sankt Johann,Sankt Johann bei Herberstein', 47.2000000, 15.8000000, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2509, 'Sankt Johann am Tauern', 'Sankt Johann am Tauern', 'Sankt Johann,Sankt Johann am Tauern', 47.3500000, 14.4666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2510, 'Sankt Jakob im Walde', 'Sankt Jakob im Walde', 'Sankt Jakob,Sankt Jakob im Walde', 47.4666700, 15.7833300, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2511, 'Sankt Jakob', 'Sankt Jakob', 'Sankt Jakob,Sankt Jakob im Rosental,Sankt Jakob im Rosenthal,Sveti Jakob', 46.5477800, 14.0572200, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2512, 'Sankt Ilgen', 'Sankt Ilgen', 'Sankt Ilgen', 47.5500000, 15.1666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2513, 'Sankt Gotthard im Mühlkreis', 'Sankt Gotthard im Muhlkreis', 'Sankt Gotthard,Sankt Gotthard im Muhlkreis,Sankt Gotthard im Mühlkreis', 48.3802000, 14.1318500, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2514, 'Sankt Gilgen', 'Sankt Gilgen', 'Saint Gilgen,Sankt Gilgen,Sankt-Gil''gen,Sankt-Gilgen,St. AEgidius,St. Gilgen,St. Ægidius,sheng ji er gen,Санкт-Гилген,Санкт-Гильген,Санкт-Гільген,سینٹ گلگن,圣吉尔根', 47.7666700, 13.3666700, 'AT', '2013-03-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2515, 'Sankt Georgen ob Murau', 'Sankt Georgen ob Murau', 'Sankt Georgen ob Murau,St. Georgen ob Murau', 47.1000000, 14.1000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2516, 'Sankt Georgen ob Judenburg', 'Sankt Georgen ob Judenburg', 'Sankt Georgen,Sankt Georgen ob Judenburg,St. Georgen ob Judenburg', 47.2074400, 14.4973600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2517, 'Sankt Georgen im Attergau', 'Sankt Georgen im Attergau', 'Sankt Georgen,Sankt Georgen im Attergau,Sankt-Georgen-im-Attergau,Санкт-Георген-им-Аттергау', 47.9359500, 13.4830600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2518, 'Sankt Georgen an der Stiefing', 'Sankt Georgen an der Stiefing', 'Sankt Georgen,Sankt Georgen an der Stiefing', 46.8733300, 15.5797200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2519, 'Sankt Georgen an der Leys', 'Sankt Georgen an der Leys', 'Sankt Georgen', 48.0314900, 15.2272200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2520, 'Sankt Georgen am Ybbsfelde', 'Sankt Georgen am Ybbsfelde', 'Sankt Georgen,Sankt Georgen am Ybbsfelde,Sankt-Georgien-na-Ibsfel''de,Санкт-Георгиен-на-Ибсфельде', 48.1333300, 14.9500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2521, 'Sankt Gallenkirch', 'Sankt Gallenkirch', '', 47.0166700, 9.9666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2522, 'Sankt Gallen', 'Sankt Gallen', 'Sankt Gallen', 47.6863100, 14.6170500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2523, 'Sankt Florian am Inn', 'Sankt Florian am Inn', 'Sankt Florian,Sankt Florian am Inn,Sankt-Florian-am-Inn,St. Florian am Inn,Санкт-Флориан-ам-Инн', 48.4412200, 13.4426300, 'AT', '2016-02-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2524, 'Sankt Corona am Wechsel', 'Sankt Corona am Wechsel', 'Sankt Corona am Wechsel,Sankt-Corona', 47.5833300, 16.0000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2525, 'Sankt Blasen', 'Sankt Blasen', 'Sankt Blasen', 47.0833300, 14.3000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2526, 'Sankt Bartholomä', 'Sankt Bartholoma', 'Sankt Bartholoma,Sankt Bartholomä', 47.0545700, 15.2588900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2527, 'Sankt Anton im Montafon', 'Sankt Anton im Montafon', 'Montafon,Sankt Anton,Sankt Anton im Montafon', 47.1166700, 9.8666700, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2528, 'Sankt Anton am Arlberg', 'Sankt Anton am Arlberg', 'ANT,Saint Anton,Sankt Anton,Sankt Anton am Arlberg,Sankt Antonas,Sankt-Anton-am-Arl''berg,St Anton,St Anton am Arlberg,St. Anton,St. Anton am Arlberg,a er shan lu sheng an dong,Санкт Антон ам Арлберг,Санкт-Антон-ам-Арльберг,סן אנטון,サンクト・アントン・アム・アールベルク,阿尔山麓圣安东', 47.1275000, 10.2637200, 'AT', '2014-05-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2529, 'Sankt Anna am Aigen', 'Sankt Anna am Aigen', 'Sankt Anna,Sankt Anna am Aigen', 46.8311100, 15.9713900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2530, 'Sankt Andrä im Lungau', 'Sankt Andra im Lungau', 'Sankt Andra,Sankt Andra im Lungau,Sankt Andrä,Sankt Andrä im Lungau', 47.1500000, 13.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2531, 'Sankt Andrä am Zicksee', 'Sankt Andra am Zicksee', 'Mosonszentandras,Mosonszentandrás,Sankt Andra,Sankt Andra bei Frauenkirchen,Sankt Andrä,Sankt Andrä bei Frauenkirchen,Sankt-Andre-am-Cikzee,Санкт-Андре-ам-Цикзее', 47.7841000, 16.9419500, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2532, 'Sankt Andrä', 'Sankt Andrae', 'Sankt Andra,Sankt Andra Lavanttal,Sankt Andrae Im Lavanttal,Sankt Andre,Sankt Andrä,Sankt Andrä Lavanttal,Sankt-Andre,Sentandraz v Labotski dolini,sheng an de lie,zankt andrh,Šentandraž v Labotski dolini,Санкт Андре,Санкт-Андре,زانکت آندره,聖安德烈', 46.7682900, 14.8199100, 'AT', '2014-10-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2533, 'Salzburg', 'Salzburg', 'Estado de Salzburgo,Gorad Zal''cburg,Ijolati Zaltsburg,Lungsod ng Salzburg,SZG,Saizburg,Salcburg,Salcburk,Salisburgh,Salisburgium,Salisburgo,Salisburgu,Salisburgum,Saltsmpournk,Saltzburg,Salzborg,Salzbourg,Salzburg,Salzburgi liidumaa,Salzburgo,Salzbursko,Sałisburgo,Såizburg,Zal''cburg,Zalcburg,Zalcburga,Zalcburgas,Zaltsburq,chai er ci bei ge,jalcheubuleukeu,jaltsaburga,sa er ci bao,sa er si bao,salajaburga,saljhabarga,sals bur k,salzaborga,salzbrg,salzbwrgh,zaltsburgi,zaltsbwrg,zarutsuburuku,zlzbwrg,Σάλτσμπουργκ,Горад Зальцбург,Залцбург,Зальцбург,Иёлати Залтсбург,Салцбург,Զալցբուրգ,זאלצבורג,זלצבורג,زالتسبورگ,سالزبرگ,سالزبورغ,जाल्त्सबुर्ग,साल्ज़बोर्ग,সলজবুর্গ,સાલ્ઝબર્ગ,ಸಾಲ್ಜ್‌ಬರ್ಗ್‌,ซาลซ์บูร์ก,ზალცბურგი,ザルツブルク,柴尔兹孛格,萨尔斯堡,萨尔茨堡,薩爾斯堡,잘츠부르크', 47.7994100, 13.0439900, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2534, 'Sallingberg', 'Sallingberg', '', 48.4666700, 15.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2535, 'Salla', 'Salla', 'Salla', 47.1000000, 14.9666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2536, 'Sachsenburg', 'Sachsenburg', 'Sachsenburg,Sochsenburg,Zaksenburg,sa he sen bao,schsnbrg,Заксенбург,سچسنبرگ,萨赫森堡', 46.8291700, 13.3550000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2537, 'Saalfelden am Steinernen Meer', 'Saalfelden am Steinernen Meer', 'Saafelden,Saalfelden,Saalfelden am Steinernen Meer,Salfelden,Zal''fel''den-am-Shtajnernen-Meer,Зальфельден-ам-Штайнернен-Меер', 47.4268100, 12.8480000, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2538, 'Saalbach', 'Saalbach', '', 47.3913800, 12.6364200, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2539, 'Rutzenham', 'Rutzenham', '', 48.0607600, 13.7188300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2540, 'Rüstorf', 'Rustorf', '', 48.0432600, 13.7898200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2541, 'Rust', 'Rust', 'Rust,Ruszt,Stadt Rust,Руст', 47.8012200, 16.6715800, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2542, 'Ruprechtshofen', 'Ruprechtshofen', '', 48.1364800, 15.2767500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2543, 'Rum', 'Rum', '', 47.2833300, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2544, 'Rudersdorf', 'Rudersdorf', '', 47.0500000, 16.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2545, 'Ruden', 'Ruden', '', 46.6583300, 14.7763900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2546, 'Rottenmann', 'Rottenmann', 'Rottenman,Rottenmann,luo teng man,Роттенман,Роттенманн,羅滕曼', 47.5166700, 14.3500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2547, 'Röthis', 'Rothis', '', 47.2933200, 9.6548400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2548, 'Röthelstein', 'Roethelstein', 'Rothelstein,Röthelstein', 47.3166700, 15.3666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2549, 'Rotenturm an der Pinka', 'Rotenturm an der Pinka', 'Rotenturm,Rotenturm an der Pinka,Rotenturm-na-Pinke,Rothenthurm,Vasvoeroesvar,Vasvörösvár,Ротентурм-на-Пинке', 47.2500000, 16.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2550, 'Rosegg', 'Rosegg', 'Rosegg,Rozeg,Rozek,Rožek,luo sai ge,Розег,罗塞格', 46.5883300, 14.0171800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2551, 'Röschitz', 'Roschitz', '', 48.6431200, 15.8177400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2552, 'Roppen', 'Roppen', '', 47.2166700, 10.8166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2553, 'Röns', 'Rons', '', 47.2166700, 9.7000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2554, 'Rohr im Gebirge', 'Rohr im Gebirge', 'Rohr', 47.8947100, 15.7360300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2555, 'Rohr im Burgenland', 'Rohr im Burgenland', 'Rohr,Rohr im Burgenland,Ror (Burgenland),Рор (Бургенланд)', 47.1166700, 16.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2556, 'Röhrenbach', 'Rohrenbach', '', 48.6500000, 15.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2557, 'Rohrbach bei Mattersburg', 'Rohrbach bei Mattersburg', 'Fraknonadasd,Fraknónádasd,Orbuh,Rohrbach,Rohrbach bei Mattersburg,Rorbakh-Mattersburg,Рорбах-Маттерсбург', 47.7052000, 16.4300500, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2558, 'Rohrbach an der Lafnitz', 'Rohrbach an der Lafnitz', 'Rohrbach,Rohrbach an der Lafnitz', 47.3833300, 16.0000000, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2559, 'Rohrau', 'Rohrau', 'Khollern,Rorau,luo lao,Рорау,Холлерн,罗劳', 48.0666700, 16.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2560, 'Ritzing', 'Ritzing', 'Receny,Ricinja,Récény', 47.6131600, 16.4954600, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2561, 'Rinn', 'Rinn', 'Rinn,lin en,Ринн,Рінн,林恩', 47.2500000, 11.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2562, 'Riezlern', 'Riezlern', '', 47.3577800, 10.1875900, 'AT', '2017-05-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2563, 'Rietz', 'Rietz', '', 47.2859300, 11.0307500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2564, 'Riegersburg', 'Riegersburg', '', 47.0000000, 15.9302800, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2565, 'Riefensberg', 'Riefensberg', '', 47.5013700, 9.9583800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2566, 'Riedlingsdorf', 'Riedlingsdorf', 'Ridlingsdorf,Roedoeny,Rödöny,li de ling si duo fu,Ридлингсдорф,里德灵斯多夫', 47.3500000, 16.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2567, 'Ried im Oberinntal', 'Ried im Oberinntal', 'Ried,Ried im Oberinntal', 47.0500000, 10.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2568, 'Ried im Innkreis', 'Ried im Innkreis', 'Reid,Riad im Innkreis,Rid (Inkrajs),Rid u Inkrajsu,Rid-im-Innkrajs,Ried,Ried im Innkreis,Rydas,li de yin ke rui si,ryd aym aynkrays,Рид (Инкрайс),Рид у Инкрајсу,Рид-им-Иннкрайс,Рід-ім-Іннкрайс,رید ایم اینکرایس,რიდ-ინ-იმკრაისი,里德因克瑞斯', 48.2112300, 13.4885500, 'AT', '2011-07-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2569, 'Reutte', 'Reutte', 'Reutte,Reutte in Tirol,Rojte,Rojtte,luo yi te,Ройте,Ройтте,Ројте,ریوٹ,羅伊特', 47.4833300, 10.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2570, 'Reuthe', 'Reuthe', '', 47.3711300, 9.8948100, 'AT', '2014-08-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2571, 'Retznei', 'Retznei', 'Retznei', 46.7333300, 15.5666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2572, 'Retz', 'Retz', 'Khofern,Rec,Retc,Retz,Rotz,Rötz,lei ci,Ретц,Рец,Хоферн,雷茨', 48.7500000, 15.9500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2573, 'Rettenschöss', 'Rettenschoss', '', 47.6571800, 12.2687200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2574, 'Rettenegg', 'Rettenegg', 'Frauenwald,Rettenegg', 47.5269400, 15.7810400, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2575, 'Reith bei Seefeld', 'Reith bei Seefeld', 'Reith,Reith bei Seefeld', 47.3000000, 11.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2576, 'Reith bei Kitzbühel', 'Reith bei Kitzbuhel', 'Reith,Reith bei Kitzbuhel,Reith bei Kitzbühel', 47.4666700, 12.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2577, 'Reith im Alpbachtal', 'Reith im Alpbachtal', 'Rajt,Rajt-im-Al''pbakhtal'',Reith,Reith bei Brixlegg,Reith im Aipbachtai,Reith im Åipbåchtåi,a er pu ba he gu de lai te,ryt am alpbahtl,Райт,Райт-им-Альпбахталь,Райт-ім-Альпбахталь,ریت ام الپباحتل,阿尔普巴赫谷地赖特', 47.4169400, 11.8778500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2578, 'Reisenberg', 'Reisenberg', '', 47.9940600, 16.5201800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2579, 'Reinsberg', 'Reinsberg', 'Reinsperg', 47.9856700, 15.0706700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2580, 'Reingers', 'Reingers', '', 48.9666700, 15.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2581, 'Reifling', 'Reifling', 'Reifling', 47.1333300, 14.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2582, 'Reichraming', 'Reichraming', 'Reichraming', 47.8833300, 14.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2583, 'Reichenthal', 'Reichenthal', 'Reichenthal', 48.5428600, 14.3847100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2584, 'Reichenfels', 'Reichenfels', 'Rajkhenfel''s,lai xing fu er si,Райхенфельс,赖兴弗尔斯', 47.0071800, 14.7442500, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2585, 'Reichendorf', 'Reichendorf', 'Reichendorf', 47.1892200, 15.7616000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2586, 'Reichenau im Mühlkreis', 'Reichenau im Muhlkreis', 'Reichenau,Reichenau im Muhlkreis,Reichenau im Muhlkreise,Reichenau im Mühlkreis,Reichenau im Mühlkreise', 48.4570400, 14.3487500, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2587, 'Reichenau an der Rax', 'Reichenau an der Rax', 'Rajkhenau-an-der-Raks,Reichenau an der Rax,la ke si shan lu lai xie nao,Райхенау-ан-дер-Ракс,拉克斯山麓赖歇瑙', 47.6950900, 15.8457200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2588, 'Redlham', 'Redlham', 'Redlham', 48.0166700, 13.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2589, 'Redleiten', 'Redleiten', '', 48.0813800, 13.4689400, 'AT', '2017-05-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2590, 'Rechnitz', 'Rechnitz', 'Rechnitz,Rekhnic,Rohonc,lei xi ni ci,rknyz,Рехниц,רכניץ,雷希尼茨', 47.3046700, 16.4409500, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2591, 'Raxendorf', 'Raxendorf', '', 48.3410800, 15.2766600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2592, 'Ravelsbach', 'Ravelsbach', 'Ravel''sbakh,la fu er si ba he,Равельсбах,拉弗尔斯巴赫', 48.5500000, 15.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2593, 'Rauris', 'Rauris', 'Rauris,lao li si,Раурис,Рауріс,劳里斯', 47.2265600, 12.9945900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2594, 'Rauchenwarth', 'Rauchenwarth', '', 48.0833000, 16.5279400, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2595, 'Rattenberg', 'Rattenberg', 'Rattenberg', 47.4394100, 11.8940700, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2596, 'Ratten', 'Ratten', 'Ratten', 47.4833300, 15.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2597, 'Ratschendorf', 'Ratschendorf', 'Ratschendorf', 46.7422200, 15.8158300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2598, 'Ratsch an der Weinstraße', 'Ratsch an der Weinstrasse', 'Ratsch,Ratsch an der Weinstrasse,Ratsch an der Weinstraße', 46.6894400, 15.5711100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2599, 'Rastenfeld', 'Rastenfeld', 'Cirings,Rastenfel''d,la si teng fei er de,Растенфельд,Цирингс,拉斯滕费尔德', 48.5734800, 15.3317600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2600, 'Rassach', 'Rassach', 'Rassach', 46.8602800, 15.2700000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2601, 'Rappottenstein', 'Rappottenstein', 'Klajnnondorf,Rappottenshtajn,la bo teng shi tai yin,Клайннондорф,Раппоттенштайн,拉波滕施泰因', 48.5216100, 15.0792500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2602, 'Ranten', 'Ranten', 'Ranten', 47.1594900, 14.0834900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2603, 'Rankweil', 'Rankweil', 'Rankvajl,Rankvajl'',Rankweil,lan ke wei er,Ранквайл,Ранквайль,Ранквајл,رانک‌وایل,რანკვაილი,蘭克韋爾', 47.2710800, 9.6430800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2604, 'Raning', 'Raning', '', 46.8500000, 15.8166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2605, 'Ranggen', 'Ranggen', '', 47.2572700, 11.2112000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2606, 'Rangersdorf', 'Rangersdorf', '', 46.8600100, 12.9492300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2607, 'Randegg', 'Randegg', '', 48.0119800, 14.9733400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2608, 'Ramsau', 'Ramsau', '', 48.0031300, 15.8033200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2609, 'Ramsau im Zillertal', 'Ramsau im Zillertal', 'Ramsau,Ramsau im Zillertal,Ramzau,Рамзау', 47.2038300, 11.8754500, 'AT', '2012-02-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2610, 'Ramingstein', 'Ramingstein', '', 47.0746200, 13.8364200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2611, 'Raiding', 'Raiding', 'Doborjan,Doborján,Raiding,Rajding,Rajnof,raidingu,Райдинг,ライディング', 47.5658100, 16.5305600, 'AT', '2012-11-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2612, 'Ragnitz', 'Ragnitz', 'Ragnitz', 46.8366700, 15.5927800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2613, 'Raggal', 'Raggal', '', 47.2108200, 9.8368800, 'AT', '2013-04-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2614, 'Radstadt', 'Radstadt', 'Radshtadt,Radstadt,Radstatt,Rashtadt,Rodstoud,la de si ta te,Радштадт,Раштадт,拉德斯塔特', 47.3833300, 13.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2615, 'Bad Radkersburg', 'Bad Radkersburg', 'Bad Radkersburg,Bad-Radkersburg,Donja Radjona,Obrajna,Radgona,Radkersburg,ba te la de ke si bao,Бад Радкерсбург,Бад-Радкерсбург,巴特拉德克斯堡', 46.6880600, 15.9880600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2616, 'Radfeld', 'Radfeld', 'Radfeld', 47.4480600, 11.9142400, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2617, 'Radenthein', 'Radenthein', 'Radence,Radentajn,Radenthein,Radenče,la deng tai yin,Радентайн,拉登泰因', 46.8005600, 13.7116700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2618, 'Rachau', 'Rachau', 'Rachau', 47.2166700, 14.9000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2619, 'Rabenwald', 'Rabenwald', 'Rabenwald', 47.4000000, 15.9000000, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2620, 'Rabenstein an der Pielach', 'Rabenstein an der Pielach', '', 48.0653500, 15.4677200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2621, 'Rabensburg', 'Rabensburg', '', 48.6500000, 16.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2622, 'Raasdorf', 'Raasdorf', '', 48.2465700, 16.5653200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2623, 'Raach am Hochgebirge', 'Raach am Hochgebirge', 'Raach,Raach am Hochgebirge', 47.6333300, 15.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2624, 'Raabs an der Thaya', 'Raabs an der Thaya', 'Raabs,Raabs an der Thaya,Rabs-an-der-Tajja,Рабс-ан-дер-Тайя', 48.8500000, 15.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2625, 'Raabau', 'Raabau', 'Raabau', 46.9627800, 15.9116700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2626, 'Raaba', 'Raaba', 'Raaba', 47.0333300, 15.5000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2627, 'Pyhra', 'Pyhra', 'Khojberg,Pira,pi la,Пира,Хойберг,皮拉', 48.1591000, 15.6862400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2628, 'Pusterwald', 'Pusterwald', 'Pusterwald', 47.3061100, 14.3755600, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2629, 'Purkersdorf', 'Purkersdorf', 'Purkersdorf,pu er ke er si duo fu,Пуркерсдорф,普尔克尔斯多夫', 48.2076900, 16.1753900, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2630, 'Purgstall', 'Purgstall', '', 48.0584100, 15.1347800, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2631, 'Pulkau', 'Pulkau', 'Pul''kau,pu er kao,Пулькау,普尔考', 48.7048400, 15.8603100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2632, 'Pühret', 'Puhret', '', 48.0348800, 13.7225200, 'AT', '2017-07-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2633, 'Puchenstuben', 'Puchenstuben', 'Pukhenshtuben,pu xing shi tu ben,Пухенштубен,普兴施图本', 47.9281900, 15.2874800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2634, 'Puchberg am Schneeberg', 'Puchberg am Schneeberg', 'Puchberg,Puchberg am Schneeberge,Pukhberg-am-Shneberg,Pukhberg-am-Shneeberg,Пухберг-ам-Шнеберг,Пухберг-ам-Шнееберг', 47.7870900, 15.9135200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2635, 'Puch bei Weiz', 'Puch bei Weiz', 'Puch,Puch bei Weiz', 47.2166700, 15.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2636, 'Puch bei Hallein', 'Puch bei Hallein', 'Puch,Pukh-Khallajn,Пух-Халлайн', 47.7153600, 13.0929600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2637, 'Prutz', 'Prutz', 'Prutz', 47.0833300, 10.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2638, 'Pruggern', 'Pruggern', 'Pruggern', 47.4237000, 13.8762500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2639, 'Proleb', 'Proleb', 'Proleb', 47.4000000, 15.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2640, 'Prinzersdorf', 'Prinzersdorf', '', 48.2000000, 15.5166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2641, 'Prigglitz', 'Prigglitz', 'Priglic,pu li ge li ci,Приглиц,普里格利茨', 47.7031800, 15.9279400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2642, 'Pressbaum', 'Pressbaum', 'Presbaum,Pressbaum,pu lei si bao mu,Пресбаум,普雷斯鮑姆', 48.1833300, 16.0833300, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2643, 'Prellenkirchen', 'Prellenkirchen', '', 48.0740100, 16.9523300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2644, 'Preitenegg', 'Preitenegg', 'Prajteneg,pu lai te nei ge,Прайтенег,普赖特内格', 46.9400000, 14.9258300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2645, 'Preding', 'Preding', 'Preding,pu lei ding,Прединг,普雷丁', 46.8586100, 15.4097200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2646, 'Pram', 'Pram', 'Pram', 48.2353600, 13.6057900, 'AT', '2017-07-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2647, 'Prägraten', 'Praegraten', 'Praegraten am Grossvenediger,Prägraten am Großvenediger', 47.0166700, 12.3833300, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2648, 'Poysdorf', 'Poysdorf', 'Khjobertsgrub,Pojsdorf,Poysdorf,bo yi si duo fu,Пойсдорф,Хёбертсгруб,波伊斯多夫', 48.6666700, 16.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2649, 'Potzneusiedl', 'Potzneusiedl', 'Lajtafalu,Potzneusiedl', 48.0450400, 16.9477000, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2650, 'Pöttsching', 'Pottsching', 'Pecsenyed,Pecsenyéd', 47.8044500, 16.3710900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2651, 'Pottenstein', 'Pottenstein', '', 47.9582000, 16.0948000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2652, 'Pottendorf', 'Pottendorf', 'Pottendorf,bo teng duo fu,Поттендорф,波滕多夫', 47.9000000, 16.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2653, 'Pöttelsdorf', 'Pottelsdorf', 'Petofalva,Petőfalva', 47.7536900, 16.4386400, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2654, 'Poppendorf', 'Poppendorf', '', 46.8561100, 15.8563900, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2655, 'Pöls', 'Poels', 'Pjol''s,Pols,Pols ob Judenburg,Pöls,Pöls ob Judenburg,po er si,Пёльс,珀尔斯', 47.2166700, 14.5833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2656, 'Polling in Tirol', 'Polling in Tirol', 'Polling,Polling in Tirol', 47.2833300, 11.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2657, 'Pöllauberg', 'Poellauberg', 'Pollauberg,Pöllauberg', 47.3166700, 15.8500000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2658, 'Pöllau', 'Poellau', 'Pollau,Pollau bei Gleisdorf,Pöllau,Pöllau bei Gleisdorf', 47.3000000, 15.8333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2659, 'Pöggstall', 'Poggstall', 'Pjoggshtall'',Vjurnsdorf,po ge shi ta er,Вюрнсдорф,Пёггшталль,珀格施塔尔', 48.3173400, 15.2040500, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2660, 'Poggersdorf', 'Poggersdorf', 'Poggersdorf,Pokrce,Pokrče,bo ge er si duo fu,Поггерсдорф,波格尔斯多夫', 46.6500000, 14.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2661, 'Podersdorf am See', 'Podersdorf am See', 'Patfalu,Podersdorf,Podersdorf-am-Ze,Podersdorf-am-Zee,Poudistoaf,Pátfalu,bin hu bo de er si duo fu,Подерсдорф-ам-Зе,Подерсдорф-ам-Зее,滨湖波德尔斯多夫', 47.8541200, 16.8370600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2662, 'Pöchlarn', 'Pochlarn', 'Bechlarn,Gross Pochlarn,Gross Pöchlarn,P''okhlarn,Pekhlarn,Pjokhlarn,Pochlarn,Pöchlarn,po xi la en,Пехларн,Пьохларн,Пёхларн,珀希拉恩', 48.2000000, 15.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2663, 'Plainfeld', 'Plainfeld', '', 47.8333300, 13.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2664, 'Pitzenberg', 'Pitzenberg', '', 48.0736100, 13.7248400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2665, 'Pitten', 'Pitten', 'Incenkhof,Pitten,pi teng,Инценхоф,Питтен,皮滕', 47.7166700, 16.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2666, 'Pitschgau', 'Pitschgau', 'Pitschgau', 46.7000000, 15.2666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2667, 'Pistorf', 'Pistorf', 'Pistorf', 46.7666700, 15.3666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2668, 'Pirka', 'Pirka', '', 47.0000000, 15.3833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2669, 'Piringsdorf', 'Piringsdorf', 'Piringstof,Piringštof,Repcebonya,Répcebónya', 47.4482600, 16.4151600, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2670, 'Pirching am Traubenberg', 'Pirching am Traubenberg', 'Pirching,Pirching am Traubenberg', 46.9500000, 15.6000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2671, 'Pinkafeld', 'Pinkafeld', 'Pinkafel''d,Pinkafeld,Pinkafelj,Pinkafo,Pinkafoed,Pinkaföd,Pinkafő,ping ka fei er te,Пинкафельд,萍卡菲尔特', 47.3666700, 16.1166700, 'AT', '2012-11-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2672, 'Pinggau', 'Pinggau', 'Pinggau,ping gao,Пинггау,平高', 47.4333300, 16.0666700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2673, 'Pillichsdorf', 'Pillichsdorf', 'Pilliksdorf,pi li xi si duo fu,Пилликсдорф,皮利希斯多夫', 48.3500000, 16.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2674, 'Pill', 'Pill', 'Pill,Pill unter dem Bache', 47.3235200, 11.6801800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2675, 'Pilgersdorf', 'Pilgersdorf', 'Pilistrof,Pilištrof,Poergoeleny,Pörgölény', 47.4410600, 16.3492000, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2676, 'Piesendorf', 'Piesendorf', '', 47.2907700, 12.7183900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2677, 'Piberegg', 'Piberegg', 'Piberegg', 47.0833300, 15.0833300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2678, 'Pians', 'Pians', 'Pians', 47.1348600, 10.5123700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2679, 'Pfunds', 'Pfunds', 'Fuond,Pfunds,pu feng de si,Пфундс,پفنڈز,普丰德斯', 46.9666700, 10.5500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2680, 'Pfons', 'Pfons', 'Pfons,pu feng si,Пфонс,普豐斯', 47.1420100, 11.4607100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2681, 'Pflach', 'Pflach', 'Pflach', 47.5166700, 10.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2682, 'Pfarrkirchen im Mühlkreis', 'Pfarrkirchen im Muehlkreis', 'Pfarrkirchen,Pfarrkirkhen,Pfarrkirkhen-im-Mjul''krajs,mi er de qu pu fa er ji xing,Пфарркирхен,Пфарркирхен-им-Мюлькрайс,米尔地区普法尔基兴', 48.5037500, 13.8263800, 'AT', '2011-07-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2683, 'Pfarrkirchen bei Bad Hall', 'Pfarrkirchen bei Bad Hall', 'Pfarrkirchen,Pfarrkirchen bei Bad Hall', 48.0304600, 14.1991400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2684, 'Pfaffstätten', 'Pfaffstatten', 'Pfafshtetten,pu fa fu shi te teng,Пфафштеттен,普法夫施特滕', 48.0173700, 16.2635400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2685, 'Pfaffing', 'Pfaffing', '', 48.0180000, 13.4750700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2686, 'Pfaffenhofen', 'Pfaffenhofen', '', 47.3000000, 11.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2687, 'Peuerbach', 'Peuerbach', 'Beiaboch,Pojerbakh,pai er ba he,Пойербах,派尔巴赫', 48.3453000, 13.7720500, 'AT', '2017-07-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2688, 'Petzenkirchen', 'Petzenkirchen', '', 48.1333300, 15.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2689, 'Petronell-Carnuntum', 'Petronell-Carnuntum', 'Petronell,Petronell''-Karnuntum,Petronell-Carnuntum,pei te luo nei er-ka nong tu mu,Петронелль-Карнунтум,佩特罗内尔-卡农图姆', 48.1129600, 16.8658200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2690, 'Pertlstein', 'Pertlstein', 'Pertlstein', 46.9405600, 15.9616700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2691, 'Pernitz', 'Pernitz', 'Pernic,pei ni ci,Перниц,Перніц,佩尼茨', 47.8975900, 15.9602200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2692, 'Pernersdorf', 'Pernersdorf', '', 48.7000000, 16.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2693, 'Pernegg an der Mur', 'Pernegg an der Mur', 'Bereneck,Perneg-an-der-Mur,Pernegg,Pernegg-an-der-Mur,mu er he pan pei er nei ge,Пернег-ан-дер-Мур,Пернегг-ан-дер-Мур,穆尔河畔佩尔内格', 47.3597900, 15.3423600, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2694, 'Pernegg', 'Pernegg', '', 48.7333300, 15.6166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2695, 'Perlsdorf', 'Perlsdorf', 'Perlsdorf', 46.9136100, 15.8141700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2696, 'Perg', 'Perg', 'Perg,pei er ge,Перг,პერგი,佩爾格', 48.2500000, 14.6333300, 'AT', '2014-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2697, 'Perchtoldsdorf', 'Perchtoldsdorf', 'Paedaschduaf,Perkhtol''dsdorf,Perkhtoldzdorf,Pädaschduaf,pei xi tuo er ci duo fu,prshtwlsdwrf,Перхтолдздорф,Перхтольдсдорф,پرشتولسدورف,პერხტოლდსდორფი,佩希托爾茨多夫', 48.1193500, 16.2660700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2698, 'Perchau am Sattel', 'Perchau am Sattel', 'Perchau,Perchau am Sattel', 47.1000000, 14.4500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2699, 'Pennewang', 'Pennewang', 'Pennewang', 48.1333300, 13.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2700, 'Peggau', 'Peggau', 'Peggau,pei gao,Пеггау,佩高', 47.2000000, 15.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2701, 'Payerbach', 'Payerbach', 'Pajerbakh,pai er ba he,Пайербах,派尔巴赫', 47.6920900, 15.8634000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2702, 'Paudorf', 'Paudorf', 'Khjorfart,Paudorf,bao duo fu,Паудорф,Хёрфарт,保多夫', 48.3500000, 15.6166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2703, 'Patsch', 'Patsch', '', 47.2052700, 11.4151000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2704, 'Paternion', 'Paternion', 'Paternion,Spatrjan,pa te ni weng,Špatrjan,Патернион,帕特尼翁', 46.7141700, 13.6361100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2705, 'Passail', 'Passail', 'Passail,Passajl'',pa sai er,Пассайль,帕赛尔', 47.2833300, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2706, 'Pasching', 'Pasching', 'Pasching,Pashing,Pasingas,Pašingas,pa xing,Пашинг,帕興', 48.2593100, 14.2036900, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2707, 'Parschlug', 'Parschlug', '', 47.4809000, 15.2864500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2708, 'Parndorf', 'Parndorf', 'Pandorfalu,Pandrof,Parndorf,Pándorfalu,pa en duo fu,parundorufu,Парндорф,パルンドルフ,帕恩多夫', 47.9996300, 16.8604900, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2709, 'Parbasdorf', 'Parbasdorf', '', 48.2833300, 16.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2710, 'Pamhagen', 'Pamhagen', 'Pamhagen,Pamkhagen,Pomogy,Памхаген', 47.7009200, 16.9077900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2711, 'Pama', 'Pama', 'Bijelo Selo,Lajtakoertvelyes,Lajtakörtvélyes,Pama,Пама', 48.0500000, 17.0333300, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2712, 'Palfau', 'Palfau', 'Pal''fau,Palfau,pa er fu,Пальфау,帕尔福', 47.7000000, 14.8000000, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2713, 'Paldau', 'Paldau', 'Paldau', 46.9422200, 15.7958300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2714, 'Pack', 'Pack', 'Pack', 46.9791700, 14.9841700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2715, 'Oetz', 'Oetz', 'Ec,Ehc,Ehtc,Oetz,Otz,e ci,Ötz,Ец,Этц,Эц,厄茨', 47.2000000, 10.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2716, 'Otterthal', 'Otterthal', 'Ottertal,Otterthal', 47.6166700, 15.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2717, 'Ottenthal', 'Ottenthal', '', 48.7610000, 16.5791400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2718, 'Ottensheim', 'Ottensheim', 'Ottensheim,Ottenskhajm,ao teng si hai mu,Оттенсхайм,奥滕斯海姆', 48.3324600, 14.1742500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2719, 'Ottenschlag im Mühlkreis', 'Ottenschlag im Muhlkreis', 'Ottenschlag,Ottenschlag im Muhlkreis,Ottenschlag im Mühlkreis', 48.4663200, 14.3847100, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2720, 'Ottenschlag', 'Ottenschlag', '', 48.4239300, 15.2192400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2721, 'Osterwitz', 'Osterwitz', 'Ostervic,Osterwitz,ao shi te er wei ci,Остервиц,奥施特尔维茨', 46.8594300, 15.0899800, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2722, 'Ossiach', 'Ossiach', 'Osoje,Ossiach,Ossiakh,Ossijakh,ao xi ya he,Оссиах,Оссіях,奥西亚赫', 46.6743500, 13.9835800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2723, 'Oslip', 'Oslip', 'Oslip,Oszlop,Uzlop,Ослип', 47.8290600, 16.6195700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2724, 'Orth an der Donau', 'Orth an der Donau', 'Orth', 48.1452400, 16.7008900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2725, 'Opponitz', 'Opponitz', 'Opponic,ao bo ni ci,Оппониц,奥波尼茨', 47.8777600, 14.8228300, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2726, 'Oppenberg', 'Oppenberg', 'Oppenberg', 47.4833300, 14.2666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2727, 'Ollersdorf im Burgenland', 'Ollersdorf im Burgenland', 'Ollersdorf,Ollersdorf (Burgenland),Ollersdorf im Burgenland,Оллерсдорф (Бургенланд)', 47.1833300, 16.1666700, 'AT', '2017-03-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2728, 'Olbendorf', 'Olbendorf', '', 47.1833300, 16.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2729, 'Offenhausen', 'Offenhausen', 'Offenhausen', 48.1500000, 13.8333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2730, 'Öblarn', 'OEblarn', 'Oblarn,Oeblarn,Öblarn', 47.4593800, 13.9902300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2731, 'Oberzeiring', 'Oberzeiring', 'Obercajring,Oberzeiring,shang cai ling,Оберцайринг,上蔡灵', 47.2500000, 14.4833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2732, 'Oberwölz Stadt', 'Oberwoelz Stadt', 'Oberwolz,Oberwolz Stadt,Oberwölz,Oberwölz Stadt', 47.2011700, 14.2832100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2733, 'Oberweg', 'Oberweg', 'Oberweg,Oberweg Talkessel', 47.1500000, 14.6333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2734, 'Oberwart', 'Oberwart', 'Felsoor,Felsőőr,Gornja Borta,Obervart,Oberwart,Owawart,Zgornja Borta,shang wa te,Оберварт,אוברוורט,上瓦特', 47.2897100, 16.2059500, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2735, 'Oberwang', 'Oberwang', 'Oberwang', 47.8666700, 13.4333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2736, 'Oberwaltersdorf', 'Oberwaltersdorf', '', 47.9756700, 16.3219100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2737, 'Obervogau', 'Obervogau', 'Obervogau', 46.7450000, 15.5847200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2738, 'Obervellach', 'Obervellach', 'Oberfellakh,Obervellach,shang wei la he,Оберфеллах,上韦拉赫', 46.9366700, 13.2041700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2739, 'Obertrum am See', 'Obertrum am See', 'Obertrum,Obertrum am See,Obertrum-am-Zee,Обертрум-ам-Зее', 47.9372200, 13.0772200, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2740, 'Obertilliach', 'Obertilliach', 'Obertiliakh,Obertilliach,Obertilliakh,Obertillijakh,awbrtylyakh,shang di li la he,Обертилиах,Обертиллиах,Обертілліях,اوبرتیلیاخ,上蒂利拉赫', 46.7105600, 12.6144400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2741, 'Oberstorcha', 'Oberstorcha', 'Oberstorcha', 46.9666700, 15.8000000, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2742, 'Obersiebenbrunn', 'Obersiebenbrunn', '', 48.2653700, 16.7107600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2743, 'Oberschützen', 'Oberschutzen', 'Felsoloevo,Felsőlövő,Obershjutcen,shang xu cen,Обершютцен,上许岑', 47.3513800, 16.2073200, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2744, 'Oberrettenbach', 'Oberrettenbach', 'Oberrettenbach', 47.1500000, 15.8000000, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2745, 'Oberpullendorf', 'Oberpullendorf', 'Felsopulya,Felsőpulya,Gornja Pulja,Oberpulendorf,Oberpullendorf,Owapuindorf,shang pu lun duo fu,Оберпулендорф,Оберпуллендорф,上普伦多夫', 47.5035200, 16.5044700, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2746, 'Pettnau', 'Pettnau', 'Oberpettnau,Pettnau', 47.2920400, 11.1596200, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2747, 'Oberneukirchen', 'Oberneukirchen', 'Oberneukirchen,Obernojkirkhen,Обернойкирхен', 48.4640400, 14.2227500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2748, 'Oberndorf in Tirol', 'Oberndorf in Tirol', 'Oberndorf,Oberndorf in Tirol', 47.5000000, 12.3833300, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2749, 'Oberndorf bei Schwanenstadt', 'Oberndorf bei Schwanenstadt', '', 48.0555900, 13.7567700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2750, 'Oberndorf bei Salzburg', 'Oberndorf bei Salzburg', 'Oberndorf,Oberndorf baj Zalcburg,Oberndorf bei Salzburg,Oberndorf-Zal''cburg,Oberndorf-baj-Zal''cburg,Owandorf ba Soizburg,ou ben duo fu,Оберндорф бай Залцбург,Оберндорф-Зальцбург,Оберндорф-бай-Зальцбург,歐本多夫', 47.9500000, 12.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2751, 'Oberndorf an der Melk', 'Oberndorf an der Melk', 'Oberndorf,Oberndorf-an-der-Melk,Оберндорф-ан-дер-Мелк', 48.0638600, 15.2243000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2752, 'Oberloisdorf', 'Oberloisdorf', 'Felsolaszlo,Felsőlászló,Nadrlostrof,Nadrloštrof', 47.4473600, 16.5076400, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2753, 'Oberlienz', 'Oberlienz', 'Oberlienc,Oberlienz,shang lin ci,Оберлиенц,Оберлієнц,上林茨', 46.8472200, 12.7313900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2754, 'Oberkurzheim', 'Oberkurzheim', 'Oberkurzheim', 47.2333300, 14.5833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2755, 'Oberhofen im Inntal', 'Oberhofen im Inntal', 'Oberhofen,Oberhofen im Inntal,Oberhofen in Tirol,Oberkhofen,Оберхофен', 47.3000000, 11.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2756, 'Oberhofen am Irrsee', 'Oberhofen am Irrsee', 'Oberhofen,Oberhofen am Irrsee,Oberkhofen-am-Irrzee,Oberkhofen-am-Irze,yi er hu pan shang huo fen,Оберхофен-ам-Ирзе,Оберхофен-ам-Иррзее,伊尔湖畔上霍芬', 47.9500000, 13.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2757, 'Oberhaag', 'Oberhaag', 'Oberkhag,shang ha ge,Оберхаг,上哈格', 46.6869000, 15.3320200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2758, 'Ober-Grafendorf', 'Ober-Grafendorf', '', 48.1504000, 15.5453100, 'AT', '2017-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2759, 'Oberdrauburg', 'Oberdrauburg', 'Ober-Drauberg,Oberdrauburg,shang de lao bao,Обердраубург,上德劳堡', 46.7430600, 12.9702800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2760, 'Oberdorf im Burgenland', 'Oberdorf im Burgenland', 'Oberdorf,Oberdorf (Burgerland),Oberdorf im Burgenland,Обердорф (Бургерланд)', 47.2166700, 16.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2761, 'Oberdorf am Hochegg', 'Oberdorf am Hochegg', 'Oberdorf,Oberdorf am Hochegg', 46.9786100, 15.7216700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2762, 'Oberalm', 'Oberalm', '', 47.7000000, 13.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2763, 'Oberaich', 'Oberaich', '', 47.4000000, 15.2166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2764, 'Obdach', 'Obdach', 'Obdach', 47.0666700, 14.6833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2765, 'Nüziders', 'Nuziders', 'Njuciders,nu qi de si,Нюцидерс,努齐德斯', 47.1666700, 9.8000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2766, 'Nußdorf am Haunsberg', 'Nussdorf am Haunsberg', 'Nusdorf-am-Gaunsberg,Nusdorf-am-Khaunsberg,Nussdorf,Nussdorf am Haunsberg,Nußdorf am Haunsberg,hao en si shan lu nu si duo fu,Нусдорф-ам-Гаунсберг,Нусдорф-ам-Хаунсберг,豪恩斯山麓努斯多夫', 47.9594400, 13.0091700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2767, 'Nofels', 'Nofels', 'Nofels', 47.2548300, 9.5780200, 'AT', '2012-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2768, 'Nöchling', 'Nochling', '', 48.2243300, 14.9812300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2769, 'Nitscha', 'Nitscha', 'Nitscha', 47.1166700, 15.7500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2770, 'Nikolsdorf', 'Nikolsdorf', 'Nikol''sdorf,Nikolsdorf,ni ke er si duo fu,Никольсдорф,Нікольсдорф,尼科尔斯多夫', 46.7858300, 12.9133300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2771, 'Niklasdorf', 'Niklasdorf', 'Niklasdorf,Никласдорф', 47.3833300, 15.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2772, 'Nikitsch', 'Nikitsch', 'Filez,Filež,Fueles,Füles,Nikich,Nikitsch,Никич', 47.5361500, 16.6601700, 'AT', '2012-11-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2773, 'Niederwölz', 'Niederwolz', 'Niederwolz,Niederwölz', 47.1512600, 14.3747900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2774, 'Niederthalheim', 'Niederthalheim', 'Niederthalheim', 48.0990100, 13.7687000, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2775, 'Niederöblarn', 'Niederoeblarn', 'Niederoblarn,Niederöblarn', 47.4766700, 14.0193700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2776, 'Niedernsill', 'Niedernsill', '', 47.2833300, 12.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2777, 'Niederndorf', 'Niederndorf', '', 47.6500000, 12.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2778, 'Niederleis', 'Niederleis', 'Niderlajs,xia lai si,Нидерлайс,下莱斯', 48.5500000, 16.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2779, 'Niederhollabrunn', 'Niederhollabrunn', 'Niderkhollabrun,Niderkhollabrunn,Niederhollabrunn,xia huo la bu lun,Нидерхоллабрун,Нидерхоллабрунн,下霍拉布伦', 48.4333300, 16.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2780, 'Nickelsdorf', 'Nickelsdorf', 'Mikloshalma,Miklóshalma,Nickelsdorf,Nikel''sdorf,Nikkel''sdorf,ni ke er si duo fu,Никкельсдорф,Нікельсдорф,尼克尔斯多夫', 47.9405600, 17.0694400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2781, 'Neutal', 'Neutal', 'Najtolj,Nyujtal,Nyujtál,Sopronujlak,Sopronújlak', 47.5454800, 16.4461900, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2782, 'Neustift im Stubaital', 'Neustift im Stubaital', 'Neustift,Neustift im Stubaital,Nojshtift,Nojshtift-im-Shtubajtal'',shi tu bai gu de xin shi di fu te,Нойштифт,Нойштіфт-ім-Штубайталь,نیوسٹفٹ ام سٹوبائٹل,施图拜谷地新施蒂夫特', 47.1166700, 11.3166700, 'AT', '2014-05-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2783, 'Neustift bei Güssing', 'Neustift bei Gussing', 'Neustift,Neustift bei Gussing,Neustift bei Güssing', 47.0247400, 16.2604100, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2784, 'Neustift an der Lafnitz', 'Neustift an der Lafnitz', 'Neustift,Neustift an der Lafnitz,Nojstift-na-Lafnice,Нойстифт-на-Лафнице', 47.3666700, 16.0333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2785, 'Neusiedl an der Zaya', 'Neusiedl an der Zaya', 'Neusiedl,Neusiedl an der Zaya,Neusiedl-Zaya,Nojzidl''-an-der-Cajja,Нойзидль-ан-дер-Цайя', 48.5992000, 16.7799000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2786, 'Neusiedl am See', 'Neusiedl am See', 'Neisiedl am See,Neusiedl,Neusiedl am See,Nezsider,Nojzidl am Zee,Nojzidl na Jezeru,Nojzidl''-am-Ze,Nojzidl''-am-Zee,Nojzidul am Zee,bin hu xin xi de er,Нойзидль-ам-Зе,Нойзидль-ам-Зее,Нойзидъл ам Зее,Нойзідль-ам-Зеє,Нојзидл ам Зее,Нојзидл на Језеру,נויזידל אם זי,濱湖新錫德爾', 47.9490100, 16.8417000, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2787, 'Neunkirchen', 'Neunkirchen', '', 47.7209600, 16.0810700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2788, 'Neumarkt in Steiermark', 'Neumarkt in Steiermark', 'Neumarkt,Neumarkt in Steiermark,Nojmarkt,Nojmarkt-in-Shtajermark,Sankt-Marajn-Nojmarkt,shi tai er ma ke de qu nuo yi ma ke te,Ноймаркт,Ноймаркт-ин-Штайермарк,Санкт-Марайн-Ноймаркт,施泰尔马克地区诺伊马克特', 47.0739800, 14.4272800, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2789, 'Neumarkt an der Ybbs', 'Neumarkt an der Ybbs', 'Neumarkt,Neumarkt an der Ybbs', 48.1410300, 15.0575800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2790, 'Neumarkt am Wallersee', 'Neumarkt am Wallersee', 'Neimorkt am Woiersee,Neumark,Neumarkt,Neumarkt am Wallersee,Nojmarkt-am-Vallerze,Nojmarkt-am-Vallerzee,wa lei hu pan nuo yi ma ke te,Ноймаркт-ам-Валлерзе,Ноймаркт-ам-Валлерзее,瓦勒湖畔诺伊马克特', 47.9500000, 13.2333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2791, 'Neulengbach', 'Neulengbach', 'Nojlengbakh,xin lun ba he,Нойленгбах,新伦巴赫', 48.1974500, 15.9021900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2792, 'Neukirchen bei Lambach', 'Neukirchen bei Lambach', 'Neukirchen,Neukirchen bei Lambach', 48.1000000, 13.8166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2793, 'Neukirchen an der Vöckla', 'Neukirchen an der Vockla', 'Neukirchen,Neukirchen an der Vockla,Neukirchen an der Vöckla,Nojkirkhen-an-der-Fjokla,Нойкирхен-ан-дер-Фёкла', 48.0333300, 13.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2794, 'Neukirchen am Großvenediger', 'Neukirchen am Grossvenediger', 'Neukirchen,Neukirchen am Grossvenediger,Neukirchen am Großvenediger,Nojkirkhen-am-Grosfenediger,Нойкирхен-ам-Гросфенедигер', 47.2504600, 12.2758500, 'AT', '2016-07-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2795, 'Neuhofen an der Ybbs', 'Neuhofen an der Ybbs', 'Neuhofen,Nojkhofen-na-Ibbse,Нойхофен-на-Иббсе', 48.0579500, 14.8548900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2796, 'Neuhaus', 'Neuhaus', '', 46.6333300, 14.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2797, 'Neufeld an der Leitha', 'Neufeld an der Leitha', 'Lajtaujfalu,Lajtaújfalu,Neifoed an da Leitha,Neiföd an da Leitha,Neufeld,Neufeld an der Leitha,Nojfel''d-an-der-Lajta,Nojfel''d-an-der-Lajte,Nojfel''d-na-Lajte,Nojfel''d-na-Lajti,Novo Selo,lai ta he pan nuo yi fu er de,Нойфельд-ан-дер-Лайта,Нойфельд-ан-дер-Лайте,Нойфельд-на-Лайте,Нойфельд-на-Лайті,莱塔河畔诺伊弗尔德', 47.8655800, 16.3785600, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2798, 'Neudörfl', 'Neudorfl', 'Lajtaszentmiklos,Lajtaszentmiklós,Nojderfl'',Nojdjorfl'',xin de er fu,Нойдерфль,Нойдёрфль,新德尔夫', 47.7965500, 16.2977000, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2799, 'Neudorf bei Staatz', 'Neudorf bei Staatz', 'Neudorf,Neudorf bei Staatz', 48.7208300, 16.4913900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2800, 'Neudau', 'Neudau', 'Neudau', 47.1755400, 16.1018400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2801, 'Neuberg an der Mürz', 'Neuberg an der Muerz', 'Neuberg,Nojberg an der Mjurc,Nojberg-an-der-Mjurc,mi er ci he pan nuo yi bei ge,Нойберг ан дер Мюрц,Нойберг-ан-дер-Мюрц,米尔茨河畔诺伊贝格', 47.6642300, 15.5722600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2802, 'Nestelbach im Ilztal', 'Nestelbach im Ilztal', 'Nestelbach im Ilztal,Nestolbach', 47.0833300, 15.8666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2803, 'Nestelbach bei Graz', 'Nestelbach bei Graz', 'Nestelbach,Nestelbach bei Graz', 47.0605300, 15.6114000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2804, 'Nesselwängle', 'Nesselwangle', 'Nessel''vengle,Nesselwangle,Nesselwängle,na se er wen lei,Нессельвенгле,纳瑟尔文勒', 47.4833300, 10.6166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2805, 'Nenzing', 'Nenzing', 'Nencing,nen qing,Ненцинг,Ненцінг,嫩青', 47.1843600, 9.7053900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2806, 'Neidling', 'Neidling', 'Neidling,Neudling', 48.2400500, 15.5559100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2807, 'Neckenmarkt', 'Neckenmarkt', 'Lekindrof,Neckenmarkt,Nekenmarkt,Nekkenmarkt,Sopronnyek,Sopronnyék,nei ken ma ke te,Некенмаркт,Неккенмаркт,内肯马克特', 47.5996400, 16.5467000, 'AT', '2012-11-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2808, 'Nauders', 'Nauders', 'Nauders,nuo de li ao,Наудерс,诺德里奥', 46.8885900, 10.5012600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2809, 'Natters', 'Natters', 'Natters,na te si,Наттерс,نیٹرز,納特斯', 47.2341400, 11.3734200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2810, 'Nassereith', 'Nassereith', 'Nasserajt,Nassereith,na se lai te,nasryt,Нассерайт,ناسریت,纳瑟莱特', 47.3166700, 10.8333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2811, 'Namlos', 'Namlos', 'Namlos', 47.3500000, 10.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2812, 'Naas', 'Naas', 'Naas', 47.2508600, 15.5944900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2813, 'Mutters', 'Mutters', 'Mutters,mu te si,Муттерс,穆特斯', 47.2333300, 11.3833300, 'AT', '2012-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2814, 'Musau', 'Musau', 'Agno,Musau,Агно', 47.5319500, 10.6733900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2815, 'Mürzzuschlag', 'Muerzzuschlag', 'Mircushlag,Mjurccushlag,Murssuschalg,Murzzuschlag,Mürzzuschlag,mi er ci chu shi la ge,Мирцушлаг,Мюрццушлаг,מירצצושלאג,مۇرززۇسچلاگ,米爾茨楚施拉格', 47.6000000, 15.6833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2816, 'Mürzsteg', 'Muerzsteg', 'Mircshteg,Mjurcshteg,Murzsteg,Myrtsstenk,Mürzsteg,mi er ci shi tai ge,Μύρτσστεγκ,Мирцштег,Мюрцштег,米尔茨施泰格', 47.6755600, 15.4914500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2817, 'Mürzhofen', 'Muerzhofen', 'Murtzhofen,Murzhofen,Mürtzhofen,Mürzhofen', 47.4833300, 15.3833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2818, 'Mureck', 'Mureck', 'Cmurek,Mureck,Murehkk,mu lei ke,Мурэкк,穆勒克', 46.7080600, 15.7747200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2819, 'Münster', 'Munster', 'Mjunster,Мюнстер', 47.4216400, 11.8335600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2820, 'Münchendorf', 'Munchendorf', 'Mjunkhendorf,Muenchendorf,Munchendorf,Münchendorf,Мюнхендорф', 48.0333300, 16.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2821, 'Müllendorf', 'Mullendorf', 'Melindoff,Szarazvam,Szárazvám', 47.8394300, 16.4625800, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2822, 'Muhr', 'Muhr', 'Muhr,Mur', 47.0989300, 13.4975600, 'AT', '2014-10-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2823, 'Mühlgraben', 'Muhlgraben', '', 46.8897200, 16.0408300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2824, 'Mühlen', 'Muhlen', '', 47.0307100, 14.5084800, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2825, 'Mühldorf bei Feldbach', 'Muehldorf bei Feldbach', 'Mjul''dorf (Fel''dbakh),Muhldorf,Muhldorf bei Feldbach,Mühldorf,Mühldorf bei Feldbach,Мюльдорф (Фельдбах)', 46.9386100, 15.9075000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2826, 'Mühldorf', 'Muhldorf', '', 48.3666700, 15.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2827, 'Mühldorf', 'Muhldorf', '', 46.8602800, 13.3536100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2828, 'Mühlbach am Hochkönig', 'Muhlbach am Hochkonig', 'Mijbouch am Houchkinig,Mjul''bakh-am-Gokhkenig,Mjul''bakh-am-Khokhkjonig,Muhlbach,Muhlbach am Hochkonig,Mühlbach,Mühlbach am Hochkönig,shang ke ni xi shan lu mi er ba he,Мюльбах-ам-Гохкеніг,Мюльбах-ам-Хохкёниг,上柯尼希山麓米尔巴赫', 47.3774600, 13.1292600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2829, 'Muggendorf', 'Muggendorf', '', 47.9105900, 15.9353300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2830, 'Mötz', 'Motz', '', 47.2833300, 10.9500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2831, 'Moschendorf', 'Moschendorf', 'Moschendorf,Moshendorf,Nagysaroslak,Nagysároslak,Мошендорф', 47.0584300, 16.4772800, 'AT', '2013-04-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2832, 'Mörtschach', 'Mortschach', '', 46.9238900, 12.9177800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2833, 'Mortantsch', 'Mortantsch', 'Mortantsch', 47.2000000, 15.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2834, 'Mörbisch am See', 'Morbisch am See', 'Fertomeggyes,Fertőmeggyes,Mjorbish-am-Zee,Moerbisch am See,Morbisch,Morbisch am See,Mörbisch,Mörbisch am See,Мёрбиш-ам-Зее', 47.7500000, 16.6666700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2835, 'Mooskirchen', 'Mooskirchen', 'Mooskirchen', 46.9816700, 15.2788900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2836, 'Moosburg', 'Moosburg', 'Moosburg,Moosburg in Karnten,Moosburg in Kärnten,Mosburg,Мосбург', 46.6575000, 14.1747200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2837, 'Moosbrunn', 'Moosbrunn', '', 48.0166700, 16.4500000, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2838, 'Mönichwald', 'Moenichwald', 'Monichwald,Mönichwald,mo ni xi wa er de,莫尼希瓦尔德', 47.4465500, 15.8827500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2839, 'Mönichkirchen', 'Monichkirchen', 'Mjonikhkirkhen,mo ni xi ji xing,Мёнихкирхен,默尼希基兴', 47.5106200, 16.0342500, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2840, 'Mondsee', 'Mondsee', 'Mondzee,Мондзее', 47.8564800, 13.3490800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2841, 'Mönchhof', 'Monchhof', 'Baratudvar,Barátudvar', 47.8802000, 16.9412600, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2842, 'Mölbling', 'Molbling', '', 46.8500000, 14.4333300, 'AT', '2013-12-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2843, 'Möggers', 'Moggers', '', 47.5666700, 9.8166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2844, 'Mogersdorf', 'Mogersdorf', 'Mogersdorf,Nagyfalva,mo ge er si duo fu,Могерсдорф,莫格尔斯多夫', 46.9491700, 16.2322200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2845, 'Modriach', 'Modriach', 'Modriach', 46.9500000, 15.0500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2846, 'Mödling', 'Modling', 'Medling,Medlingas,Mjodling,Moedling,Mödling,Mėdlingas,mdlyng,medlingi,mo de lin,mwdlyng,Медлинг,Мёдлинг,מדלינג,مودلینگ,მედლინგი,默德林', 48.0860500, 16.2892100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2847, 'Mittersill', 'Mittersill', 'Mittasue,Mittasü,Mittersil,Mittersill,Mitterzil'',Mitterzill'',mi te xi er,Миттерзилль,Миттерзиль,Міттерзілль,მიტერზილი,米特西爾', 47.2833300, 12.4833300, 'AT', '2014-09-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2848, 'Mitterndorf an der Fischa', 'Mitterndorf an der Fischa', 'Mitterndorf,Mitterndorf an der Fischa,Mitterndorf-an-der-Fisha,fei sha he pan mi te en duo fu,Миттерндорф-ан-дер-Фиша,菲沙河畔米特恩多夫', 47.9973900, 16.4735700, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2849, 'Mitterlabill', 'Mitterlabill', 'Mitterlabill', 46.8891700, 15.6355600, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2850, 'Mitterdorf im Mürztal', 'Mitterdorf im Muerztal', 'Mitterdorf,Mitterdorf (Mjurcal''),Mitterdorf im Murztal,Mitterdorf im Mürztal,Миттердорф (Мюрцаль)', 47.5333300, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2851, 'Mitterdorf an der Raab', 'Mitterdorf an der Raab', 'Mitterdorf,Mitterdorf an der Raab', 47.1666700, 15.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2852, 'Mitterbach am Erlaufsee', 'Mitterbach am Erlaufsee', 'Mitterbakh-am-Ehrlaufzee,ai lao fu hu pan mi te er ba he,Миттербах-ам-Эрлауфзее,埃劳夫湖畔米特尔巴赫', 47.8139600, 15.2953700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2853, 'Mittelberg', 'Mittelberg', '', 47.3512700, 10.1719700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2854, 'Mistelbach', 'Mistelbach', 'Mistel''-Bakh,Mistelbach,Mistelbach an der Zaya,Мистель-Бах', 48.5700000, 16.5766700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2855, 'Mischendorf', 'Mischendorf', 'Mishendorf,Pinkamiske,mi shen duo fu,Мишендорф,Мішендорф,米申多夫', 47.1927700, 16.3144400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2856, 'Mils bei Imst', 'Mils bei Imst', 'Mils,Mils bei Imst', 47.2061600, 10.6748500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2857, 'Miesenbach', 'Miesenbach', '', 47.8403500, 15.9823600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2858, 'Miesenbach bei Birkfeld', 'Miesenbach bei Birkfeld', 'Miesenbach', 47.3666700, 15.7666700, 'AT', '2017-06-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2859, 'Mieming', 'Mieming', 'Miming,maymng,mi ming,Миминг,Мімінг,مائمنگ,米明', 47.3000000, 10.9833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2860, 'Mieders', 'Mieders', 'Miders,mi de er si,Мидерс,Мідерс,米德尔斯', 47.1666700, 11.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2861, 'Michelhausen', 'Michelhausen', '', 48.2908500, 15.9389300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2862, 'Micheldorf in Oberösterreich', 'Micheldorf in Oberoesterreich', 'Micheldorf,Mikhel''dorf,Mikhel''dorf (Verkhnjaja Avstrija),shang ao de li zhou mi xie er duo fu,Михельдорф,Михельдорф (Верхняя Австрия),上奧地利州米歇爾多夫', 47.8776400, 14.1335700, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2863, 'Micheldorf', 'Micheldorf', '', 46.9166700, 14.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2864, 'Michaelerberg', 'Michaelerberg', '', 47.4108300, 13.8933300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2865, 'Mettersdorf am Saßbach', 'Mettersdorf am Sassbach', 'Mettersdorf,Mettersdorf am Sassbach,Mettersdorf am Saßbach', 46.8058300, 15.7111100, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2866, 'Metnitz', 'Metnitz', 'Metnic,mei te ni ci,Метниц,梅特尼茨', 46.9805600, 14.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2867, 'Merkendorf', 'Merkendorf', '', 46.8572200, 15.9038900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2868, 'Mellach', 'Mellach', '', 46.9333300, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2869, 'Melk', 'Melk', 'Mel''k,Melk,Mellicum,Moek,Mök,mei er ke,melkeu,meruku,mlq,Мелк,Мельк,מלק,メルク,梅爾克,멜크', 48.2273700, 15.3318600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2870, 'Meiningen', 'Meiningen', '', 47.2989100, 9.5786200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2871, 'Mayrhofen', 'Mayrhofen', 'Mairhofen,Majerkhofen,Majrgofen,Majrkhofen,Mayrhofen,Zillertal,mai er huo fen,Майерхофен,Майргофен,Майрхофен,מאיירהופן,迈尔霍芬', 47.1666700, 11.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2872, 'Mautern in Steiermark', 'Mautern in Steiermark', 'Mautern,Mautern Markt,Mautern Steiermark,Mautern in Steiermark', 47.4000000, 14.8333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2873, 'Mauterndorf', 'Mauterndorf', 'Mautterndorf', 47.1345100, 13.6788400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2874, 'Mauerbach', 'Mauerbach', 'Mauehrbakh,mao er ba he,Мауэрбах,毛尔巴赫', 48.2451400, 16.1679300, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2875, 'Mattsee', 'Mattsee', 'Mattze,Matze,Matzee,ma te sai,Матзе,Матзее,Маттзе,马特塞', 47.9666700, 13.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2876, 'Mattersburg', 'Mattersburg', 'Matersburg,Matersburgas,Mattasburg,Mattersburg,Mattersdorf,Nagymarton,Walbersdorf,ma te si bao,mateleuseubuleukeu,matterusuburuku,mtrsbwrg,Матерсбург,Маттерсбург,מאטערסדארף,מטרסבורג,マッテルスブルク,馬特斯堡,마테르스부르크', 47.7333300, 16.4000000, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2877, 'Matrei in Osttirol', 'Matrei in Osttirol', 'Matraj,Matraj (Osttirol''),Matraj-in-Osttirol'',Matrei,Matrei in Osttirol,Motre,dong di luo er de qu ma te lai,Матрай,Матрай (Осттироль),Матрай-ин-Осттироль,Матрай-ін-Осттіроль,东蒂罗尔地区马特赖', 47.0000000, 12.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2878, 'Matrei am Brenner', 'Matrei am Brenner', 'Matrei,Matrei am Brenner', 47.1333300, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2879, 'Marz', 'Marz', 'Marca,Marczfalva,Márczfalva', 47.7166700, 16.4166700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2880, 'Martinsberg', 'Martinsberg', '', 48.3754900, 15.1499700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2881, 'Markt Sankt Martin', 'Markt Sankt Martin', 'Markt Sankt Martin,Markt-Sankt-Martin,Sankt Martin,Sopronszentmarton,Sopronszentmárton,Sveti Martin,Маркт-Санкт-Мартин', 47.5620500, 16.4250800, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2882, 'Sankt Florian', 'Sankt Florian', 'Markt Sankt Florian,Markt-Sankt-Florian,Sankt Florian,Маркт-Санкт-Флориан', 48.2056800, 14.3783600, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2883, 'Bad Pirawarth', 'Bad Pirawarth', 'Bad Pirawarth,Markt Pirawarth,Pyrawarth', 48.4519400, 16.5983300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2884, 'Markt Piesting', 'Markt Piesting', 'Markt-Pisting,Piesting,Unterpiesting,ma ke te pi shi ting,Маркт-Пистинг,马克特皮施廷', 47.8735800, 16.1251000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2885, 'Markt Neuhodis', 'Markt Neuhodis', 'Markt Hodis,Markt Neuhodis,Markt-Nojkhodis,Novi Hodas,Varoshodasz,Városhodász,Маркт-Нойходис', 47.2956500, 16.3956400, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2886, 'Markt Allhau', 'Markt Allhau', 'Alhau,Allhau,Markt Al''khau,Markt Allhau,Маркт Альхау', 47.2833300, 16.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2887, 'Markgrafneusiedl', 'Markgrafneusiedl', '', 48.2666700, 16.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2888, 'Mariazell', 'Mariazell', 'Mariacell'',Mariazell,Mariazoe,Mariazö,ma li ya cai er,mariatsu~eru,Мариацелль,Маріацелль,マリアツェル,瑪麗亞采爾', 47.7730600, 15.3163900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2889, 'Maria Wörth', 'Maria Worth', 'Maria Worth,Maria Wörth,Maria-Vjort,Marija-Vjort,Otok,ma li ya wei er te,Мариа-Вёрт,Мария-Вёрт,玛丽亚韦尔特', 46.6163900, 14.1630600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2890, 'Mariatrost', 'Mariatrost', 'Mariatrost', 47.1000000, 15.5000000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2891, 'Maria Taferl', 'Maria Taferl', 'Marija-Taferl'',Vim,ma li ya ta fei er,Вим,Мария-Таферль,玛丽亚塔费尔', 48.2270200, 15.1595400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2892, 'Mariastein', 'Mariastein', 'Mariastein', 47.5277200, 12.0547900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2893, 'Mariasdorf', 'Mariasdorf', 'Mariafalva,Mariasdorf,Máriafalva,ma li ya duo fu,Мариасдорф,玛丽亚多夫', 47.3658000, 16.2313600, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2894, 'Maria Saal', 'Maria Saal', 'Gospa Sveta,Maria Saal,Maria-Zal'',Marija-Zal'',ma li ya sa er,Мариа-Заль,Мария-Заль,ማሪያ ዛል,玛丽亚萨尔', 46.6808300, 14.3486100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2895, 'Maria Rain', 'Maria Rain', '', 46.5538900, 14.2955600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2896, 'Mariapfarr', 'Mariapfarr', 'Mariapfar,Pforch,ma li ya pu fa er,Мариапфар,Маріапфар,玛丽亚普法尔', 47.1500000, 13.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2897, 'Maria Neustift', 'Maria Neustift', 'Maria Neustift', 47.9333300, 14.6000000, 'AT', '2015-08-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2898, 'Maria Lankowitz', 'Maria Lankowitz', 'Lankowitz,Maria Lankowitz,Maria- Lankovic,Marija-Lankovic,ma li ya lan ke wei ci,Мариа- Ланковиц,Мария-Ланковиц,玛丽亚兰科维茨', 47.0500000, 15.0666700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2899, 'Maria Laach am Jauerling', 'Maria Laach am Jauerling', 'Maria Laach,Maria Laach am Jauerling', 48.3041200, 15.3447200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2900, 'Mariahof', 'Mariahof', 'Mariahof', 47.1000000, 14.4000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2901, 'Maria Enzersdorf', 'Maria Enzersdorf', 'Maria Enzersdorf,Marija-Ehncersdorf,ma li ya en ce si duo fu,Мария-Энцерсдорф,玛丽亚恩策斯多夫', 48.1000000, 16.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2902, 'Maria-Anzbach', 'Maria-Anzbach', '', 48.1901200, 15.9315500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2903, 'Maria Alm am Steinernen Meer', 'Maria Alm am Steinernen Meer', 'Alm', 47.4057900, 12.9012100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2904, 'Marchtrenk', 'Marchtrenk', 'Markhtrenk,ma xi te lun ke,marshtrnk,Мархтренк,مارشترنک,მარხტრენკი,馬希特倫克', 48.1833300, 14.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2905, 'Marchegg', 'Marchegg', 'Markheg,ma er xie ge,Мархег,马尔歇格', 48.2621700, 16.9104500, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2906, 'Marbach an der Donau', 'Marbach an der Donau', 'Marbach,Marbach an der Donau,Marbakh-na-Dunae,Марбах-на-Дунае', 48.2166700, 15.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2907, 'Mannsdorf an der Donau', 'Mannsdorf an der Donau', 'Mannsdorf', 48.1520000, 16.6650600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2908, 'Manning', 'Manning', 'Manning', 48.0885100, 13.6668200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2909, 'Mannersdorf an der Rabnitz', 'Mannersdorf an der Rabnitz', 'Malistrof,Malištrof,Mannersdorf,Mannersdorf an der Rabnitz,Mannersdorf-na-Rabenic,Repcekethely,Répcekethely,Маннерсдорф-на-Рабениц', 47.4281500, 16.5267800, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2910, 'Mannersdorf am Leithagebirge', 'Mannersdorf am Leithagebirge', 'Mannersdorf,Mannersdorf am Leithagebirge,Mannersdorf-am-Lajtagebirge,lai ta shan lu ma nei er si duo fu,Маннерсдорф-ам-Лайтагебирге,莱塔山麓马内尔斯多夫', 47.9666700, 16.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2911, 'Mank', 'Mank', '', 48.1102400, 15.3391500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2912, 'Maissau', 'Maissau', 'Majsau,Vil''khel''msdorf,mai shao,Вильхельмсдорф,Майсау,迈绍', 48.5730000, 15.8300500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2913, 'Maishofen', 'Maishofen', '', 47.3666700, 12.8000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2914, 'Mailberg', 'Mailberg', '', 48.6737900, 16.1813200, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2915, 'Maierdorf', 'Maierdorf', 'Maierdorf', 46.8925000, 15.8497200, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2916, 'Mäder', 'Mader', '', 47.3500000, 9.6166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2917, 'Lutzmannsburg', 'Lutzmannsburg', 'Locsmand,Locsmánd,Lucman,Lucmannsburg,Lucmansburg,Lutzmannsburg,lu ci man si bao,Луцманнсбург,Луцмансбург,卢茨曼斯堡', 47.4637300, 16.6366500, 'AT', '2012-11-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2918, 'Lustenau', 'Lustenau', 'Lustenau,lu si te nao,luseutenau,rusutenau,Лустенау,לוסטנאו,لوستن‌آئو,ლუსტენაუ,ルステナウ,盧斯特瑙,루스테나우', 47.4264200, 9.6585100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2919, 'Lunz am See', 'Lunz am See', 'Lunc-am-Ze,Lunz,bin hu lun ci,Лунц-ам-Зе,滨湖伦茨', 47.8612000, 15.0299800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2920, 'Ludmannsdorf', 'Ludmannsdorf', 'Bilcovs,Bilčovs,Ludmannsdorf,lu de man si duo fu,Лудманнсдорф,卢德曼斯多夫', 46.5413900, 14.1342500, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2921, 'Ludesch', 'Ludesch', '', 47.2000000, 9.7830600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2922, 'Losenstein', 'Losenstein', 'Losenstein', 47.9242800, 14.4367200, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2923, 'Lorüns', 'Loruns', '', 47.1330600, 9.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2924, 'Loretto', 'Loretto', 'Lorettom,Lovreta', 47.9155900, 16.5179000, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2925, 'Loosdorf', 'Loosdorf', 'Loosdorf,Losdorf,lu si duo fu,Лоосдорф,Лосдорф,卢斯多夫', 48.2000000, 15.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2926, 'Loipersdorf bei Fürstenfeld', 'Loipersdorf bei Fuerstenfeld', 'Loipersdorf,Loipersdorf bei Furstenfeld,Loipersdorf bei Fürstenfeld', 47.0000000, 16.1000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2927, 'Loipersbach im Burgenland', 'Loipersbach im Burgenland', 'Lepesfalva,Loipersbach,Loipersbach im Burgenland,Lojpersbakh (Burgenland),Lépesfalva,Лойперсбах (Бургенланд)', 47.6965600, 16.4791900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2928, 'Loich', 'Loich', 'Loichgegend', 47.9957800, 15.4016300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2929, 'Lofer', 'Lofer', 'Lofer,Lófer,luo fu,Лофер,洛弗', 47.5847500, 12.6933300, 'AT', '2014-10-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2930, 'Lödersdorf', 'Loedersdorf', 'Lodersdorf,Lödersdorf', 46.9586100, 15.9433300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2931, 'Lochau', 'Lochau', 'Lochau am Bodensee,Lokhau,luo hao,Лохау,洛豪', 47.5333300, 9.7500000, 'AT', '2013-11-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2932, 'Litzelsdorf', 'Litzelsdorf', '', 47.2082600, 16.1717000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2933, 'Litschau', 'Litschau', 'Khjormanns,Lichau,Litschau,li qiao,Личау,Хёрманнс,利乔', 48.9440900, 15.0448300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2934, 'Linz', 'Linz', 'Gorad Linc,LNZ,Lentia,Linc,Linca,Lincas,Linec,Lints,Linz,lin ci,lincheu,lins,lintsa,lintsi,lnz,lynts,lyntz,lynz,rintsu,Λιντς,Горад Лінц,Линц,Лінц,Լինց,לינץ,لنز,لينتز,لینتس,लिंत्स,ลินซ์,ლინცი,リンツ,林茨,린츠', 48.3063900, 14.2861100, 'AT', '2014-05-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2935, 'Lilienfeld', 'Lilienfeld', 'Khintereben,Lilienfel''d,Lilienfeld,Lilienfoeid,Lilienföid,Lilijenfeld,li lin fei er de,Лилиенфелд,Лилиенфельд,Лилијенфелд,Хинтеребен,利林费尔德', 48.0131200, 15.5966400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2936, 'Ligist', 'Ligist', 'Ligist,li ji si te,Лигист,利吉斯特', 46.9938900, 15.2108300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2937, 'Liezen', 'Liezen', 'Licen,Liezen,Lizen,li cen,Лизен,Лицен,利岑', 47.5666700, 14.2333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2938, 'Lienz', 'Lienz', 'Lianz,Lienc,Lienz,Lijenc,Linc,li en ci,liencheu,lientsi,lyynts,lyynz,rientsu,Лиенц,Линц,Лијенц,Лієнц,ליינץ,ليينز,لیینتس,ლიენცი,リエンツ,利恩茨,리엔츠', 46.8289000, 12.7690300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2939, 'Lieboch', 'Lieboch', 'Libokh,Lieboch,li bo he,Либох,利博赫', 46.9741700, 15.3375000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2940, 'Lichtenwörth', 'Lichtenworth', '', 47.8275600, 16.2987300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2941, 'Lichtenegg', 'Lichtenegg', 'Lichteneg,Lichtenegg', 47.6000000, 16.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2942, 'Leutschach', 'Leutschach', 'Lojchakh,Lucane,Lučane,luo yi cha he,Лойчах,洛伊查赫', 46.6672200, 15.4688900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2943, 'Lermoos', 'Lermoos', 'Leermoos,Lermoos,Lermos,Лермос', 47.4035800, 10.8807000, 'AT', '2013-11-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2944, 'Leopoldsdorf im Marchfelde', 'Leopoldsdorf im Marchfelde', 'Leopol''dsdorf-im-Markhfel''de,Leopoldsdorf,Леопольдсдорф-им-Мархфельде', 48.2226100, 16.6885800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2945, 'Leopoldsdorf', 'Leopoldsdorf', '', 48.1155700, 16.3912600, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2946, 'Leonding', 'Leonding', 'Leonding,lai weng ding,leondingi,li an ding,lywdyng,reondinku,Леондинг,לאונדינג,لئودینگ,لیونڈنگ,ლეონდინგი,レオンディンク,利安定,萊翁丁', 48.2796500, 14.2533000, 'AT', '2014-05-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2947, 'Leogang', 'Leogang', 'Leogang,Loigom,lai ao gang,Леоганг,萊奧岡', 47.4390600, 12.7610900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2948, 'Leobersdorf', 'Leobersdorf', 'Leobersdorf,lai ao bo er si duo fu,Леоберсдорф,莱奥伯尔斯多夫', 47.9279600, 16.2165100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2949, 'Leobendorf', 'Leobendorf', '', 48.3833300, 16.3166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2950, 'Leoben', 'Leoben', 'Leoben,Leobenas,Leobene,Leompen,Liupina,lai ao ben,le-oben,leobeni,lywbn,reoben,Λεόμπεν,Леобен,לאובן,لئوبن,ლეობენი,レオーベン,萊奧本,레오벤', 47.3765000, 15.0914400, 'AT', '2012-09-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2951, 'Lenzing', 'Lenzing', '', 47.9732600, 13.6084600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2952, 'Lengenfeld', 'Lengenfeld', '', 48.4718700, 15.5987000, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2953, 'Lendorf', 'Lendorf', '', 46.8352800, 13.4302800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2954, 'Lend', 'Lend', '', 47.2985600, 13.0517600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2955, 'Leitzersdorf', 'Leitzersdorf', '', 48.4191800, 16.2451300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2956, 'Leithaprodersdorf', 'Leithaprodersdorf', 'Lajtapordany,Lajtapordány', 47.9334800, 16.4791500, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2957, 'Leitersdorf im Raabtal', 'Leitersdorf im Raabtal', 'Leitersdorf,Leitersdorf im Raabtal', 46.9418200, 15.9336500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2958, 'Leisach', 'Leisach', 'Lajzakh,Leisach,lai sa he,Лайзах,莱萨赫', 46.8125000, 12.7486100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2959, 'Leibnitz', 'Leibnitz', 'Lajbnic,Leibnitz  Stiria,Leibnitz  Styria,Lipnica,lai bu ni ci,laipeunicheu,laybnytz,raipunittsu,Лайбниц,Лајбниц,لايبنيتز,ライプニッツ,萊布尼茨,라이프니츠', 46.7816100, 15.5383600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2960, 'Leiben', 'Leiben', '', 48.2462800, 15.2746000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2961, 'Lechaschau', 'Lechaschau', 'Lechaschau', 47.4880400, 10.7065200, 'AT', '2012-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2962, 'Lech', 'Lech', 'Lekh,Лех', 47.2079700, 10.1418400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2963, 'Laxenburg', 'Laxenburg', 'Laksenburg,Laxemburgo,Laxenbourg,la ke sen bao,Лаксенбург,拉克森堡', 48.0683300, 16.3560700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2964, 'Lavant', 'Lavant', 'Lavant', 46.7988900, 12.8380600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2965, 'Lavamünd', 'Lavamund', 'Labot,Lafamjund,la fa ming de,Лафамюнд,拉法明德', 46.6401900, 14.9473300, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2966, 'Lauterach', 'Lauterach', 'QLX', 47.4830600, 9.7330600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2967, 'Laussa', 'Laussa', 'Lausa,Laussa', 47.9500000, 14.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2968, 'Lassing', 'Lassing', 'Lassing', 47.5337400, 14.2580800, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2969, 'Lassee', 'Lassee', '', 48.2247900, 16.8223000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2970, 'Lanzenkirchen', 'Lanzenkirchen', 'Kajnvol''kersdorf,Lancenkirkhen,lan cen ji xing,Кайнволькерсдорф,Ланценкирхен,蘭岑基興', 47.7362100, 16.2198500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2971, 'Lans', 'Lans', '', 47.2383300, 11.4313900, 'AT', '2016-04-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2972, 'Lannach', 'Lannach', 'Lannach,Lannakh,Ланнах', 46.9461100, 15.3372200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2973, 'Langschlag', 'Langschlag', '', 48.5744800, 14.8845900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2974, 'Langenzersdorf', 'Langenzersdorf', 'Langencersdorf,Langenzersdorf,lang gen ce si duo fu,Лангенцерсдорф,朗根策斯多夫', 48.3000000, 16.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2975, 'Langenwang', 'Langenwang', 'Langenvang,Langenwang,Лангенванг', 47.5666700, 15.6166700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2976, 'Langenrohr', 'Langenrohr', '', 48.3048900, 16.0103400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2977, 'Langenlois', 'Langenlois', 'Langenlois,Langenlojs,lang gen luo yi si,Лангенлойс,朗根洛伊斯', 48.4666700, 15.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2978, 'Langegg bei Graz', 'Langegg bei Graz', 'Langegg,Langegg bei Graz', 47.0500000, 15.6333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2979, 'Langau', 'Langau', 'Khessendorf,Langau,lan gao,Лангау,Хессендорф,兰高', 48.8320700, 15.7156000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2980, 'Lang', 'Lang', 'Lang,Langerberg', 46.8376500, 15.5047100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2981, 'Landl', 'Landl', 'Landl'',lan de er,Ландль,兰德尔', 47.6566600, 14.7318900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2982, 'Landeck', 'Landeck', '', 47.1398800, 10.5659300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2983, 'Lamprechtshausen', 'Lamprechtshausen', 'Lampehausen,Lamprechtshausen,Lamprekhtsgauzen,Lamprekhtskhauzen,lan pu lei xi ci hao sen,Лампрехтсгаузен,Лампрехтсхаузен,兰普雷希茨豪森', 47.9909800, 12.9548100, 'AT', '2017-07-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2984, 'Lambach', 'Lambach', 'Lambakh,Ламбах', 48.0927600, 13.8745300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2985, 'Lafnitz', 'Lafnitz', 'Lafnitz', 47.3666700, 16.0166700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2986, 'Ladis', 'Ladis', 'Ladis,la di si,Ладис,Ладіс,拉迪斯', 47.0745900, 10.6494900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2987, 'Ladendorf', 'Ladendorf', 'Ladendorf,la deng duo fu,Ладендорф,拉登多夫', 48.5333300, 16.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2988, 'Lackendorf', 'Lackendorf', 'Lakfalva,Lakindrof', 47.5899600, 16.5040400, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2989, 'Lackenbach', 'Lackenbach', 'Lakimpuh,Lakompak', 47.5904200, 16.4653300, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2990, 'Labuch', 'Labuch', 'Labuch,Unter Labuch', 47.0666700, 15.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2991, 'Laakirchen', 'Laakirchen', 'Laakircha,Lakirkhen,la ji xing,Лакирхен,拉基兴', 47.9818800, 13.8216600, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2992, 'Laab im Walde', 'Laab im Walde', 'Laab,Lab-im-Val''de,lin qu la bu,Лаб-им-Вальде,林区拉布', 48.1548600, 16.1735900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2993, 'Laa an der Thaya', 'Laa an der Thaya', 'La-an-der-Tajja,Laa,Laa an der Thaya,Laa-an-der-Tajja,ta ya he pan la zhen,Ла-ан-дер-Тайя,Лаа-ан-дер-Тайя,塔亞河畔拉鎮', 48.7166700, 16.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2994, 'Kundl', 'Kundl', 'Kundl,Kundl'',kun de er,Кундль,昆德尔', 47.4666700, 11.9833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2995, 'Kumberg', 'Kumberg', 'Kumberg,Кумберг', 47.1642200, 15.5326100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2996, 'Kulm am Zirbitz', 'Kulm am Zirbitz', 'Kulm,Kulm am Zirbitz', 47.0581400, 14.4870200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2997, 'Kukmirn', 'Kukmirn', '', 47.0754400, 16.2103300, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2998, 'Kufstein', 'Kufstein', 'Kuffstein,Kufshhajn,Kufshtajn,Kufsstein,Kufstein,Kufsteinas,Kufstoa,Kufšteinas,ku fu shi tai yin,kufushutain,kupeusyutain,qwpstyyn,Куфштайн,Куфштајн,Куфщайн,קופשטיין,کوف‌اشتاین,კუფშტაინი,クーフシュタイン,库夫施泰因,쿠프슈타인', 47.5833300, 12.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(2999, 'Kuchl', 'Kuchl', 'Kuche,Kuchl,Kukhl'',ku he er,Кухль,庫赫爾', 47.6264700, 13.1448000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3000, 'Krusdorf', 'Krusdorf', 'Krusdorf', 46.8394400, 15.8608300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3001, 'Krumegg', 'Krumegg', '', 47.0211100, 15.6313900, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3002, 'Krumbach', 'Krumbach', '', 47.4830600, 9.9358300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3003, 'Krumau am Kamp', 'Krumau am Kamp', 'Krumau,Krumau am Kamp', 48.5887900, 15.4491400, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3004, 'Krottendorf', 'Krottendorf', '', 47.2000000, 15.6333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3005, 'Krispl', 'Krispl', '', 47.7166700, 13.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3006, 'Krieglach', 'Krieglach', 'Alpl,Kriaglach,Kriaglåch,Krieglach,Kriglakh,ke li ge la he,Криглах,克里格拉赫', 47.5472800, 15.5624800, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3007, 'Bad Kreuzen', 'Bad Kreuzen', 'Bad-Krojcen,ba te ke luo yi cen,Бад-Кройцен,巴特克罗伊岑', 48.2673700, 14.8064800, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3008, 'Krensdorf', 'Krensdorf', 'Krenistof,Kreništof,Krensdorf,Tormafalu,Кренсдорф', 47.7855200, 16.4149500, 'AT', '2012-11-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3009, 'Kremsmünster', 'Kremsmunster', 'Cremifanum,Kremsmjunster,Kremsmunster,Kremsmünster,ke lei mu si ming si te,Кремсмюнстер,克雷姆斯明斯特', 48.0529000, 14.1291900, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3010, 'Krems an der Donau', 'Krems an der Donau', 'Krems,Krems an der Donau,Krems-na-Dunae,qrms,Кремс-на-Дунае,קרמס', 48.4092100, 15.6141500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3011, 'Kraubath an der Mur', 'Kraubath an der Mur', 'Kraubath,Kraubath an der Mur', 47.3000000, 14.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3012, 'Kramsach', 'Kramsach', 'Kramsach,Kramzakh,ke la mu sa he,Крамзах,克拉姆萨赫', 47.4431200, 11.8754500, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3013, 'Krakauschatten', 'Krakauschatten', 'Krakauschatten', 47.1833300, 13.9666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3014, 'Krakauhintermühlen', 'Krakauhintermuehlen', 'Krakauhintermuhlen,Krakauhintermühlen', 47.1833300, 13.9833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3015, 'Krakaudorf', 'Krakaudorf', 'Krakaudorf', 47.1813100, 14.0206100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3016, 'Köttmannsdorf', 'Kottmannsdorf', 'Kjottmannsdorf,Koettmannsdorf,Kotmara vas,Kottmannsdorf,Köttmannsdorf,ke te man si duo fu,Кёттманнсдорф,科特曼斯多夫', 46.5613900, 14.2338900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3017, 'Kottingbrunn', 'Kottingbrunn', 'Kottingbrunn,ke ting bu lun,kwtnjbrn,Коттингбрунн,كوتنجبرن,科廷布伦', 47.9509600, 16.2271500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3018, 'Köstendorf', 'Kostendorf', 'Gross Kostendorf,Gross Köstendorf,Kestendorf,Kjostendorf,Kostendorf,Köstendorf,ke shi teng duo fu,Кестендорф,Кёстендорф,克施滕多夫', 47.9500000, 13.2000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3019, 'Kössen', 'Kossen', 'Kessen,Kessn,Kjossen,ke sen,kwsn,Кессен,Кёссен,کوسن,克森', 47.6699000, 12.4054500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3020, 'Korneuburg', 'Korneuburg', 'Korneubourg,Korneuburg,Kornojburg,ke er xin bao,krnwybwrg,Корнойбург,Корнојбург,کرنویبورگ,კორნოიბურგი,科爾新堡', 48.3500000, 16.3333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3021, 'Koppl', 'Koppl', 'Kopl'',Koppl'',ke pu er,Копль,Коппль,科普尔', 47.8080800, 13.1556100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3022, 'Königstetten', 'Konigstetten', '', 48.3019800, 16.1449200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3023, 'Königsdorf', 'Konigsdorf', '', 47.0000000, 16.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3024, 'Kolsassberg', 'Kolsassberg', '', 47.2815000, 11.6528900, 'AT', '2017-03-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3025, 'Kohlschwarz', 'Kohlschwarz', 'Kohlschwarz', 47.1166700, 15.1166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3026, 'Kohlberg', 'Kohlberg', 'Kohlberg', 46.9000000, 15.7833300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3027, 'Kohfidisch', 'Kohfidisch', 'Gyepufuezes,Gyepufüzes,Kofidish,Kohfedish,Kohfidisch,Кофидиш', 47.1747200, 16.3570100, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3028, 'Köflach', 'Koeflach', 'Gorad Kjoflakh,Keflakh,Kjoflakh,Koflach,Köflach,ke fu la he,kwflakh,Горад Кёфлах,Кефлах,Кёфлах,کوفلاخ,克夫拉赫', 47.0666700, 15.0833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3029, 'Koblach', 'Koblach', '', 47.3330600, 9.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3030, 'Kobersdorf', 'Kobersdorf', 'Kabold,Kobersdorf,Коберсдорф', 47.5957200, 16.3917300, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3031, 'Kobenz', 'Kobenz', 'Kobenz', 47.2500000, 14.8500000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3032, 'Knittelfeld', 'Knittelfeld', 'Knitelfeld,Knitelfelnt,Knittel''fel''d,Knittelfeld,ke ni te er fei er de,keunitelpelteu,kunitteruferuto,Κνίτελφελντ,Кнителфелд,Книттельфельд,کنیتل‌فلد,კნიტელფელდი,クニッテルフェルト,克尼特爾費爾德,크니텔펠트', 47.2166700, 14.8166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3033, 'Klosterneuburg', 'Klosterneuburg', 'Gorad Klostehrnojburg,Klosterneuberg,Klosterneuburg,Klosternoiburgas,Klosternojburg,Vajdlingbakh-und-Shajblinshtajn,ke luo si te xin bao,klwstrnwybwrg,kurosutanoiburuku,Вайдлингбах-унд-Шайблинштайн,Горад Клостэрнойбург,Клостернойбург,Клостернојбург,کلوسترنویبورگ,کوسٹرنیوبرگ,კლოსტერნოიბურგი,クロスターノイブルク,克洛斯特新堡', 48.3052100, 16.3252200, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3034, 'Klösterle', 'Klosterle', '', 47.1333300, 10.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3035, 'Kloster', 'Kloster', 'Kloster,Klosterwinkel', 46.8833300, 15.0833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3036, 'Klöch', 'Kloech', 'Kloch,Klöch', 46.7647200, 15.9655600, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3037, 'Klingenbach', 'Klingenbach', 'Kelenpatak,Kelénpatak,Klingenbach,Klingenbakh,Klinpuh,Клингенбах', 47.7520200, 16.5406900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3038, 'Kleinzell im Mühlkreis', 'Kleinzell im Muehlkreis', 'Klajncell'',Klajncell''-im-Mjul''krajs,Kleinzel,Kleinzell,Kleinzell im Muhlkreis,Kleinzell im Mühlkreis,mi er de qu xiao ce er,Клайнцелль,Клайнцелль-им-Мюлькрайс,米尔地区小策尔', 48.4558500, 13.9919500, 'AT', '2011-07-11', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3039, 'Kleinzell', 'Kleinzell', 'Klajncell'',Klazoe,Klazö,xiao ce er,Клайнцелль,小策尔', 47.9799300, 15.7362000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3040, 'Kleinsölk', 'Kleinsoelk', 'Kleinsolk,Kleinsölk,Vorderwald', 47.3944400, 13.9394400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3041, 'Klein-Pöchlarn', 'Klein-Poechlarn', '', 48.2166700, 15.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3042, 'Kleinmürbisch', 'Kleinmurbisch', 'Felsomedves,Felsőmedves', 47.0329900, 16.3244800, 'AT', '2013-04-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3043, 'Kleinlobming', 'Kleinlobming', 'Kleinlobming', 47.1495400, 14.8487500, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3044, 'Kleinkirchheim', 'Kleinkirchheim', 'Bad Klajnkirkhgajm,Bad Kleinkirchheim,Kleinkirchheim,Бад Клайнкирхгайм', 46.8227800, 13.7922200, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3045, 'Klausen-Leopoldsdorf', 'Klausen-Leopoldsdorf', 'Klausenleopoldsdorf,Klauzen-Leopol''dsdorf,ke lao sen-lai ao bo er de si duo fu,Клаузен-Леопольдсдорф,克劳森-莱奥波尔德斯多夫', 48.0877100, 16.0168600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3046, 'Klaus', 'Klaus', '', 47.3091300, 9.6467800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3047, 'Klagenfurt am Wörthersee', 'Klagenfurt am Woerthersee', 'Celovec,Clagenfurtum,KLU,Klagenfurt,Klagenfurte,Klāgenfurte,ke la gen fu,kuragenfuruto,qlgnpwrt,Клагенфурт,קלגנפורט,クラーゲンフルト,克拉根福', 46.6247200, 14.3052800, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3048, 'Kitzeck im Sausal', 'Kitzeck im Sausal', 'Kitzeck,Kitzeck im Sausal', 46.7807200, 15.4538400, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3049, 'Kitzbühel', 'Kitzbuhel', 'Kicbil,Kicbiuhelis,Kicbjuehl'',Kicbjuel,Kicbjuel'',Kitzbichl,Kitzbuehel,Kitzbühel,ji ci bi e er,kicheubwil,kittsubyuru,ktsbwyl,qyzbyl,Кицбил,Кицбюел,Кицбюэль,Кіцбюель,קיצביל,كتسبويل,キッツビュール,基茨比厄爾,키츠뷜', 47.4463700, 12.3921500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3050, 'Kittsee', 'Kittsee', 'Gijeca,Kittsee,Kitzee,Koepcseny,Köpcsény,kittoze,Китзее,キットゼー', 48.0925000, 17.0638900, 'AT', '2012-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3051, 'Kirnberg an der Mank', 'Kirnberg an der Mank', 'Kirnberg', 48.0724600, 15.3223200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3052, 'Kirchstetten', 'Kirchstetten', '', 48.1833300, 15.8166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3053, 'Kirchschlag in der Buckligen Welt', 'Kirchschlag in der Buckligen Welt', 'Kirchschlag in da Buckling Woeid,Kirchschlag in der Buckligen Welt,Kirchschlåg in da Buckling Wöid,Kirkhshlag,Kirkhshlag-in-der-Bukligen-Vel''t,Kirschlag,bu ke li gen wei er te de qu ji xi shi la ge,Кирхшлаг,Кирхшлаг-ин-дер-Буклиген-Вельт,布克利根韦尔特地区基希施拉格', 47.5000000, 16.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3054, 'Kirchschlag bei Linz', 'Kirchschlag bei Linz', 'Kirchschlag,Kirchschlag bei Linz', 48.4114900, 14.2765600, 'AT', '2011-12-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3055, 'Kirchschlag', 'Kirchschlag', '', 48.3934500, 15.2228500, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3056, 'Kirchdorf in Tirol', 'Kirchdorf in Tirol', 'Kirchdorf,Kirchdorf en Tyrol,Kirchdorf in Tirol,Kirkhdorf,Kirkhdorf (Tirol''),Kirkhdorf-in-Tirol'',di luo er zhou ji xi duo fu,Кирхдорф,Кирхдорф (Тироль),Кірхдорф-ін-Тіроль,کرخڈورف ان ٹیرول,蒂罗尔州基希多夫', 47.5562600, 12.4451100, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3057, 'Kirchberg in Tirol', 'Kirchberg in Tirol', 'Kirchberg,Kirkhberg (Tirol''),Кирхберг (Тироль)', 47.4453900, 12.3160200, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3058, 'Kirchberg an der Raab', 'Kirchberg an der Raab', 'Kirchberg,Kirchberg an der Raab,Kirkhberg-an-der-Rab,la bu he pan ji xi bei ge,Кирхберг-ан-дер-Раб,拉布河畔基希贝格', 46.9858300, 15.7669400, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3059, 'Kirchberg an der Pielach', 'Kirchberg an der Pielach', 'Kirchberg,Kirkhberg-an-der-Pilakh,Kirkhberg-na-Pilakhe,Pilakhtagy Kirkhberg,pi la he he pan ji xi bei ge,Кирхберг-ан-дер-Пилах,Кирхберг-на-Пилахе,Пилахтағы Кирхберг,皮拉赫河畔基希贝格', 48.0269000, 15.4287500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3060, 'Kirchberg am Wechsel', 'Kirchberg am Wechsel', 'Kirchberg,Kirchberg am Wechsel,Kirkhberg-am-Vekzel'',Kirkhberg-na-Veksele,wei xi se er shan lu ji xi bei ge,Кирхберг-ам-Векзель,Кирхберг-на-Векселе,韦希瑟尔山麓基希贝格', 47.6073800, 15.9910300, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3061, 'Kirchberg am Walde', 'Kirchberg am Walde', 'Kirchberg,Kirchberg am Walde,Kirkhberg-am-Val''de,Kirkhberg-na-Val''de,lin qu ji xi bei ge,Кирхберг-ам-Вальде,Кирхберг-на-Вальде,林区基希贝格', 48.7247700, 15.0882600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3062, 'Kirchberg am Wagram', 'Kirchberg am Wagram', 'Kirchberg,Kirchberg am Wagram,Kirkhberg-am-Vagram,Kirkhberg-na-Vagrame,Vagramdagy Kirkhberg,wa ge la mu shan lu ji xi bei ge,Ваграмдағы Кирхберг,Кирхберг-ам-Ваграм,Кирхберг-на-Ваграме,瓦格拉姆山麓基希贝格', 48.4318200, 15.8969200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3063, 'Kirchbach in Steiermark', 'Kirchbach in Steiermark', 'Kirchbach,Kirchbach in Steiermark', 46.9316700, 15.6619400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3064, 'Kirchbach', 'Kirchbach', 'Kirchbach,Kirchbach im Gailtal,Kirkhbakh,Кирхбах', 46.6416000, 13.1845400, 'AT', '2012-12-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3065, 'Kindberg', 'Kindberg', 'Kindberg,jin de bei ge,Киндберг,金德贝格', 47.5000000, 15.4500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3066, 'Kilb', 'Kilb', '', 48.1010100, 15.4085000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3067, 'Keutschach am See', 'Keutschach am See', 'Hodise,Hodiše,Keutschach,Keutschach am See,Kojchakh-am-Ze,Kojtchakh-am-Zee,bin hu ke yi cha he,Койтчах-ам-Зее,Койчах-ам-Зе,滨湖科伊查赫', 46.5930600, 14.1888900, 'AT', '2016-02-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3068, 'Kennelbach', 'Kennelbach', '', 47.4830600, 9.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3069, 'Kemeten', 'Kemeten', '', 47.2485900, 16.1521300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3070, 'Kematen in Tirol', 'Kematen in Tirol', 'Kematen,Kematen en Tyrol,Kematen in Tirol,Kematen-in-Tirol'',di luo er zhou ke ma teng,Кематен,Кематен-ин-Тироль,Кематен-ін-Тіроль,کیماتن ان ٹیرول,蒂罗尔州克马滕', 47.2500000, 11.2666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3071, 'Kematen an der Ybbs', 'Kematen an der Ybbs', '', 48.0254100, 14.7646800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3072, 'Kautzen', 'Kautzen', '', 48.9300000, 15.2393200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3073, 'Kauns', 'Kauns', 'Kauns', 47.0782200, 10.6921900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3074, 'Kaumberg', 'Kaumberg', '', 48.0241500, 15.8984200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3075, 'Katzelsdorf', 'Katzelsdorf', 'Katcel''sdorf,Katzelsdorf an der Leitha,Macskasd,Macskásd,ka ce er si duo fu,Катцельсдорф,卡策尔斯多夫', 47.7805500, 16.2698500, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3076, 'Kasten bei Böheimkirchen', 'Kasten bei Boheimkirchen', '', 48.1532000, 15.7794600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3077, 'Kartitsch', 'Kartitsch', 'Boden,Kartich,Kartitsch,ka er di qi,Картич,Картіч,کارٹیٹش,卡尔蒂奇', 46.7288900, 12.5008300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3078, 'Karrösten', 'Karrosten', 'Karresten,Karrjosten,ka lei shi teng,Каррестен,Каррёстен,卡勒施滕', 47.2254000, 10.7656100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3079, 'Karres', 'Karres', '', 47.2166700, 10.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3080, 'Karlstetten', 'Karlstetten', '', 48.2592000, 15.5654400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3081, 'Kaprun', 'Kaprun', 'Kaprun,ka pu lun,Капрун,卡普伦', 47.2723900, 12.7598500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3082, 'Kappl', 'Kappl', 'Kappl', 47.0666700, 10.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3083, 'Kappel am Krappfeld', 'Kappel am Krappfeld', 'Kappel,Kappel am Krappfeld', 46.8386100, 14.4863900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3084, 'Kapfenstein', 'Kapfenstein', 'Kapfenstein', 46.8861100, 15.9716700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3085, 'Kapfenberg', 'Kapfenberg', 'Kapfenberg,Kapfenbergas,ka pu fen bei ge,kapfnbrg,qpnbrg,Капфенберг,קפנברג,کاپفنبرگ,კაპფენბერგი,卡普芬貝格', 47.4445800, 15.2933100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3086, 'Kapelln', 'Kapelln', '', 48.2581700, 15.7573100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3087, 'Kapellen', 'Kapellen', '', 47.6478400, 15.6286300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3088, 'Kammern im Liesingtal', 'Kammern im Liesingtal', 'Kammern im Liesingtal,Kammern-im-Lizingtal'',li xin gu de ka mo en,Каммерн-им-Лизингталь,利辛谷地卡默恩', 47.3924500, 14.9040700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3089, 'Kalwang', 'Kalwang', 'Kallwang,Kalwang', 47.4267800, 14.7544200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3090, 'Kaltenleutgeben', 'Kaltenleutgeben', 'Kal''tenlojtgeben,ka er teng luo yi te ge ben,Кальтенлойтгебен,卡尔滕洛伊特格本', 48.1164600, 16.1995600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3091, 'Kaltenbach', 'Kaltenbach', '', 47.2833300, 11.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3092, 'Kalsdorf bei Graz', 'Kalsdorf bei Graz', 'Kal''sdorf (Grac),Kal''sdorf-baj-Grac,Kalsdorf,Kalsdorf bei Graz,ge la ci fu jin ka er si duo fu,Кальсдорф (Грац),Кальсдорф-бай-Грац,格拉茨附近卡尔斯多夫', 46.9652800, 15.4802800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3093, 'Kaisersdorf', 'Kaisersdorf', 'Csaszarfalu,Császárfalu,Kaisersdorf,Kajzersdorf,Kalistrof,Kalištrof,Кайзерсдорф', 47.5374100, 16.3919800, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3094, 'Kaindorf an der Sulm', 'Kaindorf an der Sulm', 'Kaindorf,Kajndorf-an-der-Zul''m,Кайндорф-ан-дер-Зульм', 46.7924800, 15.5387900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3095, 'Kaindorf', 'Kaindorf', 'Kaindorf,Kaindorf bei Hartberg', 47.2253700, 15.9112500, 'AT', '2017-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3096, 'Kainach bei Voitsberg', 'Kainach bei Voitsberg', 'Kainach,Kainach bei Voitsberg', 47.1363700, 15.0953000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3097, 'Kaibing', 'Kaibing', 'Kaibing', 47.2000000, 15.8333300, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3098, 'Jungholz', 'Jungholz', 'Gioun''nkcholts,Junggol''c,Jungholzi vald,Jungkhol''c,rong huo er ci,Γιούνγκχολτς,Юнггольц,Юнгхольц,容霍尔茨', 47.5740900, 10.4472300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3099, 'Judenburg', 'Judenburg', 'Judenburg,you deng bao,yudenbuleukeu,yudenburuku,ywdnbwrg,ywdnbwrgh,Јуденбург,Юденбург,יודנבורג,يودنبورغ,ユーデンブルク,尤登堡,유덴부르크', 47.1666700, 14.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3100, 'Jois', 'Jois', 'Nyulas', 47.9616500, 16.7960400, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3101, 'Johnsbach', 'Johnsbach', 'Johnsbach', 47.5333300, 14.5833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3102, 'Jochberg', 'Jochberg', 'Jochberg,Khollersbakh,Холлерсбах', 47.3792000, 12.4180700, 'AT', '2012-04-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3103, 'Jerzens', 'Jerzens', '', 47.1512000, 10.7468600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3104, 'Jennersdorf', 'Jennersdorf', 'Enersdorf,Ennersdorf,Gyanafalva,Jenersdorf,Jennersdorf,ye nei er si duo fu,Єннерсдорф,Јенерсдорф,Енерсдорф,Еннерсдорф,Йеннерсдорф,耶内尔斯多夫', 46.9384800, 16.1415800, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3105, 'Jenbach', 'Jenbach', 'Enbakh,Jenbakh,yan ba he,Єнбах,Енбах,Йенбах,延巴赫', 47.3917300, 11.7724500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3106, 'Jedenspeigen', 'Jedenspeigen', '', 48.4980700, 16.8722500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3107, 'Japons', 'Japons', '', 48.7925000, 15.5683100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3108, 'Jaidhof', 'Jaidhof', '', 48.5333300, 15.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3109, 'Jagerberg', 'Jagerberg', '', 46.8536100, 15.7380600, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3110, 'Jabing', 'Jabing', '', 47.2388000, 16.2765900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3111, 'Ischgl', 'Ischgl', 'Isglis,Ishgl'',Ishgul,Išglis,XOI,aschgl,yi shi ge er,Ішгль,Ишгль,Ишгъл,אישגל,اسچگل,伊施格尔', 47.0125700, 10.2917900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3112, 'Irschen', 'Irschen', 'Irschen,Irshen,yi er shen,Иршен,伊尔申', 46.7569400, 13.0252800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3113, 'Irdning', 'Irdning', 'Irdning,yi er de ning,Ирднинг,伊尔德宁', 47.5052900, 14.1015500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3114, 'Inzing', 'Inzing', '', 47.2737000, 11.1975100, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3115, 'Inzenhof', 'Inzenhof', '', 47.0166700, 16.3166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3116, 'Innsbruck', 'Innsbruck', 'Gorad Insbruk,INN,Innsbruck,Innschbruck,Insbruc,Insbruk,Insbruka,Insbrukas,Insmprouk,Inzbruk,Pons Aeni,ansbrwk,anzbrk,aynsbrwk,insabruka,inseubeulukeu,insuburukku,xin s brukh,yin si bei lu ke,yin si bu lu ke,İnnsbruck,İnsbruk,Ίνσμπρουκ,Інсбрук,Горад Інсбрук,Инзбрук,Инсбрук,Ինսբրուք,אינסברוק,إنسبروك,انزبرک,اینسبروک,इन्सब्रुक,ইন্সব্রুক,อินส์บรุค,ინსბრუკი,インスブルック,因斯孛鲁克,因斯布鲁克,인스브루크', 47.2626600, 11.3945400, 'AT', '2014-05-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3117, 'Innervillgraten', 'Innervillgraten', 'Innerfil''graten,Innerfill''graten,Innervillgraten,nei wei er ge la teng,Іннерфілльгратен,Иннерфильгратен,انرولگراٹن,内维尔格拉滕', 46.8119400, 12.3747200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3118, 'Innerschwand', 'Innerschwand', 'Innerschwand', 47.8333300, 13.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3119, 'Innerbraz', 'Innerbraz', '', 47.1500000, 9.9166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3120, 'Imsterberg', 'Imsterberg', '', 47.2051700, 10.6960500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3121, 'Imst', 'Imst', 'Imscht,Imst,imusuto,yi mu si te,Імст,Имст,イムスト,伊姆斯特', 47.2450400, 10.7397400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3122, 'Ilz', 'Ilz', 'Il''c,Ilz,Ильц', 47.0864900, 15.9267600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3123, 'Illmitz', 'Illmitz', 'Il''mic,Ill''mic,Illmic,UEmitz,yi er mi ci,Ümitz,Ілльміц,Ильмиц,伊尔米茨', 47.7614800, 16.8002400, 'AT', '2012-10-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3124, 'Hüttschlag', 'Huttschlag', '', 47.1763500, 13.2323900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3125, 'Hüttenberg', 'Huttenberg', 'Huttenberg,Hüttenberg', 46.9413900, 14.5500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3126, 'Hüttau', 'Huttau', 'Gjuttau,Hittau,Khjuttau,xu tao,Гюттау,Хюттау,许陶', 47.4161000, 13.3077500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3127, 'Hürm', 'Hurm', '', 48.1560100, 15.4126200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3128, 'Hundsheim', 'Hundsheim', '', 48.1174900, 16.9358100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3129, 'Hörsching', 'Horsching', 'Hoersching,Khjorshing,he er xing,Хёршинг,赫爾興', 48.2262700, 14.1778600, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3130, 'Hornstein', 'Hornstein', 'Hornstein,Khornshtajn,Szarvko,Szarvkő,Voristan,Vorištan,Хорнштайн', 47.8804900, 16.4444700, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3131, 'Horn', 'Horn', 'Horn', 48.6627400, 15.6566300, 'AT', '2016-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3132, 'Horitschon', 'Horitschon', 'Haracsony,Haracun,Haračun', 47.5872900, 16.5469600, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3133, 'Hörbranz', 'Horbranz', 'Gerbranc,Horbranz,Hörbranz,Kh''orbranc,Khjorbranc,Khjornbranc,Kirchdorf,he er bu lan ci,Гербранц,Хьорбранц,Хёрбранц,Хёрнбранц,ہوربرانز,赫爾布蘭茨', 47.5500000, 9.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3134, 'Hopfgarten im Brixental', 'Hopfgarten im Brixental', 'Gopfgarten-im-Briksental'',Hopfgarten,Hopfgarten Markt,Hopfgarten im Brixental,Hopfgarten in Nordtirol,Khopfgarten-im-Briksental'',bu li ke sen gu de huo pu fu jia er teng,Гопфгартен-ім-Бріксенталь,Хопфгартен-им-Бриксенталь,布里克森谷地霍普夫加尔滕', 47.4500000, 12.1666700, 'AT', '2014-05-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3135, 'Hopfgarten in Defereggen', 'Hopfgarten in Defereggen', 'Gopfgarten-in-Defereggen,Hopfgarten,Hopfgarten in Defereggen,Khopfgarten-in-Defereggen,de fu lei gen shan lu huo pu fu jia er teng,Гопфгартен-ін-Деферегген,Хопфгартен-ин-Деферегген,德弗雷根山麓霍普夫加尔滕', 46.9191700, 12.5363900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3136, 'Holzhausen', 'Holzhausen', '', 48.2229600, 14.0968300, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3137, 'Hollersbach im Pinzgau', 'Hollersbach im Pinzgau', 'Hollersbach,Hollersbach im Pinzgau', 47.2765800, 12.4232600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3138, 'Hollenthon', 'Hollenthon', '', 47.5893800, 16.2613100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3139, 'Hollenstein an der Ybbs', 'Hollenstein an der Ybbs', 'Grosshollenstein,Hollenstein,Hollenstein an der Ybbs,Khollenshtajn-an-der-Ibs,Khollenshtajndagy Ibse,yi bu si he pan huo lun shi tai yin,Холленштайн-ан-дер-Ибс,Холленштайндағы Ибсе,伊布斯河畔霍伦施泰因', 47.8000000, 14.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3140, 'Hollenegg', 'Hollenegg', '', 46.7914700, 15.2134500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3141, 'Hollabrunn', 'Hollabrunn', 'Hollabrunn,Kholabrun,Khollabrun,Khollabrunn,Oberhollabrunn,Vizel''sfel''d,holabruni,huo la bu lun,hwlabrwn,Визельсфельд,Холабрун,Холлабрун,Холлабрунн,هولابرون,ჰოლაბრუნი,霍拉布倫', 48.5500000, 16.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3142, 'Hohenweiler', 'Hohenweiler', '', 47.5833300, 9.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3143, 'Hohenthurn', 'Hohenthurn', 'Khoehnturn,Straja vas,huo heng tu en,Хоэнтурн,霍亨图恩', 46.5583300, 13.6677800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3144, 'Hohentauern', 'Hohentauern', 'Hohentauern,Khoehntauehrn,huo heng tao en,hwhntawrn,Хоэнтауэрн,هوهنتاورن,霍亨陶恩', 47.4333300, 14.4833300, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3145, 'Hohenruppersdorf', 'Hohenruppersdorf', '', 48.4643900, 16.6524400, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3146, 'Hohenems', 'Hohenems', 'Gogenems,HOH,Hohenems,Khoehnems,Khoenems,ho-enemseu,hoenemsi,hoenemusu,huo en ai mu si,hwhnms,Гогенемс,Хоенемс,Хоэнемс,هوهنمس,ჰოენემსი,ホーエネムス,霍恩埃姆斯,호에넴스', 47.3666700, 9.6830600, 'AT', '2013-05-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3147, 'Hoheneich', 'Hoheneich', '', 48.7719500, 15.0285700, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3148, 'Hohenberg', 'Hohenberg', '', 47.9067900, 15.6199800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3149, 'Hohenau an der Raab', 'Hohenau an der Raab', 'Hohenau,Hohenau an der Raab', 47.3000000, 15.5500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3150, 'Hofstätten an der Raab', 'Hofstatten an der Raab', 'Hofstatten,Hofstatten an der Raab,Hofstätten,Hofstätten an der Raab', 47.0666700, 15.7333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3151, 'Höfen', 'Hofen', '', 47.4666700, 10.6833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3152, 'Hof bei Straden', 'Hof bei Straden', 'Hof,Hof bei Straden', 46.8000000, 15.9333300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3153, 'Hof bei Salzburg', 'Hof bei Salzburg', 'Hof,Khof (Zal''cburg),Хоф (Зальцбург)', 47.8192900, 13.2148800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3154, 'Hof am Leithaberge', 'Hof am Leithaberge', 'Hof,Hof am Leithaberge,Hof am Leithagebirge', 47.9500000, 16.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3155, 'Hochwolkersdorf', 'Hochwolkersdorf', '', 47.6612700, 16.2807200, 'AT', '2017-06-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3156, 'Höchst', 'Hochst', '', 47.4593400, 9.6405000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3157, 'Hochfilzen', 'Hochfilzen', 'Gokhfil''cen,Hochfilzen,Hohfilcene,Khokhfil''cen,Khokhfilcen,huo he fei er cen,Гохфільцен,Хохфилцен,Хохфильцен,霍赫菲尔岑', 47.4666700, 12.6166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3158, 'Hitzendorf', 'Hitzendorf', '', 47.0333300, 15.3000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3159, 'Hirtenberg', 'Hirtenberg', '', 47.9309500, 16.1790800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3160, 'Hirschbach', 'Hirschbach', '', 48.7432900, 15.1252100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3161, 'Hirnsdorf', 'Hirnsdorf', 'Hirnsdorf', 47.1916700, 15.8286800, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3162, 'Hirm', 'Hirm', 'Felszerfalva,Félszerfalva,Hirma', 47.7865200, 16.4546000, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3163, 'Hippach', 'Hippach', 'Hippach,Khippakh,Хиппах', 47.2043500, 11.8652300, 'AT', '2012-02-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3164, 'Hintersee', 'Hintersee', 'Feichten,Hintersee', 47.7000000, 13.2833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3165, 'Hinterbrühl', 'Hinterbruehl', 'Khinterbrjul'',hou bu lu er,Хинтербрюль,后布吕尔', 48.0861100, 16.2480900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3166, 'Himmelberg', 'Himmelberg', 'Himmelberg,Khimmel''berg,xi mo er bei ge,Химмельберг,锡默尔贝格', 46.7566700, 14.0305600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3167, 'Himberg', 'Himberg', '', 48.0833300, 16.4333300, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3168, 'Hieflau', 'Hieflau', 'Hieflau,Khiflau,xi fu lao,Хифлау,希夫劳', 47.6063900, 14.7450300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3169, 'Heugraben', 'Heugraben', 'Heugraben,Khojgraben,Zarnovica,Žarnovica,Хойграбен', 47.1178300, 16.1904100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3170, 'Herzogsdorf', 'Herzogsdorf', 'Herzogsdorf,Khercogsdorf,Херцогсдорф', 48.4301100, 14.1128000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3171, 'Herzogenburg', 'Herzogenburg', 'Khercogenburg,Vilandstal'',hei cuo gen bao,Виландсталь,Херцогенбург,黑措根堡', 48.2813700, 15.6943100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3172, 'Herrnbaumgarten', 'Herrnbaumgarten', '', 48.6960600, 16.6828300, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3173, 'Hernstein', 'Hernstein', 'Khernshtajn,hei en si tai yin,Хернштайн,黑恩斯泰因', 47.8946500, 16.1056100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3174, 'Hermagor', 'Hermagor', '', 46.6272200, 13.3672200, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3175, 'Hennersdorf', 'Hennersdorf', '', 48.1117300, 16.3631100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3176, 'Henndorf am Wallersee', 'Henndorf am Wallersee', 'Genndorf-am-Vallerze,Heedorf am Wallersee,Henndorf,Henndorf am Wallersee,Khenndorf-am-Vallerze,Khenndorf-am-Vallerzee,Генндорф-ам-Валлерзе,Хенндорф-ам-Валлерзе,Хенндорф-ам-Валлерзее', 47.9000000, 13.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3177, 'Hengsberg', 'Hengsberg', 'Hengsberg,Khengsberg,heng si bei ge,Хенгсберг,亨斯贝格', 46.8666700, 15.4333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3178, 'Hellmonsödt', 'Hellmonsodt', 'Hellmonsodt,Hellmonsödt,Khel''monzjodt,hei er meng se te,Хельмонзёдт,黑尔蒙瑟特', 48.4333300, 14.3000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3179, 'Heiterwang', 'Heiterwang', 'Heiterwang', 47.4500000, 10.7500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3180, 'Heiligenkreuz im Lafnitztal', 'Heiligenkreuz im Lafnitztal', 'Hagensdorf im Burgenland,Heiligenkreuz,Heiligenkreuz im Lafnitztal,Khajligenkrojc,Khajligenkrojc-im-Lafnictal'',Rabakeresztur,Rábakeresztúr,la fu ni ci gu de hai li gen ke luo yi ci,Хайлигенкройц,Хайлигенкройц-им-Лафницталь,拉夫尼茨谷地海利根克罗伊茨', 46.9891700, 16.2608300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3181, 'Heiligenkreuz am Waasen', 'Heiligenkreuz am Waasen', 'Heiligenkreuz,Heiligenkreuz am Waasen', 46.9558300, 15.5880600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3182, 'Heiligenkreuz', 'Heiligenkreuz', 'Khajligenkrojc,Хайлигенкройц', 48.0555900, 16.1249300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3183, 'Heiligenbrunn', 'Heiligenbrunn', 'Khajligenbrun,Khajligenbrunn,Szentkut,Szentkút,hai li gen bu lun,Хайлигенбрун,Хайлигенбрунн,海利根布伦', 47.0270500, 16.4168800, 'AT', '2013-04-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3184, 'Heiligenblut', 'Heiligenblut', 'Heiligenblut,Heiligenblut am Grossglockner,Heiligenblut am Großglockner,Khajligenbljut,Khajligenblut,Sveta Kri,hai li gen bu lu te,Хайлигенблут,Хайлигенблют,Хайліґенблют,ہیلیگنبلٹ,海利根布卢特', 47.0397900, 12.8434500, 'AT', '2013-09-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3185, 'Heidenreichstein', 'Heidenreichstein', 'Heidenreichstein,Khajdenrajkhshtajn,hai deng lai xi shi tai yin,Хайденрайхштайн,海登赖希施泰因', 48.8666700, 15.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3186, 'Hausmannstätten', 'Hausmannstatten', 'Hausmannstatten,Hausmannstätten,Khausmannshtetten,Хаусманнштеттен', 46.9911100, 15.5113900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3187, 'Hausleiten', 'Hausleiten', 'Cajna,Khauslajten,hao si lai teng,Хауслайтен,Цайна,豪斯莱滕', 48.3833300, 16.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3188, 'Hauskirchen', 'Hauskirchen', '', 48.6000000, 16.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3189, 'Hausbrunn', 'Hausbrunn', '', 48.6260200, 16.8284400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3190, 'Haus', 'Haus', '', 47.4099700, 13.7672400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3191, 'Haunoldstein', 'Haunoldstein', '', 48.2000000, 15.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3192, 'Haugsdorf', 'Haugsdorf', '', 48.7076200, 16.0765600, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3193, 'Haugschlag', 'Haugschlag', '', 48.9833300, 15.0500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3194, 'Hatzendorf', 'Hatzendorf', 'Hatzendorf', 46.9768600, 16.0010700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3195, 'Hatting', 'Hatting', '', 47.2787000, 11.1683800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3196, 'Häselgehr', 'Haselgehr', 'Haselgehr,Häselgehr', 47.3166700, 10.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3197, 'Hartl', 'Hartl', '', 47.1833300, 15.9166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3198, 'Hart im Zillertal', 'Hart im Zillertal', 'Hart,Hart im Zillertal', 47.3510600, 11.8647600, 'AT', '2013-12-06', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3199, 'Hartberg', 'Hartberg', 'Hartberg,Hartbergas,Khartberg,ha te bei ge,Хартберг,哈特貝格', 47.2833300, 15.9666700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3200, 'Harmannsdorf', 'Harmannsdorf', 'Harmannsdorf', 48.3972400, 16.3722000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3201, 'Haringsee', 'Haringsee', '', 48.1927000, 16.7874100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3202, 'Bad Häring', 'Bad Haering', '', 47.5107100, 12.1191200, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3203, 'Hardegg', 'Hardegg', 'Hardegg', 48.8500000, 15.8500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3204, 'Hard', 'Hard', '', 47.4830600, 9.6830600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3743, 'York', 'York', 'Jork,Jorko,York,Йорк,یارک، مغربی آسٹریلیا', -31.8880900, 116.7678000, 'AU', '2014-12-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3744, 'Yanchep', 'Yanchep', 'Yanchep,Yancher', -31.5467800, 115.6317100, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3745, 'Yallingup', 'Yallingup', 'Yallingup,Yallingup Caves', -33.6459200, 115.0351400, 'AU', '2014-07-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3746, 'Wundowie', 'Wundowie', 'Wundowie', -31.7616300, 116.3799000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3747, 'Wooroloo', 'Wooroloo', 'Wooroloo', -31.8038000, 116.3131100, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3748, 'Woodville', 'Woodville', 'Woodville', -34.8833300, 138.5500000, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3749, 'Woodside', 'Woodside', 'Woodside', -34.9543300, 138.8790100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3750, 'Wongan Hills', 'Wongan Hills', 'Wongan Hills', -30.8929400, 116.7192500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3751, 'Williamstown', 'Williamstown', 'Uill''jamstaun,Williamstown,Уилльямстаун', -34.6721000, 138.8910800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3752, 'Willaston', 'Willaston', 'Willaston', -34.5833300, 138.7500000, 'AU', '2012-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3753, 'Whyalla', 'Whyalla', 'Gorad Uajala,Gouaialla,Uajalla,Vajala,Vajalla,WYA,Whyalla,huai a la,hwaiaella,uaiala,wayala,wyala,Γουαϊάλλα,Вайалла,Вајала,Горад Уаяла,Уайалла,ויאלה,وایالا,واۓلا,ویالا,ہوائالا، جنوبی آسٹریلیا,უაიალა,怀阿拉,화이앨라', -33.0326800, 137.5648300, 'AU', '2013-08-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3754, 'Wembley', 'Wembley', 'Wembley', -31.9333300, 115.8000000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3755, 'Wellard', 'Wellard', 'Wellard', -32.2666700, 115.8333300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3756, 'Wayville', 'Wayville', 'Wayville', -34.9500000, 138.5833300, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3757, 'Waroona', 'Waroona', 'Waroona', -32.8432300, 115.9220100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3758, 'Wanneroo', 'Wanneroo', 'Wanneroo,Wanneru', -31.7500000, 115.8000000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3759, 'Wallaroo', 'Wallaroo', 'Uollaru,Wallaroo,Уоллару', -33.9388100, 137.6336500, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3760, 'Waikerie', 'Waikerie', 'Uehjkeri,Waikerie,Уэйкери', -34.1817800, 139.9855200, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3761, 'Wagin', 'Wagin', 'Wagin', -33.3089400, 117.3432800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3762, 'Waggrakine', 'Waggrakine', 'Waggrakine', -28.7188300, 114.6392400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3763, 'Virginia', 'Virginia', 'Virginia', -34.6663000, 138.5602700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3764, 'Victor Harbor', 'Victor Harbor', 'Victor Harbor,Victor Harbour,Viktor-Garbor,Viktor-Kharbor,bigteohabeo,wei ke duo gang,wyktwr harbr  gwnyy awstwralya,Виктор-Харбор,Віктор-Гарбор,ויקטור הארבור,وکٹر ہاربر,وکٹر ہاربر، جنوبی آسٹریلیا,ویکتور هاربر، گونئی اوستورالیا,ڤیکتۆر ھاربۆر,ვიქტორ-ჰარბორი,維克多港,维克多港,빅터하버', -35.5504200, 138.6215400, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3765, 'Vasse', 'Vasse', 'Vasse', -33.6666700, 115.2500000, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3766, 'Upper Sturt', 'Upper Sturt', 'Upper Sturt', -35.0166700, 138.6833300, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3767, 'Unley', 'Unley', 'Unley', -34.9500000, 138.6000000, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3768, 'Two Wells', 'Two Wells', 'Tu Vells,Two Wells,Ту Веллс', -34.5932700, 138.5136700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3769, 'Tumby Bay', 'Tumby Bay', 'Tambi-Bej,Tumby,Tumby Bay,Тамби-Бей', -34.3773000, 136.1006500, 'AU', '2016-11-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3770, 'Trigg', 'Trigg', '', -31.8693900, 115.7571000, 'AU', '2015-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3771, 'Toodyay', 'Toodyay', 'Toodyay', -31.5497700, 116.4674300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3772, 'Thebarton', 'Thebarton', 'Thebarton', -34.9166700, 138.5666700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3773, 'Tennant Creek', 'Tennant Creek', 'TCA,Tennant Creek,Tennant-Krik,tnnt kryk,tnnt qryq,Теннант-Крик,Теннант-Крік,טננט קריק,تننت کریک,ტენანტ-კრიკი', -19.6497000, 134.1914700, 'AU', '2012-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3774, 'Tanunda', 'Tanunda', 'Tanunda', -34.5233600, 138.9598200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3775, 'Tailem Bend', 'Tailem Bend', 'Tailem Bend,Tailen Bend,Tejlem-Bend,Тейлем-Бенд', -35.2522600, 139.4554600, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3776, 'Swan View', 'Swan View', '', -31.8833300, 116.0500000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3777, 'Swanbourne', 'Swanbourne', 'Swanbourne', -31.9687800, 115.7673000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3778, 'Subiaco', 'Subiaco', 'Subiaco', -31.9485000, 115.8268000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3779, 'Sturt', 'Sturt', 'Sturt', -35.0166700, 138.5500000, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3780, 'Streaky Bay', 'Streaky Bay', 'Flinders,KBY,Streaky Bay,Striki-Bej,Стрики-Бей', -32.7955400, 134.2092800, 'AU', '2014-10-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3781, 'Strathalbyn', 'Strathalbyn', 'Strathalbyn', -35.2597900, 138.8924700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3782, 'Stoneville', 'Stoneville', 'Stoneville', -30.8666700, 121.7666700, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3783, 'Stirling', 'Stirling', 'Stirling,Stirling East,Stirling West', -35.0151800, 138.7363700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3784, 'Spearwood', 'Spearwood', 'Spearwood', -32.1053400, 115.7779700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3785, 'South Perth', 'South Perth', 'Perth South,South Perth', -31.9833300, 115.8666700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3786, 'Solomontown', 'Solomontown', 'Solomontown', -33.2000000, 138.0333300, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3787, 'Smithfield', 'Smithfield', 'Smithfield', -34.6833300, 138.6833300, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3788, 'Serpentine', 'Serpentine', 'Serpentine', -32.3605100, 115.9772300, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3789, 'Seaton', 'Seaton', 'Seaton', -34.9000000, 138.5166700, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3790, 'Seaford', 'Seaford', 'Seaford', -35.1898000, 138.4758900, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3791, 'Scarborough', 'Scarborough', 'Scarborough,Scarborough Beach', -31.8957800, 115.7643100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3792, 'Salisbury', 'Salisbury', 'Salisbury', -34.7666700, 138.6333300, 'AU', '2012-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3793, 'Safety Bay', 'Safety Bay', 'Safety Bay', -32.3046300, 115.7421300, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3794, 'Roxby Downs', 'Roxby Downs', '', -30.5630500, 136.8954600, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3795, 'Roseworthy', 'Roseworthy', 'Roseworthy', -34.5339700, 138.7502300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3796, 'Roebourne', 'Roebourne', 'RBU,Roebourne', -20.7722900, 117.1464800, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3797, 'Rockingham', 'Rockingham', 'Rockingham,Rokingam,Rokingem,Рокингам,Рокінгем,راکنگھم، مغربی آسٹریلیا', -32.2768200, 115.7297800, 'AU', '2017-04-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3798, 'Maida Vale', 'Maida Vale', '', -31.9518700, 116.0276400, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3799, 'Reynella', 'Reynella', '', -35.0937200, 138.5308200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3800, 'Ravensthorpe', 'Ravensthorpe', 'RVT,Ravensthorpe', -33.5830300, 120.0468800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3801, 'Quorn', 'Quorn', 'Kuorn,Quorn,Куорн', -32.3467600, 138.0417600, 'AU', '2013-08-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3802, 'Quindalup', 'Quindalup', 'Quindalup', -33.6356000, 115.1489900, 'AU', '2014-08-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3803, 'Prospect', 'Prospect', '', -34.8824100, 138.5933000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3804, 'Port Willunga', 'Port Willunga', 'Port Willunga', -35.2779200, 138.4523000, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3805, 'Port Victoria', 'Port Victoria', 'Port Victoria,Port-Viktorija,Wauraltee,Порт-Виктория', -34.4960200, 137.4827000, 'AU', '2016-03-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3806, 'Port Pirie', 'Port Pirie', 'PPI,Port Pirie,Port-Piri,poteupili,potopiri,pwrt pyry,Порт-Пири,Порт-Пірі,פורט פירי,پورت پیری,پورٹ پیری,پۆرت پیێری,პორტ-პირი,ポートピリー,포트피리', -33.1917600, 138.0174600, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3807, 'Port Noarlunga', 'Port Noarlunga', 'Port Noarlunga', -35.1480200, 138.4709900, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3808, 'Port Lincoln', 'Port Lincoln', 'PLO,Port Lincoln,Port-Linkol''n,Pt Lincoln,lin ken gang,poteulingkeon,potorinkan,Порт-Линкольн,Порт-Лінкольн,پورٹ لنکولن,პორტ-ლინკოლნი,ポートリンカーン,林肯港,포트링컨', -34.7262500, 135.8744200, 'AU', '2017-05-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3809, 'Port Hedland', 'Port Hedland', 'PHE,Port Hedland,Port Khedland,Port-Gedlend,Port-Khedlend,poteuhedeullaendeu,potoheddorando,pwrt hdlnd,Порт Хедланд,Порт-Гедленд,Порт-Хедленд,פורט הדלנד,პორტ-ჰედლანდი,ポートヘッドランド,포트헤들랜드', -20.3121500, 118.6105900, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3810, 'Port Elliot', 'Port Elliot', 'Port Elliot', -35.5301700, 138.6792200, 'AU', '2015-12-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3811, 'Port Augusta West', 'Port Augusta West', '', -32.4861100, 137.7583300, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3812, 'Port Augusta', 'Port Augusta', 'Kurdnatta,PUG,Port Augusta,Port Avgusta,Port-Ogasta,Puerto Augusta,ao gu si ta gang,poteuogeoseuta,potoogasuta,pwrt agwsta,Порт Августа,Порт-Огаста,פורט אוגוסטה,پورت آگوستا,پورٹ آگستا,پورٹ آگسٹا، جنوبی آسٹریلیا,پۆرت ئۆگەستا,პორტ-ოგასტა,ポートオーガスタ,奧古斯塔港,포트오거스타', -32.4959700, 137.7728100, 'AU', '2013-08-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3813, 'Port Adelaide', 'Port Adelaide', 'Port Adelaide,پورٹ ایڈیلیڈ، جنوبی آسٹریلیا', -34.8500000, 138.4666700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3205, 'Hannersdorf', 'Hannersdorf', 'Samfalva,Sampovar,Sámfalva,Šampovar', 47.2289500, 16.3825000, 'AT', '2012-11-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3206, 'Hallwang', 'Hallwang', '', 47.8500000, 13.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3207, 'Hallein', 'Hallein', 'Gallajn,Hallein,Khalajn,Khallajn,Salinae,ha lai yin,halaini,halayn,hallain,harain,Галлайн,Халајн,Халлайн,האליין,هالاین,ჰალაინი,ハライン,哈萊因,할라인', 47.6833300, 13.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3208, 'Halbturn', 'Halbturn', 'Feltorony,Féltorony,Gal''bturn,Khal''bturn,ha bu tu en,Гальбтурн,Хальбтурн,哈布图恩', 47.8701900, 16.9754200, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3209, 'Halbenrain', 'Halbenrain', 'Halbenrain,Khal''benrajn,ha er ben lai yin,Хальбенрайн,哈尔本赖因', 46.7219400, 15.9466700, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3210, 'Hainzenberg', 'Hainzenberg', 'Hainzenberg', 47.2178800, 11.9003400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3211, 'Hainsdorf im Schwarzautal', 'Hainsdorf im Schwarzautal', 'Hainsdorf,Hainsdorf im Schwarzautal', 46.8358300, 15.6413900, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3212, 'Hainfeld', 'Hainfeld', '', 48.0339000, 15.7741400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3213, 'Hainersdorf', 'Hainersdorf', 'Hainersdorf', 47.1150600, 15.9437400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3214, 'Hainburg an der Donau', 'Hainburg an der Donau', 'Gajnburg-na-Dunai,Hainburg,Hainburgo ce Danubo,Hainburgo ĉe Danubo,Khajnburg,Khajnburg-an-der-Donau,duo nao he pan hai en bao,Гайнбург-на-Дунаї,Хайнбург,Хайнбург-ан-дер-Донау,多瑙河畔海恩堡', 48.1462700, 16.9450400, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3215, 'Haiming', 'Haiming', '', 47.2500000, 10.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3216, 'Haidershofen', 'Haidershofen', '', 48.0757900, 14.4613100, 'AT', '2016-03-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3217, 'Haibach im Mühlkreis', 'Haibach im Muhlkreis', 'Haibach,Haibach im Muhlkreis,Haibach im Mühlkreis', 48.4442900, 14.3441100, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3218, 'Hagenbrunn', 'Hagenbrunn', '', 48.3333300, 16.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3219, 'Hafnerbach', 'Hafnerbach', '', 48.2166700, 15.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3220, 'Hadres', 'Hadres', '', 48.7096500, 16.1303800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3221, 'Hackerberg', 'Hackerberg', 'Hackerberg,Hakerberg,Khakkerberg,Хаккерберг', 47.2000000, 16.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3222, 'Haag', 'Haag', '', 48.1136200, 14.5675300, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3223, 'Güttenbach', 'Guttenbach', 'Gjuttenbakh,Guttenbach,Güttenbach,Pinkovac,Гюттенбах', 47.1571000, 16.2923000, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3224, 'Guttaring', 'Guttaring', '', 46.8853600, 14.5107100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3225, 'Gutenstein', 'Gutenstein', '', 47.8760000, 15.8888100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3226, 'Gutenbrunn', 'Gutenbrunn', '', 48.3652000, 15.1189900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3227, 'Güssing', 'Guessing', 'Gising,Gjussing,Guessing,Güssing,Nemetujvar,Novi Grad,Németújvár,ju xing,Гисинг,Гюссинг,Гюссінг,居兴', 47.0593600, 16.3243100, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3228, 'Gurk', 'Gurk', 'Gurk,Krka  Avstrija,Гурк', 46.8738900, 14.2916700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3229, 'Guntramsdorf', 'Guntramsdorf', 'Guntramsdorf,gong te la mu si duo fu,Гунтрамсдорф,貢特拉姆斯多夫', 48.0468700, 16.3138400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3230, 'Guntersdorf', 'Guntersdorf', '', 48.6500000, 16.0500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3231, 'Gunskirchen', 'Gunskirchen', 'Gunskirkhen,gong si ji xing,Гунскирхен,貢斯基興', 48.1333300, 13.9500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3232, 'Günselsdorf', 'Gunselsdorf', '', 47.9439500, 16.2606200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3233, 'Gundersdorf', 'Gundersdorf', '', 46.9500000, 15.2333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3234, 'Gumpoldskirchen', 'Gumpoldskirchen', 'Gumpol''dskirkhen,gong bo er de si ji xing,Гумпольдскирхен,贡波尔德斯基兴', 48.0453800, 16.2771000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3235, 'Grünbach am Schneeberg', 'Grunbach am Schneeberg', 'Grunbach,Grunbach am Schneeberge,Grünbach,Grünbach am Schneeberge', 47.7974700, 15.9878500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3236, 'Grünau im Almtal', 'Gruenau im Almtal', 'Gmunden,Grjunau,Grjunau-im-Al''mtal'',Grunau,Grünau,ge lu nao,Грюнау,Грюнау-им-Альмталь,格呂瑙', 47.8549300, 13.9557300, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3237, 'Großweikersdorf', 'Grossweikersdorf', 'Grosvajkersdorf,Klajnvizendorf,da wei ke er si duo fu,Гросвайкерсдорф,Клайнвизендорф,大魏克尔斯多夫', 48.4712300, 15.9825100, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3238, 'Großsölk', 'Grosssoelk', 'Grosssolk,Grosssölk,Großsölk', 47.4166700, 13.9666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3239, 'Groß-Siegharts', 'Gross-Siegharts', '', 48.7918000, 15.4042900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3240, 'Groß-Schweinbarth', 'Gross-Schweinbarth', 'Gross-Schweinbarth,Grossschweinbarth,Groß-Schweinbarth,Großschweinbarth', 48.4147200, 16.6319400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3241, 'Groß Sankt Florian', 'Gross Sankt Florian', 'Gros-Sankt-Florian,Gross Sankt Florian,Groß Sankt Florian,da sheng fu luo li an,Грос-Санкт-Флориан,大圣弗洛里安', 46.8244400, 15.3186100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3242, 'Großrußbach', 'Grossrussbach', '', 48.4741200, 16.4164900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3243, 'Großriedenthal', 'Grossriedenthal', '', 48.4833300, 15.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3244, 'Grosspetersdorf', 'Grosspetersdorf', 'Grosspetersdorf,Großpetersdorf,Nagyszentmihaly,Nagyszentmihály', 47.2389500, 16.3178300, 'AT', '2017-02-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3245, 'Großmugl', 'Grossmugl', 'Grosmugl'',da mu ge er,Гросмугль,大穆格尔', 48.4991700, 16.2305600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3246, 'Großlobming', 'Grosslobming', 'Grosslobming,Großlobming', 47.1833300, 14.8000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3247, 'Großkrut', 'Grosskrut', '', 48.6438900, 16.7236100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3248, 'Großklein', 'Grossklein', 'Grossklein,Großklein,Klein', 46.7361100, 15.4444400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3249, 'Großhofen', 'Grosshofen', '', 48.2583400, 16.6194000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3250, 'Heimschuh', 'Heimschuh', 'Grossheimschuh,Heimschuh', 46.7600000, 15.4930600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3251, 'Großharras', 'Grossharras', '', 48.6638900, 16.2455600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3252, 'Groß-Gerungs', 'Gross-Gerungs', '', 48.5742200, 14.9578900, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3253, 'Groß-Enzersdorf', 'Gross-Enzersdorf', 'Genzersdorf,Gros-Encersdorf,Grosehncersdorf,Gross-Enzersdorf,Groß-Enzersdorf,da en ce si duo fu,Грос-Енцерсдорф,Гросэнцерсдорф,大恩策斯多夫', 48.2027800, 16.5508300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3254, 'Groß-Engersdorf', 'Gross-Engersdorf', 'Grossengersdorf,Großengersdorf', 48.3587300, 16.5661000, 'AT', '2017-06-30', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3255, 'Großebersdorf', 'Grossebersdorf', 'Grosehbersdorf,Grossebersdorf,da ai bo er si duo fu,Гроссеберсдорф,Гросэберсдорф,大埃伯尔斯多夫', 48.3640500, 16.4707600, 'AT', '2013-03-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3256, 'Grödig', 'Grodig', 'Graedig,Gredig,Grjodig,Grodig,Grädig,Grödig,ge lei di xi,Гредіг,Грёдиг,格勒迪希', 47.7383300, 13.0373000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3257, 'Gröbming', 'Grobming', 'Grjobming,Grobming,Gröbming,ge lei bu ming,Грёбминг,格勒布明', 47.4427200, 13.9012200, 'AT', '2011-09-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3258, 'Grins', 'Grins', 'Grins,Innerdorf,ge lin si,Гринс,Грінс,格林斯', 47.1403400, 10.5140900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3259, 'Grimmenstein', 'Grimmenstein', 'Grimmenshtajn,Grimmenstein,ge li men shi tai yin,Гримменштайн,格里门施泰因', 47.6163500, 16.1272400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3260, 'Griffen', 'Griffen', 'Grebinj,Griffen,ge li fen,Гриффен,Ґріффен,格里芬', 46.7044400, 14.7327800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3261, 'Grieskirchen', 'Grieskirchen', 'Griaskircha,Grieskirchen,Griskirkhen,ge li si ji xing,Грискирхен,格里斯基兴', 48.2333300, 13.8333300, 'AT', '2014-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3262, 'Gries im Sellrain', 'Gries im Sellrain', 'Gries,Gries in Sellrain', 47.1955400, 11.1561900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3263, 'Gries am Brenner', 'Gries am Brenner', 'Gries,Gries am Brenner', 47.0384900, 11.4813100, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3264, 'Gresten', 'Gresten', 'Gresten,ge lei si teng,Грестен,格雷斯滕', 47.9852100, 15.0255200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3265, 'Gressenberg', 'Gressenberg', '', 46.8000000, 15.1166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3266, 'Greisdorf', 'Greisdorf', 'Greisdorf', 46.9166700, 15.2166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3267, 'Greifenburg', 'Greifenburg', 'Grajfenburg,ge lai fen bao,Грайфенбург,格赖芬堡', 46.7502700, 13.1798200, 'AT', '2017-06-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3268, 'Graz', 'Graz', 'GRZ,Gorad Grac,Grac,Graca,Gracas,Gradec,Graecia,Gratz,Graz,Grác,Gráz,Grāca,Nkrats,Qras,Styrsky Hradec,ge la ci,geulacheu,ghrats,grats,gratsa,gratsi,guratsu,kras,Štýrský Hradec,Γκρατς,Горад Грац,Грац,Գրաց,גראץ,غراتس,گراتس,ग्रात्स,กราซ,გრაცი,グラーツ,格拉茨,그라츠', 47.0666700, 15.4500000, 'AT', '2015-04-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3269, 'Gratwein', 'Gratwein', 'Gratvajn,Gratwein,ge la te wei yin,Гратвайн,格拉特韦因', 47.1166700, 15.3166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3270, 'Gratkorn', 'Gratkorn', 'Gratkorn,ge la te ke en,Граткорн,格拉特科恩', 47.1333300, 15.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3271, 'Grän', 'Graen', 'Gren,Грен', 47.5000000, 10.5500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3272, 'Grambach', 'Grambach', 'Grambach', 47.0166700, 15.5000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3273, 'Gramatneusiedl', 'Gramatneusiedl', 'Gramatnojzidl'',ge la ma te nuo yi xi de er,Граматнойзидль,格拉馬特諾伊錫德爾', 48.0304000, 16.4893600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3274, 'Gramastetten', 'Gramastetten', 'Gramashtetten,ge la ma shi te teng,Грамаштеттен,格拉马施特滕', 48.3802800, 14.1918500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3275, 'Gramais', 'Gramais', 'Gramais', 47.2666700, 10.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3276, 'Grafenwörth', 'Grafenworth', '', 48.4079000, 15.7782600, 'AT', '2017-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3277, 'Grafenstein', 'Grafenstein', '', 46.6139300, 14.4671900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3278, 'Grafenschlag', 'Grafenschlag', '', 48.5000000, 15.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3279, 'Grafenschachen', 'Grafenschachen', '', 47.3666700, 16.0666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3280, 'Grafenegg', 'Grafenegg', 'Grafeneg,Grafenegg,ge la fei nei ge,Графенег,Графенегг,格拉费内格', 48.4304000, 15.7490700, 'AT', '2017-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3281, 'Grafendorf bei Hartberg', 'Grafendorf bei Hartberg', 'Grafendorf,Grafendorf (Khartberg),Grafendorf bei Hartberg,Grafendorf-Khartberg,Grafendorf-baj-Khartberg,ha te bei ge fu jin ge la fen duo fu,Графендорф (Хартберг),Графендорф-Хартберг,Графендорф-бай-Хартберг,哈特贝格附近格拉芬多夫', 47.3402800, 15.9906000, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3282, 'Grabersdorf', 'Grabersdorf', 'Grabersdorf', 46.8430600, 15.8247200, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3283, 'Götzis', 'Gotzis', 'G''ocis,Gecis,Getcis,Gjotcis,Gotzis,Götzis,ge qi si,getsu~isu,gwtsyz,Гетціс,Гецис,Гьоцис,Гётцис,گوتسیز,ゲツィス,格齊斯', 47.3330600, 9.6330600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3284, 'Götzens', 'Gotzens', 'Getcens,Gjotcens,ge cen si,Гетценс,Гётценс,گوٹزنز,格岑斯', 47.2360600, 11.3115400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3285, 'Götzendorf an der Leitha', 'Gotzendorf an der Leitha', 'Goetzendorf,Gotzendorf,Gotzendorf an der Leitha,Götzendorf,Götzendorf an der Leitha', 48.0166700, 16.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3286, 'Göstling an der Ybbs', 'Gostling an der Ybbs', 'Gjostling-an-der-Ibs,Gostling,Gostling an der Ybbs,Göstling,Göstling an der Ybbs,Ibstajnbakh,yi bu si he pan ge shi te ling,Гёстлинг-ан-дер-Ибс,Ибстайнбах,伊布斯河畔格施特灵', 47.8066400, 14.9379700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3287, 'Gösting', 'Goesting', 'Gosting,Gösting', 47.0978800, 15.3977700, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3288, 'Gössendorf', 'Gossendorf', 'Gjossendorf,Gossendorf,Gössendorf,ge sen duo fu,Гёссендорф,格森多夫', 46.9833300, 15.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3289, 'Gossendorf', 'Gossendorf', '', 46.9107600, 15.9304300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3290, 'Gössenberg', 'Goessenberg', 'Gossenberg,Gossenberger,Gössenberg,Gössenberger', 47.4166700, 13.8166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3291, 'Gosdorf', 'Gosdorf', 'Gosdorf', 46.7277800, 15.7925000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3292, 'Göpfritz an der Wild', 'Gopfritz an der Wild', 'Gopfritz,Gopfritz an der Wild,Göpfritz,Göpfritz an der Wild', 48.7249700, 15.4023600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3293, 'Gols', 'Gols', 'Galos,Gol''s,Gols,Gálos,Гольс', 47.8968900, 16.9111300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3294, 'Golling an der Salzach', 'Golling an der Salzach', 'Golling,Golling an der Salzach,Golling-an-der-Zal''cakh,Golling-na-Zal''cakhe,sa er cha he he pan ge ling,Голлинг-ан-дер-Зальцах,Голлинг-на-Зальцахе,Голлінг-ан-дер-Зальцах,萨尔察赫河畔戈灵', 47.6000000, 13.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3295, 'Göllersdorf', 'Gollersdorf', 'Gjollersdorf,ge lei er si duo fu,Гёллерсдорф,格勒尔斯多夫', 48.4935700, 16.1194300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3296, 'Goldwörth', 'Goldworth', 'Goldworth,Goldwörth', 48.3266400, 14.1011200, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3297, 'Goldegg', 'Goldegg', 'Gol''deg,Goldeck,Гольдег', 47.3187500, 13.0992200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3298, 'Going', 'Going', 'Going am Wilden Kaiser', 47.5133200, 12.3316400, 'AT', '2017-06-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3299, 'Göfis', 'Gofis', '', 47.2335600, 9.6345800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3300, 'Gnesau', 'Gnesau', '', 46.7754400, 13.9625100, 'AT', '2011-09-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3301, 'Gnas', 'Gnas', 'Gnas,ge na si,Гнас,格納斯', 46.8730600, 15.8252800, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3302, 'Gnadendorf', 'Gnadendorf', 'Gnadendorf,ge na deng duo fu,Гнадендорф,格纳登多夫', 48.6166700, 16.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3303, 'Gmunden', 'Gmunden', 'Gmunden,Gmunden an der Traun,Gmundn,ge meng deng,geumunden,gmundeni,gmwndn,gumunden,Гмунден,Գմունդեն,גמונדן,گموندن,გმუნდენი,グムンデン,格蒙登,그문덴', 47.9183900, 13.7993300, 'AT', '2013-11-19', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3304, 'Gmünd', 'Gmund', 'Cmunt,Gmjund,Гмюнд', 48.7683000, 14.9808000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3305, 'Gmünd', 'Gmuend', 'Gmjund,Гмюнд', 46.9072200, 13.5294400, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3306, 'Glojach', 'Glojach', 'Glojach,Glojakh,Глоях', 46.8666700, 15.6666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3307, 'Gloggnitz', 'Gloggnitz', 'Glognic,Vajsenbakh,ge luo ge ni ci,glognitsi,Вайсенбах,Глогниц,გლოგნიცი,格洛格尼茨', 47.6748700, 15.9389300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3308, 'Glödnitz', 'Glodnitz', 'Gljodnic,ge lei de ni ci,Глёдниц,格勒德尼茨', 46.8739800, 14.1191500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3309, 'Globasnitz', 'Globasnitz', 'Globasnic,Globasnica,Globasnitz,Glóbasnitz,Klobasnica,ge luo ba si ni ci,Глобасниц,格洛巴斯尼茨', 46.5569400, 14.7027800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3310, 'Glinzendorf', 'Glinzendorf', '', 48.2460500, 16.6406000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3311, 'Gleisdorf', 'Gleisdorf', 'Glajsdorf,ge lai si duo fu,Глайсдорф,格萊斯多夫', 47.1055900, 15.7101100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3312, 'Gleinstätten', 'Gleinstaetten', 'Glajnshtetten,Gleinstatten,Gleinstätten,ge lai yin shi te teng,Глайнштеттен,格莱因施特滕', 46.7536100, 15.3697200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3313, 'Glanegg', 'Glanegg', 'Glaneg,Glanegg,ge la nei ge,Гланег,格拉内格', 46.7225900, 14.1989300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3314, 'Gießhübl', 'Giesshubl', 'Giskhjubl'',ji si xu bu er,Гисхюбль,吉斯许布尔', 48.0978000, 16.2347900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3315, 'Gföhl', 'Gfohl', 'Gfjol'',ge fu er,Гфёль,格弗尔', 48.5166700, 15.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3316, 'Gersdorf an der Feistritz', 'Gersdorf an der Feistritz', 'Gersdorf,Gersdorf an der Feistritz', 47.1666700, 15.8500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3317, 'Gerersdorf', 'Gerersdorf', '', 48.2008800, 15.5561300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3318, 'Gerasdorf bei Wien', 'Gerasdorf bei Wien', 'Gerasdorf,Gerasdorf-Vin,Gerasdorf-baj-Vin,Gerasdorfas,wei ye na fu jin ge la si duo fu,Герасдорф-Вин,Герасдорф-бай-Вин,维也纳附近格拉斯多夫', 48.2944700, 16.4676500, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3319, 'Geras', 'Geras', '', 48.7972500, 15.6726800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3320, 'Geistthal', 'Geistthal', 'Geisttal,Geistthal', 47.1666700, 15.1666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3321, 'Gedersdorf', 'Gedersdorf', '', 48.4331900, 15.6886500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3322, 'Gaweinstal', 'Gaweinstal', 'Gavajnstal'',Gaweinstal,jia wei yin shi ta er,Гавайнсталь,加韦因施塔尔', 48.4800300, 16.5879000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3323, 'Gaubitsch', 'Gaubitsch', '', 48.6500000, 16.3833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3324, 'Gattendorf', 'Gattendorf', 'Lajtakata,Lajtakáta', 48.0166700, 16.9833300, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3325, 'Gastern', 'Gastern', '', 48.8944600, 15.2202700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3326, 'Gasen', 'Gasen', 'Gasen', 47.3833300, 15.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3327, 'Gaschurn', 'Gaschurn', 'Gaschurn,Gashurn,jia shu en,Гашурн,加舒恩', 46.9858400, 10.0270200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3328, 'Garsten', 'Garsten', '', 48.0224000, 14.4074700, 'AT', '2017-07-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3329, 'Gars am Kamp', 'Gars am Kamp', 'Gars,Gars am Kamp,Gars-am-Kamp,kan pu he pan jia er si,Гарс-ам-Камп,坎普河畔加尔斯', 48.5889900, 15.6536300, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3330, 'Garanas', 'Garanas', 'Garanas', 46.7666700, 15.1166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3331, 'Ganz', 'Ganz', '', 47.6000000, 15.6833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3332, 'Gänserndorf', 'Ganserndorf', 'Genzerndorf,Unterganserndorf,Untergänserndorf,Гензерндорф', 48.3392500, 16.7201600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3333, 'Bad Gams', 'Bad Gams', 'Bad Gams,Bad-Gams,Gams,Gams ob Frauental,Gams ob Frauenthal,ba te jia mu si,Бад-Гамс,巴特加姆斯', 46.8711100, 15.2247200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3334, 'Gams bei Hieflau', 'Gams bei Hieflau', 'Gams,Gams bei Hieflau', 47.6666700, 14.7833300, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3335, 'Gampern', 'Gampern', '', 47.9874500, 13.5592700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3336, 'Gamlitz', 'Gamlitz', 'Gamlic,Gamlitc,Gamlitz,jia mu li ci,Гамлитц,Гамлиц,加姆利茨', 46.7202800, 15.5533300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3337, 'Gaming', 'Gaming', 'Gaming,Kinberg,jia ming,Гаминг,Кинберг,加明', 47.9290000, 15.0881800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3338, 'Galtür', 'Galtur', 'Gal''tjur,Galtjur,Galtur,Galtür,Platz,jia er di,Галтюр,Гальтюр,گالٹر,加尔蒂', 46.9666700, 10.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3339, 'Gallzein', 'Gallzein', 'Gallzein,Gallzein uber Jenbach,Gallzein über Jenbach', 47.3680700, 11.7715900, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3340, 'Gallneukirchen', 'Gallneukirchen', 'Gal''nojkirkhen,Goineikircha,jia er nuo yi ji xing,Гальнойкирхен,加爾諾伊基興', 48.3536300, 14.4160400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3341, 'Gallmannsegg', 'Gallmannsegg', 'Gallmannsegg', 47.1833300, 15.0666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3342, 'Gallizien', 'Gallizien', '', 46.5500000, 14.5166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3343, 'Gaißau', 'Gaissau', 'Gaissau,Gaißau', 47.4666700, 9.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3344, 'Gaflenz', 'Gaflenz', 'Gaflenc,Gaflenz,jia fu lun ci,Гафленц,加夫伦茨', 47.8951100, 14.7247700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3345, 'Gablitz', 'Gablitz', 'Gablic,jia bu li ci,Габлиц,加布里茨', 48.2285600, 16.1543700, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3346, 'Gabersdorf', 'Gabersdorf', 'Gabersdorf', 46.7772200, 15.5841700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3347, 'Gaal', 'Gaal', 'Gaal', 47.2726800, 14.6700300, 'AT', '2017-01-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3348, 'Gaaden', 'Gaaden', 'Gaden,jia deng,Гаден,加登', 48.0536400, 16.2000300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3349, 'Fußach', 'Fussach', 'Fussach,Fussakh,Fußach,Фуссах', 47.4793300, 9.6627800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3350, 'Fuschl am See', 'Fuschl am See', 'Fuschl,Fuschl am See,Fushl''-am-Zee,Фушль-ам-Зее', 47.8000000, 13.3000000, 'AT', '2016-07-23', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3351, 'Furth an der Triesting', 'Furth an der Triesting', 'Furt-an-der-Tristing,Furth,te li shi ting he pan fu er te,Фурт-ан-дер-Тристинг,特里施廷河畔富尔特', 47.9732600, 15.9732600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3352, 'Fürstenfeld', 'Fuerstenfeld', 'Firshtenfeld,Fjurstenfel''d,Foeloestoem,Furstenfeld,Fölöstöm,Fürstenfeld,fei er si teng fei er de,Фирштенфелд,Фюрстенфельд,菲爾斯滕費爾德', 47.0500000, 16.0833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3353, 'Fulpmes', 'Fulpmes', 'Ful''pmes,Fulpmes,Vulpmes,fu er pu mei si,Фульпмес,富尔普梅斯', 47.1520200, 11.3492200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3354, 'Fügenberg', 'Fugenberg', 'Fjugenberg,Fugenberg,Fügenberg,fei gen bei ge,Фюгенберг,菲根贝格', 47.3521000, 11.8417300, 'AT', '2013-12-06', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3355, 'Fügen', 'Fugen', 'Fjugen,Fugen,Fügen,Фюген', 47.3470000, 11.8493900, 'AT', '2013-12-06', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3356, 'Frohnleiten', 'Frohnleiten', 'Frohnleiten,Fronlajten,fu long lai teng,Фронлайтен,弗龍萊騰', 47.2666700, 15.3166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3357, 'Fritzens', 'Fritzens', '', 47.3000000, 11.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3358, 'Friesach', 'Friesach', 'Friesach', 46.9552800, 14.4058300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3359, 'Friedberg', 'Friedberg', 'Fridberg,Friedberg,Фридберг', 47.4333300, 16.0500000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3360, 'Fresach', 'Fresach', '', 46.7155600, 13.6908300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3361, 'Freistadt', 'Freistadt', 'Frajshhat,Frajshtadt,Freistadt,frayshtat,fu lai shi ta te,Фрайштадт,Фрайщат,Ֆրայշթաթ,فرایشتات,弗賴施塔特', 48.5110300, 14.5045300, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3362, 'Freiland bei Deutschlandsberg', 'Freiland bei Deutschlandsberg', 'Frajland-Dojchlandsberg,Frajland-baj-Dojchlandsberg,Freiland,Freiland bei Deutschlandsberg,de yi zhi lan ci bei ge fu jin fei lai lan,Фрайланд-Дойчландсберг,Фрайланд-бай-Дойчландсберг,德意志兰茨贝格附近费赖兰', 46.8333300, 15.1333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3363, 'Fraxern', 'Fraxern', '', 47.3149800, 9.6739100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3364, 'Frauenkirchen', 'Frauenkirchen', 'Boldogasszony,Frauehnkirkhen,Frauenkirchen,Фрауэнкирхен', 47.8367800, 16.9258100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3365, 'Frauenberg', 'Frauenberg', '', 47.4285500, 15.3420600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3366, 'Frannach', 'Frannach', 'Frannach', 46.9130600, 15.6336100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3367, 'Frankenmarkt', 'Frankenmarkt', 'Frankenmarkt,fu lan ken ma ke te,Франкенмаркт,弗兰肯马克特', 47.9833300, 13.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3368, 'Frankenfels', 'Frankenfels', 'Frankenfel''s,Frongafoes,Frongafös,fu lan ken fei er si,Франкенфельс,弗兰肯费尔斯', 47.9823400, 15.3259300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3369, 'Frankenburg', 'Frankenburg', '', 48.0684400, 13.4906500, 'AT', '2014-05-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3370, 'Forstau', 'Forstau', '', 47.3784200, 13.5555800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3371, 'Fornach', 'Fornach', '', 48.0227700, 13.4294100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3372, 'Forchach', 'Forchach', 'Forchach', 47.4166700, 10.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3373, 'Fohnsdorf', 'Fohnsdorf', 'Fohnsdorf,Fonsdorf,feng si duo fu,fwnsdwrf,Фонсдорф,فونسدورف,丰斯多夫', 47.2000000, 14.6833300, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3374, 'Floing', 'Floing', 'Floing', 47.2635600, 15.7465000, 'AT', '2013-02-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3375, 'Flirsch', 'Flirsch', 'Flirsch,Flirsch am Arlberg,Flirsh,fu li er shi,Флирш,Флірш,弗利尔施', 47.1500000, 10.4000000, 'AT', '2016-04-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3376, 'Flaurling', 'Flaurling', '', 47.2914300, 11.1231900, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3377, 'Flattach', 'Flattach', 'Flattakh,fu la ta he,Флаттах,弗拉塔赫', 46.9386100, 13.1344400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3378, 'Flatschach', 'Flatschach', '', 47.2166700, 14.7500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3379, 'Fladnitz im Raabtal', 'Fladnitz im Raabtal', 'Fladnitz,Fladnitz im Raabtal', 46.9916700, 15.7852800, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3380, 'Flachau', 'Flachau', '', 47.3440600, 13.3914800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3381, 'Fiss', 'Fiss', 'Fis,Fiss,fei si,Фис,Фісс,菲斯', 47.0571400, 10.6174700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3382, 'Fischbach', 'Fischbach', 'Fischbach', 47.4423400, 15.6497200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3383, 'Fischamend Dorf', 'Fischamend Dorf', '', 48.1188400, 16.6128700, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3384, 'Filzmoos', 'Filzmoos', 'Burgfried,Filzmoos', 47.4333300, 13.5166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3385, 'Fieberbrunn', 'Fieberbrunn', 'Fiberbrun,Fiberbrunn,Fieberbrunn,fei bo er bu lun,Фибербрун,Фибербрунн,Фібербрунн,菲伯尔布伦', 47.4762600, 12.5434700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3386, 'Ferschnitz', 'Ferschnitz', '', 48.0941900, 14.9845400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3387, 'Fernitz', 'Fernitz', '', 46.9738900, 15.5011100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3388, 'Ferndorf', 'Ferndorf', '', 46.7365100, 13.6266100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3389, 'Ferlach', 'Ferlach', 'Borovlje,Ferlach,Ferlah,Ferlakh,fei la he,Ферлах,費拉赫', 46.5269400, 14.3019400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3390, 'Fendels', 'Fendels', 'Fendels', 47.0539000, 10.6777700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3391, 'Fels am Wagram', 'Fels am Wagram', 'Fels,Fels am Wagram', 48.4333300, 15.8166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3392, 'Felixdorf', 'Felixdorf', 'Feliksdorf,fei li ke si duo fu,Феликсдорф,费利克斯多夫', 47.8815900, 16.2420800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3393, 'Feldkirchen in Kärnten', 'Feldkirchen in Karnten', 'Fel''dkirkhen,Fel''dkirkhen (Karintija),Fel''dkirkhen-in-Kernten,Feldkirchen,Feldkirchen in Karnten,Feldkirchen in Kärnten,Feldkirchenas,Feldkirkhen,fei er de ji xing,fldkyrshn ayn krntn,Фелдкирхен,Фельдкирхен,Фельдкирхен (Каринтия),Фельдкирхен-ин-Кернтен,فلدکیرشن این کرنتن,ფელდკირხენი,費爾德基興', 46.7236800, 14.0958000, 'AT', '2012-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3394, 'Feldkirchen bei Graz', 'Feldkirchen bei Graz', 'Fel''dkirkhen (Grac),Fel''dkirkhen-Grac,Fel''dkirkhen-baj-Grac,Feldkirchen,Feldkirchen bei Graz,ge la ci fu jin fei er de ji xing,Фельдкирхен (Грац),Фельдкирхен-Грац,Фельдкирхен-бай-Грац,Фельдкірхен-бай-Грац,格拉茨附近费尔德基兴', 47.0166700, 15.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3395, 'Feldkirchen an der Donau', 'Feldkirchen an der Donau', 'Fel''dkirkhen-an-der-Donau,Fel''dkirkhen-na-Dunae,Feldkirchen,Feldkirchen a. d. Donau,Feldkirchen an der Donau,Foeikirchn an da Doana,Föikirchn an da Doana,duo nao he pan fei de ji xing,Фельдкирхен-ан-дер-Донау,Фельдкирхен-на-Дунае,多瑙河畔费德基兴', 48.3452400, 14.0513400, 'AT', '2013-10-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3396, 'Feldkirch', 'Feldkirch', 'Fel''dkirkh,Feldkirch,pldqyrk,Фельдкирх,פלדקירך', 47.2330600, 9.6000000, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3397, 'Feldbach', 'Feldbach', 'Fel''dbakh,Feldbach,Фельдбах', 46.9530600, 15.8883300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3398, 'Feld am See', 'Feld am See', 'Fel''d-am-Ze,Fel''d-am-Zee,Feld,Feld am See,bin hu fei er de,Фельд-ам-Зе,Фельд-ам-Зее,滨湖费尔德', 46.7763900, 13.7477800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3399, 'Feistritz ob Bleiburg', 'Feistritz ob Bleiburg', 'Bistrica nad Pliberkom,Feistritz,Feistritz ob Bleiburg,Feistritz ober Bleiburg', 46.5500000, 14.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3400, 'Feistritz im Rosental', 'Feistritz im Rosental', 'Fajshtric,Feistritz,Feistritz im Rosental,Feistritz im Rosenthale,Файштриц', 46.5166700, 14.1666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3401, 'Feistritz bei Knittelfeld', 'Feistritz bei Knittelfeld', 'Feistritz,Feistritz bei Knittelfeld', 47.2680200, 14.8933400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3402, 'Feistritz an der Gail', 'Feistritz an der Gail', 'Bistrica na Zilji,Fajshtric-an-der-Gajl,Fajstric na Gajl,Fajstric-an-der-Gajl'',Feistris,Feistritz,Feistritz an der Gail,gai er he pan fa yi shi te li ci,Файстриц-ан-дер-Гайль,Файштріц-ан-дер-Ґайл,Фајстриц на Гајл,盖尔河畔法伊施特里茨', 46.5775000, 13.6066700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3403, 'Feistritz am Wechsel', 'Feistritz am Wechsel', 'Feistritz,Feistritz am Wechsel', 47.6000000, 16.0500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3404, 'Fehring', 'Fehring', 'Fehring,Fering,fei ling,Феринг,费灵', 46.9400000, 16.0080600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3405, 'Fallbach', 'Fallbach', '', 48.6500000, 16.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3406, 'Falkenstein', 'Falkenstein', 'Fal''kenshtajn,fa er ken shi tai yin,Фалькенштайн,فالکینسٹین، لوئر وسٹریا,法尔肯施泰因', 48.7166700, 16.5833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3407, 'St. Ruprecht-Falkendorf', 'St. Ruprecht-Falkendorf', '', 47.1011000, 14.0175200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3408, 'Faistenau', 'Faistenau', 'Fajshtenau,Fajstenau,Foastnau,fa yi shi te nao,Файстенау,Файштенау,فیسٹینو,法伊施特瑙', 47.7776700, 13.2339300, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3409, 'Euratsfeld', 'Euratsfeld', '', 48.0818100, 14.9315400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3410, 'Eugendorf', 'Eugendorf', 'Eingdorf,Ojgendorf,ao yi gen duo fu,Ойгендорф,奥伊根多夫', 47.8666700, 13.1166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3411, 'Eschenau', 'Eschenau', '', 48.0482500, 15.5669400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3412, 'Ernstbrunn', 'Ernstbrunn', 'Ehrnstbrun,Ehrnstbrunn,ai en shi te bu lun,Эрнстбрун,Эрнстбрунн,埃恩施特布伦', 48.5333300, 16.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3413, 'Erlauf', 'Erlauf', '', 48.1833300, 15.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3414, 'Bad Erlach', 'Bad Erlach', 'Ehrlakh,Erlach,ba te ai la he,Эрлах,巴特埃拉赫', 47.7272200, 16.2144400, 'AT', '2013-11-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3415, 'Erl', 'Erl', 'Erl', 47.6833300, 12.1833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3416, 'Enzersfeld', 'Enzersfeld', '', 48.3633800, 16.4238700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3417, 'Enzersdorf an der Fischa', 'Enzersdorf an der Fischa', 'Ehncersdorf-an-der-Fisha,Enzersdorf,Enzersdorf an der Fischa,Энцерсдорф-ан-дер-Фиша', 48.0850200, 16.6083200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3418, 'Enzenreith', 'Enzenreith', '', 47.6683900, 15.9524900, 'AT', '2017-06-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3419, 'Ennsdorf', 'Ennsdorf', '', 48.2118100, 14.5029000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3420, 'Enns', 'Enns', 'Enns  Niederoesterreich,Enns  Niederösterreich', 48.2134600, 14.4761200, 'AT', '2017-07-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3421, 'Engerwitzdorf', 'Engerwitzdorf', 'Ehngervicdorf,en ge er wei ci duo fu,Энгервицдорф,恩格尔维茨多夫', 48.3450700, 14.4420400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3422, 'Engelhartstetten', 'Engelhartstetten', 'Ehngel''khartshtetten,en ge er ha qi te teng,Энгельхартштеттен,恩格尔哈奇特滕', 48.1816000, 16.8836700, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3423, 'Empersdorf', 'Empersdorf', 'Empersdorf', 46.9833300, 15.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3424, 'Emmersdorf an der Donau', 'Emmersdorf an der Donau', 'Ehmmersdorf-an-der-Donau,Emmersdorf,Emmersdorf an der Donau,Khofamt,duo nao he pan ai mo si duo fu,Хофамт,Эммерсдорф-ан-дер-Донау,多瑙河畔埃默斯多夫', 48.2414000, 15.3372100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3425, 'Eltendorf', 'Eltendorf', '', 47.0087000, 16.2023900, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3426, 'Elsbethen', 'Elsbethen', 'Ehl''sbeten,El''sbeten,OEsbethen,ai er si bei teng,Ösbethen,Ельсбетен,Эльсбетен,埃爾斯貝滕', 47.7500000, 13.0833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3427, 'Elmen', 'Elmen', 'Ehl''men,El''men,Elmen,ai er men,Ельмен,Эльмен,埃尔门', 47.3403900, 10.5431800, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3428, 'Ellmau', 'Ellmau', 'Ehl''mau,Ell''mau,ai er mao,aylmaw,Елльмау,Эльмау,ایلماؤ,埃尔毛', 47.5137800, 12.2993700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3429, 'Elixhausen', 'Elixhausen', '', 47.8666700, 13.0666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3430, 'Elbigenalp', 'Elbigenalp', 'Ehl''bigenal''p,El''bigenal''p,Elbigenalp,ai er bi ge na er pu,aylbygnalp,Ельбігенальп,Эльбигенальп,ایلبیگنالپ,埃尔比格纳尔普', 47.2904100, 10.4360700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3431, 'Eisgarn', 'Eisgarn', 'Ajsgarn,Klajnradishen,ai si jia en,Айсгарн,Клайнрадишен,艾斯加恩', 48.9167500, 15.1032000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3432, 'Eisenstadt', 'Eisenstadt', 'Aizenstat,Ajzenshhat,Ajzenshtadt,Ajzenshtat,Ayzenstad,Eisenstadt,Eisnstod,Eizenstatas,Eizenstate,Eizenštatas,Eizenštate,Ferreum Castrum,Gorad Ajzenshtat,Kismarton,Stadt Eisenstadt,Zelezno,Zeljezno,ai sen si ta te,aijensyutateu,aizenshutatto,ayajhenastada,Železno,Željezno,Άιζενστατ,Айзенштадт,Айзенщат,Ајзенштат,Горад Айзенштат,Այզենշտադ,אייזנשטט,آیزنشٹڈ,آیزن‌اشتات,आयझेनश्टाड,აიზენშტადტი,アイゼンシュタット,艾森斯塔特,아이젠슈타트', 47.8456500, 16.5232700, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3433, 'Bad Eisenkappel', 'Bad Eisenkappel', 'Bad Ajzenkappel'',Eisenkappel,Бад Айзенкаппель', 46.4884100, 14.5913900, 'AT', '2014-07-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3434, 'Eisenerz', 'Eisenerz', 'Eisenerz', 47.5333300, 14.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3435, 'Eisbach', 'Eisbach', 'Eisbach', 47.1166700, 15.2666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3436, 'Eidenberg', 'Eidenberg', '', 48.3943900, 14.2331300, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3437, 'Eichgraben', 'Eichgraben', 'Ajkhgraben,ai xi ge la ben,Айхграбен,艾希格拉本', 48.1720400, 15.9839100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3438, 'Eichfeld', 'Eichfeld', 'Eichfeld,Unterrakitsch', 46.7252800, 15.7680600, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3439, 'Eichenberg', 'Eichenberg', '', 47.5333300, 9.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3440, 'Eichberg', 'Eichberg', '', 47.3818800, 15.9735600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3441, 'Eibiswald', 'Eibiswald', 'Ajbisval''d,Ivnik,ai bi si wa er de,Айбисвальд,艾比斯瓦尔德', 46.6866700, 15.2472200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3442, 'Ehrenhausen', 'Ehrenhausen', 'Ehrenhausen', 46.7241700, 15.5866700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3443, 'Ehenbichl', 'Ehenbichl', 'Ehenbichl', 47.4666700, 10.7000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3444, 'Eggersdorf bei Graz', 'Eggersdorf bei Graz', 'Eggersdorf,Eggersdorf bei Graz,Ehggersdorf-Grac,Ehggersdorf-baj-Grac,ge la ci fu jin ai ge er si duo fu,Эггерсдорф-Грац,Эггерсдорф-бай-Грац,格拉茨附近埃格尔斯多夫', 47.1233800, 15.6008400, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3445, 'Eggern', 'Eggern', '', 48.9082900, 15.1487700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3446, 'Eggenburg', 'Eggenburg', 'Eggenburg,Ehggenburg,ai gen bao,Эггенбург,埃根堡', 48.6389200, 15.8190300, 'AT', '2011-09-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3447, 'Egg', 'Egg', 'Egg,Ehgg,ai ge,Егг,Эгг,埃格', 47.4315400, 9.8976200, 'AT', '2014-10-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3448, 'Edt bei Lambach', 'Edt bei Lambach', 'Edt,Edt bei Lambach', 48.1166700, 13.8833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3449, 'Edlitz', 'Edlitz', '', 47.5979700, 16.1405200, 'AT', '2017-06-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3450, 'Edelstal', 'Edelstal', 'Ehdel''stal'',Nemesvoelgy,Nemesvölgy,Эдельсталь', 48.1000000, 16.9833300, 'AT', '2013-05-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3451, 'Edelsgrub', 'Edelsgrub', 'Edelsgrub', 47.0333300, 15.6000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3452, 'Edelschrott', 'Edelschrott', 'Edelschrott,Ehdel''shrot,ai de er shi luo te,Эдельшрот,埃德尔施罗特', 47.0215600, 15.0526600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3453, 'Edelsbach bei Feldbach', 'Edelsbach bei Feldbach', 'Edelsbach,Edelsbach bei Feldbach', 46.9894400, 15.8369400, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3454, 'Eckartsau', 'Eckartsau', '', 48.1450700, 16.7973700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3455, 'Echsenbach', 'Echsenbach', '', 48.7166700, 15.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3456, 'Ebreichsdorf', 'Ebreichsdorf', 'Ebrajkhsdorf,Ehbrajkhsdorf,ai bu lai xi si duo fu,Ебрайхсдорф,Эбрайхсдорф,埃布賴希斯多夫', 47.9557900, 16.4070500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3457, 'Eberstein', 'Eberstein', 'Ebershtajn,Ehbershtajn,ai bo er shi tai yin,Еберштайн,Эберштайн,埃伯尔施泰因', 46.8080600, 14.5600000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3458, 'Ebersdorf', 'Ebersdorf', '', 47.1985200, 15.9621900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3459, 'Eberndorf', 'Eberndorf', 'Dobrla vas,Eberndorf,Ehberndorf,ai bo en duo fu,Еберндорф,Эберндорф,埃伯恩多夫', 46.5913900, 14.6436100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3460, 'Ebergassing', 'Ebergassing', '', 48.0456700, 16.5170900, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3461, 'Eberau', 'Eberau', 'Eberau,Eberava,Ehberau,Monyorokerek,Monyorókerék,ai bo lao,Эберау,埃伯劳', 47.1076400, 16.4604400, 'AT', '2013-04-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3462, 'Ebenthal', 'Ebenthal', '', 48.4333300, 16.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3463, 'Ebenthal', 'Ebenthal', 'Ebenthal', 46.6080600, 14.3641700, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3464, 'Ebensee', 'Ebensee', 'Ebensee,Ebenzee,Ehbenze,Ehbenzee,Emsee,ai ben sai,Ебензее,Эбензе,Эбензее,埃本塞', 47.8071600, 13.7790000, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3465, 'Eben im Pongau', 'Eben im Pongau', 'Eben,Eben im Pongau', 47.4000000, 13.4000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3466, 'Ebenfurth', 'Ebenfurth', 'Ebenfurt', 47.8773800, 16.3673100, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3467, 'Ebenau', 'Ebenau', '', 47.7907300, 13.1752700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3468, 'Eben am Achensee', 'Eben am Achensee', 'Eben,Eben am Achensee,Eben-am-Akhenze,Ehben-am-Akhenze,Ehben-am-Akhenzee,a heng hu pan ai ben,Ебен-ам-Ахензе,Эбен-ам-Ахензе,Эбен-ам-Ахензее,阿亨湖畔埃本', 47.4138000, 11.7613800, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3469, 'Ebbs', 'Ebbs', 'Ebbs,Ebs,Ehbbs,ai bu si,Еббс,Ебс,Эббс,埃布斯', 47.6333300, 12.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3470, 'Dürnstein in der Steiermark', 'Duernstein in der Steiermark', 'Durnstein,Durnstein in Steiermark,Durnstein in der Steiermark,Dürnstein,Dürnstein in Steiermark,Dürnstein in der Steiermark', 46.9883300, 14.3916700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3471, 'Dürnstein', 'Duernstein', 'Djurnshtajn,Durnstein,Dürnstein,Дюрнштайн', 48.3958200, 15.5197300, 'AT', '2016-01-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3472, 'Dürnkrut', 'Durnkrut', '', 48.4731500, 16.8506200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3473, 'Düns', 'Duns', '', 47.2235300, 9.7166300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3474, 'Droß', 'Dross', 'Dross', 48.4639300, 15.5756100, 'AT', '2015-12-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3475, 'Drösing', 'Drosing', 'Droesing', 48.5390000, 16.9026400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3476, 'Drasenhofen', 'Drasenhofen', '', 48.7500000, 16.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3477, 'Dornbirn', 'Dornbirn', 'Dornbirn,Dornbirnas,Gorad Dornbirn,HOH,Ntornmpirn,doleunbileun,dornbirni,dorunbirun,duo en bi en,dwrnbyrn,Ντόρνμπιρν,Горад Дорнбірн,Дорнбирн,Дорнбірн,דורנבירן,درن‌بیرن,دورنبيرن,ڈارنبرن,ڈورنبیرن,დორნბირნი,ドルンビルン,多恩比恩,도른비른', 47.4142700, 9.7419500, 'AT', '2013-05-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3478, 'Dorfstetten', 'Dorfstetten', '', 48.3257300, 14.9821800, 'AT', '2011-09-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3479, 'Dorfgastein', 'Dorfgastein', '', 47.2417200, 13.1022300, 'AT', '2012-07-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3480, 'Dorfbeuern', 'Dorfbeuern', '', 48.0166700, 13.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3481, 'Doren', 'Doren', '', 47.4927800, 9.8797200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3482, 'Donnerskirchen', 'Donnerskirchen', 'Bijela Crikva,Fertofeheregyhaza,Fertőfehéregyháza', 47.8942500, 16.6463500, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3483, 'Donnersbach', 'Donnersbach', 'Donnersbach,Donnersbach Au', 47.4613900, 14.1297200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3484, 'Dölsach', 'Dolsach', 'Dolsach,Dölsach', 46.8283300, 12.8452800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3485, 'Dobersberg', 'Dobersberg', 'Dobasbeag,Dobersberg,Klajnkharmans,duo bo er si bei ge,Доберсберг,Клайнхарманс,多伯尔斯贝格', 48.9151000, 15.3218800, 'AT', '2016-09-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3486, 'Diex', 'Diex', '', 46.7500000, 14.6000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3487, 'Dietersdorf am Gnasbach', 'Dietersdorf am Gnasbach', 'Dietersdorf,Dietersdorf am Gnasbach', 46.8091700, 15.8116700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3488, 'Dienten am Hochkönig', 'Dienten am Hochkonig', '', 47.3832400, 13.0036900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3489, 'Dienersdorf', 'Dienersdorf', 'Dienersdorf', 47.2397900, 15.9014200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3490, 'Deutsch-Wagram', 'Deutsch-Wagram', 'Deutsch-Wagram,Dojch-Vagram,Gorad Dojch-Vagram,Vahram,Vəqram,de yi zhi wa ge la mu,Горад Дойч-Ваграм,Дойч-Ваграм,Վահրամ,德意志瓦格拉姆', 48.2997200, 16.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3491, 'Deutschlandsberg', 'Deutschlandsberg', 'Deutschlandberg,Deutschlandsberg,Dojchlandsberg,Lonc,Lonč,de yi zhi lan ci bei ge,doichillancheubeleukeu,doichurantsuberuku,Дойчландсберг,Дојчландсберг,ドイチュランツベルク,德意志兰茨贝格,도이칠란츠베르크', 46.8152800, 15.2222200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3492, 'Deutschkreutz', 'Deutschkreutz', 'Deutschkreutz,Dojchkrojc,Sopronkeresztur,Sopronkeresztúr,Дойчкройц', 47.6000000, 16.6333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3493, 'Deutsch Kaltenbrunn', 'Deutsch Kaltenbrunn', 'Deutsch Kaltenbrunn,Dojch-Kal''tenbrun,Kaltenbrunn,Дойч-Кальтенбрун', 47.0945500, 16.1314500, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3494, 'Deutsch Jahrndorf', 'Deutsch Jahrndorf', '', 48.0166700, 17.1000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3495, 'Deutsch Goritz', 'Deutsch Goritz', 'Deutsch Goritz', 46.7508300, 15.8294400, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3496, 'Deutschfeistritz', 'Deutschfeistritz', 'Deutschfeistritz,Dojchfajshtric,Dojchfajstric,de yi zhi fa yi shi te li ci,Дойчфайстриц,Дойчфайштриц,德意志法伊施特里茨', 47.1985200, 15.3362300, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3497, 'Desselbrunn', 'Desselbrunn', 'Desselbrunn', 48.0214500, 13.7702700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3498, 'Dellach im Drautal', 'Dellach im Drautal', 'Dellach,Dellach im Drautal,Dellach im Drautale,Dellakh,Dellakh-im-Drautal'',de lao shan gu de la he,Деллах,Деллах-им-Драуталь,Деллах-ім-Драуталь,德劳山谷德拉赫', 46.7375000, 13.0783300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3499, 'Dellach', 'Dellach', 'Dellach,Dellach im Gailtale', 46.6617500, 13.0796500, 'AT', '2012-12-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3500, 'Dechantskirchen', 'Dechantskirchen', 'Dechantskirchen', 47.4166700, 16.0166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3501, 'Dalaas', 'Dalaas', '', 47.1244600, 9.9910400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3502, 'Bürs', 'Buers', 'Bjurs,bi er si,Бюрс,比尔斯', 47.1497200, 9.8000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3503, 'Burgau', 'Burgau', '', 47.1426800, 16.0964300, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3504, 'Buchkirchen', 'Buchkirchen', 'Buchkirchen,Bukhkirkhen,Бухкирхен', 48.2242700, 14.0224200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3505, 'Buch bei Jenbach', 'Buch bei Jenbach', 'Buch,Buch bei Jenbach,Buch in Tirol,Bukh (Jenbakh),Бух (Йенбах)', 47.3744700, 11.7540000, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3506, 'Buchbach', 'Buchbach', '', 47.6964800, 15.9842500, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3507, 'Brunn an der Wild', 'Brunn an der Wild', 'Brunn', 48.6942500, 15.5200800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3508, 'Brunn am Gebirge', 'Brunn am Gebirge', 'Brun am Gebirge,Brun-am-Gebirge,Brunn,Brunn-am-Gebirge,brwn am gbyrgh,shan lu bu lun,Брун ам Гебирге,Брун-ам-Гебирге,Брунн-ам-Гебирге,برون ام گبیرگه,山麓布倫', 48.1069700, 16.2846600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3509, 'Bruckneudorf', 'Bruckneudorf', 'Bruckneudorf,Bruknojdorf,Kiralyhida,Királyhida,Брукнойдорф', 48.0166700, 16.7833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3510, 'Brückl', 'Bruckl', 'Brjukl'',Mostic,Mostič,bu lu ke er,Брюкль,布吕克尔', 46.7516700, 14.5366700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3511, 'Bruck an der Mur', 'Bruck an der Mur', 'Bruck,Bruck an da Mur,Bruck an der Mur,Bruk an der Mur,Bruk na Muri,Bruk-an-der-Mur,Brukk-an-der-Mur,beulukeuandeeomuleu,brwk an dr mwr,mu er he pan bu lu ke,Брук ан дер Мур,Брук на Мури,Брук-ан-дер-Мур,Брукк-ан-дер-Мур,بروک آن در مور,ბრუკ-ან-დერ-მური,ブルック・アン・デア・ムーア,穆爾河畔布魯克,브루크안데어무르', 47.4166700, 15.2833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3512, 'Bruck an der Leitha', 'Bruck an der Leitha', 'Bruck,Bruck an der Leitha,Bruck-Leitha,Bruk na Lajti,Bruk-an-der-Lajta,Brukk-an-der-Lajta,lai ta he pan bu lu ke,Брук на Лајти,Брук-ан-дер-Лайта,Брукк-ан-дер-Лайта,萊塔河畔布魯克', 48.0166700, 16.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3513, 'Bruck an der Großglocknerstraße', 'Bruck an der Grossglocknerstrasse', 'Bruck,Bruck an der Glocknerstrasse,Bruck an der Grossglocknerstrasse,Bruk-am-der-Grosgloknershtrase,Bruk-an-der-Grosgloknershtrasse,Brukk-an-der-Grosglokknershtrase,da ge luo ke nei si te la se de qu bu lu ke,Брук-ам-дер-Гросглокнерштрасе,Брук-ан-дер-Гросглокнерштрассе,Брукк-ан-дер-Гросглоккнерштрасе,大格洛克内斯特拉瑟地区布鲁克', 47.2849400, 12.8231000, 'AT', '2013-11-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3514, 'Bruck am Ziller', 'Bruck am Ziller', 'Bruck,Bruck am Ziller', 47.3899800, 11.8512400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3515, 'Bromberg', 'Bromberg', '', 47.6653900, 16.2099000, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3516, 'Brixlegg', 'Brixlegg', 'Briksleg,Brikslegg,bu li ke si lai ge,Брикслег,Брикслегг,布里克斯莱格', 47.4294200, 11.8779400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3517, 'Brixen im Thale', 'Brixen im Thale', 'Briksen-im-Tale,Brixen,Brixen im Tal,Brixen im Tale,Brixen im Thale,ta lei de qu bu li shen,Бриксен-им-Тале,Бріксен-ім-Тале,塔勒地区布里申', 47.4500000, 12.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3518, 'Bretstein', 'Bretstein', 'Bretstein,Bretsteingassen,Brettstein,Gassner', 47.3333300, 14.4166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3519, 'Breitenwang', 'Breitenwang', 'Breitenwang', 47.4833300, 10.7333300, 'AT', '2012-09-10', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3520, 'Breitenfurt bei Wien', 'Breitenfurt bei Wien', 'Brajtenfurt-Vin,Brajtenfurt-baj-Vin,Breitenfurt,Breitenfurt bei Wien,Breitenfurth,wei ye na fu jin bu lai teng fu te,Брайтенфурт-Вин,Брайтенфурт-бай-Вин,維也納附近布賴滕富特', 48.1333300, 16.1500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3521, 'Breitenfeld an der Rittschein', 'Breitenfeld an der Rittschein', 'Breitenfeld,Breitenfeld an der Rittschein', 47.0333300, 15.9500000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3522, 'Breitenfeld am Tannenriegel', 'Breitenfeld am Tannenriegel', 'Breitenfeld,Breitenfeld am Tannenriegel', 46.8500000, 15.6333300, 'AT', '2017-06-18', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3523, 'Breitenbrunn', 'Breitenbrunn', 'Fertoszeleskut,Fertőszéleskút,Patipron', 47.9445200, 16.7314900, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3524, 'Breitenbach am Inn', 'Breitenbach am Inn', 'Brajtenbakh-am-Inn,Breitenbach,Breitenbach am Inn,Брайтенбах-ам-Инн', 47.4782900, 11.9737200, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3525, 'Breitenau', 'Breitenau', '', 47.7335500, 16.1433800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3526, 'Bregenz', 'Bregenz', 'Bregenc,Bregenca,Bregencas,Bregence,Bregencja,Bregenz,Brenkentz,Brigantium,Brégence,Brēgenca,Brėgencas,Gorad Brehgenc,XGZ,ber ken s,beulegencheu,bregenjha,bregentsi,brgnts,brgnz,bryghnz,brygnz,bu lei gen ci,buregentsu,Μπρέγκεντζ,Брегенц,Горад Брэгенц,Բրեգենց,ברגנץ,بريغنز,برگنتس,برگنز,بریگنز,ब्रेगेन्झ,เบรเกนซ์,ბრეგენცი,ብሬገንጽ,ブレゲンツ,布雷根茨,브레겐츠', 47.5031100, 9.7471000, 'AT', '2014-07-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3527, 'Braunau am Inn', 'Braunau am Inn', 'Braunau,Braunau Inni aeaeres,Braunau Inni ääres,Braunau am Inn,Braunau na In,Braunau na Innu,Braunau na Inu,Braunau prie Ino,Braunau-am-Inn,Braunau-na-Inni,Braunava pie Innas,Braunavia,be ra nea xam xinn,beulaunauam-in,branayw am ayn,brawnaw am an,inis braunau,yin he pan bu lao nao,Браунау на Ин,Браунау на Ину,Браунау-ам-Инн,Браунау-на-Інні,בראונאו אם אין,בראונאו-אם אין,برانائو ام این,براوناو آم إن,เบราเนาอัมอินน์,ინის ბრაუნაუ,ブラウナウ・アム・イン,因河畔布劳瑙,브라우나우암인', 48.2562800, 13.0434300, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3528, 'Brandenberg', 'Brandenberg', 'Brandenberg', 47.4905300, 11.8945900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3529, 'Bramberg am Wildkogel', 'Bramberg am Wildkogel', 'Bramberg,Bramberg am Wildkogel,Bramberg am Wuedkogl,Bramberg am Wüdkogl,Bramberg-am-Vil''dkogel'',Bramer-am-Vil''dkogel'',wei er de ke ge er shan lu bu lan bei ge,Брамберг-ам-Вильдкогель,Брамберг-ам-Вільдкогель,Брамер-ам-Вильдкогель,维尔德科格尔山麓布兰贝格', 47.2697900, 12.3385000, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3530, 'Böheimkirchen', 'Boheimkirchen', '', 48.1977900, 15.7617800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3531, 'Bocksdorf', 'Bocksdorf', '', 47.1425600, 16.1778400, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3532, 'Bockfließ', 'Bockfliess', 'Bockfliess,Bockfließ,Bockfluss,Bockflüss', 48.3600000, 16.6038900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3533, 'Bad Blumau', 'Bad Blumau', 'Bad-Blumau,Blumau,ba te bu lu mao,Бад-Блумау,巴特布卢毛', 47.1166700, 16.0500000, 'AT', '2014-04-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3534, 'Bludesch', 'Bludesch', 'Bludesh,blwdsh,bu lu de shi,Блудеш,بلودش,布卢德施', 47.2000000, 9.7330600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3535, 'Bludenz', 'Bludenz', 'Bludenc,Bludenz,bludentsi,blwdnts,blwdnz,bu lu deng ci,Блуденц,בלודנץ,بلودنتس,ბლუდენცი,布盧登茨', 47.1547600, 9.8225500, 'AT', '2013-02-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3536, 'Blons', 'Blons', '', 47.2232700, 9.8341400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3537, 'Blindenmarkt', 'Blindenmarkt', '', 48.1274900, 14.9864700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3538, 'Bleiburg/Pliberk', 'Bleiburg/Pliberk', 'Blajburg,Bleiburg,Blelburg,Pliberk,Блайбург,Блајбург', 46.5900000, 14.7988900, 'AT', '2014-07-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3539, 'Blaindorf', 'Blaindorf', 'Blaindorf,Blajndorf,Блайндорф', 47.1749800, 15.8679500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3540, 'Bizau', 'Bizau', '', 47.3690600, 9.9283900, 'AT', '2014-08-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3541, 'Bischofstetten', 'Bischofstetten', '', 48.1222200, 15.4690900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3542, 'Bischofshofen', 'Bischofshofen', 'Behofn,Bischofhofen,Bischofshofen,Bischofshogen,Bishofsgofen,Bishofskhofen,bi shao fu si huo fen,bishofusuhofen,bisyopeusyopen,Бишофсхофен,Бішофсгофен,بیشوفس‌هوفن,ビショフスホーフェン,比紹夫斯霍芬,비쇼프쇼펜', 47.4166700, 13.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3543, 'Bisamberg', 'Bisamberg', 'Bizamberg,bi sang bei ge,Бизамберг,比桑贝格', 48.3333300, 16.3500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3544, 'Birkfeld', 'Birkfeld', 'Birkfel''d,Birkfeld,bi ke fei er de,Биркфельд,比克费尔德', 47.3500000, 15.6833300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3545, 'Birgitz', 'Birgitz', '', 47.2353600, 11.2992200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3546, 'Bildstein', 'Bildstein', '', 47.4500000, 9.7666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3547, 'Bierbaum am Auersbach', 'Bierbaum am Auersbach', 'Bierbaum,Bierbaum am Auersbach', 46.8294900, 15.7923700, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3548, 'Biedermannsdorf', 'Biedermannsdorf', '', 48.0839300, 16.3454200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3549, 'Bichlbach', 'Bichlbach', 'Bichlbach', 47.4203300, 10.7904200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3550, 'Biberwier', 'Biberwier', 'Biberwiehr,Biberwier', 47.3833300, 10.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3551, 'Biberbach', 'Biberbach', '', 48.0300600, 14.7079500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3552, 'Bezau', 'Bezau', 'Becau,Bezau,bei cao,Бецау,贝曹', 47.3847800, 9.9013900, 'AT', '2014-10-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3553, 'Berwang', 'Berwang', 'Berwang', 47.4080700, 10.7473500, 'AT', '2011-10-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3554, 'Bernstein', 'Bernstein', 'Bernshtajn,Bernstein,Borostyanko,Borostyánko,Бернштайн', 47.4000000, 16.2500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3555, 'Bernhardsthal', 'Bernhardsthal', 'Bernkhardstal'',Pernital,Pernitál,bei en ha de si ta er,Бернхардсталь,贝恩哈德斯塔尔', 48.6915800, 16.8695100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3556, 'Berndorf bei Salzburg', 'Berndorf bei Salzburg', 'Berndorf,Berndorf bei Salzburg', 47.9953200, 13.0614600, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3557, 'Berndorf', 'Berndorf', '', 47.9456700, 16.1097300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3558, 'Bergheim', 'Bergheim', '', 47.8333300, 13.0333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3559, 'Berg', 'Berg', 'Berg,Берг', 48.1014700, 17.0384200, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3560, 'Behamberg', 'Behamberg', '', 48.0166700, 14.4833300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3561, 'Baumkirchen', 'Baumkirchen', '', 47.3000000, 11.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3562, 'Baumgarten bei Gnas', 'Baumgarten bei Gnas', 'Baumgarten,Baumgarten bei Gnas', 46.9166700, 15.7666700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3563, 'Bartholomäberg', 'Bartholomaberg', 'Bartholomaberg,Bartholomäberg,Bartolomeberg,ba tuo luo mei bei ge,Бартоломеберг,巴托洛梅贝格', 47.0833300, 9.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3564, 'Bärnkopf', 'Barnkopf', '', 48.3904600, 15.0047900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3565, 'Bärnbach', 'Barnbach', '', 47.0333300, 15.8500000, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3566, 'Baldramsdorf', 'Baldramsdorf', '', 46.8011100, 13.4533300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3567, 'Bairisch Kölldorf', 'Bairisch Koelldorf', 'Bairisch Kolldorf,Bairisch Kölldorf', 46.8666700, 15.9333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3568, 'Bad Wimsbach-Neydharting', 'Bad Wimsbach-Neydharting', 'Bad Neidharting,Bad Wimsbach-Neydharting,Bad-Vimsbakh-Najdkharting,Neidharting,Neydharting,Wimsbach,Wunsbach,Бад-Вимсбах-Найдхартинг', 48.0666700, 13.9000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3569, 'Bad Vöslau', 'Bad Voslau', 'Bad Fezlau,Bad-Fjoslau,Bad-Vjoslau,Voslau,Vöslau,ba te fu si lao,bad fwslayw,bad-peslau,Бад Фезлау,Бад-Вёслау,Бад-Фёслау,باد فوسلائو,ბად-ფესლაუ,巴特弗斯勞', 47.9653300, 16.2135900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3570, 'Bad Tatzmannsdorf', 'Bad Tatzmannsdorf', 'Bad Tatzmannsdorf,Bad-Tacmansdorf,Tarcsafuerdo,Tarcsafürdő,Бад-Тацмансдорф', 47.3312600, 16.2306700, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3571, 'Bad Schönau', 'Bad Schonau', 'Bad Schonau,Bad Schönau,Schonau,Schonau im Gebirge,Schönau,Schönau im Gebirge', 47.4947300, 16.2341000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3572, 'Bad Schallerbach', 'Bad Schallerbach', 'Bad Schallerbach,Bad-Shallerbakh,Schallerbach,ba te sha lei ba he,Бад-Шаллербах,巴特沙勒巴赫', 48.2299900, 13.9192500, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3573, 'Bad Sankt Leonhard im Lavanttal', 'Bad Sankt Leonhard im Lavanttal', 'Bad Sankt Leonhard,Bad Sankt Leonhard im Lavanttal,Bad Sankt Leonhard im Lavanttale,Bad-Sankt-Leonard-im-Lavanttal'',Bad-Sankt-Leonkhard,Bad-Sankt-Leonkhard-im-Lafanttal'',Bad-Zankt-Leongard-im-Lavanttal'',Sankt Leonhard,la wan te he gu ba te sheng lai ang ha de,Бад-Занкт-Леонгард-ім-Лавантталь,Бад-Санкт-Леонард-им-Лавантталь,Бад-Санкт-Леонхард,Бад-Санкт-Леонхард-им-Лафантталь,拉万特河谷巴特圣莱昂哈德', 46.9627800, 14.7916700, 'AT', '2014-05-01', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3574, 'Bad Ischl', 'Bad Ischl', 'Bad Ischl,Bad Ishl,Bad Ishul,Bad Islis,Bad Išlis,Bad-Ishl'',Bod Ischl,Ischi,Ischl,ba de yi she,bad ayshl,bad-ishli,bateu-isyul,Бад Ишл,Бад Ишъл,Бад-Ішль,Бад-Ишль,באד אישל,باد ایشل,ბად-იშლი,バート・イシュル,巴德伊舍,바트이슐', 47.7110900, 13.6189300, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3575, 'Bad Hofgastein', 'Bad Hofgastein', 'Bad Hofgastein,Bad Khofgashhajn,Bad-Gofgashtajn,Bad-Khofgashtajn,Bad-Khofgastajn,Hofgastein,Hofgoschdei,ba te huo fu jia shi tai yin,Бад Хофгащайн,Бад-Гофгаштайн,Бад-Хофгастайн,Бад-Хофгаштайн,באד הופגאסטיין,巴特霍夫加施泰因', 47.1727400, 13.0987100, 'AT', '2012-07-02', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3576, 'Bad Hall', 'Bad Hall', 'Bad Hall,Bad-Khall'',Bod Hoi,ba te ha er,Бад-Халль,巴特哈尔', 48.0383200, 14.2077300, 'AT', '2011-07-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3577, 'Bad Goisern', 'Bad Goisern', 'Bad Goisern am Hallstaettersee,Bad Goisern am Hallstättersee,Bad-Gojzern,Bod Goisan,Goisern,ba te ge yi se en,Бад-Гойзерн,巴特戈伊瑟恩', 47.6425200, 13.6160900, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3578, 'Bad Gleichenberg', 'Bad Gleichenberg', 'Bad Glajkhenberg,Bad Gleichenberg,Bad-Glajkhenberg,Gleichenberg,ba te ge lai xing bei ge,Бад Глайхенберг,Бад-Глайхенберг,巴特格莱兴贝格', 46.8755600, 15.9086100, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3579, 'Bad Gastein', 'Bad Gastein', 'Bad-Gashtajn,Gastein,Бад-Гаштайн', 47.1154700, 13.1346700, 'AT', '2013-01-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3580, 'Badersdorf', 'Badersdorf', '', 47.2000000, 16.3666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3581, 'Baden', 'Baden', 'Baden,Baden bei Wien,Badenas,Badene pie Vines,Bādene pie Vīnes,badenbaibin,badeni,baden・bai・u~in,badn nzdyk bh wyn,wei ye na ba deng,Баден,באדן,بادن نزدیک به وین,ბადენი,バーデン・バイ・ウィーン,維也納巴登,바덴바이빈', 48.0054300, 16.2326400, 'AT', '2011-09-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3582, 'Bad Deutsch-Altenburg', 'Bad Deutsch-Altenburg', 'Bad-Dojch-Al''tenburg,Deutsch Altenburg,Бад-Дойч-Альтенбург,巴特多伊奇—阿尔滕堡', 48.1342500, 16.9062400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3583, 'Bad Aussee', 'Bad Aussee', 'Bad-Ausze,Bod Aussee,ba te ao sai,Бад-Аусзе,巴特奧塞', 47.6099800, 13.7824300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3584, 'Bachmanning', 'Bachmanning', 'Bachmaning,Bachmanning', 48.1310400, 13.7943600, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3585, 'Axams', 'Axams', 'Aksams,a ke sa mu si,aksamz,Аксамс,اکسامز,阿克萨姆斯', 47.2311100, 11.2789200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3586, 'Außervillgraten', 'Ausservillgraten', 'Auserfil''graten,Auserfill''graten,Ausserfil''graten,Ausserviligraten,Ausservillgraten,Außervillgraten,wai fei er ge la teng,Аусерфильгратен,Аусерфілльгратен,Ауссерфильгратен,外菲尔格拉滕', 46.7875000, 12.4313900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3587, 'Aurach am Hongar', 'Aurach am Hongar', 'Aurach,Aurach am Hongar', 47.9518200, 13.6729100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3588, 'Auersthal', 'Auersthal', '', 48.3737300, 16.6359600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3589, 'Auersbach', 'Auersbach', '', 47.0166700, 15.8666700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3590, 'Au am Leithaberge', 'Au am Leithaberge', 'Au,Au am Leithaberge,Au am Leithagebirge', 47.9229600, 16.5579400, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3591, 'Au', 'Au', '', 47.3217600, 9.9806700, 'AT', '2014-10-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3592, 'Atzesberg', 'Atzesberg', '', 48.5395900, 13.8693600, 'AT', '2017-05-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3593, 'Atzenbrugg', 'Atzenbrugg', '', 48.2911900, 15.9061400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3594, 'Atzbach', 'Atzbach', 'Atzbach', 48.0836400, 13.7034700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3595, 'Attersee', 'Attersee', 'Attersee', 47.9164600, 13.5395300, 'AT', '2011-09-07', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3596, 'Attendorf', 'Attendorf', '', 47.0042600, 15.3389700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3597, 'Asten', 'Asten', '', 48.2194100, 14.4178400, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3598, 'Asperhofen', 'Asperhofen', '', 48.2458300, 15.9260600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3599, 'Asparn an der Zaya', 'Asparn an der Zaya', 'Asparn,Asparn an der Zaya,Asparn-an-der-Cajja,cha yi ya he pan a si pa en,Аспарн-ан-дер-Цайя,察伊亚河畔阿斯帕恩', 48.5833300, 16.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3600, 'Arzl im Pitztal', 'Arzl im Pitztal', 'Arcl'' (Pictal''),Arzl,Arzl im Pitztal,Арцль (Пицталь)', 47.2071200, 10.7626100, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3601, 'Arzberg', 'Arzberg', '', 47.2500000, 15.5166700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3602, 'Arriach', 'Arriach', 'Arriakh,a li ya he,Арриах,Арріах,阿里亚赫', 46.7292100, 13.8504600, 'AT', '2015-11-05', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3603, 'Arnoldstein', 'Arnoldstein', 'Arnol''dshtajn,Arnoldshhajn,Arnoldstein,Oristagn,Podkloster,Podklošter,a nuo er de shi tai yin,Арнолдщайн,Арнольдштайн,阿諾爾德施泰因', 46.5461100, 13.7100000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3604, 'Arnfels', 'Arnfels', 'Arnfel''s,Arnfels,a en fu er si,Арнфельс,阿恩弗尔斯', 46.6763900, 15.4030600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3605, 'Ardning', 'Ardning', 'Ardning', 47.5912000, 14.3637200, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3606, 'Arbesbach', 'Arbesbach', 'Arbesbakh,a er bei si ba he,Арбесбах,阿尔贝斯巴赫', 48.4933700, 14.9530800, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3607, 'Apfelberg', 'Apfelberg', 'Apfelberg', 47.2000000, 14.8333300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3608, 'Apetlon', 'Apetlon', 'Apatlan,Apetlon,Apátlan,Mosonbanfalva,Mosonbánfalva,a pei te long,Апетлон,阿佩特隆', 47.7439400, 16.8302000, 'AT', '2012-11-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3609, 'Anthering', 'Anthering', '', 47.8833300, 13.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3610, 'Antau', 'Antau', 'Antau,Otava,Ottova,Selegszanto,Selegszántó,Антау', 47.7737700, 16.4798400, 'AT', '2012-10-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3611, 'Ansfelden', 'Ansfelden', 'Ansfel''den,Ansfelden,Aunsfoein,Aunsföin,an si fei er deng,anspeldeni,anzfldn,Ансфелден,Ансфельден,אנספלדן,آنزفلدن,ანსფელდენი,安斯菲尔登', 48.2096900, 14.2900400, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3612, 'Anras', 'Anras', 'Anras', 46.7738900, 12.5608300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3613, 'Annaberg', 'Annaberg', '', 47.8713400, 15.3764800, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3614, 'Anif', 'Anif', 'Anif,a ni fu,anf,Аниф,Аніф,آنف,阿尼夫', 47.7500000, 13.0666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3615, 'Angern an der March', 'Angern an der March', 'Angern,Angern an der March,Angern-an-der-Markh,Congr,ma xi he pan an ge en,Ангерн-ан-дер-Марх,马希河畔安格恩', 48.3777800, 16.8280600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3616, 'Anger', 'Anger', '', 47.2742200, 15.6913900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3617, 'Angath', 'Angath', 'Angath', 47.5075800, 12.0651300, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3618, 'Andorf', 'Andorf', 'Andorf,an duo fu,Андорф,安多夫', 48.3713000, 13.5741200, 'AT', '2017-07-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3619, 'Andlersdorf', 'Andlersdorf', '', 48.1833300, 16.6666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3620, 'Andelsbuch', 'Andelsbuch', 'Andel''sbukh,an de er si bu he,andlzbwch,Андельсбух,اندلزبوچ,安德尔斯布赫', 47.4116700, 9.8932600, 'AT', '2014-10-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3621, 'Andau', 'Andau', 'Andau,Mosontarcsa,an dao,andayw,Андау,اندائو,安道', 47.7744100, 17.0329300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3622, 'Amstetten', 'Amstetten', 'Amshheten,Amshteten,Amshtetten,Amsteta,Amšteta,Aumstettn,a mu shi tai teng,amshttn,amsyuteten,amushutetten,Амштетен,Амштеттен,Амщетен,آمشتتن,ამშტეტენი,アムシュテッテン,阿姆施泰滕,암슈테텐', 48.1229000, 14.8720600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3623, 'Ampass', 'Ampass', 'Agenbach,Ampas,Ampass,Ampass Unterdorf,Taxerhof Lake,an pa si,Ампас,安帕斯', 47.2625100, 11.4622600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3624, 'Amlach', 'Amlach', 'Amlakh,a mu la he,amlach,Амлах,املاچ,阿姆拉赫', 46.8163900, 12.7636100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3625, 'Altmünster', 'Altmunster', 'Al''tmjunster,Altmuenster,Oidmuensta,Oidmünsta,altmanstr,jiu ming si te,Альтмюнстер,אלטמינסטר,التمانستر,舊明斯特', 47.9021900, 13.7641500, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3626, 'Altmelon', 'Altmelon', 'Al''tmelon,a er te mei long,altmlan,Альтмелон,التملان,阿尔特梅隆', 48.4622200, 14.9655200, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3627, 'Altlichtenwarth', 'Altlichtenwarth', '', 48.6444200, 16.7966400, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3628, 'Altlengbach', 'Altlengbach', '', 48.1535500, 15.9260600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3629, 'Althofen', 'Althofen', 'Al''tgofen,Al''tkhofen,Altkhofen,a er te huo fen,altafn,Алтхофен,Альтгофен,Альтхофен,التافن,阿尔特霍芬', 46.8729800, 14.4744900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3630, 'Altheim', 'Altheim', '', 48.2515400, 13.2340600, 'AT', '2011-07-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3631, 'Altenmarkt im Pongau', 'Altenmarkt im Pongau', 'Al''tenmarkt,Al''tenmarkt (Pongau),Al''tenmarkt-im-Pongau,Altenmarkt,Altenmarkt im Pongau,Oidnmorkt im Pongau,Old Markt,altnmarkt aym pangw,peng gao de qu a er teng ma ke te,Альтенмаркт,Альтенмаркт (Понгау),Альтенмаркт-им-Понгау,Альтенмаркт-ім-Понгау,التنمارکت ایم پانگو,蓬高地区阿尔滕马科特', 47.3833300, 13.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3632, 'Altenmarkt bei Sankt Gallen', 'Altenmarkt bei Sankt Gallen', 'Al''tenmarkt-Sankt-Gallen,Al''tenmarkt-baj-Sankt-Gallen,Altenmarkt,Altenmarkt bei Sankt Gallen,altnmarkt by sankt galn,sheng jia lun fu jin a er teng ma ke te,Альтенмаркт-Санкт-Галлен,Альтенмаркт-бай-Санкт-Галлен,التنمارکت بی سانکت گالن,圣加伦附近阿尔滕马科特', 47.7232700, 14.6483800, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3633, 'Altenmarkt bei Fürstenfeld', 'Altenmarkt bei Fuerstenfeld', 'Altenmarkt,Altenmarkt bei Furstenfeld,Altenmarkt bei Fürstenfeld', 47.0663800, 16.0478500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3634, 'Altenmarkt an der Triesting', 'Altenmarkt an der Triesting', 'Altenmarkt', 48.0155300, 15.9966100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3635, 'Altendorf', 'Altendorf', '', 47.6500000, 16.0166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3636, 'Altenburg', 'Altenburg', '', 48.6476500, 15.5929500, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3637, 'Altenberg bei Linz', 'Altenberg bei Linz', 'Al''tenberg (Linc),Altenberg,Альтенберг (Линц)', 48.3728400, 14.3502900, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3638, 'Altaussee', 'Altaussee', 'Al''tausze,Al''tauszee,Oid Aussee,a er tao sai,altawsy,Альтаусзе,Альтаусзее,التاوسی,阿尔陶塞', 47.6384400, 13.7627800, 'AT', '2012-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3639, 'Altach', 'Altach', 'Al''takh,Altach,Altachas,Altakh,a er te a he,altach,altaheu,arutahha,Алтах,Альтах,التاچ,アルタッハ,阿爾特阿赫,알타흐', 47.3500000, 9.6500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3640, 'Allhartsberg', 'Allhartsberg', '', 48.0263300, 14.7900900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3641, 'Allerheiligen im Mürztal', 'Allerheiligen im Muerztal', 'Allerheiligen,Allerheiligen im Murztal,Allerheiligen im Mürztal', 47.4666700, 15.4000000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3642, 'Allerheiligen bei Wildon', 'Allerheiligen bei Wildon', 'Allerheiligen,Allerheiligen bei Wildon', 46.9141700, 15.5544400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3643, 'Allentsteig', 'Allentsteig', 'Allentshtajg,a lun te shi tai ge,Аллентштайг,الینس‌تستج,阿伦特施泰格', 48.6972500, 15.3275600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3644, 'Alland', 'Alland', 'Alland,Alland im Gebirge,a lan,aland,Алланд,الاند,阿兰', 48.0582900, 16.0790100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3645, 'Aldrans', 'Aldrans', 'Al''drans,a er de lan si,aldrans,Альдранс,الدرانس,阿尔德兰斯', 47.2500000, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3646, 'Alberndorf in der Riedmark', 'Alberndorf in der Riedmark', 'Al''berndorf,Al''berndorf (Ridmark),Al''berndorf-in-der-Ridmark,Alberndorf,Alberndorf in der Riedmark,albrndarf ayn dr rydmark,li de ma ke de qu a bei en duo fu,Альберндорф,Альберндорф (Ридмарк),Альберндорф-ин-дер-Ридмарк,البرندارف این در ریدمارک,里德马克地区阿贝恩多夫', 48.4060700, 14.4144100, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3647, 'Ainet', 'Ainet', 'Ainet,Ajnet,ai nei te,aynt,Айнет,اینت,艾内特', 46.8660300, 12.6896800, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3648, 'Aigen-Schlägl', 'Aigen-Schlaegl', 'Aigen-Schlaegl,Aigen-Schlägl,Ajgen,Ajgen-im-Mjul''krajs,aygn aym mahlkryz,mi er ke lei si de qu ai gen,Айген,Айген-им-Мюлькрайс,ایگن ایم ماهلکریز,米尔克雷斯地区艾根', 48.6457800, 13.9710900, 'AT', '2017-02-03', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3649, 'Aigen im Ennstal', 'Aigen im Ennstal', 'Aigen,Aigen im Ennstal,Aigen im Ennstale,Aigen im Ennstoi,Ajgen,Ajgen (Ehnstal''),Ajgen-im-Ehnstal'',aygn aym anstal,en si he gu ai gen,Айген,Айген (Энсталь),Айген-им-Энсталь,ایگن ایم انستال,恩斯河谷艾根', 47.5166700, 14.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3650, 'Aichkirchen', 'Aichkirchen', 'Aichkirchen', 48.1094400, 13.7915800, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3651, 'Aich', 'Aich', '', 47.4166700, 13.8166700, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3652, 'Aibl', 'Aibl', 'Aibel,Aibl', 46.6814500, 15.2261900, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3653, 'Aggsbach', 'Aggsbach', 'Aggsbach,Aggsbach Markt,Markt Aggsbach', 48.2940400, 15.4038200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3654, 'Aflenz Kurort', 'Aflenz Kurort', 'Aflenz,Aflenz Kurort', 47.5333300, 15.2333300, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3655, 'Admont', 'Admont', 'Admont,a de meng te,admant,Адмонт,ادمانت,阿德蒙特', 47.5753700, 14.4607500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3656, 'Aderklaa', 'Aderklaa', '', 48.2833300, 16.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3657, 'Achenkirch', 'Achenkirch', '', 47.5265900, 11.7055900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3658, 'Achau', 'Achau', '', 48.0802600, 16.3861100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3659, 'Abtenau', 'Abtenau', 'Abbtenau,Abtenao,Abtenau,Абтенау', 47.5637300, 13.3459900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3660, 'Absam', 'Absam', '', 47.3000000, 11.5000000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3661, 'Abfaltersbach', 'Abfaltersbach', 'Abfaltersbach', 46.7571500, 12.5282800, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3662, 'Schlaiten', 'Schlaiten', 'Schlaiten,Schlatn,Shlajten,shi lai teng,Шлайтен,施莱滕', 46.8794400, 12.6541700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3663, 'Thurn', 'Thurn', '', 46.8505600, 12.7686100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3664, 'Untertilliach', 'Untertilliach', 'Untertilliach,Untertilliakh,Untertillijakh,xia di li ya he,Унтертиллиах,Унтертілліях,下蒂利亚赫', 46.7041700, 12.7086100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3665, 'Finkenstein am Faaker See', 'Finkenstein am Faaker See', 'Bekstanj,Bekštanj,Finkenshhajn am Faaker Zee,Finkenshtajn-am-Faker-Ze,Finkenshtajn-am-Faker-Zee,fa ke er hu pan fen ken shi tai yin,Финкенштайн-ам-Факер-Зе,Финкенштайн-ам-Факер-Зее,Финкенщайн ам Фаакер Зее,Фінкенштайн-ам-Факер-Зее,法克尔湖畔芬肯施泰因', 46.5790400, 13.9349600, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3666, 'Sankt Jakob in Defereggen', 'Sankt Jakob in Defereggen', 'Sankt Jakob in Defereggen', 46.9197200, 12.3313900, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3667, 'Attnang-Puchheim', 'Attnang-Puchheim', 'Atnang-Pukhkhajm,Attnang-Buachham,Attnang-Puchheim,a te nan-pu he hai mu,Атнанг-Пуххайм,阿特南-普赫海姆', 48.0083300, 13.7166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3668, 'Obernberg am Brenner', 'Obernberg am Brenner', 'Obernberg-am-Brenner,Obernberg-na-Brennere,awbrnbrg aym brynr,bu lun na shan kou fu jin ao bo en bei ge,Обернберг-ам-Бреннер,Обернберг-на-Бреннере,اوبرنبرگ ایم برینر,布伦纳山口附近奥伯恩贝格', 47.0166700, 11.4166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3669, 'Mühlbachl', 'Muhlbachl', 'Mjul''bakhl'',mi he er ba he er,Мюльбахль,米赫爾巴赫爾', 47.1333300, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3670, 'Leutasch', 'Leutasch', 'Lojtash,luo yi ta shi,Лойташ,洛伊塔施', 47.3689000, 11.1440400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3671, 'Gschnitz', 'Gschnitz', '', 47.0446900, 11.3508900, 'AT', '2017-06-25', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3672, 'Navis', 'Navis', '', 47.1166700, 11.5333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3673, 'Ellbögen', 'Ellbogen', '', 47.1666700, 11.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3674, 'Sellrain', 'Sellrain', '', 47.2166700, 11.2166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3675, 'Oberperfuss', 'Oberperfuss', 'Oberperfuss', 47.2445100, 11.2475500, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3676, 'Obsteig', 'Obsteig', '', 47.3000000, 10.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3677, 'Kolsass', 'Kolsass', '', 47.3000000, 11.6333300, 'AT', '2017-03-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3678, 'Gnadenwald', 'Gnadenwald', '', 47.3166700, 11.5666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3679, 'Ehrwald', 'Ehrwald', 'Ehrval''d,Ehrwald,Erval''d,ai er wa er de,Ервальд,Эрвальд,اہروالڈ,埃尔瓦尔德', 47.4000000, 10.9166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3680, 'Lanzendorf', 'Lanzendorf', '', 48.1105600, 16.4450000, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3681, 'Ansfelden', 'Ansfelden', '', 47.9650000, 13.0494400, 'AT', '2013-07-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3682, 'Heinfels', 'Heinfels', 'Gajnfel''s,Heinfels,Khajnfel''s,hai yin fei er si,Гайнфельс,Хайнфельс,海因费尔斯', 46.7500000, 12.4500000, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3683, 'Kals am Großglockner', 'Kals am Grossglockner', '', 47.0022700, 12.6455200, 'AT', '2017-06-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3684, 'Gerlosberg', 'Gerlosberg', 'Gerlosberg', 47.2166700, 11.9333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3685, 'Gerlos', 'Gerlos', 'Gerlos,Герлос', 47.2246400, 12.0301200, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3686, 'Krimml', 'Krimml', 'Kriml'',Krimml,Krimml'',Krimmoe,Krimmö,ke li mu er,Кримль,Криммль,Крімль,克里姆尔', 47.2179900, 12.1748700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3687, 'Rohrberg', 'Rohrberg', '', 47.2333300, 11.9166700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3688, 'Ried im Zillertal', 'Ried im Zillertal', 'Ried im Zillertal', 47.3000000, 11.8666700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3689, 'Alpbach', 'Alpbach', 'Aipbach,Al''pbakh,a er bei ba he,alpbakh,Åipbåch,Альпбах,الپباخ,阿尔卑巴赫', 47.3987800, 11.9437300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3690, 'Itter', 'Itter', '', 47.4666700, 12.1333300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3691, 'Brand', 'Brand', '', 47.1008300, 9.7372200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3692, 'Liebenfels', 'Liebenfels', 'Libenfel''s,Liebenfels,li ben fu er si,Либенфельс,利本弗尔斯', 46.7377800, 14.2866700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3693, 'Frauenstein', 'Frauenstein', '', 46.8141700, 14.2941700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3694, 'Eppenstein', 'Eppenstein', 'Eppenstein', 47.1283300, 14.7375000, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3695, 'Hochleithen', 'Hochleithen', '', 48.4531700, 16.5309000, 'AT', '2017-06-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3696, 'Sankt Oswald ob Eibiswald', 'Sankt Oswald ob Eibiswald', 'Sankt Oswald ob Eibiswald', 46.7083300, 15.1466700, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3697, 'Wildschönau', 'Wildschoenau', 'Vil''dshenau,Vil''dshjonau,Wuedschnau,Wüdschnau,wei er de she nao,Вильдшёнау,Вільдшенау,维尔德舍瑙', 47.4061900, 12.0378400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3698, 'Langkampfen', 'Langkampfen', 'Langkampfen,Лангкампфен', 47.5487800, 12.1012700, 'AT', '2017-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3699, 'Hart bei Graz', 'Hart bei Graz', '', 47.0431100, 15.5152700, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3700, 'Berg im Drautal', 'Berg im Drautal', '', 46.7491500, 13.1353600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3701, 'Lockenhaus', 'Lockenhaus', 'Leka,Lockenhaus,Lokkenkhaus,Léka,Локкенхаус', 47.4075300, 16.4162300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3702, 'St. Georgen am Längsee', 'St. Georgen am Laengsee', '', 46.7806100, 14.4303300, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3703, 'Großkirchheim', 'Grosskirchheim', '', 46.9727000, 12.8958900, 'AT', '2017-06-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3704, 'Damüls', 'Damuels', 'Damjul''s,da mi er si,Дамюльс,达米尔斯', 47.2803400, 9.8916400, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3705, 'Bad Waltersdorf', 'Bad Waltersdorf', 'Bad-Val''tersdorf,ba te wa er te si duo fu,Бад-Вальтерсдорф,巴特瓦尔特斯多夫', 47.1696000, 16.0087000, 'AT', '2017-06-22', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3706, 'Bad Leonfelden', 'Bad Leonfelden', 'Bad-Leonfel''den,ba te lai ang fei er deng,Бад-Леонфельден,巴特莱昂费尔登', 48.5204700, 14.2945900, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3707, 'Pfarrwerfen', 'Pfarrwerfen', 'Pfarrverfen,Pfourwerfen,pu fa er wei er fen,Пфаррверфен,普法尔韦尔芬', 47.4572900, 13.2053100, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3708, 'Thal', 'Thal', 'Tal''-Grac,Таль-Грац', 47.0764400, 15.3605200, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3709, 'Bürserberg', 'Buerserberg', '', 47.1464400, 9.7773600, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3710, 'Holzgau', 'Holzgau', 'Gol''cgau,Khol''cgau,huo er ci gao,Гольцгау,Хольцгау,霍尔茨高', 47.2604500, 10.3441900, 'AT', '2011-07-31', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3711, 'Schröcken', 'Schroecken', 'Shreken,Shrjokken,shi lei ken,shrwkn,Шрекен,Шрёккен,شروکن,施勒肯', 47.2575500, 10.0919700, 'AT', '2014-10-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3712, 'Rossleithen', 'Rossleithen', 'Rossleithen,Roßleithen', 47.7017000, 14.2736000, 'AT', '2011-06-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3713, 'Sankt Georgen am Walde', 'Sankt Georgen am Walde', '', 48.3597900, 14.9023500, 'AT', '2011-06-28', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3714, 'Nebelberg', 'Nebelberg', '', 48.6285400, 13.8462900, 'AT', '2011-07-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3715, 'Sonnberg im Mühlkreis', 'Sonnberg im Muehlkreis', '', 48.4608000, 14.3116700, 'AT', '2011-12-20', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3716, 'Baierdorf-Umgebung', 'Baierdorf-Umgebung', '', 47.2851100, 15.7104500, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3717, 'Sonntag', 'Sonntag', '', 47.2385700, 9.8976500, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3718, 'Haus im Ennstal', 'Haus im Ennstal', '', 47.4105800, 13.7675900, 'AT', '2014-04-24', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3719, 'Hall bei Admont', 'Hall bei Admont', '', 47.5870000, 14.4637200, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3720, 'Vandans', 'Vandans', '', 47.0956900, 9.8652500, 'AT', '2015-08-26', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3721, 'Ertl', 'Ertl', '', 47.9770400, 14.6313400, 'AT', '2015-12-27', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3722, 'Hittisau', 'Hittisau', '', 47.4578100, 9.9596200, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3723, 'Pongrazen bei Hartberg', 'Pongrazen bei Hartberg', 'Pongratzen', 47.3419300, 15.9099400, 'AT', '2017-06-23', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3724, 'Neuberg im Burgenland', 'Neuberg im Burgenland', '', 47.1689400, 16.2605400, 'AT', '2017-06-08', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3725, 'Schönkirchen-Reyersdorf', 'Schoenkirchen-Reyersdorf', '', 48.3547700, 16.6911500, 'AT', '2017-06-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3726, 'Klein-Neusiedl', 'Klein-Neusiedl', '', 48.0937900, 16.6066100, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3727, 'Eggendorf', 'Eggendorf', '', 47.8580900, 16.3218200, 'AT', '2017-06-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3728, 'Seitenberg', 'Seitenberg', '', 46.7480100, 14.0882500, 'AT', '2017-06-09', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3729, 'Dünserberg', 'Duenserberg', '', 47.2275200, 9.7237200, 'AT', '2017-06-12', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3730, 'Aschau im Zillertal', 'Aschau im Zillertal', '', 47.2661300, 11.8953600, 'AT', '2017-06-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3731, 'Assling', 'Assling', '', 46.7866300, 12.6395100, 'AT', '2017-06-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3732, 'Thiersee', 'Thiersee', '', 47.5942400, 12.1175800, 'AT', '2017-06-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3733, 'Mauer', 'Mauer', '', 46.7410400, 14.2293700, 'AT', '2017-06-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3734, 'Mautbrücken', 'Mautbruecken', '', 46.7203700, 14.1939900, 'AT', '2017-06-15', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3735, 'Fresen', 'Fresen', '', 46.7051600, 14.0451300, 'AT', '2017-06-17', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3736, 'Draschen', 'Draschen', '', 46.7690900, 14.0675800, 'AT', '2017-06-16', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3737, 'Tillmitsch Links der Laßnitz', 'Tillmitsch Links der Lassnitz', '', 46.8095500, 15.5239400, 'AT', '2017-06-21', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3738, 'Sticklberg', 'Sticklberg', '', 47.5303600, 15.7791100, 'AT', '2017-07-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3739, 'Klaffenegg', 'Klaffenegg', '', 47.5181300, 15.7600600, 'AT', '2017-07-04', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3740, 'Weißenkirchen im Attergau', 'Weissenkirchen im Attergau', '', 47.9496400, 13.4184300, 'AT', '2017-07-13', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3741, 'Klausner', 'Klausner', '', 47.5756000, 14.3502900, 'AT', '2017-07-14', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3742, 'Wagnergraben', 'Wagnergraben', '', 48.0203600, 13.0239500, 'AT', '2017-07-29', 15);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3814, 'Plympton', 'Plympton', 'Plympton', -34.9500000, 138.5500000, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3815, 'Pinjarra', 'Pinjarra', 'Pinjarra', -32.6298000, 115.8735100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3816, 'Peterborough', 'Peterborough', 'Peterborough,Petersburgh,Piterboro,Питерборо', -32.9720500, 138.8407300, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3817, 'Perth', 'Perth', 'Gorad Pert,PER,Peairt,Pert,Perta,Pertas,Perth,Perth City,Perthia,Perto,Perþ,Pirth,Purt,Pērta,byrth,part,partha,pasu,peoseu,pert,pheirth,po si,prt,prt'',prtھ  asٹrylya,Περθ,Горад Перт,Перт,Пертһ,Пърт,Պերթ,פרת'',بيرث,پرت,پرتھ، آسٹریلیا,पर्थ,பேர்த்,ಪರ್ತ್,പെർത്ത്,เพิร์ท,ပါ့သ်မြို့,პერთი,パース,珀斯,퍼스', -31.9522400, 115.8614000, 'AU', '2015-06-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3818, 'Pemberton', 'Pemberton', 'Pemberton', -34.4431100, 116.0368900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3819, 'Pearce', 'Pearce', '', -31.6666700, 116.0166700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3820, 'Parkerville', 'Parkerville', 'Parkerville', -31.8747200, 116.1380000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3821, 'Parap', 'Parap', 'Parap,Paraparap', -12.4305400, 130.8414200, 'AU', '2013-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3822, 'One Tree Hill', 'One Tree Hill', 'One Tree Hill', -34.7000000, 138.7666700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3823, 'Oakbank', 'Oakbank', 'Oakbank', -34.9834000, 138.8452800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3824, 'Nuriootpa', 'Nuriootpa', 'Nuriootpa', -34.4682500, 138.9976700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3825, 'North Fremantle', 'North Fremantle', '', -32.0333300, 115.7500000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3826, 'North Beach', 'North Beach', '', -31.8629800, 115.7562400, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3827, 'Northampton', 'Northampton', 'Northampton', -28.3499400, 114.6382100, 'AU', '2014-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3828, 'Northam', 'Northam', 'Northam', -31.6493200, 116.6742300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3829, 'Normanville', 'Normanville', 'Normanvill,Норманвилл', -35.4462300, 138.3213000, 'AU', '2017-01-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3830, 'Noarlunga', 'Noarlunga', 'Noarlunga,Noarlunga Centre,Old Noarlunga', -35.1820900, 138.5013800, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3831, 'Nhulunbuy', 'Nhulunbuy', 'GOV,Gove,Nhulunbuy,Nhulunby,Nullumbuy,nhwlwnbwy,nwlwnbyy,נולונביי,نهولونبوی', -12.1816500, 136.7784100, 'AU', '2016-04-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3832, 'Newman', 'Newman', 'Mount Newman,N''jumen,Newman,ZNE,Ньюмен,نیومین، مغربی آسٹریلیا', -23.3564400, 119.7355300, 'AU', '2012-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3833, 'Nedlands', 'Nedlands', 'Crawley-Nedlands,Nedlands', -31.9818400, 115.8073000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3834, 'Narrogin', 'Narrogin', 'NRG,Narrogin', -32.9328200, 117.1776300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3835, 'Nairne', 'Nairne', 'Nairne', -35.0345000, 138.9115400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3836, 'Murray Bridge', 'Murray Bridge', 'Marri-Bridzh,Marri-Brij,Murray Bridge,mo lei qiao,mry brydj  gwnyy awstwralya,murei-briji,mwray bryj,Марри-Бридж,Маррі-Брідж,Մարրի-Բրիջ,מארי ברידג,مری بریدج، گونئی اوستورالیا,مرے بریج,مرے بریج، جنوبی آسٹریلیا,مورای بریج,مووری برێج، باشووری ئوسترالیا,მურეი-ბრიჯი,墨累橋', -35.1198600, 139.2734500, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3837, 'Mundijong', 'Mundijong', 'Mundijong', -32.2921700, 115.9856400, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3838, 'Mundaring', 'Mundaring', 'Mundaring', -31.9021000, 116.1675700, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3839, 'Mount Isa', 'Mount Isa', 'ISA,Maunt Ajza,Maunt-Ajza,Mont Isa,Mount Ajza,Mount Isa,Mt Isa,Mt. Isa,maunteuaija,mawnt yysa,mwnt aysa,yi sa shan,Маунт Айза,Маунт Ајза,Маунт-Айза,Моунт Айза,מאונט איסה,ماؤنٹ ایسا,ماونت ئیسا,مونت ایسا,მაუნტ-აიზა,伊薩山,마운트아이자', -20.7252300, 139.4972700, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3840, 'Mount Helena', 'Mount Helena', 'Maunt Khelena,Mount Helena,Маунт Хелена', -31.8760600, 116.2102500, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3841, 'Mount Compass', 'Mount Compass', 'Mount Compass', -35.3468500, 138.6203200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3842, 'Mount Barker', 'Mount Barker', 'Maunt Barker,Mount Barker,Mt Barker,Маунт Баркер,ماؤنٹ بارکر، جنوبی آسٹریلیا', -35.0666700, 138.8666700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3843, 'Mount Barker', 'Mount Barker', 'Mount Barker', -34.6308400, 117.6660600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3844, 'Mosman Park', 'Mosman Park', 'Mosman Park', -32.0053800, 115.7638000, 'AU', '2016-03-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3845, 'Morphett Vale', 'Morphett Vale', 'Morphett Vale', -35.1333300, 138.5166700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3846, 'Moora', 'Moora', 'Moora,Mura,Мура', -30.6400300, 116.0036500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3847, 'Modbury', 'Modbury', 'Modbury', -34.8333300, 138.6833300, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3848, 'Moana', 'Moana', 'Moana', -35.1939400, 138.4761400, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3849, 'Mitcham', 'Mitcham', 'Mitcham', -34.9789200, 138.6218400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3850, 'Midland', 'Midland', 'Midland Junction', -31.9000000, 116.0000000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3851, 'Middle Swan', 'Middle Swan', 'Middle Swan', -31.8500000, 116.0166700, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3852, 'Merredin', 'Merredin', 'Merredin', -31.4809400, 118.2744800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3853, 'Meningie', 'Meningie', 'Meningi,Meningie,miningi,Менинги,ミニンギー', -35.6863700, 139.3400700, 'AU', '2015-05-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3854, 'Melville', 'Melville', '', -28.1833300, 116.7333300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3855, 'Medina', 'Medina', 'Medina', -32.2333300, 115.7833300, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3856, 'Meadows', 'Meadows', 'Meadows,Midous,Мидоус', -35.1802100, 138.7625000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3857, 'McMinns Lagoon', 'McMinns Lagoon', 'McMinns Lagoon', -12.5539700, 131.1116500, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3858, 'McLaren Vale', 'McLaren Vale', 'McLaren Vale', -35.2189500, 138.5432600, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3859, 'Maylands', 'Maylands', 'Maylands', -31.9309700, 115.8948600, 'AU', '2015-06-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3860, 'Marion', 'Marion', 'Marion', -35.0042300, 138.5531300, 'AU', '2016-03-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3861, 'Marino', 'Marino', 'Marino', -35.0446800, 138.5123600, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3862, 'Margaret River', 'Margaret River', 'MQZ,Margaret,Margaret River,ma ge li te he,Маргарет,玛格丽特河', -33.9550400, 115.0759900, 'AU', '2017-01-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3863, 'Mannum', 'Mannum', 'Mannum,Маннум', -34.9152900, 139.3032500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3864, 'Manning', 'Manning', '', -32.0159400, 115.8671400, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3865, 'Manjimup', 'Manjimup', 'MJP,Manjimup,Manjimup Shire', -34.2412200, 116.1456400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3866, 'Mandurah', 'Mandurah', 'Mandujura,Mandura,Mandurah,Mandzhera,man du la,mandula,manduraha,mandwrah,manjura,mndwra,mondurahi,Манджера,Мандура,Мандъюра,ماندوراه,ماندورہ,مندورا,مندوراہ,مێندیۆرا,मंदूरह,მონდურაჰი,マンジュラ,曼杜拉,만두라', -32.5269000, 115.7217000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3867, 'Mallala', 'Mallala', 'Mallala,Маллала', -34.4374000, 138.5098700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3868, 'Maitland', 'Maitland', 'Maitland,Mejtlend,Мейтленд', -34.3738600, 137.6733300, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3869, 'Maddington', 'Maddington', 'Maddington', -32.0500000, 115.9833300, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3870, 'Macclesfield', 'Macclesfield', 'Macclesfield', -35.1718200, 138.8358900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3871, 'Lyndoch', 'Lyndoch', 'Lyndoch', -34.6012400, 138.8909400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3872, 'Lower Chittering', 'Lower Chittering', 'Lower Chittering,Lower Chittertering', -31.5833300, 116.1166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3873, 'Lobethal', 'Lobethal', 'Lobethal', -34.9045500, 138.8747700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3874, 'Little Hampton', 'Little Hampton', 'Little Hampton,Littlehampton', -35.0500000, 138.8500000, 'AU', '2013-09-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3875, 'Lewiston', 'Lewiston', 'Lewiston', -34.6044900, 138.5912500, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3876, 'Langhorne Creek', 'Langhorne Creek', 'Langhorne Creek', -35.2959600, 139.0359100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3877, 'Kwinana', 'Kwinana', 'Kwinana', -32.2301300, 115.7812800, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3878, 'Kununurra', 'Kununurra', 'KNX,Kununarra,Kununurra,kananara,Кунунарра,კუნუნურა,カナナラ', -15.7782500, 128.7420800, 'AU', '2016-12-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3879, 'Kojonup', 'Kojonup', 'Kojonup', -33.8305000, 117.1594600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3880, 'Kingscote', 'Kingscote', 'KGC,Kingscote,Kingskot,kingseukos,Кингскот,Кінгскот,킹스콧', -35.6559000, 137.6393000, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3881, 'Kenwick', 'Kenwick', 'Kenwick', -32.0333300, 115.9666700, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3882, 'Kendenup', 'Kendenup', 'Kendenup', -34.4821300, 117.6253300, 'AU', '2013-10-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3883, 'Kelmscott', 'Kelmscott', '', -32.1243400, 116.0259000, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3884, 'Katherine', 'Katherine', 'KTR,Katherine,kyasarin,qtryn,קתרין,キャサリン', -14.4651700, 132.2634700, 'AU', '2013-07-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3885, 'Katanning', 'Katanning', 'KNI,Katanning', -33.6878700, 117.5584000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3886, 'Kapunda', 'Kapunda', 'Kapunda,Капунда', -34.3387100, 138.9164400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3887, 'Kalgoorlie', 'Kalgoorlie', 'KGI,Kalgoorlie,Kalgoorlie-Boulder,Kalgurli,Kalgurli-Bolder,ka er gu li,kaelgulli,kalagurli,kalghwrly,kalgurli-bauldara,kalgwrly,kalgwrlyy,karuguri,qlgwrly,Калгурли,Калгурли-Болдер,Калгурлі,קלגורלי,كالغورلي,کالگورلئی,کالگورلی,کالگورڵی,कल्गूर्ली-बौल्डर,कालगुर्ली,კალგურლი,カルグーリー,卡尔古利,캘굴리', -30.7461400, 121.4742000, 'AU', '2014-04-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3888, 'Kalbarri', 'Kalbarri', 'KAX,Kalbarri', -27.7105000, 114.1650500, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3889, 'Kadina', 'Kadina', 'Kadina,Кадина', -33.9649500, 137.7163400, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3890, 'Jamestown', 'Jamestown', 'Dzhejmstaun,Jamestown,Джеймстаун', -33.2053100, 138.6050300, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3891, 'Ingle Farm', 'Ingle Farm', 'Ingle Farm', -34.8333300, 138.6333300, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3892, 'Hope Valley', 'Hope Valley', 'Hope Valley', -34.8333300, 138.7000000, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3893, 'Honiton', 'Honiton', '', -35.1166700, 137.6500000, 'AU', '2014-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3894, 'Hindmarsh Island', 'Hindmarsh Island', 'Hindmarsh,Hindmarsh Island', -35.5101400, 138.8676200, 'AU', '2015-10-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3895, 'Heathfield', 'Heathfield', 'Heathfield', -35.0166700, 138.7166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3896, 'Harvey', 'Harvey', 'Harvey,ha wei,哈維', -33.0786300, 115.9151200, 'AU', '2016-08-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3897, 'Happy Valley', 'Happy Valley', 'Happy Valley', -35.0833300, 138.5333300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3898, 'Halls Creek', 'Halls Creek', 'HCQ,Halls Creek', -18.2248500, 127.6664700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3899, 'Hahndorf', 'Hahndorf', 'Chantorf,Hahndorf,Khandorf,hahndwrf,Χάντορφ,Хандорф,هاهندورف', -35.0286300, 138.8077900, 'AU', '2014-12-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3900, 'Hackham', 'Hackham', 'Hackham', -35.1500000, 138.5166700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3901, 'Gumeracha', 'Gumeracha', 'Gumeracha', -34.8238800, 138.8846700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3902, 'Guildford', 'Guildford', 'Guildford', -31.9000000, 115.9666700, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3903, 'Greenmount', 'Greenmount', 'Greenmount,Grinmaunt,Гринмаунт', -31.9007200, 116.0495000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3904, 'Grasmere', 'Grasmere', 'Grasmere,Grassmere', -35.0180600, 117.7555600, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3905, 'Grange', 'Grange', 'Grange', -34.9022300, 138.4902200, 'AU', '2015-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3906, 'Gosnells', 'Gosnells', 'Gosnells', -32.0810000, 116.0054000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3907, 'Gooseberry Hill', 'Gooseberry Hill', 'Gooseberry Hill', -31.9544400, 116.0492000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3908, 'Goolwa', 'Goolwa', 'gwlwa,گولوا', -35.5015900, 138.7819100, 'AU', '2015-05-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3909, 'Golden Grove', 'Golden Grove', 'Golden Grove', -34.7833300, 138.7333300, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3910, 'Glenelg', 'Glenelg', 'Glenel''g,Glenelg,ge lai nei er ge,ge lian nai er,Гленельг,搿连乃尔,格萊內爾格', -34.9807900, 138.5150000, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3911, 'Gilles Plains', 'Gilles Plains', 'Gilles Plains', -34.8500000, 138.6500000, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3912, 'Geraldton', 'Geraldton', 'Dzeraldton,Dzheral''dton,Dzheraldton,GET,Geraldton,grldtwn,jeleolteon,jeraldatana,jeraruton,jie la er dun,jyraldtwn,Џералдтон,Джералдтон,Джеральдтон,גרלדטון,جيرالدتون,جیرالڈٹن,جێراڵدتن,گیرالڈٹن,जेराल्डटन,ჯერალდტონი,ジェラルトン,傑拉爾頓,제럴턴', -28.7789700, 114.6145900, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3913, 'Gawler', 'Gawler', 'Gawler,Goler,Gouler,gawlr,Голер,Гоулер,گاولر', -34.6025100, 138.7490200, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3914, 'Fremantle', 'Fremantle', 'Fremantle,Frimantl,JFM,frymantl,fu li man te er,furimantoru,peulimaenteul,primantʼli,Фримантл,Фрімантл,فريمانتل,فریمانٹیل,ფრიმანტლი,フリーマントル,弗里曼特爾,프리맨틀', -32.0563200, 115.7455700, 'AU', '2017-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3915, 'Freeling', 'Freeling', 'Freeling,Friling,Фрилинг', -34.4540700, 138.8086800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3916, 'Findon', 'Findon', 'Findon', -34.9000000, 138.5333300, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3917, 'Esperance', 'Esperance', 'EPR,Ehsperans,Esperance,Esperance-Urbo,Esperans,Esperansos,eseupeoleonseu,esuperansu,Есперанс,Эсперанс,ესპერანსე,エスペランス,에스퍼런스', -33.8591900, 121.8916400, 'AU', '2016-03-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3918, 'Encounter Bay', 'Encounter Bay', '', -35.5741900, 138.6005500, 'AU', '2016-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3919, 'Elizabeth', 'Elizabeth', 'Elizabeth,الزبتھ، جنوبی آسٹریلیا', -34.7194400, 138.6770700, 'AU', '2013-09-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3920, 'Donnybrook', 'Donnybrook', 'Donnybrook', -33.5713000, 115.8244600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3921, 'Dongara', 'Dongara', 'DOX,Dongara,Dongarra', -29.2581800, 114.9327600, 'AU', '2016-06-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3922, 'Chidlow', 'Chidlow', '', -31.8609400, 116.2724300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3923, 'Derby', 'Derby', 'DRB,Derbi,Derbis,Derby,Дерби', -17.3029500, 123.6286400, 'AU', '2014-03-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3924, 'Denmark', 'Denmark', 'Denmark,dnmark,Денмарк,دنمارك', -34.9606700, 117.3532100, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3925, 'Port Denison', 'Port Denison', 'Denison,Port Denison', -29.2833300, 114.9166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3926, 'Darwin', 'Darwin', 'DRW,Daarwin,Darvin,Darvina,Darvinas,Darvino,Darwin,Dārvina,Gorad Darvin,Ntargouin,Palmerston,Port Darwin,da er wen,da er wen gang,dar win,dara''u''ina,daravina,darvina,darvini,darwyn,dau~in,dawin,drwwyn,tarvin,Ντάργουιν,Горад Дарвін,Дарвин,Дарвін,Դարվին,דארווין,דרווין,داروين,داروین,داروین، قوزئی توپراق‌لاری,ڈارون,डार्विन,ডারউইন,ਡਾਰਵਿਨ,டார்வின்,ഡാർവിൻ,ดาร์วิน,ဒါဝင်မြို့,დარვინი,ダーウィン,达尔文,达尔文港,다윈', -12.4611300, 130.8418500, 'AU', '2017-04-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3927, 'Darlington', 'Darlington', 'Darlington', -35.0333300, 138.5666700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3928, 'Darlington', 'Darlington', 'Darlington', -31.9190600, 116.0812000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3929, 'Dampier', 'Dampier', 'Dampier,Dampierin satama,Dampir,Дампир', -20.6627500, 116.7125600, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3930, 'Cunderdin', 'Cunderdin', 'Cunderdin', -31.6539800, 117.2337400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3931, 'Cummins', 'Cummins', 'Cummins,Kammins,Камминс', -34.2639600, 135.7260000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3932, 'Crystal Brook', 'Crystal Brook', 'Crystal Brook,Kristal-Bruk,Кристал-Брук', -33.3525600, 138.2095500, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3933, 'Craigburn Farm', 'Craigburn Farm', '', -35.0500000, 138.6166700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3934, 'Crafers', 'Crafers', 'Crafers', -35.0000000, 138.7000000, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3935, 'Cottesloe', 'Cottesloe', '', -32.0000000, 115.7666700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3936, 'Coromandel Valley', 'Coromandel Valley', 'Coromandel Valley', -35.0500000, 138.6166700, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3937, 'Coogee', 'Coogee', 'Coogee', -32.1193400, 115.7665000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3938, 'Coober Pedy', 'Coober Pedy', 'CPD,Kuber-Pedi,Кубер-Педи', -29.0141500, 134.7549500, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3939, 'Collie', 'Collie', 'Collie', -33.3620600, 116.1561700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3940, 'Cleve', 'Cleve', 'CVC,Cleve,Kliv,Клив', -33.7000000, 136.5000000, 'AU', '2013-08-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3941, 'Clare', 'Clare', 'Clare,Klehr,Клэр', -33.8332500, 138.6106400, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3942, 'Cheltenham', 'Cheltenham', 'Cheltenham', -34.8666700, 138.5166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3943, 'Ceduna', 'Ceduna', 'CED,Ceduna,Sed''juna,Седьюна', -32.1266000, 133.6727100, 'AU', '2014-09-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3944, 'Caversham', 'Caversham', 'Caversham', -31.8833300, 115.9666700, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3945, 'Carnarvon', 'Carnarvon', 'CVQ,Carnarvon,Karnarvon,qrnrbwn,Карнарвон,קרנרבון', -24.8825800, 113.6571300, 'AU', '2016-03-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3946, 'Capel', 'Capel', 'Capel', -33.5580800, 115.5627800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3947, 'Cannington', 'Cannington', '', -32.0166700, 115.9500000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3948, 'Campbelltown', 'Campbelltown', 'Cambelltown,Campbelltown', -34.8833300, 138.6666700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3949, 'Callington', 'Callington', 'Callington', -35.1197700, 139.0414000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3950, 'Byford', 'Byford', 'Bajford,Byford,Байфорд', -32.2209900, 116.0090000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3951, 'Busselton', 'Busselton', 'BQB,Busselton,bsltwn,bwsltwn,בסלטון,باسڵتن,بوسلتون,بیسیلٹن,ბუსელტონი', -33.6524900, 115.3455000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3952, 'Bunbury', 'Bunbury', 'BUY,Banberi,Banberis,Bunbury,ban bo li,banbari,banbary,banberi,beonbeoli,bnbry,Банбери,בנברי,بانباري,بانبوری، ڕۆژاوای ئوسترالیا,بنبری,بنبری، مغربی آسٹریلیا,ბანბერი,バンバリー,班伯利,번버리', -33.3271100, 115.6413700, 'AU', '2017-04-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3953, 'Bullsbrook', 'Bullsbrook', 'Bullsbrook', -31.6690500, 115.9999000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3954, 'Broome', 'Broome', 'BME,Broome,Brum,beulum,bruma,brumi,brwm,bu lu mu,burumu,Брум,ברום,ब्रूम,ბრუმი,ブルーム,布鲁姆,브룸', -17.9553800, 122.2392200, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3955, 'Brighton', 'Brighton', 'Brighton', -35.0182000, 138.5235100, 'AU', '2014-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3956, 'Bridgewater', 'Bridgewater', 'Bridgewater', -35.0000000, 138.7500000, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3957, 'Bridgetown', 'Bridgetown', 'Bridgetown,برج ٹاؤن، مغربی آسٹریلیا', -33.9624200, 116.1359800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3958, 'Boyup Brook', 'Boyup Brook', 'Boyup Brook', -33.8342500, 116.3877600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3959, 'Boyanup', 'Boyanup', 'Boyanup', -33.4829500, 115.7283800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3960, 'Boulder', 'Boulder', '', -30.7820400, 121.4912000, 'AU', '2017-04-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3961, 'Blackwood', 'Blackwood', 'Blackwood', -35.0213900, 138.6142900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3962, 'Birkenhead', 'Birkenhead', 'Birkenhead', -34.8368500, 138.4978800, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3963, 'Birdwood', 'Birdwood', 'Birdwood', -34.8182600, 138.9647800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3964, 'Beverley', 'Beverley', 'Beverley', -32.1083900, 116.9273600, 'AU', '2014-12-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3965, 'Bentley', 'Bentley', 'Bentley', -32.0000000, 115.9166700, 'AU', '2015-03-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3966, 'Bellevue', 'Bellevue', '', -31.9000000, 116.0166700, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3967, 'Belair', 'Belair', 'Belair', -34.9976600, 138.6207700, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3968, 'Bedford Park', 'Bedford Park', 'Bedford Park', -35.0333300, 138.5666700, 'AU', '2012-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3969, 'Bedfordale', 'Bedfordale', '', -32.1740600, 116.0504000, 'AU', '2015-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3970, 'Beaumont', 'Beaumont', 'Beaumont', -34.9489900, 138.6618800, 'AU', '2012-07-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3971, 'Bassendean', 'Bassendean', 'Bassendean', -31.9090600, 115.9437000, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3972, 'Balhannah', 'Balhannah', 'Balhannah', -34.9909400, 138.8256500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3973, 'Balaklava', 'Balaklava', 'Balaklava,balaklawa,Балаклава,بالاکلاوا', -34.1454200, 138.4114800, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3974, 'Australind', 'Australind', 'Australind', -33.2792000, 115.7150400, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3975, 'Augusta', 'Augusta', 'Augusta,ao gu si ta,آگسٹا، مغربی آسٹریلیا,奧古斯塔', -34.3156600, 115.1592200, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3976, 'Armadale', 'Armadale', 'Armadale,Armadejl,Армадейл', -32.1460700, 116.0093000, 'AU', '2015-08-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3977, 'Ardrossan', 'Ardrossan', 'Androssan,Ardrossan,Port Androssan,Ардроссан', -34.4221700, 137.9190700, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3978, 'Applecross', 'Applecross', '', -32.0166700, 115.8333300, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3979, 'Angle Vale', 'Angle Vale', 'Angle Vale', -34.6409800, 138.6461000, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3980, 'Angaston', 'Angaston', 'Angaston,angastwn,Ангастон,انگاستون', -34.5012900, 139.0462500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3981, 'Alice Springs', 'Alice Springs', 'ASP,Alice Springs,Alice Springs Region,Alis Springs,Alis-Springs,Alisspringsa,Elis Springsas,Springs,Stuart,aelliseuseupeulingseu,ai li si ping,ai li si quan,alys aspryngz,arisusupuringusu,ayls sprngz,Алис Спрингс,Алис-Спрингс,Аліс-Спрінгс,אליס ספרינגס,آلیس اسپرینگز,ایلس سپرنگز,ॲलिस स्प्रिंग्ज,ალის-სპრინგსი,アリススプリングス,愛麗斯泉,愛麗絲坪,앨리스스프링스', -23.6974800, 133.8836200, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3982, 'Aldinga', 'Aldinga', 'Aldinga', -35.2833300, 138.4833300, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3983, 'Aldgate', 'Aldgate', 'Aldgate', -35.0166700, 138.7333300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3984, 'Albany', 'Albany', 'ALH,Albani,Albany,Olbani,albany,ao ban ni,arubani,olbani,olbeoni,Албани,Олбани,Олбані,אולבני,ألباني,ئاڵبانی، ڕۆژاوای ئوسترالیا,البانی,البانی، مغربی آسٹریلیا,ოლბანი,アルバニー,奧班尼,올버니', -35.0269200, 117.8836900, 'AU', '2017-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3985, 'Adelaide', 'Adelaide', 'ADL,Adelaida,Adelaidae,Adelaide,Adelaidis,Adelaidė,Adelajda,Adelajdo,Adelaïda,Adelaïde,Adelejd,Adelàida,Adélaïde,Edelaid,Gorad Adehlaida,Tarndanya,Tarndarnya,a de lai de,adelaida,aderedo,adilaid,adiled,adlayd,adylyd,aedeulleideu,atileyit,edile''ida,edileda,Αδελαΐδα,Аделаидæ,Аделаида,Аделаїда,Аделейд,Аделејд,Горад Адэлаіда,Ադելաիդա,אדלייד,آدلاید,أديليد,ئادېلايدې,ایڈیلیڈ,एडिलेड,ॲdaleda,ॲडलेड,એડિલેઇડ,அடிலெயிட்,అడిలైడ్,ಅಡಿಲೇಡ್,അഡിലെയ്‌ഡ്,แอดิเลด,အက်ဒလိတ်မြို့,ადელაიდა,アデレード,阿德来得,阿德莱德,애들레이드', -34.9286600, 138.5986300, 'AU', '2014-07-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3986, 'Dunsborough', 'Dunsborough', '', -33.6151200, 115.1056100, 'AU', '2015-05-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3987, 'Eaton', 'Eaton', 'Eaton', -33.3166400, 115.7050300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3988, 'Seacliff', 'Seacliff', 'Seacliff', -35.0347400, 138.5228800, 'AU', '2014-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3989, 'Clapham', 'Clapham', 'Clapham', -34.9898900, 138.6015800, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3990, 'Two Rocks', 'Two Rocks', 'Two Rocks', -31.4998500, 115.5873700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3991, 'Quinns Rocks', 'Quinns Rocks', '', -31.6737900, 115.7037200, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3992, 'East Fremantle', 'East Fremantle', '', -32.0382300, 115.7676000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3993, 'Peppermint Grove', 'Peppermint Grove', '', -31.9987800, 115.7682000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3994, 'Claremont', 'Claremont', '', -31.9796100, 115.7823000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3995, 'Bicton', 'Bicton', 'Bicton', -32.0277800, 115.7833300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3996, 'Attadale', 'Attadale', 'Attadale', -32.0248900, 115.8020000, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3997, 'Shenton Park', 'Shenton Park', 'Shenton Park', -31.9583300, 115.7972200, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3998, 'Dalkeith', 'Dalkeith', '', -31.9951700, 115.7998000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(3999, 'Jurien Bay', 'Jurien Bay', 'Dzhurien-Bej,JUR,Jurien,Jurien Bay,zhu li en wan,Джуріен-Бей,朱里恩灣', -30.3059100, 115.0382500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4000, 'Warnbro', 'Warnbro', 'Warnbro', -32.3401700, 115.7473000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4001, 'Mullaloo', 'Mullaloo', '', -31.7789600, 115.7367600, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4002, 'Alyangula', 'Alyangula', 'Alyangula', -13.8541300, 136.4212900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4003, 'Stuart Park', 'Stuart Park', 'Stuart Park', -12.4486000, 130.8424900, 'AU', '2016-09-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4004, 'Larrakeyah', 'Larrakeyah', '', -12.4552700, 130.8317200, 'AU', '2013-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4005, 'Leanyer', 'Leanyer', 'Leanyer', -12.3666700, 130.9000000, 'AU', '2013-07-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4006, 'Ludmilla', 'Ludmilla', '', -12.4203200, 130.8550600, 'AU', '2013-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4007, 'Fannie Bay', 'Fannie Bay', '', -12.4227500, 130.8362700, 'AU', '2013-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4008, 'Nightcliff', 'Nightcliff', 'Nightcliff', -12.3829900, 130.8517000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4009, 'Glen Iris', 'Glen Iris', '', -33.3371300, 115.6743000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4010, 'Lower King', 'Lower King', '', -34.9577800, 117.9383300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4011, 'Young', 'Young', 'NGA,Young,ینگ، نیو ساؤتھ ویلز', -34.3135000, 148.3010700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4012, 'Yeppoon', 'Yeppoon', 'Eppun,Yeppoon,Еппун', -23.1268300, 150.7440600, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4013, 'Yatala', 'Yatala', 'Yatala', -27.7166700, 153.2166700, 'AU', '2015-02-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4014, 'Yass', 'Yass', 'Jass,Yass,Ясс', -34.8403600, 148.9098700, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4015, 'Yarrawonga', 'Yarrawonga', 'Jarravonga,Yarrawonga,Ярравонга', -36.0192300, 145.9997300, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4016, 'Yarraville', 'Yarraville', '', -37.8166700, 144.9000000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4017, 'Yarraman', 'Yarraman', 'Yarraman', -26.8416700, 151.9813800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4018, 'Yarra Junction', 'Yarra Junction', 'Yarra Junction', -37.7819200, 145.6143000, 'AU', '2015-01-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4019, 'Yarra Glen', 'Yarra Glen', 'Yarra Glen', -37.6579400, 145.3741600, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4020, 'Yandina', 'Yandina', 'Yandina', -26.5616500, 152.9559500, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4021, 'Wynyard', 'Wynyard', 'Wynyard', -40.9897000, 145.7261700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4022, 'Wynnum', 'Wynnum', 'Wynnum', -27.4452700, 153.1581300, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4023, 'Worrolong', 'Worrolong', '', -37.8061900, 140.8480300, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4024, 'Woree', 'Woree', 'Woree', -16.9500000, 145.7500000, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4025, 'Woori Yallock', 'Woori Yallock', 'Woori Yallock', -37.7806200, 145.5381900, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4026, 'Woorim', 'Woorim', 'Woorim', -27.0693100, 153.2042700, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4027, 'Woombye', 'Woombye', 'Wombye,Woombye', -26.6605400, 152.9694700, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4028, 'Woolgoolga', 'Woolgoolga', 'Woogoolga,Woolgoolga', -30.1105800, 153.2006700, 'AU', '2011-10-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4029, 'Woodridge', 'Woodridge', 'Woodridge', -27.6333300, 153.1000000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4030, 'Woodford', 'Woodford', 'Woodford', -26.9529100, 152.7774700, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4031, 'Wondai', 'Wondai', 'WDI,Wondai', -26.3177000, 151.8724200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4032, 'Wodonga', 'Wodonga', 'Uodonga,Wodonga,uodonga,wo dong jia,wo tong ge,wodong-ga,wwdwnga,Уодонга,وودونگا,ووڈونگا,ویڈانگا,وێدانگا,უოდონგა,沃东加,窝同搿,워동가', -36.1217900, 146.8880900, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4033, 'Windsor', 'Windsor', '', -37.8534400, 144.9924100, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4034, 'Windaroo', 'Windaroo', 'Windaroo', -27.7333300, 153.2000000, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4035, 'Williamstown', 'Williamstown', 'Uil''jamstaun,Uill''jamstaun,wei lian si dun,Уилльямстаун,Уильямстаун,ولیمزٹاؤن، وکٹوریہ,威廉斯頓', -37.8634900, 144.8990000, 'AU', '2017-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4036, 'Whittlesea', 'Whittlesea', 'Uitlsi,Whittlesea,Уитлси', -37.5115200, 145.1183600, 'AU', '2015-01-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4037, 'West Wyalong', 'West Wyalong', 'WWY,West Wyalong', -33.9237300, 147.2047300, 'AU', '2013-10-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4038, 'Westcourt', 'Westcourt', '', -26.8000000, 150.1500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4039, 'Westbury', 'Westbury', 'Vestburi,Westbury,Вестбури', -41.5291400, 146.8391400, 'AU', '2014-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4040, 'Westbrook', 'Westbrook', 'Westbrook', -27.6166700, 151.8666700, 'AU', '2013-11-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4041, 'Werribee', 'Werribee', 'Werribee,wei lei bi,威勒比', -37.9000000, 144.6666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4042, 'Wellington Point', 'Wellington Point', 'Wellington Point', -27.4833300, 153.2500000, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4043, 'Wellington', 'Wellington', 'Vellington,Wellington,Веллингтон', -32.5558800, 148.9450800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4044, 'Weipa', 'Weipa', 'Uehjpa,WEI,Weipa,u~eipa,weipa,Уэйпа,ウェイパ,웨이파', -12.6234600, 141.8788300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4045, 'Wattleglen', 'Wattleglen', 'Wattle Glen', -37.6666700, 145.1833300, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4046, 'Watsonia', 'Watsonia', '', -37.7166700, 145.0833300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4047, 'Warwick', 'Warwick', 'Uorik,WAZ,Warwick,u~orikku,Уорик,ウォリック', -28.2190100, 152.0343800, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4048, 'Warrnambool', 'Warrnambool', 'Gouornampoul,Uornambul,Vornambul,WMB,Warrnambool,uornambuli,u~onanburu,varanambula,warnambwl,warnmbwl,Γουόρναμπουλ,Ворнамбул,Уорнамбул,ווארנאמבול,وارنامبول,وارنمبول,وارنمبووڵ,वारनाम्बूल,უორნამბული,ウォーナンブール', -38.3817600, 142.4879900, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4049, 'Warrane', 'Warrane', 'Warrane', -42.8554600, 147.3829700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4050, 'Warrandyte', 'Warrandyte', 'Warrandyte,fa lang dai tuo,伐朗代脫', -37.7500000, 145.2333300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4051, 'Warragul', 'Warragul', 'Uorragul,Warragul,fa la gu lei,waragl,Уоррагул,واراگل,伐拉古嘞', -38.1591200, 145.9311800, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4052, 'Wantirna South', 'Wantirna South', '', -37.8833300, 145.2166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4053, 'Wantirna', 'Wantirna', '', -37.8500000, 145.2166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4054, 'Wangaratta', 'Wangaratta', 'Uangaratta,Vangaratta,WGT,Wangaratta,Вангаратта,Уангаратта,وانگاراٹا,وانگاراٹا، وکٹوریہ,وانگراتا، ڤیکتۆریا,უონგარატა', -36.3584600, 146.3205600, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4055, 'Walkerston', 'Walkerston', 'Walkerston', -21.1609700, 149.0581400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4056, 'Wagga Wagga', 'Wagga Wagga', 'Uaga Uaga,Uoaqqa-Uoaqqa,Uogga Uogga,Uogga-Uogga,Vaga Vaga,Vagga-Vagga,Voga Voga,WGA,Wagga,Wagga Wagga,uaga-uaga,u~ogau~oga,vagga vagga,waga waga,wagawaga,waqa waqa,wo jia wo jia,Вагга-Вагга,Вога Вога,Уага Уага,Уогга Уогга,Уогга-Уогга,וואגה וואגה,واقا واقا,واگا واگا,वाग्गा वाग्गा,უაგა-უაგა,ウォガウォガ,沃加沃加,와가와가', -35.1257700, 147.3537500, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4057, 'Wacol', 'Wacol', 'Wacol,Wolston', -27.5833300, 152.9333300, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4058, 'Victoria Point', 'Victoria Point', 'Victoria Point', -27.5832900, 153.3117200, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4059, 'Vermont', 'Vermont', '', -37.8361600, 145.1942800, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4060, 'Urraween', 'Urraween', '', -25.2880900, 152.7676000, 'AU', '2017-01-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4061, 'Urangan', 'Urangan', 'Urangan', -25.2921400, 152.9053500, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4062, 'Upwey', 'Upwey', '', -37.9000000, 145.3333300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4063, 'Upper Coomera', 'Upper Coomera', 'Upper Coomera', -27.9000000, 153.3000000, 'AU', '2015-02-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4064, 'Ulverstone', 'Ulverstone', 'Ulverston,Ulverstone,Улверстон', -41.1602600, 146.1824200, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4065, 'Ulladulla', 'Ulladulla', 'Ulladulla,Улладулла', -35.3590600, 150.4724700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4066, 'Tyabb', 'Tyabb', 'Tyabb', -38.2500000, 145.1833300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4067, 'Tumut', 'Tumut', 'T''jumut,TUM,Tumut,Тьюмут', -35.3001600, 148.2250500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4068, 'Tumbi Vmbi', 'Tumbi Vmbi', 'Tumbi Umbi', -33.3666700, 151.4500000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4069, 'Tullamarine', 'Tullamarine', 'twlhmryn,טולהמרין', -37.7012800, 144.8810000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4070, 'Tugun', 'Tugun', 'Tugun', -28.1500000, 153.5000000, 'AU', '2015-02-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4071, 'Truganina', 'Truganina', 'Truganina', -37.8166700, 144.7500000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4072, 'Trinity Beach', 'Trinity Beach', '', -16.7887600, 145.6968200, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4073, 'Tremont', 'Tremont', 'Tremont', -37.9000000, 145.3333300, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4074, 'Traralgon', 'Traralgon', 'TGN,Traralgon,ta la lei gong,traralgn,Траралгон,טרארלגון,ترارالگن,ٹرارالگن,ٹرارالگون,ტრარალგონი,他拉嘞共', -38.1952800, 146.5415000, 'AU', '2017-07-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4075, 'Townsville', 'Townsville', 'TSV,Taunsvil,Taunsvil'',Taunsvilis,Taunsvill,Townsville,ta''unsavhila,ta''unsavila,tang shi wei lu,tang si wei er,taunjeubil,taunzubiru,tawnsfyl,tawnzvyl,tawnzwyl,Таунсвил,Таунсвилл,Таунсвіль,טאונסוויל,تاونزویل,تاونزڤیل,تاونسفيل,ٹاؤنزویلی,ٹاؤنسول,टाउन्सविल,टाउन्सव्हिल,ტაუნზვილი,タウンズビル,汤斯维尔,湯士威路,타운즈빌', -19.2663900, 146.8056900, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4076, 'Torquay', 'Torquay', 'Torquay', -25.2849600, 152.8788600, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4077, 'Toowoomba', 'Toowoomba', 'TWB,Toowoomba,Tuuomba,Tuvumba,teoumba,to~unba,tu wen ba,tuvumba,tuvumpa,twwmba,twwwmba,Тувумба,Тууомба,توومبا,تووومبا,ٹوومبا,ٹووومبا,तूवूम्बा,துவும்பா,ტუვუმბა,トゥーンバ,图文巴,터움바', -27.5605600, 151.9538600, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4078, 'Toorak', 'Toorak', '', -37.8416500, 145.0143800, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4079, 'Tooradin', 'Tooradin', 'Tooradin', -38.2147500, 145.3832500, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4080, 'Toolooa', 'Toolooa', '', -23.9333300, 151.2833300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4081, 'Tolga', 'Tolga', 'Tolga', -17.2333300, 145.4833300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4082, 'Tin Can Bay', 'Tin Can Bay', 'Tin Can Bay,Tin Kehn Behj,Тин Кэн Бэй', -25.9191400, 153.0032000, 'AU', '2017-01-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4083, 'Thornbury', 'Thornbury', '', -37.7500000, 145.0000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4084, 'Thomastown', 'Thomastown', '', -37.6833300, 145.0166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4085, 'The Entrance', 'The Entrance', 'Ehntrans,The Entrance,Энтранс', -33.3387600, 151.4978000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4086, 'The Basin', 'The Basin', '', -37.8500000, 145.3166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4087, 'Thagoona', 'Thagoona', 'Thagoona', -27.6333300, 152.6333300, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4088, 'Thabeban', 'Thabeban', '', -24.9000000, 152.3500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4089, 'Tewantin', 'Tewantin', 'TWN,Tewantin', -26.3910400, 153.0343200, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4090, 'Templestowe Lower', 'Templestowe Lower', 'Lower Templestowe,Templestowe Lower', -37.7666700, 145.1166700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4091, 'Tarragindi', 'Tarragindi', 'Tarragindi', -27.5333300, 153.0333300, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4092, 'Taroona', 'Taroona', 'Taroona', -42.9452000, 147.3484000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4093, 'Taroom', 'Taroom', 'Taroom,Tarum,XTO,Тарум', -25.6392500, 149.7998000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4094, 'Tarneit', 'Tarneit', '', -37.8666700, 144.6666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4095, 'Taree', 'Taree', 'TRO,Taree,Tari,Тари,Тарі', -31.9109900, 152.4538700, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4096, 'Tamworth', 'Tamworth', 'TMW,Tamuort,Tamvort,Tamworth,Tehmuortch,ta mu wo si,tamwrth,Тамворт,Тамуорт,Тэмуортч,טאמוורת,تام وۆرس,تامورث,ٹیمورتھ,ٹیمورتھ، نیو ساؤتھ ویلز,ტამუერთი,塔姆沃思', -31.0904800, 150.9290500, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4097, 'Tallebudgera', 'Tallebudgera', '', -28.1500000, 153.4333300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4098, 'Sydney', 'Sydney', 'Gorad Sidnej,SYD,Sanctus Dionysius,Sedniejos,Sek-na,Sidnef,Sidnei,Sidnej,Sidneja,Sidnejo,Sidnejus,Sidney,Sidneý,Sidni,Sidnéy,Sidnėjus,Sit-ni,Sit-nì,Syd,Sydneium,Sydney,Sydney City,Sék-nà̤,Sídney,Sîdney,Sėdniejos,citni,shidoni,sidani,sideuni,sidnei,sidni,sidniy,sydny,xi ni,xue li,Σίδνεϋ,Горад Сідней,Сиднеи,Сидней,Сиднеј,Сидни,Сідней,Сідні,Սիդնեյ,סידני,سيدنى,سيدني,سڈنی,سیدنی,ܣܝܕܢܝ,सिडनी,सिड्नी,सिद्नी,সিডনি,ਸਿਡਨੀ,સીડની,சிட்னி,సిడ్నీ,ಸಿಡ್ನಿ,സിഡ്നി,සිඩ්නි,ซิดนีย์,སིད་ནེ།,ဆစ်ဒနီမြို့,სიდნეი,ሲድኒ,ស៊ីដនីយ៏,シドニー,悉尼,雪梨,시드니', -33.8678500, 151.2073200, 'AU', '2016-07-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4099, 'Sydenham', 'Sydenham', '', -37.7000000, 144.7666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4100, 'Swan Hill', 'Swan Hill', 'SWH,Suon-Khill,suon-hili,swan hyl,tian e shan,Суон-Хилл,سوان هیل,سوان ہل,سوان ہل، وکٹوریہ,სუონ-ჰილი,天鵝山', -35.3378100, 143.5544000, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4101, 'Surrey Hills', 'Surrey Hills', '', -37.8166700, 145.1000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4102, 'Surfers Paradise', 'Surfers Paradise', 'SFP,Sjorfers Paradajz,Surfers Paradise,srfrz paradayz  kwyynzlnd,srprz prdyyz,Сёрферс Парадайз,Сөрферс Парадайс,סרפרז פרדייז,سرفرز پارادایز، کوئینزلند', -28.0027400, 153.4299900, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4103, 'Sunnybank', 'Sunnybank', 'Sunnybank,sen ni ban ke,森尼班克', -27.5833300, 153.0500000, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4104, 'Sunbury', 'Sunbury', 'Sanberi,Sunbury,sunburi,Санбери,სუნბური', -37.5774200, 144.7260700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4105, 'Strathpine', 'Strathpine', '', -27.3041400, 152.9897700, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4106, 'Port Stephens', 'Port Stephens', '', -32.7131400, 152.0662300, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4107, 'Stawell', 'Stawell', 'SWC,Stawell,Stoehll,Стоэлл', -37.0563200, 142.7808800, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4108, 'Stanthorpe', 'Stanthorpe', 'SNH,Stanthorpe,Stehntkhorp,Стэнтхорп', -28.6542500, 151.9338800, 'AU', '2014-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4109, 'Springvale South', 'Springvale South', 'Springvale South', -37.9666700, 145.1500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4110, 'Springvale', 'Springvale', 'Springvale', -37.9485300, 145.1527400, 'AU', '2016-11-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4111, 'Spring Hill', 'Spring Hill', '', -27.4614100, 153.0231100, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4112, 'Spotswood', 'Spotswood', '', -37.8297500, 144.8851600, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4113, 'Werribee South', 'Werribee South', 'South Werribee,Werribee South', -37.9475000, 144.7166700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4114, 'Southport', 'Southport', 'SHQ,Southport,nan gang,南港', -27.9672400, 153.3979600, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4115, 'South Melbourne', 'South Melbourne', 'Melbourne South,South Melbourne', -37.8333300, 144.9666700, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4116, 'South Grafton', 'South Grafton', '', -29.7076000, 152.9262700, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4117, 'Sorrento', 'Sorrento', 'Sorrento,Сорренто', -38.3395800, 144.7412600, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4118, 'Sorell', 'Sorell', 'Midway Point,Sorell', -42.7816100, 147.5626700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4119, 'Somerville', 'Somerville', '', -38.2166700, 145.1666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4120, 'Somers', 'Somers', 'Somers', -38.4000000, 145.1666700, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4121, 'Smithton', 'Smithton', 'SIO,Smithton,Smitton,Смиттон', -40.8458700, 145.1249800, 'AU', '2014-03-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4122, 'Slacks Creek', 'Slacks Creek', 'Slacks Creek', -27.6500000, 153.1500000, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4123, 'Singleton', 'Singleton', 'SIX,Singleton,Singlton,Синглтон', -32.5674200, 151.1660300, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4124, 'Shorncliffe', 'Shorncliffe', '', -27.3275900, 153.0816100, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4125, 'Shepparton', 'Shepparton', 'Mooroopna,SHT,Sheparton,Shepparton,separtana,sprtwn,Шепартон,Шеппартон,שפרטון,شیپارٹن,شێپێرتن، ڤیکتۆریا,शेपार्टन,შეპარტონი', -36.3804700, 145.3986700, 'AU', '2017-03-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4126, 'Shellharbour Village', 'Shellharbour Village', 'Shellharbour,Shellharbour Village', -34.5833300, 150.8666700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4127, 'Sheffield', 'Sheffield', 'Sheffield,Sheffild,Шеффилд', -41.3994700, 146.3389700, 'AU', '2014-03-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4128, 'Sharon', 'Sharon', 'Sharon', -24.8759300, 152.2699400, 'AU', '2013-11-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4129, 'Selby', 'Selby', 'Selby', -37.9166700, 145.3833300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4130, 'Sebastopol', 'Sebastopol', 'Sebastopol', -37.5853200, 143.8395300, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4131, 'Seaford', 'Seaford', 'Seaford', -38.1000000, 145.1333300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4132, 'Scottsdale', 'Scottsdale', 'Scottsdale', -41.1578000, 147.5172700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4133, 'Scoresby', 'Scoresby', 'Scoresby', -37.9000000, 145.2333300, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4134, 'Scarness', 'Scarness', '', -25.2840500, 152.8560000, 'AU', '2016-01-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4135, 'Sawtell', 'Sawtell', 'Sawtell', -30.3645900, 153.1014100, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4136, 'Sarina', 'Sarina', 'Sarina,Сарина', -21.4191000, 149.2167700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4137, 'Sandgate', 'Sandgate', '', -27.3219800, 153.0695100, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4138, 'Sandford', 'Sandford', 'Sandford', -42.9333300, 147.5000000, 'AU', '2012-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4139, 'Sale', 'Sale', 'SXE,Sale,Sejl,sale,seil,syl,Сейл,سیل,سیل، وکٹوریہ,سێیڵ، ڤیکتۆریا,სალე,세일', -38.1109500, 147.0680200, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4140, 'Saint Kilda', 'Saint Kilda', 'Saint Kilda,St Kilda', -37.8676000, 144.9809900, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4141, 'St Helens', 'St Helens', 'HLS,Sent-Khelens,Сент-Хеленс', -41.3202800, 148.2388900, 'AU', '2012-01-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4142, 'Saint Helena', 'Saint Helena', '', -37.7000000, 145.1333300, 'AU', '2016-03-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4143, 'Saint Andrews', 'Saint Andrews', 'Queenstown,Saint Andrews,St Andrews', -37.6015100, 145.2723500, 'AU', '2015-01-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4144, 'Saint Albans', 'Saint Albans', 'Saint Albans', -37.7333300, 144.8000000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4145, 'Rye', 'Rye', 'Rye', -38.3666700, 144.8166700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4146, 'Rutherford', 'Rutherford', '', -32.7166700, 151.5333300, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4147, 'Rowville', 'Rowville', '', -37.9333300, 145.2333300, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4148, 'Rosebud', 'Rosebud', 'Rosebud', -38.3554200, 144.9068000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4149, 'Rosebery', 'Rosebery', 'Rosebery,Rozberi,Розбери', -41.7794100, 145.5382500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4150, 'Rosanna', 'Rosanna', '', -37.7500000, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4151, 'Roma', 'Roma', 'RMA,Roma,luo ma,罗马', -26.5674100, 148.7875100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4152, 'Rokeby', 'Rokeby', '', -42.8987500, 147.4491700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4153, 'Rocklea', 'Rocklea', '', -27.5391700, 153.0040200, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4154, 'Rockhampton', 'Rockhampton', 'ROK,Rockhampton,Rokgempton,Rokkhempton,luo kan pu dun,rakhmptwn,rokahampatana,Рокгемптон,Рокхемптон,רוקהאמפטון,راکهمپتون,راکہیمپٹن,راکہیمپٹون,ڕاکھەمپتن,रोकहाम्पटन,როკჰემპტონი,洛坎普頓', -23.3803200, 150.5059500, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4155, 'Rockbank', 'Rockbank', '', -37.7335300, 144.6700300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4156, 'Riverview', 'Riverview', 'Riverview', -27.6000000, 152.8500000, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4157, 'Riverstone', 'Riverstone', 'Riverstone', -33.6833300, 150.8666700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4158, 'Ripponlea', 'Ripponlea', '', -37.8833300, 145.0000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4159, 'Ringwood East', 'Ringwood East', '', -37.8166700, 145.2500000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4160, 'Richmond', 'Richmond', 'Richmond', -37.8181900, 145.0017600, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4161, 'Richmond', 'Richmond', 'Richmond,lichimeondeu,richmondi,Ричмонд,რიჩმონდი,리치먼드', -33.5995600, 150.7514200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4162, 'Rhodes', 'Rhodes', 'Rhodes', -33.8266300, 151.0881000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4163, 'Revesby', 'Revesby', 'Revesby', -33.9500000, 151.0166700, 'AU', '2014-04-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4164, 'Reservoir', 'Reservoir', 'Reservoir', -37.7166700, 145.0000000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4165, 'Research', 'Research', 'Research', -37.7000000, 145.1833300, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4166, 'Renmark West', 'Renmark West', '', -34.1653100, 140.7097000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4167, 'Renmark', 'Renmark', 'RMK,Renmark,rnmark  astralyay jnwby,Ренмарк,رنمارک، استرالیای جنوبی', -34.1770200, 140.7469700, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4168, 'Regents Park', 'Regents Park', 'Regents Park', -33.8833300, 151.0166700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4169, 'Redlynch', 'Redlynch', '', -16.8833300, 145.7000000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4170, 'Redland Bay', 'Redland Bay', '', -27.6113000, 153.3002200, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4171, 'Red Hill', 'Red Hill', '', -20.3166700, 148.5000000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4172, 'Redhead', 'Redhead', 'Redhead', -33.0117800, 151.7114200, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4173, 'Redfern', 'Redfern', 'rdprn,רדפרן', -33.8927900, 151.2041500, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4174, 'Redbank', 'Redbank', 'Redbank', -27.6000000, 152.8666700, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4175, 'Raworth', 'Raworth', '', -32.7333300, 151.6166700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4176, 'Ravenshoe', 'Ravenshoe', 'Ravenshoe', -17.6090100, 145.4841300, 'AU', '2016-08-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4177, 'Rathmines', 'Rathmines', 'Rathmines', -33.0377300, 151.5844300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4178, 'Quirindi', 'Quirindi', 'Quirindi,UIR', -31.5076300, 150.6790200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4179, 'Queenstown', 'Queenstown', 'Kuinstaun,Kvinstaun,Queenstown,UEE,Квинстаун,Куинстаун', -42.0805000, 145.5564600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4180, 'Queenscliff', 'Queenscliff', 'Kvinskliff,Queenscliff,Квинсклифф', -38.2678900, 144.6619300, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4181, 'Queanbeyan', 'Queanbeyan', 'Kuinbejan,Kuinbian,Kvinbijan,Queanbeyan,kun bi en,kwynbyan,Квинбијан,Куинбеян,Куинбиан,کوینبیان,კუნიბეი,昆比恩', -35.3549300, 149.2320000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4182, 'Quakers Hill', 'Quakers Hill', '', -33.7333300, 150.8833300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4183, 'Pymble', 'Pymble', 'Pymble', -33.7438600, 151.1418800, 'AU', '2014-09-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4184, 'Proserpine', 'Proserpine', 'PPP,Proserpajn,Proserpine,pu la se pan,Просерпайн,普拉瑟潘', -20.4011000, 148.5802000, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4185, 'Preston', 'Preston', 'Preston', -37.7500000, 145.0166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4186, 'Port Sorell', 'Port Sorell', 'Port Sorell,Порт Сорелл', -41.1665200, 146.5528300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4187, 'Port Melbourne', 'Port Melbourne', 'Sandridge', -37.8396100, 144.9422800, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4188, 'Port Macquarie', 'Port Macquarie', 'PQQ,Port Macquarie,Port Makkuori,Port Makvori,mai jue li gang,porta makvari,Порт Маквори,Порт Маккуори,پورٹ مکوائری,पोर्ट मक्वारी,პორტ-მაკუარი,麥覺理港', -31.4308400, 152.9089400, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4189, 'Portland', 'Portland', 'PTJ,Portland,Portlend,Портленд,پورٹلینڈ,پورٹلینڈ، وکٹوریہ,پۆرتلەند، ڤیکتۆریا', -38.3462000, 141.6025700, 'AU', '2016-10-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4190, 'Portland', 'Portland', 'Portland', -33.3570900, 149.9814800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4191, 'Port Kembla', 'Port Kembla', 'Port Kembla', -34.4818000, 150.9012000, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4192, 'Port Fairy', 'Port Fairy', 'Port Fairy,Port-Fehri,Порт-Фэри', -38.3853500, 142.2371000, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4193, 'Port Douglas', 'Port Douglas', 'PTI,Port Douglas,Port Duglas,Port-Duglas,poteudeogeullaseu,potodagurasu,Порт Дуглас,Порт-Дуглас,ポートダグラス,포트더글라스', -16.4838300, 145.4672500, 'AU', '2015-04-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4194, 'Point Cook', 'Point Cook', '', -37.9148200, 144.7508800, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4195, 'Point Clare', 'Point Clare', 'Point Clare', -33.4437800, 151.3273200, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4196, 'Plenty', 'Plenty', '', -37.6666700, 145.1166700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4197, 'Pitt Town', 'Pitt Town', 'Pitt Town', -33.5871800, 150.8585700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4198, 'Picton', 'Picton', 'Gol Gol,Picton,Гол Гол', -34.1699500, 150.6116800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4199, 'Phillip', 'Phillip', '', -31.1333300, 150.8500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4200, 'Perthville', 'Perthville', 'Perthville', -33.4874100, 149.5464200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4201, 'Perth', 'Perth', 'Perth', -41.5723100, 147.1709600, 'AU', '2014-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4202, 'Penshurst', 'Penshurst', 'Penshurst', -33.9666700, 151.0833300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4203, 'Penrith', 'Penrith', 'Penrith,penrisu,პენრითი,ペンリス', -33.7500000, 150.7000000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4204, 'Penola', 'Penola', 'Penola,Пенола', -37.3752000, 140.8367800, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4205, 'Pennant Hills', 'Pennant Hills', '', -33.7378300, 151.0721600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4206, 'Penguin', 'Penguin', 'Penguin', -41.1225800, 146.0731800, 'AU', '2014-03-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4207, 'Peak Hill', 'Peak Hill', 'Peak Hill,Pik Khill,Пик Хилл', -32.7238700, 148.1905200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4208, 'Pascoe Vale', 'Pascoe Vale', '', -37.7333300, 144.9333300, 'AU', '2015-01-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4209, 'Parkville', 'Parkville', 'Parkville', -37.7833300, 144.9500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4210, 'Parkes', 'Parkes', 'PKE,Parkes,pa ke si,帕克斯', -33.1372000, 148.1759000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4211, 'Parkdale', 'Parkdale', '', -37.9833300, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4212, 'Palm Beach', 'Palm Beach', 'Palm Beach,Palm-Bich,zong lu hai tan,Палм-Бич,棕櫚海灘', -33.5966400, 151.3238400, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4213, 'Palm Beach', 'Palm Beach', '', -28.1169400, 153.4658400, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4214, 'Pakenham Upper', 'Pakenham Upper', '', -38.0166700, 145.5166700, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4215, 'Pakenham South', 'Pakenham South', '', -38.1333300, 145.5166700, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4216, 'Ouyen', 'Ouyen', 'OYN,Oujen,Ouyen,Оуйен', -35.0708700, 142.3203400, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4217, 'Ormond', 'Ormond', '', -37.9000000, 145.0333300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4218, 'Orange', 'Orange', 'OAG,Orandzh,Orange,Орандж', -33.2839700, 149.1001800, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4219, 'One Mile', 'One Mile', '', -27.6290200, 152.7376800, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4220, 'Olinda', 'Olinda', '', -37.8500000, 145.3666700, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4221, 'Old Beach', 'Old Beach', 'Old Beach,Oldbridzh,Олдбридж', -42.7775800, 147.2665900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4222, 'Old Bar', 'Old Bar', 'Old Bar,Олд Бар', -31.9694000, 152.5880700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4223, 'Officer', 'Officer', 'Officer', -38.0591600, 145.4094700, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4224, 'Oberon', 'Oberon', 'Oberon', -33.7039800, 149.8591500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4225, 'Oatley', 'Oatley', 'Oatley', -33.9800400, 151.0720100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4226, 'Oakey', 'Oakey', 'OKY,Oakey,Oaky', -27.4330500, 151.7206300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4227, 'Oakdale', 'Oakdale', 'Oakdale', -34.0793000, 150.5132000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4228, 'Nyngan', 'Nyngan', 'NYN,Nyngan', -31.5637500, 147.1937300, 'AU', '2017-05-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4229, 'Nunawading', 'Nunawading', '', -37.8204300, 145.1730800, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4230, 'Nowra', 'Nowra', 'NOA,Novra,Nowra,Nowra-Bomaderry,bldt nawra,novra,nuo la,nwwra,nwwra  yyny gwnyy wlz,Новра,بلدة ناورا,ناروا، نیو ساؤتھ ویلز,نوورا,نوورا، یئنی گونئی ولز,ნოვრა,諾拉', -34.8842200, 150.6003600, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4231, 'Notting Hill', 'Notting Hill', '', -37.9050000, 145.1427000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4232, 'North Wonthaggi', 'North Wonthaggi', '', -38.6000000, 145.6000000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4233, 'North Turramurra', 'North Turramurra', '', -33.7131300, 151.1463800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4234, 'North Sydney', 'North Sydney', 'North Sydney,Pak Sydney,nosushidoni,ノースシドニー', -33.8390000, 151.2072000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4235, 'North Melbourne', 'North Melbourne', 'Hotham,North Melbourne,Parkside', -37.8000000, 144.9666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4236, 'Northmead', 'Northmead', 'Northmead', -33.7833300, 150.9833300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4237, 'North Haven', 'North Haven', 'North Haven', -31.6368000, 152.8135700, 'AU', '2013-10-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4238, 'North Fitzroy', 'North Fitzroy', 'Fitzroy North,North Fitzroy', -37.7886200, 144.9788500, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4239, 'Northcote', 'Northcote', 'Northcote', -37.7666700, 145.0000000, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4240, 'Normanhurst', 'Normanhurst', 'Normanhurst', -33.7333300, 151.1000000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4241, 'Noosaville', 'Noosaville', 'NSV,Noosaville', -26.4000000, 153.0666700, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4242, 'Noosa Heads', 'Noosa Heads', 'Noosa,Noosa Heads', -26.3943300, 153.0901000, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4243, 'Noble Park', 'Noble Park', 'Noble Park', -37.9666700, 145.1666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4244, 'Nimbin', 'Nimbin', 'Nimbin', -28.5954500, 153.2233600, 'AU', '2016-09-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4245, 'Newtown', 'Newtown', 'xin zhen,ניוטאון,نیو ٹاؤن، نیو ساؤتھ ویلز,新镇', -33.8983500, 151.1775400, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4246, 'Newstead', 'Newstead', 'Newstead', -41.4333300, 147.1666700, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4247, 'Newport', 'Newport', '', -37.8442700, 144.8848300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4248, 'Newport', 'Newport', '', -33.6563900, 151.3140100, 'AU', '2016-12-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4249, 'New Norfolk', 'New Norfolk', 'N''ju-Norfolk,xin nuo fu ke,Нью-Норфолк,新诺福克', -42.7826100, 147.0587000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4250, 'Newnham', 'Newnham', 'Newnham', -41.3971400, 147.1312700, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4251, 'Newington', 'Newington', '', -37.5584600, 143.8248500, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4252, 'Newcastle', 'Newcastle', 'Avstralyn N''jukasl,Gorad N''jukasl,N''jukasl,NTL,Newcastle,Niukaslas,Njukasl,Njukasul,Novkastelo,n''yukesala,niu ka si er,niyukacil,nyukaeseul,nyukassuru,nyw kasl,nywkasl,nywkasl  nyw sawt wlz,nywkasl  yyny gwnyy wlz,Њукасл,Австралын Ньюкасл,Горад Ньюкасл,Ньюкасл,Нюкасъл,ניוקאסל,نيوكاسل,نیو کاسل,نیو کیسل، نیو ساؤتھ ویلز,نیوکاسل، نیو ساوت ولز,نیوکاسل، یئنی گونئی ولز,نیوکاسڵ,न्यूकॅसल,நியூகாசில்,ნიუკასლი,ニューカッスル,纽卡斯尔,뉴캐슬', -32.9271500, 151.7764700, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4253, 'Nerang', 'Nerang', 'Nerang', -27.9894100, 153.3363300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4254, 'Nelson Bay', 'Nelson Bay', 'Nel''son Behj,Nelson Bay,Nelson''s Bay,Nelson’s Bay,Нельсон Бэй', -32.7204300, 152.1439800, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4255, 'Narromine', 'Narromine', 'Narromine,QRM', -32.2312100, 148.2405200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4256, 'Narre Warren North', 'Narre Warren North', '', -37.9833300, 145.3166700, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4257, 'Narre Warren', 'Narre Warren', '', -38.0333300, 145.3000000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4258, 'Narrandera', 'Narrandera', 'NRA,Narrandera,Наррандера', -34.7475200, 146.5509600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4259, 'Narrabri', 'Narrabri', 'NAA,Narrabri,na la bu lai,纳拉布赖', -30.3248800, 149.7826600, 'AU', '2016-06-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4260, 'Narrabeen', 'Narrabeen', '', -33.7127700, 151.2973600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4261, 'Narooma', 'Narooma', 'Narooma,Naruma,Noorooma,QRX,bldt narwma,Нарума,بلدة ناروما', -36.2178300, 150.1324700, 'AU', '2016-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4262, 'Narellan', 'Narellan', 'Narellan', -34.0333300, 150.7333300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4263, 'Narara', 'Narara', 'Narara', -33.4000000, 151.3500000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4264, 'Narangba', 'Narangba', 'Narangba', -27.2033800, 152.9592300, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4265, 'Naracoorte', 'Naracoorte', 'NAC,Narakort,Наракорт', -36.9578500, 140.7383000, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4266, 'Nana Glen', 'Nana Glen', 'Nana Glen', -30.1333300, 153.0166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4267, 'Nambucca Heads', 'Nambucca Heads', 'NBH,Nambucca,Nambucca Heads,Namoucca Heads', -30.6431800, 153.0088400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4268, 'Nambucca', 'Nambucca', '', -30.6333300, 152.9833300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4269, 'Nambour', 'Nambour', 'Nambor,Nambour,nambueo,nan bo,nanbo,Намбор,ナンボー,楠伯,남부어', -26.6261300, 152.9594100, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4270, 'Nabiac', 'Nabiac', 'Nabiac', -32.0983700, 152.3762700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4271, 'Muswellbrook', 'Muswellbrook', 'Musclebrook,Muswellbrook', -32.2611800, 150.8900900, 'AU', '2016-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4272, 'Murwillumbah', 'Murwillumbah', 'Murwillumbah', -28.3273200, 153.3933900, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4273, 'Murrumbeena', 'Murrumbeena', '', -37.9000000, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4274, 'Murrumbateman', 'Murrumbateman', 'Morumbateman,Murrumbateman', -34.9719900, 149.0298500, 'AU', '2016-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4275, 'Mundulla', 'Mundulla', 'Mundalla,Mundulla', -36.3666700, 140.6833300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4276, 'Mulwala', 'Mulwala', 'Mulwala', -35.9853600, 146.0053400, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4277, 'Mulgrave', 'Mulgrave', 'Mulgrave', -37.9166700, 145.2000000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4278, 'Mulgoa', 'Mulgoa', 'Mulgoa', -33.8380000, 150.6496300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4279, 'Mudgee', 'Mudgee', 'DGE,Madzhi,Маджи', -32.5942600, 149.5871000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4280, 'Mount Pleasant', 'Mount Pleasant', '', -37.5833300, 143.8666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4281, 'Mount Martha', 'Mount Martha', 'Mount Martha', -38.2666700, 145.0166700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4282, 'Mount Gambier', 'Mount Gambier', 'Gambier Town,MGB,Maunt Gambir,Maunt-Gambier,Maunt-Gambir,Mont Gambier,Mount Gambier,Mt Gambier,Mt. Gambier,mang te gan bi er,maunteugaembieo,mauntoganbia,mwnt qambyr  gwnyy awstwralya,Маунт Гамбир,Маунт-Гамбиер,Маунт-Гамбир,Маунт-Гамбір,מאונט גמבייר,ماؤنٹ گمبیئر، جنوبی آسٹریلیا,ماؤنٹ گیمبیر,ماونت گەمبیێر,مونت قامبیر، گونئی اوستورالیا,მაუნტ-გამბირი,マウントガンビア,芒特甘比尔,마운트갬비어', -37.8318000, 140.7791900, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4283, 'Mount Evelyn', 'Mount Evelyn', 'Evelyn,Mount Evelyn', -37.7833300, 145.3833300, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4284, 'Mount Eliza', 'Mount Eliza', '', -38.1833300, 145.0833300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4285, 'Mount Druitt', 'Mount Druitt', 'Mount Druitt,Mt Druitt,Mt. Druitt', -33.7666700, 150.8166700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4286, 'Mount Dandenong', 'Mount Dandenong', '', -37.8333300, 145.3666700, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4287, 'Mount Colah', 'Mount Colah', 'Mount Colah', -33.6833300, 151.1166700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4288, 'Mount Clear', 'Mount Clear', '', -37.6000000, 143.8833300, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4289, 'Mount Beauty', 'Mount Beauty', 'Mount Beauty', -36.7362800, 147.1753100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4290, 'Moss Vale', 'Moss Vale', 'Moss Vale', -34.5537400, 150.3711500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4291, 'Mosman', 'Mosman', 'Mosman,mosamana,Мосман,मोसमान,ミュニシパリティ・オブ・モスマン', -33.8390200, 151.2395600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4292, 'Morwell', 'Morwell', 'Moruehll,Moruel,Morwell,morueli,mwrwl,Моруел,Моруэлл,مورول,موریل، وکٹوریہ,مۆروێڵ، ڤیکتۆریا,მორუელი', -38.2347600, 146.3949900, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4293, 'Moruya', 'Moruya', 'MYA,Moruya', -35.9125000, 150.0814400, 'AU', '2014-05-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4294, 'Mortdale', 'Mortdale', '', -33.9666700, 151.0833300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4295, 'Mornington', 'Mornington', 'Mornington,Морнингтон', -38.2179200, 145.0387600, 'AU', '2016-10-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4296, 'Moree', 'Moree', 'MRZ,Moree', -29.4627800, 149.8415700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4297, 'Mordialloc', 'Mordialloc', 'Mordialloc', -38.0000000, 145.0833300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4298, 'Morayfield', 'Morayfield', 'Morayfield', -27.1087600, 152.9490700, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4299, 'Moorooduc', 'Moorooduc', '', -38.2166700, 145.1166700, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4300, 'Moorabbin', 'Moorabbin', 'MBW', -37.9366700, 145.0341700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4301, 'Moonee Ponds', 'Moonee Ponds', 'Moni Pontz,Moonee Ponds,Μόνι Ποντζ', -37.7666700, 144.9166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4302, 'Moonee Beach', 'Moonee Beach', '', -30.2057500, 153.1529300, 'AU', '2011-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4303, 'Moonah', 'Moonah', 'Moonah', -42.8461700, 147.3022800, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4304, 'Mooloolaba', 'Mooloolaba', 'Alexandra-Mooloolaba,Mooloolaba,Mululaba,Мулулаба', -26.6816400, 153.1192500, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4305, 'Montrose', 'Montrose', '', -37.8166700, 145.3500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4306, 'Montmorency', 'Montmorency', '', -37.7166700, 145.1166700, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4307, 'Mont Albert', 'Mont Albert', 'Mont Albert', -37.8166700, 145.1000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4308, 'Monbulk', 'Monbulk', 'Monbulk', -37.8833300, 145.4000000, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4309, 'Monash', 'Monash', 'Monash', -34.2384000, 140.5613100, 'AU', '2013-09-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4310, 'Molong', 'Molong', 'Molong', -33.0923300, 148.8700200, 'AU', '2011-10-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4311, 'Moggill', 'Moggill', 'Moggill', -27.5833300, 152.8666700, 'AU', '2015-01-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4312, 'Moe', 'Moe', 'Moe,Moi,Yallourn,moe,Мои,موء,مۆیی، ڤیکتۆریا,მოე', -38.1782800, 146.2609900, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4313, 'Moama', 'Moama', 'Moama,Town of Moama', -36.1041300, 144.7608000, 'AU', '2016-01-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4314, 'Mittagong', 'Mittagong', 'Mittagong', -34.4500200, 150.4457200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4315, 'Mitcham', 'Mitcham', '', -37.8166700, 145.2000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4316, 'Miranda', 'Miranda', 'Miranda', -34.0385700, 151.1000500, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4317, 'Milton', 'Milton', 'Milton,Милтон', -35.3164400, 150.4361000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4318, 'Millthorpe', 'Millthorpe', 'Millthorpe', -33.4460100, 149.1853900, 'AU', '2011-10-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4319, 'Mill Park', 'Mill Park', '', -37.6666700, 145.0666700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4320, 'Millicent', 'Millicent', 'MLR,Millicent,Millisent,mirisento,Миллисент,ミリセント', -37.5938900, 140.3494700, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4321, 'Millgrove', 'Millgrove', 'Millgrove', -37.7552700, 145.6534700, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4322, 'Mildura', 'Mildura', 'MQL,Mild''jura,Mildjura,Mildura,mi er du la,mildiura,mildula,mildyura,mirude~yura,mldwra,myldwrh,Милдьюра,Милдјура,Միլդուրա,מילדורה,ملدورا,ملڈورہ,میلدۆرا,मिल्ड्युरा,მილდიურა,ミルデューラ,米爾杜拉,밀두라', -34.1855100, 142.1625100, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4323, 'Merrylands', 'Merrylands', 'Merrylands', -33.8333300, 150.9833300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4324, 'Merriwa', 'Merriwa', 'Merriwa', -32.1392200, 150.3556200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4325, 'Merimbula', 'Merimbula', 'MIM,Merimbula,Merrimbula,Меримбула', -36.8890100, 149.9096100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4326, 'Merricks', 'Merricks', 'Merrick,Merricks', -38.3833300, 145.0833300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4327, 'Mernda', 'Mernda', 'Mernda', -37.6007500, 145.0955500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4328, 'Mentone', 'Mentone', 'Mentone', -37.9833300, 145.0666700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4329, 'Menai', 'Menai', 'Menai', -34.0166700, 151.0166700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4330, 'Melton South', 'Melton South', '', -37.7077300, 144.5749300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4331, 'Melton', 'Melton', 'Melton,Мелтон,میلٹن,میلٹن، وکٹوریہ,მელტონი', -37.6833900, 144.5854300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4332, 'Melbourne', 'Melbourne', 'MEL,Mel''burn,Melbourne,Melbourne City,Melbournum,Melburn,Melburna,Melburnas,Melburno,Melvourni,mel beirn,melaborna,melbeoleun,melporn,meruborun,mlbwrn,mo er ben,Μελβούρνη,Мелбурн,Мелбърн,Мельбурн,מלבורן,ملبورن,مېلبۇرن,मेलबोर्न,மெல்போர்ன்,เมลเบิร์น,མེར་བུན,メルボルン,墨尔本,멜버른', -37.8140000, 144.9633200, 'AU', '2016-07-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4333, 'Medowie', 'Medowie', 'Medowie', -32.7415000, 151.8676000, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4334, 'McKinnon', 'McKinnon', '', -37.9166700, 145.0500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4335, 'Matraville', 'Matraville', 'Matraville,mtrwwyl,מטרוויל', -33.9500000, 151.2333300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4336, 'Mascot', 'Mascot', 'Mascot,msqwt,מסקוט', -33.9259800, 151.1934700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4337, 'Maryborough', 'Maryborough', 'Maryborough,Mehriboro,ma li bo lei,Мэриборо,مەریبۆرۆ، ڤیکتۆریا,瑪麗伯勒', -37.0456200, 143.7392300, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4338, 'Maryborough', 'Maryborough', 'MBH,Maryborough,Mehriboro,Meriboro,ma li bo lei,meriboro,myrybra,Мериборо,Меріборо,Мэриборо,مری‌بری، کوئینزلند,میریبرا,مەریبۆرۆ، کوینزلەند,მერიბორო,瑪麗伯勒', -25.5407300, 152.7049300, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4339, 'Marrickville', 'Marrickville', 'Marrickville,marikkubiru,マリックビル', -33.9031800, 151.1517600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4340, 'Maroubra', 'Maroubra', 'Maroubra,Maroubra Beach,marubura,מארוברה,マルブラ', -33.9500000, 151.2333300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4341, 'Maribyrnong', 'Maribyrnong', 'Maribyrnong', -37.7833300, 144.8833300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4342, 'Margate', 'Margate', 'Margate', -43.0281400, 147.2625600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4343, 'Margate', 'Margate', '', -27.2476100, 153.0980900, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4344, 'Mareeba', 'Mareeba', 'MRG,Mareeba', -16.9909600, 145.4230600, 'AU', '2016-06-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4345, 'Mansfield', 'Mansfield', 'Mansfied,Mansfield,Mansfild,Мансфилд', -37.0520000, 146.0884600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4346, 'Manly', 'Manly', 'Manli,Манли', -33.7979800, 151.2882600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4347, 'Manilla', 'Manilla', 'Manilla', -30.7474800, 150.7197400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4348, 'Maleny', 'Maleny', 'Maleny', -26.7600100, 152.8492600, 'AU', '2017-06-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4349, 'Malabar', 'Malabar', 'Malabar', -33.9621600, 151.2479600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4350, 'Maitland', 'Maitland', 'MTL,Maitland,Mehjtlend,Mejtland,Mejtlend,West Maitland,mei te lan,mytlnd  yyny gwnyy wlz,Мейтленд,Мејтланд,Мэйтленд,میئٹلینڈ، نیو ساؤتھ ویلز,میتلند، یئنی گونئی ولز,میٹلینڈ,مێیتلەند، نیو ساوت وێلز,მეიტლენდი,梅特兰', -32.7330800, 151.5574000, 'AU', '2017-04-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4351, 'Macleod', 'Macleod', '', -37.7333300, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4352, 'Maclean', 'Maclean', 'Maclean', -29.4581000, 153.1975300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4353, 'Macksville', 'Macksville', 'MVH,Macksville', -30.7078000, 152.9202900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4354, 'Mackay', 'Mackay', 'MKY,Mackay,Makaj,Makej,Makkaj,maekai,mai kai,make,makkai,mkay,mkay  kwyynzlnd,Макай,Макај,Макей,Маккай,מאקאי,مکائے، کوئنزلینڈ,مکای,مکای، کوئینزلند,میکے,مەکای، کوینزلەند,मके,მაკაი,マッカイ,麥凱,매카이', -21.1534500, 149.1655400, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4355, 'Macclesfield', 'Macclesfield', 'Macclesfield', -37.8833300, 145.4833300, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4356, 'Lysterfield', 'Lysterfield', '', -37.9333300, 145.3000000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4357, 'Luddenham', 'Luddenham', 'Luddenham', -33.8785000, 150.6886300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4358, 'Loxton', 'Loxton', 'Lokston,Loxton,Локстон', -34.4502000, 140.5690800, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4359, 'Lower Plenty', 'Lower Plenty', '', -37.7333300, 145.1166700, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4360, 'Loveday', 'Loveday', 'Loveday', -34.2833300, 140.4333300, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4361, 'Lorn', 'Lorn', 'Lorn', -32.7333300, 151.5666700, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4362, 'Long Jetty', 'Long Jetty', 'Long Jetty', -33.3579500, 151.4813500, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4363, 'Longford', 'Longford', 'Longford', -41.6051200, 147.1188700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4364, 'Liverpool', 'Liverpool', 'Liverpool,lywrpwl  astralya,لیورپول، استرالیا,لیورپول، نیو ساؤتھ ویلز,ლივერპული,ሊቨርፑል፣ አውስትራልያ', -33.9000000, 150.9333300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4365, 'Little River', 'Little River', '', -37.9666700, 144.5000000, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4366, 'Lithgow', 'Lithgow', 'Lightgow,Litgou,Lithgow,li si ge,litgou,lytqww  yyny gwnyy wlz,Литгоу,لتھگو,لیتقوو، یئنی گونئی ولز,لیسگەو,ლითგოუ,ሊትጎ,利斯戈', -33.4824700, 150.1363100, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4367, 'Lismore', 'Lismore', 'LSY,Lismor,Lizmor,li si mo er,lijeumo-eo,lismora,lismori,lsmwr,lysmwr  astralya,lysmwr  yyny gwnyy wlz,rizumo,Лизмор,Лисмор,لسمور,لیزمۆر,لیسمور، استرالیا,لیسمور، یئنی گونئی ولز,लिस्मोर,ლისმორი,リズモー,利斯莫尔,리즈모어', -28.8135400, 153.2773000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4368, 'Lisarow', 'Lisarow', 'Lisarow', -33.3833300, 151.3666700, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4369, 'Lindisfarne', 'Lindisfarne', 'Lindisfarne', -42.8483700, 147.3619200, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4370, 'Lindfield', 'Lindfield', 'Lindfield', -33.7833300, 151.1666700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4371, 'Lilydale', 'Lilydale', 'Lilydale', -37.7500000, 145.3500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4372, 'Lightning Ridge', 'Lightning Ridge', 'LHG,Lajtning Ridzh,Lightning Ridge,Лайтнинг Ридж', -29.4274300, 147.9786500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4373, 'Lidcombe', 'Lidcombe', 'Lidcomb,Lidkomb,Лидкомб,Лідкомб', -33.8643600, 151.0397000, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4374, 'Leura', 'Leura', 'Leura', -33.7166700, 150.3333300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4375, 'Leumeah', 'Leumeah', 'Leumeah', -34.0500000, 150.8333300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4376, 'Leopold', 'Leopold', 'Leopol''d,Leopold,Леопольд', -38.1900100, 144.4682500, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4377, 'Leichhardt', 'Leichhardt', 'Leichhardt', -33.8834100, 151.1562500, 'AU', '2015-08-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4378, 'Leeton', 'Leeton', 'Leeton,Liton,QLE,Литон', -34.5510500, 146.4048300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4379, 'Lawson', 'Lawson', 'Lawson', -33.7206400, 150.4297500, 'AU', '2014-12-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4380, 'Lavington', 'Lavington', 'Lavington', -36.0397600, 146.9395800, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4381, 'Camden Haven', 'Camden Haven', 'Camden Haven,Laurieton', -31.6448400, 152.7946200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4382, 'Launceston', 'Launceston', 'LST,Launceston,Launcestown,Lonseston,Patersonia,lancecutan,lang sai si dun,lansstwn  tasmany,lawnsstwn,lonasesatana,lonseoseuteon,lwnstwn,ronsesuton,Лонсестон,לונסטון,لانسستون، تاسمانی,لانسسٹن، تسمانیا,لانسێستن، تاسمانیا,لاونسستون,لاونسسٹن,लॉनसेसटन,லான்செசுடன்,ლონსესტონი,ローンセストン,朗塞斯顿,론서스턴', -41.4387600, 147.1346700, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4383, 'Lauderdale', 'Lauderdale', 'Lauderdale', -42.9136400, 147.4874700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4384, 'Latrobe', 'Latrobe', 'LTB,Latrobe', -41.2464100, 146.4245800, 'AU', '2017-07-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4385, 'Larnook', 'Larnook', 'Larnook', -28.6516200, 153.1107700, 'AU', '2013-10-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4386, 'Largs', 'Largs', 'Largs', -32.7000000, 151.6000000, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4387, 'Lara', 'Lara', 'Lara', -38.0238800, 144.4061700, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4388, 'Langwarrin', 'Langwarrin', 'Langwarrin', -38.1666700, 145.1666700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4389, 'Lane Cove', 'Lane Cove', 'Lane Cove', -33.8157000, 151.1667900, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4390, 'Lalor', 'Lalor', '', -37.6666700, 145.0166700, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4391, 'Lakes Entrance', 'Lakes Entrance', 'Lejks-Ehntrans,Лейкс-Энтранс', -37.8667900, 148.0015900, 'AU', '2016-11-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4392, 'Lakemba', 'Lakemba', 'Lakemba', -33.9197200, 151.0759200, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4393, 'Lake Illawarra', 'Lake Illawarra', '', -34.5465800, 150.8564500, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4394, 'Lake Cargelligo', 'Lake Cargelligo', 'Lake Cargellico,Lake Cargelligo', -33.2988400, 146.3729600, 'AU', '2017-05-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4395, 'Lake Albert', 'Lake Albert', 'Lake Albert', -35.1666700, 147.3833300, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4396, 'Kyogle', 'Kyogle', 'Kyogle', -28.6207500, 153.0048200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4397, 'Kyabram', 'Kyabram', 'Kyabram', -36.3133500, 145.0503500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4398, 'Kurri Kurri', 'Kurri Kurri', 'Kurri Kurri', -32.8193300, 151.4790800, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4399, 'Kurnell', 'Kurnell', 'Kurnell,Kurnell Peninsula Headland', -34.0108800, 151.2051200, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4400, 'Kuranda', 'Kuranda', 'Kuranda,Куранда', -16.8197800, 145.6381800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4401, 'Kotara', 'Kotara', 'Kotara', -32.9500000, 151.6833300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4402, 'Koo-Wee-Rup', 'Koo-Wee-Rup', 'Koo-Wee-Rup', -38.1994100, 145.4908100, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4403, 'Kootingal', 'Kootingal', 'Kootingal', -31.0585700, 151.0535000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4404, 'Kogarah', 'Kogarah', 'Kogarah', -33.9833300, 151.1166700, 'AU', '2012-09-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4405, 'Kirribilli', 'Kirribilli', 'Kirribilli', -33.8486700, 151.2162000, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4406, 'Kingston Beach', 'Kingston Beach', 'Kingston Beach', -42.9802100, 147.3194100, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4407, 'Kingston', 'Kingston', 'Kingston', -42.9763800, 147.3035100, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4408, 'Kingston', 'Kingston', '', -34.2333300, 140.3500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4409, 'Kingscliff', 'Kingscliff', 'Kingscliff', -28.2598300, 153.5781600, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4410, 'Kinglake West', 'Kinglake West', 'Kinglake West,Tommy''s Hut,Tommy’s Hut', -37.4666700, 145.2333300, 'AU', '2015-01-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4411, 'Kingaroy', 'Kingaroy', 'KGY,Kingaroy,jin ge luo yi,金格羅伊', -26.5399400, 151.8373000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4412, 'Kilsyth', 'Kilsyth', '', -37.8000000, 145.3166700, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4413, 'Kiama', 'Kiama', 'Kiama', -34.6682800, 150.8521900, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4414, 'Keysborough', 'Keysborough', '', -37.9911600, 145.1738500, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4415, 'Kew', 'Kew', 'Kju,Кю', -37.8063900, 145.0308600, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4416, 'Kettering', 'Kettering', 'Kettering,Кеттеринг', -43.1262300, 147.2464100, 'AU', '2014-10-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4417, 'Kenthurst', 'Kenthurst', 'Kenthurst', -33.6552700, 151.0050300, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4418, 'Kensington', 'Kensington', 'Kensington', -33.9201900, 151.2224100, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4419, 'Kensington', 'Kensington', '', -37.7833300, 144.9333300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4420, 'Kennington', 'Kennington', 'Kennington', -36.7833300, 144.3000000, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4421, 'Kendall', 'Kendall', 'Kendall', -31.6329500, 152.7039300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4422, 'Kempsey', 'Kempsey', 'KPS,Kempsey,ken pu xi,肯普西', -31.0789800, 152.8309300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4423, 'Kelso', 'Kelso', 'Kelso', -33.4166700, 149.6000000, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4424, 'Keith', 'Keith', 'Keith,Kit,Кит', -36.0991000, 140.3531500, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4425, 'Keiraville', 'Keiraville', 'Keiraville', -34.4166700, 150.8666700, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4426, 'Keilor', 'Keilor', 'Keilor', -37.7166700, 144.8333300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4427, 'Katoomba', 'Katoomba', 'Katoomba,Katumba,Катумба', -33.7197700, 150.3073900, 'AU', '2012-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4428, 'Kanwal', 'Kanwal', '', -33.2530000, 151.4911000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4429, 'Kangaroo Valley', 'Kangaroo Valley', 'Kangaroo Valley,Kenguru Vehlli,Кенгуру Вэлли', -34.7380600, 150.5365700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4430, 'Kangaroo Flat', 'Kangaroo Flat', '', -36.8000000, 144.2500000, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4431, 'Kandos', 'Kandos', 'Kandos', -32.8577200, 149.9683200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4432, 'Kalorama', 'Kalorama', 'Kalorama,Mount Dandenong North', -37.8166700, 145.3666700, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4433, 'Kallista', 'Kallista', 'Kallista', -37.8833300, 145.3666700, 'AU', '2015-03-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4434, 'Kahibah', 'Kahibah', 'Kahibah', -32.9666700, 151.7166700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4435, 'Junee', 'Junee', 'Junee,Junee Junction', -34.8681900, 147.5827300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4436, 'Jindera', 'Jindera', 'Dzhindera,Jindera,Джиндера', -35.9547400, 146.8885200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4437, 'Jindabyne', 'Jindabyne', 'Jindabyne,Jinderboine,QJD,Village of Jindabyne', -36.4186100, 148.6199900, 'AU', '2016-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4438, 'Jilliby', 'Jilliby', 'Jilliby', -33.2260500, 151.4168400, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4439, 'Jannali', 'Jannali', 'Jannali', -34.0164300, 151.0606500, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4440, 'Jamberoo', 'Jamberoo', 'Jamberoo', -34.6474500, 150.7746400, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4441, 'Ivanhoe East', 'Ivanhoe East', '', -37.7832000, 145.0524900, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4442, 'Inverell', 'Inverell', 'IVR,Inverell', -29.7740300, 151.1116600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4443, 'Innisfail', 'Innisfail', 'Geraldton,IFL,Innisfail,aynysfyl,إينيسفيل', -17.5220900, 146.0310200, 'AU', '2016-12-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4444, 'Ingleburn', 'Ingleburn', 'Ingleburn', -34.0000000, 150.8666700, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4445, 'Ingham', 'Ingham', 'IGH,Ingem,Ingham,Інгем,Ингем', -18.6455200, 146.1624800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4446, 'Hurstville Grove', 'Hurstville Grove', 'Hurstville,Hurstville Grove', -33.9799300, 151.0902900, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4447, 'Hurstbridge', 'Hurstbridge', 'Hurstbridge,Kherstbridzh,Херстбридж', -37.6415700, 145.1940800, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4448, 'Huonville', 'Huonville', 'Huonville,Kh''juonvill,Khuonvill'',Хуонвилль,Хьюонвилл', -43.0312400, 147.0481300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4449, 'Hughesdale', 'Hughesdale', '', -37.9000000, 145.0833300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4450, 'Hughenden', 'Hughenden', 'HGD,Hughenden,Kh''juehnden,Хьюэнден', -20.8439900, 144.2003500, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4451, 'Howlong', 'Howlong', 'Howlong,Khaulong,Хаулонг', -35.9819700, 146.6324800, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4452, 'Horsham', 'Horsham', 'HSM,Horsham,Khorshem,horshemi,Хоршем,ھۆرشەم، ڤیکتۆریا,ہورشم,ہوشیم، وکٹوریہ,ჰორშემი', -36.7113100, 142.1998100, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4453, 'Hornsby', 'Hornsby', '', -33.7024400, 151.0993100, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4454, 'Home Hill', 'Home Hill', 'Home Hill', -19.6592100, 147.4123200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4455, 'Homebush', 'Homebush', 'Homebush,hompus,ஹோம்புஷ்', -33.8666700, 151.0833300, 'AU', '2014-06-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4456, 'Holsworthy', 'Holsworthy', 'Holsworthy', -33.9833300, 150.9666700, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4457, 'Holgate', 'Holgate', 'Holgate', -33.4000000, 151.4166700, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4458, 'Holbrook', 'Holbrook', 'Holbrook,Kholbruk,Ten Mile,Холбрук', -35.7210000, 147.3160500, 'AU', '2017-06-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4459, 'Hobart', 'Hobart', 'Chompart,Gobart,Gorad Khobart,HBA,Hobart,Hobart Town,Hobarta,Hobartas,Hobarto,Hobat,Hobārta,Khobart,Khoubart,he ba te,hobarata,hobart,hobarta,hobateu,hobato,hopart,huo ba te,hwbart,Χόμπαρτ,Гобарт,Горад Хобарт,Хобарт,Хоубарт,הובארט,هوبارت,ہابرٹ,ہوبارٹ,होबार्ट,ਹੋਬਾਰਟ,ହୋବାର୍ଟ,ஹோபார்ட்,හෝබාර්ට්,โฮบาร์ต,ཧོ་སྦར་ཐེ།,ჰობარტი,ホバート,荷巴特,霍巴特,호바트', -42.8793600, 147.3294100, 'AU', '2017-04-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4460, 'Hillston', 'Hillston', 'Daisy Hill,Hillston,Khillston,Хиллстон', -33.4826600, 145.5352500, 'AU', '2017-05-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4461, 'Highett', 'Highett', '', -37.9500000, 145.0500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4462, 'Henty', 'Henty', 'Henty,Village of Henty', -35.5209400, 147.0342600, 'AU', '2017-06-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4463, 'Helensburgh', 'Helensburgh', 'Helensbourgh,Helensburgh,Khelensburg,Хеленсбург', -34.1783600, 150.9952200, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4464, 'Heidelberg West', 'Heidelberg West', '', -37.7500000, 145.0333300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4465, 'Heidelberg', 'Heidelberg', '', -37.7500000, 145.0666700, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4466, 'Heddon Greta', 'Heddon Greta', 'Heddon Greta', -32.8020400, 151.5132700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4467, 'Heathmont', 'Heathmont', '', -37.8333300, 145.2500000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4468, 'Heatherton', 'Heatherton', '', -37.9666700, 145.1000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4469, 'Heathcote', 'Heathcote', 'Heathcote', -34.0841000, 151.0130500, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4470, 'Healesville', 'Healesville', 'Healesville,Khilsvill,xi lei shi wei lei,Хилсвилл,希嘞士维嘞', -37.6539500, 145.5171800, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4471, 'Hazelbrook', 'Hazelbrook', 'Hazelbrook', -33.7244600, 150.4583900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4472, 'Haymarket', 'Haymarket', 'hyymrqt,xi shi,היימרקט,禧市', -33.8786800, 151.2052600, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4473, 'Hay', 'Hay', 'HXX,Hay', -34.5090300, 144.8430600, 'AU', '2015-06-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4474, 'Hawthorn South', 'Hawthorn South', 'Hawthorn South,Hawthorne South', -37.8329000, 145.0367000, 'AU', '2017-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4475, 'Hawks Nest', 'Hawks Nest', 'Hawks Nest', -32.6675500, 152.1783100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4476, 'Hastings', 'Hastings', 'Hastings', -38.3000000, 145.1833300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4477, 'Harrington', 'Harrington', 'Harrington', -31.8743500, 152.6435300, 'AU', '2016-09-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4478, 'Hampton Park', 'Hampton Park', '', -38.0333300, 145.2500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4479, 'Hampton', 'Hampton', 'Sandringham', -37.9500000, 145.0000000, 'AU', '2015-06-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4480, 'Hamilton', 'Hamilton', 'Gamil''ton,HLT,Hamilton,Hamiltonium,Khamilton,ha mi lei tun,haemilteon,hamiruton,hmyltwn,Гамильтон,Хамилтон,המילטון,ھەمیڵتن، ڤیکتۆریا,ہیملٹن,ہیملٹن، وکٹوریہ,ჰამილტონი,ハミルトン,哈米嘞吞,해밀턴', -37.7442500, 142.0220200, 'AU', '2017-07-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4481, 'Hallam', 'Hallam', '', -38.0166700, 145.2666700, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4482, 'Haberfield', 'Haberfield', '', -33.8833300, 151.2000000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4483, 'Gympie', 'Gympie', 'GYP,Gimpi,Gympie,gympy,jin pi,Гимпи,گیمپی,金皮', -26.1897900, 152.6649900, 'AU', '2011-06-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4484, 'Guyra', 'Guyra', 'Guyra', -30.2168000, 151.6678500, 'AU', '2016-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4485, 'Gunnedah', 'Gunnedah', 'GUH,Gunnedah,Gunnendah', -30.9806500, 150.2583800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4486, 'Gundaroo', 'Gundaroo', 'Gundaroo,Gundaru,Gunderoo,Гундару', -35.0333300, 149.2500000, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4487, 'Gundagai', 'Gundagai', 'Gundagai', -35.0652500, 148.1080200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4488, 'Gulgong', 'Gulgong', 'Gulgong', -32.3625300, 149.5320100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4489, 'Griffith', 'Griffith', 'GFF,Griffit,Griffith,gripiti,gryfys,gryfyt  astralya,gurifisu,qryfyt  yyny gwnyy wlz,Гриффит,قریفیت، یئنی گونئی ولز,گریفتھ,گریفیت، استرالیا,گریفیس,გრიფითი,グリフィス', -34.2885300, 146.0509300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4490, 'Greta', 'Greta', 'Greta', -32.6778300, 151.3892400, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4491, 'Grenfell', 'Grenfell', 'GFE,Grenfell', -33.8954900, 148.1643800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4492, 'Greenwell Point', 'Greenwell Point', 'Greenwell Point', -34.9075100, 150.7311300, 'AU', '2016-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4493, 'Greenvale', 'Greenvale', 'Greenvale', -37.6333300, 144.8666700, 'AU', '2016-11-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4494, 'Greensborough', 'Greensborough', '', -37.7046200, 145.1030200, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4495, 'Granville', 'Granville', 'Granville,Granville Junction', -33.8333300, 151.0166700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4496, 'Granton', 'Granton', '', -42.7514900, 147.2279500, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4497, 'Grafton', 'Grafton', 'GFN,Grafton,qraftwn  yyny gwnyy wlz,Графтон,قرافتون، یئنی گونئی ولز,گرافتن، نیو ساوت وێلز,گرافٹن,გრაფტონი,ግራፍተን', -29.6810400, 152.9339400, 'AU', '2016-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4498, 'Goulburn', 'Goulburn', 'GUL,Golbern,Goulbern,Goulburn,Gulbern,golbeon,goulberni,gu er ben,gwlbrn,qwlbwrn  yyny gwnyy wlz,Голберн,Гоулберн,Гулберн,قولبورن، یئنی گونئی ولز,گولبرن,گوولبۆرن، نیو ساوت وێلز,გოულბერნი,ጎልበርን,古尔本,골번', -34.7515500, 149.7208600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4499, 'Gosford', 'Gosford', 'GOS,Gosford,gasfwrd,ge si fu de,ghwsfwrd,goseupeodeu,gospordi,gosufodo,qasfwrd,Госфорд,غوسفورد,قاسفورد,گاسفورد,گاسفۆرد,گوسفورڈ,გოსფორდი,ゴスフォード,戈斯福德,고스퍼드', -33.4244000, 151.3439900, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4500, 'Gorokan', 'Gorokan', '', -33.2576400, 151.5097000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4501, 'Gordon', 'Gordon', '', -29.3000000, 152.7166700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4502, 'Goonellabah', 'Goonellabah', 'Goonellabah', -28.8166700, 153.3166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4503, 'Goondiwindi', 'Goondiwindi', 'GOO,Goondiwindi,Gundivindi,gundiu~indi,Гундивинди,グンディウィンディ', -28.5470900, 150.3054600, 'AU', '2014-10-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4504, 'Goodna', 'Goodna', 'Goodna', -27.6104600, 152.8989600, 'AU', '2015-08-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4505, 'Gol Gol', 'Gol Gol', 'Gol Gol,Town of Gol Gol', -34.1738800, 142.2218700, 'AU', '2016-01-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4506, 'Gold Coast', 'Gold Coast', 'City of Gold Coast,Costa Dorada,Gold,Gold Coast,Gold Koust,OOL,gorudokosuto,huang jin hai an,Голд Коуст,ゴールドコースト,ゴールド・コースト,黃金海岸,黄金海岸', -28.0002900, 153.4308800, 'AU', '2016-03-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4507, 'Gloucester', 'Gloucester', 'Gloucester', -32.0077000, 151.9633000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4508, 'Glenroy', 'Glenroy', '', -37.7000000, 144.9333300, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4509, 'Glenorie', 'Glenorie', 'Glenorie', -33.6017700, 151.0088600, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4510, 'Glenorchy', 'Glenorchy', '', -42.8334300, 147.2759300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4511, 'Glen Innes', 'Glen Innes', 'GLI,Glen Innes', -29.7348500, 151.7385000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4512, 'Glen Huntly', 'Glen Huntly', '', -37.8833300, 145.0500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4513, 'Glenhaven', 'Glenhaven', 'Glenhaven', -33.7000000, 151.0000000, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4514, 'Glenfield', 'Glenfield', 'Glenfield', -33.9666700, 150.9000000, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4515, 'Glenferrie', 'Glenferrie', '', -37.8333300, 145.0500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4516, 'Glenbrook', 'Glenbrook', 'Glenbrook', -33.7666700, 150.6166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4517, 'Gladstone', 'Gladstone', 'GLT,Gladston,Gladstone,Gledston,Glehdston,ge la de si tong,qladstwn  kwyynzlnd,Гладстон,Гледстон,Глэдстон,قلادستون، کوئینزلند,گلیڈسٹون,گلیڈسٹون، کوئنزلینڈ,گلەدستۆن,გლადსტონი,格拉德斯通', -23.8485200, 151.2577500, 'AU', '2014-10-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4518, 'Gilgandra', 'Gilgandra', 'Gilgandra', -31.7117300, 148.6625200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4519, 'Gilgai', 'Gilgai', 'Gilgai', -29.8527000, 151.1180600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4520, 'Gerringong', 'Gerringong', 'Geringong,Gerringong,Геррингонг', -34.7470200, 150.8280900, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4521, 'George Town', 'George Town', 'Dzhordzh Taun,GEE,George Town,Georgetown,Джордж Таун', -41.1055900, 146.8260600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4522, 'Gembrook', 'Gembrook', 'Gembrook', -37.9532100, 145.5553600, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4523, 'Geeveston', 'Geeveston', '', -43.1633700, 146.9254900, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4524, 'Geelong West', 'Geelong West', 'Geelong West', -38.1388800, 144.3484200, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4525, 'Geelong', 'Geelong', 'Dzhelong,Dzhilong,Dzilong,Dzilongas,Džilongas,GEX,Geelong,Zhelon,ghylwngh,gilonga,gylang,gylwng,jeollong,ji lang,jilongi,jirongu,jylang,jylanq,Џилонг,Джелонг,Джилонг,Желон,גילונג,جیلانق,جیلانگ,جیڵانگ,غيلونغ,گیلانگ,गीलोंग,गीलोङ्ग,ჯილონგი,ジーロング,吉朗,절롱', -38.1471100, 144.3606900, 'AU', '2013-07-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4526, 'Gayndah', 'Gayndah', 'GAH,Gayndah', -25.6252200, 151.6114400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4527, 'Gatton', 'Gatton', 'Gatton,jia dun,Гаттон,加頓', -27.5587300, 152.2761800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4528, 'Garfield', 'Garfield', 'Garfield,Garfild,Гарфилд', -38.0898500, 145.6750200, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4529, 'Galston', 'Galston', 'Galston', -33.6529700, 151.0471300, 'AU', '2015-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4530, 'Frederickton', 'Frederickton', 'Frederickton', -31.0374900, 152.8753000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4531, 'Frankston East', 'Frankston East', 'Frankston East,Frenkston,Френкстон', -38.1333300, 145.1333300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4532, 'Frankston', 'Frankston', 'Frankston,fu lan ke si dun,furankusuton,peulaengkeuseuteon,فرینکسٹان,فرینکسٹن، وکٹوریہ,ფრანკსტონი,フランクストン,弗兰克斯顿,프랭크스턴', -38.1445800, 145.1229100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4533, 'Franklin', 'Franklin', 'Franklin', -43.0888400, 147.0090600, 'AU', '2013-07-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4534, 'Forster', 'Forster', 'FOT,Forster', -32.1813600, 152.5171500, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4535, 'Forest Hill', 'Forest Hill', 'Forest Hill,Forest Khill,Форест Хилл', -35.1481000, 147.4670700, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4536, 'Forest Hill', 'Forest Hill', '', -37.8333300, 145.1833300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4537, 'Forbes', 'Forbes', 'FRB,Forbes,Forbs,Форбс', -33.3843600, 148.0076000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4538, 'Footscray', 'Footscray', 'Footscray', -37.8000000, 144.9000000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4539, 'Fitzroy', 'Fitzroy', 'Fitzroy', -37.7983900, 144.9783300, 'AU', '2012-06-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4540, 'Finley', 'Finley', 'FLY,Finley', -35.6549800, 145.5710600, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4541, 'Ferny Creek', 'Ferny Creek', '', -37.8833300, 145.3333300, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4542, 'Federal', 'Federal', '', -28.6485000, 153.4512000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4543, 'Fawkner', 'Fawkner', 'Fawkner', -37.7166700, 144.9666700, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4544, 'Falls Creek', 'Falls Creek', 'FLC,Falls Creek', -34.9666700, 150.6000000, 'AU', '2012-05-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4545, 'Evans Head', 'Evans Head', 'EVH,Evans Head', -29.1177700, 153.4307200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4546, 'Evandale', 'Evandale', 'Evandale', -41.5685800, 147.2527100, 'AU', '2014-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4547, 'Eulomogo', 'Eulomogo', '', -32.2666700, 148.6833300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4548, 'Ettalong Beach', 'Ettalong Beach', 'Ettalong Beach', -33.5105800, 151.3304400, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4549, 'Ettalong', 'Ettalong', '', -33.5130100, 151.3383000, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4550, 'Essendon', 'Essendon', 'Essendon', -37.7666700, 144.9166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4551, 'Erina', 'Erina', 'Erina', -33.4321800, 151.3897200, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4552, 'Epsom', 'Epsom', 'Epsom', -36.7166700, 144.3166700, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4553, 'Epping', 'Epping', '', -37.6500000, 145.0333300, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4554, 'Epping', 'Epping', 'ai ping,艾坪', -33.7727100, 151.0818400, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4555, 'Enmore', 'Enmore', '', -30.7333300, 151.8000000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4556, 'Engadine', 'Engadine', 'Ehngadin,Engadine,Энгадин', -34.0656400, 151.0126600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4557, 'Empire Bay', 'Empire Bay', 'Empire Bay', -33.4938500, 151.3629000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4558, 'Emerald', 'Emerald', 'Ehmerald,Emerald,Эмералд', -37.9316700, 145.4409300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4559, 'Emerald', 'Emerald', 'EMD,Ehmeral''d,Ehmerald,Emerald,Емералд,Эмералд,Эмеральд', -23.5229600, 148.1578400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4560, 'Eltham North', 'Eltham North', 'Eltham North,North Eltham', -37.7000000, 145.1500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4561, 'Eltham', 'Eltham', 'Eltham', -37.7333300, 145.1500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4562, 'Elderslie', 'Elderslie', 'Elderslie', -34.0500000, 150.7000000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4563, 'Eglinton', 'Eglinton', '', -33.3773100, 149.5465400, 'AU', '2011-10-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4564, 'Edithvale', 'Edithvale', '', -38.0372400, 145.1097400, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4565, 'Edgecliff', 'Edgecliff', '', -33.8833300, 151.2500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4566, 'Eden', 'Eden', 'Eden,Ehden,QDN,Эден', -37.0667500, 149.9002900, 'AU', '2017-04-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4567, 'Echuca', 'Echuca', 'ECH,Echuca,Ichuka,ai chu ka,akwka,Ичука,اکوکا,埃楚卡', -36.1405700, 144.7518500, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4568, 'East Maitland', 'East Maitland', 'East Maitland', -32.7500000, 151.5833300, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4569, 'East Hills', 'East Hills', '', -33.9666700, 150.9833300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4570, 'East Gosford', 'East Gosford', 'East Gosford', -33.4387400, 151.3533800, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4571, 'East Ballina', 'East Ballina', '', -28.8666700, 153.5833300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4572, 'Earlwood', 'Earlwood', 'Earlwood', -33.9500000, 151.1000000, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4573, 'Dungog', 'Dungog', 'Dungog', -32.4043100, 151.7519200, 'AU', '2016-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4574, 'Dunedoo', 'Dunedoo', 'Dunedoo', -32.0163400, 149.3871000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4575, 'Dubbo', 'Dubbo', 'DBO,Dabbo,Dabo,Dubbo,dabbo,dabo,deobo,dubbo,dwbw,Даббо,Дабо,דובו,دوبو,دۆببۆ,ڈبو,ڈوبو,डुब्बो,दब्बो,დაბო,ዱቦ,더보', -32.2429500, 148.6048400, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4576, 'Dromana', 'Dromana', '', -38.3337500, 144.9645800, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5510, 'Vårdö', 'Vardoe', '', 60.2500000, 20.3833300, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5511, 'Sund', 'Sund', 'Sund,Sundi vald,song de,Сунд,松德', 60.2500000, 20.1166700, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5512, 'Sottunga', 'Sottunga', 'Sottunga', 60.1302300, 20.6668300, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5513, 'Saltvik', 'Saltvik', '', 60.2833300, 20.0500000, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5514, 'Lumparland', 'Lumparland', 'Lumparland,Lumparlanti', 60.1169500, 20.2581900, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5515, 'Lemland', 'Lemland', 'Lemlanti', 60.0717800, 20.0847200, 'AX', '2015-04-30', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5516, 'Kumlinge', 'Kumlinge', 'Kumlinge,Kumlinki', 60.2601300, 20.7789200, 'AX', '2014-09-30', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5517, 'Kökar', 'Koekar', 'Koekar,Koeoekari,Kökar,Köökari', 59.9205100, 20.9088300, 'AX', '2015-08-12', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5518, 'Föglö', 'Foegloe', 'Foegloe,Fogleo,Fögleö,Föglö', 60.0166700, 20.4166700, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5519, 'Brändö', 'Braendoe', 'Braendoe,Brändö', 60.4116500, 21.0453400, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5520, 'Mariehamn', 'Mariehamn', 'MHQ,Maarianhamina,Marianhamina,Mariankhamina,Mariehameena,Mariehamn,Mariekhamn,Mariuhoefn,Mariyekhamn,Marrianhamina,Maríuhöfn,mariehamun,Мариехамн,マリエハムン', 60.0972600, 19.9348100, 'AX', '2015-05-02', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5521, 'Jomala', 'Jomala', '', 60.1490200, 19.9510000, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5522, 'Hammarland', 'Hammarland', 'Hammarland,Khammarland', 60.2166700, 19.7500000, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5523, 'Geta', 'Geta', 'Eta,Geta vald,gai ta,Ета,蓋塔', 60.3745300, 19.8445500, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5524, 'Finström', 'Finstroem', 'Finstroem,Finström', 60.2666700, 19.9333300, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5525, 'Eckerö', 'Eckeroe', 'Eckeroe,Eckeroe vald,Eckerö,Eckerö vald,Ehkkerjo,ai ke lei,Эккерё,埃克勒', 60.2124900, 19.6144200, 'AX', '2014-09-26', 2);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5509, 'Oranjestad', 'Oranjestad', 'Gorad Aran''estad,Oran''estad,Oranestad,Oraniestat,Oranjestad,Oranjestad pa Aruba,Oranjestad på Aruba,Oranjestadas,Oranjestade,Oranjestado,Oranjested,Oranjestêd,ao la nie si ta de,awrnjstad,olanyeseutateu,oraniesutaddo,oraniyecuttatu,oranjestada,xo ran yes tad,Οράνιεστατ,Горад Араньестад,Оранестад,Ораньестад,Ораньєстад,Орањестад,אורנייסטאד,أورنجستاد,اورنجستاد,اورنجسٹیڈ، اروبا,ओरांजेश्टाड,ஒரானியெசுத்தாடு,โอรันเยสตัด,ორანესტადი,オラニエスタッド,奥拉涅斯塔德,오라녜스타트', 12.5239800, -70.0270300, 'AW', '2010-12-07', 13);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4577, 'Douglas Park', 'Douglas Park', 'Douglas Park,Pikton,Пиктон', -34.1849600, 150.7144900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4578, 'Dorrigo', 'Dorrigo', 'Dorrigo,dorigo,Дорриго,დორიგო', -30.3411200, 152.7139400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4579, 'Doreen', 'Doreen', '', -37.6000000, 145.1500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4580, 'Dora Creek', 'Dora Creek', 'Dora Creek', -33.0813900, 151.4967700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4581, 'Doonside', 'Doonside', 'Doonside', -33.7666700, 150.8666700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4582, 'Donvale', 'Donvale', '', -37.7891000, 145.1748800, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4583, 'Doncaster East', 'Doncaster East', '', -37.7876100, 145.1488800, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4584, 'Doncaster', 'Doncaster', 'Doncaster', -37.7882800, 145.1237300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4585, 'Dingley Village', 'Dingley Village', 'Dingley', -37.9827000, 145.1342000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4586, 'Diggers Rest', 'Diggers Rest', 'Diggers Rest', -37.6259700, 144.7188100, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4587, 'Diamond Creek', 'Diamond Creek', '', -37.6666700, 145.1500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4588, 'Devonport', 'Devonport', 'DPO,Devenport,Devonport,de wen gang,devonaporta,dwwnpwrt,dwwnpwrt  tasmany,Девонпорт,דוונפורט,دوونپورت، تاسمانی,دێڤنپۆرت، تاسمانیا,ڈیونپورٹ,ڈیونپورٹ، تسمانیا,डेवोनपोर्ट,დევონპორტი,德文港', -41.1769500, 146.3515200, 'AU', '2017-07-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4589, 'Derrimut', 'Derrimut', 'Derrimut', -37.7923800, 144.7699400, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4590, 'Denman', 'Denman', 'Denman', -32.3878800, 150.6893500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4591, 'Deniliquin', 'Deniliquin', 'DNQ,Deniliquin,South Deniliquin', -35.5324500, 144.9536400, 'AU', '2016-01-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4592, 'Deloraine', 'Deloraine', 'Dehlorehjn,Deloraine,Дэлорэйн', -41.5247700, 146.6570100, 'AU', '2014-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4593, 'Deer Park', 'Deer Park', '', -37.7666700, 144.7833300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4594, 'Deception Bay', 'Deception Bay', 'Deception Bay', -27.1935400, 153.0263100, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4595, 'Deagon', 'Deagon', 'Deagon', -27.3333300, 153.0666700, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4596, 'Davistown', 'Davistown', 'Davistown', -33.4855900, 151.3615100, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4597, 'Davidson', 'Davidson', '', -33.7429700, 151.2008000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4598, 'Darlington Point', 'Darlington Point', 'Darling Point,Darlington Point,Дарлинг Поинт', -34.5694200, 145.9987000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4599, 'Darlinghurst', 'Darlinghurst', 'drlynghrst,דרלינגהרסט', -33.8793900, 151.2192500, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4600, 'Dareton', 'Dareton', 'Dareton', -34.0946800, 142.0396600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4601, 'Lower Plenty', 'Lower Plenty', '', -37.7500000, 145.1166700, 'AU', '2016-05-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4602, 'Dapto', 'Dapto', 'Dapto', -34.5000000, 150.7833300, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4603, 'Dandenong', 'Dandenong', 'Dandenong,Dandenong South,dandenongi,dandenongu,Данденонг,ڈینڈینانگ,ڈینڈینونگ، وکٹوریہ,დანდენონგი,ダンデノング', -37.9833300, 145.2000000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4604, 'Dalby', 'Dalby', 'DBY,Dalbi,Dalby,Далби', -27.1816900, 151.2620500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4605, 'D’Aguilar', 'D''Aguilar', '', -26.9833300, 152.8000000, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4606, 'Daceyville', 'Daceyville', 'Daceyville', -33.9333300, 151.2333300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4607, 'Cygnet', 'Cygnet', 'Cygnet', -43.1533300, 147.0725300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4608, 'Currie', 'Currie', 'Currie', -39.9297600, 143.8538500, 'AU', '2014-03-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4609, 'Cundletown', 'Cundletown', 'Cundle,Cundletown', -31.8941000, 152.5214100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4610, 'Culcairn', 'Culcairn', 'Culcairn', -35.6666900, 147.0384500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4611, 'Croydon North', 'Croydon North', '', -37.7833300, 145.3000000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4612, 'Croydon', 'Croydon', 'Croydon,Krojdon,Кройдон', -33.8833300, 151.1166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4613, 'Crookwell', 'Crookwell', 'Crookwell,Krukvell,Круквелл', -34.4592500, 149.4713700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4614, 'Cronulla', 'Cronulla', 'Cronulla,Cronulla Beach,Gunnamatta,krona''ulla,क्रॉनउल्ला', -34.0625100, 151.1496100, 'AU', '2016-04-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4615, 'Cringila', 'Cringila', 'Cringila', -34.4666700, 150.8833300, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4616, 'Crib Point', 'Crib Point', '', -38.3500000, 145.2000000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4617, 'Crescent Head', 'Crescent Head', 'Crescent Head', -31.1887000, 152.9730100, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4618, 'Cremorne', 'Cremorne', 'Cremorne', -37.8333300, 145.0000000, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4619, 'Cranbourne', 'Cranbourne', 'Cranbourne,Krenburn,Кренбурн', -38.1000000, 145.2833300, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4620, 'Cranbourne', 'Cranbourne', 'Cranbourne', -38.1134200, 145.2832600, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4621, 'Craigieburn', 'Craigieburn', 'Craigieburn', -37.6000000, 144.9500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4622, 'Cowra', 'Cowra', 'CWT,Cowra,kaula,kaura,カウラ,카우라', -33.8355400, 148.6966300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4623, 'Cowes', 'Cowes', 'Cowes,Kaus,Каус', -38.4523100, 145.2386500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4624, 'Coutts Crossing', 'Coutts Crossing', 'Coutts Crossing', -29.8261900, 152.8915600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4625, 'Corrimal', 'Corrimal', 'Corrima,Corrimal', -34.3786400, 150.9035600, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4626, 'Corowa', 'Corowa', 'CWW,Corowa', -35.9970400, 146.3855200, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4627, 'Coraki', 'Coraki', 'Coraki', -28.9933200, 153.2821200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4628, 'Cootamundra', 'Cootamundra', 'CMD,Cootamundra,Cootamundry,Kutamundra,kwtamwndra,Кутамундра,کوتاموندرا', -34.6409500, 148.0283800, 'AU', '2016-07-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4629, 'Cooranbong', 'Cooranbong', 'Cooranbong,Coorumbung', -33.0762200, 151.4540900, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4630, 'Coonamble', 'Coonamble', 'CNB,Coonamble', -30.9538900, 148.3888100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4631, 'Coonabarabran', 'Coonabarabran', 'COJ,Coonabarabran,Coonabarrabran,Kunabarabran,Кунабарабран', -31.2773400, 149.2790400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4632, 'Cooma', 'Cooma', 'Comma,Cooma,Kuma,OOM,Кума', -36.2351700, 149.1240800, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4633, 'Coolum Beach', 'Coolum Beach', 'Coolum,Coolum Beach', -26.5283000, 153.0880900, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4634, 'Coolamon', 'Coolamon', 'Coolamon', -34.8164100, 147.1957700, 'AU', '2014-08-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4635, 'Cooktown', 'Cooktown', 'CTN,Cooktown,Kuktaun,ku ke dui,kukata''una,Куктаун,कूकटाउन,庫克敦', -15.4391200, 145.1360000, 'AU', '2016-07-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4636, 'Coogee', 'Coogee', 'ku ji zhen,qwgy,קוגי,库吉镇', -33.9205000, 151.2552200, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4637, 'Coniston', 'Coniston', 'Coniston', -34.4500000, 150.8833300, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4638, 'Condobolin', 'Condobolin', 'CBX,Condobolin,Condoublin', -33.0887700, 147.1513900, 'AU', '2016-06-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4639, 'Concord', 'Concord', 'Concord,کانکورڈ، نیو ساؤتھ ویلز', -33.8472200, 151.1038100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4640, 'Como', 'Como', 'Como', -33.9994100, 151.0638900, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4641, 'Colo Vale', 'Colo Vale', 'Colo Vale', -34.4009500, 150.4857300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4642, 'Collingwood', 'Collingwood', 'Collingwood', -37.8000000, 144.9833300, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4643, 'Colac', 'Colac', 'Colac,Kolak,XCO,korakku,Колак,کۆلاک، ڤیکتۆریا,コーラック', -38.3390000, 143.5848900, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4644, 'Coffs Harbour', 'Coffs Harbour', 'CFS,Coffs Harbour,Kofs Kharbor,Kofs-Kharbor,bndr kafs,kafs harbr,ke fu si gang,kofusuhaba,kopeuseuhabeo,kophs harbar,Кофс Харбор,Кофс-Харбор,קופס הארבור,بندر کافس,بەندەری کافس,کافس هاربر,کافس ہاربر,کوفس ہاربر,कॉफ्स् हार्बर्,კოფს-ჰარბური,コフスハーバー,科夫斯港,코프스하버', -30.2962600, 153.1135100, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4645, 'Cockatoo', 'Cockatoo', 'Cockatoo', -37.9367700, 145.4937600, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4646, 'Coburg', 'Coburg', 'Coburg', -37.7500000, 144.9666700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4647, 'Cobbitty', 'Cobbitty', 'Cobbitty,Cobbity', -34.0159200, 150.6785400, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4648, 'Cobar', 'Cobar', 'CAZ,Cobar', -31.4966600, 145.8343900, 'AU', '2017-05-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4649, 'Cloncurry', 'Cloncurry', 'CNJ,Cloncurry,Klonkarri,Klonkurri,ji lang ka lie,Клонкарри,Клонкурри,吉朗卡列', -20.7071800, 140.5130300, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4650, 'Clifton Springs', 'Clifton Springs', 'Clifton Springs,Klifton Springs,Клифтон Спрингс', -38.1567000, 144.5551000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4651, 'Clifton Hill', 'Clifton Hill', '', -37.7979800, 144.9953300, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4652, 'Cleveland', 'Cleveland', 'Cleveland', -27.5267700, 153.2651600, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4653, 'Clayton South', 'Clayton South', 'Clayton South', -37.9333300, 145.1166700, 'AU', '2012-09-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4654, 'Clayton', 'Clayton', '', -37.9166700, 145.1166700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4655, 'Clarinda', 'Clarinda', '', -37.9333300, 145.1166700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4656, 'Clarence Town', 'Clarence Town', 'Clarence Town', -32.5839500, 151.7775700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4657, 'Claremont', 'Claremont', 'Claremont', -42.7833300, 147.2500000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4658, 'Wollongong', 'Wollongong', 'City of Greater Wollongong,Gorad Vulangang,Uulongong,Vullongon,Vullongong,Vulongong,Vulongongas,WOL,Wollongong,ulleongong,urongon,vulamgamga,vulongongi,wlwnghwngh,wlwngwng,wo long gang,wo long gang shi,wwlwngwng,wwlwnqwnq,Вуллонгон,Вуллонгонг,Вулонгонг,Горад Вуланганг,Уулонгонг,וולונגונג,ولونغونغ,ولونگونگ,وولونقونق,وولونگونگ,وۆڵۆنگانگ,वूलाँगाँग,ვულონგონგი,ウロンゴン,卧龙岗,卧龙岗市,울런공', -34.4240000, 150.8934500, 'AU', '2017-04-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4659, 'Churchill', 'Churchill', '', -27.6423300, 152.7502200, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4660, 'Chipping Norton', 'Chipping Norton', 'Chipping Norton', -33.9000000, 150.9500000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4661, 'Chippendale', 'Chippendale', 'zypndyyl,ציפנדייל', -33.8867300, 151.1974500, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4662, 'Chinderah', 'Chinderah', 'Chinderah', -28.2333300, 153.5500000, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4663, 'Chinchilla', 'Chinchilla', 'CCL,Chinchilla,Чинчилла', -26.7378700, 150.6297000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4664, 'Childers', 'Childers', 'Childers,tshayldrz,Чилдерс,تشايلدرز', -25.2370800, 152.2787600, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4665, 'Chelsea Heights', 'Chelsea Heights', 'Chelsea Heights', -38.0333300, 145.1333300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4666, 'Chelsea', 'Chelsea', '', -38.0500000, 145.1166700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4667, 'Chatswood', 'Chatswood', 'Chatswood,che shi huo,车士活', -33.8000000, 151.1833300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4668, 'Charters Towers', 'Charters Towers', 'CXT,Charters Towers,Charters-Tauehrs,Чартерс-Тауэрс,چارٹدز ٹاورز,ჩარეტერს-ტაუერსი', -20.0767100, 146.2635300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4669, 'Charlestown', 'Charlestown', 'Charlestown', -32.9500000, 151.6666700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4670, 'Cessnock', 'Cessnock', 'CES,Cessnock,Sesnok,ksnak,sai si nuo ke,ssnwk  yyny gwnyy wlz,sysnwk,Сеснок,سسنوک، یئنی گونئی ولز,سيسنوك,سێسناک، نیو ساو وێلز,کسناک,სესნოკი,ሴስኖክ,塞斯诺克', -32.8321100, 151.3562300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4671, 'Caulfield North', 'Caulfield North', '', -37.8739000, 145.0248500, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4672, 'Caulfield East', 'Caulfield East', '', -37.8833300, 145.0500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4673, 'Caulfield', 'Caulfield', '', -37.8825100, 145.0228800, 'AU', '2011-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4674, 'Castlemaine', 'Castlemaine', 'Castlemaine,Kaslmejn,ka suo man,Каслмейн,کاسٹلمین,کەسڵمێین، ڤیکتۆریا,卡索曼', -37.0670900, 144.2168400, 'AU', '2013-07-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4675, 'Castle Hill', 'Castle Hill', 'Castle Hill', -33.7333300, 151.0000000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4676, 'Castlecrag', 'Castlecrag', 'Castlecrag', -33.7998700, 151.2231000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4677, 'Casino', 'Casino', 'CSI,Casino', -28.8581900, 153.0474800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4678, 'Carrum Downs', 'Carrum Downs', 'Carrum Downs', -38.0996800, 145.1724800, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4679, 'Carrum', 'Carrum', '', -38.0833300, 145.1333300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4680, 'Carnegie', 'Carnegie', '', -37.8833300, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4681, 'Carlton North', 'Carlton North', '', -37.7833300, 144.9666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4682, 'Carlton', 'Carlton', 'Carlton', -37.8000000, 144.9666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4683, 'Carlingford', 'Carlingford', '', -33.7826900, 151.0488800, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4684, 'Caringbah', 'Caringbah', 'Caringbah', -34.0472600, 151.1205100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4685, 'Cardiff', 'Cardiff', 'Cardiff', -32.9500000, 151.6666700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4686, 'Canowindra', 'Canowindra', 'Canowindra', -33.5624700, 148.6643400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4687, 'Canberra', 'Canberra', 'CBR,Camberra,Canberra,Canberrah,Gorad Kanbera,Kamberra,Kambra,Kampera,Kanapera,Kanbera,Kanbero,Kanberr,Kanberra,Kanberrae,Kanberre,Kanbérra,Kham-phi-la,Khâm-phì-là,Kānapera,kaenbeola,kainabara,kainberra,kan pei la,kanabera,kanbra,kanpara,kenabera,kyanabara,kyanabera,kyanbera,kynbra,kʼanbera,qnbrh,Καμπέρα,Горад Канбера,Канбера,Канберрæ,Канберра,Канберре,Канбєра,Կանբերրա,קאנבערא,קנברה,كانبرا,کانبرا,کانبێرا,کینبرا,कॅनबेरा,कैनबरा,कैन्बेर्रा,क्यानबरा,ক্যানবেরা,ਕੈਨਬਰਾ,କାନବେରା,கான்பரா,കാൻബറ,කැන්බරා,แคนเบอร์รา,ཁན་པེ་ར།,კანბერა,ካንበራ,キャンベラ,坎培拉,堪培拉,캔버라', -35.2834600, 149.1280700, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4688, 'Canadian', 'Canadian', '', -37.5760600, 143.8774200, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4689, 'Camperdown', 'Camperdown', 'קמפרדאון', -33.8896500, 151.1764200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4690, 'Campbelltown', 'Campbelltown', 'Campbelltown,kyanberutaun,კემპბელტაუნი,ካምቤልታውን,キャンベルタウン', -34.0666700, 150.8166700, 'AU', '2012-06-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4691, 'Campbellfield', 'Campbellfield', '', -37.6833300, 144.9500000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4692, 'Cambridge', 'Cambridge', 'Cambridge', -42.8333300, 147.4500000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4693, 'Camberwell', 'Camberwell', 'Camberwell', -37.8420500, 145.0694000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4694, 'Caloundra', 'Caloundra', 'CUD,Caloundra,Kalaundra,Kalundra,kalwndra,klawndra,Калаундра,Калундра,کالوندرا,کلاؤنڈرا,کلاوندرا,کیلاؤنڈرا,კალაუნდრა', -26.8034600, 153.1219500, 'AU', '2014-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4695, 'Cairns', 'Cairns', 'CNS,Cairns,Kehrns,Kerns,Kernsa,Kernsas,Kērnsa,jian ci,kai en si,kairnsa,karnz,keanzu,keeonseu,kernsa,knz,kyrnz,qyyrns,Кернс,Кэрнс,קיירנס,كيرنز,کارنز,کنز,کیرنز,کێنز,केर्न्स,कैर्न्स,ကိန်းမြို့,კერნსი,ケアンズ,凱恩斯,柬兹,케언스', -16.9230400, 145.7662500, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4696, 'Caboolture', 'Caboolture', 'Caboolture,kaburucha,カブルチャー', -27.0846500, 152.9511000, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4697, 'Byron Bay', 'Byron Bay', 'Bajron Behj,Bajron-Bej,Byron Bay,QYN,bai lun wan,baileonbei,khlyj bayrwn,Байрон Бэй,Байрон-Бей,خليج بايرون,拜倫灣,바이런베이', -28.6420100, 153.6119400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4698, 'Buxton', 'Buxton', 'Buxton', -34.2601700, 150.5328800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4699, 'Burwood East', 'Burwood East', 'Burwood East,East Burwood', -37.8500000, 145.1500000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4700, 'Burringbar', 'Burringbar', 'Burringbar', -28.4358000, 153.4732400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4701, 'Burpengary', 'Burpengary', '', -27.1574600, 152.9575800, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4702, 'Burnie', 'Burnie', 'BWT,Berni,Burnie,berni,bo er ni,brny,brny  tasmany,bwrny,bwrny  tasmanya,Берни,Берні,בורני,برنی,برنی، تاسمانی,بورنی، تاسمانیا,ბერნი,伯爾尼', -41.0558400, 145.9037500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4703, 'Bunyip', 'Bunyip', 'Bunyip', -38.0978900, 145.7160600, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4704, 'Bungendore', 'Bungendore', 'Bungendore', -35.2538200, 149.4400700, 'AU', '2014-12-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4705, 'Bundanoon', 'Bundanoon', 'Bundanoon', -34.6565800, 150.2962300, 'AU', '2015-07-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4706, 'Bundamba', 'Bundamba', '', -27.6094700, 152.8113300, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4707, 'Bundaberg', 'Bundaberg', 'BDB,Bandaberg,Bandaberga,Bundaberg,Bundaburg,ban de bao,bandabarga,bandabergi,bwndabrg,bwndabyrj,Бандаберг,Бундаберг,Бъндабърг,باندابێرگ,بنڈابرگ,بوندابرگ,بوندابيرج,बण्डाबर्ग,ბანდაბერგი,班德堡', -24.8662100, 152.3479000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4708, 'Bulli', 'Bulli', 'Bulli', -34.3383400, 150.9134700, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4709, 'Bulleen', 'Bulleen', 'Bulleen', -37.7666700, 145.0833300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4710, 'Bulahdelah', 'Bulahdelah', 'Bulahdelah,Bullah Delah', -32.4069800, 152.2118500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4711, 'Budgewoi', 'Budgewoi', 'Budgewoi', -33.2339000, 151.5541200, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4712, 'Buderim', 'Buderim', 'Buderim', -26.6844300, 153.0570500, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4713, 'Brunswick West', 'Brunswick West', '', -37.7646100, 144.9438300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4714, 'Brunswick Heads', 'Brunswick Heads', 'Brunswick,Brunswick Heads', -28.5415400, 153.5481000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4715, 'Brunswick East', 'Brunswick East', 'Brunswick East', -37.7725500, 144.9724100, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4716, 'Brunswick', 'Brunswick', 'Brunswick,برنزوک، وکٹوریہ', -37.7666700, 144.9666700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4717, 'Brown Hill', 'Brown Hill', '', -37.5500000, 143.9000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4718, 'Broulee', 'Broulee', 'Broulee', -35.8546900, 150.1739200, 'AU', '2011-06-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4719, 'Broken Hill', 'Broken Hill', 'BHQ,Broken Hill,Broken-Khill,Willyama,burokunhiru,Брокен-Хилл,ブロークンヒル', -31.9652000, 141.4512000, 'AU', '2015-12-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4720, 'Broadmeadows', 'Broadmeadows', '', -37.6801500, 144.9187700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4721, 'Brisbane', 'Brisbane', 'BNE,Bresbens,Brisbane,Brisbane City,Brisbano,Brisbehn,Brisben,Brisbena,Brisbenas,Brisbin,Brismpein,Brizbejn,Brėsbens,Gorad Brysben,Pu-li-su-pan,Pu-lî-sṳ̂-pân,beulijeubeon,brisabena,brisben,brisbena,brizabana,brizbeni,brsbyn,brysban,bryzbn,bryzbyn,bryzbyyn,bu li si ban,bu li si ben,burisuben,pirispen,Μπρίσμπεϊν,Бризбейн,Бризбејн,Брисбен,Брисбэн,Горад Брысбен,בריזביין,בריזבן,برسبین,برىسبان,بريزبن,بریزبن,بریزبین,بریزبێن,ब्रिसबेन,ब्रिस्बेन,ব্রিসবেন,ਬ੍ਰਿਜ਼ਬਨ,பிரிஸ்பேன்,బ్రిస్బేన్,ಬ್ರಿಸ್ಬೇನ್‌,ബ്രിസ്ബെയ്ൻ,บริสเบน,ဘရစ်စဘိန်းမြို့,ბრიზბენი,ብርዝበን,ブリスベン,布里司班,布里斯本,布里斯班,브리즈번', -27.4679400, 153.0280900, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4722, 'Bringelly', 'Bringelly', 'Bringelly', -33.9333300, 150.7333300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4723, 'Brighton', 'Brighton', '', -27.2958200, 153.0572100, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4724, 'Bridport', 'Bridport', 'Bridport,Бридпорт', -41.0004600, 147.3917500, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4725, 'Bridgewater', 'Bridgewater', 'Bridge Water Junction,Bridgewater,North Bridgewater', -42.7371900, 147.2278400, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4726, 'Briar Hill', 'Briar Hill', '', -37.7166700, 145.1166700, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4727, 'Brewarrina', 'Brewarrina', 'BWQ,Brewarrina', -29.9606700, 146.8598600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4728, 'Branxton', 'Branxton', 'Branxton', -32.6554700, 151.3511300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4729, 'Braidwood', 'Braidwood', 'Braidwood', -35.4414800, 149.7998000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4730, 'Box Hill', 'Box Hill', '', -37.8188700, 145.1254500, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4731, 'Bowraville', 'Bowraville', 'Bowra,Bowraville', -30.6499700, 152.8514600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4732, 'Bowral', 'Bowral', 'Bowral', -34.4775000, 150.4204000, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4733, 'Bowenfels', 'Bowenfels', 'Bowenfels,South Bowenfels', -33.5166700, 150.1166700, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4734, 'Bowen', 'Bowen', 'Bowen,ZBO', -20.0136700, 148.2475400, 'AU', '2014-08-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4735, 'Bourke', 'Bourke', 'BRK,Bourke', -30.0901100, 145.9364600, 'AU', '2014-10-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4736, 'Botany', 'Botany', 'Botany', -33.9459900, 151.1959100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4737, 'Boronia', 'Boronia', 'Boronia', -37.8666700, 145.2833300, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4738, 'Bordertown', 'Bordertown', 'Bordertaun,Bordertown,Бордертаун', -36.3076800, 140.7716700, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4739, 'Boorowa', 'Boorowa', 'Boorowa', -34.4366100, 148.7163400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4740, 'Booker Bay', 'Booker Bay', 'Booker Bay', -33.5166700, 151.3500000, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4741, 'Bonville', 'Bonville', 'Bonville', -30.3828400, 153.0595900, 'AU', '2013-10-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4742, 'Bongaree', 'Bongaree', 'Bongaree,Bribie', -27.0836700, 153.1594200, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4743, 'Bombala', 'Bombala', 'Bombala,Bomballa,Бомбала', -36.9121200, 149.2366900, 'AU', '2015-02-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4744, 'Bomaderry', 'Bomaderry', 'Bomaderry', -34.8496700, 150.6109300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4745, 'Bolwarra', 'Bolwarra', '', -32.7166700, 151.5666700, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4746, 'Boggabri', 'Boggabri', 'Bogabri,Boggabri', -30.7095300, 150.0412100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4747, 'Boggabilla', 'Boggabilla', 'Boggabilla', -28.6047700, 150.3593400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4748, 'Boambee', 'Boambee', 'Boambee', -30.3398100, 153.0678300, 'AU', '2014-09-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4749, 'Blayney', 'Blayney', 'Blayney', -33.5323300, 149.2536700, 'AU', '2011-10-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4750, 'Blaxland', 'Blaxland', 'Blaxland', -33.7500000, 150.6000000, 'AU', '2012-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4751, 'Blair Athol', 'Blair Athol', '', -30.6500000, 150.2000000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4752, 'Blackwater', 'Blackwater', 'BLT,Blackwater', -23.5835100, 148.8791200, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4753, 'Blackwall', 'Blackwall', 'Blackwall', -33.5019000, 151.3236500, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4754, 'Blacktown', 'Blacktown', 'Blacktown', -33.7666700, 150.9166700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4755, 'Blackmans Bay', 'Blackmans Bay', 'Blackman Bay', -43.0031100, 147.3169400, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4756, 'Black Hill', 'Black Hill', '', -37.5500000, 143.8666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4757, 'Blackheath', 'Blackheath', 'Blackheath', -33.6356700, 150.2831800, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4758, 'Bingara', 'Bingara', 'Bingara', -29.8693100, 150.5720400, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4759, 'Biloela', 'Biloela', 'Biloela,ZBL', -24.3958900, 150.5150400, 'AU', '2013-11-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4760, 'Bilambil', 'Bilambil', '', -28.2266000, 153.4676000, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4761, 'Bexley', 'Bexley', 'Bexley', -33.9500000, 151.1166700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4762, 'Berwick', 'Berwick', 'Berwick', -38.0333300, 145.3500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4763, 'Berry', 'Berry', 'Berri,Berry,Берри', -34.7750700, 150.6943600, 'AU', '2015-05-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4764, 'Berrigan', 'Berrigan', 'Berrigan,Berrigehn,Берригэн', -35.6587900, 145.8114500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4765, 'Berriedale', 'Berriedale', 'Berriedale', -42.8166700, 147.2500000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4766, 'Berridale', 'Berridale', 'Berridale', -36.3667300, 148.8277200, 'AU', '2016-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4767, 'Berri', 'Berri', 'Berri,Берри', -34.2810700, 140.5995800, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4768, 'Berowra', 'Berowra', 'Berowra', -33.6207800, 151.1509100, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4769, 'Bermagui', 'Bermagui', 'Bermaguee,Bermagui', -36.4190000, 150.0635500, 'AU', '2014-06-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4770, 'Berkeley Vale', 'Berkeley Vale', 'Berkeley Vale', -33.3500000, 151.4333300, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4771, 'Berkeley', 'Berkeley', 'Berkeley', -34.4833300, 150.8500000, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4772, 'Beresfield', 'Beresfield', 'Beresfield', -32.8000000, 151.6500000, 'AU', '2012-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4773, 'Bentleigh', 'Bentleigh', '', -37.9180600, 145.0354400, 'AU', '2014-07-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4774, 'Bensville', 'Bensville', 'Bensville', -33.4975700, 151.3808400, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4775, 'Bendigo', 'Bendigo', 'BXG,Bendigo,Bentinko,ban de ge,ben di ge,bendigo,bndygw,Μπέντιγκο,Бендиго,Бендіго,בנדיגו,بینڈگو,بینڈیگو,بێندیگۆ,बेन्डिगो,ბენდიგო,ベンディゴ,本迪戈,班地戈,벤디고', -36.7581800, 144.2802400, 'AU', '2013-07-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4776, 'Benalla', 'Benalla', 'BLN,Benalla,benala,Беналла,بینالہ,بینالہ، وکٹوریہ,بێنالا,ბენალა', -36.5511300, 145.9842500, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4777, 'Belmont', 'Belmont', 'Belmont', -33.0274000, 151.6601000, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4778, 'Belmont', 'Belmont', 'Belmont', -27.5000000, 153.1166700, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4779, 'Bellingen', 'Bellingen', 'Bellingen', -30.4529400, 152.8991100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4780, 'Bellerive', 'Bellerive', 'Bellerive', -42.8755100, 147.3703000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4781, 'Belgrave South', 'Belgrave South', 'Belgrave South,South Belgrave', -37.9333300, 145.3333300, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4782, 'Belgrave Heights', 'Belgrave Heights', 'Belgrave Heights', -37.9166700, 145.3500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4783, 'Belgrave', 'Belgrave', 'Belgrave,ban lei ge lei fu,班嘞格雷夫', -37.9000000, 145.3500000, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4784, 'Belconnen', 'Belconnen', 'Belconnen,Belkonnen,Белконнен', -35.2166700, 149.0833300, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4785, 'Bega', 'Bega', 'Bega,QBE,Бега', -36.6739200, 149.8417800, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4786, 'Beenleigh', 'Beenleigh', 'Beenleigh', -27.7113700, 153.2029000, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4787, 'Beauty Point', 'Beauty Point', 'B''juti Point,Beauty Point,Бьюти Поинт', -41.1621600, 146.8214600, 'AU', '2015-08-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4788, 'Beaumaris', 'Beaumaris', '', -37.9853400, 145.0336100, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4789, 'Beaconsfield Upper', 'Beaconsfield Upper', 'Beaconsfield Upper,Upper Beaconsfield', -37.9941500, 145.4142000, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4790, 'Beaconsfield', 'Beaconsfield', 'Beaconsfield', -41.2022700, 146.8172300, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4791, 'Bay View', 'Bay View', 'Bayview', -33.6598200, 151.2987800, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4792, 'Bayswater', 'Bayswater', 'Bayswater', -37.8500000, 145.2666700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4793, 'Baxter', 'Baxter', '', -38.2000000, 145.1500000, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4794, 'Baulkham Hills', 'Baulkham Hills', '', -33.7588100, 150.9929200, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4795, 'Bathurst', 'Bathurst', 'BHS,Baterst,Bathurst,Behtkherst,Betkherst,ba se si te,baeseoseuteu,basasuto,batwrst  nyw sawt wlz,batwrst  yyny gwnyy wlz,Батерст,Бетхерст,Бэтхерст,باتورست، نیو ساوت ولز,باتورست، یئنی گونئی ولز,باتھرسٹ,باتھرسٹ، نیو ساؤتھ ویلز,بەتۆرست، نیو ساوت وێلز,ბათერსტი,ባተርስት,バサースト,巴瑟斯特,배서스트', -33.4166500, 149.5806000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4796, 'Batemans Bay', 'Batemans Bay', 'Bateman,Batemans,Batemans Bay,QBW,bei tuo ma en si wan,孛脱马恩斯湾', -35.7065800, 150.1754100, 'AU', '2016-05-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4797, 'Barmera', 'Barmera', 'Barmera,Бармера', -34.2556200, 140.4614700, 'AU', '2013-08-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4798, 'Banora Point', 'Banora Point', '', -28.2129800, 153.5363400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4799, 'Bankstown', 'Bankstown', 'BWU,Bankstown,bankusutaun,バンクスタウン', -33.9166700, 151.0333300, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4800, 'Balwyn', 'Balwyn', 'Deepene', -37.8166700, 145.0666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4801, 'Balnarring', 'Balnarring', 'Balnarring', -38.3666700, 145.1333300, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4802, 'Balmain', 'Balmain', 'Balmain', -33.8548100, 151.1833000, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4803, 'Ballina', 'Ballina', 'BNK,Ballina,West Ballina', -28.8641400, 153.5654100, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4804, 'Ballarat East', 'Ballarat East', '', -37.5666700, 143.8666700, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4805, 'Ballarat', 'Ballarat', 'Balarat,Balaratas,Ballaarat,Ballarat,ba la rui te,baelleolaes,balarat,balart,ballarata,bararatto,blrt,Μπαλαράτ,Баларат,Балларат,בלאראט,بالارات,بالاراٹ,بالارت,بلرت,بەلێرات,बल्लारत,ბალარატი,バララット,巴拉瑞特,밸러랫', -37.5662200, 143.8495700, 'AU', '2014-05-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4806, 'Balgowlah', 'Balgowlah', 'Balgowlah', -33.7949400, 151.2572000, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4807, 'Balaclava', 'Balaclava', '', -37.8666700, 145.0000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4808, 'Bairnsdale', 'Bairnsdale', 'BSJ,Bairnsdale,Bairsdale,Behrnsdejl,Bernsdejl,Бернсдейл,Бэрнсдейл,برینزڈیل، وکٹوریہ,بیرنزدێل,بیرنزڈیل', -37.8228900, 147.6104100, 'AU', '2013-08-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4809, 'Badger Creek', 'Badger Creek', 'Badger Creek,Badgers Creek', -37.7000000, 145.5166700, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4810, 'Bacchus Marsh', 'Bacchus Marsh', 'Bakkus-Marsh,Баккус-Марш', -37.6726800, 144.4382900, 'AU', '2016-03-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4811, 'Ayr', 'Ayr', 'AYR,Ayr', -19.5739300, 147.4066600, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4812, 'Avoca Beach', 'Avoca Beach', 'Avoca Beach', -33.4681800, 151.4339000, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4813, 'Austins Ferry', 'Austins Ferry', 'Austins Ferry', -42.7666700, 147.2500000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4814, 'Auburn', 'Auburn', 'Auburn,ao ben,奧本', -33.8500000, 151.0333300, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4815, 'Atherton', 'Atherton', 'Aterton,Atherton,Атертон', -17.2686400, 145.4752200, 'AU', '2015-08-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4816, 'Asquith', 'Asquith', 'Asquith', -33.6833300, 151.1000000, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4817, 'Aspendale', 'Aspendale', '', -38.0291300, 145.1026600, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4818, 'Ashfield', 'Ashfield', '', -33.8883400, 151.1227400, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4819, 'Ashburton', 'Ashburton', 'Ashburton', -37.8666700, 145.0833300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4820, 'Ascot Vale', 'Ascot Vale', 'Ascot Vale', -37.7833300, 144.9166700, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4821, 'Artarmon', 'Artarmon', 'Artarman,Artarmon', -33.8166700, 151.1833300, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4822, 'Armidale', 'Armidale', 'ARM,Armidale,Armidejl,a mi dai er,amideiru,armdal,armideili,armydal,armydal  yyny gwnyy wlz,Армидейл,Армідейл,آرمدال,آرمیدال,آرمیدال، یئنی گونئی ولز,آرمیڈیل,ئارمیداڵ,არმიდეილი,አርሚዳል,アーミデイル,阿米代尔', -30.5012300, 151.6655300, 'AU', '2017-06-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4823, 'Arcadia', 'Arcadia', 'Arcadia', -33.6166700, 151.0333300, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4824, 'Ararat', 'Ararat', 'ARY,Ararat,Butingitch,ararat  wyktwrya,Арарат,Արարատ,آرارات، ویکتوریا,آراراٹ,ئارارات، ڤیکتۆریا,ارارات، وکٹوریہ,არარატი', -37.2854200, 142.9272800, 'AU', '2015-07-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4825, 'Apollo Bay', 'Apollo Bay', 'Apollo Bay,Apollo Behj,Kambruk,Krambruck,Krambruk,Аполло Бэй', -38.7594000, 143.6721900, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4826, 'Anna Bay', 'Anna Bay', 'Anna Bay', -32.7813500, 152.0858600, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4827, 'Anglesea', 'Anglesea', 'Anglesea,Anglesea River,Ehnglsi,Энглси', -38.4073000, 144.1858700, 'AU', '2012-02-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4828, 'Altona', 'Altona', '', -37.8696400, 144.8303600, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4829, 'Alphington', 'Alphington', '', -37.7833300, 145.0333300, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4830, 'Allansford', 'Allansford', 'Allansford', -38.3863900, 142.5943100, 'AU', '2013-07-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4831, 'Alexandria', 'Alexandria', 'Alexandria', -33.9166700, 151.2000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4832, 'Alexandra', 'Alexandra', 'Alegzandra,Alexandra,Алегзандра,الیگزینڈرا، وکٹوریہ', -37.1913200, 145.7112000, 'AU', '2013-07-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4833, 'Albury', 'Albury', 'ABX,Albury,Olberi,Olberis,Town of Albury,aelbeoli,albry,albwry,ao er bo li,aylbry,olberi,oruberi,Олбери,אולבורי,آلبری,ألبوري,ئەڵبوری,البری,ایلبری,ოლბერი,አልበሪ,オルベリー,奥尔伯里,앨버리', -36.0748200, 146.9240100, 'AU', '2016-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4834, 'Albion', 'Albion', '', -37.7666700, 144.8333300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4835, 'Albert Park', 'Albert Park', 'Albert Park', -37.8333300, 145.0000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4836, 'Abbotsford', 'Abbotsford', 'Abbotsford', -37.8000000, 145.0000000, 'AU', '2016-06-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4837, 'Holmesville', 'Holmesville', '', -32.9000000, 151.5916700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4838, 'Lambton', 'Lambton', 'Lambton', -32.9166700, 151.7000000, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4839, 'New Lambton', 'New Lambton', 'New Lambton', -32.9500000, 151.6833300, 'AU', '2012-08-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4840, 'Raymond Terrace', 'Raymond Terrace', '', -32.7500000, 151.7500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4841, 'Mayfield', 'Mayfield', 'Mayfield', -41.3876000, 147.1305200, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4842, 'Invermay', 'Invermay', 'Invermay', -41.3916700, 147.1305600, 'AU', '2012-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4843, 'Gymea', 'Gymea', 'Gymea', -34.0363700, 151.0852800, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4844, 'Kirrawee', 'Kirrawee', 'Kirrawee', -34.0383100, 151.0690300, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4845, 'Loftus', 'Loftus', 'Loftus', -34.0446700, 151.0464600, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4846, 'Dolans Bay', 'Dolans Bay', 'Dolans Bay', -34.0665300, 151.1280600, 'AU', '2016-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4847, 'Bundeena', 'Bundeena', '', -34.0838400, 151.1501600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4848, 'Gymea Bay', 'Gymea Bay', 'Gymea Bay', -34.0520900, 151.0879500, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4849, 'Kareela', 'Kareela', 'Kareela', -34.0133600, 151.0834500, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4850, 'Bonnet Bay', 'Bonnet Bay', 'Bonnet Bay', -34.0102300, 151.0525300, 'AU', '2016-12-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4851, 'Oyster Bay', 'Oyster Bay', '', -34.0040700, 151.0758800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4852, 'Grays Point', 'Grays Point', 'Grays Point', -34.0587300, 151.0860400, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4853, 'Brighton-Le-Sands', 'Brighton-Le-Sands', 'Brighton-Le-Sands,برائٹن لے سینڈز، نیو ساؤتھ ویلز', -33.9600900, 151.1511000, 'AU', '2015-05-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4854, 'Monterey', 'Monterey', 'Monterey', -33.9725000, 151.1481000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4855, 'Ramsgate', 'Ramsgate', 'Ramsgate', -33.9822000, 151.1400000, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4856, 'Blakehurst', 'Blakehurst', 'Blakehurst', -33.9915200, 151.1087600, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4857, 'Connells Point', 'Connells Point', 'Connells Point', -33.9882700, 151.0909400, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4858, 'Lugarno', 'Lugarno', 'Lugarno', -33.9826700, 151.0418400, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4859, 'Peakhurst', 'Peakhurst', 'Peakhurst', -33.9628800, 151.0516100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4860, 'Padstow', 'Padstow', 'Padstow', -33.9568700, 151.0319100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4861, 'Goodwood', 'Goodwood', 'Goodwood', -42.8282200, 147.2930100, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4862, 'Lutana', 'Lutana', 'Lutana', -42.8347500, 147.3115200, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4863, 'New Town', 'New Town', 'New Town', -42.8575800, 147.3086900, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4864, 'Lake Heights', 'Lake Heights', 'Lake Heights', -34.4866700, 150.8750000, 'AU', '2013-04-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4865, 'Sandy Bay', 'Sandy Bay', '', -42.8944900, 147.3243900, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4866, 'Fairy Meadow', 'Fairy Meadow', 'Fairy Meadow', -34.3930300, 150.8927500, 'AU', '2016-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4867, 'Mount Ousley', 'Mount Ousley', 'Mount Ousley', -34.4021300, 150.8878600, 'AU', '2016-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4868, 'Mount Keira', 'Mount Keira', '', -34.4188900, 150.8541700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4869, 'Gwynneville', 'Gwynneville', 'Gwynneville', -34.4166700, 150.8875000, 'AU', '2012-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4870, 'Mangerton', 'Mangerton', 'Mangerton', -34.4366700, 150.8716700, 'AU', '2012-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4871, 'Mount Saint Thomas', 'Mount Saint Thomas', '', -34.4433300, 150.8722200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4872, 'Palm Cove', 'Palm Cove', '', -16.7500000, 145.6666700, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4873, 'Yorkeys Knob', 'Yorkeys Knob', 'Yorkeys Knob,Yorkeys Knob Beach', -16.8027800, 145.7208300, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4874, 'South Brisbane', 'South Brisbane', '', -27.4803400, 153.0204900, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4875, 'Scarborough', 'Scarborough', 'Scarborough', -27.2011800, 153.1093900, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4876, 'Bonbeach', 'Bonbeach', '', -38.0652800, 145.1227800, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4877, 'McCrae', 'McCrae', '', -38.3497200, 144.9280600, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4878, 'Laverton', 'Laverton', '', -37.8620100, 144.7697900, 'AU', '2011-09-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4879, 'North Brighton', 'North Brighton', '', -37.9069400, 145.0052800, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4880, 'Cheltenham', 'Cheltenham', 'Cheltenham', -37.9694400, 145.0480600, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4881, 'Bellevue Hill', 'Bellevue Hill', 'Bellevue Hill', -33.8789900, 151.2510100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4882, 'Paddington', 'Paddington', 'Paddington,pdyngtwn,פדינגטון', -33.8841900, 151.2315100, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4883, 'Lilyfield', 'Lilyfield', 'Lilyfield', -33.8749900, 151.1653000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4884, 'Drummoyne', 'Drummoyne', 'Drummoyne', -33.8523700, 151.1549100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4885, 'Greenwich', 'Greenwich', 'Greenwich', -33.8395400, 151.1830000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4886, 'Hunters Hill', 'Hunters Hill', 'Hunter''s Hill,Hunters Hill', -33.8343200, 151.1459000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4887, 'Longueville', 'Longueville', 'Longueville', -33.8328500, 151.1653100, 'AU', '2016-12-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4888, 'Crows Nest', 'Crows Nest', 'Crows Nest', -33.8249400, 151.2039800, 'AU', '2016-03-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4889, 'Cammeray', 'Cammeray', 'Cammeray', -33.8213200, 151.2160900, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4890, 'Clontarf', 'Clontarf', 'Clontarf', -33.8055400, 151.2536700, 'AU', '2016-01-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4891, 'Cremorne', 'Cremorne', 'Cremorne', -33.8267900, 151.2263300, 'AU', '2016-03-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4892, 'Neutral Bay', 'Neutral Bay', 'Neutral Bay', -33.8378400, 151.2175000, 'AU', '2014-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4893, 'Point Piper', 'Point Piper', 'Point Piper', -33.8666700, 151.2500000, 'AU', '2014-04-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4894, 'Darling Point', 'Darling Point', 'Darling Point', -33.8706400, 151.2389500, 'AU', '2014-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4895, 'Dover Heights', 'Dover Heights', 'Dover Heights', -33.8708300, 151.2791700, 'AU', '2012-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4896, 'Randwick', 'Randwick', 'Randwick,rndwwyq,רנדוויק,র‌্যান্ডউইক', -33.9143900, 151.2489500, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4897, 'Clovelly', 'Clovelly', 'Clovelly', -33.9121400, 151.2588200, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4898, 'Bronte', 'Bronte', 'Bronte', -33.9019800, 151.2655600, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4899, 'Bondi', 'Bondi', 'bang di,bwndyy,בונדיי,邦迪', -33.8942900, 151.2644400, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4900, 'Gladesville', 'Gladesville', 'Gladesville', -33.8333300, 151.1333300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4901, 'Forestville', 'Forestville', 'Forestville', -33.7666700, 151.2083300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4902, 'Brookvale', 'Brookvale', 'Brookvale', -33.7610800, 151.2744600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4903, 'Curl Curl', 'Curl Curl', 'Curl Curl', -33.7688600, 151.2888800, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4904, 'Dee Why', 'Dee Why', 'Dee why', -33.7500000, 151.3000000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4905, 'Umina', 'Umina', 'Umina Beach', -33.5231400, 151.3132500, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4906, 'Blairgowrie', 'Blairgowrie', '', -38.3613100, 144.7795500, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4907, 'Flinders', 'Flinders', '', -34.5833300, 150.8551600, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4908, 'Airport West', 'Airport West', '', -37.7247000, 144.8812600, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4909, 'Niddrie', 'Niddrie', '', -37.7375000, 144.8921200, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4910, 'Gladstone Park', 'Gladstone Park', '', -37.6874200, 144.8867500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4911, 'Palmerston', 'Palmerston', 'Palmerston,pa mo si dun,Палмерстон,پالمرسٹون,პალმერსტონი,帕默斯頓', -12.4860200, 130.9833000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4912, 'Tom Price', 'Tom Price', 'TPR', -22.6939000, 117.7931000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4913, 'Moranbah', 'Moranbah', 'MOV', -22.0016300, 148.0466100, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4914, 'Heyfield', 'Heyfield', '', -37.9813000, 146.7855900, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4915, 'Kaleen', 'Kaleen', '', -35.2181400, 149.1051600, 'AU', '2015-03-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4916, 'Karratha', 'Karratha', 'KTA,Karatha,Karratha,קראטה,კარათა', -20.7376500, 116.8462900, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4917, 'Enfield', 'Enfield', '', -34.8526000, 138.6025500, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4918, 'Hillarys', 'Hillarys', '', -31.8069800, 115.7404500, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4919, 'Kingsford', 'Kingsford', '', -33.9239900, 151.2274900, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4920, 'Klemzig', 'Klemzig', '', -34.8792800, 138.6356200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4921, 'Maidstone', 'Maidstone', '', -37.7803500, 144.8735300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4922, 'Osborne Park', 'Osborne Park', '', -31.9006600, 115.8108300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4923, 'Seven Mile Beach', 'Seven Mile Beach', '', -42.8586300, 147.5053200, 'AU', '2015-04-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4924, 'Woollahra', 'Woollahra', '', -33.8878000, 151.2368100, 'AU', '2014-06-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4925, 'Corlette', 'Corlette', '', -32.7201400, 152.1084600, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4926, 'Burswood', 'Burswood', '', -31.9587200, 115.9039600, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4927, 'Howrah', 'Howrah', '', -42.8872800, 147.4055400, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4928, 'Springfield Lakes', 'Springfield Lakes', '', -27.6675700, 152.9248800, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4929, 'Attwood', 'Attwood', '', -37.6695500, 144.8867500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4930, 'North Narrabeen', 'North Narrabeen', '', -33.7093500, 151.2960700, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4931, 'Joondalup', 'Joondalup', 'jun da le,jwndalwp,جوندالوپ,君达乐', -31.7444500, 115.7683500, 'AU', '2014-12-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4932, 'Como', 'Como', '', -31.9911900, 115.8633600, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4933, 'Arncliffe', 'Arncliffe', '', -33.9362700, 151.1481900, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4934, 'East Lismore', 'East Lismore', '', -28.8259100, 153.2888000, 'AU', '2016-09-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4935, 'Mindarie', 'Mindarie', '', -31.6893200, 115.7069800, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4936, 'Clarkson', 'Clarkson', '', -31.6828200, 115.7247000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4937, 'Kinross', 'Kinross', '', -31.7186800, 115.7383900, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4938, 'Currambine', 'Currambine', '', -31.7330600, 115.7476600, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4939, 'Iluka', 'Iluka', '', -31.7355400, 115.7305800, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4940, 'Heathridge', 'Heathridge', '', -31.7624400, 115.7589500, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4941, 'Girraween', 'Girraween', 'Girraween', -33.7990000, 150.9430000, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4942, 'Freshwater', 'Freshwater', '', -33.7786700, 151.2856900, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4943, 'Tieri', 'Tieri', '', -23.0382900, 148.3446300, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4944, 'Kingsbury', 'Kingsbury', '', -37.7140600, 145.0350900, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4945, 'Taringa', 'Taringa', '', -27.4906100, 152.9786100, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4946, 'Inala', 'Inala', '', -27.5971500, 152.9743200, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4947, 'Mount Lawley', 'Mount Lawley', 'Mount Lawley,Mt Lawley', -31.9343900, 115.8716000, 'AU', '2013-04-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4948, 'Main Beach', 'Main Beach', '', -27.9787900, 153.4266000, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4949, 'Paradise', 'Paradise', '', -34.8736100, 138.6689600, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4950, 'Blair Athol', 'Blair Athol', '', -34.8588900, 138.5965600, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4951, 'Athelstone', 'Athelstone', '', -34.8701900, 138.6999000, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4952, 'Wooloowin', 'Wooloowin', '', -27.4224400, 153.0420400, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4953, 'Zillmere', 'Zillmere', '', -27.3559100, 153.0445300, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4954, 'Taigum', 'Taigum', '', -27.3426500, 153.0444400, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4955, 'Bracken Ridge', 'Bracken Ridge', '', -27.3171000, 153.0309700, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4956, 'Mango Hill', 'Mango Hill', '', -27.2434900, 153.0238400, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4957, 'Woolloongabba', 'Woolloongabba', '', -27.4885500, 153.0365500, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4958, 'Milton', 'Milton', 'Milton', -27.4703900, 153.0031200, 'AU', '2015-01-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4959, 'Fortitude Valley', 'Fortitude Valley', 'Fortitjud Vali,Фортитјуд Вали,フォーティテュード・ヴァリー', -27.4570600, 153.0317800, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4960, 'Windsor', 'Windsor', '', -27.4363100, 153.0288200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4961, 'Twin Waters', 'Twin Waters', '', -26.6100000, 153.0000000, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4962, 'Bridegman Downs', 'Bridegman Downs', '', -27.3553800, 152.9943200, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4963, 'Canada Bay', 'Canada Bay', '', -33.8500000, 151.1500000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4964, 'Canterbury', 'Canterbury', 'kyantaraberi,ক্যান্টারবেরি', -33.9119200, 151.1186200, 'AU', '2014-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4965, 'Forresters Beach', 'Forresters Beach', '', -33.4070000, 151.4760000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4966, 'Tamborine Mountain', 'Tamborine Mountain', 'Mount Tamborine', -27.9695400, 153.1993700, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4967, 'East Melbourne', 'East Melbourne', 'East Melbourne,Melbourne East', -37.8166700, 144.9879000, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4968, 'Rainbow Beach', 'Rainbow Beach', '', -25.9043200, 153.0917400, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4969, 'North Shore', 'North Shore', '', -31.4023700, 152.9018500, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4970, 'North Ryde', 'North Ryde', '', -33.7967700, 151.1243600, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4971, 'Stirling', 'Stirling', '', -31.8834300, 115.8099000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4972, 'North Melbourne', 'North Melbourne', 'Melbourne North,North Melbourne,bei mo er ben,北墨尔本', -37.8028900, 144.9481600, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4973, 'Caroline Springs', 'Caroline Springs', '', -37.7412400, 144.7363100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4974, 'Hoppers Crossing', 'Hoppers Crossing', '', -37.8826400, 144.7003000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4975, 'West Melbourne', 'West Melbourne', 'Melbourne West,West Melbourne', -37.8101400, 144.9500000, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4976, 'Rouse Hill', 'Rouse Hill', '', -33.6820700, 150.9154000, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4977, 'Logan City', 'Logan City', 'Citta di Logan,Città di Logan,Logan,Logan City,logani,luo gen shi,lwghan syty,لوغان سيتي,لوگن سٹی,ლოგანი,洛根市', -27.6391700, 153.1094400, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4978, 'Carindale', 'Carindale', '', -27.5057800, 153.1023600, 'AU', '2015-01-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4979, 'Parramatta', 'Parramatta', '', -33.8178000, 151.0034800, 'AU', '2017-07-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4980, 'Macquarie', 'Macquarie', '', -35.2512600, 149.0636300, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4981, 'Ferntree Gully', 'Ferntree Gully', 'prntry gly,פרנטרי גלי', -37.8846100, 145.2953900, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4982, 'Fullarton', 'Fullarton', '', -34.9510000, 138.6290000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4983, 'Macarthur', 'Macarthur', 'McArthur', -35.4088500, 149.1269600, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4984, 'City of Parramatta', 'City of Parramatta', 'City of Parramatta,Parramatta', -33.8166700, 151.0000000, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4985, 'Phillip Island', 'Phillip Island', '', -38.4834900, 145.2310200, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4986, 'Springwood', 'Springwood', '', -27.6118300, 153.1289900, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4987, 'Adelaide Hills', 'Adelaide Hills', '', -34.9111900, 138.7073500, 'AU', '2013-06-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4988, 'Erskine', 'Erskine', '', -32.5571700, 115.7065700, 'AU', '2015-02-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4989, 'Canning Vale', 'Canning Vale', '', -32.0579900, 115.9181400, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4990, 'Varsity Lakes', 'Varsity Lakes', '', -28.0894000, 153.4122000, 'AU', '2015-02-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4991, 'Roselands', 'Roselands', '', -33.9331700, 151.0732000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4992, 'Oxenford', 'Oxenford', '', -27.8903300, 153.3130900, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4993, 'Toormina', 'Toormina', '', -30.3538400, 153.0884300, 'AU', '2014-09-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4994, 'Glenmore Park', 'Glenmore Park', '', -33.7906800, 150.6693000, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4995, 'Southbank', 'Southbank', 'Sautbenk,Southbank,nan an,Саутбенк,南岸', -37.8228000, 144.9643400, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4996, 'Magnetic Island', 'Magnetic Island', '', -19.1551400, 146.8485000, 'AU', '2011-06-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4997, 'St Kilda East', 'St Kilda East', '', -37.8659400, 145.0001800, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4998, 'Docklands', 'Docklands', 'Doklends,mo er ben bin hai gang qu,Доклендс,墨爾本濱海港區', -37.8149000, 144.9505200, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(4999, 'Shoalwater', 'Shoalwater', '', -32.2908800, 115.7110100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5000, 'Melton West', 'Melton West', '', -37.6785200, 144.5688300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5001, 'Brookfield', 'Brookfield', '', -37.7008000, 144.5602500, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5002, 'Kurunjang', 'Kurunjang', '', -37.6758700, 144.5969000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5003, 'Ashwood', 'Ashwood', '', -37.8665900, 145.1055300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5004, 'Glen Iris', 'Glen Iris', '', -37.8599500, 145.0548900, 'AU', '2011-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5005, 'Caulfield North', 'Caulfield North', '', -37.8725500, 145.0226200, 'AU', '2011-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5006, 'Elsternwick', 'Elsternwick', '', -37.8844100, 145.0043400, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5007, 'Elwood', 'Elwood', '', -37.8821400, 144.9821500, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5008, 'Burwood', 'Burwood', '', -37.8497800, 145.1190100, 'AU', '2011-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5009, 'Box Hill South', 'Box Hill South', '', -37.8323600, 145.1209800, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5010, 'Blackburn', 'Blackburn', '', -37.8190100, 145.1532600, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5011, 'Canterbury', 'Canterbury', '', -37.8247000, 145.0847600, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5012, 'Hawthorn East', 'Hawthorn East', '', -37.8248400, 145.0464000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5013, 'Kew East', 'Kew East', '', -37.7975800, 145.0537800, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5014, 'Balwyn North', 'Balwyn North', '', -37.7908600, 145.0938600, 'AU', '2011-08-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5015, 'Mont Albert North', 'Mont Albert North', '', -37.8004300, 145.1082800, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5016, 'Box Hill North', 'Box Hill North', '', -37.8026600, 145.1265600, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5017, 'Blackburn North', 'Blackburn North', '', -37.8093100, 145.1518000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5018, 'Blackburn South', 'Blackburn South', '', -37.8397500, 145.1554900, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5019, 'Chadstone', 'Chadstone', '', -37.8876600, 145.0951900, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5020, 'Malvern East', 'Malvern East', 'East Malvern', -37.8739700, 145.0425300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5021, 'Oakleigh South', 'Oakleigh South', '', -37.9241600, 145.0914600, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5022, 'Caulfield South', 'Caulfield South', '', -37.8956200, 145.0259700, 'AU', '2014-09-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5023, 'Brighton East', 'Brighton East', '', -37.9023200, 145.0173400, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5024, 'Hampton East', 'Hampton East', '', -37.9369500, 145.0286300, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5025, 'Black Rock', 'Black Rock', '', -37.9735700, 145.0163600, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5026, 'Aspendale Gardens', 'Aspendale Gardens', '', -38.0227700, 145.1179800, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5027, 'Booval', 'Booval', '', -27.6132800, 152.7894400, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5028, 'North Booval', 'North Booval', '', -27.6039200, 152.7948500, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5029, 'North Ipswich', 'North Ipswich', '', -27.6028600, 152.7614600, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5030, 'Brassall', 'Brassall', '', -27.5975300, 152.7475500, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5031, 'Silkstone', 'Silkstone', '', -27.6212600, 152.7876800, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5032, 'Eastern Heights', 'Eastern Heights', '', -27.6284900, 152.7782800, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5033, 'Raceview', 'Raceview', '', -27.6347200, 152.7751900, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5034, 'Flinders View', 'Flinders View', '', -27.6504600, 152.7745100, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5035, 'Deebing Heights', 'Deebing Heights', '', -27.6671900, 152.7486700, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5036, 'Yamanto', 'Yamanto', '', -27.6602700, 152.7386300, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5037, 'Redbank Plains', 'Redbank Plains', '', -27.6461300, 152.8596500, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5038, 'Collingwood Park', 'Collingwood Park', '', -27.6128200, 152.8600800, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5039, 'Clontarf', 'Clontarf', '', -27.2534100, 153.0783500, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5040, 'Woody Point', 'Woody Point', '', -27.2560800, 153.1042700, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5041, 'Ballarat Central', 'Ballarat Central', '', -37.5620600, 143.8508200, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5042, 'Golden Point', 'Golden Point', '', -37.5749300, 143.8687000, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5043, 'Delacombe', 'Delacombe', '', -37.5891100, 143.8147200, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5044, 'St Albans', 'St Albans', 'Saint Albans', -37.7449600, 144.8004900, 'AU', '2011-09-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5045, 'St Leonards', 'St Leonards', '', -33.8234400, 151.1983600, 'AU', '2011-09-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5046, 'St Kilda West', 'St Kilda West', 'Saint Kilda West', -37.8598800, 144.9710800, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5047, 'Eleebana', 'Eleebana', '', -32.9896000, 151.6364200, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5048, 'Summer Hill', 'Summer Hill', '', -33.8914600, 151.1382500, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5049, 'Bohle Plains', 'Bohle Plains', 'Bohle Plains', -19.3136500, 146.6918600, 'AU', '2015-02-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5050, 'Jacobs Well', 'Jacobs Well', 'Jacobs Well', -27.7799200, 153.3615300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5051, 'Launching Place', 'Launching Place', 'Launching Place', -37.7805800, 145.5683400, 'AU', '2015-01-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5052, 'Saint Andrews Beach', 'Saint Andrews Beach', 'Saint Andrews Beach', -38.4141000, 144.8243600, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5053, 'West Perth', 'West Perth', 'West Perth', -31.9489600, 115.8419900, 'AU', '2012-05-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5054, 'Altona North', 'Altona North', 'North Altona', -37.8348700, 144.8473500, 'AU', '2012-05-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5055, 'Balcatta', 'Balcatta', 'Balcatta', -31.8750100, 115.8283900, 'AU', '2012-05-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5056, 'Belmont', 'Belmont', 'Belmont', -31.9435000, 115.9255000, 'AU', '2012-05-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5057, 'Bateau Bay', 'Bateau Bay', 'Bateau Bay', -33.3833400, 151.4667100, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5058, 'Macmasters Beach', 'Macmasters Beach', 'McMasters Beach', -33.4966300, 151.4221500, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5059, 'Paraburdoo', 'Paraburdoo', 'PBO,Paraburdoo', -23.2041700, 117.6697300, 'AU', '2015-09-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5060, 'Pottsville Beach', 'Pottsville Beach', 'Pottsville Beach', -28.3885300, 153.5656400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5061, 'Thursday Island', 'Thursday Island', 'Ile Thursday,Ilha Thursday,Tersdi,Thursday,Thursday Island,Torsdagsoen,Torsdagsön,Wyspa Thursday,mog-yoseom,mu yao dao,ta shi die dao,xing qi si dao,Île Thursday,Терсди,Терсді,他士爹島,星期四岛,星期四島,木曜島,목요섬', -10.5825700, 142.2194900, 'AU', '2016-11-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5062, 'East Perth', 'East Perth', 'East Perth', -31.9587200, 115.8710900, 'AU', '2012-06-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5063, 'Leederville', 'Leederville', 'Leederville', -31.9362800, 115.8419000, 'AU', '2012-06-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5064, 'Alexandria', 'Alexandria', 'Alexandria', -33.9021900, 151.2003700, 'AU', '2012-06-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5065, 'Doveton', 'Doveton', '', -37.9934600, 145.2389100, 'AU', '2012-07-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5066, 'Endeavour Hills', 'Endeavour Hills', '', -37.9769500, 145.2586600, 'AU', '2012-07-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5067, 'Tighes Hill', 'Tighes Hill', '', -32.9073200, 151.7509000, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5068, 'White Gum Valley', 'White Gum Valley', '', -32.0603100, 115.7705800, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5069, 'Tapping', 'Tapping', '', -31.7194700, 115.7955900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5070, 'Casuarina', 'Casuarina', '', -28.3004200, 153.5706400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5071, 'Taylors Lakes', 'Taylors Lakes', '', -37.6986300, 144.7863100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5072, 'Woodvale', 'Woodvale', '', -31.7892800, 115.7967600, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5073, 'Bellfield', 'Bellfield', '', -37.7530900, 145.0384800, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5074, 'Roxburgh Park', 'Roxburgh Park', '', -37.6258100, 144.9255500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5075, 'Eumemmerring', 'Eumemmerring', '', -37.9978000, 145.2482100, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5076, 'Warriewood', 'Warriewood', '', -33.6885700, 151.2953400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5077, 'Beeliar', 'Beeliar', '', -32.1333900, 115.8063700, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5078, 'Lynbrook', 'Lynbrook', '', -38.0558800, 145.2561500, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5079, 'Botanic Ridge', 'Botanic Ridge', '', -38.1392200, 145.2684100, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5080, 'Orelia', 'Orelia', '', -32.2333000, 115.8222700, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5081, 'Waterways', 'Waterways', '', -38.0147800, 145.1305000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5082, 'Wyndham Vale', 'Wyndham Vale', '', -37.8415000, 144.5410100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5083, 'Ardross', 'Ardross', '', -32.0269600, 115.8354800, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5084, 'Long Gully', 'Long Gully', '', -36.7430500, 144.2578800, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5085, 'Willetton', 'Willetton', '', -32.0525100, 115.8878200, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5086, 'Travancore', 'Travancore', '', -37.7807600, 144.9354500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5087, 'Carramar', 'Carramar', '', -31.6902300, 115.7715900, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5088, 'Seaholme', 'Seaholme', '', -37.8640000, 144.8450400, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5089, 'South Kingsville', 'South Kingsville', '', -37.8301800, 144.8709000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5090, 'Safety Beach', 'Safety Beach', '', -38.3153500, 145.0002700, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5091, 'Blind Bight', 'Blind Bight', '', -38.2142700, 145.3377000, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5092, 'Alexander Heights', 'Alexander Heights', '', -31.8275800, 115.8650100, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5093, 'Singleton', 'Singleton', '', -32.4440300, 115.7572500, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5094, 'Ridgewood', 'Ridgewood', '', -31.6615000, 115.7226100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5095, 'Delahey', 'Delahey', '', -37.7198000, 144.7773200, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5096, 'Wilson', 'Wilson', '', -32.0205800, 115.9118100, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5097, 'Butler', 'Butler', '', -31.6429800, 115.7043100, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5098, 'Darch', 'Darch', '', -31.8125500, 115.8458000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5099, 'Queens Park', 'Queens Park', '', -32.0031400, 115.9462100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5100, 'Innaloo', 'Innaloo', '', -31.8927200, 115.7950800, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5101, 'Cannon Hill', 'Cannon Hill', '', -27.4723700, 153.0947500, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5102, 'Booragoon', 'Booragoon', '', -32.0394500, 115.8336900, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5103, 'Rossmoyne', 'Rossmoyne', '', -32.0396500, 115.8678100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5104, 'Seville Grove', 'Seville Grove', '', -32.1364500, 115.9890500, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5105, 'Murrumba Downs', 'Murrumba Downs', '', -27.2673300, 153.0105300, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5106, 'Knoxfield', 'Knoxfield', '', -37.8897800, 145.2496200, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5107, 'Chambers Flat', 'Chambers Flat', '', -27.7481100, 153.0776400, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5108, 'Brookdale', 'Brookdale', '', -32.1669600, 116.0019300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5109, 'Little Mountain', 'Little Mountain', '', -26.7843600, 153.0921800, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5110, 'Glendenning', 'Glendenning', '', -33.7483000, 150.8541100, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5111, 'Sinagra', 'Sinagra', '', -31.7426100, 115.8063300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5112, 'Langford', 'Langford', '', -32.0409200, 115.9415700, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5113, 'Padbury', 'Padbury', '', -31.8064500, 115.7688000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5114, 'East Victoria Park', 'East Victoria Park', '', -31.9889400, 115.9038800, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5115, 'Milperra', 'Milperra', '', -33.9393400, 150.9814800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5116, 'Soldiers Hill', 'Soldiers Hill', '', -37.5496200, 143.8587200, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5117, 'Tecoma', 'Tecoma', '', -37.9030300, 145.3446800, 'AU', '2015-01-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5118, 'Palmyra', 'Palmyra', '', -32.0450200, 115.7858900, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5119, 'Stratton', 'Stratton', '', -31.8682800, 116.0406600, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5120, 'Tootgarook', 'Tootgarook', '', -38.3777000, 144.8501500, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5121, 'Spotswood', 'Spotswood', '', -37.8299500, 144.8878400, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5122, 'Bell Park', 'Bell Park', '', -38.1079300, 144.3383900, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5123, 'Bell Post Hill', 'Bell Post Hill', '', -38.0956400, 144.3196800, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5124, 'Quarry Hill', 'Quarry Hill', '', -36.7764600, 144.2802400, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5125, 'Park Orchards', 'Park Orchards', '', -37.7768800, 145.2146300, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5126, 'Golden Square', 'Golden Square', '', -36.7726500, 144.2527100, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5127, 'Annerley', 'Annerley', '', -27.5122800, 153.0324800, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5128, 'Kealba', 'Kealba', '', -37.7371000, 144.8283000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5129, 'Jacana', 'Jacana', '', -37.6877800, 144.9111100, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5130, 'Dulwich Hill', 'Dulwich Hill', '', -33.9041000, 151.1394500, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5131, 'Viewbank', 'Viewbank', '', -37.7399100, 145.0932300, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5132, 'Highvale', 'Highvale', '', -27.3722700, 152.8019500, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5133, 'Chirnside Park', 'Chirnside Park', '', -37.7386000, 145.3143100, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5134, 'Coolaroo', 'Coolaroo', '', -37.6567500, 144.9346000, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5135, 'Junction Village', 'Junction Village', '', -38.1363600, 145.2968400, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5136, 'Meadow Heights', 'Meadow Heights', '', -37.6511700, 144.9185500, 'AU', '2015-01-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5137, 'Middle Park', 'Middle Park', '', -37.8511600, 144.9620100, 'AU', '2015-01-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5138, 'Westminster', 'Westminster', '', -31.8674400, 115.8391900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5139, 'Bertram', 'Bertram', '', -32.2436900, 115.8457200, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5140, 'Bibra Lake', 'Bibra Lake', '', -32.0976400, 115.8192100, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5141, 'Hammond Park', 'Hammond Park', '', -32.1685300, 115.8504000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5142, 'Hillman', 'Hillman', '', -32.2832700, 115.7636400, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5143, 'Yallambie', 'Yallambie', '', -37.7251500, 145.0935200, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5144, 'Kardinya', 'Kardinya', '', -32.0656100, 115.8148300, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5145, 'Karrinyup', 'Karrinyup', '', -31.8723300, 115.7768400, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5146, 'Kewdale', 'Kewdale', '', -31.9788600, 115.9515900, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5147, 'Millars Well', 'Millars Well', '', -20.7416800, 116.8173100, 'AU', '2014-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5148, 'Ocean Reef', 'Ocean Reef', '', -31.7587100, 115.7360100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5149, 'Samson', 'Samson', '', -32.0699600, 115.7977000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5150, 'Port Kennedy', 'Port Kennedy', '', -32.3734200, 115.7515000, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5151, 'Secret Harbour', 'Secret Harbour', '', -32.4058900, 115.7585200, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5152, 'Success', 'Success', '', -32.1428100, 115.8499900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5153, 'Tuart Hill', 'Tuart Hill', '', -31.8980800, 115.8349500, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5154, 'Thornlie', 'Thornlie', '', -32.0600300, 115.9550000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5155, 'Winthrop', 'Winthrop', '', -32.0521600, 115.8297200, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5156, 'Yangebup', 'Yangebup', '', -32.1206500, 115.8162300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5157, 'Yokine', 'Yokine', '', -31.9011300, 115.8531900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5158, 'Brooklyn', 'Brooklyn', '', -37.8160900, 144.8415000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5159, 'Hillside', 'Hillside', '', -37.6904700, 144.7417200, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5160, 'Redcliffe', 'Redcliffe', '', -31.9384500, 115.9464500, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5161, 'Wavell Heights', 'Wavell Heights', '', -27.3938500, 153.0469800, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5162, 'The Vines', 'The Vines', '', -31.7549200, 116.0023800, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5163, 'Springvale', 'Springvale', '', -35.1668700, 147.3305800, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5164, 'Grange', 'Grange', '', -27.4225100, 153.0152700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5165, 'Beldon', 'Beldon', '', -31.7746600, 115.7627000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5166, 'St James', 'St James', '', -32.0000400, 115.9098000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5167, 'Braybrook', 'Braybrook', '', -37.7867100, 144.8548400, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5168, 'Cairnlea', 'Cairnlea', '', -37.7593100, 144.7878100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5169, 'Bundoora', 'Bundoora', '', -37.6982500, 145.0596700, 'AU', '2015-01-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5170, 'Patterson Lakes', 'Patterson Lakes', '', -38.0693400, 145.1432700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5171, 'Southern River', 'Southern River', '', -32.1065800, 115.9589600, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5172, 'Skye', 'Skye', '', -38.1050500, 145.2163000, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5173, 'City of Cockburn', 'City of Cockburn', '', -32.1026100, 115.8442200, 'AU', '2012-09-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5174, 'Beaumont Hills', 'Beaumont Hills', '', -33.6999300, 150.9411000, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5175, 'North Adelaide', 'North Adelaide', 'North Adelaide', -34.9073300, 138.5914100, 'AU', '2013-03-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5176, 'Victoria Park', 'Victoria Park', 'Victoria Park', -31.9761900, 115.9052500, 'AU', '2013-03-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5177, 'Milsons Point', 'Milsons Point', 'Milsons Point', -33.8460000, 151.2119200, 'AU', '2013-03-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5178, 'Forrest', 'Forrest', 'Forrest', -35.3149900, 149.1285900, 'AU', '2013-03-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5179, 'Cranbourne South', 'Cranbourne South', 'Cranbourne South', -38.1350200, 145.2395800, 'AU', '2015-01-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5180, 'Bondi Junction', 'Bondi Junction', 'Bondi Junction', -33.8927500, 151.2472300, 'AU', '2013-06-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5181, 'Bald Hills', 'Bald Hills', '', -27.3211200, 153.0085700, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5182, 'East Geelong', 'East Geelong', '', -38.1556800, 144.3720200, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5183, 'Beecroft', 'Beecroft', 'Bee Croft', -33.7495400, 151.0648000, 'AU', '2015-07-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5184, 'Williams Landing', 'Williams Landing', '', -37.8619000, 144.7437100, 'AU', '2015-01-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5185, 'Nickol', 'Nickol', '', -20.7455800, 116.7954000, 'AU', '2014-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5186, 'Lane Cove North', 'Lane Cove North', '', -33.8054300, 151.1663800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5187, 'Carrolls Creek', 'Carrolls Creek', '', -28.8227200, 152.1030500, 'AU', '2014-09-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5188, 'Ascot', 'Ascot', '', -27.4315400, 153.0580000, 'AU', '2015-01-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5189, 'Robertson', 'Robertson', '', -27.5658300, 153.0573800, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5190, 'Nathan', 'Nathan', '', -27.5588800, 153.0623000, 'AU', '2015-01-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5191, 'Chermside West', 'Chermside West', '', -27.3838300, 153.0158600, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5192, 'Everton Park', 'Everton Park', '', -27.4073200, 152.9884000, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5193, 'Gordon Park', 'Gordon Park', '', -27.4189900, 153.0254700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5194, 'Stafford', 'Stafford', '', -27.4104400, 153.0110500, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5195, 'Stafford Heights', 'Stafford Heights', '', -27.3935400, 153.0105000, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5196, 'Wilston', 'Wilston', '', -27.4321800, 153.0190400, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5197, 'Burbank', 'Burbank', '', -27.5558400, 153.1470100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5198, 'Coopers Plains', 'Coopers Plains', '', -27.5646300, 153.0406700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5199, 'Forest Lake', 'Forest Lake', '', -27.6256300, 152.9688300, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5200, 'Greenslopes', 'Greenslopes', '', -27.5081500, 153.0495100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5201, 'Mackenzie', 'Mackenzie', '', -27.5435100, 153.1205700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5202, 'Mansfield', 'Mansfield', '', -27.5392900, 153.0989500, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5203, 'Mount Gravatt East', 'Mount Gravatt East', '', -27.5405000, 153.0822100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5204, 'Richlands', 'Richlands', '', -27.5961600, 152.9532100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5205, 'Seventeen Mile Rocks', 'Seventeen Mile Rocks', '', -27.5507000, 152.9589600, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5206, 'Sunnybank Hills', 'Sunnybank Hills', '', -27.6102500, 153.0538800, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5207, 'Upper Mount Gravatt', 'Upper Mount Gravatt', '', -27.5612800, 153.0845300, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5208, 'Yeerongpilly', 'Yeerongpilly', '', -27.5215000, 153.0123400, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5209, 'Yeronga', 'Yeronga', '', -27.5157100, 153.0164200, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5210, 'Balmoral', 'Balmoral', '', -27.4534100, 153.0668000, 'AU', '2016-08-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5211, 'Camp Hill', 'Camp Hill', '', -27.4935400, 153.0762900, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5212, 'Chandler', 'Chandler', '', -27.5139800, 153.1490700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5213, 'Manly West', 'Manly West', '', -27.4738200, 153.1664100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5214, 'Morningside', 'Morningside', '', -27.4616500, 153.0751100, 'AU', '2016-08-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5215, 'Seven Hills', 'Seven Hills', '', -27.4834100, 153.0747400, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5216, 'Wynnum West', 'Wynnum West', '', -27.4582400, 153.1531900, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5217, 'Kenmore Hills', 'Kenmore Hills', '', -27.5042000, 152.9318300, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5218, 'Pullenvale', 'Pullenvale', '', -27.5228300, 152.8865100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5219, 'Riverhills', 'Riverhills', '', -27.5592800, 152.9110600, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5220, 'East Ipswich', 'East Ipswich', '', -27.6063700, 152.7723200, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5221, 'Sadliers Crossing', 'Sadliers Crossing', '', -27.6125100, 152.7457700, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5222, 'Springfield', 'Springfield', '', -27.6536500, 152.9171600, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5223, 'Tivoli', 'Tivoli', '', -27.5927800, 152.7679800, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5224, 'Cedar Vale', 'Cedar Vale', '', -27.8892300, 153.0289100, 'AU', '2015-01-13', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5225, 'Logan Reserve', 'Logan Reserve', '', -27.7241400, 153.0900200, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5226, 'North Maclean', 'North Maclean', '', -27.7675900, 153.0164600, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5227, 'Park Ridge South', 'Park Ridge South', '', -27.7270700, 153.0332000, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5228, 'Rochedale South', 'Rochedale South', '', -27.5952100, 153.1233200, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5229, 'Waterford West', 'Waterford West', '', -27.6905600, 153.1331900, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5230, 'Caboolture South', 'Caboolture South', '', -27.0938900, 152.9487400, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5231, 'Ferny Hills', 'Ferny Hills', '', -27.3959400, 152.9373700, 'AU', '2015-01-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5232, 'Samford Valley', 'Samford Valley', '', -27.3727000, 152.8669900, 'AU', '2015-01-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5233, 'Flemington', 'Flemington', '', -37.7882500, 144.9300100, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5234, 'Fairfield', 'Fairfield', '', -37.7797700, 145.0176400, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5235, 'Heidelberg Heights', 'Heidelberg Heights', '', -37.7431300, 145.0569500, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5236, 'Watsonia North', 'Watsonia North', '', -37.6998100, 145.0846800, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5237, 'Westmeadows', 'Westmeadows', '', -37.6760400, 144.8870100, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5238, 'Essendon North', 'Essendon North', '', -37.7422500, 144.9054600, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5239, 'Essendon West', 'Essendon West', '', -37.7575800, 144.8790300, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5240, 'Keilor East', 'Keilor East', '', -37.7326100, 144.8650400, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5241, 'Coburg North', 'Coburg North', '', -37.7286700, 144.9613400, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5242, 'Gowanbrae', 'Gowanbrae', '', -37.7082300, 144.8907900, 'AU', '2015-01-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5243, 'Hadfield', 'Hadfield', '', -37.7072800, 144.9416000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5244, 'Oak Park', 'Oak Park', '', -37.7184200, 144.9194500, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5245, 'Pascoe Vale South', 'Pascoe Vale South', '', -37.7397300, 144.9461500, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5246, 'North Warrandyte', 'North Warrandyte', '', -37.7292400, 145.2157400, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5247, 'Bayswater North', 'Bayswater North', '', -37.8261200, 145.2983100, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5248, 'Croydon Hills', 'Croydon Hills', '', -37.7765100, 145.2635500, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5249, 'Croydon South', 'Croydon South', '', -37.8123200, 145.2681000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5250, 'Kilsyth South', 'Kilsyth South', '', -37.8203300, 145.3159900, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5251, 'Warranwood', 'Warranwood', '', -37.7755500, 145.2472800, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5252, 'Vermont South', 'Vermont South', '', -37.8574700, 145.1827000, 'AU', '2015-01-26', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5253, 'Officer South', 'Officer South', '', -38.0863000, 145.4020800, 'AU', '2016-03-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5254, 'Cranbourne East', 'Cranbourne East', '', -38.1153100, 145.2981400, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5255, 'Cranbourne North', 'Cranbourne North', '', -38.0829200, 145.2780500, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5256, 'Cranbourne West', 'Cranbourne West', '', -38.0965000, 145.2670700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5257, 'Narre Warren South', 'Narre Warren South', '', -38.0436900, 145.2923000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5258, 'Dandenong North', 'Dandenong North', '', -37.9664900, 145.2081000, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5259, 'Noble Park North', 'Noble Park North', '', -37.9497800, 145.1925700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5260, 'Frankston North', 'Frankston North', '', -38.1235200, 145.1483600, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5261, 'Frankston South', 'Frankston South', '', -38.1660400, 145.1364300, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5262, 'Sandhurst', 'Sandhurst', '', -38.0810000, 145.2076700, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5263, 'Langwarrin South', 'Langwarrin South', '', -38.1986800, 145.1806800, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5264, 'Rosebud West', 'Rosebud West', '', -38.3644400, 144.8774800, 'AU', '2015-01-27', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5265, 'Keilor Downs', 'Keilor Downs', '', -37.7233700, 144.8083900, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5266, 'Keilor Lodge', 'Keilor Lodge', '', -37.6999700, 144.8033200, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5267, 'Keilor Park', 'Keilor Park', '', -37.7202500, 144.8542200, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5268, 'Sunshine North', 'Sunshine North', '', -37.7698700, 144.8278700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5269, 'Sunshine West', 'Sunshine West', '', -37.7911700, 144.8163700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5270, 'Altona Meadows', 'Altona Meadows', '', -37.8841300, 144.7836700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5271, 'Williamstown North', 'Williamstown North', '', -37.8551500, 144.8825900, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5272, 'Kingsville', 'Kingsville', '', -37.8081900, 144.8791100, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5273, 'Seddon', 'Seddon', '', -37.8060700, 144.8907000, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5274, 'West Footscray', 'West Footscray', '', -37.7974600, 144.8772700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5275, 'Burnside Heights', 'Burnside Heights', '', -37.7269100, 144.7522500, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5276, 'Taylors Hill', 'Taylors Hill', '', -37.7098800, 144.7548300, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5277, 'Allambie Heights', 'Allambie Heights', '', -33.7665500, 151.2498100, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5278, 'Balmain East', 'Balmain East', '', -33.8571000, 151.1928200, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5279, 'Banksia', 'Banksia', '', -33.9460100, 151.1430400, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5280, 'Bardwell Valley', 'Bardwell Valley', '', -33.9334400, 151.1366800, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5281, 'Belfield', 'Belfield', '', -33.9035400, 151.0846700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5282, 'Berala', 'Berala', '', -33.8719700, 151.0338600, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5283, 'Berowra Heights', 'Berowra Heights', '', -33.6121100, 151.1375400, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5284, 'Beverly Park', 'Beverly Park', '', -33.9770700, 151.1343700, 'AU', '2015-01-28', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5285, 'Bexley North', 'Bexley North', '', -33.9384800, 151.1138500, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5286, 'Bilgola Beach', 'Bilgola Beach', '', -33.6448700, 151.3242700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5287, 'Blackett', 'Blackett', '', -33.7379200, 150.8181200, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5288, 'Bondi Beach', 'Bondi Beach', '', -33.8907900, 151.2785200, 'AU', '2016-12-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5289, 'Cabramatta West', 'Cabramatta West', '', -33.8966900, 150.9105600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5290, 'Cambridge Park', 'Cambridge Park', '', -33.7478400, 150.7220800, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5291, 'Camden South', 'Camden South', '', -34.0831200, 150.6949100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5292, 'Caringbah South', 'Caringbah South', '', -34.0566200, 151.1214900, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5293, 'Castle Cove', 'Castle Cove', '', -33.7865500, 151.2092500, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5294, 'Chatswood West', 'Chatswood West', '', -33.7940200, 151.1649200, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5295, 'Church Point', 'Church Point', '', -33.6451000, 151.2836700, 'AU', '2016-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5296, 'Carramar', 'Carramar', '', -33.8838200, 150.9615300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5297, 'Cecil Park', 'Cecil Park', '', -33.8743300, 150.8417700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5298, 'Clemton Park', 'Clemton Park', '', -33.9347600, 151.0904600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5299, 'Concord West', 'Concord West', '', -33.8480900, 151.0860900, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5300, 'Constitution Hill', 'Constitution Hill', '', -33.7925900, 150.9762700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5301, 'Cremorne Point', 'Cremorne Point', '', -33.8400800, 151.2269800, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5302, 'Darlington', 'Darlington', '', -33.8910300, 151.1954800, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5303, 'Denham Court', 'Denham Court', '', -33.9830700, 150.8460600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5304, 'Denistone', 'Denistone', '', -33.7983500, 151.0905100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5305, 'Dolls Point', 'Dolls Point', '', -33.9949800, 151.1455200, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5306, 'Dundas Valley', 'Dundas Valley', '', -33.7882600, 151.0526100, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5307, 'East Lindfield', 'East Lindfield', '', -33.7666400, 151.1868500, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5308, 'East Ryde', 'East Ryde', '', -33.8103100, 151.1315300, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5309, 'Emu Heights', 'Emu Heights', '', -33.7345300, 150.6487400, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5310, 'Ermington', 'Ermington', '', -33.8148300, 151.0546700, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5311, 'Fairfield East', 'Fairfield East', '', -33.8693800, 150.9712900, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5312, 'Fairfield Heights', 'Fairfield Heights', '', -33.8644500, 150.9388400, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5313, 'Fairlight', 'Fairlight', '', -33.7957500, 151.2734600, 'AU', '2015-01-29', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5314, 'Glen Alpine', 'Glen Alpine', '', -34.0860000, 150.7851200, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5315, 'Guildford West', 'Guildford West', '', -33.8524200, 150.9739500, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5316, 'Harris Park', 'Harris Park', '', -33.8228500, 151.0078100, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5317, 'Hassall Grove', 'Hassall Grove', '', -33.7334900, 150.8354200, 'AU', '2015-01-30', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5318, 'Hornsby Heights', 'Hornsby Heights', '', -33.6713000, 151.0942800, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5319, 'Horsley Park', 'Horsley Park', '', -33.8432200, 150.8488900, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5320, 'Ingleside', 'Ingleside', '', -33.6846200, 151.2635400, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5321, 'Killara', 'Killara', '', -33.7660400, 151.1621300, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5322, 'Killarney Heights', 'Killarney Heights', '', -33.7745100, 151.2202800, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5323, 'Kingswood Park', 'Kingswood Park', '', -33.7665100, 150.7144000, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5324, 'Kogarah Bay', 'Kogarah Bay', '', -33.9795100, 151.1211900, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5325, 'Kurraba Point', 'Kurraba Point', '', -33.8423500, 151.2225600, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5326, 'Koomooloo', 'Koomooloo', '', -33.5547000, 139.4680500, 'AU', '2015-01-31', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5327, 'Lane Cove West', 'Lane Cove West', '', -33.8161300, 151.1514500, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5328, 'Lewisham', 'Lewisham', '', -33.8971900, 151.1488300, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5329, 'Macquarie Park', 'Macquarie Park', '', -33.7750000, 151.1124800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5330, 'Marsfield', 'Marsfield', '', -33.7778400, 151.1057400, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5331, 'Miller', 'Miller', '', -33.9208900, 150.8846900, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5332, 'Narellan Vale', 'Narellan Vale', '', -34.0497400, 150.7439200, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5333, 'Narraweena', 'Narraweena', '', -33.7551900, 151.2765900, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5334, 'North Bondi', 'North Bondi', '', -33.8878700, 151.2807500, 'AU', '2016-12-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5335, 'North Curl Curl', 'North Curl Curl', '', -33.7643400, 151.2972700, 'AU', '2017-04-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5336, 'North Epping', 'North Epping', '', -33.7594400, 151.0924800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5337, 'North Manly', 'North Manly', '', -33.7756100, 151.2692100, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5338, 'North Wahroonga', 'North Wahroonga', '', -33.7053100, 151.1227800, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5339, 'Ramsgate Beach', 'Ramsgate Beach', '', -33.9852300, 151.1463400, 'AU', '2015-02-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5340, 'Roseville Chase', 'Roseville Chase', '', -33.7785200, 151.1967700, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5341, 'Scheyville', 'Scheyville', '', -33.6045000, 150.8831400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5342, 'South Coogee', 'South Coogee', '', -33.9310600, 151.2559900, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5343, 'South Turramurra', 'South Turramurra', '', -33.7494100, 151.1125700, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5344, 'South Windsor', 'South Windsor', '', -33.6180800, 150.8044300, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5345, 'Stanhope Gardens', 'Stanhope Gardens', '', -33.7220600, 150.9259700, 'AU', '2016-07-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5346, 'Strathfield South', 'Strathfield South', '', -33.8925200, 151.0833400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5347, 'Telopea', 'Telopea', '', -33.7927900, 151.0385800, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5348, 'Wareemba', 'Wareemba', '', -33.8581900, 151.1308500, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5349, 'Werrington County', 'Werrington County', '', -33.7465000, 150.7392900, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5350, 'Werrington Downs', 'Werrington Downs', '', -33.7420600, 150.7277900, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5351, 'West Pennant', 'West Pennant', '', -33.7457000, 151.0476400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5352, 'West Ryde', 'West Ryde', '', -33.8054300, 151.0738600, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5353, 'Wollstonecraft', 'Wollstonecraft', '', -33.8328000, 151.1898100, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5354, 'Woronora Heights', 'Woronora Heights', '', -34.0356200, 151.0273400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5355, 'Virginia', 'Virginia', '', -12.5189500, 131.0284400, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5356, 'Glenunga', 'Glenunga', '', -34.9501300, 138.6384100, 'AU', '2015-02-02', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5357, 'Hazelwood Park', 'Hazelwood Park', '', -34.9394700, 138.6587900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5358, 'Kensington Gardens', 'Kensington Gardens', '', -34.9258200, 138.6614500, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5359, 'Leabrook', 'Leabrook', '', -34.9297600, 138.6586200, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5360, 'Linden Park', 'Linden Park', '', -34.9472800, 138.6528700, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5361, 'Mount Osmond', 'Mount Osmond', '', -34.9629000, 138.6566400, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5362, 'Tusmore', 'Tusmore', '', -34.9389400, 138.6505900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5363, 'Wattle Park', 'Wattle Park', '', -34.9251600, 138.6750100, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5364, 'Hectorville', 'Hectorville', '', -34.8915700, 138.6589200, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5365, 'Albert Park', 'Albert Park', '', -34.8720100, 138.5196600, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5366, 'Allenby Gardens', 'Allenby Gardens', '', -34.8976600, 138.5542500, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5367, 'Henley Beach', 'Henley Beach', '', -34.9202900, 138.4944200, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5368, 'Royal Park', 'Royal Park', '', -34.8741500, 138.5118900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5369, 'West Lakes Shore', 'West Lakes Shore', '', -34.8601000, 138.4896600, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5370, 'Woodville North', 'Woodville North', '', -34.8720000, 138.5430900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5371, 'Woodville West', 'Woodville West', '', -34.8864000, 138.5309500, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5372, 'Glenelg East', 'Glenelg East', '', -34.9764000, 138.5296200, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5373, 'North Brighton', 'North Brighton', '', -35.0027900, 138.5221100, 'AU', '2016-03-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5374, 'Seacliff Park', 'Seacliff Park', '', -35.0298300, 138.5312900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5375, 'Clovelly Park', 'Clovelly Park', '', -34.9995100, 138.5708100, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5376, 'Plympton Park', 'Plympton Park', '', -34.9807100, 138.5491800, 'AU', '2016-03-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5377, 'South Plympton', 'South Plympton', '', -34.9768200, 138.5558800, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5378, 'Trott Park', 'Trott Park', '', -35.0757600, 138.5418900, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5379, 'Clarence Gardens', 'Clarence Gardens', '', -34.9753900, 138.5798300, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5380, 'Hawthorn', 'Hawthorn', '', -34.9738400, 138.6073800, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5381, 'Marden', 'Marden', '', -34.8956900, 138.6378000, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5382, 'Payneham', 'Payneham', '', -34.8972400, 138.6406400, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5383, 'Royston Park', 'Royston Park', '', -34.9004500, 138.6360500, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5384, 'Trinity Gardens', 'Trinity Gardens', '', -34.9143800, 138.6414100, 'AU', '2015-02-03', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5385, 'Noarlunga Downs', 'Noarlunga Downs', '', -35.1504000, 138.5039500, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5386, 'Alberton', 'Alberton', '', -34.8592500, 138.5213800, 'AU', '2015-02-04', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5387, 'Forestville', 'Forestville', '', -34.9494600, 138.5784500, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5388, 'Millswood', 'Millswood', '', -34.9550500, 138.5888800, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5389, 'Unley Park', 'Unley Park', '', -34.9638800, 138.6077600, 'AU', '2015-02-06', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5390, 'Acton', 'Acton', '', -35.2776700, 149.1182900, 'AU', '2016-03-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5391, 'Alfred Cove', 'Alfred Cove', '', -32.0331600, 115.8125900, 'AU', '2015-02-07', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5392, 'Bedford', 'Bedford', '', -31.9113200, 115.8892000, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5393, 'City Beach', 'City Beach', '', -31.9344000, 115.7617400, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5394, 'Coolbinia', 'Coolbinia', '', -31.9147000, 115.8489400, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5395, 'Crawley', 'Crawley', '', -31.9841800, 115.8160300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5396, 'Daglish', 'Daglish', '', -31.9482800, 115.8189900, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5397, 'East Cannington', 'East Cannington', '', -32.0098000, 115.9550300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5398, 'Eden Hill', 'Eden Hill', '', -31.8890800, 115.9467500, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5399, 'Embleton', 'Embleton', '', -31.9035500, 115.9090200, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5400, 'Ferndale', 'Ferndale', '', -32.0349400, 115.9223300, 'AU', '2015-02-08', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5401, 'Harrisdale', 'Harrisdale', '', -32.1108400, 115.9356300, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5402, 'Henley Brook', 'Henley Brook', '', -31.8139300, 115.9880700, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5403, 'Hilton', 'Hilton', '', -32.0620800, 115.7804900, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5404, 'Jindalee', 'Jindalee', '', -31.6493800, 115.6949600, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5405, 'Joondanna', 'Joondanna', '', -31.9076700, 115.8423300, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5406, 'Kallaroo', 'Kallaroo', '', -31.7909800, 115.7529800, 'AU', '2015-02-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5407, 'Mount Pleasant', 'Mount Pleasant', '', -32.0397400, 115.8499300, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5408, 'Myaree', 'Myaree', '', -32.0400000, 115.8176100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5409, 'Oakford', 'Oakford', '', -32.2009400, 115.9339100, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5410, 'Parmelia', 'Parmelia', '', -32.2578400, 115.8220800, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5411, 'Rivervale', 'Rivervale', '', -31.9554600, 115.9130600, 'AU', '2015-02-10', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5412, 'South Fremantle', 'South Fremantle', '', -32.0690700, 115.7545300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5413, 'South Guildford', 'South Guildford', '', -31.9122000, 115.9682500, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5414, 'South Lake', 'South Lake', '', -32.1112500, 115.8387300, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5415, 'Watermans Bay', 'Watermans Bay', '', -31.8491500, 115.7559000, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5416, 'Wembley Downs', 'Wembley Downs', '', -31.9116900, 115.7735800, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5417, 'West Leederville', 'West Leederville', '', -31.9414100, 115.8311700, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5418, 'Woodbridge', 'Woodbridge', '', -31.8869500, 115.9919600, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5419, 'Acton Park', 'Acton Park', '', -42.8793200, 147.4845900, 'AU', '2015-02-11', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5420, 'West Moonah', 'West Moonah', '', -42.8499600, 147.2818100, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5421, 'Dynnyrne', 'Dynnyrne', '', -42.9054100, 147.3157600, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5422, 'Burleigh Waters', 'Burleigh Waters', '', -28.0997500, 153.4246300, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5423, 'Clear Island Waters', 'Clear Island Waters', '', -28.0530800, 153.3981500, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5424, 'Lower Beechmont', 'Lower Beechmont', '', -28.0475100, 153.2457200, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5425, 'Mount Nathan', 'Mount Nathan', '', -27.9643000, 153.2719800, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5426, 'Ormeau Hills', 'Ormeau Hills', '', -27.7965300, 153.2567000, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5427, 'Tallebudgera Valley', 'Tallebudgera Valley', '', -28.1927000, 153.3548900, 'AU', '2015-02-12', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5428, 'Lakelands', 'Lakelands', '', -32.4775400, 115.7557300, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5429, 'South Yunderup', 'South Yunderup', '', -32.5851000, 115.7801500, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5430, 'Arcadia vale', 'Arcadia vale', '', -33.0605200, 151.5840800, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5431, 'Buff Point', 'Buff Point', '', -33.2228500, 151.5312500, 'AU', '2015-02-14', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5432, 'Charmhaven', 'Charmhaven', '', -33.2267100, 151.5028400, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5433, 'Chittaway Bay', 'Chittaway Bay', '', -33.3276900, 151.4297100, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5434, 'Kingfisher Shores', 'Kingfisher Shores', '', -33.1683400, 151.5530500, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5435, 'Little Jilliby', 'Little Jilliby', '', -33.2406600, 151.3700600, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5436, 'Noraville', 'Noraville', '', -33.2678500, 151.5535200, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5437, 'Tuggerawong', 'Tuggerawong', '', -33.2804000, 151.4804400, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5438, 'Bar Beach', 'Bar Beach', '', -32.9412800, 151.7654400, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5439, 'Broadmeadow', 'Broadmeadow', '', -32.9237100, 151.7284900, 'AU', '2015-02-15', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5440, 'Carrington', 'Carrington', '', -32.9150100, 151.7643600, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5441, 'Cooks Hill', 'Cooks Hill', '', -32.9324400, 151.7711400, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5442, 'Elermore Vale', 'Elermore Vale', '', -32.9162100, 151.6766500, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5443, 'Hamilton', 'Hamilton', '', -32.9220700, 151.7471100, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5444, 'The Junction', 'The Junction', '', -32.9382200, 151.7590900, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5445, 'Mayfield', 'Mayfield', '', -32.8979300, 151.7361300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5446, 'Mayfield West', 'Mayfield West', '', -32.8919500, 151.7271100, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5447, 'Merewether Heights', 'Merewether Heights', '', -32.9473300, 151.7356500, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5448, 'New Lambton Heights', 'New Lambton Heights', '', -32.9246600, 151.6936400, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5449, 'North Lambton', 'North Lambton', '', -32.9060500, 151.7057400, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5450, 'Rankin Park', 'Rankin Park', '', -32.9251600, 151.6801600, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5451, 'Waratah', 'Waratah', '', -32.9066700, 151.7264700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5452, 'Belmont North', 'Belmont North', '', -33.0208100, 151.6684900, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5453, 'Belmont South', 'Belmont South', '', -33.0493400, 151.6569500, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5454, 'Bolton Point', 'Bolton Point', '', -33.0017700, 151.6101300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5455, 'Cardiff Heights', 'Cardiff Heights', '', -32.9362600, 151.6722700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5456, 'Cardiff South', 'Cardiff South', '', -32.9547000, 151.6644600, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5457, 'Coal Point', 'Coal Point', '', -33.0422500, 151.6115900, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5458, 'Fennell Bay', 'Fennell Bay', '', -32.9922000, 151.6000800, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5459, 'Floraville', 'Floraville', '', -33.0111600, 151.6648000, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5460, 'Garden Suburb', 'Garden Suburb', '', -32.9436800, 151.6808500, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5461, 'Gateshead', 'Gateshead', '', -32.9820800, 151.6918800, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5462, 'Glendale', 'Glendale', '', -32.9319400, 151.6410300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5463, 'Highfields', 'Highfields', '', -32.9533100, 151.7123100, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5464, 'Jewells', 'Jewells', '', -33.0138600, 151.6830800, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5465, 'Tingira Heights', 'Tingira Heights', '', -32.9972500, 151.6702100, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5466, 'Windale', 'Windale', '', -32.9927700, 151.6816700, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5467, 'Toronto', 'Toronto', '', -33.0135700, 151.5937300, 'AU', '2015-02-16', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5468, 'Bolwarra Heights', 'Bolwarra Heights', '', -32.7010000, 151.5854100, 'AU', '2015-02-17', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5469, 'West Rockhampton', 'West Rockhampton', '', -23.3794100, 150.4817500, 'AU', '2015-04-19', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5470, 'Black Mountain', 'Black Mountain', '', -26.3988600, 152.8756100, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5471, 'Caloundra West', 'Caloundra West', '', -26.7985400, 153.1140500, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5472, 'Dicky Beach', 'Dicky Beach', '', -26.7836400, 153.1376600, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5473, 'Peregian Springs', 'Peregian Springs', '', -26.4880100, 153.0757700, 'AU', '2015-02-18', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5474, 'Albion Park Rail', 'Albion Park Rail', '', -34.5663400, 150.7917700, 'AU', '2017-04-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5475, 'Barrack Heights', 'Barrack Heights', '', -34.5646400, 150.8569200, 'AU', '2017-04-01', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5476, 'Calderwood', 'Calderwood', '', -34.5505000, 150.7113100, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5477, 'Cordeaux Heights', 'Cordeaux Heights', '', -34.4404300, 150.8374800, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5478, 'Croom', 'Croom', '', -34.5943200, 150.8412600, 'AU', '2015-02-20', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5479, 'East Corrimal', 'East Corrimal', '', -34.3760600, 150.9107800, 'AU', '2016-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5480, 'Koonawarra', 'Koonawarra', '', -34.5021200, 150.8085500, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5481, 'West Wollongong', 'West Wollongong', '', -34.4248000, 150.8641700, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5482, 'Lake Wendouree', 'Lake Wendouree', '', -37.5499300, 143.8473000, 'AU', '2015-02-21', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5483, 'White Hills', 'White Hills', '', -36.7287500, 144.3052500, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5484, 'Nulsen', 'Nulsen', '', -33.8569600, 121.8749900, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5485, 'Breakwater', 'Breakwater', '', -38.1798700, 144.3676500, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5486, 'Hamlyn Heights', 'Hamlyn Heights', '', -38.1210800, 144.3279900, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5487, 'Wandana Heights', 'Wandana Heights', '', -38.1757700, 144.3038700, 'AU', '2015-02-22', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5488, 'Monkland', 'Monkland', '', -26.2119100, 152.6824500, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5489, 'East Launceston', 'East Launceston', '', -41.4384300, 147.1510100, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5490, 'Summerhill', 'Summerhill', '', -41.4674700, 147.1279600, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5491, 'West Launceston', 'West Launceston', '', -41.4509200, 147.1311400, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5492, 'Bilambil Heights', 'Bilambil Heights', '', -28.2161000, 153.4841500, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5493, 'Tweed Heads West', 'Tweed Heads West', '', -28.1873600, 153.5227800, 'AU', '2015-02-23', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5494, 'Rangeville', 'Rangeville', '', -27.5831800, 151.9799700, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5495, 'Darling Heights', 'Darling Heights', '', -27.5965900, 151.9304500, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5496, 'East Toowoomba', 'East Toowoomba', '', -27.5708600, 151.9742200, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5497, 'Top Camp', 'Top Camp', '', -27.6358400, 151.9392000, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5498, 'Wilsonton Heights', 'Wilsonton Heights', '', -27.5322700, 151.9244400, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5499, 'East Tamworth', 'East Tamworth', '', -31.0854800, 150.9372100, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5500, 'South Tamworth', 'South Tamworth', '', -31.1100000, 150.9225400, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5501, 'Tinbeerwah', 'Tinbeerwah', '', -26.4044300, 152.9825600, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5502, 'Cooroibah', 'Cooroibah', '', -26.3631600, 152.9859900, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5503, 'East Albury', 'East Albury', '', -36.0814400, 146.9299100, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5504, 'North Albury', 'North Albury', '', -36.0574500, 146.9299500, 'AU', '2015-02-24', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5505, 'South Albury', 'South Albury', '', -36.0865400, 146.9090500, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5506, 'West Albury', 'West Albury', '', -36.0797900, 146.8922700, 'AU', '2015-02-25', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5507, 'Sunshine Coast', 'Sunshine Coast', 'MCY,Sunshine Coast', -26.6568200, 153.0795500, 'AU', '2015-09-05', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5508, 'Marangaroo', 'Marangaroo', '', -31.8271100, 115.8384300, 'AU', '2016-03-09', 14);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5526, 'Sharur City', 'Sharur City', 'Il''ichevsk,Ilich,Il’ichëvsk,Norashen,Sarur,Sharur City,Şərur', 39.5529800, 44.9799300, 'AZ', '2016-03-25', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5527, 'Prishibinskoye', 'Prishibinskoye', 'Geytepe,Goytapa,Göytəpə,Prishib,Prishibinske,Prishibinskoe,Prishibinskoye,Prisib,Prişib', 39.1181700, 48.5925500, 'AZ', '2013-01-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5528, 'Zangilan', 'Zangilan', 'Icari,Ikari,Kovsakan,Zangelan,Zangilak,Zangilan,Zəngilan,İçəri,Կովսական', 39.0884000, 46.6513000, 'AZ', '2013-12-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5529, 'Yaycı', 'Yayci', 'Yaji-ye Azarbayjan,Yayci,Yaycı,Yaydzhi,Yaydzhy,Yājī-ye Āz̄arbāyjān,yajy adhrbayjan,یاجی آذربایجان', 38.9405200, 45.7324400, 'AZ', '2016-04-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5530, 'Yardımlı', 'Yardimli', 'Iardymly,Jardymly,Yardimli,Yardymly,Yardımlı,Ярдымлы', 38.9077100, 48.2405200, 'AZ', '2012-12-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5531, 'Novyy Karanlug', 'Novyy Karanlug', 'Martouni,Martuni,Novyy Karanlug,Xocavand,Xocavənd,Մարտունի', 39.7954600, 47.1098900, 'AZ', '2013-10-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5532, 'Xankandi', 'Xankandi', 'Chankaendi,Chankändi,Hankendi,Khankendy,Stepanakert,Xankǝndi,Xankəndi,astpanakrt,stpnqrt,Степанакерт,סטפנקרט,استپاناکرت', 39.8177000, 46.7528000, 'AZ', '2016-08-24', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5533, 'Əhmədbəyli', 'Ahmadbayli', 'Ahmadbayli,Tel''mankend,Telmankand,Telmankənd,Tel’mankend,Əhmədbəyli', 39.8786700, 48.3990100, 'AZ', '2013-04-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5534, 'Shushi', 'Shushi', 'Shoushi,Shusha,Shushe,Shushi,Susa,Suse,Susi,Szusza,shwshy,swsh,Şuşa,Шуша,Շուշե,Շուշի,שושה,شوشی', 39.7600600, 46.7498900, 'AZ', '2015-09-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5535, 'Salyan', 'Salyan', 'Sal''jan,Sal''yany,Salian,Salyan,Sal’yany,Ssaljany,Сальян', 39.5962100, 48.9847900, 'AZ', '2013-04-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5536, 'Şahbuz', 'Sahbuz', 'Chay-Shakhbuz,Sahbuz,Shahbuz,Shakhbuz,Şahbuz,Шахбуз', 39.4072200, 45.5738900, 'AZ', '2016-04-14', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5537, 'Sedarak', 'Sedarak', 'Sadarak,Sedarak,Sederek,Sədərək', 39.7142700, 44.8845500, 'AZ', '2016-04-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5538, 'Sumbatan-diza', 'Sumbatan-diza', 'Sabirkand,Sabirkend,Sabirkənd,Sumbatan-diza', 38.9480400, 45.8257200, 'AZ', '2016-04-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5539, 'Saatlı', 'Saatli', 'Saatli,Saatly,Saatlı,Saotly,Саатлы', 39.9321400, 48.3689200, 'AZ', '2013-08-02', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5540, 'Qubadlı', 'Qubadli', 'Ghubat''ly,Ghubat’ly,Koubatly,Kubadli,Kubadlı,Kubatlu,Kubatly,Qubadli,Qubadly,Qubadlı,Sanasar,ku ba te lei,qbadly,qwbadly,Кубадли,Кубатлы,Ղուբաթլը,Սանասար,Քաշունիք,قبادلی,قوبادلی,庫巴特雷', 39.3444100, 46.5818300, 'AZ', '2013-10-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5541, 'Qaraçala', 'Qaracala', 'Karachala,Karachalinskaya,Qaracala,Qaraçala', 39.8161400, 48.9379200, 'AZ', '2013-04-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5542, 'Orconikidze', 'Orconikidze', 'Orconikidze,Ordzhonikidze', 39.6323800, 47.6898000, 'AZ', '2013-04-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5543, 'Ordubad', 'Ordubad', 'Ordoubad,Ordoubat,Orduar,Ordubad,Ordubadas,Ordubat,ao er du ba de,ardwbad,awrdwbad,Ордубад,Որդուար,اردوباد,اوردوباد,奧爾杜巴德', 38.9096100, 46.0227400, 'AZ', '2016-04-14', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5544, 'Neftçala', 'Neftcala', 'Neftcala,Neftechala,Neftçala,Nephte Chala,Poselok Tresta,Нефтечала', 39.3768000, 49.2470000, 'AZ', '2013-04-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5545, 'Nakhchivan', 'Nakhchivan', 'NAJ,Nachitschewan,Nakhchivan,Nakhchyvan,Nakhicevan,Nakhichevan'',Nakhichevan’,Nakhichivan,Nakhitchevan,Nakhitsjevan,Nakhjavan,Naxcivan,Naxçıvan,nkhchywan,Нахичевань,نخچیوان', 39.2088900, 45.4122200, 'AZ', '2017-04-01', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5546, 'Mincivan', 'Mincivan', 'Mijnavan,Mincivan,Mindshewan,Mindzhevan'',Mindzhevan’,Mindzhivan,Миндживан,Միջնավան', 39.0305800, 46.7214000, 'AZ', '2016-06-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5547, 'Masally', 'Masally', 'Masali,Masalli,Masally,Masallı,Masalı,Massaly', 39.0353200, 48.6654000, 'AZ', '2013-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5548, 'Lerik', 'Lerik', 'Lerik', 38.7738800, 48.4149700, 'AZ', '2012-12-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5549, 'Lankaran', 'Lankaran', 'LLK,Lankaran,Lencoran,Lenkoran,Lenkoran'',Ljankjaran,Länkäran,Lǝnkǝran,Lənkəran,Ленкорань,Лянкяран', 38.7542800, 48.8506200, 'AZ', '2017-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5550, 'Laçın', 'Lacin', 'Abdallyar,Abdalyar,Berdzor,Berjor,Datschin,Lachin,Lachyan,Lachyn,Lacin,Lačin,Lichin,lachn,lachyn,Бердзор,Лачин,Բերձոր,لاچن,لاچین', 39.5988100, 46.5504500, 'AZ', '2013-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5551, 'Qıvraq', 'Qivraq', 'Kivrag,Kivrakh,Kyvrak,Kyvrakh,Qivraq,Qıvraq', 39.3993900, 45.1151300, 'AZ', '2016-11-23', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5552, 'Qırmızı Bazar', 'Qirmizi Bazar', 'Karmir Shouka,Karmir Shuka,Karmir Suka,Krasnyj Bazar,Krasnyy Bazar,Qirmizi Bazar,Qırmızı Bazar,Красный Базар,Կարմիր Շուկա', 39.6783300, 46.9488400, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5553, 'Kizhaba', 'Kizhaba', 'Kijaba,Kijoba,Kijäba,Kijəba,Kijəbə,Kizhaba', 38.5346100, 48.8054600, 'AZ', '2014-05-29', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5554, 'Xocalı', 'Xocali', 'Ay-Khodzhaly,Daerah Khojali,Distrito ng Khojali,Hocali Rayonu,Hocalı Rayonu,Hogali,Ivanyan,Khodgalou,Khodjaly,Khodzali,Khodzalinski rejon,Khodzhalinskaja,Khodzhalinskaya,Khodzhalinskij rajon,Khodzhalv,Khodzhaly,Khojali,Khojali Rayon,Khojaly,Khojaly District,Khozhali,Khozhalinskaya,Rayon Khojali,Rejon Xocali,Rejon Xocalı,Xocali,Xocali rayonu,Xocalin piirikunta,Xocalı,Xocalı rayonu,Xocalın piirikunta,hojalleu gu,huo gu lei qu,shhrstan khwjaly,Ĥoĝali,Ходжалин кӀошт,Ходжалинская,Ходжалинский район,Ходжалы,Хоџали,Хоџалински рејон,Իվանյան,Խոջալը,חוגאלי,شهرستان خوجالی,ضلع خوجالی,霍賈雷區,호잘르 구', 39.9129700, 46.7902800, 'AZ', '2013-12-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5555, 'Xıllı', 'Xilli', 'Khilly,Xilli,Xıllı,Yukhary-Khylly', 39.4301200, 49.1016600, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5556, 'Imishli', 'Imishli', 'Emishti,Imishli,Imishly,Imisli,İmişli,Имишли', 39.8709500, 48.0599500, 'AZ', '2013-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5557, 'Horadiz', 'Horadiz', 'Geradiz,Goradiz,Gorodiz,Horadiz,Горадиз', 39.4487700, 47.3353100, 'AZ', '2016-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5558, 'Haftoni', 'Haftoni', 'Gaftoni,Haftoni,Havtoni,Гафтони', 38.7632500, 48.7622300, 'AZ', '2013-03-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5559, 'Hadrut', 'Hadrut', 'Gadrut,Hadroet,Hadrout,Hadrowt,Hadrut,Hadrut'',Hadrut’,hadrwt,Гадрут,Հադրութ,هادروت,ہادروت', 39.5200200, 47.0318000, 'AZ', '2013-10-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5560, 'Fizuli', 'Fizuli', 'Fizuli,Fuzuli,Füzuli,Karjagino,Karyagino,Sardar,Физули,Ֆիզուլի', 39.6009400, 47.1452900, 'AZ', '2013-08-02', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5561, 'Jebrail', 'Jebrail', 'Cabrayil,Cəbrayıl,Djebrail,Dzhebrail,Jabrail,Jabrayyl,Jebraiele,Jebrail,Jebrayil,Jrakan,Jäbrayyl,Mekhakavan,Mexakavan,Ձրական,Մեխակավան,Ջաբրաիլ', 39.3991700, 47.0283500, 'AZ', '2013-12-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5562, 'Dünyamalılar', 'Dunyamalilar', 'Dun''yamalylar,Dunyamalilar,Dunyamallar,Dun’yamalylar,Dünyamallar,Dünyamalılar', 39.7727800, 47.7588900, 'AZ', '2013-05-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5563, 'Deste', 'Deste', 'Dasta,Deste,Dəstə', 38.8837500, 45.9096300, 'AZ', '2013-05-31', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5564, 'Culfa', 'Culfa', 'Culfa,Dzhul''fa,Dzhul’fa,Jolfa,Jolfa-ye Nakhjavan,Jolfā,Jolfā-ye Nakhjavān,Julfa,jlfay nkhjwan,Джульфа,جلفای نخجوان', 38.9539700, 45.6296100, 'AZ', '2016-04-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5565, 'Dzhalilabad', 'Dzhalilabad', 'Astrahanka,Astrakhan-Bazar,Astrakhanka,Astrakhanovka,Calilabad,Cəlilabad,Dzhalil''abad,Dzhalilabad,Jalilabad,Jälilabad,Джалильабад', 39.2096300, 48.4918600, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5566, 'Cahri', 'Cahri', 'Cahri,Cəhri,Dzhagri,Dzhagry,Dzhakhri,Jahri', 39.3483700, 45.4155700, 'AZ', '2016-06-22', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5567, 'Boradigah', 'Boradigah', 'Baradigyakh,Boradigah,Boradigyakh,Boradygia,Boradygiya,Boradygyakh,Vardygya', 38.9301300, 48.7092000, 'AZ', '2013-03-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5568, 'Pushkino', 'Pushkino', 'Bilasuvar,Biləsuvar,Pushkin,Pushkino,Puskin,Puşkin', 39.4583300, 48.5450000, 'AZ', '2013-01-10', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5569, 'Beylagan', 'Beylagan', 'Beylagan,Beylaqan,Beyləqan,Jdanov,Zhdanov,Zhdanovsk', 39.7755600, 47.6186100, 'AZ', '2014-09-16', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5570, 'Severo-Vostotchnyi Bank', 'Severo-Vostotchnyi Bank', 'Bank,Banka,Bankov,Bankə,Imeni Kirova,Rybokombinat Imeni Kirova,Severo-Vostochnyy Bank,Severo-Vostotchnyi Bank', 39.4111700, 49.2479200, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5571, 'Tazakend', 'Tazakend', 'Babak,Babek,Babekskiy,Babək,Tazakand,Tazakend,Təzəkənd', 39.1545900, 45.4428200, 'AZ', '2016-06-22', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5572, 'Astara', 'Astara', 'Astara,Azerbaydzhanskaya Astara,a si ta la,aseutala,astara,Астара,Աստարա,آستارا,ასტარა,阿斯塔拉,아스타라', 38.4559800, 48.8749800, 'AZ', '2012-08-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5573, 'Askyaran', 'Askyaran', 'Asgaran,Askeran,Askyaran,Berdayagi,Berdaygi,Əsgəran,Аскеран,Ասկերան,Բերդայգի', 39.9366700, 46.8327800, 'AZ', '2016-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5574, 'Şirvan', 'Sirvan', 'Ali Bairamly,Ali Bayramli,Ali-Bairamli,Ali-Bajramly,Ali-Bayramli,Ali-Bayramly,Aly-Bayramly,Arab Shakhverdi,Arab-Shakhberdy,Arab-Shakhverdy,Shirvan,Sirvan,Zubovka,Şirvan,Əli Bayramlı,Али-Байрамлы,Ширван', 39.9377800, 48.9290000, 'AZ', '2014-03-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5575, 'Ağdam', 'Agdam', 'Ag''dam,Agdam,Agdamas,Aghdam,Agʻdam,Akn,Akna,Ankntam,Ağdam,a ge da mu,ageudam,aghdam,aghdami,aq dam,Άγκνταμ,Агдам,Ակն,Ակնա,Աղդամ,آغدام,آق دام,აღდამი,阿格達姆,아그담', 39.9909600, 46.9273600, 'AZ', '2013-10-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5576, 'Sovetabad', 'Sovetabad', 'Gasanabad,Hasanabad,Həsənabad,Iyirmi Alti Baki Komissari,Sovetabad,İyirmi Altı Bakı Komissarı,Гасанабад', 39.3366700, 49.2141400, 'AZ', '2017-07-13', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5577, 'Avşar', 'Avsar', 'Avsar,Avşar,Uzeirkend,Uzejirkand,Uzeyirkand,Üzejirkənd,Üzeyirkənd', 39.9738900, 47.4238900, 'AZ', '2013-05-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5578, 'Birinci Aşıqlı', 'Birinci Asiqli', 'Ashykhly Pervoye,Birinci Asiqli,Birinci Aşıqlı', 39.8191700, 47.6794400, 'AZ', '2013-05-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5579, 'Yuxarı Aran', 'Yuxari Aran', 'Yuxari Aran,Yuxarı Aran', 39.7336100, 47.6550000, 'AZ', '2013-05-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5580, 'Çalxanqala', 'Calxanqala', 'Calxanqala,Çalxanqala', 39.4416700, 45.2833300, 'AZ', '2016-06-22', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5581, 'Oğlanqala', 'Oglanqala', 'Oglanqala,Oğlanqala', 39.5869400, 45.0461100, 'AZ', '2016-06-22', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5582, 'Zyrya', 'Zyrya', 'Zira,Zirja,Zirya,Zirǝ,Zirə,Zyrya,Зиря', 40.3661300, 50.2919800, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5583, 'Zardob', 'Zardob', 'Zardab,Zardob,Zǝrdab,Zərdab,Зардаб,Зардоб', 40.2199100, 47.7099700, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5584, 'Zaqatala', 'Zaqatala', 'Sakataly,ZTU,Zagatala,Zakatali,Zakatalsk,Zakataly,Zaqatala,Загатала,Закаталы', 41.6316000, 46.6447900, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5585, 'Zabrat', 'Zabrat', 'Sabrat,Zabrat,Забрат', 40.4774600, 49.9417400, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5586, 'Yevlakh', 'Yevlakh', 'Avlakh,Evlakh,Jewlach,YLV,Yevlakh,Yevlax,Евлах', 40.6183200, 47.1501400, 'AZ', '2013-10-22', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5587, 'Yanıqlı', 'Yaniqli', 'Vezirly,Yaniqli,Yanykhly,Yanıqlı', 40.8411500, 45.6728300, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5588, 'Xudat', 'Xudat', 'Khudaf,Khudat,Xudat,Худат', 41.6305200, 48.6816100, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5589, 'Yelenendorf', 'Yelenendorf', 'Elenendorf,Gjojgjol'',Goygol,Göygöl,Helenendorf,Khanlar,Kol-Yelendorf,Xanlar,Yelenendorf,Гёйгёль,Ханлар', 40.5858400, 46.3189000, 'AZ', '2013-12-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5590, 'Xaçmaz', 'Xacmaz', 'Chatschmas,Gorad Khachmaz,Hacimaz,Hacmaz,Haçmaz,Kegna Khachmas,Kekhna-Khachmaz,Khachmas,Khachmaz,Khuachmaz,Këgna Khachmas,Xacmaz,Xaçmaz,ha qi ma si,khachmaz,khashmaz,Горад Хачмаз,Хачмаз,Хачмас,Хъачмаз,Խաչմազ,خاشماز,خاچماز,哈奇馬斯', 41.4642600, 48.8056500, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5591, 'Verkhniy Dashkesan', 'Verkhniy Dashkesan', 'Verin-Karagat,Verkh.Dashkesan,Verkhniy Dashkesan,Yuxari Daskasan,Yuxarı Daşkǝsǝn,Yuxarı Daşkəsən,Верх.Дашкесан', 40.4935700, 46.0717500, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5592, 'Ujar', 'Ujar', 'Ucar,Udshary,Udzhar,Udzhara,Udzhary,Ujar,Уджары', 40.5190200, 47.6542300, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5593, 'Türkan', 'Turkan', 'Tjurkjan,Tuerkan,Turkan,Turkyany,Tyurkend,Tyurkyan,Tyurkyany,Türkan,Тюркян', 40.3646000, 50.2207500, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5594, 'Tovuz', 'Tovuz', 'Tauz,Tavus,Tovuz,Тауз', 40.9924900, 45.6283800, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5595, 'Terter', 'Terter', 'Mir Bashir,Mir Basir,Mirbashir,Mirbasir,Mirbäshir,Mirbəşir,T''art''arr,Tartar,Terter,Tǝrtǝr,Tərtər,Tʻartʻar,T’art’arr,Тертер,Թարթառ,Միր Բաշիր', 40.3417900, 46.9324200, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5596, 'Sumqayıt', 'Sumqayit', 'Sumgait,Sumgjajet,Sumqayit,Sumqayyt,Sumqayıt,Сумгаит,סומגאיט', 40.5897200, 49.6686100, 'AZ', '2012-08-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5597, 'Kyzyl-Burun', 'Kyzyl-Burun', 'Kisil-burun,Kyzyl-Burun,Siazan'',Siazan’,Siyazan,Siyǝzǝn,Siyəzən,Сиазань', 41.0775400, 49.1125700, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5598, 'Şuraabad', 'Suraabad', 'Mikhailabad,Shuraabad,Sovetabad,Soviet Abad,Suraabad,Şuraabad,Шураабад', 40.8194300, 49.4678700, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5599, 'Qaraçuxur', 'Qaracuxur', 'Garachukhur,Imeni Kaganovicha,Kaganovich,Kaganovicha,Karachekhur,Karachukhur,Poselok Imeni Kaganovicha,Posëlok Imeni Kaganovicha,Qaracuxur,Qaraçuxur,Serebovski,Serebrovskiy,Гарачухур', 40.3966700, 49.9736100, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5600, 'Saray', 'Saray', 'Sarai,Saraj,Saray,Сарай', 40.5329900, 49.7168100, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5601, 'Samur', 'Samur', 'Samur,Самур', 41.6367100, 48.4302800, 'AZ', '2013-10-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5602, 'Shamkhor', 'Shamkhor', 'Anino,Annenfel''d,Annenfel’d,Annino,Samkir,Samxor,Shamkhor,Shamkir,Şamxor,Şǝmkir,Şəmkir,Шамки́р,Шамкир', 40.8297500, 46.0178000, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5603, 'Shamakhi', 'Shamakhi', 'Samaxi,Schemacha,Shamakhy,Shemakha,Şamaxı,Шемаха', 40.6314100, 48.6413700, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5604, 'Saloğlu', 'Saloglu', 'Kukheti,Kukhety,Saloghly,Saloglu,Salogly,Saloğlu', 41.2752400, 45.3529300, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5605, 'Sheki', 'Sheki', 'Nucha,Nukha,Nuxa,Saki,Shaki,Sheki,Shäki,Şǝki,Şəki,Шеки', 41.1919400, 47.1705600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5606, 'Samux', 'Samux', 'Nabiagali,Nǝbiağalı,Nəbiağalı,Sabarkend,Sabir,Sabira,Safarabad,Safaraliev,Safaraliyav,Safaraliyeb,Safaraliyev,Samux,Səfərəliyəv,Сафаралиев', 40.7648500, 46.4086800, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5607, 'Sabunçu', 'Sabuncu', 'Sabunchi,Sabunchy,Sabuncu,Sabunçu,Сабунчи', 40.4425000, 49.9480600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5608, 'Sabirabad', 'Sabirabad', 'Petropavlovka,Petropavlovskoye,Sabirabad,Sabirabadas,Ssabirabad,sa bi la ba de,sbyr abad,Сабирабад,Սաբիրաբադ,سبیر آباد,薩比拉巴德', 40.0086900, 48.4770100, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5609, 'Qusar', 'Qusar', 'Kusary,Qusar,Кусары', 41.4275000, 48.4302000, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5610, 'Quba', 'Quba', 'Guba,Kuba,Kuuba,Kuuval,Kuwa,Quba,ku ba,mdynt qwba,qwba,qwbh,Губа,Куба,Къуба,Къувал,Ґуба,Կուբա,קובה,قوبا,مدينة قوبا,庫巴', 41.3610800, 48.5134100, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5611, 'Qobustan', 'Qobustan', 'Duvannaya,Duvanni,Duvanny,Duvannyy,Duvannı,Duyannaya,Gobustan,Qobustan,Гобустан', 40.0823800, 49.4120500, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5612, 'Hacıqabul', 'Haciqabul', 'Adshikabul,Adzha-Kabul,Adzhikabul,Aja Kabul,Haciqabul,Hacıqabul,Kasi-Mahomed,Kazi Mahomed,Kazi-Magomed,Kazi-Magomet,Qazimammad,Qazımǝmmǝd,Qazıməmməd,Кази-Магомед', 40.0387400, 48.9428600, 'AZ', '2013-07-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5613, 'Qazax', 'Qazax', 'Agkeynak,Agkëynak,Gazakh,Kasach,Kasachisee,Kazachas,Kazah,Kazakh,Qazakh,Qazax,ha sa ke,qazakh,Газах,Казах,Կողթ,قازاخ,哈薩克', 41.0924600, 45.3656100, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5614, 'Qax', 'Qax', 'Kakhi,Qakh,Qax,Кахи', 41.4182600, 46.9204300, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5615, 'Qasım İsmayılov', 'Qasim Ismayilov', 'Alabashly,Kasum-Ismailov,Kasum-Izmaylov,Kasym-Ismailov,Qasim Ismayilov,Qasım İsmayılov', 40.8115600, 46.2611200, 'AZ', '2013-11-08', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5616, 'Qutqashen', 'Qutqashen', 'Gabala,Kutkashen,Kutkashin,Qabala,Qutqashen,Qəbələ,Габала', 40.9824700, 47.8490900, 'AZ', '2014-04-06', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5617, 'Puta', 'Puta', 'Puta,Staraya Puta,Пута', 40.2966700, 49.6602800, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5618, 'Oğuz', 'Oguz', 'Bartashen,Oguz,Oğuz,Vartasen,Vartashen,Vartashin,Vartaşen,Огуз', 41.0712800, 47.4652800, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5619, 'Novosaratovka', 'Novosaratovka', 'Novaya Saratovka,Novosaratovka', 40.5981100, 45.6007900, 'AZ', '2013-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5620, 'Hacı Zeynalabdin', 'Haci Zeynalabdin', 'Haci Zeynalabdin,Hacı Zeynalabdin,Nasoslu,Nasosnaya,Nasosnyy,Nassosny', 40.6233300, 49.5586100, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5621, 'Nardaran', 'Nardaran', 'Nardaran', 40.5561100, 50.0055600, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5622, 'Naftalan', 'Naftalan', 'Naftalan,Нафталан', 40.5082100, 46.8203000, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5623, 'Mingelchaur', 'Mingelchaur', 'Mengechaur,Min''nkatsebir,Mingacevir,Mingachevir,Mingaecevir,Mingechaur,Mingechaurges,Mingeczaur,Mingelchaur,Mingächevir,Mingäçevir,Mingǝçevir,Mingəçevir,ming gai qia wu er,Μινγκατσεβίρ,Мингечаур,明盖恰乌尔', 40.7639500, 47.0595300, 'AZ', '2014-03-15', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5624, 'Maştağa', 'Mastaga', 'Mashtaga,Mashtaghy,Mashtagi,Mastaga,Maştağa,Маштага', 40.5298300, 50.0061600, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5625, 'Mardakan', 'Mardakan', 'Mardakan,Mardakjan,Mardakyan,Mardakyany,Mǝrdǝkan,Mərdəkan,Мардакян', 40.4918200, 50.1429200, 'AZ', '2015-11-11', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5626, 'Qobustan', 'Qobustan', 'Gobustan,Maraza,Marazi,Marazy,Mǝrǝzǝ,Mərəzə,Qobustan,Мараза', 40.5336000, 48.9281900, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5627, 'Mamrux', 'Mamrux', 'Mamrukh,Mamrux', 41.5424300, 46.7670000, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5628, 'Lökbatan', 'Lokbatan', 'Loekbatan,Lokbatan,Lökbatan,Локбатан', 40.3256000, 49.7337600, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5629, 'Qızılhacılı', 'Qizilhacili', 'Kyzylgadzhily,Kyzylgadzhyly,Qizilhacili,Qızılhacılı,Кызылгаджилы,Кызылгаджылы', 40.5736200, 46.8490000, 'AZ', '2016-06-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5630, 'Kyurdarmir', 'Kyurdarmir', 'Kiordamir,Kjurdamir,Kurdamir,Kyurdamir,Kyurdarmir,Kürdǝmir,Kürdəmir,Кюрдамир', 40.3453200, 48.1508500, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5631, 'Qobu', 'Qobu', 'Kobi,Kobu,Qobu,Кобу', 40.4047200, 49.7130600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5632, 'Kilyazi', 'Kilyazi', 'Gilazi,Giləzi,Kiljasi,Kiljazi,Kilyazi,Килязи', 40.8709800, 49.3423300, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5633, 'Khyzy', 'Khyzy', 'Khizy,Khyzy,Xizi,Xızı,Хызы', 40.9057600, 49.0812700, 'AZ', '2012-08-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5634, 'Khirdalan', 'Khirdalan', 'Khurdalan,Khyrdalan,Xirdalan,Хырдалан', 40.4480800, 49.7550200, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5635, 'Khodzhi-Gasan', 'Khodzhi-Gasan', 'Gadzhi-Gasan,Khodzhagasan,Khodzhasan,Khodzhi-Gasan,Xocasan,Xocəsən', 40.4129300, 49.7690400, 'AZ', '2013-07-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5636, 'Korgöz', 'Korgoz', 'Kar''yery,Kar’yery,Kergez,Korgoez,Korgoz,Korgöz,Kërgëz,Кергез', 40.3044600, 49.6236000, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5637, 'Qarayeri', 'Qarayeri', 'Karaeri,Karayeri,Qarayeri,Караери', 40.7882500, 46.3072000, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5638, 'Qaramanlı', 'Qaramanli', 'Karamanli,Karamanly,Pederly,Qaramanli,Qaramanlı,Караманлы', 40.4813500, 46.9933900, 'AZ', '2016-06-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5639, 'Qaraxanlı', 'Qaraxanli', 'Karakhanly,Qaraxanli,Qaraxanlı', 41.0341500, 45.6451600, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5640, 'Qandax', 'Qandax', 'Kandak,Kandakh,Qandax', 41.4754600, 46.5412800, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5641, 'Vurğun', 'Vurgun', 'Gryunfel''d,Gryunfel’d,Kalininkand,Kalininkend,Kalininkänd,Kalininkənd,Vurgun,Vurğun,Вургун,Калининкенд', 41.0952400, 45.4711100, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5642, 'Kerbakhiar', 'Kerbakhiar', 'K''arvacharr,Kalbacar,Kalbajar,Kel''badzhar,Kelbadshar,Kel’badzhar,Kerbakhiar,Kälbäjär,Kǝlbǝcǝr,Kəlbəcər,Kʻarvacar,K’arvacharr,Кельбаджар,Քարվաճառ', 40.1098400, 46.0444600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5643, 'Qala', 'Qala', 'Kala,Kala-Machtagi,Qala,Кала', 40.4425600, 50.1675900, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5644, 'Qax İngiloy', 'Qax Ingiloy', 'Kakh Ingilo,Kakh-Bash-Ingiloy,Kakhingiloy,Qax Ingiloy,Qax İngiloy', 41.4241200, 46.9385900, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5645, 'Qaxbaş', 'Qaxbas', 'Kakhbash,Qaxbas,Qaxbaş', 41.4325400, 46.9646000, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5646, 'İsmayıllı', 'Ismayilli', 'Ismailly,Ismaily,Ismanlli,Ismayilli,Ismayylly,Ismoylly,Jsmailly,İsmayıllı,Исмаиллы', 40.7848500, 48.1514100, 'AZ', '2014-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5647, 'Yeni Suraxanı', 'Yeni Suraxani', 'Imeni Kirova,Kirov Adina,Kirov Adına,Kirova,Poselok Imeni Kirova,Posëlok Imeni Kirova,Rasulzada,Rəsulzadə,Yeni Suraxani,Yeni Suraxanı,Yeni-Surakhany', 40.4302600, 50.0359800, 'AZ', '2013-07-04', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5648, 'Gyuzdek', 'Gyuzdek', 'Gezdek,Gjuzdek,Guzdak,Gyuzdek,Güzdǝk,Güzdək,Гюздек', 40.3744400, 49.6819400, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5649, 'Geoktschai', 'Geoktschai', 'Gekchai,Geokchai,Geokchaj,Geokchay,Geoktschai,Goeycay,Goycay,Goychay,Göychay,Göyçay,Геокчай', 40.6505500, 47.7421900, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5650, 'Hövsan', 'Hovsan', 'Gousan,Gousany,Goussan,Govsan,Hoevsan,Hovsan,Hövsan,Говсан', 40.3744400, 50.0852800, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5651, 'Goranboy', 'Goranboy', 'Geran''boy,Geranboj,Geran’boy,Goranboy,Kasum-Ismailov,Kasum-Ismailovo,Kasum-Izmaylovo,Qasim Ismayilov,Qasym Ismayylov,Qasım Ismayılov,Геранбой', 40.6102800, 46.7897200, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5652, 'Ganja', 'Ganja', 'Elisavetpol,Elizavetpol'',Elizavetpol’,Gaencae,Gaendz,Gaendzjae,Ganca,Gandja,Gandza,Gandzha,Gandzhe,Gandża,Gandža,Ganga,Ganja,Ganjak,Ganĝa,Ganҷa,Gence,Gendzakh,Gendze,Gendže,Gendžė,Gjandzha,Gjanzha,Gyandzha,Gäncä,Gändzjä,Gändž,Gǝncǝ,Gəncə,KVD,Kirovabad,Kirowabad,Nkantza,Yelizavetpol'',Yelizavetpol’,ganja,gngh,gnjh,gyanja,jnja,knjh,zhan gu,Γκαντζά,Ганджа,Гандза,Ганџа,Ганҷа,Гянджа,Гянжа,Гәнжә,Елизаветполь,Գանձակ,גנגה,جنجا,كنجه,گانجا شہر,گنجه,گنجہ,განჯა,ギャンジャ,占贾,간자', 40.6827800, 46.3605600, 'AZ', '2017-07-08', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5653, 'Kyadabek', 'Kyadabek', 'Gadabay,Gǝdǝbǝy,Gədəbəy,Kedabek,Kedabeko,Kedalek,Kyadabek,Кедабек', 40.5705500, 45.8122900, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5654, 'Faldarlı', 'Faldarli', 'Faldar,Faldarli,Faldarly,Faldarlı', 41.4686800, 46.5157900, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5655, 'Corat', 'Corat', 'Corat,Dzhorat,Джорат', 40.5717600, 49.7050900, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5656, 'Ceyranbatan', 'Ceyranbatan', 'Ceyranbatan,Dzhejranbatan,Dzheyranbatan,Джейранбатан', 40.5419400, 49.6607300, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5657, 'Dzagam', 'Dzagam', 'Dzagam,Dzegam,Dzegan,Guseynbeili,Guseynbeyli,Pzegam,Star Agozam,Zayam,Zǝyǝm,Zəyəm,Дзегам', 40.9033000, 45.8856400, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5658, 'Dondar Quşçu', 'Dondar Quscu', 'Dondar Quscu,Dondar Quşçu,Dondar-Kushchu', 40.9539000, 45.6194200, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5659, 'Digah', 'Digah', 'Digah,Digjakh,Digyakh,Dygya,Дигях', 40.4925700, 49.8747700, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5660, 'Divichibazar', 'Divichibazar', 'Davachi,Davaci,Divachi,Divichi,Divichibazar,Dävächi,Dǝvǝçi,Dəvəçi,Sabran,Shabran,Дивичи', 41.2011700, 48.9871200, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5661, 'Yukhary-Dashkesan', 'Yukhary-Dashkesan', 'Dashkasan,Dashkesan,Dashkezan,Dashkäsän,Daskasan,Daşkǝsǝn,Daşkəsən,Verkhniy Dashkesan,Yukhary-Dashkesan,Дашкесан', 40.5239300, 46.0818600, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5662, 'Dolyar', 'Dolyar', 'Dalilar,Dallar,Dalljar,Dallyar,Dolyar,Dǝlilǝr,Dəlilər,Dəllər,Далляр', 40.8627800, 46.0349300, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5663, 'Çobansığnaq', 'Cobansignaq', 'Chobansygnakh,Cobansignaq,Çobansığnaq', 40.7524400, 45.7064500, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5664, 'Çinarlı', 'Cinarli', 'Chinarly,Cinarli,Lenin,Çinarlı,Ленин', 41.4696500, 46.9158200, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5665, 'Çatax', 'Catax', 'Catax,Chatakh,Çatax', 40.7262200, 45.5591900, 'AZ', '2013-09-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5666, 'Buzovna', 'Buzovna', 'Busovny,Busowny,Buzouvna,Buzovna,Buzovny,Бузовна', 40.5190300, 50.1143800, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5667, 'Binagadi', 'Binagadi', 'Binagadi,Binagady,Binaghad,Binaqadi,Binǝqǝdi,Binəqədi,Bonogady,Бинагади', 40.4660200, 49.8278300, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5668, 'Biny Selo', 'Biny Selo', 'Bina,Bina Staraya,Biny Selo,Binǝ,Binə,Бина', 40.4507600, 50.0868600, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5669, 'Bilajer', 'Bilajer', 'Bil''gjakh,Bil''gya,Bil''gyakh,Bil''gykh,Bilajer,Bilgah,Bilgǝh,Bilgəh,Bil’gya,Bil’gyakh,Bil’gykh,Бильгях', 40.5644100, 50.0400200, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5670, 'Basqal', 'Basqal', 'Azizbekovo,Baskal,Baskhal,Basqal,Баскал', 40.7552000, 48.3910400, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5671, 'Baş Göynük', 'Bas Goynuk', 'Bas Goeynuek,Bas Goynuk,Bas Koynuk,Bash Gejnjuk,Bash Geynyuk,Bash Gëynyuk,Baş Göynük,Baş Köynük,Баш Гейнюк', 41.3258200, 47.1135700, 'AZ', '2014-02-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5672, 'Barda', 'Barda', 'Bard,Barda,Bardaa,Barde khot,Barnta,Berde,Berdė,Bärdä,Bǝrdǝ,Bərdə,Partav,ba er da,barda,brdh,Μπαρντά,Барда,Барде хот,Պարտավ,بردع,برده,ბარდა,巴爾達', 40.3757700, 47.1261900, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5673, 'Belokany', 'Belokany', 'Balakan,Balakon,Balakǝn,Balakən,Belokan,Belokani,Belokany,Белоканы', 41.7262600, 46.4047800, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5674, 'Balakhani', 'Balakhani', 'Balaban,Balachany,Baladzary,Balakhani,Balakhany,Balaxani,Balaxanı,Балаханы', 40.4634400, 49.9189300, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5675, 'Bilajari', 'Bilajari', 'Baku-Baladshary,Baladjary,Baladzhary,Bilacari,Biləcəri', 40.4444000, 49.8056600, 'AZ', '2011-08-30', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5676, 'Baku', 'Baku', 'BAK,Bacu,Bacú,Baki,Bako,Bakoe,Bakou,Baku,Bakue,Bakuo,Bakuu,Baky,Bakó,Bakú,Bakû,Bakü,Bakı,Baqu,Boku,Gorad Baku,Mpakou,ba ku,bakku,bako,baku,bakw,bakww,pakku,Μπακού,Баку,Бакы,Баҡы,Боку,Горад Баку,Բաքու,באקו,باكو,باکو,باکوو,बाकु,बाकू,বাকু,பாக்கு,ബക്കു,บากู,པཱ་ཁི།,ბაქო,ባኩ,バクー,巴库,바쿠', 40.3776700, 49.8920100, 'AZ', '2015-06-03', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5677, 'Arıqıran', 'Ariqiran', 'Anygyran,Ariqiran,Arygyran,Arıqıran', 40.5397100, 45.6141400, 'AZ', '2013-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5678, 'Arıqdam', 'Ariqdam', 'Ariqdam,Arygdam,Arykhdam,Arıqdam', 40.5931300, 45.7990000, 'AZ', '2013-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5679, 'Pirallahı', 'Pirallahi', 'Artem-Ostrov,Artyom,Artëm-Ostrov,Imeni "Dvadtsati Shesti",Imeni Artema,Imeni ”Dvadtsati Shesti”,Pirallahi,Pirallahı,Poselok Imeni Dvadtsati Shesti,Posëlok Imeni Dvadtsati Shesti,Артем-Остров', 40.4701300, 50.3247600, 'AZ', '2013-08-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5680, 'Amirdzhan', 'Amirdzhan', 'Amirabdzhan,Amiradzhan,Amiradzhany,Amircan,Amirdzhan,Əmircan', 40.4263900, 49.9836100, 'AZ', '2012-01-17', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5681, 'Altıağac', 'Altiagac', 'Altiagac,Altiagach,Altiagak,Alty-Agatsch,Altyagach,Altıağac,Alyagach,Алтиагак,Алтыагач', 40.8592700, 48.9347700, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5682, 'Aliabad', 'Aliabad', 'Aliabad,Əliabad,Алиабад', 41.4829000, 46.6348300, 'AZ', '2014-01-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5683, 'Aghsu', 'Aghsu', 'Aghsu,Agsu,Akhsu,Aksu,Ağsu,Ахсу', 40.5702800, 48.4008700, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5684, 'Aghstafa', 'Aghstafa', 'Agstafa,Akstafa,Akstafal,Ağstafa,Акстафа', 41.1188900, 45.4538900, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5685, 'Ağdaş', 'Agdas', 'Ag''dash,Agdas,Agdasas,Agdasch,Agdash,Agdašas,Aghdash,Agʻdash,Akdash,Ağdaş,a ge da shen,aghdashi,aq dash,Агдаш,Քաղբերդ,آغ‌داش,آق داش,აღდაში,阿格達什', 40.6469900, 47.4738000, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5686, 'Martakert', 'Martakert', 'Agdara,Agdere,Aghdara,Ağdǝrǝ,Ağdərə,Mardakert,Martakert,Агдере,Мардакерт,Мартакерт,Մարտակերտ,آغ‌دره', 40.2123800, 46.8208600, 'AZ', '2017-07-19', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5687, 'Agdzhabedy', 'Agdzhabedy', 'Agcabadi,Agdzhabedi,Agdzhabedy,Aghjabadi,Aghjabädi,Ağcabǝdi,Ağcabədi,Агджабеди', 40.0501500, 47.4593700, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5688, 'Böyük Qaramurad', 'Boyuk Qaramurad', 'Beyuk-Karamurad,Boyuk Qaramurad,Bëyuk-Karamurad,Böyük Qaramurad', 40.5762600, 45.6372700, 'AZ', '2013-05-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5689, 'Mughan', 'Mughan', 'Mugan,Mugan'',Muğan,Мугань', 40.0990200, 48.8188600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5690, 'Qabaqçöl', 'Qabaqcol', 'Qabaqcol,Qabaqçöl', 41.7525900, 46.2705200, 'AZ', '2014-01-14', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5691, 'Bakıxanov', 'Bakixanov', 'Bakikhanov,Bakikhanova,Bakixanov,Bakıxanov,Бакиханова', 40.4189400, 49.9669300, 'AZ', '2013-07-06', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5692, 'Qırmızı Samux', 'Qirmizi Samux', 'Krasnyy Samukh,Qirmizi Samux,Qırmızı Samux', 40.9397200, 46.3788900, 'AZ', '2013-10-09', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5693, 'Hacıhüseynli', 'Hacihuseynli', 'Hacihuseynli,Hacıhüseynli', 41.4563900, 48.6488900, 'AZ', '2013-05-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5694, 'Aran', 'Aran', 'Arai,Aran,Араи', 40.6252800, 46.9755600, 'AZ', '2014-06-26', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5695, 'Samuxlu', 'Samuxlu', 'Leninabad,Samuxlu', 40.5083300, 47.1691700, 'AZ', '2013-06-05', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5696, 'Ramana', 'Ramana', 'Ramana,Рамана', 40.4422200, 49.9805600, 'AZ', '2014-06-27', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5697, 'Badamdar', 'Badamdar', 'Badamdar', 40.3402400, 49.8045000, 'AZ', '2013-07-07', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5698, 'Heydarabad', 'Heydarabad', 'Heydarabad,Heydərabad', 39.7228600, 44.8484600, 'AZ', '2016-04-16', 16);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5972, 'Thākurgaon', 'Thakurgaon', 'TKR,Thakurgaom,Thakurgaon,Thakus Gaon,Thākurgaom,Thākurgaon', 26.0309700, 88.4698900, 'BD', '2017-04-06', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5973, 'Teknāf', 'Teknaf', 'Teknaaf,Teknaf,Teknāf', 20.8582900, 92.2977300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5974, 'Tungi', 'Tungi', 'Tangi,Tongi,Tungi,tangi,টঙ্গী', 23.8915400, 90.4023200, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5975, 'Sylhet', 'Sylhet', 'Jalalabad,Rajnagar,Rājnagar,Silet,Sileţ,Silhatas,Silhatta,Silkhet,Silot,Silôţ,Sreehatta,Srihotto,Srihôţţo,Sylhet,Szilhet,ZYL,cil''het,shiretto,silahata,sileta,silles,sylht,sylt,xi er he te shi,Силхет,Сілет,سلہٹ,سيلهت,سیلت,सिलहट,সিলেট,சில்ஹெட்,സിൽഹെറ്റ്,シレット,錫爾赫特市,실렛', 24.8990400, 91.8719800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5976, 'Dohār', 'Dohar', 'Dohai,Dohar,Dohāi,Dohār,Sutarpara,Sutārpara', 23.5931100, 90.1425100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5977, 'Jamālpur', 'Jamalpur', 'Jamaipur,Jamalpur,Jamālpur,Singhjani,Singhjāni', 24.9196500, 89.9481200, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5978, 'Shibganj', 'Shibganj', 'Shibgandzh,Shibganj,Sibganj,Шибгандж', 25.0014600, 89.3226600, 'BD', '2017-06-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5979, 'Shibganj', 'Shibganj', 'Shibganj,Sibganj', 24.6850100, 88.1563800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5980, 'Sātkhira', 'Satkhira', 'Satkhira,Shatkhira,Sātkhira', 22.7081700, 89.0718500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5981, 'Sirajganj', 'Sirajganj', 'SAJ,Serajganj Municipality,Siradzhgandzh,Sirajganj,Siranganj,Sirājganj,sirajaganja,Сираджгандж,সিরাজগঞ্জ', 24.4577100, 89.7080200, 'BD', '2017-05-04', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5982, 'Netrakona', 'Netrakona', 'Netrakona,Satpai,Sātpāi', 24.8835200, 90.7289800, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5983, 'Narsingdi', 'Narsingdi', 'Narsingdi,Narsinghdi,Satirpara,Satirpāra', 23.9229800, 90.7176800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5984, 'Sandwīp', 'Sandwip', 'Sandvip,Sandwip,Sandwīp,Сандвип', 22.5140900, 91.4549100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5985, 'Shāhzādpur', 'Shahzadpur', 'Sahzadpur,Shahzadpur,Shāhzādpur', 24.1768700, 89.5988000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5986, 'Rāmganj', 'Ramganj', 'Ramganj,Ratanpur,Rāmganj', 23.1006000, 90.8498900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5987, 'Rājshāhi', 'Rajshahi', 'RJH,Radzhshakhi,Rajshahi,Rampur Baolia,Rampur Bauleah,Rampur Boalia,Rājshāhi,rajasahi,Раджшахи,রাজশাহী', 24.3740000, 88.6011400, 'BD', '2017-04-06', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5988, 'Purbadhala', 'Purbadhala', 'Purbadhala,Purbba Dhala', 24.9407700, 90.6002500, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5989, 'Pirojpur', 'Pirojpur', 'Perijpur,Perojpur Municipality,Pirojpur', 22.5796500, 89.9752100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5990, 'Panchagarh', 'Panchagarh', 'Pachagar,Pachagarh,Pachāgarh,Panchagarh', 26.3333800, 88.5577700, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5991, 'Patiya', 'Patiya', 'Patia,Patiya', 22.2954300, 91.9790000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5992, 'Parbatipur', 'Parbatipur', 'Parbatipur,Parvatipur,Pārvatīpur', 25.6636900, 88.9309300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5993, 'Nārāyanganj', 'Narayanganj', 'Narajanganj,Narayanganj,Nārāyanganj', 23.6135200, 90.5029800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5994, 'Nālchiti', 'Nalchiti', 'Nalchhiti,Nalchiti,Nālchiti', 22.6369600, 90.2719500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5995, 'Nāgarpur', 'Nagarpur', 'Nagarpur,Nagurpoor,Nāgarpur', 24.0578300, 89.8769600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5996, 'Nageswari', 'Nageswari', 'Nagasewari,Nageshawari,Nageshwari,Nageswari,Nagheswari,Nāgeshwari,Paschim Nageswari', 25.9681700, 89.6915300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5997, 'Mymensingh', 'Mymensingh', 'Majmensingkh,Mymensing,Mymensingh,Nasirabad,Nasirābād,mayamanasinha,Майменсингх,ময়মনসিংহ', 24.7563600, 90.4064600, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5998, 'Muktāgācha', 'Muktagacha', 'Muktagacha,Muktagachha,Muktāgācha', 24.7648400, 90.2569800, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5999, 'Mirzāpur', 'Mirzapur', 'Mirzapur,Mirzāpur,Mrizapur,Мирзапур', 24.1028700, 90.0984100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6000, 'Maulavi Bāzār', 'Maulavi Bazar', 'Maulavi Bazar,Maulavi Bāzār,Maulvi Bazar,Maulvi Bāzār,Moulvi Bazar,Moulvi Bazar Municipality,Moulvi Bāzār', 24.4888800, 91.7707500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6001, 'Morrelgonj', 'Morrelgonj', 'Fakirertakia,Fakirertākia,Morrelganj,Morrelgonj,Morrellganj', 22.4556600, 89.8558400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6002, 'Mehendiganj', 'Mehendiganj', 'Mehdigunj,Mehendiganj', 22.8225700, 90.5285900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6003, 'Mathba', 'Mathba', 'Matbari,Matbaria,Matbāri,Mathba,Mathbari,Mathbaria,Sankibhanga', 22.2861600, 89.9588300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6004, 'Lalmanirhat', 'Lalmanirhat', 'Lalmanir Hat,Lalmanirat,Lalmanirhat,Lalmonirhat,Lālmanir Hāt', 25.9171900, 89.4459500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6005, 'Lākshām', 'Laksham', 'Laksam,Laksham,Lākshām', 23.2401800, 91.1214300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6006, 'Comilla', 'Comilla', 'CLA,Comilla,Komila,Komilla,Komille,Kumilla,Kumillā,khu mi l la,komilla,kumilla,kumirra,kwmyla,Комилла,Комилле,کومیلا,कोमिल्ला,কুমিল্লা,คูมิลลา,クミッラ', 23.4618600, 91.1850300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6007, 'Rangpur', 'Rangpur', 'Kotwali,Kotwāli,Mosque Rangpur,RAU,Rangpur,Rangpur City,Rangpuras,Rongpur,lang bu er shi,langpuleu,rampura,ranpuru,Рангпур,رنگپور شہر,রংপুর,ランプル,朗布尔市,랑푸르', 25.7466400, 89.2516600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6008, 'Kushtia', 'Kushtia', 'Khustia,Kushtia', 23.9028000, 89.1194300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6009, 'Kālīganj', 'Kaliganj', 'Aliganj,Kaliganj,Kaliganja,Kālīganj', 23.4096400, 89.1380100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6010, 'Jhingergācha', 'Jhingergacha', 'Jhikargacha,Jhikargachha,Jhikargāchha,Jhikergacha,Jhingergacha,Jhingergācha,Jhinkargacha', 23.1113400, 89.0906100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6011, 'Joypur Hāt', 'Joypur Hat', 'Jaipur Hat,Jaipur Hāt,Jaypur Hat,Joypur Hat,Joypur Hāt', 25.1014700, 89.0273400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6012, 'Ishurdi', 'Ishurdi', 'IRD,Ishurda,Ishurdi', 24.1285800, 89.0657300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6013, 'Habiganj', 'Habiganj', 'Habiganj,Habiganj Bazar,Habiganj Sadar,Hobiganj', 24.3804400, 91.4129900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6014, 'Gaurnadi', 'Gaurnadi', 'Gaurnadi,Gournadi', 22.9737200, 90.2237600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6015, 'Gafargaon', 'Gafargaon', 'Gafargaon,Gaffargaon,Ghafargaon', 24.4320000, 90.5585000, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6016, 'Feni', 'Feni', 'Feni,Feni  Bangladesh,Fenny', 23.0144000, 91.3966000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6017, 'Rāipur', 'Raipur', 'Deyanatpur,Deyānatpur,Raipur,Rajpur,Raypur,Rāipur,Райпур', 23.0391000, 90.7680800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6018, 'Sarankhola', 'Sarankhola', 'Dakshin Rajapur,Dakshin Rājāpur,Sarankhola', 22.3100600, 89.7911300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6019, 'Dhaka', 'Dhaka', 'DAC,Daaka,Daca,Dacca,Dacca - dhaka,Dacca - ঢাকা,Daka,Dakah,Dakk,Dakka,Dakkae,Dakke,Dako,Deka,Dgaka,Dhaka,Dháka,Dhâkâ,Dəkkə,Gorad Daka,Mujib City,Ntaka,Ntakka,da ka,daka,dakka,dhaka,dhakka,dka,takka,thaka,Ντάκα,Ντάκκα,Горад Дака,Даака,Дака,Даккæ,Дакка,Дакке,Дгака,Դաքքա,דאקא,דאקה,داكا,داکا,دكا,ڈھاکہ,ޑާކާ,ढाका,ঢাকা,ਢਾਕਾ,ઢાકા,ଢାକା,டாக்கா,ఢాకా,ಢಾಕಾ,ഢാക്ക,ඩකා,ธากา,དྷ་ཁ།,ဒါကာမြို့,დაკა,ዳካ,ダッカ,达卡,達卡,다카', 23.7104000, 90.4074400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6020, 'Chilmāri', 'Chilmari', 'Chillmari,Chilmari,Chilmāri', 25.5561300, 89.6709700, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6021, 'Chhāgalnāiya', 'Chhagalnaiya', 'Chhagainaya,Chhagalnaia,Chhagalnaiya,Chhagalnaya,Chhāgalnāiya,Paschim Chhagalnaiya,Paschim Chhāgalnāiya,West Chhagal Naiya,West Chhagalnaia', 23.0247500, 91.5109100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6022, 'Lālmohan', 'Lalmohan', 'Char Lalmohan,Char Lalmohun,Char Lālmohan,Dhar Lalmohan,Lalmohan,Lālmohan', 22.3377400, 90.7370800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6023, 'Khagrachhari', 'Khagrachhari', 'Changrachhari,Khabangpari,Khagrachari,Khagrachhari,Khagrāchari,Khagrāchhari,Kkhagrachari,Кхаграчари', 23.1078700, 91.9700700, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6024, 'Chhātak', 'Chhatak', 'Cehatak,Chatak,Chattakbazar,Chhatak,Chhatar Bazaar,Chhātak', 25.0385200, 91.6695800, 'BD', '2016-11-14', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6025, 'Bhātpāra Abhaynagar', 'Bhatpara Abhaynagar', 'Abhaynagar,Bhatpara Abhaynagar,Bhātpāra Abhaynagar', 23.0147200, 89.4393600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6026, 'Bherāmāra', 'Bheramara', 'Bhairamara,Bheramara,Bherāmāra', 24.0245200, 88.9923400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6027, 'Bhairab Bāzār', 'Bhairab Bazar', 'Bhairab Bazar,Bhairab Bāzār,Bhairab Town', 24.0524000, 90.9764000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6028, 'Bāndarban', 'Bandarban', 'Bandarban,Bardarban,Bāndarban,Бандарбан', 22.1953400, 92.2194600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6029, 'Kālia', 'Kalia', 'Bara Kalia,Bara Kālia,Kalia,Kalija,Kālia,Калия', 23.0430000, 89.6309400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6030, 'Baniachang', 'Baniachang', 'Baniachang,Banivachong,Baniyachong,Baniyachung,Bāniyāchung', 24.5186300, 91.3578700, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6031, 'Bājitpur', 'Bajitpur', 'Bajitpur,Bajutpur,Bājitpur', 24.2162300, 90.9500200, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6032, 'Bagerhat', 'Bagerhat', 'Bagerhat,Bagerhat Town,Bagerkhat,Bagherhat,Bāgerhāt,Bāgherhāt,Багерхат', 22.6565700, 89.7912300, 'BD', '2017-06-26', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6033, 'Badarganj', 'Badarganj', 'Badarganj,Badarganja', 25.6741900, 89.0537700, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6034, 'Narail', 'Narail', 'Aladatpur,Alādātpur,Narail,Naral,Narāl', 23.1550900, 89.4951500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6035, 'Tungipāra', 'Tungipara', 'Tongipara,Tungipara,Tungipāra', 22.8998300, 89.9032600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6036, 'Sonārgaon', 'Sonargaon', 'Sonargaon,Sonārgaon,Сонаргаон', 23.6500000, 90.6166700, 'BD', '2017-07-04', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6037, 'Sarishābāri', 'Sarishabari', 'Sarisabar,Sarisabari,Sarishabari,Sarishābāri,Sarsabari', 24.7512700, 89.8312600, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6038, 'Sakhipur', 'Sakhipur', '', 24.3198800, 90.1694300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6039, 'Raojān', 'Raojan', 'Raajan,Raajān,Raojan,Raojān,Raozan,Rauzan', 22.5351100, 91.9191900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6040, 'Phultala', 'Phultala', '', 22.7167300, 89.5119400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6041, 'Pālang', 'Palang', '', 23.2182400, 90.3507600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6042, 'Pār Naogaon', 'Par Naogaon', 'Par Naogaon,Pār Naogaon', 24.8041800, 88.9487500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6043, 'Nabīnagar', 'Nabinagar', '', 23.8879100, 90.9679200, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6044, 'Lakshmīpur', 'Lakshmipur', 'Lakshmipur,Lakshmipur Jela,Lakshmipur Zila,Lakshmīpur,laksmipura jela,লক্ষ্মীপুর জেলা', 22.9443000, 90.8300500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6045, 'Kesabpur', 'Kesabpur', 'Kesabpur,Keshabpur', 22.9072500, 89.2195400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6046, 'Jahedpur', 'Jahedpur', 'Jahedpur,Jahidpur', 24.8333300, 91.6500000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6047, 'Hājīganj', 'Hajiganj', '', 23.2519100, 90.8550800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6048, 'Farīdpur', 'Faridpur', '', 23.6061200, 89.8406400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6049, 'Dinājpur', 'Dinajpur', 'Dinajpur,Dinājpur', 25.6274500, 88.6377900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6050, 'Uttar Char Fasson', 'Uttar Char Fasson', 'Dakshin Char Fasson,South Char Fashion,Uttar Char Fasson', 22.2264700, 90.7127500, 'BD', '2012-07-04', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6051, 'Chittagong', 'Chittagong', 'CGP,Cattagram,Caṭṭagrām,Cetagons,Chitagong,Chittagong,Chittagong Ghat,Chottogram,Chôţţogram,Citagaon,Citagong,Citagonga,Citagongas,Citagongo,Cittaqonq,Cottogram,Csittagong,Islamabad,Tsitankon''nk,catagamva,cattagrama,chitagong,chittagon,chytagwng,cirragean,cit ta kxng,citagonga,cittagang,cittagonga,cittakon,ji da gang,ji da gang shi,shytaghwngh,shytajwnj,zytgwng,Çitagong,Çittaqonq,Ćottogram,Ĉitagongo,Čattagrám,Čitagonga,Čitagongas,Čitágáon,Čėtagons,Τσιταγκόνγκ,Читагонг,Читтагонг,Читтаґонґ,טשיטאגאנג,ציטגונג,شيتاجونج,شيتاغونغ,چٹاگانگ,چیتاگونگ,चटगाँव,चट्टग्राम,चिटागोंग,চট্টগ্রাম,ચિત્તાગોંગ,சிட்டகொங்,చిట్టగాంగ్,ಚಿತ್ತಗಾಂಗ್,ചിറ്റഗോങ്,จิตตะกอง,စစ်တကောင်းမြို့,ჩიტაგონგი,チッタゴン,吉大港,吉大港市,치타공', 22.3384000, 91.8316800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6052, 'Char Bhadrāsan', 'Char Bhadrasan', '', 23.3091600, 90.2269800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6053, 'Bera', 'Bera', 'Bera,Berah,Beru,Беру', 24.0782100, 89.6326200, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6054, 'Burhānuddin', 'Burhanuddin', 'Barahanuddin,Barahānuddin,Burhanuddin,Burhānuddin', 22.4951800, 90.7239100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6055, 'Sātkania', 'Satkania', 'Satkania,Sātkania', 22.0763900, 92.0495500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6056, 'Cox’s Bāzār', 'Cox''s Bazar', 'CXB,Cox''s Bazar,Cox’s Bāzār,Koks-Bazar,Кокс-Базар', 21.4397300, 92.0095500, 'BD', '2017-04-04', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6057, 'Khulna', 'Khulna', 'Khulna,Khulnâ,Kkhelna,Kkhulna,Kulna,Kulno,khulana,khwlna,ku er na shi,kulna,kuruna,Кулна,Кхелна,Кхулна,خولنا,کھلنا,खुलना,খুলনা,குல்னா,クルナ,库尔纳市,쿨나', 22.8097900, 89.5643900, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6058, 'Bhola', 'Bhola', 'Bhola,Bhola District,Bkhola,Huyen Bhola,Huyện Bhola,bhola jela,bhola jila,bo la xian,Бхола,ضلع بھولا,ভোলা জিলা,ভোলা জেলা,波拉縣', 22.6875900, 90.6440300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6059, 'Barisāl', 'Barisal', 'BZL,Barisal,Barisal Sadar,Barisāl,Barīsal Sadar,barisala,Барисал,বরিশাল', 22.7049700, 90.3701300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6060, 'Jessore', 'Jessore', 'JSR,Jessore', 23.1697100, 89.2137100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6061, 'Pābna', 'Pabna', 'Pabna,Pabne,Pābna,Пабне', 24.0064400, 89.2372000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6062, 'Tāngāil', 'Tangail', 'Tangail,Tāngāil', 24.2498400, 89.9165500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6063, 'Bogra', 'Bogra', 'Bogora,Bogra,bagura,bogura,bwgra,Богра,بوگرا,বগুড়া,ボグラ', 24.8509800, 89.3710800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6064, 'Pīrgaaj', 'Pirgaaj', 'Pirgaaj,Pirganj,Pīrgaaj,Pīrganj', 25.8558700, 88.3594300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6065, 'Nawābganj', 'Nawabganj', 'Nawabganj,Nawābganj', 24.5902500, 88.2744400, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6066, 'Mādārīpur', 'Madaripur', '', 23.1709700, 90.2093500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6067, 'Sherpur', 'Sherpur', 'Sherpur', 25.0188100, 90.0175100, 'BD', '2016-11-17', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6068, 'Kishorganj', 'Kishorganj', 'Kisharganj,Kishoreganj,Kishoreganj Municipality,Kishorganj', 24.4394400, 90.7829100, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6069, 'Manikchari', 'Manikchari', 'Manikchari,Manikchhari,Mānikchhari', 22.8395700, 91.8412800, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6070, 'Bhāndāria', 'Bhandaria', 'Bhandaria,Bhāndāria', 22.4889800, 90.0627300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6071, 'Fatikchari', 'Fatikchari', 'Fatikchari', 22.6876800, 91.7812300, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6072, 'Saidpur', 'Saidpur', 'SPD,Syedpur,saiyadapura,সৈয়দপুর', 25.7776900, 88.8916900, 'BD', '2013-07-20', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6073, 'Puthia', 'Puthia', 'Puthia,Putkhija,Путхия', 24.3653700, 88.8343100, 'BD', '2017-06-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6074, 'Natore', 'Natore', 'Nator,Natore,Nātor,Натор', 24.4111200, 88.9867300, 'BD', '2017-06-26', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6075, 'Nowlamary', 'Nowlamary', 'na''olamari,নওলামারী', 23.6734600, 88.9888500, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6076, 'Magura', 'Magura', 'Districtul Magura,Huyen Magura,Huyện Magura,Magura,Magura District,ma gu la xian,magura jela,magura jila,Магура,ضلع ماگورا,ماگورا ضلع,মাগুরা জিলা,মাগুরা জেলা,马古拉县', 23.4870200, 89.4159200, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6077, 'Azimpur', 'Azimpur', 'Azimpur  Dhaka  Bangladesh', 23.7298000, 90.3854000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6078, 'Gaibandha', 'Gaibandha', 'Gaibanda,Gaibandha', 25.3293000, 89.5438000, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6079, 'Mahasthangarh', 'Mahasthangarh', 'Mahastan,Makhastan,Махастан', 24.9611100, 89.3427800, 'BD', '2017-06-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6080, 'Paltan', 'Paltan', 'Paltan  Dhaka  Bangladesh', 23.7362500, 90.4142600, 'BD', '2016-11-09', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6081, 'Parvez Ali Hossain', 'Parvez Ali Hossain', '', 23.7875800, 90.1648700, 'BD', '2017-07-13', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6082, 'Khanbaniara', 'Khanbaniara', '', 23.7822500, 90.1838200, 'BD', '2017-07-14', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6083, 'Char Golora', 'Char Golora', '', 23.8203700, 90.1217500, 'BD', '2017-07-14', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6084, 'Parvez Ali Family', 'Parvez Ali Family', '', 23.8174100, 90.1192100, 'BD', '2017-07-14', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6085, 'Joymontop', 'Joymontop', '', 23.7878900, 90.1647200, 'BD', '2017-07-14', 19);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5962, 'Welchman Hall', 'Welchman Hall', '', 13.1867600, -59.5766300, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5963, 'Crane', 'Crane', 'The Crane', 13.1048700, -59.4486100, 'BB', '2016-10-29', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5964, 'Speightstown', 'Speightstown', 'Speightstown,Spreightstown', 13.2507200, -59.6439600, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5965, 'Oistins', 'Oistins', 'Oistin''s Town,Oistins,Oistin’s Town', 13.0706700, -59.5463700, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5966, 'Holetown', 'Holetown', 'Holetown,The Hole', 13.1867200, -59.6380800, 'BB', '2012-01-16', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5967, 'Greenland', 'Greenland', 'Greenland', 13.2580800, -59.5776300, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5968, 'Four Cross Roads', 'Four Cross Roads', '', 13.1701800, -59.5218600, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5969, 'Checker Hall', 'Checker Hall', '', 13.2844500, -59.6422300, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5970, 'Bridgetown', 'Bridgetown', 'BGI,Bridgetown,Bridzhtaun,Bridztaun,Bridztaunas,Bridžtaunas,The Bridge Town,beulijitaun,brydj tawn,bu li qi dun,burijjitaun,Бриджтаун,Бриџтаун,ברידג''טאון,بريدج تاون,ብርጅታውን,ブリッジタウン,布里奇敦,브리지타운', 13.1073200, -59.6202100, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5971, 'Bathsheba', 'Bathsheba', 'Bathsheba', 13.2113300, -59.5259600, 'BB', '2016-10-28', 20);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6086, 'Zwijndrecht', 'Zwijndrecht', 'Zuindracum,Zvejndrekht,Zwijndrecht,Zwyndrecht,ci wei en de lei he te,zwyyzhndrkt,Звейндрехт,زوئیژندرکت,兹韦恩德雷赫特', 51.2197900, 4.3266400, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6087, 'Zwevegem', 'Zwevegem', 'Sweveghem,Zvevegem,Zwevegem,Zwevehem,ci wei fu hai mu,zwywwzhm,Звевегем,زوئووژم,兹韦弗海姆', 50.8126800, 3.3384800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6088, 'Zutendaal', 'Zutendaal', 'Sutendael,Zutendaal', 50.9330600, 5.5753000, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6089, 'Zulte', 'Zulte', 'Zulte', 50.9195400, 3.4485900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6090, 'Zuienkerke', 'Zuienkerke', 'Zuienkerke,Zuujnkerke,Zuyenkerke', 51.2651100, 3.1550600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6091, 'Zoutleeuw', 'Zoutleeuw', 'Leau,Léau,Zoutleeuw,Zoutleew', 50.8331600, 5.1037600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6092, 'Zottegem', 'Zottegem', 'Sottegem,Zotegem,Zottegem,ztzhm,zuo te hai mu,Зотегем,Зоттегем,زتژم,佐特海姆', 50.8695500, 3.8105200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6093, 'Zonnebeke', 'Zonnebeke', 'Sonnebeca,Zonebeke,Zonempeke,Zonnebeke,Zunnebeke,zuo nei bei ke,zwnwbwk,Ζονεμπέκε,Зонебеке,Зоннебеке,زونوبوک,佐内贝克', 50.8726000, 2.9872500, 'BE', '2015-11-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6094, 'Zonhoven', 'Zonhoven', 'Zoneve,Zonhoven,Zonhovena,Zonkhoven,son ho fein,zong huo fen,zwnwwan,Зонховен,زونووان,โซนโฮเฟิน,宗霍芬', 50.9906400, 5.3681900, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6095, 'Zomergem', 'Zomergem', 'Somergein,Somergem,Zomergem', 51.1199400, 3.5649600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6096, 'Zoersel', 'Zoersel', 'OBL,Zoersel', 51.2682500, 4.7129600, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6097, 'Zingem', 'Zingem', 'Syngem,Zingem', 50.9040900, 3.6530500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6098, 'Zemst', 'Zemst', 'Sempst,Zemst,zamst,ze mu si te,Земст,زامست,泽姆斯特', 50.9831800, 4.4607900, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6099, 'Zelzate', 'Zelzate', 'Selzaet,Selzaete,Zelzate', 51.1896300, 3.8077700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6100, 'Zele', 'Zele', 'Zele,ze lai,zl,Зеле,زل,泽莱', 51.0656600, 4.0403000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6101, 'Zeebrugge', 'Zeebrugge', 'Seebruegge,Seebrügge,Zebrjuge,Zebrjugge,Zeebruges,Zeebrugge,Zeebrygge,Zêebrugge,ze bu lu he,Зебрюгге,Зебрюге,泽布吕赫', 51.3290100, 3.1818800, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6102, 'Zedelgem', 'Zedelgem', 'Zedel''gem,Zedelgem,Zedelghem,Zillegem,Zillehem,ze de er hai mu,zwdlzhm,Зеделгем,Зедельгем,زودلژم,泽德尔海姆', 51.1423600, 3.1368000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6103, 'Zaventem', 'Zaventem', 'Saventhem,Zaventem,zha fen te mu,zwantm,Завентем,زوانتم,扎芬特姆', 50.8836500, 4.4729800, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6104, 'Zandhoven', 'Zandhoven', 'Santhoven,Zandhoven', 51.2148800, 4.6616400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6105, 'Yvoir', 'Yvoir', 'Ivoar,Ivuar,Uwar,Yvoir,aywwar,yi wa er,ywwr,Ивоар,Ивуар,ایووآر,یوور,伊瓦尔', 50.3279000, 4.8805900, 'BE', '2011-05-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6106, 'Wuustwezel', 'Wuustwezel', 'Wuestwezel,Wuustwezel', 51.3921400, 4.5954600, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6107, 'Wommelgem', 'Wommelgem', 'Wommelgem,Wommelghem', 51.2045200, 4.5225000, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6108, 'Wingene', 'Wingene', 'Wingene,Wynghene', 51.0578200, 3.2735900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6109, 'Willebroek', 'Willebroek', 'Vilebruk,Villebruk,Willebroeck,Willebroek,wei lei bu lu ke,wywbrwyk,Вилебрук,Виллебрук,ویوبروئک,维勒布鲁克', 51.0604100, 4.3601900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6110, 'Wijnegem', 'Wijnegem', 'Wijnegem,Wyneghem', 51.2278700, 4.5189500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6111, 'Wielsbeke', 'Wielsbeke', 'Wielsbeke', 50.9000000, 3.3666700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6112, 'Wichelen', 'Wichelen', 'Wichelen', 51.0052600, 3.9768300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6113, 'Wezembeek-Oppem', 'Wezembeek-Oppem', 'Vezembek-Opem,Vezembek-Oppem,Wesembeek,Wezembeek-Oppem,wei ze mei bei ke-ao pei mu,wwzanbyk-awpm,Везембек-Опем,Везембек-Оппем,ووزانبئک-اوپم,韦泽梅贝克-奥佩姆', 50.8395000, 4.4942700, 'BE', '2011-01-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6114, 'Wevelgem', 'Wevelgem', 'Vevel''geme,Vevelgem,Wevelgem,Wevelghem,Wevelhem,wei fu er hai mu,Вевелгем,Вевельгеме,韦弗尔海姆', 50.8000000, 3.1666700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6115, 'Wetteren', 'Wetteren', 'Veteren,Vetteren,Wetteran,Wetteren,awytwran,wei te lun,Ветерен,Веттерен,اوئتوران,韦特伦', 51.0052600, 3.8834100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6116, 'Westerlo', 'Westerlo', 'Vesterlas,Vesterlo,Westerlo,Westerloo,awystrlw,wei si te luo,Вестерло,اوئسترلو,韦斯特洛', 51.0904900, 4.9154400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6117, 'Wervik', 'Wervik', 'Vervik,Viroviacum,Wervicq,Wervik,wei er fei ke,wrwyk,Вервик,Вервік,ورویک,韦尔菲克', 50.7806900, 3.0385400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6118, 'Wenduine', 'Wenduine', 'Vandjuin,Wenduine,Wenduyne,Вандюин', 51.2983000, 3.0821300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6119, 'Wemmel', 'Wemmel', 'Vemel,Vemmel,Wemmel,wei mei er,wml,Вемел,Веммел,ومل,韦梅尔', 50.9081200, 4.3061300, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6120, 'Wellin', 'Wellin', 'Uelen,Vellen,Welin,Wellin,Wellini vald,wei lan,wwln,Веллен,Уелен,وولن,韦兰', 50.0813300, 5.1141300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6121, 'Wellen', 'Wellen', 'Wellen,Wille', 50.8409600, 5.3386700, 'BE', '2011-03-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6122, 'Welkenraedt', 'Welkenraedt', 'Velkenradt,Velkenrat,Welkenraedt,Welkenrote,Wellekete,awylkwnryt,wei er ken la te,Велкенрадт,Велкенрат,اوئلکونرئت,韦尔肯拉特', 50.6605000, 5.9703400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6123, 'Wavre', 'Wavre', 'Uavur,Vavr,Vavra,Vavras,Wave,Waver,Wavre,Wavria,Wåve,ZGV,uabeuleu,wa fu er,wavuru,wwr,Βαβρ,Вавр,Уавър,وور,ワーヴル,瓦夫爾,우아브르', 50.7171700, 4.6013800, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6124, 'Waterloo', 'Waterloo', 'Vaterlo,Vaterloo,Vatʻerloo,Waterlo,Waterloo,Waterloum,Waterlô,hua tie lu,oyataralu,wateruro,watrlw,wo da lao,woteollu,wwtrlw,Βατερλώ,Ватерло,Ватерлоо,Վաթեռլոո,ווטרלו,واترلو,واٹرلو، بیلجئیم,ওয়াটারলু,ワーテルロー,滑鐵盧,窩打老,워털루', 50.7146900, 4.3991000, 'BE', '2013-11-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6125, 'Wasseiges', 'Wasseiges', 'Wasseiges', 50.6218600, 5.0052800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6126, 'Waremme', 'Waremme', 'Borgworm,Uarem,Varem,Wareme,Waremme,Werm,Wèrm,wa lei mu,wrm,Варем,Уарем,ورم,瓦雷姆', 50.6976000, 5.2552400, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6127, 'Waregem', 'Waregem', 'Varegem,Varegemas,Waereghem,Waregem,Waregemi vald,Woaregem,baleheom,wa lei hai mu,warehemu,warkhm,Варегем,وارخم,ワレヘム,瓦勒海姆,바레험', 50.8889800, 3.4275600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6128, 'Wanze', 'Wanze', 'Uanz,Vanz,Wanze,awyanz,wang ci,Ванз,Уанз,اوئانز,旺兹', 50.5390700, 5.2084600, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5699, 'Zvornik', 'Zvornik', 'Zvonik,Zvornik,Zvornikas,jeuboleunikeu,zi wo er ni ke,zuvu~oruniku,Зворник,ズヴォルニク,茲沃爾尼克,즈보르니크', 44.3860500, 19.1024700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5700, 'Živinice', 'Zivinice', 'Zivinice,Živinice', 44.5476500, 17.3735700, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5701, 'Živinice', 'Zivinice', 'Zhivinice,Zhivinice Grad,Zivinice,ri wei ni cai,Živinice,Živinicė,Живинице,Живинице Град,日維尼采', 44.4492900, 18.6497800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5702, 'Žepče', 'Zepce', 'Zepce,Zhepche,re pu qie,Žepče,Žepčė,Жепче,热普切', 44.4266700, 18.0377800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5703, 'Zenica', 'Zenica', 'Zenica,Zenicja,jenicha,se nit sa,ze ni cha,zenitsa,zenitsu~a,znyka,znytsa,znyzh,zynytsa,Зеница,Зениця,Զենիցա,זניצה,زنیتسا,زنیکا,زينيتسا,زینیتسا,เซนีตซา,ზენიცა,ゼニツァ,泽尼察,제니차', 44.2016900, 17.9039700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5704, 'Željezno Polje', 'Zeljezno Polje', '', 44.3987500, 17.9410300, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5705, 'Zborište', 'Zboriste', '', 45.1459300, 16.0172800, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5706, 'Zavidovići', 'Zavidovici', 'Zavidovichi,Zavidovici,Zavidovići,zha wei duo wei qi,Завидовичи,Завидовићи,扎維多維齊', 44.4458300, 18.1497200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5707, 'Zabrišće', 'Zabrisce', 'Zabrisce,Zabrišće', 43.7922400, 16.9422400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5708, 'Vukovije Donje', 'Vukovije Donje', 'Donje Vukovije,Vukovije Donje,Vukovje Donje', 44.4620900, 18.7494100, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5709, 'Vrnograč', 'Vrnograc', 'Vrnograc,Vrnograč', 45.1636900, 15.9544400, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5710, 'Vozuća', 'Vozuca', '', 44.3587800, 18.3539700, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5711, 'Voljevac', 'Voljevac', '', 43.8787300, 17.6586100, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5712, 'Vogošća', 'Vogosca', 'Gornja Vogosca,Gornja Vogošća,Opcina Vogosca,Općina Vogošća,Vogosa,Vogosca,Vogoshca,Vogošća,vu~ogoshucha,wwgwsa,wwgwshcha,Вогошћа,Վոգոշա,ووگوسا,ووگوشچا,ヴォゴシュチャ', 43.9022500, 18.3443800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5713, 'Vlasenica', 'Vlasenica', 'Vlasenica,Vlasenice,beullasenicha,vurasenitsu~a,Власеница,ヴラセニツァ,블라세니차', 44.1818300, 18.9409600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5714, 'Vitina', 'Vitina', 'Vitina', 43.2375000, 17.4838900, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5715, 'Vitez', 'Vitez', 'Vitez,Vitezas,wei te zi,Витез,維特茲', 44.1542400, 17.7900900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5716, 'Visoko', 'Visoko', 'Visokas,Visoko,bisoko,vu~isoko,wei suo ke,Високо,ヴィソコ,维索科,비소코', 43.9888900, 18.1780600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5717, 'Višegrad', 'Visegrad', 'Visegrad,Visegradas,Visenkrant,Vishegrad,Vixegrad,Vişegrad,Višegrad,Višegradas,Wiszegrad,bisyegeuladeu,vishegrad,vu~ishegurado,wei she ge lei,Βίσεγκραντ,Вишеград,ヴィシェグラード,维舍格勒,비셰그라드', 43.7826000, 19.2925600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5718, 'Vidoši', 'Vidosi', 'Vidosi,Vidoši', 43.7713900, 17.0283300, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5719, 'Velika Obarska', 'Velika Obarska', 'Obarska Velika,Velika Obarska', 44.8046100, 19.1618300, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5720, 'Velika Kladuša', 'Velika Kladusa', 'Velika Kladusa,Velika Kladusha,Velika Kladuša,Velika-Kladusha,da ke la du sha,wlyka kldwsha,wlyqh qldwsh,wylyka kladwsha,Велика Кладуша,Велика-Кладуша,וליקה קלדושה,ولیکا کلدوشا,ویلیکا کلادوشا,ヴェリカ・クラドゥシャ,大克拉杜沙', 45.1849700, 15.8057900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5721, 'Velagići', 'Velagici', 'Velagici,Velagići,wlgychy,Велагићи,ولگیچی', 44.5561800, 16.7334900, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5722, 'Varoška Rijeka', 'Varoska Rijeka', 'Varoska Rijeka,Varoška Rijeka', 45.0893600, 16.0190600, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5723, 'Vareš', 'Vares', 'Vares,Vares Grad,Varesh,Vareš,Vareš Grad,Вареш', 44.1644400, 18.3283300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5724, 'Ustikolina', 'Ustikolina', 'Ustikolina', 43.5833800, 18.7910600, 'BA', '2016-03-10', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5725, 'Ugljevik', 'Ugljevik', 'Uglevik,Uglevikas,Угљевик', 44.6636100, 19.0202800, 'BA', '2011-12-22', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5726, 'Tuzla', 'Tuzla', 'Donja Tuzla,Gorad Tuzla,Soli,TZL,Tuzl,Tuzla,to~uzura,tu ci la,tujeulla,twzla,tzla,Горад Тузла,Тузла,تزلا,تزلہ,توزلا,ტუზლა,トゥズラ,图兹拉,투즐라', 44.5384200, 18.6670900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5727, 'Turbe', 'Turbe', '', 44.2435200, 17.5749900, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5728, 'Tržačka Raštela', 'Trzacka Rastela', 'Trzacka Rastela,Tržačka Raštela', 44.9759700, 15.7848900, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5729, 'Trnovo', 'Trnovo', 'Trnovo,te er nuo wo,torunovu~o,Трново,トルノヴォ,特尔诺沃', 43.6658000, 18.4459300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5730, 'Trn', 'Trn', '', 44.8582900, 17.2358300, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5731, 'Trebinje', 'Trebinje', 'Trebigne,Trebin''e,Trebine,Trebinje,Trebinė,te lei bi nie,teulebine,torebinye,Требине,Требинье,Требиње,トレビニェ,特雷比涅,트레비네', 42.7119700, 18.3436200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5732, 'Travnik', 'Travnik', 'Traunik,Travnik,Travnikas,te la fu ni ke,teulabeunikeu,toravuniku,travnik,trawnyk,Травник,Траўнік,טראווניק,تراونیک,トラヴニク,特拉夫尼克,트라브니크', 44.2263700, 17.6658300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5733, 'Tojšići', 'Tojsici', 'Tojsici,Tojšići', 44.5013300, 18.7852300, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5734, 'Teslić', 'Teslic', 'Teslic,Teslich,Teslicius,Teslić,Tesliĉ,Tesličius,tai si li qi,Теслич,Теслић,泰斯利奇', 44.6063900, 17.8597200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5735, 'Tešanj', 'Tesanj', 'Tesanis,Tesanj,Teshan,Teshan'',Tešanis,Tešanj,tai sha ni,Тешань,Тешањ,泰沙尼', 44.6119100, 17.9855200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5736, 'Tasovčići', 'Tasovcici', 'Tasovcici,Tasovčići', 43.1133300, 17.7200000, 'BA', '2013-05-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5737, 'Svodna', 'Svodna', 'Svodna', 45.0377000, 16.5401900, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5738, 'Šumatac', 'Sumatac', '', 45.0974300, 15.8581800, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5739, 'Šturlić', 'Sturlic', 'Gradina Sturlic,Gradina Šturlić,Sturlic,Šturlić', 45.0638900, 15.7780600, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5740, 'Stupari', 'Stupari', '', 44.3138200, 18.6841600, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5741, 'Stolac', 'Stolac', 'Stolac,Stolacas,Столац', 43.0840000, 17.9599500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5742, 'Stjepan-Polje', 'Stjepan-Polje', 'Stjepan-Polje', 44.7163400, 18.2578300, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5743, 'Stijena', 'Stijena', '', 44.9363000, 16.0222400, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5744, 'Srebrenik', 'Srebrenik', 'Srebrenik,Srebrenikas,Srebrnica,Srebrnik,Сребреник', 44.7081900, 18.4883400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5745, 'Srebrenica', 'Srebrenica', 'Argentaria,Srebrenica,Srebrenicja,Srebrenitsa,Srebrnica,seulebeulenicha,si lei bu lei ni cha,srbnytsa,srbrnytsa,srybrynytsa,sureburenitsu~a,Сребреница,Сребрениця,سربرنيتسا,سربرنیتسا,سربنیتسا,سریبرینیتسا,スレブレニツァ,斯雷布雷尼察,스레브레니차', 44.1074800, 19.2966900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5746, 'Srbac', 'Srbac', 'Srbac,Srbacas,Srpac,Srpak,Svinjar,Србац', 45.0973000, 17.5233100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5747, 'Solina', 'Solina', '', 44.5622600, 18.6932200, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5748, 'Sokolac', 'Sokolac', 'Sokola,Sokolac,Sokolacas,sokollacheu,sokoratsu,Соколац,ソコラツ,소콜라츠', 43.9381700, 18.8007900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5749, 'Sladna', 'Sladna', 'Sladna', 44.7289700, 18.4257500, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5750, 'Kneževo', 'Knezevo', 'Knezevo,Kneževo,Skender Vakuf', 44.4907100, 17.3816100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5751, 'Šipovo', 'Sipovo', 'Shipovo,Sipovo,Šipovo,Шипово', 44.2823700, 17.0859700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5752, 'Šerići', 'Serici', 'Seric,Serici,Šerić,Šerići', 44.4667400, 18.5637000, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5753, 'Šekovići', 'Sekovici', 'Sejkovic,Sejkovici,Sekovici,Shekovichi,Shekovici,shekovu~ichi,Šejković,Šejkovići,Šekovići,Шековичи,Шековићи,シェコヴィチ', 44.2989600, 18.8553200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5754, 'Sarajevo', 'Sarajevo', 'Bosna-Sarai,Gorad Saraeva,SJJ,Saarayego,Saireavo,Sairéavó,Saraevo,Saraevo osh,Saragebo,Saragiebo,Saragievo,Sarajeva,Sarajevas,Sarajevo,Sarajevs,Sarajevu,Sarajevó,Sarajewo,Sarajèvo,Saraxevo,Saraybosna,Sarayevo,Sarayevu,Seraium,Serayevo,Szarajevo,Szarajevó,Vrh Bosna,carayevo,sa la re wo,sai la ye fu,salayebo,saraevo,saraevu~o,sarajyww,sarayavea,sarayebho,sarayevho,sarayevo,sarayewo,sarayh ww,sarayww,sarayyfw,srayyfw,srayyww,sryybw,Σαράγεβο,Σαράγιεβο,Σαραγιεβο,Горад Сараева,Сараево,Сараево ош,Сараєво,Сарајево,Сараѥво,Սարաևո,סאראיעווא,סרייבו,ساراجیوو,ساراييفو,سارايېۋو,سارایه وو,سارایوو,سارایێڤۆ,سرائیوو,سراييفو,सारायेव्हो,সারায়েভো,ਸਾਰਾਯੇਵੋ,சாரயேவோ,സരയാവോ,ซาราเยโว,ས་ར་ཇི་བོ།,სარაევო,ሳራዬቮ,サラエヴォ,塞拉耶佛,薩拉熱窩,사라예보', 43.8486400, 18.3564400, 'BA', '2012-11-15', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5755, 'Sapna', 'Sapna', 'Sapna,Сапна', 44.5038000, 18.9981800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5756, 'Sanski Most', 'Sanski Most', 'Sana,Sanski Most,Сански Мост', 44.7667000, 16.6670000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5757, 'Sanica', 'Sanica', 'Pravoslavna Sanica,Sanica,Саница', 44.6135400, 16.6406200, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5758, 'Rumboci', 'Rumboci', '', 43.8315400, 17.5027300, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5759, 'Rudo', 'Rudo', 'Rudo,Рудо', 43.6178100, 19.3671900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5760, 'Rogatica', 'Rogatica', 'Jelengrad,Rogatica,Rogaticja,rogatitsu~a,Рогатица,Рогатиця,ロガティツァ', 43.7989400, 19.0036300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5761, 'Rodoč', 'Rodoc', 'Rodoc,Rodoč', 43.3145300, 17.8029000, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5762, 'Ravno', 'Ravno', 'Opshtina Ravno,Ravno,la fu nuo,Општина Равно,Равно,拉夫诺', 42.8874100, 17.9655500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5763, 'Radišići', 'Radisici', 'Radisici,Radišići', 43.2230200, 17.5405600, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5764, 'Puračić', 'Puracic', 'Puracic,Puračić', 44.5456200, 18.4786500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5765, 'Novi Travnik', 'Novi Travnik', 'Novi Travnik,Novi Travnikas,Pucarevo,xin te la fu ni ke,Нови Травник,新特拉夫尼克', 44.1713300, 17.6581600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5766, 'Prozor', 'Prozor', 'Prozor', 43.8222200, 17.6091700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5767, 'Prnjavor', 'Prnjavor', '', 44.8702100, 17.6625600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5768, 'Prijedor', 'Prijedor', 'Grad Prijedor,Priedor,Priedora,Prijedor,Prijedoras,peuliyedoleu,pu li ye duo er,purii~edoru,Град Приједор,Приедор,Приедора,Прієдор,پریجیڈور,プリイェドル,普里耶多尔,프리예도르', 44.9799100, 16.7140100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5769, 'Priboj', 'Priboj', '', 44.6023300, 18.9316500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5770, 'Pribinić', 'Pribinic', '', 44.6101000, 17.6898100, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5771, 'Prača', 'Praca', '', 43.7636700, 18.7651200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5772, 'Potoci', 'Potoci', '', 44.3926100, 16.6200100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5773, 'Potoci', 'Potoci', '', 43.4095300, 17.8785500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5774, 'Posušje', 'Posusje', 'Posusje,Posušje', 43.4728100, 17.3262100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5775, 'Popovi', 'Popovi', 'Popovi', 44.7654700, 19.2866700, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5776, 'Polje-Bijela', 'Polje-Bijela', 'Donje Bjela,Polje,Polje-Bijela', 43.6329900, 17.9721600, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5777, 'Podzvizd', 'Podzvizd', '', 45.1741700, 15.8736100, 'BA', '2006-01-17', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5778, 'Podhum', 'Podhum', '', 43.7229500, 16.9988700, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5779, 'Petkovci', 'Petkovci', '', 44.4684900, 19.0746600, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5780, 'Pelagićevo', 'Pelagicevo', 'Gornji Zabar,Gornji Žabar,Pelagicevo,Pelagichevo,Pelagićevo,pei la ji qie wo,Пелагичево,Пелагићево,佩拉吉切沃', 44.9010500, 18.5918500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5781, 'Pećigrad', 'Pecigrad', 'Pecigrad,Pećigrad', 45.0544400, 15.8969400, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5782, 'Peći', 'Peci', 'Peci,Peći', 44.6313900, 16.7825000, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5783, 'Pazarić', 'Pazaric', 'Pazaric,Pazarić', 43.7888200, 18.1604900, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5784, 'Pale', 'Pale', 'Pale,Pale i Bosnia-Hercegovina,Palė,pa lai,palle,pare,Пале,پالے، بوسنیا و ہرزیگووینا,パレ,帕莱,팔레', 43.8166400, 18.5694900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5785, 'Otoka', 'Otoka', 'Otoka', 44.9600000, 16.1791700, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5786, 'Ostrožac', 'Ostrozac', 'Ostrazac,Ostražac,Ostrozac,Ostrožac', 44.9086600, 15.9404500, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5787, 'Oštra Luka', 'Ostra Luka', '', 44.9972400, 18.5846400, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5788, 'Oštra Luka', 'Ostra Luka', 'Opshtina Oshtra Luka,Ostra Luka,Oštra Luka,Општина Оштра Лука', 44.8602700, 16.6606900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5789, 'Osmaci', 'Osmaci', 'Osmaci,Osmak', 44.4015900, 18.9163800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5790, 'Orguz', 'Orguz', 'Orguz', 43.7741400, 16.8632900, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5791, 'Orašje', 'Orasje', 'Orasje,Orašje', 45.0336600, 18.6933400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5792, 'Orašac', 'Orasac', '', 44.6303900, 16.0744300, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5793, 'Orahovica Donja', 'Orahovica Donja', 'Donja Orahovica,Orahovica Donja,Orakhovica Dona,Ораховица Доња', 44.6534500, 18.3695100, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5794, 'Omarska', 'Omarska', 'Omarska,Омарска', 44.8917000, 16.8981400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5795, 'Omanjska', 'Omanjska', '', 44.6983100, 17.9575700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5796, 'Olovo', 'Olovo', 'Olovo,Олово', 44.1277000, 18.5806500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5797, 'Odžak', 'Odzak', 'Odzak,Odzakas,Odzhak,Odžak,Odžakas,Opcina Odzak,Općina Odžak,Vukosavlje,awzhak,ojaku,Оджак,Оџак,اوژاک,オジャク', 45.0246100, 18.3210700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5798, 'Obudovac', 'Obudovac', 'Obudovac', 44.9521500, 18.5986900, 'BA', '2016-03-10', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5799, 'Novo Selo', 'Novo Selo', 'Novo Selo', 44.0800700, 17.1555600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5800, 'Novi Šeher', 'Novi Seher', 'Novi Seher,Novi Šeher', 44.5103100, 18.0262400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5801, 'Nevesinje', 'Nevesinje', 'Nevesinje', 43.2586100, 18.1133300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5802, 'Neum', 'Neum', 'Neum,Portus Noumensis,ne-um,neumu,nie mu,Неум,נאום,ネウム,涅姆,네움', 42.9233300, 17.6155600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5803, 'Mrkonjić Grad', 'Mrkonjic Grad', 'Mrkonic Grad,Mrkonich-Grad,Mrkonjic Grad,Mrkonjić Grad,Murkonich grad,Varcar Vakuf,mrqwnyyz grʼd,Мрконич-Град,Мркоњић Град,Мърконич град,מרקונייץ גראד,ムルコニチ・グラード', 44.4172900, 17.0828800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5804, 'Mramor', 'Mramor', '', 44.5923400, 18.5645800, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5805, 'Mostar', 'Mostar', 'Mandetrium,Mostar,Mostara,Mostaras,Mostari,OMO,mo si ta er,moseutaleu,mosutaru,mwstar,mwstr,Μόσταρ,Мостар,מוסטר,موستار,モスタル,莫斯塔爾,모스타르', 43.3433300, 17.8080600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5806, 'Mionica', 'Mionica', 'Donja Mionica,Mionica,Mionica Donja', 44.8664600, 18.4660300, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5807, 'Milići', 'Milici', 'Milici,Milići', 44.1701600, 19.0919500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5808, 'Matuzići', 'Matuzici', 'Matuzici,Matuzići', 44.6877600, 18.0488500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5809, 'Maslovare', 'Maslovare', 'Maslovare,Mastovare', 44.5659400, 17.5321600, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5810, 'Marićka', 'Maricka', '', 44.8680100, 16.8551000, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5811, 'Mala Kladuša', 'Mala Kladusa', '', 45.1344300, 15.8521700, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5812, 'Mahala', 'Mahala', 'Mahala', 44.0119400, 18.2552800, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5813, 'Maglajani', 'Maglajani', 'Bosanski Aleksandrovac,Maglajani', 44.9497500, 17.3501400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5814, 'Maglaj', 'Maglaj', 'Maglaj,Maglajus,Маглај', 44.5477100, 18.1000300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5815, 'Lukavica', 'Lukavica', 'Lukavica', 44.7645200, 18.1688700, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5816, 'Lukavica', 'Lukavica', 'Lukavica,Srpsko Sarajevo', 43.8269300, 18.3831800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5817, 'Lukavac', 'Lukavac', 'Lukavac,Lukavac Muslimanski,Lukavacas,Muslimanski Lukavac,lu ka wa ci,Лукавац,盧卡瓦茨', 44.5424500, 18.5261800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5818, 'Lopare', 'Lopare', 'Lopare,luo pa lei,Лопаре,洛帕雷', 44.6349800, 18.8434000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5819, 'Lokvine', 'Lokvine', 'Lokrine,Lokvine', 44.2046600, 17.8566500, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5820, 'Ljubuški', 'Ljubuski', 'Liubuskai,Liubuškai,Ljubushki,Ljubuski,Ljubuški,liu bu shen ji,Љубушки,Любушки,柳布什基', 43.1969400, 17.5450000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5821, 'Ljubinje', 'Ljubinje', 'Ljubine,Ljubinje,Љубиње', 42.9512000, 18.0870200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5822, 'Livno', 'Livno', 'Cleuna,Livnas,Livno,li fu nuo,libeuno,livno,rivuno,Ливно,Лівно,リヴノ,利夫諾,리브노', 43.8269500, 17.0074600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5823, 'Široki Brijeg', 'Siroki Brijeg', 'Collis Amplus,Listica,Lištica,Shiroki Brieg,Shiroki Brijeg,Siroki Brijeg,Siroki Brijegas,shyrwky bryg,shyrwky bryyg,silokibeuliyegeu,Široki Brijeg,Široki Brijegas,Широки Бриег,Широки Бријег,Широкі Брієг,شیروکی بریئگ,شیروکی بریگ,シロキ・ブリイェグ,시로키브리예그', 43.3829000, 17.5941600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5824, 'Laktaši', 'Laktasi', 'Banja Laktasi,Banja Laktaši,Laktasai,Laktashi,Laktasi,Laktasi Ilidza,Laktašai,Laktaši,Laktaši Ilidža,la ke ta xi,Лакташи,拉克塔希', 44.9085700, 17.3013500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5825, 'Kupres', 'Kupres', 'Kupres,Купрес', 43.9927300, 17.2763900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5826, 'Krupa na Vrbasu', 'Krupa na Vrbasu', 'Krupa,Krupa na Vrbasu,Krupa-Na-Vrbasu,Vrbas,Крупа-На-Врбасу', 44.6187500, 17.1435100, 'BA', '2015-11-08', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5827, 'Teočak', 'Teocak', 'Krstac,Teocak,Teočak', 44.6032100, 18.9796700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5828, 'Kreševo', 'Kresevo', 'Kresevo,Kreshevo,Kreševo,Крешево', 43.8655600, 18.0433300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5829, 'Kotor Varoš', 'Kotor Varos', '', 44.6183100, 17.3720400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5830, 'Kopači', 'Kopaci', '', 43.6783300, 19.0284500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5831, 'Kočerin', 'Kocerin', 'Kocerin,Kocherin,Kočerin,Кочерин', 43.3900500, 17.4855200, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5832, 'Kobilja Glava', 'Kobilja Glava', 'Kobilja Glava', 43.8818800, 18.3886400, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5833, 'Klokotnica', 'Klokotnica', '', 44.7329000, 18.1888400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5834, 'Ključ', 'Kljuc', 'Kljuc,Ključ,Kluch,ke liu qi,kuryuchi,Кључ,クリュチ,克柳奇', 44.5325100, 16.7768200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5835, 'Kladanj', 'Kladanj', 'Kladan'',Kladanj,Opshtina Kladan,kuradani,Кладань,Општина Кладањ,クラダニ', 44.2266900, 18.6927400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5836, 'Kiseljak', 'Kiseljak', 'Kiseljak', 44.4890400, 18.5698200, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5837, 'Kiseljak', 'Kiseljak', 'Kiselak,Kiseliakas,Kiseljak,ji sai er ya ke,kiseryaku,Кисељак,キセリャク,基塞爾雅克', 43.9429500, 18.0813200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5838, 'Karadaglije', 'Karadaglije', '', 44.5706500, 18.0177500, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5839, 'Kalinovik', 'Kalinovik', 'Kalinovik,Калиновик', 43.5046400, 18.4464900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5840, 'Kalesija', 'Kalesija', '', 44.4376500, 18.9071300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5841, 'Kalenderovci Donji', 'Kalenderovci Donji', 'Kalenderovci Doni,Kalenderovci Donji,Kalenderovci-Doni,Календеровци Доњи,Календеровци-Дони', 44.9467300, 17.8378500, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5842, 'Kakanj', 'Kakanj', 'Kakan,Kakanis,Kakanj,ka ka ni,Какањ,卡卡尼', 44.1331100, 18.1229200, 'BA', '2017-05-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5843, 'Jezerski', 'Jezerski', 'Jezerski,Jezersko', 44.9817200, 16.0944700, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5844, 'Jezero', 'Jezero', 'Jakovljevici,Jakovljevići,Jezero', 44.3495400, 17.1688000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5845, 'Janja', 'Janja', 'Janja', 44.6655400, 19.2469100, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5846, 'Jajce', 'Jajce', 'Gorad Jajceh,Iaicia,Jaice,Jaicė,Jajca,Jajce,ya yi cai,yaiche,yaitsu~e,Јајце,Горад Яйцэ,Яйце,יאיצה,ヤイツェ,亞伊采,야이체', 44.3420300, 17.2705900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5847, 'Izačić', 'Izacic', 'Izacic,Izacic Grad,Izačić,Izačić Grad', 44.8748500, 15.7825600, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5848, 'Ilijaš', 'Ilijas', 'Ilias,Iliaš,Ilijas,Ilijash,Ilijaš,iriyashu,Илијаш,イリヤシュ', 43.9512800, 18.2712800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5849, 'Ilidža', 'Ilidza', 'Ilide,Ilidja,Ilidza,Ilidze,Ilidzha,Ilidža,Ilidže,Iliđe,irija,yi li zha,Илиджа,Илиџа,イリジャ,伊利扎', 43.8293900, 18.3000300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5850, 'Hreša', 'Hresa', 'Hresa,Hreša', 43.8780000, 18.4969900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5851, 'Han Pijesak', 'Han Pijesak', 'Han Pijesak', 44.0816100, 18.9525800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5852, 'Hadžići', 'Hadzici', 'Hadzici,Hadziciai,Hadžići,Hadžičiai,Khadzici,hajichi,Хаџићи,ハジチ', 43.8222200, 18.2066700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5853, 'Grude', 'Grude', 'Grude', 43.3720800, 17.4144900, 'BA', '2017-07-18', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5854, 'Gromiljak', 'Gromiljak', 'Gromiljak', 43.9666800, 18.0550400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5855, 'Gradačac', 'Gradacac', 'Gradacac,Gradacacas,Gradachac,Gradačac,Gradačacas,ge la da cha ci,guradachatsu,Градачац,グラダチャツ,格拉達查茨', 44.8785100, 18.4276400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5856, 'Gračanica', 'Gracanica', 'Gracanica,Grachanica,Gračanica,ge la cha ni cha,grachanytsa  bwsny w hrzgwyn,Грачаница,گراچانیتسا، بوسنی و هرزگوین,گراچانیسا، بوسنیا و ہرزیگووینا,格拉查尼察', 44.7030700, 18.3101000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5857, 'Gračanica', 'Gracanica', '', 43.7333300, 18.2833300, 'BA', '2007-05-30', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5858, 'Gostovići', 'Gostovici', 'Gostovic,Gostovici,Gostović,Gostovići', 44.4112400, 18.1702900, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5859, 'Gornji Vakuf', 'Gornji Vakuf', 'Gornji Vakuf,Uskoplje,Vakuf Gornji', 43.9380600, 17.5883300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5860, 'Gornji Ribnik', 'Gornji Ribnik', 'Gorni Ribnik,Gorni-Ribnik,Gornji Ribnik,Ribnik Gornji,Горни-Рибник,Горњи Рибник', 44.4175200, 16.8169000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5861, 'Gornje Živinice', 'Gornje Zivinice', 'Gornje Zivinice,Gornje Živinice,Muslimanske Zivinice,Muslimanske Živinice,Zivinice Gornje,Živinice Gornje', 44.4292100, 18.6166700, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5862, 'Gornje Moštre', 'Gornje Mostre', 'Gornje Mostre,Gornje Moštre,Mostre Gornje,Moštre Gornje', 44.0191100, 18.1547700, 'BA', '2012-10-07', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5863, 'Gornja Tuzla', 'Gornja Tuzla', 'Gornja Tuzla', 44.5565900, 18.7615900, 'BA', '2016-03-10', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5864, 'Gornja Koprivna', 'Gornja Koprivna', 'Gornja Koprivna', 45.0109100, 15.9548700, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5865, 'Goražde', 'Gorazde', 'Gorajde,Gorazde,Gorazhda,Gorazhde,Goražde,Goraždė,ge la ri dai,golajude,gorajude,grazhdh,Горажде,گراژده,ゴラジュデ,戈拉日代,고라주데', 43.6679500, 18.9756400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5866, 'Gnojnica', 'Gnojnica', '', 44.6205800, 18.4468400, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5867, 'Glamoč', 'Glamoc', 'Glamoc,Glamoch,Glamoč,Гламоч', 44.0458300, 16.8486100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5868, 'Gacko', 'Gacko', 'Gackas,Gacko,gatsuko,Гацко,ガツコ', 43.1672200, 18.5352800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5869, 'Fojnica', 'Fojnica', 'Fojnica,fwynchh,فوینچه', 43.9595200, 17.9028800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5870, 'Foča', 'Foca', 'Foca,Focha,Foça,Foča,Srbinje,focha,fu cha,pocha,Фоча,フォチャ,福查,포차', 43.5064600, 18.7785400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5871, 'Tomislavgrad', 'Tomislavgrad', 'Duvno,Tomislavgrad,Zupanjac,Županjac,Томиславград,Томіславград', 43.7184900, 17.2251500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5872, 'Dubravica', 'Dubravica', '', 44.4413100, 18.1188300, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5873, 'Dubrave Gornje', 'Dubrave Gornje', 'Dubrave Gornje,Gornje Dubrave', 44.4722900, 18.7268500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5874, 'Dubrave Donje', 'Dubrave Donje', 'Donje Dubrave,Dubrave Donje', 44.4806000, 18.6970900, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5875, 'Drvar', 'Drvar', 'Drvar,Durvar,Titov Drvar,Дрвар,Дървар', 44.3738900, 16.3808300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5876, 'Drinovci', 'Drinovci', 'Drinovcai,Drinovci,Дриновци', 43.3545400, 17.3253600, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5877, 'Drinić', 'Drinic', 'Drinic,Drinici,Drinić,Drinići', 44.5067100, 16.4669900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5878, 'Donji Žabar', 'Donji Zabar', 'Donji Zabar,Donji Žabar', 44.9431700, 18.6467300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5879, 'Donji Vakuf', 'Donji Vakuf', 'Don''i-Vakuf,Doni Vakuf,Donji Vakuf,Srbobran,Доньи-Вакуф,Доњи Вакуф,ドニ・ヴァクフ', 44.1436100, 17.4000000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5880, 'Donji Dubovik', 'Donji Dubovik', 'Alibegov Dubovik,Donji Dubovik', 44.8902100, 16.3251000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5881, 'Donja Međiđa', 'Donja Medida', 'Donja Mededa,Donja Medida,Donja Medjedja,Donja Medjidja,Donja Međeđa,Donja Međiđa', 44.8023500, 18.4047700, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5882, 'Donja Mahala', 'Donja Mahala', 'Donja Mahala', 45.0432700, 18.6699600, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5883, 'Donja Dubica', 'Donja Dubica', '', 45.0755900, 18.4102300, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5884, 'Domaljevac', 'Domaljevac', 'Domaljevac,Gornji Domaljevac', 45.0611000, 18.5861200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5885, 'Dobrljin', 'Dobrljin', 'Dobrlin,Dobrljin', 45.1510600, 16.4786900, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5886, 'Dobrinje', 'Dobrinje', '', 44.0500800, 18.1195800, 'BA', '2012-10-07', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5887, 'Doboj', 'Doboj', 'Doboj,Dobojus,doboi,duo bo yi,dwbwj,Добой,Добој,دوبوج,ドボイ,多博伊,도보이', 44.7317900, 18.0869800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5888, 'Divičani', 'Divicani', 'Divicani,Divichani,Divičani,Дивичани', 44.3668200, 17.3267800, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5889, 'Derventa', 'Derventa', 'Derbend,Dervent,Derventa,dai er wen ta,deruvu~enta,drbnd,Дервента,دربند,デルヴェンタ,代爾文塔', 44.9783900, 17.9077900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5890, 'Čitluk', 'Citluk', 'Aequum,Chitluk,Citluk,Citlukas,Opshtina Chitluk,qi te lu ke,Čitluk,Čitlukas,Општина Читлук,Читлук,契特卢克', 43.2286100, 17.7008300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5891, 'Cim', 'Cim', '', 43.3540100, 17.7804500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5892, 'Čelinac', 'Celinac', 'Celinac,Celinac Donji,Donji Celinac,Donji Čelinac,Muslimlanski Celinac,Muslimlanski Čelinac,Čelinac,Čelinac Donji', 44.7399800, 17.3188100, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5893, 'Čelić', 'Celic', 'Celic,Čelić', 44.7252400, 18.8147400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5894, 'Čečava', 'Cecava', 'Cecava,Chechava,Čečava,Чечава', 44.6796100, 17.7578000, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5895, 'Cazin', 'Cazin', 'Cazin,Cazinas,cha jin,tsu~ajin,Цазин,ツァジン,察津', 44.9669400, 15.9430600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5896, 'Čapljina', 'Capljina', '', 43.1213900, 17.6844400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5897, 'Čajniče', 'Cajnice', 'Cajnice,Čajniče', 43.5571200, 19.0718600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5898, 'Bužim', 'Buzim', 'Buzim,Bužim', 45.0536100, 16.0325400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5899, 'Busovača', 'Busovaca', 'Busovaca,Busovača', 44.0976900, 17.8783000, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5900, 'Bugojno', 'Bugojno', 'Bugoinas,Bugojne,Bugojno,Bugoyno,bugoino,Бугойно,Бугојно,Բուգոյնո,ブゴイノ', 44.0572200, 17.4508300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5901, 'Bronzani Majdan', 'Bronzani Majdan', 'Bronzani Majdan', 44.7923700, 16.9403900, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5902, 'Brka', 'Brka', 'Brka', 44.8283700, 18.7242000, 'BA', '2016-03-10', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5903, 'Breza', 'Breza', 'Breza,bu lei zha,Бреза,布雷扎', 44.0186200, 18.2606300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5904, 'Brčko', 'Brcko', 'Bercka,Brchko,Brckas,Brcko,Brczko,Breucus,Bruchko,Brčkas,Brčko,Bërçka,beuleuchiko,brchkw,brkw,brtshkw,brzqw,bu er qi ke,buruchiko,Брчко,Бръчко,ברצקו,برتشكو,برچکو,برکو,ブルチコ,布尔奇科,브르치코', 44.8699500, 18.8101200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5905, 'Bratunac', 'Bratunac', 'Bratinac,Bratunac', 44.1845500, 19.3308500, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5906, 'Petrovo', 'Petrovo', 'Bosansko Petrovo Selo,Petrovo', 44.6280400, 18.3532300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5907, 'Bosansko Grahovo', 'Bosansko Grahovo', 'Bosansko Grahovo,Bosansko Grakhovo,Bosansko Graxovo,Bosansko-Grakhovo,Grahovo,Hrvatsko Grahovo,Босанско Грахово,Босанско-Грахово,Босанско-Ґрахово,Բոսանսկո Գրախովո', 44.1794400, 16.3638900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5908, 'Šamac', 'Samac', 'Bosanski Samac,Bosanski Shamac,Bosanski Šamac,Samac,Shamac,Šamac,Босански Шамац,Шамац', 45.0598700, 18.4675600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5909, 'Bosanski Petrovac', 'Bosanski Petrovac', 'Bosanski Petrovac,Petrovac,bo si ni ya bi de luo wa ci,Босански Петровац,Բոսանսկի Պետրովաց,ボサンスキ・ペトロヴァツ,波斯尼亞彼得羅瓦茨', 44.5553700, 16.3689700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5910, 'Novi Grad', 'Novi Grad', 'Bosanski Novi,Novi,Novi Grad', 45.0464300, 16.3778200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5911, 'Brod', 'Brod', 'Bosanski Brod,Brod,Brodas,Srpski Brod,bu luo de,burodo,Брод,ブロド,布罗德', 45.1374700, 17.9872200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5912, 'Bosanska Krupa', 'Bosanska Krupa', 'Bosanska Krupa,Krupa,Krupa na Uni,bo si ni ya ke lu pa,Босанска Крупа,ボサンスカ・クルパ,波斯尼亞克魯帕', 44.8825000, 16.1513900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5913, 'Kostajnica', 'Kostajnica', 'Bosanska Kostajnica,Kostajnica,Srpska Kostajnica', 45.2195600, 16.5392900, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5914, 'Gradiška', 'Gradiska', 'Bosanska Gradishka,Bosanska Gradiska,Bosanska Gradiška,Gradiska,Gradiska na Savi,Gradiška,Gradiška na Savi,Босанска Градишка', 45.1448400, 17.2545300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5915, 'Kozarska Dubica', 'Kozarska Dubica', 'Bosanska Dubica,Dubica,Dubicza,Kozarska Dubica,Kozarska-Dubica,bo si ni ya du bi cha,Козарска Дубица,Козарска-Дубица,دوبیسا، بوسنیا-ہرزیگووینا,ボサンスカ・ドゥビツァ,波斯尼亞杜比察', 45.1766700, 16.8094400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5916, 'Blatnica', 'Blatnica', '', 44.4867700, 17.8227800, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5917, 'Blagaj', 'Blagaj', 'Blagaj', 43.2582200, 17.8897000, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5918, 'Bileća', 'Bileca', 'Bileca,Bilece,Bilecha,Bilegja,Bileća,Bileće,bylzh,Билеча,Билећа,Բիլեչա,בילצה', 42.8764500, 18.4296700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5919, 'Bila', 'Bila', '', 43.7826500, 16.9267600, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5920, 'Bijeljina', 'Bijeljina', 'Beline,Bielina,Bieline,Bijelina,Bijeljina,bi ye li na,bielina,bii~erina,biyellina,bjljyna,blnh,byh lyna,byylynh,Биелина,Биелине,Бијељина,Бієліна,Բիելինա,ביילינה,بجلجینا,بلنه,بيه لينا,بیه‌لینا,بیےلینا,ბიელინა,ビイェリナ,比耶利納,비옐리나', 44.7587400, 19.2143700, 'BA', '2017-05-08', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5921, 'Bihać', 'Bihac', 'Bichacas,Bichačas,Bihac,Bihacium,Bihacs,Bihaç,Bihać,Bihács,Bikhach,Bikhak,bi ha qi,bi hach,bihachi,byhach,byhʼz,bykhach,bykhatsh,Бихач,Бихаћ,Бихаќ,Біхач,ביחאץ,بيخاتش,بیخاچ,بیهاچ,بیہاج,บีฮาช,ビハチ,比哈奇,비하치', 44.8169400, 15.8708300, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5922, 'Berkovići', 'Berkovici', 'Berkovici,Berkovići', 43.0947200, 18.1702800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5923, 'Banovići', 'Banovici', 'Banovic,Banovichi,Banovici,Banoviciai,Banoviki,Banović,Banovići,Banovičiai,Litva,Stara Litva,ba nuo wei qi,banovu~ichi,Бановичи,Бановићи,Бановиќи,Բանովիչի,バノヴィチ,巴諾維契', 44.4059600, 18.5264800, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5924, 'Banja Luka', 'Banja Luka', 'BNX,Bagnaluka,Bana Luka,Bania Louka,Bania Luka,Banialuca,Banja Luka,Banja Luka - Bana Luka,Banja Luka - Бања Лука,Banja-Luka,Banja-Lukae,Banjaluka,Banjaluko,Banya Luka,Baņa Luka,Gorad Banja-Luka,ba ni ya lu ka,ban ya luk a,banja luka,banja lwka,banya lwka,banyaluka,Μπάνια Λούκα,Баня Лука,Баня-Лукæ,Баня-Лука,Банꙗ Лоука,Бања Лука,Горад Баня-Лука,Բանյա Լուկա,באניה לוקה,بانجا لوکا,بانيا لوكا,بانیا لوکا,बंजा लुका,บันยาลูกา,ბანია-ლუკა,バニャ・ルカ,巴尼亚卢卡,바냐루카', 44.7784200, 17.1938600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5925, 'Balatun', 'Balatun', 'Balatun', 44.8633200, 19.3393100, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5926, 'Koran', 'Koran', '', 43.8103800, 18.5699900, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5927, 'Jelah', 'Jelah', 'Jelah', 44.6540000, 17.9589700, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5928, 'Stanari', 'Stanari', 'Stanari,Станари', 44.7447500, 17.8271400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5929, 'Dobratići', 'Dobratici', 'Dobratici,Dobratići,Dobretici,Dobretići', 44.3779200, 17.4142600, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5930, 'Podbrdo', 'Podbrdo', '', 44.4418900, 17.0149500, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5931, 'Malešići', 'Malesici', 'Malesici,Malešići', 44.7382400, 18.2733500, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5932, 'Svojat', 'Svojat', '', 44.3954800, 18.7384900, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5933, 'Dvorovi', 'Dvorovi', 'Dvorovi', 44.8075300, 19.2599900, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5934, 'Knežica', 'Knezica', 'Knezica,Knežica', 45.1054800, 16.6766800, 'BA', '2012-02-28', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5935, 'Pjanići', 'Pjanici', 'Pjanici,Pjanići', 44.9856800, 15.8230400, 'BA', '2012-08-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5936, 'Polje', 'Polje', '', 43.8801400, 18.0745200, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5937, 'Ilići', 'Ilici', 'Ilici,Ilići', 43.3476500, 17.7684800, 'BA', '2013-04-04', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5938, 'Careva Ćuprija', 'Careva Cuprija', '', 44.2663000, 18.4296100, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5939, 'Starcevica', 'Starcevica', '', 44.7570800, 17.2117800, 'BA', '2012-07-12', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5940, 'Čelinac', 'Celinac', 'Celinac,Čelinac', 44.7245300, 17.3243100, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5941, 'Hiseti', 'Hiseti', 'Kocicev Vijenac,Kočićev Vijenac', 44.7611100, 17.1794400, 'BA', '2011-06-12', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5942, 'Piskavica', 'Piskavica', '', 44.8671700, 16.9746400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5943, 'Lamovita', 'Lamovita', '', 44.9201800, 16.8993300, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5944, 'Tešanjka', 'Tesanjka', '', 44.6722800, 18.0110900, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5945, 'Kovači', 'Kovaci', '', 44.4487400, 18.2052100, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5946, 'Liješnica', 'Lijesnica', 'Lijesnica,Liješnica', 44.4949700, 18.0764400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5947, 'Ćoralići', 'Coralici', '', 45.0069400, 15.8719400, 'BA', '2006-01-17', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5948, 'Crnići', 'Crnici', '', 43.1315600, 17.8645200, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5949, 'Barice', 'Barice', '', 44.5406500, 18.4806900, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5950, 'Hotonj', 'Hotonj', 'Hotonj', 43.8934100, 18.3775100, 'BA', '2012-04-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5951, 'Ustikolina', 'Ustikolina', 'Ustikolina', 43.5956400, 18.7832400, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5952, 'Skokovi', 'Skokovi', 'Skokovi', 45.0313900, 15.9144400, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5953, 'Drežnica', 'Dreznica', '', 43.5289100, 17.2812000, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5954, 'Kačuni', 'Kacuni', 'Kacuni,Kačuni', 44.0643300, 17.9389400, 'BA', '2012-05-06', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5955, 'Pajić Polje', 'Pajic Polje', 'Pajic Polje,Pajić Polje', 43.9758300, 17.5275000, 'BA', '2012-01-19', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5956, 'Gornja Breza', 'Gornja Breza', 'Breza,Gornja Breza', 44.0375800, 18.2456400, 'BA', '2012-10-07', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5957, 'Todorovo', 'Todorovo', '', 45.0883300, 15.9308300, 'BA', '2006-01-17', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5958, 'Konjic', 'Konjic', 'Konjic', 43.6512600, 17.9608200, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5959, 'Jablanica', 'Jablanica', 'Jablanica,ya bu la ni cha,Јабланица,Ябланица,جبلانیکا، بوسنیا و ہرزیگووینا,亞布拉尼察', 43.6602800, 17.7616700, 'BA', '2016-06-05', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5960, 'Bijela', 'Bijela', 'Bijela', 43.6087100, 17.9507800, 'BA', '2012-02-29', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(5961, 'Mejdan - Obilićevo', 'Mejdan - Obilicevo', '', 44.7632400, 17.1901200, 'BA', '2012-06-30', 29);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6129, 'Walhain-Saint-Paul', 'Walhain-Saint-Paul', 'Walhain (Walhain-Saint-Paul)', 50.6262700, 4.6983700, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6130, 'Walcourt', 'Walcourt', 'Val''kur,Valkur,Walcou,Walcourt,Walcoû,wa er ku er,wlkwr,Валкур,Валькур,ولکور,瓦尔库尔', 50.2540100, 4.4379600, 'BE', '2011-07-19', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6131, 'Waimes', 'Waimes', 'Waimes,Weismes', 50.4148800, 6.1120700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6132, 'Wachtebeke', 'Wachtebeke', 'Wachtebeke', 51.1685200, 3.8718300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6133, 'Waasmunster', 'Waasmunster', 'Waasmunster,Waesmunster', 51.1057200, 4.0857300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6134, 'Waarschoot', 'Waarschoot', 'Waarschoot,Waerschoot', 51.1525000, 3.6050000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6135, 'Vosselaar', 'Vosselaar', 'Vosselaar,Vosselaer', 51.3085600, 4.8896000, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6136, 'Vorselaar', 'Vorselaar', 'Vorselaar,Vorsselaer', 51.2024300, 4.7725900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6137, 'Visé', 'Vise', 'Vise,Visé,Wezet', 50.7376000, 5.6990700, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6138, 'Virton', 'Virton', 'Vierton,Virton,Wirten,bileutong,vu~iruton,wei er tong,wyrtn,Виртон,Վիրտոն,ویرتن,ヴィルトン,维尔通,비르통', 49.5682400, 5.5325900, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6139, 'Vilvoorde', 'Vilvoorde', 'Vilvoorde,Vilvorde,Vilvordė,fei er fu er de,wylwwrd,Вилворде,Вілворде,ویلوورد,菲尔福尔德', 50.9281400, 4.4293800, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6140, 'Villers-le-Bouillet', 'Villers-le-Bouillet', 'Vijers l''o Buje,Viller-le-Buje,Villers-le-Bouillet,wei lai er si lei bu ye,wyh-lw-bwyh,Вийерс льо Буйе,Виллер-ле-Буйе,ویه-لو-بویه,维莱尔斯勒布耶', 50.5770800, 5.2594500, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6141, 'Villers-la-Ville', 'Villers-la-Ville', 'Villers-la-Ville', 50.5666700, 4.5166700, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6142, 'Vielsalm', 'Vielsalm', 'Li Viye Sam,Li Viye Såm,V''el''sal''m,Vielsalm,wei er sa mu,wylslm,Виелсалм,Вьельсальм,ویلسلم,维尔萨姆', 50.2840700, 5.9150200, 'BE', '2012-01-30', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6143, 'Veurne', 'Veurne', 'Furna,Furnes,V''orne,Veurn,Veurne,fu er nei,wrn,Вьорне,ورن,弗尔内', 51.0731600, 2.6680300, 'BE', '2013-11-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6144, 'Verviers', 'Verviers', 'Verv''e,Verve,Vervi,Vervia,Vervie,Verviers,Vervje,Vervjė,Vervî,beleubie,vervie,vu~eruvu~ie,wei er wei ye,wrwyh,Вервие,Вервье,Вервє,Вервје,ورویه,ვერვიე,ヴェルヴィエ,韦尔维耶,베르비에', 50.5890700, 5.8624100, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6145, 'Verlaine', 'Verlaine', 'Verlaine', 50.6074300, 5.3174000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6146, 'Vaux-sur-Sûre', 'Vaux-sur-Sure', 'Li Va-so-Seure,Li Vå-so-Seure,Vaux-sur-Sure,Vaux-sur-Sûre,Vo sjur Sjur,Vo-sjur-Sjur,ww-swr-swr,xu er he pan wo,Во сюр Сюр,Во-сюр-Сюр,وو-سور-سور,叙尔河畔沃', 49.9110000, 5.5784800, 'BE', '2011-10-19', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6147, 'Turnhout', 'Turnhout', 'T''ornkhaut,Tjurnkhaut,Turnaut,Turnholtum,Turnhout,Turnkhout,di lun hao te,to~urunhauto,twileunhauteu,twrnhawt,twrnw,Турнаут,Турнхоут,Тьорнхаут,Тюрнхаут,تورنهاوت,تورنو,トゥルンハウト,蒂伦豪特,튀른하우트', 51.3225400, 4.9447100, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6148, 'Tubize', 'Tubize', 'Tiubizas,Tjubiz,Tubeke,Tubize,di bi ci,twbyz,twibijeu,Тюбиз,توبيز,توبیز,蒂比兹,튀비즈', 50.6905900, 4.2009000, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6149, 'Trooz', 'Trooz', 'Li Tro,Li Trô,Troo,Trooz,Troz,te luo,trwz,Троз,Троо,تروز,特羅', 50.5702600, 5.6952100, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6150, 'Trois-Ponts', 'Trois-Ponts', 'Troa Pon,Trois Ponts,Trua-Pon,te lu wa peng,trwa-pwn,Троа Пон,Труа-Пон,تروآ-پون,特鲁瓦蓬', 50.3712800, 5.8714600, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6151, 'Tremelo', 'Tremelo', 'Tremelo,Tremeloo', 50.9923100, 4.7080700, 'BE', '2011-02-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6152, 'Tournai', 'Tournai', 'Doornik,Doornyk,Tornai,Tournai,Tournay,Turnacum,Turne,Turnė,ZGQ,to~urune,tu er nai,tuleune,twrnay,twrnh,Τουρναί,Турне,טורנה,تورناي,تورنه,ตูร์แน,トゥルネー,图尔奈,투르네', 50.6071500, 3.3893200, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6153, 'Torhout', 'Torhout', 'Thourout,Toeroet,Torhout,Torkhaut,Torkhout,Turholt,trw,tuo er hao te,Торхаут,Торхоут,ترو,托尔豪特', 51.0656000, 3.1008500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6154, 'Tongeren', 'Tongeren', 'Atuatuca Tungrorum,Gorad Tongerehn,Tongere,Tongeren,Tongerenas,Tongres,Toungern,Tungro,Tóngere,tnzhran,tong e lun,tong-eleon,tongngexrein,tonheren,Горад Тонгерэн,Тонгерен,تنژران,โตงเงอเริน,トンヘレン,通厄伦,통에런', 50.7805400, 5.4648400, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6155, 'Tintigny', 'Tintigny', 'Tentin''i,Tentini,Tintigny,tan di ni,tntyny,Тентини,Тентиньи,تنتینی,坦蒂尼', 49.6832600, 5.5134900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6156, 'Tinlot', 'Tinlot', 'Tenlo,Tinlot,Tinlot vald,tan luo,tnlw,Тенло,تنلو,坦洛', 50.4749300, 5.3775500, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6157, 'Tienen', 'Tienen', 'Thenae,Thienen,Tienen,Tijnen,Tinen,Tirlemont,di nen,tyynan,Тийнен,Тинен,تیئنان,蒂嫩', 50.8074500, 4.9378000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6158, 'Tielt', 'Tielt', 'Thielt,Tielt,Tijlt,Tilt,di er te,tyylt,Тийлт,Тілт,تیئلت,蒂尔特', 50.9993100, 3.3270700, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6159, 'Thuin', 'Thuin', 'Thuin,Tjuehn,Tjuen,Twin,twyn,Тюен,Тюэн,توئن', 50.3393300, 4.2860400, 'BE', '2011-09-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6160, 'Theux', 'Theux', 'T''o,Teu,Theux,Thieux,Tjo,te zhen,tw,Тьо,Тё,تو,特镇', 50.5332300, 5.8124500, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6161, 'Tessenderlo', 'Tessenderlo', 'Loei,Tesenderlo,Tessenderlo,Tessenderloo,tai sen de luo,teseondeleullo,theis seinde xrlo,tsandrlw,Тесендерло,تساندرلو,เทิสเซินเดอร์โล,泰森德洛,테선데를로', 51.0651300, 5.0885600, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6162, 'Tervuren', 'Tervuren', 'Terv''oren,Tervjuren,Tervueren,Tervuren,te er fei lun,trwwran,Тервьорен,Тервюрен,ترووران,特尔菲伦', 50.8237200, 4.5141800, 'BE', '2011-02-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6163, 'Ternat', 'Ternat', 'Ternat,Ternath', 50.8665400, 4.1668200, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6164, 'Tenneville', 'Tenneville', 'Tenneville,Tennevillei vald,Tenvil,Tenvil'',Tiniveye,tai ne wei er,twnw wyl,Тенвил,Тенвиль,تونو ویل,泰讷维尔', 50.0950100, 5.5289500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6165, 'Temse', 'Temse', 'Tamise,Tamsch,Tamse,Temsche,Temse,tams,te mu sai,Темсе,تامس,特姆塞', 51.1279400, 4.2137200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6166, 'Tellin', 'Tellin', 'Telen,Telin,Tellen,Tellin,Tellini vald,tai lan,tln,Телен,Теллен,تلن,泰兰', 50.0803800, 5.2163800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6167, 'Stoumont', 'Stoumont', 'Staumont,Stoumont,Stumon,si tu meng,stwmwn,Стумон,ستومون,斯图蒙', 50.4066700, 5.8083800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6168, 'Stekene', 'Stekene', 'Stekene', 51.2099000, 4.0365100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6169, 'Steenokkerzeel', 'Steenokkerzeel', 'Steen-Ockerzeel,Steenokkerzeel,Stenokerzel,si teng ao ke er ze er,Стенокерзел,斯滕奥克尔泽尔', 50.9185100, 4.5098900, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6170, 'Stavelot', 'Stavelot', 'Stablo,Stavelo,Stavelot,Stavleu,Stavlo,Ståvleu,si ta wo luo,stafylw,stwwlw,Ставело,Ставло,ستافيلو,ستوولو,斯塔沃洛', 50.3950000, 5.9312400, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6171, 'Staden', 'Staden', 'Staden,Stoan,si ta deng,stdan,Стаден,ستدان,斯塔登', 50.9745600, 3.0146900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6172, 'Stabroek', 'Stabroek', 'Stabroeck,Stabroek', 51.3318900, 4.3712700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6173, 'Sprimont', 'Sprimont', 'Sprimon,Sprimont,si pu li meng,spyrmwn,Спримон,سپیرمون,斯普里蒙', 50.5092200, 5.6595000, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6174, 'Spa', 'Spa', 'Spa,Spa La Sauvehiece,Spå,Σπα,Спа', 50.4837500, 5.8667400, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6175, 'Soumagne', 'Soumagne', 'Soumagne,Soûmagne,Suman,Suman'',su ma nie,swmny,Суман,Сумань,سومنی,苏马涅', 50.6138500, 5.7467900, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6176, 'Somme-Leuze', 'Somme-Leuze', 'Som L''oz,Som-Ljoz,Some-Leuze,Somme-Leuze,suo mu-lei ci,swm-lwz,Сом Льоз,Сом-Лёз,سوم-لوز,索姆－勒兹', 50.3369900, 5.3670500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6177, 'Sombreffe', 'Sombreffe', 'Sombref,Sombrefe,Sombreffe,song bu lei fu,swmbrf,Сомбреф,سومبرف,松布雷夫', 50.5286500, 4.6008700, 'BE', '2011-03-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6178, 'Soignies', 'Soignies', 'Soani,Sougniye,Suan''e,Suan''i,Zinnik,swynyh,Соани,Суанье,Суаньи,Суаньї,سوئنیه', 50.5790400, 4.0712900, 'BE', '2010-01-29', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6179, 'Sint-Truiden', 'Sint-Truiden', 'Gorad Sankt-Trond,Oppidum Sancti Trudonis,Saint-Trond,Sent-Trueden,Sent-Trüden,Sint Treidenas,Sint Treidens,Sint Trojden,Sint Truijen,Sint-Trejden,Sint-Trjojden,Sint-Trjujden,Sint-Trond,Sint-Truiden,Sint-Truudn,Sintruin,Sinttreidena,sant trwnd,sheng te lei deng,shinto=toroiden,sint-tery dein,sinteuteulawideon,snt trwydn,Горад Санкт-Тронд,Синт Тройден,Синт Тројден,Синт-Трюйден,Синт-Трёйден,Сінт-Трейден,سانت تروند,سنت ترویدن,ซินต์-เตรยเดิน,シント＝トロイデン,圣特雷登,신트트라위던', 50.8167900, 5.1864700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6180, 'Sint-Pieters-Leeuw', 'Sint-Pieters-Leeuw', 'Ieus,Leeuw-Saint-Pierre,Sin Piters Leuv,Sint Pijters Leu,Sint-Pieters-Leeuw,Sint-Piters-Leuv,sheng bi de si-lai wu,sn-pywth-lyw,Син Питерс Леув,Синт Пийтерс Леу,Синт-Питерс-Леув,سن-پیوته-لئو,圣彼得斯-莱乌', 50.7792600, 4.2435500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6181, 'Sint-Niklaas', 'Sint-Niklaas', 'Saint-Nicolas,Sint-Niklaas,Sint-Niklas,Синт-Никлас', 51.1650900, 4.1437000, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6182, 'Sint-Martens-Lennik', 'Sint-Martens-Lennik', 'Lennick-Saint-Martin,Lennik (Sint-Martens-Lennik)', 50.8115800, 4.1696500, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6183, 'Sint-Martens-Latem', 'Sint-Martens-Latem', 'Laethem-Saint-Martin,Sint-Martens-Latem', 51.0145900, 3.6377900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6184, 'Sint-Maria-Lierde', 'Sint-Maria-Lierde', 'Lierde-Sainte-Marie,Sint-Maria-Lierde', 50.8217200, 3.8481400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6185, 'Sint-Lievens-Houtem', 'Sint-Lievens-Houtem', 'Hautem-Saint-Lievin,Hautem-Saint-Liévin,Sint Lijvens Khautem,Sint-Lievens-Houtem,Sint-Livens-Khautem,sheng li fen si-hao te mu,sn-lywwanzwtm,Синт Лийвенс Хаутем,Синт-Ливенс-Хаутем,سن-لیووانزوتم,スィント・リーヴェンス・ハウテム,圣利芬斯－豪特姆', 50.9197000, 3.8622500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6186, 'Sint-Laureins', 'Sint-Laureins', 'Saint-Laurent,Sint Laurajns,Sint-Laureins,Sint-Laurejns,sheng lao lun si,sn-lwrn,Синт Лаурайнс,Синт-Лаурейнс,سن-لورن,圣劳伦斯', 51.2420200, 3.5244100, 'BE', '2013-06-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6187, 'Sint-Kruis', 'Sint-Kruis', 'Sainte-Croix,Sint-Kruis', 51.2139900, 3.2494900, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6188, 'Sint-Katelijne-Waver', 'Sint-Katelijne-Waver', 'Sint Katelejne - Vaver,Sint Katelijne Waver,Sint-Katelijne-Waver,Sint-Kathelijne-Waver,Wavre-Sainte-Catherine,sheng ka te lai na-wa fu er,sn-ktwlyzhnwywh,Синт Кателейне - Вавер,سن-کتولیژنوئوه,圣卡特莱娜-瓦弗尔', 51.0669100, 4.5346900, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6189, 'Sint-Gillis-Waas', 'Sint-Gillis-Waas', 'Saint-Gilles-Waes,Saint-Gillis-Waas,Sint-Gillis-Waas', 51.2191400, 4.1237400, 'BE', '2014-02-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6190, 'Sint-Genesius-Rode', 'Sint-Genesius-Rode', 'Rhode-Saint-Genese,Rhode-Saint-Genèse,Sint-Genesius-Rode', 50.7464500, 4.3575400, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6191, 'Sint-Amands', 'Sint-Amands', 'Saint-Amand,Sint Amands,Sint-Amands,sheng a man ci,sn-aman,Синт Амандс,سن-امان,圣阿曼兹', 51.0564500, 4.2095700, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6192, 'Silly', 'Silly', 'Opzullik,Silly', 50.6487700, 3.9236300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6193, 'Seraing', 'Seraing', 'Seraing,Sere,Seren,Serenas,Serranius,Serè,se lan,selaeng,seran,sex ræng,srn,Серен,سرن,เซอแร็ง,セラン,瑟兰,세랭', 50.5836200, 5.5011500, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6194, 'Seneffe', 'Seneffe', 'Senef,Seneffe,swnf,Сенеф,سونف', 50.5313500, 4.2630100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6195, 'Schoten', 'Schoten', 'Schooten,Schoten,Skhoten,shwtan,si huo teng,Схотен,شوتان,斯霍滕', 51.2525100, 4.5026800, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6196, 'Schilde', 'Schilde', 'Schilde,Shil''de,Шильде', 51.2410700, 4.5833600, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6197, 'Schelle', 'Schelle', 'Schelle', 51.1261500, 4.3411400, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6198, 'Saint-Yvon', 'Saint-Yvon', 'Saint Ivon', 50.7433500, 2.9099200, 'BE', '2010-03-06', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6199, 'Saint-Vith', 'Saint-Vith', 'Saint-Vith,Sankt Vaeit,Sankt Vith,Sankt Väit,Sankt-Vith', 50.2814600, 6.1272400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6200, 'Saint-Nicolas', 'Saint-Nicolas', 'Saint-Nicolas,Sankt-Nikola,Sint-Niklaas,Санкт-Никола', 50.6283700, 5.5324300, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6201, 'Saint-Léger', 'Saint-Leger', 'Saint-Leger,Saint-Léger', 49.6119600, 5.6568800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6202, 'Saint-Hubert', 'Saint-Hubert', 'Saint-Hubert', 50.0266800, 5.3740100, 'BE', '2013-06-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6203, 'Saint-Ghislain', 'Saint-Ghislain', 'Sankt-Gilene,Sen Gislen,Sen-Gilen,sheng ji si lan,sn-gyzln,Санкт-Гилене,Сен Гислен,Сен-Гилен,سن-گیزلن,سینٹ-غصلیں,聖吉斯蘭', 50.4481600, 3.8188600, 'BE', '2010-01-29', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6204, 'Sainte-Ode', 'Sainte-Ode', 'Saint-Ode,Sainte-Ode,Sent Od,Sent-Od,sheng ao de,sntwd,Сент Од,Сент-Од,سنتود,سین-اڈے,圣奥德', 50.0172300, 5.5192600, 'BE', '2012-01-20', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6205, 'Rumst', 'Rumst', 'Rumpst,Rumst', 51.0815300, 4.4221700, 'BE', '2014-12-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6206, 'Rumes', 'Rumes', 'Rjum,Rumes,rwm,Рюм,روم', 50.5545000, 3.3053500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6207, 'Ruiselede', 'Ruiselede', 'Ruiselede,Ruysselede', 51.0403900, 3.3941600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6208, 'Rouvroy', 'Rouvroy', 'Rouvroy', 49.5377100, 5.4903100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6209, 'Rotselaar', 'Rotselaar', 'Rotselaar,Rotselaer,Rotselar,luo ce la er,rwtswlr,Ротселар,روتسولر,罗策拉尔', 50.9530200, 4.7166500, 'BE', '2011-02-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6210, 'Ronse', 'Ronse', 'Renaix,Rinais,Ronse,Rotnacum,long sai,rnz,Ронсе,رنز,龙塞', 50.7457400, 3.6005000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6211, 'Mons-lez-Liège', 'Mons-lez-Liege', '', 50.6166700, 5.4666700, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6212, 'Roeulx', 'Roeulx', '', 50.5036500, 4.1116300, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6213, 'Roeselare', 'Roeselare', 'Roeselare,Roeselare vald,Roeselave,Roeseloare,Roulers,Rouselare,Ruselare,Ruselarė,lu se la lei,lusellale,ruserare,rwslarh,Руселаре,روسلاره,ルーセラーレ,鲁瑟拉勒,루셀라레', 50.9465300, 3.1226900, 'BE', '2008-07-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6214, 'Rochefort', 'Rochefort', 'Notre-Dame-de-Foy-de-Rochefort,Roshfor,Рошфор', 50.1631000, 5.2216000, 'BE', '2016-05-12', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6215, 'Rixensart', 'Rixensart', 'Ricsinsat,Ricsinsåt,Riksansar,Riksensart,Rixensart,li ke sang sa er,ryksansr,Риксансар,Риксенсарт,ریکسانسر,里克桑萨尔', 50.7122900, 4.5252900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6216, 'Rijkevorsel', 'Rijkevorsel', 'Rijkevorsel,Ryckevorsel', 51.3479500, 4.7605300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6217, 'Riemst', 'Riemst', 'Riempst,Riemst', 50.8099500, 5.6013100, 'BE', '2011-03-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6218, 'Retie', 'Retie', 'Rethy,Retie', 51.2665200, 5.0824200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6219, 'Rendeux', 'Rendeux', 'R''ond''o,Randjo,Rendeux,Rindeu,lang de,randw,Рандё,Рьондьо,راندو,朗德', 50.2342300, 5.5041400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6220, 'Remicourt', 'Remicourt', 'Remicourt', 50.6806900, 5.3278500, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6221, 'Rebecq-Rognon', 'Rebecq-Rognon', 'Rebecq (Rebecq-Rognon)', 50.6514700, 4.1068300, 'BE', '2011-01-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6222, 'Ravels', 'Ravels', 'Raevels,Ravels', 51.3727400, 4.9921000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6223, 'Ranst', 'Ranst', 'Ranst', 51.1898300, 4.5653300, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6224, 'Ramillies', 'Ramillies', '', 50.6339500, 4.9011900, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6225, 'Raeren', 'Raeren', 'Raeren', 50.6672000, 6.1153500, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6226, 'Quiévrain', 'Quievrain', 'K''evren,Kievren,kywrn,Киеврен,Кьеврен,کیورن', 50.4073700, 3.6835100, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6227, 'Quévy-le-Petit', 'Quevy-le-Petit', '', 50.3687900, 3.9360200, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6228, 'Quaregnon', 'Quaregnon', 'Cargnon,Couargnon,Karen''on,krwnywn,Кареньон,کرونیون', 50.4406700, 3.8653000, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6229, 'Puurs', 'Puurs', 'Pjurs,Puers,Puurs,pi er si,pwr,Пюрс,پور,皮尔斯', 51.0740900, 4.2884400, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6230, 'Putte', 'Putte', 'Putte', 51.0533700, 4.6326300, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6231, 'Profondeville', 'Profondeville', 'Parfondveye,Profondeville,Profondvil,Profondvil'',prwfwndw wyl,pu luo feng de wei ye,Профондвил,Профондвиль,پروفوندو ویل,普罗丰德维耶', 50.3758100, 4.8650600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6232, 'Poperinge', 'Poperinge', 'Poperienge,Poperinge,Poperinghe,bo po ling e,pprnzh,Поперинге,پپرنژ,波珀灵厄', 50.8538600, 2.7265900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6233, 'Pont-à-Celles', 'Pont-a-Celles', 'Pont a Sel,Pont-a-Sel'',pwn-a-sl,Понт а Сел,Понт-а-Сель,پون-ا-سل', 50.5051800, 4.3688700, 'BE', '2013-05-13', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6234, 'Plombières', 'Plombieres', 'Bleyberg,Blieberg,Blieberig,Plomb''er,Plombier,Plombieres,Plombières,blwmbyyr,plwmbyr,pu long bi ai,Пломбиер,Пломбьер,بلومبيير,پلومبیر,普隆比埃', 50.7365600, 5.9592200, 'BE', '2011-03-24', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6235, 'Pittem', 'Pittem', 'Pittem,Pitthem', 50.9927900, 3.2631700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6236, 'Philippeville', 'Philippeville', 'Filippvil'',Filipvil,Flipveye,Philippeville,Phillippeville,fei li pu wei er,firippuvu~iru,pillipeubil,Филипвил,Филиппвиль,فیلیپ‌ویل,フィリップヴィル,菲利普维尔,필리프빌', 50.1961200, 4.5437400, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6237, 'Perwez', 'Perwez', 'Perve,Perwe,Perwez,Perwijs,Perwé,pei er wei,prwyh,Перве,پروئه,佩尔韦', 50.6242600, 4.8135400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6238, 'Péruwelz', 'Peruwelz', 'Perjuvel''z,Perjuvelz,Perwe-e-Hinnot,Perwé-e-Hinnot,Pierwe,Piérwé,prwwlz,Перювелз,Перювельз,پروولز', 50.5081900, 3.5937300, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6239, 'Perre', 'Perre', '', 50.8891400, 3.8609800, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6240, 'Pepinster', 'Pepinster', 'Pepenster,Pepinster,po pan si te er,pwpnsth,Пепенстер,پوپنسته,珀潘斯特尔', 50.5737500, 5.8049000, 'BE', '2011-03-24', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6241, 'Pepingen', 'Pepingen', 'Pepingen,Pepinghen', 50.7592200, 4.1598300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6242, 'Peer', 'Peer', 'Peer', 51.1303000, 5.4595200, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6243, 'Pecq', 'Pecq', 'Pecq,Pek,Pècq,pwk,Пек,پوک', 50.6861900, 3.3378900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6244, 'Paliseul', 'Paliseul', 'Palijhou,Palijhoû,Paliseul,Paliseuli vald,Paliz''ol,Palizjol'',ba li se er,plyzw,Пализьол,Пализёль,پلیزو,巴利瑟尔', 49.9039500, 5.1353700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6245, 'Overpelt', 'Overpelt', 'Overpelt,Overpeltas,Pelt,ao fu pei er te,awrplt,xo wexr phel t,Оверпелт,اورپلت,โอเวอร์เพลต์,奥弗佩尔特', 51.2103800, 5.4155700, 'BE', '2011-03-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6246, 'Overijse', 'Overijse', 'Overejse,Overijase,Overijsche,Overijse,Overyssche,ao gang lai ze,awryzhz,Оверейсе,Оверийсе,اوریژز,奥纲赖泽', 50.7743600, 4.5346100, 'BE', '2011-01-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6247, 'Oupeye', 'Oupeye', 'Oupeye,Oûpêye,Upe,Upej,awpyy,wu pei,Упе,Упей,اوپئی,乌佩', 50.7118400, 5.6468000, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6248, 'Ouffet', 'Ouffet', 'Ouffet,Ufe,Uffe,awfh,wu fei,Уфе,Уффе,اوفه,乌费', 50.4387000, 5.4657000, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6249, 'Oud-Turnhout', 'Oud-Turnhout', 'Oud-Turnhout,Vieux-Turnhout', 51.3197800, 4.9841000, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6250, 'Oud-Heverlee', 'Oud-Heverlee', 'Oud-Heverlee,Vieux-Heverle,Vieux-Héverlé', 50.8352200, 4.6642100, 'BE', '2011-02-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6251, 'Oudenburg', 'Oudenburg', 'Oednburh,Oudenburg', 51.1848900, 3.0003500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6252, 'Oudenaarde', 'Oudenaarde', 'Aldenarda,Audenaarde,Audenarde,Ontenarnt,Oudenaarde,Oudenoarde,ao de na er de,audenaleudeo,audenarude,awdnrd,Οντενάρντ,Ауденарде,Оуденаарде,اودنرد,アウデナールデ,奥德纳尔德,아우데나르더', 50.8516800, 3.6089100, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6253, 'Ottignies', 'Ottignies', 'Ottignies-Louvain-la-Neuve (Ottignies),Ottin''i,Оттиньи', 50.6653500, 4.5667900, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6254, 'Oreye', 'Oreye', 'Oerle,Ore,Orej,Oreye,ao lai,Оре,Орей,اوره‌ای,奥赖', 50.7174900, 5.3488000, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6255, 'Opwijk', 'Opwijk', 'Opwijk,Opwyck', 50.9672400, 4.1844200, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6256, 'Opglabbeek', 'Opglabbeek', 'Opglabbeek', 51.0425800, 5.5834600, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6257, 'Oostrozebeke', 'Oostrozebeke', 'Oostroosebeke,Oostroozebeke,Oostrozebeke', 50.9209300, 3.3379900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6258, 'Oostmalle', 'Oostmalle', 'Oostmalle', 51.3000000, 4.7333300, 'BE', '2015-03-16', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6259, 'Oostkamp', 'Oostkamp', 'Oostcamp,Oostkamp,Ostkamp,Oôstkamp,ao si te kan pu,awztkam,Ôostkamp,Осткамп,اوزتکام,奥斯特坎普', 51.1543200, 3.2312800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6260, 'Oosterzele', 'Oosterzele', 'Oosterzeele,Oosterzele,Osterzele,ao si te er ze lai,awztrzl,Остерзеле,اوزترزل,奥斯特尔泽莱', 50.9526100, 3.7982600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6261, 'Ostend', 'Ostend', 'OST,Oostende,Oostenn,Ostend,Ostenda,Ostende,Ostendo,Ostendė,ao si teng de,astent,awstndh,oseutendeo,osutende,Οστένδη,Остенде,אוסטנדה,اوستنده,ஆஸ்டெண்ட்,オーステンデ,奥斯滕德,오스텐더', 51.2155100, 2.9270000, 'BE', '2014-10-30', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6262, 'Onhaye', 'Onhaye', 'One,Onhaye,weng ai,Оне,عونه,翁艾', 50.2414800, 4.8406900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6263, 'Olne', 'Olne', 'Ol''n,Oln,Olne,ao er en,awln,Олн,Ольн,اولن,奥尔恩', 50.5899400, 5.7466200, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6264, 'Olen', 'Olen', 'Olen,Oolen', 51.1439100, 4.8598000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6265, 'Ohey', 'Ohey', 'Oe,Oeh,Ohe,Ohey,Ohè,ao ai,awyh,Ое,Оэ,اوئه,奥埃', 50.4357000, 5.1237500, 'BE', '2011-04-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6266, 'Noville-les-Bois', 'Noville-les-Bois', 'Noville-les-Bois', 50.5570200, 4.9846600, 'BE', '2013-06-30', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6267, 'Nivelles', 'Nivelles', 'Nijvel,Nivel,Nivel'',Nivele,Nivelles,ni wei er,nywl,Нивел,Нивель,Нівель,نیول,尼韦尔', 50.5983300, 4.3284800, 'BE', '2011-01-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6268, 'Ninove', 'Ninove', 'Ninove,Outer,ni nuo fu,nynw,Нинове,نینو,尼诺弗', 50.8277600, 4.0265700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6269, 'Nijlen', 'Nijlen', 'Nijlen,Nylen', 51.1609600, 4.6700800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6270, 'Nieuwpoort', 'Nieuwpoort', 'Nieuport,Nieuwpoort,Nieuwpoôrt,Nieuwpôort', 51.1300800, 2.7513500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6271, 'Nieuwerkerken', 'Nieuwerkerken', 'Nieuwerkerken', 50.8638000, 5.1946700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6272, 'Niel', 'Niel', 'Niel', 51.1109600, 4.3342800, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6273, 'Nevele', 'Nevele', 'Nevele', 51.0353100, 3.5457400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6274, 'Neufchâteau', 'Neufchateau', 'Neufchateau,Neufchâteau', 49.8407400, 5.4353500, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6275, 'Neerpelt', 'Neerpelt', 'Neerpelt', 51.2280700, 5.4427000, 'BE', '2011-03-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6276, 'Nazareth', 'Nazareth', 'Nazareth', 50.9568600, 3.5942500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6277, 'Nassogne', 'Nassogne', 'Nason,Nason'',Nassogne,na suo nie,nswny,Насон,Насонь,نسونی,纳索涅', 50.1284900, 5.3427400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6278, 'Nandrin', 'Nandrin', 'Nandren,Nandrin,nan de lan,nandrn,Нандрен,ناندرن,楠德兰', 50.5067500, 5.4190500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6279, 'Namur', 'Namur', 'Gorad Namjur,Name,Namen,Nameur,Namir,Namira,Namiuras,Namiūras,Namjur,Namouer,Namur,Namurcum,Namuro,Namyr,Namyur,Namīra,QNM,na mu er,namu r,namwileu,namwr,namyuru,nmwr  blzhyk,Ναμύρ,Горад Намюр,Намир,Намюр,Նամյուր,נאמור,نامور,نمور، بلژیک,นามูร์,ናሙር,ナミュール,那慕爾,나뮈르', 50.4669000, 4.8674600, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6280, 'Musson', 'Musson', 'Mjuson,Musson,Mussoni vald,mi song,mwswn,Мюсон,موسون,米松', 49.5583500, 5.7052500, 'BE', '2012-03-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6281, 'Mouscron', 'Mouscron', 'MWW,Moeschroen,Moeschroên,Moeskroen,Moucron,Mouscron,Mukronas,Musera,Muskron,Muskrono,museukeulong,musukuron,mwzkrwn,Мускрон,موزکرون,ムスクロン,무스크롱', 50.7449700, 3.2063900, 'BE', '2017-06-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6282, 'Mortsel', 'Mortsel', 'Mortensella,Mortsel,mo ce er,mrtzl,Мортсел,مرتزل,莫策尔', 51.1669700, 4.4512700, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6283, 'Morlanwelz-Mariemont', 'Morlanwelz-Mariemont', 'Morlanwelz,Morlanwelz-Mariemont', 50.4550200, 4.2451900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6284, 'Moorslede', 'Moorslede', 'Moorslede', 50.8919000, 3.0611700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6285, 'Mont-Saint-Guibert', 'Mont-Saint-Guibert', 'Mon Sen Giber,Mon-Sen-Giber,Mont-Saint-Guibert,Mont-Sint-Wubert,meng-sheng ji bei er,mwn-sn-zhybh,Мон Сен Гибер,Мон-Сен-Гибер,مون-سن-ژیبه,蒙－圣吉贝尔', 50.6342700, 4.6106100, 'BE', '2011-01-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6286, 'Mons', 'Mons', 'Berge,Bergen,Bergn,Gorad Mons,Mon,Mons,Monsa,Monsas,Mont,Montes,mamsa,meng si,mngs,mongseu,monsu,mwn,mwns,Μονς,Горад Монс,Монс,Մոնս,מונס,مون,مونس,माँस,มงส์,モンス,蒙斯,몽스', 50.4541300, 3.9522900, 'BE', '2016-03-30', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6287, 'Momignies', 'Momignies', 'Momignies', 50.0271000, 4.1651900, 'BE', '2011-10-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6288, 'Mol', 'Mol', 'Mol,Moli vald,Moll,mo er,mol,mwl,mwl  bljyka,Мол,مول,مول، بلجيكا,莫尔,몰', 51.1918800, 5.1166200, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6289, 'Moerbeke', 'Moerbeke', 'Moerbeke', 51.1740900, 3.9300100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6290, 'Modave', 'Modave', 'Modav,Modave,mo da wo,mwdw,Модав,مودو,莫达沃', 50.4461400, 5.2953200, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6291, 'Middelkerke', 'Middelkerke', 'Middelkerke,Middelkerke Bains,Middelkerke-Baden,Midelkerke,mi de er ke er ke,mydlkrk,Миделкерке,میدلکرک,米德尔克尔克', 51.1853200, 2.8207700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6292, 'Meulebeke', 'Meulebeke', 'Meulebeke', 50.9513600, 3.2880400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6293, 'Mettet', 'Mettet', 'Mete,Metet,Mettet,mei tai,mth,Мете,مته,梅泰', 50.3211900, 4.6623200, 'BE', '2011-07-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6294, 'Messancy', 'Messancy', 'Mesansi,Messanceye,Messancy,Miezeg,mei sang xi,msansy,Месанси,Месансі,مسانسی,梅桑西', 49.5920100, 5.8187900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6295, 'Merksplas', 'Merksplas', 'Merksplas,Merxplas', 51.3585100, 4.8651300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6296, 'Merelbeke', 'Merelbeke', 'Meirelbeke,Merelbeke,mei lei er bei ke,mwrlbwk,Мерелбеке,مورلبوک,梅勒尔贝克', 50.9944700, 3.7462100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6297, 'Merchtem', 'Merchtem', 'Merchtem', 50.9512900, 4.2319700, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6298, 'Merbes-le-Château', 'Merbes-le-Chateau', 'Merb l''o Shato,Merbes-le-Chateau,Merbes-le-Château,mrbwl-shtw,Мерб льо Шато,مربول-شتو', 50.3244900, 4.1648900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6299, 'Menen', 'Menen', 'Meenen,Meenn,Menen,Menin,Mjeenn,Mêenn,mei nen,mnn,Менен,منن,梅嫩', 50.7972200, 3.1224500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6300, 'Melle', 'Melle', 'Melle', 51.0023200, 3.8052600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6301, 'Meix-devant-Virton', 'Meix-devant-Virton', 'Mech-divant-Vierton,Meix-devant-Virton,Meks devan Virton,Meks-devan-Virton,Méch-divant-Vierton,mei de wang wei tong,mks-dwan-wyrtn,Мекс деван Виртон,Мекс-деван-Виртон,مکس-دوان-ویرتن,梅德旺维通', 49.6058100, 5.4804500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6302, 'Meise', 'Meise', 'Meise,Mejse,Meysse,mai ze,mz,Мейсе,مز,迈泽', 50.9393400, 4.3265500, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6303, 'Meerhout', 'Meerhout', 'Meerhout', 51.1321000, 5.0784200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6304, 'Mechelen', 'Mechelen', 'Gorad Mekhelen,Malinas,Malines,Mechele,Mechelen,Mechelenas,Mecheln,Mechlinia,Mehleno,Mekhelen,Meĥleno,ZGP,me khexlein,mehellen,meheren,mei he lun,mkln,mshlan,Горад Мехелен,Мехелен,מכלן,مشلان,เมเคอเลิน,メヘレン,梅赫伦,메헬렌', 51.0257400, 4.4776200, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6305, 'Martelange', 'Martelange', 'Martelange,Martelanzh,Martelarge,Matlindje,Måtlindje,Nartelange,ma te lang ri,mrtwlanzh,Мартеланж,مرتولانژ,马特朗日', 49.8319500, 5.7365500, 'BE', '2013-08-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6306, 'Marchin', 'Marchin', 'Marchin,Marcin,Marshen,Mårcin,ma er shang,mrshn,Маршен,مرشن,马尔尚', 50.4670700, 5.2428000, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6307, 'Marche-en-Famenne', 'Marche-en-Famenne', 'Marca in Falmana,Marche,Marsh an Famen,Marsh-an-Famen,Matche-el-Famene,Måtche-el-Fåmene,fa mei en de qu ma er shen,maleusyuangpamen,marushu=an=famen''nu,Марш ан Фамен,Марш-ан-Фамен,مرش‌آن‌فمن,マルシュ＝アン＝ファメンヌ,法梅恩地区马尔什,마르슈앙파멘', 50.2267800, 5.3441600, 'BE', '2008-06-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6308, 'Manhay', 'Manhay', 'Mane,Manhay,Manhe,Manhé,ma nai,mnh,Мане,منه,马奈', 50.2921900, 5.6756200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6309, 'Manage', 'Manage', 'Manadje,Manage,Manazh,mnzh,Манаж,منژ', 50.5031200, 4.2358900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6310, 'Malmédy', 'Malmedy', 'Malmedy,Malmédy,Mamdey,Måmdey', 50.4268600, 6.0279400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6311, 'Maldegem', 'Maldegem', 'Mal''degem,Maldegem,Moaldegem,ma er de hai mu,mldwzhm,Малдегем,Мальдегем,ملدوژم,马尔德海姆', 51.2073700, 3.4451100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6312, 'Machelen', 'Machelen', 'Machelen,Makhelen,ma he lun,mshwlan,Махелен,مشولان,马赫伦', 50.9106100, 4.4417400, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6313, 'Maasmechelen', 'Maasmechelen', 'Maasmechelen,Maasmekhelen,Maasmekhelene,Masmekhelen,Massmechelen,Mechele,ma si mei he lun,mas me khexlein,masmykhylyn,masumeheren,myamshlan,Маасмехелен,Маасмехелене,Масмехелен,مئامشلان,ماسميخيلين,มาสเมเคอเลิน,マースメヘレン,马斯梅赫伦', 50.9654500, 5.6945200, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6314, 'Maaseik', 'Maaseik', 'Maaseik,Maasejk,Maeseyck,Mezeik,ma sai ke,ma sik,masaiku,masayk,maseikeu,mazk,Маасейк,مازک,ماسايك,มาไซก์,マーサイク,马塞克,마세이크', 51.0980200, 5.7837900, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6315, 'Lummen', 'Lummen', 'Lummen', 50.9877200, 5.1912100, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6316, 'Lubbeek', 'Lubbeek', 'Lubbeek', 50.8827800, 4.8389600, 'BE', '2011-02-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6317, 'Lovendegem', 'Lovendegem', 'Lovendegem', 51.1016800, 3.6129800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6318, 'Louvain-la-Neuve', 'Louvain-la-Neuve', 'Li Nou Loven,Li Noû Lovén,Luven-la-Nev,Novum Lovanium,Ottignies-Louvain-la-Neuve (Louvain-la-Neuve),ruvu~an=ra=nuvu,Лувен-ла-Нев,ルーヴァン＝ラ＝ヌーヴ', 50.6682900, 4.6144300, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6319, 'Lontzen', 'Lontzen', 'Lontzen,Sontzen', 50.6812600, 6.0071200, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6320, 'Londerzeel', 'Londerzeel', 'Londerzeel,Londerzel,long de ze er,lwndrzyl,Лондерзел,لوندرزئل,隆德泽尔', 51.0046800, 4.3030400, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6321, 'Lommel', 'Lommel', 'Lomel,Lomelis,Lommel,lml,lom meil,luo mo er,lwml,Ломел,Ломмел,لمل,لومل,โลมเมิล,洛默尔', 51.2307400, 5.3134900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6322, 'Lokeren', 'Lokeren', 'Lokeren,Lokerenas,luo ke lun,lwkrn,Локерен,لوکرن,洛克伦', 51.1036400, 3.9933900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6323, 'Lochristi', 'Lochristi', 'Lochristi,Lokhristi,Loochristi,Loochristy,luo ke li si di,lwkrysty,Лохристи,لوکریستی,洛克里斯蒂', 51.0964400, 3.8319400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6324, 'Lobbes', 'Lobbes', 'Lob,Lobbes,Lobe,Lôbe,lwb,Лоб,لوب', 50.3525800, 4.2671600, 'BE', '2011-10-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6325, 'Lint', 'Lint', 'Lint,Linth', 51.1270700, 4.4966900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6326, 'Linkebeek', 'Linkebeek', 'Linkebeek,Linkebek,lin ke bei ke,lnkwbwk,Линкебек,Լինկեբեեկ,لنکوبوک,林克贝克', 50.7678100, 4.3368800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6327, 'Lincent', 'Lincent', 'Lensan,Liessem,Lijsem,Lincent,Lissin,Lîssin,lan sang,lnsan,Ленсан,لنسان,兰桑', 50.7122200, 5.0365400, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6328, 'Limbourg', 'Limbourg', 'Laeboer,Limbourg,Limburg', 50.6122200, 5.9412000, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6329, 'Lille', 'Lille', 'Lille', 51.2419700, 4.8231300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6330, 'Lier', 'Lier', 'L''er,Lier,Lierre,Lijr,Lir,Lyras,li er,lileu,lyr,riru,Лийр,Лир,Льер,Лір,لیر,リール,利尔,리르', 51.1312800, 4.5704100, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6331, 'Lierneux', 'Lierneux', 'L''ernjo,Liern''o,Lierneu,Lierneux,Lieurneux,li er na,lyrnw,Лиерньо,Льернё,لیرنو,利尔纳', 50.2847700, 5.7923600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6332, 'Liège', 'Liege', 'Gorad L''ezh,L''ezh,LGG,Leck,Leodic,Leodicum,Leodium,Lidje,Liege,Liegi,Liego,Lieja,Liex,Liez,Liezh,Lieĝo,Lige,Lijezh,Liège,Lièja,Ljez,Ljeza,Ljezas,Ljež,Lježas,Ljēža,Luettich,Luik,Luttich,Lutych,Luuk,Léck,Lüttich,Lēodic,Suguru,Sùguru,lie ri,lieju,liezhi,lija,lyj,lyyj,lyyz,lyzh,rieju,Λιέγη,Горад Льеж,Лиеж,Лијеж,Льеж,Льєж,Լիեժ,לייז,ליעזש,لييج,لیج,لیژ,लीज,ลีแยฌ,လိဂျမြို့,ლიეჟი,リエージュ,列日,리에주', 50.6337300, 5.5674900, 'BE', '2014-08-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6333, 'Liedekerke', 'Liedekerke', 'Lidekerke,Liedekerke,Lijdekerke,li de kai er ke,lywdwkrk,Лидекерке,Лийдекерке,لیودوکرک,利德凯尔克', 50.8689200, 4.0874300, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6334, 'Lichtervelde', 'Lichtervelde', 'Lichterveld,Lichtervelde', 51.0333300, 3.1500000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6335, 'Libin', 'Libin', 'Liben,Libin,Libini vald,li ban,lybn,Либен,لیبن,利班', 49.9810700, 5.2561200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6336, 'Leuven', 'Leuven', 'L''oven,Leouben,Leuve,Leuven,Ljoven,Loewen,Louvain,Lovaina,Lovan,Lovanio,Lovanium,Lovaň,Loveno,Luven,Löwen,ZGK,lu wen,revu~en,ruvu~en,Λέουβεν,Лувен,Льовен,Лёвен,ルーヴェン,レーヴェン,鲁汶', 50.8795900, 4.7009300, 'BE', '2008-07-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6337, 'Lessines', 'Lessines', 'Lesin,Lessen,Lessin,Lessines,lai xi en,lsyn,Лесин,Лессин,لسین,莱西恩', 50.7110400, 3.8357900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6338, 'Leopoldsburg', 'Leopoldsburg', 'Bourg-Leopold,Bourg-Léopold,Leopoldsburg', 51.1166700, 5.2500000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6339, 'Lens', 'Lens', '', 50.5569600, 3.8994600, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6340, 'Lendelede', 'Lendelede', 'Lendelede,Lendlee', 50.8862600, 3.2374700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6341, 'Léglise', 'Leglise', 'Leglijhe,Leglise,Legliz,Léglise,lai ge li ci,lglyz,Леглиз,لگلیز,莱格利兹', 49.7998500, 5.5365200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6342, 'Ledegem', 'Ledegem', 'Ledegem,Ledeghem', 50.8578500, 3.1240900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6343, 'Ledeberg', 'Ledeberg', 'Ledeberg', 51.0385900, 3.7445800, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6344, 'Ledeberg', 'Ledeberg', '', 50.8435600, 4.0911200, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6345, 'Lede', 'Lede', 'Lede', 50.9662600, 3.9859400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6346, 'Lebbeke', 'Lebbeke', 'Lebbeke', 51.0046400, 4.1345700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6347, 'La Roche-en-Ardenne', 'La Roche-en-Ardenne', 'La Roche-en-Ardenne,La Rosh an Arden,La Rosh-an-Arden,Laroche,Li Rotche,la luo shen ang a deng,lalosyuang-aleuden,lrwsh-an-ardn,Ла Рош ан Арден,Ла Рош-ан-Арден,لروش-آن-اردن,拉罗什昂阿登,라로슈앙아르덴', 50.1836100, 5.5754700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6348, 'Landen', 'Landen', 'Landen', 50.7526700, 5.0820000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6349, 'Lanaken', 'Lanaken', 'Lanaeken,Lanaken', 50.8931800, 5.6468000, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6350, 'La Louvière', 'La Louviere', 'El Lovire,La Louviere,La Louvière,La Luvjer,La Luvjeras,La-Luv''er,Louvierre,Luparia,Luvier,la lu wei ye er,la lwwyr,lalubieleu,Ла Лувјер,Ла-Лувьер,Лувиер,لا لوویر,ラ・ルヴィエール,拉卢维耶尔,라루비에르', 50.4865700, 4.1878500, 'BE', '2008-06-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6351, 'La Hulpe', 'La Hulpe', 'L Elpe,La Hulpe,La Julp,La-Jul''p,Terhulpen,la yu er pu,lywlp,Ла Юлп,Ла-Юльп,لئولپ,拉于尔普', 50.7309100, 4.4857700, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6352, 'La Calamine', 'La Calamine', 'Calmene,Calmène,Kelmis,La Calamine', 50.7180900, 6.0110700, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6353, 'La Bruyère', 'La Bruyere', '', 50.3947800, 4.6144400, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6354, 'Laarne', 'Laarne', 'Laarne,Laerne', 51.0307800, 3.8507700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6355, 'Kuurne', 'Kuurne', 'Cuerne,Kuurne', 50.8514300, 3.2824000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6356, 'Kruishoutem', 'Kruishoutem', 'Cruyshautem,Kruishoutem', 50.9016800, 3.5258800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6357, 'Kruibeke', 'Kruibeke', 'Cruybeke,Kruibeke', 51.1704800, 4.3144400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6358, 'Kraainem', 'Kraainem', 'Crainhem,Kraainem,Krajnem,ke lai nei mu,krnm,Крайнем,کرنم,克赖内姆', 50.8615500, 4.4694600, 'BE', '2011-01-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6359, 'Kortrijk', 'Kortrijk', 'Contrai,Cortoriacum,Cortrique,Courtrai,Gorad Kortrehjk,KJK,Kortrajk,Kortreika,Kortreikas,Kortrejk,Kortrejko,Kortrijk,Kortrik,Kortryk,ke te lai ke,khxrth rikh,koleuteuleikeu,kortrejk,korutoreiku,kwrtryk,qwrtryyq,Горад Кортрэйк,Кортрајк,Кортрейк,קורטרייק,کورتریک,คอร์ทไรค์,コルトレイク,科特赖克,코르트레이크', 50.8280300, 3.2648700, 'BE', '2008-06-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6360, 'Kortessem', 'Kortessem', 'Cortessem,Cortessum,Kortessem,Kortessum', 50.8589000, 5.3897400, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6361, 'Kortenberg', 'Kortenberg', 'Cortenberg,Kortenberg,ke teng bei he,kwrtanbrg,Кортенберг,کورتانبرگ,科滕贝赫', 50.8898200, 4.5435300, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6362, 'Kortenaken', 'Kortenaken', 'Cortenaeken,Kortenaken', 50.9086200, 5.0596800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6363, 'Kortemark', 'Kortemark', 'Cortemarck,Kortemark', 51.0295100, 3.0411200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6364, 'Kontich', 'Kontich', 'Condacum,Contich,Kontich,Kontikh,kong di he,kwntyk,Контих,Контич,کونتیک,孔蒂赫', 51.1321300, 4.4470600, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6365, 'Koksijde', 'Koksijde', 'Coxyde,Koksejde,Koksijde,Koksyde,ke ke sai de,kwksyzhd,Коксейде,Коксийде,کوکسیژد,科克赛德', 51.1164200, 2.6377200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6366, 'Koekelare', 'Koekelare', 'Couckelaere,Koekelare', 51.0904700, 2.9783000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6367, 'Knokke-Heist', 'Knokke-Heist', 'Knoke-Khajst,Knokke-Heist,Knokke-Khejst,Knokkne,Noke-Khajst,ke nuo ke-hai si te,keunokeoheiseuteu,knwkyst,kunokku=heisuto,Кноке-Хайст,Кнокке-Хейст,Ноке-Хајст,کنوکئست,クノック＝ヘイスト,克诺克－海斯特,크노커헤이스트', 51.3500000, 3.2666700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6368, 'Knesselare', 'Knesselare', 'Knesselaere,Knesselare', 51.1393200, 3.4128200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6369, 'Kinrooi', 'Kinrooi', 'Kinjer,Kinroy', 51.1454300, 5.7420700, 'BE', '2009-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6370, 'Keerbergen', 'Keerbergen', 'Keerbergen', 51.0029500, 4.6343400, 'BE', '2011-02-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6371, 'Kasterlee', 'Kasterlee', 'Casterle,Kasterlee', 51.2411800, 4.9665100, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6372, 'Kaprijke', 'Kaprijke', 'Caprycke,Kaprijke', 51.2172000, 3.6151900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6373, 'Kapelle-op-den-Bos', 'Kapelle-op-den-Bos', 'Chapelle-au-Bois,Kapele op den Bos,Kapelle-op-den-Bos,ka pei er-ao pu-deng-bo si,kpl-awp-dan-bw,Капеле оп ден Бос,Капелле-оп-ден-Бос,کپل-اوپ-دان-بو,卡佩尔－奥普－登－博斯', 51.0097000, 4.3630300, 'BE', '2011-02-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6374, 'Kapellen', 'Kapellen', 'Cappellen,Kapelen,Kapellen,Kapellene,ka pei lun,kpwlan,Капелен,Капеллен,Капеллене,کپولان,卡佩伦', 51.3137700, 4.4353900, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6375, 'Kampenhout', 'Kampenhout', 'Campenhout,Kampenhout', 50.9421000, 4.5510300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6376, 'Kalmthout', 'Kalmthout', 'Calmpthout,Kalmthout', 51.3844200, 4.4755600, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6377, 'Jurbise', 'Jurbise', 'Djurbize,Jurbeke,Zhjurbiz,Zhurbiz,zhwrbyz,Журбиз,Жюрбиз,ژوربیز', 50.5310000, 3.9094200, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6378, 'Juprelle', 'Juprelle', 'Juprelle', 50.7076000, 5.5312700, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6379, 'Jodoigne', 'Jodoigne', 'Djodogne,Geldenaken,Jodoigne,Zhodoan,Zhoduan'',ruo du wa nie,zhwdwany,Жодоан,Жодуань,ژودوآنی,若杜瓦涅', 50.7235700, 4.8691400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6380, 'Jalhay', 'Jalhay', 'Djalhe,Djalhé,Jalhay,Zhale,ya lai,zhlh,Жале,جلھے,ژله,雅莱', 50.5587600, 5.9676400, 'BE', '2011-03-24', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6381, 'Jabbeke', 'Jabbeke', 'Jabbeke', 51.1818500, 3.0893500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6382, 'Izegem', 'Izegem', 'Iseghem,Izegem,Izzegem,Yzegem,ayzzhm,yi ze hai mu,Изегем,ایزژم,伊泽海姆', 50.9139600, 3.2137800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6383, 'Ittre', 'Ittre', 'Ite,Itr,Itter,Ittre,Itur,aytr,yi te er,Итр,Итър,ایتر,伊特尔', 50.6439600, 4.2647600, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6384, 'Ingelmunster', 'Ingelmunster', 'Ingelmunster', 50.9208100, 3.2557100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6385, 'Incourt', 'Incourt', 'Incourt', 50.6915100, 4.7981600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6386, 'Ieper', 'Ieper', 'Gorad Ipr,Ieper,Iper,Ipr,Ipra,Ipro,Yper,Ypern,Ypr,Ypra,Ypras,Ypres,Ypry,aypr,ipeoleu,iperu,yi po er,yprys,Υπρ,Іпр,Горад Іпр,Ипер,Ипр,איפר,ایپر,یپریس,イーペル,伊珀尔,이퍼르', 50.8511400, 2.8856900, 'BE', '2013-04-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6387, 'Ichtegem', 'Ichtegem', 'Ichtegem,Ichteghem', 51.0957200, 3.0154900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6388, 'Huy', 'Huy', 'Hoei,Hu,Huy,Jui,awyy,hwy,i,yu yi,yui,Юи,Юї,אואי,اویی,هوي,ユイ,于伊,이', 50.5189400, 5.2328400, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6389, 'Hulshout', 'Hulshout', 'Hulshout', 51.0745100, 4.7908100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6390, 'Huldenberg', 'Huldenberg', 'Huldenberg', 50.7893900, 4.5831000, 'BE', '2011-02-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6391, 'Hove', 'Hove', 'Hove', 51.1544600, 4.4707000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6392, 'Houyet', 'Houyet', 'Houyet,Uje,awyh,wu ye,Уйе,اویه,乌耶', 50.1861900, 5.0076200, 'BE', '2011-05-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6393, 'Houthulst', 'Houthulst', 'Houthuls,Houthulst,Oetulst', 50.9782400, 2.9505000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6394, 'Houthalen', 'Houthalen', 'Houthaelen,Houthaelenberg,Houthalen-Helchteren (Houthalen)', 51.0342700, 5.3742900, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6395, 'Houffalize', 'Houffalize', 'Houffalize,Houffalizei vald,Oufalijhe,Ufaliz,Uffaliz,awflyz,hu fa li ci,Уфализ,Уффализ,اوفلیز,胡法利兹', 50.1323500, 5.7896200, 'BE', '2011-10-19', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6396, 'Hotton', 'Hotton', 'Hotton,Houton,Oton,ao tong,awtwn,Отон,اوتون,奥通', 50.2674200, 5.4460900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6397, 'Hoogstraten', 'Hoogstraten', 'Hoogstraeten,Hoogstraten,Khogstraten,awgstrtan,huo he si te la teng,hwkhstratn,Хогстратен,اوگسترتان,هوخستراتن,霍赫斯特拉滕', 51.4002900, 4.7603400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6398, 'Hooglede', 'Hooglede', 'Hooglede,Ooglee', 50.9833300, 3.0833300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6399, 'Holsbeek', 'Holsbeek', 'Holsbeek', 50.9209700, 4.7574700, 'BE', '2011-02-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6400, 'Hoeselt', 'Hoeselt', 'Hoeiselt,Hoeselt,Hoesselt', 50.8471400, 5.4876700, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6401, 'Hoeilaart', 'Hoeilaart', 'Hoeilaart,Hoeylaert', 50.7673000, 4.4683500, 'BE', '2011-02-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6402, 'Hoegaarden', 'Hoegaarden', 'Hoegaarden,Hougaerde,Khugarden,awygrdan,hu ha er deng,huhaleudeon,Хугарден,اویگردان,胡哈尔登,후하르던', 50.7756000, 4.8895200, 'BE', '2011-02-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6403, 'Hoboken', 'Hoboken', 'Antwerp (Hoboken),Hoboken-lez-Anvers', 51.1761100, 4.3484400, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6404, 'Heusden', 'Heusden', 'Heusden-Zolder (Heusden)', 51.0366400, 5.2801300, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6405, 'Herzele', 'Herzele', 'Herzele', 50.8868100, 3.8901400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6406, 'Herve', 'Herve', 'Ehrv,Erv,Herf,Herve,arw,he er fu,Ерв,Эрв,ارو,赫尔夫', 50.6408300, 5.7935300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6407, 'Herstal', 'Herstal', 'Ehrstal'',Erstal,Heristalium,Herstal,Herstalis,Hesta,Kherstal,arstal,eleuseutal,erusutaru,he er si ta er,Ерстал,Херстал,Эрсталь,ارستال,エルスタル,赫尔斯塔尔,에르스탈', 50.6641500, 5.6234600, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6408, 'Herselt', 'Herselt', 'Herselt,Hersselt', 51.0515900, 4.8823100, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6409, 'Héron', 'Heron', 'Heron', 50.5473100, 5.0977400, 'BE', '2013-05-13', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6410, 'Herne', 'Herne', 'Herinnes,Herne,Hérinnes', 50.7242300, 4.0348100, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6411, 'Herk-de-Stad', 'Herk-de-Stad', 'Herck-la-Ville,Herk,Herk-de-Stad', 50.9401300, 5.1663600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6412, 'Herenthout', 'Herenthout', 'Herenthout', 51.1401000, 4.7557200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6413, 'Herentals', 'Herentals', 'Herentals,Herenthals,Kherentals,arantl,he lun ta er si,Херенталс,ارانتل,赫伦塔尔斯', 51.1765500, 4.8324800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6414, 'Herent', 'Herent', 'Herent,Kherent,aran,hai lun te,Херент,اران,海伦特', 50.9086100, 4.6705600, 'BE', '2011-02-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6415, 'Herbeumont', 'Herbeumont', 'Arbumont,Arbûmont,Ehrbjomon,Erb''omon,Herbeumont,ai er bo meng,arbwmwn,Ербьомон,Эрбёмон,اربومون,埃尔伯蒙', 49.7808600, 5.2358000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6416, 'Hensies', 'Hensies', 'Ansi,ansy,Анси,آنسی', 50.4326300, 3.6841100, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6417, 'Hemiksem', 'Hemiksem', 'Hemiksem,Hemixem,Hemixeu', 51.1448400, 4.3387400, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6418, 'Helchteren', 'Helchteren', 'Houthalen-Helchteren (Helchteren)', 51.0559100, 5.3824400, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6419, 'Heist-op-den-Berg', 'Heist-op-den-Berg', 'Heist-op-den-Berg,Heyst-op-den-Berg,Khajst op den Berg,Khejst op den Berg,aystwp-dan-brg,hai si te ao pu deng bei er he,Хајст оп ден Берг,Хейст оп ден Берг,ایستوپ-دان-برگ,海斯特奥普登贝尔赫', 51.0753700, 4.7282700, 'BE', '2013-06-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6420, 'Heers', 'Heers', 'Heers,Hier,Hiër', 50.7538300, 5.3021000, 'BE', '2011-03-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6421, 'Havelange', 'Havelange', 'Avelanzh,Avlanzh,Havelange,Havlondje,awlanzh,ha fu lang ri,Авеланж,Авланж,اولانژ,哈弗朗日', 50.3893100, 5.2381600, 'BE', '2011-04-12', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6422, 'Hastière-Lavaux', 'Hastiere-Lavaux', 'Hastiere (Hastiere-Lavaux),Hastière (Hastière-Lavaux)', 50.2184900, 4.8244600, 'BE', '2011-05-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6423, 'Hasselt', 'Hasselt', 'Asselt,Gasselt,Gorad Khaselt,Haselt,Haseltas,Haselto,Hasselt,Khaselt,Khasselt,QHA,aslt,ha se er te,has sel th,haselteu,hasseruto,Άσσελτ,Гасселт,Горад Хаселт,Хаселт,Хасселт,Հասելտ,اسلت,ฮัสเซลท์,ハッセルト,哈瑟尔特,하셀트', 50.9310600, 5.3378100, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6424, 'Harelbeke', 'Harelbeke', 'Hailebeke,Harelbeke,Harelbeke vald,Harelbekė,Harlebeke,Kharelbeke,Oarelbeke,ha lei er bei ke,Харелбеке,ارل‌بک,哈勒尔贝克', 50.8534300, 3.3093500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6425, 'Hannut', 'Hannut', 'Anju,Annju,Haneu,Hannuit,Hannut,anwt,han ni,Анню,Аню,انوت,寒尼', 50.6714200, 5.0789800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6426, 'Hamois', 'Hamois', 'Amoa,Amua,Hamwe,Hamwè,a mu wa,amwa,Амоа,Амуа,اموآ,阿穆瓦', 50.3402000, 5.1561900, 'BE', '2011-04-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6427, 'Hamoir', 'Hamoir', 'Amoar,Amuar,Hamoir,Hamwer,a mu wa er,amwar,Амоар,Амуар,اموآر,阿穆瓦尔', 50.4267500, 5.5330400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6428, 'Hamme', 'Hamme', 'Ama,Hame,Hamme,Hamė,Khame,Khamme,am,ha mo,Хаме,Хамме,ام,哈默', 51.0982200, 4.1370500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6429, 'Halle', 'Halle', 'Galle,Hal,Halle,Halle i Belgia,Khale,Khalle,al,ha lai,halh,Галле,Хале,Халле,ال,هاله,哈莱', 50.7338500, 4.2345400, 'BE', '2011-02-12', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6430, 'Halen', 'Halen', 'Haelen,Halen,Hole,Hôle,Khalen,alan,ha lein,ha lun,Хален,Հալեն,الان,ฮาเลิน,哈伦', 50.9483700, 5.1109600, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6431, 'Habay-la-Vieille', 'Habay-la-Vieille', 'Habay,Habay-la-Vieille', 49.7232900, 5.6199900, 'BE', '2012-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6432, 'Haaltert', 'Haaltert', 'Haaltert,Haeltert', 50.9063400, 4.0009300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6433, 'Haacht', 'Haacht', 'Haacht,Haecht', 50.9773700, 4.6377700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6434, 'Grobbendonk', 'Grobbendonk', 'Grobbendonck,Grobbendonk', 51.1904300, 4.7356200, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6435, 'Grimbergen', 'Grimbergen', 'Grimbergen,Grimberghen,Xrimberxen,grymbrzhan,he lin bei heng,Гримберген,Խրիմբերխեն,گریمبرژان,赫林贝亨', 50.9340900, 4.3721300, 'BE', '2011-02-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6436, 'Grez-Doiceau', 'Grez-Doiceau', 'Graven,Gre,Gre-Duaso,Grez Doaso,Grez-Doiceau,Gré,Helecine,Hélécine,ge lei-du wa suo,grh-dwasw,Гре-Дуасо,Грез Доасо,گره-دوآسو,格雷－杜瓦索', 50.7390100, 4.6982900, 'BE', '2011-01-27', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6437, 'Gouvy', 'Gouvy', 'Gouvi,Gouvy,Guvi,gu wei,gwwy,Гуви,گووی,古维', 50.1860000, 5.9391700, 'BE', '2012-01-20', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6438, 'Gooik', 'Gooik', 'Gojk,Gooik,Goyck,gwyk,huo yi ke,jwyk,Гойк,جويك,گوئک,霍伊克', 50.7944300, 4.1137800, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6439, 'Glabbeek-Zuurbemde', 'Glabbeek-Zuurbemde', 'Glabbeek,Glabbeek-Suerbempde,Glabbeek-Zuurbemde', 50.8734800, 4.9444200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6440, 'Gistel', 'Gistel', 'Ghistelles,Gistel,Histel,Гистел', 51.1561200, 2.9638700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6441, 'Gingelom', 'Gingelom', 'Gingelom', 50.7479200, 5.1342200, 'BE', '2011-03-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6442, 'Gesves', 'Gesves', 'Djeve,Gesves,Zhev,re fu,zhsw,Жев,ژسو,热弗', 50.4014600, 5.0745700, 'BE', '2011-04-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6443, 'Gerpinnes', 'Gerpinnes', 'Djerpene,Gerpinnes,Zherpin,Zherpinn,zhrpyn,Жерпин,Жерпинн,ژرپین', 50.3378900, 4.5273100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6444, 'Geraardsbergen', 'Geraardsbergen', 'Geeraardsbergen,Geraardsbergen,Gerardsbergen,Grammont,he la er ci bei heng,zhrardzbrzhan,Гераардсберген,Герардсберген,ژراردزبرژان,赫拉尔兹贝亨', 50.7734300, 3.8822300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6445, 'Gent', 'Gent', 'GNE,Gaent,Gand,Gandavum,Gandawa,Gande,Gant,Gante,Ganti,Gent,Gentas,Gente,Gento,Ghent,Gint,Gorad Gent,Gænt,gen te,genta,ghnt,gnt,henteu,hento,jenta,jnt,ken t,khenta,khnt,Γάνδη,Гент,Горад Гент,Գենտ,גנט,جنت,خنت,غنت,غینٹ,खेंट,गेंट,জেন্ট,เกนต์,ဂင့်မြို့,გენტი,ヘント,根特,헨트', 51.0500000, 3.7166700, 'BE', '2008-06-24', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6446, 'Genk', 'Genk', 'Genck,Genk,Генк', 50.9650000, 5.5008200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6447, 'Genappe', 'Genappe', 'Djinape,Genappe,Genepien,Genepiën,Zhenap,re na pu,zhnp,Женап,ژنپ,热纳普', 50.6117300, 4.4515200, 'BE', '2011-01-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6448, 'Gembloux', 'Gembloux', 'Djiblou,Gembloers,Gembloux,Gemblua,Geminiacum,Jembloux,Zamblu,Zhamblu,janburu,jangbeullu,rang bu lu,zhamblw,Žamblu,Гемблуа,Жамблу,ژامبلو,ジャンブルー,让布卢,장블루', 50.5614900, 4.6988900, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6449, 'Geetbets', 'Geetbets', 'Geet Betz,Geetbets', 50.8943100, 5.1119900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6450, 'Geer', 'Geer', 'Geer', 50.6699000, 5.1736400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6451, 'Geel', 'Geel', 'Geel,Gel,Gelis,Gheel,he er,heil,heru,zhl,Геел,Гел,ژل,ヘール,赫尔,헤일', 51.1655700, 4.9891700, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6452, 'Gedinne', 'Gedinne', 'Djedene,Gedinne,Zhedin,re di ne,zhwdyn,Жедин,ژودین,热迪讷', 49.9803700, 4.9367400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6453, 'Gavere', 'Gavere', 'Gavere,gwr,ha fu er,Гавере,گور,哈弗尔', 50.9291700, 3.6618400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6454, 'Galmaarden', 'Galmaarden', 'Galmaarden,Gammerages', 50.7538900, 3.9712100, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6455, 'Froidchapelle', 'Froidchapelle', 'Froashapel,Fruashapel'',frwadshpl,Фроашапел,Фруашапель,فروآدشپل', 50.1510600, 4.3274200, 'BE', '2011-08-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6456, 'Frasnes-lez-Buissenal', 'Frasnes-lez-Buissenal', 'Frasnes,Frasnes-lez-Buissenal', 50.6678300, 3.6204700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6457, 'Frameries', 'Frameries', 'Frameri,Frameris,Framrie,Framriye,frmwrh,Фрамери,Фрамерис,فرموره', 50.4057800, 3.8960300, 'BE', '2010-01-29', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6458, 'Sint-Pieters-Voeren', 'Sint-Pieters-Voeren', 'Fouron-Saint-Pierre,Fourons (Fouron-Saint-Pierre),Sint-Pieters-Voeren,Voeren (Sint-Pieters-Voeren)', 50.7386300, 5.8222400, 'BE', '2011-03-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6459, 'Fosses-la-Ville', 'Fosses-la-Ville', 'Fos la Vil,Fos-la-Vil'',Fosse-la-Ville,Fosse-li-Veye,fs lwyl,fu si cheng,Фос ла Вил,Фос-ла-Виль,فس لویل,福斯城', 50.3951700, 4.6962300, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6460, 'Forville', 'Forville', 'Fernelmont (Forville)', 50.5742400, 4.9986100, 'BE', '2013-06-30', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6461, 'Florenville', 'Florenville', 'Floranvil,Floranvil'',Floravile,Florenville,flwran wyl,fu luo lang wei er,Флоранвил,Флоранвиль,فلوران ویل,弗洛朗维尔', 49.6998300, 5.3074000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6462, 'Florennes', 'Florennes', 'Floren,Florene,Florennes,flwrn,fu luo lei ne,Флорен,فلورن,弗洛雷讷', 50.2512700, 4.6063600, 'BE', '2011-07-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6463, 'Floreffe', 'Floreffe', 'Floref,Florefe,Floreffe,flwrf,fu luo lei fu,Флореф,فلورف,弗洛雷夫', 50.4345200, 4.7596000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6464, 'Flobecq', 'Flobecq', 'Flobecq,Vloesberg', 50.7373300, 3.7387600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6465, 'Fleurus', 'Fleurus', 'Fl''orjus,Flerus,Fleuru,Fljorjus,flwrw,fururyusu,peulloelwiseu,Флерус,Фльорюс,Флёрюс,فلورو,フルーリュス,플뢰뤼스', 50.4835100, 4.5500600, 'BE', '2011-08-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6466, 'Fléron', 'Fleron', 'Fleron,flrwn,fu lai long,Флерон,فلرون,弗莱龙', 50.6151600, 5.6806200, 'BE', '2013-05-13', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6467, 'Flémalle-Haute', 'Flemalle-Haute', 'Flemalle (Flemalle-Haute),Flémalle (Flémalle-Haute)', 50.5999400, 5.4447100, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6468, 'Fexhe-le-Haut-Clocher', 'Fexhe-le-Haut-Clocher', 'Feks l''o O Kloshe,Feks-le-O-Kloshe,Fexhe-a-Hot-Cloki,Fexhe-le-Haut-Clocher,Fexhe-å-Hôt-Clokî,fei ke ze lei ao ke luo xie,fks-lw-klwshh,Фекс льо О Клоше,Фекс-ле-О-Клоше,فکس-لو-کلوشه,费克泽勒奥克洛谢', 50.6654000, 5.3997800, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6469, 'Ferrières', 'Ferrieres', 'Ferrieres,Ferrières', 50.4015700, 5.6109200, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6470, 'Fauvillers', 'Fauvillers', 'Faivie,Faiviè,Fauvillers,Foviers,Foville,fu wei lai er,fwwyh,Фовиерс,Фовилле,فوویه,福维莱尔', 49.8511600, 5.6640500, 'BE', '2011-10-19', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6471, 'Farciennes', 'Farciennes', 'Farcene,Farciennes,Fars''en,Farsien,Fårcene,frsyyn,Фарсиен,Фарсьен,فرسیئن', 50.4300600, 4.5415200, 'BE', '2011-08-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6472, 'Faimes', 'Faimes', 'Faimes,Fem,fei mu,fm,fymys,Фем,فم,فیمیس,费姆', 50.6625200, 5.2600500, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6473, 'Evergem', 'Evergem', 'Ehvergem,Evergem,Everghem Rabot,ai fu hai mu,aywrzhm,Евергем,Эвергем,ایورژم,埃弗海姆', 51.1052900, 3.7040000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6474, 'Eupen', 'Eupen', 'Ehjpen,Ejpen,Epen,Epenas,Eupe,Eupen,Eypen,Gorad Ehjpen,Neyaw,Neyåw,Ojpen,ao yi peng,awpan,oipen,Горад Эйпен,Ейпен,Епен,Ойпен,Эйпен,Էյպեն,اوپان,オイペン,奥伊彭,오이펜', 50.6279000, 6.0364700, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6475, 'Étalle', 'Etalle', 'Etalle,Étalle', 49.6738500, 5.6001900, 'BE', '2012-03-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6476, 'Estinnes-au-Val', 'Estinnes-au-Val', '', 50.4101600, 4.1047700, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6477, 'Estaimpuis', 'Estaimpuis', 'Ehstempjui,Estaimpuis,Estempjui,Steenput,Timpu,astmpwyy,Естемпюи,Эстемпюи,استمپویی', 50.7048500, 3.2678500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6478, 'Essen', 'Essen', 'Esschen', 51.4679100, 4.4690100, 'BE', '2014-12-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6479, 'Esneux', 'Esneux', 'Ehnjo,En''o,Esneu,Esneux,Esneux vald,ai si ne,asnw,Еньо,Энё,اسنو,埃斯讷', 50.5359600, 5.5677500, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6480, 'Erquelinnes', 'Erquelinnes', 'Ehrkelin,Erkelin,Erquelinnes,arkwlyn,Еркелин,Эркелин,ارکولین', 50.3068800, 4.1112900, 'BE', '2011-10-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6481, 'Érezée', 'Erezee', 'Ehreze,Ereze,Erezee,Erezeye,Erezée,Erezêye,ai er ze,arwzh,Érezée,Ерезе,Эрезе,اروزه,埃尔泽', 50.2929200, 5.5581500, 'BE', '2013-06-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6482, 'Engis', 'Engis', 'Anzhi,Anzhis,Engis,Indji,ang ri,anzhy,Анжи,Анжис,آنژی,昂日', 50.5815600, 5.3991600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6483, 'Enghien', 'Enghien', 'Ang''en,Angian,Edingen,Enghien,Ingui,Inguî,angyyn,Ангиан,Ангьен,آنگیین', 50.6837300, 4.0328400, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6484, 'Ellezelles', 'Ellezelles', 'Ehl''zel'',Elezel,Ellezelles,Elzele,Elzile,Elzîle,alzl,Елезел,Эльзель,الزل', 50.7351200, 3.6798500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6485, 'Éghezée', 'Eghezee', 'Egeze,Eghezee,Eghezée,Ehgeze,Inguezeye,Inguezêye,agwzh,ai ge ze,Éghezée,Егезе,Эгезе,اگوزه,埃格泽', 50.5907600, 4.9117500, 'BE', '2011-04-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6486, 'Eeklo', 'Eeklo', 'Eecloo,Eeklo,Eekloo,Ehklo,Eklo,ai ke luo,aklw,Êeklo,Екло,Экло,اکلو,埃克洛', 51.1870300, 3.5565400, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6487, 'Edegem', 'Edegem', 'Edegem,Edeghem', 51.1566200, 4.4450400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6488, 'Écaussinnes-d’Enghien', 'Ecaussinnes-d''Enghien', 'Ecaussines-d''Enghien,Ecaussinnes-d''Enghien,Écaussines-d’Enghien,Écaussinnes-d’Enghien', 50.5682200, 4.1658000, 'BE', '2014-12-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6489, 'Durbuy', 'Durbuy', 'Derbu,Djurbjui,Durbui,Durbuy,de~yurubyui,di er bi yi,dwileubi,dwrby,Дюрбюи,دوربی,デュルビュイ,迪尔比伊,뒤르비', 50.3529100, 5.4563100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6490, 'Duffel', 'Duffel', 'Duffel', 51.0955400, 4.5090300, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6491, 'Drogenbos', 'Drogenbos', 'Drogenbos,Drogenbosch,Droogenbosch,de luo heng bo si,drwzhanbw,Дрогенбос,دروژانبو,德罗亨博斯', 50.7873300, 4.3147100, 'BE', '2011-02-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6492, 'Dour', 'Dour', 'Dou,Doû,Dur,du er,dwr,Дур,دور,杜尔', 50.3958300, 3.7779200, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6493, 'Donceel', 'Donceel', 'Donceel', 50.6482700, 5.3200000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6494, 'Doische', 'Doische', 'Doash,Doische,Duash,Dweche,du wa shen,dwash,Доаш,Дуаш,دوآش,杜瓦什', 50.1335600, 4.7354500, 'BE', '2011-07-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6495, 'Dison', 'Dison', 'Dison', 50.6100400, 5.8534000, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6496, 'Dinant', 'Dinant', 'Dinan,Dinant,Dionantum,di nan,dinan,dinang,dynan,dynant,Динан,Дінан,דינאן,دينانت,دینان,ディナン,迪南,디낭', 50.2580700, 4.9116600, 'BE', '2011-04-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6497, 'Dilbeek', 'Dilbeek', 'Dilbeek,Dilbek,Zibbeek,di er bei ke,dilbek,dylbyk,Дилбек,دیلبئک,迪尔贝克', 50.8479900, 4.2597200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6498, 'Diksmuide', 'Diksmuide', 'Diksmude,Diksmuide,Dixmude,Dixmuide,Dixmuiden', 51.0324800, 2.8638400, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6499, 'Diest', 'Diest', 'Diest,Dijst,Distas,di si te,dist,dyh,Дийст,دیه,ดีสต์,迪斯特', 50.9892300, 5.0506200, 'BE', '2011-02-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6500, 'Diepenbeek', 'Diepenbeek', '', 50.9076900, 5.4187500, 'BE', '2010-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6501, 'Diegem', 'Diegem', 'Dieghem,Machelen (Diegem)', 50.8972700, 4.4335400, 'BE', '2012-05-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6502, 'Destelbergen', 'Destelbergen', 'Destelbergen,dai si te er bei heng,dtlbrzhan,Дестелберген,دتلبرژان,代斯特尔贝亨', 51.0595200, 3.7989900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6503, 'Dessel', 'Dessel', 'Desschel,Dessel', 51.2385500, 5.1144800, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6504, 'De Pinte', 'De Pinte', 'De Pinte,La Pinte,de ping te,dw pnt,Де Пинте,دو پنت,德平特', 50.9933900, 3.6474700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6505, 'De Panne', 'De Panne', 'De Panne,La Panne,Panne', 51.0979300, 2.5936800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6506, 'Dentergem', 'Dentergem', 'Dentergem,Denterghem,Denterhem', 50.9642900, 3.4161700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6507, 'Dendermonde', 'Dendermonde', 'Dendermonde,Teneramonda,Termonde,dandrmwnd,dendeleumondeo,dendermonde,denderumonde,deng de er meng de,dndrmwndh,Дендермонде,דנדרמונדה,داندرموند,デンデルモンデ,登德尔蒙德,덴데르몬더', 51.0286900, 4.1010600, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6508, 'Denderleeuw', 'Denderleeuw', 'Denderleeuw', 50.8850600, 4.0760100, 'BE', '2011-02-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6509, 'Deinze', 'Deinze', 'Dajnze,Deinze,Dejnze,Deynze,dai yin ze,dnz,Дайнзе,Дейнзе,دنز,代因泽', 50.9817500, 3.5309600, 'BE', '2014-05-22', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6510, 'De Haan', 'De Haan', 'D''n Aone,D''n Oane,De Haan,Den Haan,Le Coq', 51.2726100, 3.0344600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6511, 'Deerlijk', 'Deerlijk', 'Deerlijk,Deerlyck', 50.8533700, 3.3541600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6512, 'Daverdisse', 'Daverdisse', 'Dav''ordis,Davdisse,Daverdis,Daverdisse,Dåvdisse,da fu er di si,dwrdys,Давердис,Давьордис,دوردیس,达弗尔迪斯', 50.0216100, 5.1181100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6513, 'Damme', 'Damme', 'Damme,Dammum,Damovilla,Damville,da mo,dame,dameo,danme,dm,Даме,Дамме,دم,ダンメ,达默,다머', 51.2514700, 3.2814400, 'BE', '2008-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6514, 'Dalhem', 'Dalhem', 'Dalem,Dalhem,da lei mu,dlm,Далем,دلم,达雷姆', 50.7131500, 5.7277400, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6515, 'Crisnée', 'Crisnee', 'Gerstekaove,Krisne,ke li si nei,kryznh,Крисне,کریزنه,克利斯内', 50.7170300, 5.3980200, 'BE', '2013-05-13', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6516, 'Couvin', 'Couvin', 'Couven,Couvin,Couvén,Kuven,ku wan,kubaeng,kuvu~an,kwwn,Кувен,کوون,クーヴァン,库万,쿠뱅', 50.0528400, 4.4949500, 'BE', '2011-07-19', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6517, 'Court-Saint-Étienne', 'Court-Saint-Etienne', 'Cou-Sint-Stiene,Court-Saint-Etienne,Court-Saint-Étienne,Coû-Sint-Stiene,Kur Sent Etien,ku er-sheng ai di an,kwr-sn-atyn,Кур Сент Етиен,کور-سن-اتین,库尔－圣艾蒂安', 50.6337800, 4.5685100, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6518, 'Courcelles', 'Courcelles', 'Courcele,Courcelles,Curticellae,Kursel,Kursel'',kwrsl,kwrsyl,Курсел,Курсель,كورسيل,کورسل', 50.4637900, 4.3747000, 'BE', '2011-07-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6519, 'Comblain-au-Pont', 'Comblain-au-Pont', 'Comblain,Comblin-a-Pont,Comblin-å-Pont,Komblen o Pon,Komblen-o-Pon,Komblenx,kong bu lan ou peng,kwmbln-aw-pwn,Комблен о Пон,Комблен-о-Пон,کومبلن-او-پون,孔布兰欧蓬', 50.4748800, 5.5771100, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6520, 'Colfontaine', 'Colfontaine', 'Colfontinne,Kol''fonten,Kolfonten,kwlfwntn,Колфонтен,Кольфонтен,کولفونتن', 50.4141000, 3.8556900, 'BE', '2009-01-20', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6521, 'Clavier', 'Clavier', 'Clavier', 50.4006900, 5.3515400, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6522, 'Ciney', 'Ciney', 'Cine,Ciney,Cînè,Sine,shinei,sine,synh,xi nei,Сине,سینه,シネイ,西内,시네', 50.2944900, 5.1001500, 'BE', '2011-07-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6523, 'Chiny', 'Chiny', 'Chiny,Gmin Chiny,Shini,Tchini,shyny,Шини,شینی', 49.7383300, 5.3410400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6524, 'Chimay', 'Chimay', 'Chimai,Chimay,Shime,shimei,shymh,sime,xi mai,Шиме,شیمه,シメイ,希迈,시메', 50.0485600, 4.3171200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6525, 'Chièvres', 'Chievres', 'Chieve,Sh''evr,Shievur,shywr,Шиевър,Шьевр,شیور', 50.5878700, 3.8071100, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6526, 'Chaumont-Gistoux', 'Chaumont-Gistoux', 'Chaumont,Chaumont-Gistoux,Shomon-Zhistu,Tchamont-Djistou,Tchåmont-Djistou,shao meng-ji si tu,shwmwn-zhystw,Шомон-Жисту,شومون-ژیستو,绍蒙－吉斯图', 50.6775300, 4.7212000, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6527, 'Chaudfontaine', 'Chaudfontaine', 'Chaudfontaine,Shofonten,Tchofontinne,Tchôfontinne,shao de fang dan,shwfwntn,Шофонтен,شوفونتن,绍德方丹', 50.5828000, 5.6341000, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6528, 'Châtelet', 'Chatelet', 'Castellarium,Chatelet,Châtelet,Shatle,Tcheslet,shtlh,Шатле,شتله', 50.4033800, 4.5282600, 'BE', '2011-07-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6529, 'Chastre-Villeroux-Blanmont', 'Chastre-Villeroux-Blanmont', 'Chastre (Chastre-Villeroux-Blanmont)', 50.6085700, 4.6419800, 'BE', '2011-01-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6530, 'Chasse Royale', 'Chasse Royale', '', 50.4284200, 3.9500100, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6531, 'Charleroi', 'Charleroi', 'Carleroe,Carleroé,Caroloregium,Charleroi,Gorad Sharlerua,Sarleroua,Sarlerua,Sarlrua,Sharleroa,Sharlerua,Sharlroa,Tchalerwe,Tchålerwè,char lex raw,charlyrwyy,sha lei luo wa,sharlerua,sharlrwa,sharlwrwa,sharururowa,syaleullua,Šarlerua,Šarlruā,Σαρλερουά,Горад Шарлеруа,Шарлероа,Шарлеруа,Шарлроа,Շառլեռուա,שרלרואה,شارلروآ,شارلوروا,چارلیروئی,ชาร์เลอรัว,შარლერუა,シャルルロワ,沙勒罗瓦,샤를루아', 50.4113600, 4.4444800, 'BE', '2011-07-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6532, 'Chapelle-lez-Herlaimont', 'Chapelle-lez-Herlaimont', 'Chapelle-lez-Herlaimont,Shapel lez Erlemon,Shapel''-lez-Ehrlemon,shpl-lh-arlmwn,Шапел лез Ерлемон,Шапель-лез-Эрлемон,شپل-له-ارلمون', 50.4713000, 4.2822700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6533, 'Cerfontaine', 'Cerfontaine', 'Cerfontaine', 50.1704700, 4.4102800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6534, 'Celles', 'Celles', 'Celles', 50.7122900, 3.4573300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6535, 'Butgenbach', 'Butgenbach', 'Buetgenbach,Bütgenbach', 50.4268900, 6.2050400, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6536, 'Burdinne', 'Burdinne', 'Bjurdin,Bjurdinn,Burdinne,bi er di ne,bwrdyn,Бюрдин,Бюрдинн,بوردین,比尔迪讷', 50.5845400, 5.0766300, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6537, 'Bullange', 'Bullange', 'Boellenge,Buellingen,Bullange,Bullingen,Böllénge,Büllingen', 50.4073100, 6.2574900, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6538, 'Buggenhout', 'Buggenhout', 'Buggenhout', 51.0159000, 4.2017300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6539, 'Brussels', 'Brussels', 'An Bhruiseil,An Bhruiséil,BRU,Breissel,Brisel,Brisele,Briuselis,Brjuksel,Brjusel'',Brjussel'',Brueksel,Bruessel,Bruesszel,Bruiseal,Bruksel,Bruksela,Brukseli,Brukselo,Brusehl'',Brusel,Brusela,Bruselas,Bruseles,Bruselj,Bruselo,Brusel·les,Brussel,Brussele,Brussels,Brussel·les,Bruxel,Bruxelas,Bruxellae,Bruxelles,Brwsel,Bryssel,Bryusel,Bryxelles,Bréissel,Brüksel,Brüssel,Brüsszel,Citta di Bruxelles,Città di Bruxelles,City of Brussels,Kota Brusel,beulwisel,braselsa,brassels,briuseli,brwksl,brysl,bu lu sai er,buryusseru,Βρυξέλλες,Брисел,Брусэль,Брюксел,Брюсель,Брюссель,Բրյուսել,בריסל,بروكسل,بروکسل,بريۇسسېل,ܒܪܘܟܣܠ,ब्रसेल्स,บรัสเซลส์,ბრიუსელი,ブリュッセル,布魯塞爾,布鲁塞尔,브뤼셀', 50.8504500, 4.3487800, 'BE', '2017-06-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6540, 'Brunehault', 'Brunehault', 'Brunehault,Brunehaut', 50.5052400, 4.4320900, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6541, 'Brugge', 'Brugge', 'Brige,Briuge,Briugė,Briz,Brizh,Briž,Brjuge,Brjugge,Broegge,Brudje,Bruegge,Brugae,Bruges,Brugge,Bruggy,Brugia,Brugo,Bruhhe,Brujas,Bruxas,Bruza,Bruĝo,Brycg,Brygge,Bryugge,Bryz,Brögge,Brügge,Gorad Brugeh,beulwiheo,briuge,bruch,bruja,brwj,brwkhh,brwyz,brwz,bu lu he,bu lu ri li shi zhong xin,buruhhe,Μπρυζ,Бриж,Брюгге,Брюге,Горад Бругэ,Բրյուգգե,ברוז,بروج,بروخه,برویز,ब्रूज,บรูช,ბრიუგე,ブルッヘ,布吕赫,布鲁日历史中心,브뤼허', 51.2089200, 3.2242400, 'BE', '2010-08-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6542, 'Brugelette', 'Brugelette', 'Brjuzhelet,Brjuzhlet,brwzhwlt,bu pu ri lie te,Брюжелет,Брюжлет,بروژولت,布普日列特', 50.5957700, 3.8536300, 'BE', '2009-01-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6543, 'Bree', 'Bree', 'Bree,Брее', 51.1415200, 5.5969000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6544, 'Bredene', 'Bredene', 'Bredene,Breedene,Breenienge,Brenienge,Breênienge,Brênienge', 51.2348900, 2.9755900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6545, 'Brecht', 'Brecht', 'Brecht,Brekht,brkt,bu lei he te,Брехт,برکت,布雷赫特', 51.3502400, 4.6382900, 'BE', '2011-02-11', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6546, 'Brasschaat', 'Brasschaat', 'Braschatas,Braskhat,Brasschaat,Brasschaep,Brasschaet,braskhat,bu la si ha te,Брасхат,براسخات,布拉斯哈特', 51.2912000, 4.4918200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6547, 'Braives', 'Braives', 'Braives,Braivesi vald,Brev,brw,bu lai wo,Брев,برو,布赖沃', 50.6174500, 5.1330200, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6548, 'Braine-le-Comte', 'Braine-le-Comte', '''s-Gravenbrakel,Braine-le-Comte,Brem-le-Kont,Bren l''o Kont,Bren-le-Kont,Brinne-e-Hinnot,s-Gravenbrakel,Брем-ле-Конт,Брен льо Конт,Брен-ле-Конт,برن‌لوکمت,’s-Gravenbrakel', 50.6097900, 4.1465800, 'BE', '2014-12-03', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6549, 'Braine-le-Château', 'Braine-le-Chateau', 'Braine-le-Chateau,Braine-le-Château,Kasteelbrakel', 50.6799000, 4.2738500, 'BE', '2011-01-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6550, 'Braine-l''Alleud', 'Braine-l''Alleud', 'Braine-l''Alleud,Braine-l’Alleud,Bren l''Al''o,Bren l''Ale,Bren-l''Alljo,Brinne-l''-Alou,Eigenbrakel,bu lai en la lei,Брен л''Але,Брен л''Альо,Брен-л''Аллё,برن‌للو,布赖恩拉勒', 50.6836300, 4.3678400, 'BE', '2014-02-20', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6551, 'Boutersem', 'Boutersem', 'Bautersem,Boutersem', 50.8351100, 4.8345000, 'BE', '2011-02-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6552, 'Boussu', 'Boussu', 'Boussu,Boussu-dle-Mont,Boussu-dlé-Mont,Boussu-lez-Mons,Busju,Bussju,bwsw,Боуссу,Буссю,Бусю,بوسو', 50.4341700, 3.7944000, 'BE', '2010-01-29', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6553, 'Bouillon', 'Bouillon', 'Bouillon,Bulen', 49.7932400, 5.0670300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6554, 'Borsbeek', 'Borsbeek', 'Borsbeek', 51.1966100, 4.4854300, 'BE', '2011-02-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6555, 'Bornem', 'Bornem', 'Bornem,Bornhem,bo er ne mu,bwrnm,Борнем,بورنم,博尔讷姆', 51.0971600, 4.2436400, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6556, 'Borgloon', 'Borgloon', 'Borgloon,Loeen,Loeën,Looz,Борглоон', 50.8050500, 5.3436600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6557, 'Boortmeerbeek', 'Boortmeerbeek', 'Boortmeerbeek', 50.9792900, 4.5744300, 'BE', '2011-02-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6558, 'Boom', 'Boom', 'Boom', 51.0924200, 4.3717000, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6559, 'Bonheiden', 'Bonheiden', 'Bonheyden', 51.0226100, 4.5471400, 'BE', '2008-06-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6560, 'Boechout', 'Boechout', 'Boechout,Bouchout', 51.1595900, 4.4919500, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6561, 'Bocholt', 'Bocholt', 'Bocholt,Boggetj,Bóggetj', 51.1733700, 5.5799400, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6562, 'Blégny', 'Blegny', '', 50.6725500, 5.7250800, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6563, 'Blankenberge', 'Blankenberge', 'Blank''nberge,Blankenberge,Blankenberghe,Blanknberge,blanknbrzh,bu lan ken bei er he,burankenberuhe,Бланкенберге,بلانکنبرژ,ブランケンベルヘ,布兰肯贝尔赫', 51.3130600, 3.1322700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6564, 'Binche', 'Binche', 'Bensh,Bince,Binche,Binchium,baengsyu,banshu,bnsh,Бенш,بنش,バンシュ,뱅슈', 50.4115500, 4.1646900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6565, 'Bilzen', 'Bilzen', 'Bilsen,Bilze,Bilzen,bi er ceng,bil sein,bylzan,Билзен,Білзен,بیلزان,บิลเซิน,比尔曾', 50.8732500, 5.5184000, 'BE', '2011-02-28', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6566, 'Bièvre', 'Bievre', 'Bievre,Bive,Bièvre', 49.9408500, 5.0159100, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6567, 'Bierbeek', 'Bierbeek', 'Bierbeek', 50.8287600, 4.7594900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6568, 'Beyne-Heusay', 'Beyne-Heusay', 'Beyne-Heusay', 50.6225100, 5.6650800, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6569, 'Beveren', 'Beveren', 'Beveren,Beveren Waas,Beveren-Waes,Beverenas,bebeleon,bei fu lun,bwwran,Беверен,بووران,贝弗伦,베베런', 51.2118700, 4.2563300, 'BE', '2014-12-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6570, 'Bever', 'Bever', '', 50.9166700, 4.3166700, 'BE', '2016-08-02', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6571, 'Bertrix', 'Bertrix', 'Bertri,Bertriks,Bertrix,Bietris,bei er te li,brtryks,Бертри,Бертрикс,برتریکس,贝尔特里', 49.8559600, 5.2553900, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6572, 'Bertogne', 'Bertogne', 'Berton,Berton'',Biertogne,bei er tuo nie,brtwny,Бертон,Бертонь,برتونی,贝尔托涅', 50.0836400, 5.6668900, 'BE', '2012-01-20', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6573, 'Bertem', 'Bertem', 'Bertem,Berthem', 50.8640300, 4.6291800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6574, 'Bernissart', 'Bernissart', 'Bernisar,Bernissar,bai ni sha he,brnysr,Бернисар,Берниссар,برنیسر,柏尼沙赫', 50.4746000, 3.6496100, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6575, 'Berloz', 'Berloz', 'Berlo,Berloz,Bierlo,Bierlô,bei er luo,brlwz,Берло,Берлоз,برلوز,贝尔洛', 50.6982900, 5.2123600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6576, 'Berlare', 'Berlare', 'Berlaere,Berlare,bei er la lei,brlr,Берларе,برلر,贝尔拉雷', 51.0333300, 4.0000000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6577, 'Berlaar', 'Berlaar', 'Berlaar,Berlaer', 51.1176000, 4.6583500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6578, 'Beringen', 'Beringen', 'Beeringen,Beringen,Beringenas,Beringene,Berringe,be xri ng khen,bei ling en,brnzhan,Беринген,Берингене,برنژان,เบอริงเคน,贝灵恩', 51.0495400, 5.2260600, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6579, 'Beloeil', 'Beloeil', 'Beloeil,Belœil', 50.5504700, 3.7348400, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6580, 'Bekkevoort', 'Bekkevoort', 'Becquevoort,Bekkevoort', 50.9407400, 4.9690000, 'BE', '2011-02-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6581, 'Begijnendijk', 'Begijnendijk', 'Beggynendyck', 51.0194200, 4.7837700, 'BE', '2011-02-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6582, 'Beersel', 'Beersel', 'Beersel,Bersel,bei er sai er,byrsl,Берсел,بئرسل,贝尔塞尔', 50.7658900, 4.3002000, 'BE', '2011-02-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6583, 'Beerse', 'Beerse', 'Beerse,Beersse', 51.3192700, 4.8530400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6584, 'Beernem', 'Beernem', 'Beernem,Bèèrnem', 51.1398100, 3.3389600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6585, 'Beauvechain', 'Beauvechain', 'Beauvechain,Bevekom,Boveshen,Bovetchen,Bovshen,Bôvetchén,bo fu shang,bwwshn,Бовешен,Бовшен,بووشن,博弗尚', 50.7819500, 4.7718000, 'BE', '2011-01-26', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6586, 'Beauraing', 'Beauraing', 'Beauraing,Biarin,Boren,bo lan,brn,Борен,برن,博兰', 50.1104200, 4.9555400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6587, 'Beaumont', 'Beaumont', 'Beaumont', 50.2369900, 4.2392600, 'BE', '2011-09-07', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6588, 'Bastogne', 'Bastogne', 'Baaschtnech,Bastenake,Bastenaken,Bastogne,Baston,Baston'',Bastona,Bastoña,Gorad Baston'',ba si tuo nie,baseutonyu,bastwn,basutonyu,paston,Μπαστόν,Бастон,Бастонь,Горад Бастонь,باستون,பாஸ்டோன்,バストーニュ,巴斯托涅,바스토뉴', 50.0034700, 5.7184400, 'BE', '2013-03-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6589, 'Bassenge', 'Bassenge', 'Basanzh,Bassange,Bassanzh,Bassenge,Bitsingen,ba sang ri,bsanzh,Басанж,Бассанж,بسانژ,巴桑日', 50.7588300, 5.6098900, 'BE', '2011-03-21', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6590, 'Basse Lasne', 'Basse Lasne', '', 50.6950300, 4.4921800, 'BE', '2017-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6591, 'Balen', 'Balen', 'Baelen,Balen,Balen-sur-Nethe,ba lun,blan,Бален,بلان,巴伦', 51.1683700, 5.1702700, 'BE', '2011-02-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6592, 'Baelen', 'Baelen', 'Baelen', 50.6313100, 5.9743300, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6593, 'Baarle-Hertog', 'Baarle-Hertog', 'Baarle-Chertonk,Baarle-Hertog,Baerle-Duc,Barle Khertog,Barle-Gertog,Barle-Khertog,ba er lei-he er tuo he,baleulleoheleutoheu,barure=herutofu,byrlrtwg,Μπάαρλε-Χέρτογκ,Барле Хертог,Барле-Гертог,Барле-Хертог,بئرلرتوگ,バールレ＝ヘルトフ,巴尔勒－赫尔托赫,바를러헤르토흐', 51.4050400, 4.8922600, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6594, 'Aywaille', 'Aywaille', 'Aiweye,Aiwêye,Aywaille,Ehvaj,Evaj,ai wa ye,ayway,ewayu,Евай,Эвай,ایوای,艾瓦耶,에와유', 50.4741100, 5.6768400, 'BE', '2011-03-25', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6595, 'Awans', 'Awans', 'Auans,Avan,Awan,Awans,a wang,awan,Αβάν,Аван,Ауанс,اوان,阿旺', 50.6677400, 5.4632900, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6596, 'Avelgem', 'Avelgem', 'Aovelhem,Avelgem,Avelghem', 50.7761800, 3.4450200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6597, 'Aubel', 'Aubel', 'Aobel,Aubel,Obel,Obel'',ao bo er,lawb,Обел,Обель,لاوب,奥伯尔', 50.7018900, 5.8581200, 'BE', '2011-03-24', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6598, 'Aubange', 'Aubange', 'Abindje,Aubange,Eibeng,Obanzh,ao bang ri,awbanzh,Åbindje,Éibeng,Обанж,اوبانژ,奥邦日', 49.5665200, 5.8049200, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6599, 'Attert', 'Attert', 'Attert', 49.7503500, 5.7863400, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6600, 'Ath', 'Ath', 'Aat,At,Ate,Ath,Athum,at,Ât,Ατ,Ат,ات', 50.6293700, 3.7780100, 'BE', '2009-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6601, 'Assesse', 'Assesse', 'Assesse', 50.3693400, 5.0220400, 'BE', '2011-04-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6602, 'Assenede', 'Assenede', 'Asenede,Assenede,Assenee,a sai nei de,asnwd,Асенеде,Ассенеде,اسنود,阿塞内德', 51.2259800, 3.7508500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6603, 'Asse', 'Asse', 'Ase,Assche,Asse,Asso,a se,as,aseo,Асе,Ассе,Ассо,اس,阿瑟,아서', 50.9101100, 4.1983600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6604, 'As', 'As', 'As,Asch', 51.0075500, 5.5845300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6605, 'Arlon', 'Arlon', 'Aarle,Aarlen,Arel,Arlon,Arlona,Arlonas,Arloni vald,Gorad Arlon,Orolaunum,QON,a er long,aleullong,arln,arlwn,aruron,Årlon,Αρλόν,Арлон,Горад Арлон,Արլոն,ארלון,آرلن,آرلون,アルロン,阿爾隆,아를롱', 49.6833300, 5.8166700, 'BE', '2008-06-16', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6606, 'Arendonk', 'Arendonk', 'Arendonck,Arendonk', 51.3226700, 5.0828900, 'BE', '2011-02-08', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6607, 'Ardooie', 'Ardooie', 'Ardooie,Ardoye', 50.9757000, 3.1973600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6608, 'Anzegem', 'Anzegem', 'Anseghem,Anzegem,Anzehem', 50.8370000, 3.4778600, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6609, 'Antwerpen', 'Antwerpen', 'ANR,Amberes,Amberis,Amversa,Anberes,Antuairp,Antuerpen,Antuerpia,Antuérpia,Antverpen,Antverpenas,Antverpene,Antverpeno,Antverpens,Antverpia,Antverpy,Antwarp,Antwerp,Antwerpa,Antwerpe,Antwerpen,Antwerpia,Antwerpium,Antwerpn,Antwyrpijo,Antwérp,Anvers,Anversa,Anverse,Anvèrs,Anvérse,Gorad Antverpen,Kota Antwerpen,On-thit-vi-phu,amtavarpa,an te wei pu,anteubeleupen,antou~erupen,antowapu,antverp,antwrb,antwrp,antwyrb,Ôn-thi̍t-ví-phú,Αμβέρσα,Антверпен,Горад Антверпен,Անտվերպեն,אנטווערפן,אנטוורפן,آنتورپ,أنتويرب,انتورب,انتويرب,انٹیورپ,अँटवर्प,ஆண்ட்வெர்ப்,ആന്റ്‌വെർപ്,แอนต์เวิร์ป,အန့်တွပ်မြို့,ანტვერპენი,アントウェルペン,アントワープ,安特卫普,安特衞普,안트베르펜', 51.2198900, 4.4034600, 'BE', '2012-10-10', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6610, 'Antoing', 'Antoing', 'Antoan,Antoing,antyan,Антоан,آنتئان', 50.5676500, 3.4492000, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6611, 'Anthisnes', 'Anthisnes', 'Antene,Anthisnes,Antin,Aubel,ang di en,antyzn,Антин,آنتیزن,昂蒂恩', 50.4832300, 5.5190000, 'BE', '2011-03-15', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6612, 'Ans', 'Ans', 'Ans,Anse,an,ang si,ansu,Анс,آن,アンス,昂斯', 50.6623000, 5.5202900, 'BE', '2011-03-14', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6613, 'Anhée', 'Anhee', 'Ane,Anhee,Anhee sur Meuse,Anheye,Anhée,Anhée sur Meuse,Anhêye,ang nei,anh,Ане,انه,昂内', 50.3103900, 4.8782700, 'BE', '2009-05-04', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6614, 'Anderlues', 'Anderlues', 'Anderlju,Anderlues,andrlw,Андерлю,آندرلو', 50.4070400, 4.2713600, 'BE', '2011-07-22', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6615, 'Andenne', 'Andenne', 'Anden,Andene,Andenn,Andenne,andn,ang dai ne,Анден,Анденн,آندن,昂代讷', 50.4894100, 5.0951300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6616, 'Amblève', 'Ambleve', 'Ambleve,Amblève,Amel', 50.3535700, 6.1700200, 'BE', '2011-03-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6617, 'Amay', 'Amay', 'Ama,Amay,Ame,a mai,amh,Аме,امه,阿迈', 50.5482900, 5.3097400, 'BE', '2011-03-17', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6618, 'Alveringem', 'Alveringem', 'Alveringem,Alveringhem,Oalveringem,a er fu ling e mu,alwwrnzhm,Алверингем,الوورنژم,阿尔弗灵厄姆', 51.0123800, 2.7111700, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6619, 'Alken', 'Alken', 'Alken,Alkén,Alleke', 50.8755300, 5.3055800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6620, 'Aiseau', 'Aiseau', 'Aiseau-Presles (Aiseau)', 50.4115800, 4.5867100, 'BE', '2011-08-01', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6621, 'Aartselaar', 'Aartselaar', 'Aartselaar,Aertselaer', 51.1341200, 4.3867800, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6622, 'Aarschot', 'Aarschot', 'Aarschot,Aarschoti vald,Aarshot,Aerschot,Arschotas,Arskhot,a er si huo te,aleuseuhos,arssht,arusukoto,Άαρσχοτ,Ааршот,Арсхот,آرسچوٹ,ارسشت,アールスコート,阿尔斯霍特,아르스홋', 50.9871500, 4.8369500, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6623, 'Aalter', 'Aalter', 'Aalter,Aeltre,Alter,Gemeente_Aalter,a er te,alth,Άαλτερ,Алтер,آلٹیر,الته,阿尔特', 51.0901700, 3.4469300, 'BE', '2012-01-18', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6624, 'Aalst', 'Aalst', 'Aalst,Alost', 50.9360400, 4.0355000, 'BE', '2014-12-23', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6625, 'Frasnes-lez-Anvaing', 'Frasnes-lez-Anvaing', 'Fraine-dile-Anvegn,Fraine-dilé-Anvegn,Fran lez Anven,Fran-lez-Anven,frazn-lh-anwn,Фран лез Анвен,Фран-лез-Анвен,فرازن-له-آنون', 50.6921100, 3.6356200, 'BE', '2011-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6626, 'Chastre', 'Chastre', 'Shastr,Shastur,Tchasse,Tchåsse,sha si te er,shstr,Шастр,Шастър,شستر,沙斯特尔', 50.6006700, 4.6340000, 'BE', '2011-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6627, 'Lennik', 'Lennik', 'Lenik,Lennik,lai ni ke,lnyk,Леник,Ленник,لنیک,莱尼克', 50.8090300, 4.1621900, 'BE', '2011-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6628, 'Laakdal', 'Laakdal', '', 51.0806700, 5.0055600, 'BE', '2011-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6629, 'Scherpenheuvel-Zichem', 'Scherpenheuvel-Zichem', 'Montaigu-Zichem,Sjerpenheuvel-Zichem,Skherpenkh''ovel-Zikhem,shrpnwlzyshm,si he er peng he gang er-qi ke mu,Схерпенхьовел-Зихем,شرپنولزیشم,斯赫尔彭赫纲尔－齐克姆', 51.0104100, 4.9749200, 'BE', '2011-07-31', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6630, 'Sint-Joris', 'Sint-Joris', '', 50.8711700, 5.2720000, 'BE', '2017-01-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6631, 'Terkoest', 'Terkoest', '', 50.8983200, 5.2762300, 'BE', '2017-01-05', 22);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6632, 'Zorgo', 'Zorgo', 'Zorgho,Zorgo,Zorogo', 12.2492200, -0.6152700, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6633, 'Ziniaré', 'Ziniare', 'Zimare,Zimaré,Zinarie,Zinarié,Ziniare,Ziniaré', 12.5818600, -1.2971000, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6634, 'Yako', 'Yako', 'Jako,Yako,Яко', 12.9591000, -2.2607500, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6635, 'Tougan', 'Tougan', 'TUQ,Tougan,Tugan,twgan,Туган,تؤگان', 13.0725000, -3.0694000, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6636, 'Toma', 'Toma', 'Toma', 12.7584400, -2.8987900, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6637, 'Titao', 'Titao', '', 13.7666700, -2.0666700, 'BF', '2010-08-02', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6638, 'Tenkodogo', 'Tenkodogo', 'TEG,Tenkodogas,Tenkodogo,teng ke duo ge,tenkodogo,tynkwdwgw,Тенкодого,تینکودوگو,滕科多戈,텐코도고', 11.7800000, -0.3697200, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6639, 'Salanso', 'Salanso', 'Salanso,Solenso,Solenzo', 12.1742300, -4.0847700, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6640, 'Sindou', 'Sindou', 'Sindou,Sindu', 10.6666700, -5.1666700, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6641, 'Sebba', 'Sebba', 'Sebba,XSE,Zebba', 13.4364100, 0.5304400, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6642, 'Sapouy', 'Sapouy', 'Sapoui,Sapouy,Sapui', 11.5544400, -1.7736100, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6643, 'Réo', 'Reo', 'Reo,Réo,Рео', 12.3196300, -2.4709400, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6644, 'Pô', 'Po', 'PUP,Po,Pô', 11.1697200, -1.1450000, 'BF', '2017-05-21', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6645, 'Pitmoaga', 'Pitmoaga', 'Pitmoaga', 12.2397200, -1.8766700, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6646, 'Pama', 'Pama', 'Pama,Panea,XPA', 11.2497200, 0.7075000, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6647, 'Oursi', 'Oursi', 'Oursi,Oursy,Worsi', 14.6755300, -0.4603300, 'BF', '2014-07-22', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6648, 'Ouargaye', 'Ouargaye', 'Ouargay,Ouargaye', 11.5020200, 0.0588600, 'BF', '2013-01-10', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6649, 'Ouahigouya', 'Ouahigouya', 'OUG,Ouahigouya,Uahiguja,Uakhiguja,Vakhiguja,Waiguya,wa xi gu ya,wahiguya,waiguya,Вахигуя,Уахігуя,ואיגויה,واہیگؤیا,ワヒグヤ,瓦希古亞,와이구야', 13.5827800, -2.4215800, 'BF', '2010-08-10', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6650, 'Ouagadougou', 'Ouagadougou', 'Gorad Uagadugu,Huagadugu,OUA,Ouagadouga,Ouagadougou,Ouankantounkou,Ougadougou,Owagadugu,Uagadougou,Uagadugu,Uagaduguo,Uagadugú,Uaqaduqu,Vagadugu,Wagadugu,awagadwgw,uagadugu,vagadugu,vakatuku,wa jia du gu,wa ka du ku,wagado~ugu,wagadugu,wagadwgw,wagadwwgww,waghadwghw,Ουαγκαντουγκού,Ουαγκαντούγκου,Горад Уагадугу,Уагадугу,Ուագադուգու,ואגאדוגו,וואגאדוגו,آواگادوگو,اوآگادوگو,اوگاڈوگو,واغادوغو,واگادووگوو,واگادوگو,वागाडुगू,ਵਾਗਾਦੁਗੂ,வாகடூகு,วากาดูกู,ཨོ་འ་ག་དོའུ་གོའུ།,უაგადუგუ,ዋጋዱጉ,ワガドゥグー,瓦加杜古,와가두구', 12.3656600, -1.5338800, 'BF', '2015-06-03', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6651, 'Nouna', 'Nouna', 'Nouna,XNU', 12.7293900, -3.8630500, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6972, 'Sitrah', 'Sitrah', 'Sitra,Sitrah,sitrat,strh,strt,sytrh,Ситра,סיטרה,سترة,ستره,سترہ,سِتْرَة', 26.1547200, 50.6205600, 'BH', '2015-05-06', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6973, 'Madīnat ‘Īsá', 'Madinat `Isa', 'Isa,Isa Town,Madinat `Isa,Madīnat ‘Īsá,Medinat Isa,مَدِينَة عِيسَى', 26.1736100, 50.5477800, 'BH', '2015-05-06', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6974, 'Jidd Ḩafş', 'Jidd Hafs', 'Djidd Hafs,Djidd Ḥafṣ,Jadd Hafs,Jid Hafs,Jidd Hafs,Jidd Ḩafş,Judd Hafs,Judd Ḩafş,jid hafs,جِدّ حَفْص', 26.2186100, 50.5477800, 'BH', '2012-01-18', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6975, 'Madīnat Ḩamad', 'Madinat Hamad', 'Hamad Town,Madinat Hamad,Madīnat Ḩamad,madinat hamad,مَدِينَة حَمَد', 26.1152800, 50.5069400, 'BH', '2017-03-22', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6976, 'Dār Kulayb', 'Dar Kulayb', 'Dar Chulaib,Dar Kulaib,Dar Kulayb,Dār Kulaib,Dār Kulayb,dar kulayb,دَار كُلَيْب', 26.0686100, 50.5038900, 'BH', '2015-05-06', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6977, 'Al Muharraq', 'Al Muharraq', 'Al Muharrak,Al Muharraq,Al Muḩarraq,Al''-Mukharrak,Al-Muharrak,Al-Muharraq,Al-Muḥarrak,Moharek,Muharrak,Muharraq,Muharraq Town,Muhurraq,aalmuharaq,mhrq,Аль-Мухаррак,اَلْمُحَرَّق,محرق', 26.2572200, 50.6119400, 'BH', '2013-06-27', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6978, 'Manama', 'Manama', 'Al Manama,Al Manamah,Al Manāma,Al Manāmah,Al-Manama,Al-Manamah,Al-Manāmah,Gorad Manama,Maenamae,Manaama,Manam,Manama,Manamae,Manamah,Manameh,Manamo,Manáma,Manāma,Menama,Mename,Mänamä,WGF,aalmanamat,almnamh,almnamt,mai na ma,mai na mai,manama,mnamh,mnamہ,Μανάμα,Горад Манама,Манамæ,Манама,Մանամա,מנאמה,المنامة,المنامه,اَلْمَنَامَة,منامه,منامہ,مەنامە,मनामा,মানামা,ਮਨਾਮਾ,ମାନାମା,மனாமா,മനാമ,มานามา,མ་ན་མ།,მანამა,ማናማ,マナーマ,麥納瑪,麦纳麦,마나마', 26.2278700, 50.5856500, 'BH', '2016-02-28', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6979, 'Al Ḩadd', 'Al Hadd', 'Al Hadd,Al Hidd,Al Ḩadd,Al Ḩidd,Hadd,Hidd,aalhad,اَلْحَدّ', 26.2455600, 50.6541700, 'BH', '2012-01-18', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6980, 'Ar Rifā‘', 'Ar Rifa''', 'Ar Rifa,Ar Rifa`,Ar Rifā‘,Riffa,اَلرِّفَاع', 26.1300000, 50.5550000, 'BH', '2015-05-06', 18);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7000, 'Tchaourou', 'Tchaourou', 'Chauru,Tchaourou', 8.8864900, 2.5975300, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7001, 'Tanguiéta', 'Tanguieta', 'Tangoueita,Tangueita,Tanguieta,Tanguiéta', 10.6211800, 1.2665100, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7002, 'Savé', 'Save', 'SVF,Save,Savé', 8.0342400, 2.4866000, 'BJ', '2013-05-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7003, 'Savalou', 'Savalou', 'Savalou,Savalu', 7.9280700, 1.9755800, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7004, 'Sakété', 'Sakete', 'Sakete,Sakété', 6.7361800, 2.6586600, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7005, 'Porto-Novo', 'Porto-Novo', 'Borto-Novo,Gorad Porta-Nova,Porto Neuvo,Porto Nobo,Porto Novas,Porto Novo,Porto-Novo,Portonovo,Portus Novus,Poto-Novo,Pòrto Neuvo,Pòto-Novo,Pôrto-Novo,bo duo nuo fu,bo tu nu bu,bwrtw nwfw,poleutonobo,porato-novo,porto-novho,porutonobo,pwrtw nwbw,pwrtw nwww,pxr to-no wo,xin gang,Πόρτο Νόβο,Πόρτο-Νόβο,Горад Порта-Нова,Порто Ново,Порто-Ново,Պորտո Նովո,פארטא-נאווא,פורטו נובו,بورتو نوفو,پورتو نووو,پورٹو نووو,پۆرتۆ نۆڤۆ,पोर्तो-नोव्हो,ਪੋਰਤੋ-ਨੋਵੋ,ปอร์โต-โนโว,པོར་ཊོ་-ནོ་བོ།,პორტო-ნოვო,ፖርቶ ኖቮ,ポルトノボ,新港,波圖奴埠,波多诺伏,포르토노보', 6.4964600, 2.6035900, 'BJ', '2011-03-04', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7006, 'Pobé', 'Pobe', 'Ipobe,Pobe,Pobé', 6.9800800, 2.6649000, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7007, 'Parakou', 'Parakou', 'PKO,Parakou,Paraku,pa la ku,palaku,paraku,parakw  bnyn,Параку,פאראקו,پاراکو، بنین,パラクー,帕拉庫,파라쿠', 9.3371600, 2.6303100, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7008, 'Ouidah', 'Ouidah', 'Fortaleza de Sao Joao Baptista de Ajuda,Fortaleza de São João Baptista de Ajudá,Ouidah,Sao Joao Baptista de Ajuda,São João Baptista de Ajudá,Vidy,Whydah,Wida,sheng yue han bao,Виды,圣约翰堡', 6.3630700, 2.0850600, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7009, 'Nikki', 'Nikki', 'Nikki,Никки', 9.9400900, 3.2107500, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7010, 'Natitingou', 'Natitingou', 'NAE,Natitingou,Natitingu,Натитингу', 10.3041600, 1.3796200, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7011, 'Malanville', 'Malanville', 'Malanvilem,Malanville,Mallanville,Маланвилем', 11.8681900, 3.3832700, 'BJ', '2012-04-25', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7012, 'Lokossa', 'Lokossa', 'Locossa,Lokossa', 6.6386900, 1.7167400, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7013, 'Kétou', 'Ketou', 'Ketou,Ketu,Kétou', 7.3633200, 2.5997800, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7014, 'Kandi', 'Kandi', 'KDC,Kandi,Kandis,kandi,kandy  bynn,kang di,kndy  bnyn,Канди,کاندی، بینن,کندی، بنین,カンディ,康迪,칸디', 11.1341700, 2.9386100, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7015, 'Hinvi', 'Hinvi', 'Henvi,Hinvi', 6.7666700, 2.1666700, 'BJ', '2013-06-06', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7016, 'Hévié', 'Hevie', 'Hevie,Hévié', 6.4166700, 2.2500000, 'BJ', '2013-06-06', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7017, 'Guilmaro', 'Guilmaro', 'Guilmaro', 10.5658300, 1.7244400, 'BJ', '2013-05-05', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7018, 'Grand-Popo', 'Grand-Popo', 'Ghola,Grand-Popo,Great Popo,Kpla', 6.2803600, 1.8225100, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7019, 'Dogbo', 'Dogbo', '', 6.8166700, 1.7833300, 'BJ', '2006-01-17', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7020, 'Djougou', 'Djougou', 'DJA,Djougou,Jugu', 9.7085300, 1.6659800, 'BJ', '2013-08-17', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7021, 'Dassa-Zoumé', 'Dassa-Zoume', 'Dassa Zume,Dassa-Zoume,Dassa-Zoumé', 7.7500000, 2.1833300, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7022, 'Cové', 'Cove', 'Kove,Kové', 7.2209700, 2.3401700, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7023, 'Cotonou', 'Cotonou', 'Appi,COO,Catonou,Cotonou,Cotonu,Cotonú,Gorad Katanu,Kotonou,Kotonu,Kotonuo,Kutonu,Kútọnu,ji da nu,ke tuo nu,kotonu,kottonau,kwtwnw,qwtwnw,Κοτονού,Горад Катану,Котону,קוטונו,كوتونو,کوتونو,कोतोनू,ਕੋਤੋਨੂ,கொட்டொனௌ,კოტონუ,コトヌー,吉大奴,科托努,코토누', 6.3653600, 2.4183300, 'BJ', '2017-07-27', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7024, 'Comé', 'Come', 'Come,Comé,Kome,Komé', 6.4076400, 1.8819800, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7025, 'Bohicon', 'Bohicon', 'Bohicon', 7.1782600, 2.0667000, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7026, 'Bétérou', 'Beterou', 'Beterou,Bétérou', 9.1991600, 2.2585500, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7027, 'Bembèrèkè', 'Bembereke', 'Bembereke,Bembèrèkè,Bimbereke,Bimbéréké', 10.2282700, 2.6633500, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7028, 'Bassila', 'Bassila', 'Bassila,basyla  bnyn,Бассіла,باسیلا، بنین', 9.0081400, 1.6654000, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7029, 'Banikoara', 'Banikoara', 'Banikoara', 11.2984500, 2.4385600, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7030, 'Aplahoué', 'Aplahoue', 'Aplahoue,Aplahoué,Parahoue,Parahoué,Parahue', 6.9333300, 1.6833300, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7031, 'Allada', 'Allada', 'Allada', 6.6654700, 2.1513800, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7032, 'Abomey-Calavi', 'Abomey-Calavi', 'Abome Calavi,Abomej-Kalavi,Abomey-Calavi,Kalavi,Абомей-Калави', 6.4485200, 2.3556600, 'BJ', '2012-10-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7033, 'Abomey', 'Abomey', 'Abome,Abomei,Abomej,Abomey,Palacios Reais de Abomei,Palácios Reais de Abomei,Абомей', 7.1828600, 1.9911900, 'BJ', '2012-01-18', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7034, 'Houinvigue', 'Houinvigue', '', 6.8862000, 2.4806000, 'BJ', '2016-09-26', 24);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7036, 'Saint George', 'Saint George', 'Saint George,Saint George''s,Saint George''s Town,Saint Georges,Saint George’s,Saint George’s Town,Sankta Georgo,Sent Dzordzas,Sent Džordžas,Sent-Dzhordzh,seinteujojiseu,sheng qiao zhi si,snt gwrgs,snt jwrj  brmwda,Сент-Джордж,סנט גורגס,سنت جورج، برمودا,سینٹ جارج، برمودا,სენტ-ჯორჯესი,セント・ジョージ,圣乔治斯,세인트조지스', 32.3816700, -64.6780600, 'BM', '2012-01-18', 25);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7037, 'Hamilton', 'Hamilton', 'BDA,Chamilton,Gamil''ton,Gorad Gamil''tan,Hamilton,Hamilton pa Bermuda,Hamilton på Bermuda,Hamiltonas,Hamiltono,Khamilton,Khamiltun,amiltan,ha mi er dun,haemilteon,hamiruton,hamyltwn,hemiltana,hmyltwn,Χάμιλτον,Гамильтон,Гамільтон,Горад Гамільтан,Хамилтон,Хамилтън,המילטון,هاميلتون,همیلتون,ہیملٹن,हॅमिल्टन,ஆமில்டன்,แฮมิลตัน,ჰამილტონი,ハミルトン,哈密尔顿,해밀턴', 32.2949000, -64.7830300, 'BM', '2014-09-21', 25);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7043, 'San Pedro', 'San Pedro', '', -18.2833300, -59.8166700, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7038, 'Tutong', 'Tutong', 'Tutong', 4.8000000, 114.6500000, 'BN', '2013-06-27', 34);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7039, 'Seria', 'Seria', 'Seria,Serija,seria,sex reiy,Сериа,Серия,เซอเรีย,セリア', 4.6063700, 114.3247600, 'BN', '2013-06-09', 34);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7040, 'Kuala Belait', 'Kuala Belait', 'Belait,KUB,Kuala Belait,Kuala-Belajt,Kvala Belaitas,Kwala Belait,kuallabeullais,kuaraburaito,ma lai yi,Куала-Белайт,קואלה בלייט,クアラブライト,马来奕,쿠알라블라잇', 4.5836100, 114.2312000, 'BN', '2013-06-27', 34);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7041, 'Bangar', 'Bangar', 'Bangar,Temburong', 4.7166700, 115.0666700, 'BN', '2013-06-27', 34);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7042, 'Bandar Seri Begawan', 'Bandar Seri Begawan', 'BWN,Banda Seri,Bandar Seri Begauan,Bandar Seri Begavan,Bandar Seri Begavanas,Bandar Seri Begawan,Bandar Sery Begawan,Bandar-Seri-Begavan,Bandar-Seri-Begavano,Bandarseribegavana,Brunei,Brunei Town,Bruni,Gorad Bandar-Sery-Begavan,Mpantar Seri Mpenkaban,badara seri begavana,ban dar se ribe ka wan,bandaleuseulibeugawan,bandar seri bagevan,bandar-seri-begavani,bandara seri bega''oyana,bandara seri begavana,bandara sri bagavana,bandarusuribugawan,bndr sry bgawan,bndr sry bkawan,bndr sry bygwan,pantar ceri pekavan,si li ba jia wan,si li ba jia wan shi,sry bgawan,Μπαντάρ Σερί Μπεγκαβάν,Бандар Сери Бегаван,Бандар-Сери-Бегаван,Бандар-Сері-Бегаван,Горад Бандар-Серы-Бегаван,Բանդար Սերի Բեգավան,בנדר סרי בגוואן,باندار سەرى بەگاۋان,بندر سري بكاوان,بندر سری بگاوان,بندر سری بیگوان,بەندەر سێری بێگاوان,سری بگاوان,बंदर स्री बगवान,बन्दर सेरी बेगवान,बन्दर सेरी बेगावान,বন্দর সেরি বেগাওয়ান,ਬੰਦਰ ਸੇਰੀ ਬੇਗਵਾਨ,பண்டர் செரி பெகாவான்,ಬಂದರ್ ಸೆರಿ ಬಗೆವನ್,ബന്ദർ സെരി ബെഗവൻ,บันดาร์เสรีเบกาวัน,སི་རི་པེ་ཀ་མཚོ་ཁུགས་གྲོང་ཁྱེར།,ဘန်ဒါဆရီဘဂါဝမ်မြို့,ბანდარ-სერი-ბეგავანი,ባንዳር ሰሪ ቤጋዋን,バンダルスリブガワン,斯里巴加湾市,斯里巴加灣,斯里巴加灣市,반다르스리브가완', 4.9402900, 114.9480600, 'BN', '2010-05-28', 34);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6688, 'Beloslav', 'Beloslav', 'Belevo,Belewo,Beloslav,Beloslaw,Belovo,Bielevo,Bjelevo,Byelevo,Gebedze,Gebedzhe,Gebedže,Белослав', 43.1833300, 27.7000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6689, 'Zlatograd', 'Zlatograd', 'Dara-Dere,Daridere,Dară-Dere,Darıdere,Slatograd,Zlatograd,Zlatograde,Zlatonkrant,Zlatoqrad,Złatograd,zi la tuo ge lei,zlatwgrad,Ζλάτογκραντ,Златоград,זלאטוגרד,زلاتوگراد,زلاتۆگراد,茲拉托格勒', 41.3795000, 25.0960500, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6690, 'Zlatitsa', 'Zlatitsa', 'Slatiza,Zlatica,Zlatitsa,Zlatitza,Zlatiza,Златица', 42.7166700, 24.1333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6691, 'Zlataritsa', 'Zlataritsa', 'Slatariza,Zlatarica,Zlataritsa,Zlataritza,Златарица', 43.0500000, 25.9000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6692, 'Zemen', 'Zemen', 'Belovo,Bjelovo,Byelovo,Semen,Zemen,Земен', 42.4788900, 22.7491700, 'BG', '2017-02-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6693, 'Zelenikovo', 'Zelenikovo', 'Amzalare,Amzulare,Amzŭlare,Hamzalare,Khamzalare,Selenikowo,Zelenikovo,Зелениково', 42.4000000, 25.0833300, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6694, 'Zavet', 'Zavet', 'Sawet,Zavet,Zavjet,Zavot,Zavut,Zavyet,Завет', 43.7666700, 26.6666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6695, 'Yambol', 'Yambol', 'Iambol,JAM,Jambol,Jamboli,Yambol,Yampolis,Ямбол', 42.4833300, 26.5000000, 'BG', '2017-01-30', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6696, 'Yakoruda', 'Yakoruda', 'Jakoruda,Johurut,Jokoruda,Yakoruda,Yokoruda,Якоруда', 42.0252800, 23.6841700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6697, 'Yakimovo', 'Yakimovo', 'Jakimovo,Kotenovtsi,Progorelets,Voynitsi,Yakimovo,Якимово', 43.6430600, 23.3677800, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6698, 'Yablanitsa', 'Yablanitsa', 'Ablanitsa,Iablanica,Jablanica,Jablaniza,Jablonica,Yablanitsa,Ябланица', 43.0313900, 24.1127800, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6699, 'Varshets', 'Varshets', 'Varshets,Varshetz,Vershets,Vresec,Vrešec,Vrsec,Vrshets,Vršec,Vursec,Vurshec,Vurshets,Vuršec,Vărshets,Vŭrshets,Warschez,Wărschez,Вършец', 43.1952800, 23.2861100, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6700, 'Varbitsa', 'Varbitsa', 'Varbitsa,Virbica,Vrbica,Vrbitsa,Vurbica,Vurbitsa,Vărbitsa,Vŭrbitsa,Warbiza,Wărbiza,Върбица', 43.0000000, 26.6333300, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6701, 'Valchidol', 'Valchidol', 'Kurt Dere,Valchidol,Vulchidol,Vŭlchidol,Waltschi Dol,Вълчидол', 43.4000000, 27.5500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6702, 'Valchedram', 'Valchedram', 'Valchedarma,Valchedram,Valtchedram,Valtchidarma,Vlcdrma,Vlcedrama,Vlcedrma,Vlchedrma,Vlcidrama,Vlčdrma,Vlčedrama,Vlčedrma,Vlčidrama,Vulcedurma,Vulchedrum,Vulchedurma,Vălchedărma,Vŭlchedrŭm,Vŭlchedŭrma,Vŭlčedŭrma,Waltschedrama,Waltschedrăma,Вълчедръм', 43.6963900, 23.4447200, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6703, 'Vratsa', 'Vratsa', 'Ivraca,Vraca,Vracae,Vrata,Vratca,Vratsa,Vrattsa,Vratza,Vrața,Wraca,Wraza,beulacha,fratsa,fu la cha,vratsa,vuratsu~a,wratsa,İvraca,Βράτσα,Врацæ,Враца,וראצה,فراتسا,وراتسا,ڤراتسا,ヴラツァ,弗拉察,브라차', 43.2100000, 23.5625000, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6704, 'Sveti Vlas', 'Sveti Vlas', 'Manasturkioy,Manastŭrkioy,Monasturkioy,Monastŭrkioy,Saint Vlas,Sveti Vlas,Sveti-Vlas,Sweti Wlas,Vlas,Влас,Свети-Влас', 42.7136000, 27.7586700, 'BG', '2010-03-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6705, 'Vidin', 'Vidin', 'Vidin,Vidinas,Vidine,Vidinu,Vintin,Widin,Widyn,Widyń,bidin,fydn,vu~idin,wdyn,wei ding,wydyn,Βίντιν,Видин,Видинъ,וידין,فيدن,ودین,ویدین,ヴィディン,維丁,비딘', 43.9900000, 22.8725000, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6706, 'Vetrino', 'Vetrino', 'Asya-Tepe,Jasi Tepe,Vetrino,Vyetreno,Vyetrino,Wetrino,Yasa-Tepe,Yase-Tepe,Yasu-Tepe,Yasă-Tepe,Yasŭ-Tepe,Ветрино', 43.3166700, 27.4333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6707, 'Vetovo', 'Vetovo', 'Vetova,Vetovo,Vjetevo,Vyetovo,Wetowo,Ветово', 43.7000000, 26.2666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6708, 'Venets', 'Venets', 'K''okledzha,K''oklyudzha,K''okyudzha,Kiokhudza,Kiokhudža,Kokedzha,K’okledzha,K’oklyudzha,K’okyudzha,Venec,Venets,Vyenets,Wenez,Венец', 43.5500000, 26.9333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6709, 'Velingrad', 'Velingrad', 'Velingrad,Velingradas,Velinkrant,Welingrad,bellingeuladeu,vu~eringurato,wei lin ge lei,wlyngrad,Βέλιγκραντ,Велинград,ולינגראד,ولینگراد,ڤێلینگراد,ヴェリングラト,韋林格勒,벨린그라드', 42.0275400, 23.9915500, 'BG', '2013-12-06', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6710, 'Veliko Tŭrnovo', 'Veliko Turnovo', 'Tarnovo,Tarnowo,Ternovo,Tirnovo,Trnova,Trnovo,Turnovo,Tărnovo,Tărnowo,Tŭrnovo,Veliko T"rnovo,Veliko Tarnovo,Veliko Tărnovo,Weliko Tarnowo,Wielkie Tyrnowo,vu~eriko・tarunovu~o,Велико Търново,ヴェリコ・タルノヴォ', 43.0812400, 25.6290400, 'BG', '2007-07-01', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6711, 'Varna', 'Varna', 'Barna,Gorad Varna,Odessos,Odessus,Stalin,VAR,Varna,Varna khot,Varnae,Várna,Warna,baleuna,farna,varna,vharna,vu~aruna,wa er na,war na,warna,wʼrnh,Βάρνα,Варнæ,Варна,Варна хот,Горад Варна,Վառնա,וארנה,فارنا,وارنا,व्हर्ना,วาร์นา,ვარნა,ヴァルナ,瓦爾納,바르나', 43.2166700, 27.9166700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6712, 'Ugarchin', 'Ugarchin', 'Ugarchin,Ugarcin,Ugartschin,Ugarčin,Ugirkin,Ugrchin,Ugrcin,Ugrčin,Ugurchin,Ugurcin,Ugürčin,Ugărchin,Ugărtschin,Ugŭrchin,Угърчин', 43.1000000, 24.4166700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6713, 'Tvarditsa', 'Tvarditsa', 'Tvardica,Tvarditsa,Tvarditza,Tverditsa,Tvrdica,Tvrditsa,Tvurdica,Tvurditsa,Tvŭrdica,Tvŭrditsa,Twardiza,Twărdiza,Твърдица', 42.7000000, 25.9000000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6714, 'Tutrakan', 'Tutrakan', 'Turtucaia,Turtukai,Tutrakan,Tutrakanas,Tutrakhan,tu te la kan,twtrakan,Тутракан,טוטראקן,توتراکان,圖特拉坎', 44.0500000, 26.6166700, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6715, 'Targovishte', 'Targovishte', 'Eski Cuma,Eski Djoumaia,Eski Djoumaïa,Eski Dschumaja,Eski Dzhumaya,Eski Dzuma,Eski Dzumaja,Eski Dzumaya,Eski Džuma,Eski Džumaja,TGV,Targovichte,Targovichté,Targovishte,Targovisjte,Targoviste,Targovixte,Targoviŝte,Targowischte,Targòvixte,Tarnkoviste,Tergovishce,Tergoviste,Tergovištė,Tirgovishte,Trgovishte,Trgoviste,Trgovište,Turgovishhe,Turgovishte,Turgoviste,Tyrgovishte,Tyrgowiszte,Tërgovishçe,Tărgovište,Tărgoviște,Tărgowischte,Tŭrgovishte,Tŭrgovište,Tǎrgovište,targhwfyshth,te er ge wei shen te,teoleugobisyute,trgwbysth,Ταργκόβιστε,Тирговиште,Трговиште,Търговище,Тырговиште,טרגובישטה,تارغوفيشته,ترگوویشتے,ترگوویشتے ،بلغاریہ,特爾戈維什特,터르고비슈테', 43.2512000, 26.5721500, 'BG', '2013-06-10', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6716, 'Tsenovo', 'Tsenovo', 'Causevo,Causkioj,Causovo,Cauševo,Cauškiöj,Cenevo,Cenovo,Chaushevo,Chaushovo,Tenovo,Tsenovo,Zenowo,Čaušovo,Čenevo,Ценово', 43.5358800, 25.6576400, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6717, 'Tryavna', 'Tryavna', 'Treavna,Trevna,Trewna,Triavna,Trjavna,Trjawna,Tryavna,Tryevna,Trěvna,te li ya fu na,toryavuna,tryavna,tryawna,Трявна,Трјавна,טריאבנה,تریاونا,تریاڤنا,トリャヴナ,特里亞夫納', 42.8666700, 25.5000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6718, 'Tran', 'Tran', 'Tran,Tren,Trin,Trn,Trun,Trăn,Trŭn,Трън', 42.8352800, 22.6516700, 'BG', '2017-03-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6719, 'Troyan', 'Troyan', 'Comuna Troian,Gmina Trojan,Obshhina Trojan,Troian,Trojan,Troyan Municipality,Troïan,te luo yang shi,Община Троян,Троян,ტროიანის თემი,特羅揚市', 42.8942700, 24.7158900, 'BG', '2007-07-10', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6720, 'Topolovo', 'Topolovo', 'Takhtalii,Topolovo,Topolowo,Тополово', 41.9000000, 25.0000000, 'BG', '2017-03-11', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6721, 'Topolovgrad', 'Topolovgrad', 'Kavakli,Kavaklii,Kavakly,Topolovgrad,Topolovgrade,Topolowgrad,Topołowgrad,tuo bo luo fu ge lei,twpwlwfgrad,Тополовград,توپولوفگراد,تۆپۆلۆڤگراد,托波洛夫格勒', 42.0833300, 26.3333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6722, 'Dobrich', 'Dobrich', 'Bazargic,Dobric,Dobrich,Dobrici,Dobricius,Dobricz,Dobritch,Dobritj,Dobrits,Dobritsch,Dobritsj,Dobritx,Dobritš,Dobriç,Dobriĉ,Dobrič,Dobričius,Dòbritx,Gorad Dobrych,Hadzi-Oghlu-Pazardzik,Hadži-Oghlu-Pazardžik,Khadzhioglu Bazardzhik,Khadzhioglu Pazardzhik,Ntomprits,Tolbuhin,Tolbukhin,dobeulichi,doburichi,duo bu li qi,dwbrch,dwbrych,dwbrytsh,dwbryz,Ντόμπριτς,Горад Добрыч,Добрич,Դոբրիչ,דובריץ,دوبريتش,دوبرچ,دوبریچ,ドブリチ,多布里奇,도브리치', 43.5666700, 27.8333300, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6723, 'Tochilari', 'Tochilari', 'Musakhchilar,Musatchilar,Tochilari,Totschilari,Точилари', 43.8500000, 26.4666700, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6724, 'Teteven', 'Teteven', 'Teteven,Tetevene,Tetewene,Тетевен', 42.9166700, 24.2666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6725, 'Tervel', 'Tervel', 'Comuna Tervel,Curt Bunar,Curtburnar,Dshami Machala,Gmina Terwel,Gmina Terweł,Kurt Bunar,Municipio de Tervel,Município de Tervel,Obshhina Tervel,Tervel,Tervel Municipality,tai er wei er shi,Община Тервел,Тервел,ტერველის თემი,泰爾韋爾市', 43.7500000, 27.4000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6726, 'Batanovtsi', 'Batanovtsi', 'Batanovci,Batanovitsi,Batanovtsi,Batanovtzi,Batanowzi,Temelkovo,Батановци', 42.5997200, 22.9505600, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6727, 'Svoge', 'Svoge', 'Svogbe,Svoge,Svoghe,Svoghé,Svogja,Svogje,Swoge,Своге', 42.9666700, 23.3500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6728, 'Svishtov', 'Svishtov', 'Novae,Novensis Moesia Civitas,Sistov,Sistova,Staklen,Steklen,Sveyestov,Svisclov,Svishhov,Svishtov,Svislova,Svistov,Svišlova,Svištov,Swischtow,Свищов', 43.6195900, 25.3504400, 'BG', '2013-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6729, 'Svilengrad', 'Svilengrad', 'Cisri Mustafapasa,Cisri Mustafapaşa,Mustafa-Pasha,Mustafapasa,Mustafapaşa,Slivengrad,Svilen,Svilengrad,Svilengradas,Svilengrade,Swilengrad,aswylngrad,si wei lun ge lei,Свиленград,סבילנגראד,اسویلنگراد,سڤیلێنگراد,斯維倫格勒', 41.7666700, 26.2000000, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6730, 'Suvorovo', 'Suvorovo', 'Kozludza,Kozludzha,Kozludža,Novgradets,Nowgradez,Suvorovo,qwzlwjh,qwzlyjh,Суворово,قوزلوجه,قوزلیجه', 43.3333300, 27.6000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6731, 'Sarnitsa', 'Sarnitsa', 'S''rnitsa,Sarnitsa,Sarniza,Shabanli,Surnica,Surnitsa,Sŭrnitsa,S’rnitsa,Сърница', 41.7383500, 24.0243500, 'BG', '2017-01-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6732, 'Sungurlare', 'Sungurlare', 'Sungulare,Sungulari,Sungurlar,Sungurlare,Sungurlari,Сунгурларе', 42.7666700, 26.7833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6733, 'Suhindol', 'Suhindol', 'Souhyndol,Suchindol,Suhindol,Sukhindol,Сухиндол', 43.1916700, 25.1811100, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6734, 'Saedinenie', 'Saedinenie', 'Golemo Konare,Goljamo Konare,Goljemo Konare,Goljemo Konari,Golyamo Konare,Golyemo-Konare,Saedinenie,Suedinenie,Sŭedinenie,Съединение', 42.2666700, 24.5500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6735, 'Strumyani', 'Strumyani', 'Strumjani,Strumyani,Струмяни', 41.6333300, 23.2000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6736, 'Strelcha', 'Strelcha', 'Strelca,Strelcha,Streltscha,Strelča,Strjelca,Strjelča,Stryelcha,Стрелча', 42.5000000, 24.3166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6737, 'Strazhitsa', 'Strazhitsa', 'Kada K''oy,Kada K’oy,Kadikioy,Strajitsa,Strajitza,Strashiza,Strazhica,Strazhitsa,Strazica,Stražica,Стражица', 43.2333300, 25.9666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6738, 'Straldzha', 'Straldzha', 'Straldsha,Straldza,Straldzha,Straldža,Стралджа', 42.6000000, 26.6833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6739, 'Stara Zagora', 'Stara Zagora', 'Eski Zagra,Eski Zağra,Gorad Stara-Zagora,SZR,Stara Sagora,Stara Zagora,Stara-Zagora,Stara-Zagorae,Stará Zagora,astara zagwra,jiu zha ge la,seutalajagola,stara zaghwra,stara zagwra,Στάρα Ζαγόρα,Горад Стара-Загора,Стара Загора,Стара Ꙁагора,Стара-Загорæ,Стара-Загора,Ստարա Զագորա,סטארה זאגורה,استارا زاگورا,ستارا زاغورا,ستارا زاگورا,სტარა-ზაგორა,スタラ・ザゴラ,舊扎戈拉,스타라자고라', 42.4327800, 25.6419400, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6740, 'Stara Kresna', 'Stara Kresna', 'Kresna,Stara Kresna,Стара Кресна', 41.8000000, 23.1833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6741, 'Dupnitsa', 'Dupnitsa', 'Doepnitsa,Doupnitsa,Doupnitza,Dubnica,Dupnica,Dupnicja,Dupnita,Dupnitsa,Dupnitza,Dupniza,Dupnița,Marek,Ntoupnitsa,Stanke Dimitrov,Stanke Dimitrovo,do~upunitsu~a,du pu ni cha,dupeunicha,dwpnytsa,dwpnyzh,Ντούπνιτσα,Дупница,Дупниця,דופניצה,دوپنیتسا,ドゥプニツァ,杜普尼察,두프니차', 42.2666700, 23.1166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6742, 'Stamboliyski', 'Stamboliyski', 'Gara Krichim,Krichim,Novi Krichim,Stambolijski,Stamboliyski,Stamoboliyski,Стамболийски', 42.1333300, 24.5333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6743, 'Spasovo', 'Spasovo', 'Spasova,Spasovo,Suleimanlak,Syuleymanluk,Syuleymanlŭk,Süleimanlăk,Спасово', 43.7016800, 28.3039900, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6744, 'Sozopol', 'Sozopol', 'Apollonia,Sizebolu,Sizopol,Sosopol,Sozopol,Sozopol'',Sozopole,Sozopolis,sozoporu,suo zuo bo er,swzwpwl,Σωζόπολη,Созопол,Созополь,סוזופול,سوزوپول,سۆزۆپۆل,ソゾポル,索佐波爾', 42.4166700, 27.7000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6745, 'Sofia', 'Sofia', 'Gorad Safija,SOF,Serdica,Sofi,Sofia,Sofiae,Sofie,Sofii,Sofij,Sofija,Sofija osh,Sofijo,Sofio,Sofiya,Sofiä,Sofiýa,Sofja,Sofya,Sofía,Soifia,Sophia,Sredets,Suofeje,Suofėjė,Szofia,Szófia,Sòfia,Sófia,Sófía,Sóifia,Ulpia Serdica,cohviya,saphiya,seaphiya,sofeiy,sofi''a,sofia,sophiya,sopia,suo fei ya,swfya,swfyh,swpyh,Σόφια,Горад Сафія,Софи,Софий,София,София ош,Софија,Софія,Софїꙗ,Սոֆիա,סאפיע,סופיה,سوفىيە,سۆفیا,صوفيا,صوفیه,صوفیہ,صوٙفیە,सोफिया,সফিয়া,ਸੋਫ਼ੀਆ,சோஃவியா,സോഫിയ,โซเฟีย,སོ་ཧྥི་ཡ།,სოფია,ሶፊያ,ソフィア,索菲亞,소피아,', 42.6975100, 23.3241500, 'BG', '2011-06-16', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6746, 'Smyadovo', 'Smyadovo', 'Smedovo,Smedowo,Smjadovo,Smjedovo,Smyadovo,Smyedovo,Смядово', 43.0666700, 27.0166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6747, 'Smolyan', 'Smolyan', 'Paschmaklii,Pashmakla,Pashmakli,Pashmaklă,Pasmakli,Pasmakly,Pašmakli,Smolian,Smoljan,Smolyan,Смолян', 41.5852800, 24.6919400, 'BG', '2016-04-16', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6748, 'Slivo Pole', 'Slivo Pole', 'Kashikler,Kaya Makhle,Slivitsa,Slivo Pole,Sliwiza,Sliwo Pole,Сливо Поле', 43.9424800, 26.2046400, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6749, 'Slivnitsa', 'Slivnitsa', 'Slivica,Slivnica,Slivnitsa,Slivnitza,Sliwniza,Сливница', 42.8518200, 23.0379200, 'BG', '2017-03-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6750, 'Sliven', 'Sliven', 'Gorad Sliven,Islimiye,Islimje,Sliven,Slivenas,Slivno,Sliwen,aslmyh,aslywn,seulliben,si li wen,sliveni,slybn,slyfn,slywyn,surivu~en,sylwyn,Σλίβεν,Горад Слівен,Сливен,Слівен,סליבן,اسلمیه,اسلیون,سليفن,سلیوین,سلیڤێن,سیلوین,სლივენი,スリヴェン,斯利文,슬리벤', 42.6858300, 26.3291700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6751, 'Slavyanovo', 'Slavyanovo', 'Slavianovo,Slavjanovo,Slavyanovo,Slawjanowo,Trastenik,Trstenik,Trustenik,Trăstenik,Trŭstenik,Turska Trestenik,Turski Trustenik,Turski Trŭstenik,Славяново', 43.4666700, 24.8666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6752, 'Sitovo', 'Sitovo', 'Doimuslar,Doimuşlar,Donnuslar,Donnuşlar,Doymushlar,Sitovo,Sitowo,Ситово', 44.0273000, 27.0198200, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6753, 'Simitli', 'Simitli', 'Izvoritye,Izworit,Simeti,Simetli,Simetlu,Simetlü,Simitle,Simitli,Simitlii,Simitly Gare,Симитли', 41.8833300, 23.1166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6754, 'Simeonovgrad', 'Simeonovgrad', 'Maritsa,Seimen,Sejmen,Semenli,Seymen,Simeonovgrad,Симеоновград', 42.0333300, 25.8333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6755, 'Silistra', 'Silistra', 'Durostorum,Gorad Silistra,SLS,Silistra,Silistrae,Silistre,Szilisztra,shirisutora,si li s tra,silliseuteula,sylstra,sylystra,sylystrh,xi li si te la,Σιλίστρα,Горад Сілістра,Силистрæ,Силистра,Сілістра,סיליסטרה,سيليسترا,سیلسترا,سیلیسترا,ซิลิสตรา,シリストラ,錫利斯特拉,실리스트라', 44.1166700, 27.2666700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6756, 'Shumen', 'Shumen', 'Choumen,Choumèn,Kolarovgrad,Schumen,Shoumen,Shumen,Shumla,Sjumen,Sumen,Sumla,Sumnu,shumen,Şumnu,Šumen,Šumla,Шумен', 43.2706400, 26.9228600, 'BG', '2014-01-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6757, 'Shipka', 'Shipka', 'Schipka,Shipka,Sipka,Šipka,Шипка', 42.7166700, 25.3333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6758, 'Shabla', 'Shabla', 'Sabla,Shabla,Şabla,Шабла', 43.5333300, 28.5333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6759, 'Sevlievo', 'Sevlievo', 'Savlievo,Seljvi,Selvi,Sevelijevo,Sevlievo,Sevlijevo,Sewliewo,Севлиево', 43.0258300, 25.1136100, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6760, 'Septemvri', 'Septemvri', 'Sarambei,Sarambey,Saran''ovo,Saran-Bey,Saranevo,Saraniowo,Saranjevo,Saranyovo,Saranëvo,Saran’ovo,Septemvri,Septemvrijci,Септември,Септемврийци', 42.2166700, 24.1000000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6761, 'Senovo', 'Senovo', 'Senevo,Senovo,Senowo,Syenovo,Сеново', 43.6500000, 26.3666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6762, 'Satovcha', 'Satovcha', 'Satovca,Satovcha,Satovdza,Satovdža,Satovča,Satowtscha,Сатовча', 41.6166700, 23.9833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6763, 'Sarafovo', 'Sarafovo', 'Antim I,Paparos,Papure,Sarafovo,Sarefovo,Сарафово', 42.5607900, 27.5219500, 'BG', '2017-02-11', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6764, 'Sapareva Banya', 'Sapareva Banya', 'Gorna Banja,Gorna-Bania,Gorna-Banya,Sapareva Banja,Sapareva Banya,Сапарева Баня', 42.2833300, 23.2666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6765, 'Sandanski', 'Sandanski', 'Sandanski,Sveti Vrac,Sveti Vrach,Sveti Vrač,Sveti-Vratch,Svéti-Vratch,Sweti Wratsch,Xanne Sandanski,Yane Sandanski,Сандански,Свети Врач', 41.5666700, 23.2833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6766, 'Samuil', 'Samuil', 'Ashiklar,Samuil,Самуил', 43.5166700, 26.7500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6767, 'Samokov', 'Samokov', 'Samakov,Samokov,Samokow,Samovkov,Самоков', 42.3370000, 23.5528000, 'BG', '2013-11-20', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6768, 'Sadovo', 'Sadovo', 'Cheshnegir,Cheshnigurovo,Cheshnigŭrovo,Sadova,Sadovo,Sadowo,Садово', 42.1317800, 24.9399900, 'BG', '2016-02-13', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6769, 'Ruzhintsi', 'Ruzhintsi', 'Rujintsi,Rushinzi,Ruzhentsi,Ruzhinci,Ruzhintsi,Ruzinci,Ružinci,Ружинци', 43.6233300, 22.8308300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6770, 'Ruse', 'Ruse', 'ROU,Roese,Rouse,Rousse,Roussé,Roustchouk,Ruschuk,Ruschuq,Rusciuk,Rusclink,Ruscuk,Ruse,Rushchuk,Rushtuk,Russe,Rustschuk,Rusze,Rusçuk,Rusė,Ruzo,Ruščuk,Saray-Makhle,Sexantaprista,lu sai,luse,ru se,ruse,rwsh,rwsh  blgharstan,Ρούσε,Роусє,Русе,Ռուսե,רוסה,روسه,روسه، بلغارستان,روسے، بلغاریہ,ڕوسێ,รูเซ,რუსე,ルセ,鲁塞,루세', 43.8563900, 25.9708300, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6771, 'Ruen', 'Ruen', 'Ruen,Ulanli,Ulanlii,Ulanliy,Руен', 42.8000000, 27.2833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6772, 'Rudozem', 'Rudozem', 'Chervenkovgrad,Palas,Palaz,Roodozem,Rudosem,Rudozem,Рудозем', 41.4875100, 24.8494500, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6773, 'Roman', 'Roman', 'Roman,Роман', 43.1500000, 23.9166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6774, 'Rila', 'Rila', 'Rila,Rila Selo,Riloselo,Рила', 42.1333300, 23.1333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6775, 'Razlog', 'Razlog', 'Mahomia,Mehomia,Mekhomiya,Pazlog,Raslog,Raslug,Razlog,Razlogas,Razłog,la zi luo ge,razlwg,razlwgh,razuroku,rzlwg,Разлог,רזלוג,رازلوغ,رازلوگ,ラズロク,拉茲洛格', 41.8863000, 23.4671400, 'BG', '2008-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6776, 'Razgrad', 'Razgrad', 'Rasgrad,Razgrad,Razgradas,Raznkrant,Ràzgrad,la zi ge lei,lajeugeuladeu,razghrad,razgrad,razugurato,Ράζγκραντ,Разград,ראזגרד,رازغراد,رازگراد,رازگراڈ,ラズグラト,拉茲格勒,라즈그라드', 43.5333300, 26.5166700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6777, 'Ravda', 'Ravda', 'Ravda,Ravdas,Rawda,Rhavtha,Равда', 42.6450700, 27.6768100, 'BG', '2013-06-20', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6778, 'Rakovski', 'Rakovski', 'General Niklaevo,General Nikolaevo,General Nikolaewo,Kalich,Kaliclii,Kaličh,Kaličlii,Kaluchlii,Kaluchliy,Kalŭchlii,Kalŭchliy,Rakovski,Раковски', 42.3000000, 24.9666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6779, 'Rakitovo', 'Rakitovo', 'Rakitovo,Rakitowo,Ракитово', 41.9833300, 24.0833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6780, 'Radomir', 'Radomir', 'Radomir,Radomiras,la duo mi er,ladomileu,radomiru,radwmyr,Радомир,ראדומיר,رادومیر,ڕادۆمیر,ラドミル,拉多米爾,라도미르', 42.5444400, 22.9577800, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6781, 'Radnevo', 'Radnevo', 'Radne Machale,Radne Makhle,Radne-Makhala,Radnevo,Radnewo,Раднево', 42.3000000, 25.9333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6782, 'Parvomaytsi', 'Parvomaytsi', 'Parvomaytsi,Purvomajci,Purvomaytsi,Pŭrvomaytsi,Sergjuvec,Temnisko,srghwfchh,Първомайци,Сергювец,Темниско,سرغوفچه', 43.1500000, 25.6500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6783, 'Provadia', 'Provadia', 'Pravodi,Provadia,Provadidija,Provadija,Provadiya,Prowadija,Провадия', 43.1833300, 27.4333300, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6784, 'Primorsko', 'Primorsko', 'Kjuprija,Kyupriya,Primorsko,Приморско', 42.2666700, 27.7666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6785, 'Veliki Preslav', 'Veliki Preslav', 'Eski Stambid,Eski Stambolluk,Eski-Stambul,Preslav,Preslaw,Prieslav,Prjeslav,Veliki Preslav,Weliki Preslaw,Weliki Presław,Велики Преслав', 43.1666700, 26.8166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6786, 'Pravets', 'Pravets', 'Pravec,Pravets,Pravetz,Prawez,Правец', 42.8833300, 23.9166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6787, 'Pordim', 'Pordim', 'Pordim,Pordime,Porodim,Пордим', 43.3833300, 24.8500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6788, 'Popovo', 'Popovo', 'Popkioj,Popkioy,Popkiöj,Popovas,Popovo,Popowo,bo bo wo,pwpwbw,pwpwww  blgharstan,Попово,פופובו,پوپووو، بلغارستان,پۆپۆڤۆ,波波沃', 43.3500000, 26.2333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6789, 'Pomorie', 'Pomorie', 'Ahiolo,Akhillo,Akhilu,Akhiolo,Anchialo,Anchialos,Anchijelo,Anchilejo,Anhialo,Anhiolo,Ankhelu,Ankhelú,Ankhialo,Ankhiolo,Gorad Pamorye,Pomorie,Pomorije,Pomorijė,Pomoriye,Pomorié,Pomorye,bo mo lai,pomorie,pwmwryh,Αγχίαλος,Горад Паморые,Поморие,Поморије,Поморіє,پوموریه,پۆمۆریێ,ポモリエ,波摩萊', 42.5588200, 27.6439300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6790, 'Polski Trambesh', 'Polski Trambesh', 'Polsk Trumbesh,Polsk Trŭmbesh,Polski Trambech,Polski Trambesh,Polski Trembes,Polski Trembeš,Polski Trumbesh,Polski Trŭmbesh,Polski-Trambesch,Polski-Trembesh,Polski-Trămbesch,Trembesh,Полски Тръмбеш', 43.3836100, 25.6497200, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6791, 'Plovdiv', 'Plovdiv', 'Eumolpias,Filiba,Filibe,Filipopol,Filipopul,Filippopol,Filippopol'',Filippopoli,Flavia,Julia,PDV,Philippopel,Philippopoli,Philippopolis,Philippoupole,Pinople,Plodin,Ploudin,Plovdin,Plovdiv,Plovdiva,Plovdivas,Plowdiw,Plóvdiv,Poulpoudeva,Płowdiw,Sinople,Trimontium,Ulpia,Vinipoppolis,blwfdyf,peullobeudipeu,phlx fdif,plovhadivha,plwbdyb,plwwdyf,plwwdyw,pu luo fu di fu,purovudifu,Φιλιππούπολη,Пловдив,Фїлїппополь,Պլովդիվ,פלאוודיוו,פלובדיב,بلوفديف,پلوودیف,پلوودیو,प्लॉव्हडिव्ह,พลอฟดิฟ,პლოვდივი,プロヴディフ,普罗夫迪夫,플로브디프', 42.1500000, 24.7500000, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6792, 'Pliska', 'Pliska', 'Aboba,Ak Baba,Pliska,Pliskov,Pliskow,Плиска', 43.3666700, 27.1166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6793, 'Pleven', 'Pleven', 'Gorad Pleven,Pleven,Plevenas,Plevna,Plevne,Plewen,Plyeven,blfn,peulleben,plbn,plwn,plywyn,pu lie wen,purevu~en,Πλέβεν,Горад Плевен,Плевен,Պլևեն,פלבן,بلفن,پلون,پلیوین,პლევენი,プレヴェン,普列文,플레벤', 43.4166700, 24.6166700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6794, 'Pirdop', 'Pirdop', 'Pirdop,pi er duo pu,pyrdwp,Пирдоп,پیردوپ,پیردۆپ,皮爾多普', 42.7000000, 24.1833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6795, 'Petrich', 'Petrich', 'Petric,Petrich,Petrich'',Petrici,Petricius,Petricz,Petritch,Petrits,Petritsch,Petritsi,Petritsj,Petritš,Petriç,Petrič,Petričius,Pétritch,bytrytsh,pei te li qi,peteulichi,petorichi,ptrych,ptryz,Πετρίτσι,Петрич,Пєтричь,פטריץ,بيتريتش,پتریچ,ペトリチ,佩特里奇,페트리치', 41.3984600, 23.2070200, 'BG', '2017-01-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6796, 'Peshtera', 'Peshtera', 'Momarsko,Pechtera,Pescera,Peschtera,Peshchera,Peshhera,Peshtera,Pestera,Peštera,Peščera,Пещера', 42.0333300, 24.3000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6797, 'Perushtitsa', 'Perushtitsa', 'Perishchitsa,Peruschtiza,Perushchitsa,Perushhica,Perushtitsa,Perustica,Peruštica,Перущица', 42.0500000, 24.5500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6798, 'Pernik', 'Pernik', 'Dimitrovo,Gorad Pernik,Pernik,Pernikas,brnyk,pei er ni ke,peleunikeu,per nik,peruniku,prnyk,prnyq,pyrnk,Πέρνικ,Горад Пернік,Перник,פרניק,برنيك,پرنیک,پیرنک,پێرنیک,เปร์นิก,ペルニク,佩尔尼克,페르니크', 42.6000000, 23.0333300, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6799, 'Iskar', 'Iskar', 'Iskar,Iskur,Iskŭr,Machalata,Machlata,Machluta,Machlüta,Mahalata,Mahlata,Makhalata,Makhlata,Pelovo,Искър', 43.4500000, 24.2666700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6800, 'Pazardzhik', 'Pazardzhik', 'Pasardschik,Pasardshik,Pazarcik,Pazarcık,Pazardjik,Pazardsjik,Pazardzhik,Pazardzik,Pazardzikas,Pazardzjik,Pazardĵik,Pazardżik,Pazardžik,Pazardžikas,Pazartzik,Pàzardjik,Tatar Bazardzik,Tatar Bazardžik,Tatar Pazardjik,Tatar Pazardzhik,Tatar Pazardzik,Tatar Pazardžik,Tatar-Bazardzhik,bazarjyk,pa sar cik,pa zha er ji ke,pajaleujikeu,pazarjk,pazarjyk,pazarjyk  blgharstan,pazarjyk  bwlgarya,pazarujiku,Πάζαρτζικ,Пазарджик,Пазарџик,פאזארדזיק,بازارجيك,پازارجک,پازارجیک,پازارجیک، بلغارستان,پازارجیک، بولگاریا,ปาซาร์จีก,パザルジク,帕扎爾吉克,파자르지크', 42.2000000, 24.3333300, 'BG', '2007-02-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6801, 'Pavlikeni', 'Pavlikeni', 'Pavlikem,Pavlikene,Pavlikeni,Pavlikeniai,Pawlikeni,pa fu li kai ni,pavurikeni,pawlykny,Павликени,پاولیکنی,پاڤلیکێنی,パヴリケニ,帕夫利凱尼', 43.2427800, 25.3219400, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6802, 'Pavel Banya', 'Pavel Banya', 'Banya,Ludzha Ali,Ludzha K''oy,Lŭdzha Ali,Lŭdzha K’oy,Pavel,Pavel Banja,Pavel Banya,Pawel,Павел Баня', 42.6000000, 25.2000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6803, 'Panagyurishte', 'Panagyurishte', 'Otalkioj,Otalkiöj,Panaghiourichte,Panaghiourichté,Panaghurichte,Panagiuriste,Panagjurisce,Panagjurischte,Panagjurishhe,Panagjuriste,Panagjurište,Panagjurišče,Panagyurishche,Panagyurishte,Панагюрище', 42.5000000, 24.1833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6804, 'Oryahovo', 'Oryahovo', 'Orechovo,Orechowo,Orehovo,Orejekhovo,Orekhovo,Orjahovo,Orjakhovo,Orjechovo,Orjekhovo,Oryahovo,Oryakhovo,Oryekhovo,Rachowo,Rahova,Rakhovo,Rakovo,Ruhovo,Оряхово', 43.7350400, 23.9579200, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6805, 'Opaka', 'Opaka', 'Opaka,Опака', 43.4500000, 26.1666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6806, 'Omurtag', 'Omurtag', 'Omortag,Omurtag,Osman-Pazar,Osmanbazar,Омуртаг', 43.1000000, 26.4166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6807, 'Obzor', 'Obzor', 'G''ozeken,Giozeken,Gjozeken,Gusiken,Guzuken,Gyuzekioy,Gyuzuken,Güsiken,Güzuken,G’ozeken,Kozjak-Grad,Kozyak-Grad,Obsor,Obzor,ao bu zuo er,bwzwr,Обзор,אובזור,ئۆبزۆر,بوزور,奧布佐爾', 42.8166700, 27.8833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6808, 'Novo Selo', 'Novo Selo', 'Novo Selo,Nowo-Selo,Ново Село', 44.1586100, 22.7866700, 'BG', '2017-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6809, 'Novi Pazar', 'Novi Pazar', 'Eni Bazar,Eni Pazar,Jenibazar,Novi Pazar,Novi-Paza,Nowi Pasar,Нови Пазар', 43.3500000, 27.2000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6810, 'Nova Zagora', 'Nova Zagora', 'Eni Zagra,Ienizagra,Jeni Saghra,Jeni Zagra,Nova Zagora,Nova-Zagora,Nová Zagora,Nowa Sagora,Nowa Zagora,Yeni Sagra,Yeni Zagra,Yeni Zağra,nobajagola,nwwa zagwra,xin zha ge la,Νόβα Ζαγόρα,Нова Загора,Нова-Загора,נובה זאגורה,نووا زاگورا,نۆڤا زاگۆرا,新扎戈拉,노바자고라', 42.4833300, 26.0166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6811, 'Nikopol', 'Nikopol', 'Nicopol,Nicopoli,Nicopolis,Nicòpol,Nigbolu,Nikapoly,Nikopil,Nikopol,Nikopoli,Nikápoly,Niğbolu,ni ke bo er,nikopol,nikoporu,nykwpwl  blgharstan,nyqwpwl,Никопол,Никопољ,Нікопол,ניקופול,نیکوپول، بلغارستان,نیکۆپۆل، بولگاریا,ニコポル,尼科波尔,니코폴', 43.7025500, 24.8964500, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6812, 'Nikolaevo', 'Nikolaevo', 'Eshekchii,Eshekii,Nikolaevo,Nikolaewo,Nikolajevo,Николаево', 42.6333300, 25.8000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6813, 'Nesebar', 'Nesebar', 'Gorad Njasebyr,Mesembria,Mesembrija,Mesemvria,Mesemvrija,Mesemvriya,Messemvria,Messemvrija,Messemwria,Misevrin,Misivri,Misivria,Missevriya,Nesebar,Neseber,Neseberas,Nesebr,Nesebur,Nesebyr,Nesebâr,Nesebăr,Nesebŭr,Nesempar,Nessebar,Nessebur,Nessebăr,Nessèbar,Neszebar,Nеsebăr,nei sai bo er,nesebaru,nesebeoleu,nesebiri,nsbar,nsbr,nysybar,Νέσεμπαρ,Горад Нясебыр,Месембрія,Несебар,Несебр,Несебър,Несебыр,נסבר,نسبار,نيسيبار,نێسێبار,ნესებირი,ነሰብር,ネセバル,内塞伯爾,네세버르', 42.6592100, 27.7360200, 'BG', '2014-03-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6814, 'Nedelino', 'Nedelino', 'Nedelino,Nedelio,Nedyelino,Uzendere,Uzun-Dere,Неделино', 41.4560200, 25.0800800, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6815, 'Maglizh', 'Maglizh', 'Maglis,Maglish,Magliz,Maglizh,Magliš,Magliž,Meglish,Meglizh,Mglij,Moglic,Moglis,Moglič,Muglish,Mugliz,Muglizh,Mögliš,Măglish,Măglizh,Mŭglish,Mŭglizh,Mŭgliž,Мъглиж', 42.6000000, 25.5500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6816, 'Mizia', 'Mizia', 'Buk''ovtsi,Bukiowzi,Bukyuvtsy,Buk’ovtsi,Mizia,Mizija,Miziya,Мизия', 43.6862300, 23.8537100, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6817, 'Mirkovo', 'Mirkovo', 'Mirkovo,Mirkowo,Мирково', 42.7000000, 23.9833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6818, 'Mineralni Bani', 'Mineralni Bani', 'Khaskovski Bani,Khaskovski Mineralni Bani,Mineralni Bani,Mineralni Bani-Haskovo,Минерални Бани', 41.9166700, 25.3500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6819, 'Montana', 'Montana', 'Ferdinand,Ferdinandovo,Golyama Kutlovitsa,Khristo Mikhaylov,Kutlovica,Kutlu Vice,Kutlu Viçe,Mikhailovgrad,Mikhaylovgrad,Montana,Montanae,Velika Kutlovica,meng ta na,montana,mwntana,mwntana  blgharstan,mwntnh,Μοντάνα,Монтанæ,Монтана,Монтана · Блъгарїи,מונטנה,مونتانا,مونتانا، بلغارستان,مۆنتانا، بولگاریا,モンタナ,蒙塔納,몬타나', 43.4125000, 23.2250000, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6820, 'Tsarevo', 'Tsarevo', 'Carevo,Michurin,Tsarevo,Tsarévo,Tzarevo,Vasiliko,Zarewo,Царево', 42.1695500, 27.8454100, 'BG', '2013-12-06', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6821, 'Mezdra', 'Mezdra', 'Mesdra,Mezdra,Mezhdra,Mizara,mei zi de la,mezudora,myzdra,mzdra,Мездра,مزدرا,ميزدرا,مێزدرا,メズドラ,梅茲德拉', 43.1500000, 23.7000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6822, 'Medovene', 'Medovene', 'Balbunar Endzhe,Enidzhe Balbunar,Indzhekioy,Mediowene,Medovene,Медовене', 43.7666700, 26.5166700, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6823, 'Medkovets', 'Medkovets', 'Medkovec,Medkovets,Medkovetz,Metkovec,Metkovets,Metkowez,Медковец', 43.6297200, 23.1811100, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6824, 'Malko Tarnovo', 'Malko Tarnovo', 'Malko Tarnovo,Malko Tarnowo,Malko Turnovo,Malko Tŭrnovo,Malko-Tarnov,Malko-Tirnovo,Malko-Trnovo,Malko-Tărnov,Malkotirnova,Tirnovo,Малко Търново', 41.9795800, 27.5247700, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6825, 'Madzharovo', 'Madzharovo', 'Dupnitsa,Dupniza,Madjarovo,Madzarovo,Madzarowo,Madzharovo,Madzjarovo,Madżarowo,Madžarovo,Yatadzhik,ma gu luo wo,majarwfw,Маджарово,Маџарово,ماجاروفو,ماجارۆڤۆ,馬賈羅沃', 41.6346100, 25.8643900, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6826, 'Madan', 'Madan', 'Madan,Мадан', 41.4986900, 24.9397300, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6827, 'Lyubimets', 'Lyubimets', 'Khebibchevo,Lioubimetz,Ljubimec,Ljubimetz,Ljubimez,Lyubimets,Lyubimetz,Любимец', 41.8333300, 26.0833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6828, 'Lyaskovets', 'Lyaskovets', 'Leskovec,Leskovets,Leskovetz,Leskovètz,Leskowez,Ljaskovec,Ljeskovec,Lyaskovets,Lyaskovetz,Lyeskovets,Lěskovec,Лясковец', 43.1111100, 25.7283300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6829, 'Lukovit', 'Lukovit', 'Gorni Lukovit,Loukovit,Lukovit,Lukowit,Луковит', 43.2000000, 24.1666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6830, 'Laki', 'Laki', 'Laki,Luki,Lŭki,Лъки', 41.8500000, 24.8166700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6831, 'Loznitsa', 'Loznitsa', 'Kobadin,Kobadun,Kobadŭn,Kubadin,Losniza,Lozitsa,Loznica,Loznitsa,Лозница', 43.3666700, 26.6000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6832, 'Lovech', 'Lovech', 'Gorad Lavech,Lofca,Lofça,Lovca,Lovcha,Lovec,Lovecas,Lovech,Loveci,Lovetch,Lovetj,Lovets,Lovetsj,Lovetš,Loveĉ,Loveč,Lovečas,Lovča,Lowecz,Lowetsch,Melta,lobechi,luo wei qi,lwbz,lwftsh,lwwch,lwwych,rovu~echi,Łowecz,Λόβετς,Горад Лавеч,Ловеч,לובץ,لوفتش,لووچ,لوویچ,لۆڤێچ,ロヴェチ,洛維奇,로베치', 43.1333300, 24.7166700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6833, 'Lom', 'Lom', 'Aligina Makhala,Dzhembek Makhala,Kalen Potok,Lom,Lom Palanka,Nikolaevo,Nikolaewo,Лом', 43.8138900, 23.2361100, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6834, 'Levski', 'Levski', 'Kara Agach,Levski,Lewski,Turski Karaagach,Левски', 43.3666700, 25.1333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6835, 'Letnitsa', 'Letnitsa', 'Letnica,Letnitsa,Letnitza,Letniza,Lietnica,Lyetnitsa,Lětnica,Летница', 43.3116700, 25.0733300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6836, 'Lesichevo', 'Lesichevo', 'Lesicevo,Lesichevo,Lesichovo,Lesicovo,Lesičevo,Lesičovo,Lessitschowo,Lisichevo,Ljesicevo,Ljesičevo,Lyesichevo,Лесичово', 42.3500000, 24.1166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6837, 'Lakatnik', 'Lakatnik', 'Lakatnik,Лакатник', 43.0500000, 23.4000000, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6838, 'Kyustendil', 'Kyustendil', 'Keustendil,Kioustendil,Kioustentil,Kiousténdil,Kjustendil,Koestendil,Kostendil,Kustendil,Kyustendil,Köstendil,Küstendil,Κιουστεντίλ,Кюстендил', 42.2838900, 22.6911100, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6839, 'Kardzhali', 'Kardzhali', 'Exrdzhali,Kardjali,Kardschali,Kardshali,Kardzali,Kardzhali,Kardzjali,Kardĵali,Kardžali,Kartzali,Kerdzalai,Kerdzhali,Kerdžalai,Kerjali,Kircaali,Kirdjalu,Kirdjalü,Kirdzali,Kirdzalu,Kirdzhali,Kirdžali,Kirdžalü,Kirjali,Krdjali,Krdzali,Krdžali,Kudjaly,Kurdzali,Kurdzhale,Kurdzhali,Kurdzhalii,Kyakyrdzhali,Kyrdzali,Kyrdzhali,Kyrdżali,Kărdjali,Kărdzhali,Kărdžali,Kırcaali,Kŭrdzhale,Kŭrdzhali,Kŭrdzhalii,Kŭrdžali,kardzhaly,karjly,ke er gu li,keoleujalli,kurujari,Κάρτζαλι,Кирджалі,Крџали,Кърджали,Кырджали,קרדזאלי,كارجلي,کاردژالی,კირჯალი,クルジャリ,克爾賈利,커르잘리', 41.6500000, 25.3666700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6840, 'Kula', 'Kula', 'Adlijo,Adlye,Koula,Kula,Кула', 43.8877800, 22.5213900, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6841, 'Kubrat', 'Kubrat', 'Balbunar,Kubrat,Кубрат', 43.8000000, 26.5000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6842, 'Krushari', 'Krushari', 'Armuchi,Armutli,Armutlia,Armutlii,Armutlu,Krusari,Krushari,Krušari,Крушари', 43.8167500, 27.7555200, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6843, 'Krumovgrad', 'Krumovgrad', 'Koshu-Kavak,Kosikavak,Kossukavak,Kossukovak,Kosu-Kavak,Košu-Kavak,Kroumovgrade,Krumovgrad,Krumowgrad,Крумовград', 41.4712700, 25.6548500, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6844, 'Krivodol', 'Krivodol', 'Krivdol,Krivodol,Krivodolska Makhala,Kriwodol,Криводол', 43.3744400, 23.4844400, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6845, 'Krichim', 'Krichim', 'Krichim,Kricim,Kricima,Krinchim,Kritchim,Kritschim,Krizim,Kričim,Kričima,Križim,Kroma,Кричим', 42.0500000, 24.4666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6846, 'Kresna', 'Kresna', 'Bahnhof Pirin,Gara Pirin,Kresna,Krésna,ke lei si na,krsna,kuresuna,Кресна,Крѣсьна,Կրեսնա,کرسنا,کرێسنا,クレスナ,克雷斯納', 41.7333300, 23.1500000, 'BG', '2013-01-25', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6847, 'Kozloduy', 'Kozloduy', 'Koslodui,Kosloduj,Kozlodouy,Kozlodui,Kozloduj,Kozlodujus,Kozloduy,Kozloudoui,Kozludui,Kozłoduj,ke zi luo du yi,kojeullodu-i,kozloduj,kozurodo~ui,kwzlwdwy,qwzlwdwy,Козлодуй,Козлодуј,козлодуй,קוזלודוי,کوزلودوی,کۆزلۆدوی,コズロドゥイ,科茲洛杜伊,코즐로두이', 43.7786400, 23.7205800, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6848, 'Koynare', 'Koynare', 'Koinare,Kojnare,Koynare,Койнаре', 43.3500000, 24.1333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6849, 'Kotel', 'Kotel', 'Kazan,Kotel,Котел', 42.8833300, 26.4500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6850, 'Kostinbrod', 'Kostinbrod', 'Kostinbrod,Костинброд', 42.8166700, 23.2166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6851, 'Koprivshtitsa', 'Koprivshtitsa', 'Avrat Alan,Koprivchtitsa,Koprivcica,Koprivichtitza,Koprivscica,Koprivshchitsa,Koprivshhica,Koprivshtica,Koprivshticja,Koprivshtitsa,Koprivsjtitsa,Koprivstica,Koprivstico,Koprivstita,Koprivčica,Koprivŝtico,Koprivštica,Koprivščica,Koprivștița,Kopriwschtiza,Kopriwsztica,ke pu li fu shen di cha,kopeulipeusyuticha,kopurifushititsu~a,kwpryfshtytsa,qwprybstyzh,Копривштица,Копривштиця,Копривщица,קופריבשטיצה,کوپریفشتیتسا,کۆپریفشتیتسا,コプリフシティツァ,科普里夫什蒂察,코프리프슈티차', 42.6333300, 24.3500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6852, 'Kocherinovo', 'Kocherinovo', 'Kocarinovo,Kocerinovo,Kocherinobo,Kocherinovo,Kocheripovo,Kotcherinovo,Kotscherinowo,Kočarinovo,Kočerinovo,Кочериново', 42.0843900, 23.0571000, 'BG', '2017-02-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6853, 'Knezha', 'Knezha', 'Kneja,Knesha,Kneza,Knezha,Kneža,Knizha,Knjeza,Knježa,Knyazha,Кнежа', 43.5000000, 24.0833300, 'BG', '2014-11-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6854, 'Klisura', 'Klisura', 'Derbend,Klissoura,Klissura,Klisura,Клисура', 42.7000000, 24.4500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6855, 'Kiten', 'Kiten', 'Kiten,Mukhalii,Китен', 43.0833300, 27.3166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6856, 'Kiten', 'Kiten', 'Avordovisa,Bordovasca,Chiflik Urdoviza,Kiten,Kiten Lozenets,Ourdovisa,Uerdiso,Urdoviza,Китен', 42.2342400, 27.7749000, 'BG', '2010-06-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6857, 'Kirkovo', 'Kirkovo', 'Kirkova,Kirkovo,Kirkowo,Кирково', 41.3271500, 25.3637900, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6858, 'Kilifarevo', 'Kilifarevo', 'Kilifarevo,Kilifarewo,Килифарево', 42.9833300, 25.6333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6859, 'Tsar Kaloyan', 'Tsar Kaloyan', 'Car Kalojan,Khlebarovo,Torlak,Torlaki,Tsar Kaloyan,Tsar Kaloyanovo,Turlak,Tzar Kaloyan,Zar Kalojan,Цар Калоян', 43.6166700, 26.2500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6860, 'Hisarya', 'Hisarya', 'Banja,Banya,Chissar,Hisar,Hisar Kjuselere,Hisarya,Hissar,Husar,Khisar,Khisar-Kyuselere,Khisar-Momina Banya,Khisarja,Khisarya,Khiskeseleri,Momina-Banja,Momina-banya,Хисаря', 42.5000000, 24.7000000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6861, 'Hayredin', 'Hayredin', 'Chairedin,Eredin,Hajredin,Hayredin,Khairedin,Khajredin,Khayredin,Хайредин', 43.6000000, 23.6666700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6862, 'Haskovo', 'Haskovo', 'Chaskoi,Chaskovas,Chaskovo,Chaskowo,Chasköi,Gorad Khaskava,HKV,Haskioj,Haskiöj,Haskovo,Haskoy,Hasköy,Khaskovo,Khàskovo,ha si ke wo,haseukobo,haskwfw,hasukovu~o,khaskww,Ĥaskovo,Χάσκοβο,Горад Хаскава,Хасково,חאסקובו,خاسکوو,خاسکۆڤۆ,هاسكوفو,هاسکوفو,ہسکوا,ハスコヴォ,哈斯科沃,하스코보', 41.9341500, 25.5555700, 'BG', '2013-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6863, 'Harmanli', 'Harmanli', 'Charmanlii,Harmanli,Harmanlii,Harmanlu,Harmanly,Harmanlü,Hermanli,Kharmanli,Kharmanlii,Kharmanliy,Харманли', 41.9333300, 25.9000000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6864, 'Hadzhidimovo', 'Hadzhidimovo', 'Dolna-Singartiya,Dolno-Singartiya,Hadzhidimovo,Khadzhidimovo,Shostowo,Zhostovo,Хаджидимово', 41.5222200, 23.8686100, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6865, 'Kermen', 'Kermen', 'Keremenli,Kermen,Kermenli,Kermenlii,Kermenliy,Kermenlu,Kermenlü,Kermon,Кермен', 42.5000000, 26.2500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6866, 'Kazanlak', 'Kazanlak', 'Kasanlak,Kasanlăk,Kazanl"k,Kazanlak,Kazanlako,Kazanlek,Kazanlik,Kazanlk,Kazanluk,Kazanlyk,Kazanlăk,Kazanlık,Kazanlŭk,Kazanłyk,qʼzʼnlq,Казанлък,Казанлык,קאזאנלק', 42.6166700, 25.4000000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6867, 'Kaynardzha', 'Kaynardzha', 'Cainargcaua-Mica,Cainargeaua Mica,Cainargeaua Mică,Kajnardzha,Kaynardzha,Kutschuk Kainardshi,Kutschük Kainardshi,Kyuchuk-Kaynardzha,Malka Kainardsha,Malka-Kaynardzha,Malka-Kaynaruzha,Malka-Kaynarŭzha,Кайнарджа', 43.9833300, 27.5000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6868, 'Kavarna', 'Kavarna', 'Cavarna,Kavarna,Kawarna,Каварна', 43.4333300, 28.3333300, 'BG', '2013-11-25', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6869, 'Kaspichan', 'Kaspichan', 'Bahnhof Kaspitschan,Gara Kaspican,Gara Kaspichan,Gara Kaspičan,Kaspichan,Kaspitchan,Kaspitchan Gare,Stantsiya Shumlaroad,Каспичан', 43.3166700, 27.1666700, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6870, 'Karnobat', 'Karnobat', 'Karnabat,Karnobat,Karnobatski prokhod,Poljanovgrad,Polyanovgrad,Карнобат,Карнобатски проход', 42.6500000, 26.9833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6871, 'Karlovo', 'Karlovo', 'Grad Karlove,Karliova,Karlovas,Karlovo,Karlowo,Karlıova,Karłowo,Levskigrad,ka er luo wo,kaleullobo,karlwww,karurovu~o,qrlwbw,Κάρλοβο,Карлово,קרלובו,کارلووو,کارلۆڤۆ,カルロヴォ,卡爾洛沃,카를로보', 42.6333300, 24.8000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6872, 'Kaolinovo', 'Kaolinovo', 'Beyuk Bakchilar,Boshidar,Bozhidar,Kaolinovo,Shumnu-Bokhchalar,Shumnu-Bokhchilar,Каолиново', 43.6166700, 27.1166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6873, 'Kameno', 'Kameno', 'Kaiali,Kajali,Kajalii,Kajalu,Kajalü,Kameno,Kayalii,Kayaliy,Kayalu,Kayalŭ,Kayliy,Камено', 42.5744600, 27.2938700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6874, 'Kaloyanovo', 'Kaloyanovo', 'Kalojanovo,Kalojanowo,Kaloyanovo,Seldzhikovo,Seldzikovo,Seldžikovo,Калояново', 42.3500000, 24.7333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6875, 'Kalofer', 'Kalofer', 'Kalofer,Kaloter,Калофер', 42.6166700, 24.9833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6876, 'Ivaylovgrad', 'Ivaylovgrad', 'Ivailovgrad,Ivajlovgrad,Ivatlovgrade,Ivaylovgrad,Ivaïlovgrad,Iwailowgrad,Iwajlowgrad,Iwajłowgrad,Orta-K''oy,Orta-Keui,Orta-Kioi,Orta-Kioj,Orta-Kioï,Orta-Kiöj,Orta-Kyoy,Orta-K’oy,Ortakoey,Ortakoi,Ortaköi,Ortaköy,Ortokoj,Ortoköj,aywalwfgrad,yi wa yi luo fu ge lei,Івайловград,Ивайловград,Ивајловград,ئیڤایلۆڤگراد,ایوالوفگراد,伊瓦伊洛夫格勒', 41.5267200, 26.1249000, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6877, 'Ivanovo', 'Ivanovo', 'Ivanovo,Iwanowo,Иваново', 43.6856800, 25.9556500, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6878, 'Isperih', 'Isperih', 'Isperich,Isperih,Isperikh,Kemallar,Kemanlar,Исперих', 43.7166700, 26.8333300, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6879, 'Iskar', 'Iskar', 'Gelchina Mahala,Gigen Mahala,Gigen Makhala,Gigenska Machala,Gigenska Makhala,Gigenska Makhla,Iskar,Iskur,Iskŭr,Искър', 43.6708000, 24.4523300, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6880, 'Ihtiman', 'Ihtiman', 'Ichtiman,Ihtiman,Ikhitman,Ikhtiman,Ихтиман', 42.4333300, 23.8166700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6881, 'Garmen', 'Garmen', 'Garmen,Gurmen,Gărmen,Gŭrmen,Гърмен', 41.6000000, 23.8166700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6882, 'Gurkovo', 'Gurkovo', 'Dimo Makhle,Dimovtsi,Dimowzi,Dumovtsu Razvalina,Dŭmovtsŭ Razvalina,General Gurkovo,Gurkovo,Gurkowo,Khainboaz,Khainito,Khainkioy,Kolupchii,Гурково', 42.6666700, 25.8000000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6883, 'Gulyantsi', 'Gulyantsi', 'Galyantsi,Golenci,Guleanci,Guljanci,Guljanzi,Gulyanitsa,Gulyantsi,Гулянци', 43.6410900, 24.6936800, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6884, 'Gŭlŭbovo', 'Gulubovo', 'Duvadzhizliy,Galab,Galabovo,Galob,Galöb,Gelub,Gilib,Gulab,Gulub,Gulubovo,Gălăb,Gŭlăb,Gŭlŭb,Gŭlŭbovo,Kum Duvandzhii,Гълъбово', 42.1333300, 25.8500000, 'BG', '2012-04-27', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6885, 'Sredets', 'Sredets', 'Grudovo,Kara-Bunar,Sradets,Sredec,Sredets,Sredetz,Sredez,Sryedets,Srědec,Средец', 42.3474700, 27.1789800, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6886, 'Gramada', 'Gramada', 'Gramada,Грамада', 43.8344400, 22.6586100, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6887, 'Gyovren', 'Gyovren', 'G''ovren,Gjowren,Goevren,Gyovren,Gövren,Гьоврен', 41.6632600, 24.3755700, 'BG', '2016-07-19', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6888, 'Gotse Delchev', 'Gotse Delchev', 'Ano Nevrokopi,Goce Delcev,Goce Delcevas,Goce Delchev,Goce Delczew,Goce Delčev,Goce Delčevas,Goce Dełczew,Goce-Delchev,Gote Delcev,Gotse Delchev,Gotse Deltchev,Gotse Deltsev,Gotse Deltsjev,Gotse Deltšev,Gotsi Delchev,Gotsé Deltchev,Gotze Deltchev,Goze Deltschew,Goțe Delcev,Nevrakop,Nevrekop,Nevrokop,Nevrâkop,Newrokop,ge cai dai er qie fu,gwjh dlchw,gwzh dlz''b,Άνω Νευροκόπι,Гоце Делчев,Гоце-Делчев,Գոցե Դելչև,גוצה דלצ''ב,گوجه دلچو,ゴツェ・デルチェフ,戈采代爾切夫', 41.5666700, 23.7333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6889, 'Gorna Oryahovitsa', 'Gorna Oryahovitsa', 'GOZ,Gorna Orehovica,Gorna Orehovitsa,Gorna Orehovitza,Gorna Orekhovitsa,Gorna Oriahovica,Gorna Orjakhovica,Gorna Orjechovica,Gorna Oryahovitsa,Gorna Oryakhovitsa,Gorna Oréhovitza,Gorna-Orechowiza,Gorna-Oryekhovitsa,Gorno Oryakhovitsa,Горна Оряховица', 43.1277800, 25.7016700, 'BG', '2017-01-30', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6890, 'Gorna Malina', 'Gorna Malina', 'Gorna Malina,Горна Малина', 42.6833300, 23.7000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6891, 'Gorichevo', 'Gorichevo', 'Gorichevo,Goritschewo,Orman Beshevli,Горичево', 43.8500000, 26.4500000, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6892, 'Godech', 'Godech', 'Glotnitsa,Godec,Godech,Godetch,Godetsch,Godeč,Molak,Negolova,Staro Selo,Stoykina,Trap,Yovkina,Годеч', 43.0168200, 23.0485200, 'BG', '2017-03-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6893, 'Glavinitsa', 'Glavinitsa', 'Asfatchioi,Astvatchioi,Asvatchioi,Asvatk''oy,Asvatk’oy,Glavinica,Glavinitsa,Glawinica,Главиница', 43.9166700, 26.8333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6894, 'Dolni Chiflik', 'Dolni Chiflik', 'Dolen Chiflik,Dolen Tchiflik,Dolni Chifl,Dolni Chiflik,Dolni Chiftlik,Dolni Ciflik,Dolni Tchiftlik,Dolni chiflik,Dolni Čiflik,Dolni-Chnflik,Dolni-Tschiflik,Dolèn Tchiflik,Georgi Traykov,Долни чифлик', 42.9833300, 27.7166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6895, 'General-Toshevo', 'General-Toshevo', 'Casim,General Tosevo,General Toševo,General-Toshevo,Ion Gheorghe Duca,Kasamkioi,Kassalkioi,Kassălkioi,Kasum,Kasumk''oy,Kasŭm,Kasŭmk’oy,Генерал-Тошево', 43.7000000, 28.0333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6896, 'Gara Hitrino', 'Gara Hitrino', 'Bahnhof Chitrino,Gara Hitrino,Gara Khitino,Gara Khitrino,Gara Seitandzik,Gara Sejtandzik,Gara Sheytandzhik,Gara Šeitandžik,Gara Šejtandžik,Karola,Seitandzik,Seitantzik,Sejtandzik,Shaytandzhik,Stantsiya Sheytandzhik,Šeitandžik,Šeitantžik,Гара Хитрино', 43.4333300, 26.9166700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6897, 'Gabrovo', 'Gabrovo', 'Gabrova,Gabrovas,Gabrovo,Gabrowo,Gorad Gabrava,Gàbrovo,Nkamprovo,gabeulobo,gabrww,gabrwww,gaburovu~o,gbrwbw,gbrwwa,ghabrwfw,jia bu luo wo,Γκάμπροβο,Габрово,Горад Габрава,Գաբրովո,גברובו,غابروفو,گابروو,گابرووو,گابرۆڤۆ,گبرووا,ガブロヴォ,加布羅沃,가브로보', 42.8747200, 25.3341700, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6898, 'Gabrovo', 'Gabrovo', 'Gabrovo,Grabowo,Габрово', 41.8000000, 25.2666700, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6899, 'Etropole', 'Etropole', 'Etropole,Etropolje,Etropolė,Jetropole,ai te luo bo lai,atrwpwlh,Єтрополе,Јетропоље,Етрополе,אטרופולה,ئێترۆپۆلێ,اتروپوله,埃特羅波萊', 42.8333300, 24.0000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6900, 'Elkhovo', 'Elkhovo', 'Chatal Tepe,Chital,Elchowo,Elkhovo,Елхово', 42.3833300, 25.4333300, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6901, 'Elhovo', 'Elhovo', 'Elchovo,Elchowo,Elhovo,Elkhovo,Kasul-Agac,Kazul-Agach,Kazŭl-Agach,Kizilagac,Kizilagač,Kuzul Indzhe,Kuzul-Agach,Kăsŭl-Agač,Kŭzŭl Indzhe,Kŭzŭl-Agach,Елхово', 42.1666700, 26.5666700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6902, 'Elin Pelin', 'Elin Pelin', 'Elin Pelin,Novoselci,Novoseltsi,Novosseltzi,Nowosselzi,Vlavo Trichkov,Елин Пелин', 42.6666700, 23.6000000, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6903, 'Elena', 'Elena', 'Elena,Jelena,ai lun na,alna  blgharstan,erena,Елена,אלנה,ئێلێنا,النا، بلغارستان,エレナ,埃倫娜', 42.9333300, 25.8833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6904, 'Dzhebel', 'Dzhebel', 'Djebel,Dzhebel,Shekh-Dzhumaya,Sheykh-Dzhumaya,Джебел', 41.4956600, 25.3036300, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6905, 'Dve Mogili', 'Dve Mogili', 'Damogila,Dbb Mogili,Dve Mogili,Dve mogili,Dwe Mogili,Две Могили,Две могили', 43.5925800, 25.8748600, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6906, 'Dunavtsi', 'Dunavtsi', 'Dunavci,Dunavtsi,Dunavtzi,Дунавци', 43.9211100, 22.8211100, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6907, 'Dulovo', 'Dulovo', 'Acadanlar,Accadanlar,Accadânlar,Ak-Kadunlar,Ak-Kadŭnlar,Akkadanlar,Dulovo,Dulowo,Inatra-Mahle,Дулово', 43.8166700, 27.1500000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6908, 'Dalgopol', 'Dalgopol', 'Dalgopol,Delgopol,Dulgopol,Dŭlgopol,Novo-Selo,Дългопол', 43.0500000, 27.3500000, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6909, 'Dryanovo', 'Dryanovo', 'Drenova,Drenovo,Drenowo,Drjanovo,Drjenovo,Dryanovo,Drěnovo,Дряново', 42.9789700, 25.4785000, 'BG', '2007-08-27', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6910, 'Dragoman', 'Dragoman', 'Dragoman,Драгоман', 42.9219100, 22.9310900, 'BG', '2017-03-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6911, 'Dospat', 'Dospat', 'Dospad,Dospat,Доспат', 41.6446200, 24.1585700, 'BG', '2017-01-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6912, 'Dolni Dabnik', 'Dolni Dabnik', 'Diubnik,Dolni Dabnik,Dolni Dibnik,Dolni Dobnik,Dolni Dubnik,Dolni Döbnik,Dolni Dăbnik,Dolni Dŭbnik,Dolni-Debnik,Dolni-Dubnjak,Долни Дъбник', 43.4000000, 24.4333300, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6913, 'Dolna Mitropolia', 'Dolna Mitropolia', 'Dolna Metropolja,Dolna Mitropolia,Dolna Mitropolija,Dolna Mitropoliya,Dolna Netropol Mitropoliya,Долна Митрополия', 43.4666700, 24.5333300, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6914, 'Dolna Banya', 'Dolna Banya', 'Banja,Dolna Bania,Dolna Banja,Dolna Banya,Долна Баня', 42.3000000, 23.7666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6915, 'Dimovo', 'Dimovo', 'Aleksandrovo,Burzitsa,Bŭrzitsa,Dimovo,Knjas Alexandrowo,Knyaz Aleksandrovo,Osmanie,Vlaykovo,Димово', 43.7416700, 22.7269400, 'BG', '2017-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6916, 'Dimitrovgrad', 'Dimitrovgrad', 'Dimitrovgrad,Dimitrovgradas,Dimitrowgrad,Ntimitrovnkrant,dimiteulobeugeuladeu,dymytrwfgrad  blgharstan,dymytrۆvgrad  bwlgarya,ji mi te luo fu ge lei,Ντιμίτροβγκραντ,Димитровград,Димитровъ Градъ · Блъгарїи,דימיטרובגראד,دیمیتروفگراد، بلغارستان,دیمیترۆڤگراد، بولگاریا,季米特洛夫格勒,디미트로브그라드', 42.0500000, 25.6000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6917, 'Devnya', 'Devnya', 'Devne,Devnja,Devnya,Dewnja,Девня', 43.2222200, 27.5694400, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6918, 'Devin', 'Devin', 'D''ovlen,Devin,Devine,Dewin,Djovlen,Dyevin,Děwin,dai wen,dwwyn,dwyn  blgharstan,Девин,דווין,دوین، بلغارستان,دێڤین,代溫', 41.7432700, 24.4000300, 'BG', '2014-11-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6919, 'Debelets', 'Debelets', 'Debebletz,Debelec,Debelet,Debelets,Debeletz,Debelez,Deblec,Débéblètz,Дебелец', 43.0333300, 25.6166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6920, 'Chuprene', 'Chuprene', 'Chuprene,Chupreni,Cupren,Cuprene,Cuprenja,Tschuprene,Čupren,Čuprene,Čuprenja,Чупрене', 43.5180600, 22.6661100, 'BG', '2017-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6921, 'Chirpan', 'Chirpan', 'Chirpan,Cirpan,Tchirpan,Tschirpan,Čirpan,Чирпан', 42.2000000, 25.3333300, 'BG', '2007-04-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6922, 'Chiprovtsi', 'Chiprovtsi', 'Chiporovtsi,Chiporovtsu,Chiporovtsŭ,Chiprovci,Chiprovtsi,Ciprovci,Ciprovti,Ciprovți,Cziprowci,Tchiprovtsi,Tjiprovtsi,Tschiporowzi,Tschiprowzi,chipurofutsu~i,chyprwftsy,qi pu luo fu qi,Čiprovci,Ћипровци,Чипровци,Чипровці,چیپروفتسی,چیپرۆڤتسی,チプロフツィ,奇普羅夫齊', 43.3841700, 22.8808300, 'BG', '2017-03-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6923, 'Cherven Bryag', 'Cherven Bryag', 'Cerven-Breg,Cherven brjag,Cherven-Breg,Cherven-Bryeg,Cherveni Bryag,Cherveni-Bjerg,Tcherven Bryag,Tscherwen Breg,Červen-Brěg,Червен бряг', 43.2666700, 24.1000000, 'BG', '2007-04-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6924, 'Chernomorets', 'Chernomorets', 'Agios Nikolo,Chernomorec,Chernomorets,Nikola,Sveti Nicola,Sveti Nikola,Sweti Nikola,Черноморец', 42.4458900, 27.6383400, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6925, 'Chepelare', 'Chepelare', 'Cepelare,Chepelare,Chepelari,Czepelare,Czepełare,Tchepelare,Tjepelare,Tschepelare,Tsepelare,Tsjepelare,Tšepelare,cheperare,chplarh,qie pei la lei,Čepelare,Чепеларе,چپلاره,چێپێلارێ,チェペラレ,切佩拉雷', 41.7333300, 24.6833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6926, 'Chelopech', 'Chelopech', 'Celopec,Chelopech,Tschelopetsch,Čelopeč,Челопеч', 42.7000000, 24.0833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6927, 'Chavdar', 'Chavdar', 'Chavdar,Kolanlare,Kolanlari,Radoslavo,Radoslavovo,Radoslawowo,Чавдар', 42.6500000, 24.0500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6928, 'Byala Slatina', 'Byala Slatina', 'Bela Slatina,Biela Slatina,Bjala Slatina,Bjela Slatina,Byala Slatina,Byela-Slatina,Бяла Слатина', 43.4666700, 23.9333300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6929, 'Byala Cherkva', 'Byala Cherkva', 'Bela Cerkva,Bela Cherkva,Bela Tscherkwa,Bela-Cerkova,Bela-Tchekva,Bela-Čerkova,Bjala cherkva,Bjela-Cerkova,Bjela-Cerkva,Bjela-Čerkova,Byala Cherkova,Byala Cherkva,Byela Cherkva,Byela-Cherkova,Béla-Tchekva,Běla Čerkva,Gorni Turcheta,Бяла черква', 43.2000000, 25.3000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6930, 'Byala', 'Byala', 'Ak Dere,Bela,Biela,Bjala,Bjela,Byala,Byela,Běla,Бяла', 42.8833300, 27.8833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6931, 'Burgas', 'Burgas', 'BOJ,Boergas,Bourgas,Bournkas,Burgas,Burgas khot,Burgasa,Burgasas,Burgaso,Burgasz,Burgaz,Burghaz,Burgàs,Burqas,Gorad Burgas,Mpournkas,brgas,bu er jia si,buleugaseu,burgasa,burgasi,burugasu,bwrgas,bwrghas,bwrgs,Μπουργκάς,Μπουργκας,Μπούργκας,Бургас,Бургас хот,Горад Бургас,Пѷргъ,Բուրգաս,בורגס,برگاس,بورغاس,بورگاس,बुर्गास,ბურგასი,ブルガス,布爾加斯,부르가스', 42.5060600, 27.4678100, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6932, 'Buhovo', 'Buhovo', 'Buchowo,Buhovo,Bukhovo,Бухово', 42.7666700, 23.5666700, 'BG', '2016-08-03', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6933, 'Brusartsi', 'Brusartsi', 'Brusarci,Brusartsi,Brussarz,Брусарци', 43.6666700, 23.0666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6934, 'Brezovo', 'Brezovo', 'Abrashlare,Abraslare,Bresowo,Brezovo,Brezowo,Brjesovo,Bryezovo,Obshtina Brezovo,Obsjtina Brezovo,brzwfw,bu lei zuo wo,burezovu~o,Брезово,برزوفو,برێزۆڤۆ,ブレゾヴォ,布雷佐沃', 42.3500000, 25.0833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6935, 'Breznik', 'Breznik', 'Berznik,Bresnik,Breznik,Brjeznik,Bryeznik,Obshtina Breznik,Obsjtina Breznik,brznyk,bu lei zi ni ke,burezuniku,Брезник,برزنیک,برێزنیک,ブレズニク,布雷茲尼克', 42.7413900, 22.8980600, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6936, 'Bregovo', 'Bregovo', 'Bregovo,Bregowo,Brjegovo,Bryagovo,Bryegovo,Брегово', 44.1516700, 22.6425000, 'BG', '2017-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6937, 'Bratsigovo', 'Bratsigovo', 'Bracigovo,Bratsigovo,Bratzigovo,Brazigowo,Брацигово', 42.0166700, 24.3666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6938, 'Bozhurishte', 'Bozhurishte', 'Bojurishe,Boshurischte,Bozhurishhe,Bozhurishte,Божурище', 42.7500000, 23.2000000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6939, 'Boychinovtsi', 'Boychinovtsi', 'Boichinovtsi,Bojchinovci,Bojtschinowzi,Boychinovtsi,Бойчиновци', 43.4722200, 23.3358300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6940, 'Bov', 'Bov', 'Bov,Bow,Бов', 43.0325000, 23.3780600, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6941, 'Botevgrad', 'Botevgrad', 'Botevgrad,Botewgrad,Orchanie,Orhanie,Orhanje,Orkhanie,Ботевград', 42.9000000, 23.7833300, 'BG', '2007-04-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6942, 'Borovo', 'Borovo', 'Borovo,Gorna Manastiritsa,Gorna-Manastiriza,Gorna-Monastir,Gorni-Manastirica,Борово', 43.5008600, 25.8099200, 'BG', '2017-06-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6943, 'Borovan', 'Borovan', 'Borovan,Borowan,Борован', 43.4333300, 23.7500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6944, 'Borino', 'Borino', 'Boriio,Borino,Kara-Bulak,Борино', 41.6840800, 24.2930000, 'BG', '2017-01-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6945, 'Bolyarovo', 'Bolyarovo', 'Boljarovo,Boljarowo,Bolyarovo,Pachakioi,Pasakioj,Pasha-K''oy,Pasha-Kyoy,Pasha-K’oy,Pashakioy,Pašakiöj,Болярово', 42.1496200, 26.8111600, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6946, 'Bobovdol', 'Bobovdol', 'Bobor-Dol,Bobov Dol,Bobov-Dol Mina,Bobovdol,Bobow Dol,Бобовдол', 42.3697200, 23.0172200, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6947, 'Boboshevo', 'Boboshevo', 'Bobochevo,Boboschewo,Bobosevo,Boboshevo,Boboševo,Бобочево,Бобошево', 42.1529600, 23.0014600, 'BG', '2017-02-04', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6948, 'Blagoevgrad', 'Blagoevgrad', 'Blagoevgrad,Blagoewgrad,Blagojevgrad,Blagojevgradas,Blagojewgrad,Blagoëvgrad,Blagòevgrad,Blankoevnkrant,Blaqoyevqrad,Błagojewgrad,Djumaja,Dzhumaya,Dzuma,Dzumaja,Džuma,Džumaja,Gorad Blagoeugrad,Gorna Djoumaia,Gorna Djumaya,Gorna Dshumaja,Gorna Dzhumaja,Gorna Dzhumaya,Gorna Dzumaja,Gorna Džumaja,Yukari Cuma,Yukarı Cuma,beullago-ebeugeuladeu,blaghwyfghrad,blagoevgradi,blagwwgrad,blagwyywgrad,bu la ge ye fu ge lei,buragoevugurato,Μπλαγκόεβγκραντ,Благоевград,Благоєвград,Горад Благоеўград,Горна Джумая,Բլագոևգրադ,בלגואבגרד,بلاغويفغراد,بلاگوئیوگراد,بلاگووگراد,ბლაგოევგრადი,ブラゴエヴグラト,布拉戈耶夫格勒,블라고에브그라드', 42.0166700, 23.1000000, 'BG', '2016-02-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6949, 'Berkovitsa', 'Berkovitsa', 'Berkovica,Berkovitsa,Berkovitsa Municipality,Berkovitsay,Berkovitza,Berkowiza,Comuna Berkovita,Comuna Berkovița,Gmina Berkowica,Obshhina Berkovica,Obstina Berkovica,Obština Berkovica,bei er ke wei cha shi,Берковица,Община Берковица,ბერკოვიცის თემი,貝爾科維察市', 43.2361100, 23.1258300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6950, 'Belovo', 'Belovo', 'Beljovo,Belovo,Gara Bel''oro,Gara Bel’oro,Gara Byelovo,Белово', 42.2166700, 24.0166700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6951, 'Belogradchik', 'Belogradchik', 'Belogradchik,Belogradcik,Belogradtchik,Belogradtgchik,Bjelogradcik,Bjelogradčik,Byelogradchik,Bélogradtchik,Bělogradčik,Белоградчик', 43.6272200, 22.6836100, 'BG', '2017-04-07', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6952, 'Belitsa', 'Belitsa', 'Belica,Belicja,Belita,Belitsa,Belitso,Belitza,Beliza,Belița,Bjelica,Blitsa,Byelitsa,Bělica,bei li cha,blytsa,bylytsa,Белица,Белиця,Բելիցա,بلیتسا,بيليتسا,بێلیتسا,貝利察', 41.9569400, 23.5725000, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6953, 'Belene', 'Belene', 'Beleke,Belene,Belina,Bjelene,Byelene,Белене', 43.6459400, 25.1262700, 'BG', '2017-05-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6954, 'Batak', 'Batak', 'Batak,ba ta ke,batak,batak  blgharstan,bataku,Батак,باتاک,باتاک، بلغارستان,バタク,巴塔克', 41.9500000, 24.2166700, 'BG', '2007-04-05', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6955, 'Bata', 'Bata', 'Bakadzhika,Bakazhek,Bata,Batachik,Batadzhik,Batadzik,Batadžik,Бата', 42.7333300, 27.5000000, 'BG', '2013-09-08', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6956, 'Bansko', 'Bansko', 'Banjska,Banjsko,Bans''ko,Banskas,Bansko,Banysko,ban si ke,banseuko,banskw,bansuko,bnsqw,Μπάνσκο,Банско,Бансько,Բանսկո,בנסקו,بانسکو,バンスコ,班斯科,반스코', 41.8383000, 23.4885100, 'BG', '2010-02-13', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6957, 'Banite', 'Banite', 'Banite,Ladsha,Ledzha,Ludzha,Lădsha,Lŭdzha,Баните', 41.6166700, 25.0166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6958, 'Balchik', 'Balchik', 'Balchik,Balchiq,Balcic,Baltchik,Baltschik,Балчик', 43.4166700, 28.1666700, 'BG', '2013-10-26', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6959, 'Aytos', 'Aytos', 'Aitos,Ajtos,Aytos,Айтос', 42.7000000, 27.2500000, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6960, 'Asenovgrad', 'Asenovgrad', 'Asenovgrad,Assenovgrad,Assenovgrade,Assenowgrad,Stanimaka,Асеновград', 42.0166700, 24.8666700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6961, 'Asen', 'Asen', 'Asen,Yurenlii,Yurenliy,Асен', 42.6500000, 25.2000000, 'BG', '2011-07-31', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6962, 'Ardino', 'Ardino', 'Ardino,Egridere,Eğridere,Iridere,Irideré,Khadzhi K''oy,Khadzhi K’oy,a er di nuo,ardino,ardynw,arudino,Ардино,آردینو,ئاردینۆ,არდინო,アルディノ,阿爾迪諾', 41.5833300, 25.1333300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6963, 'Apriltsi', 'Apriltsi', 'Aprilci,Apriltzi,Априлци', 42.8414200, 24.9175900, 'BG', '2007-07-01', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6964, 'Antonovo', 'Antonovo', 'Antonovo,Poljana,Poljane,Polyana,Polyane,Yayla-K''oy,Yayla-K’oy,Yaylakioi,Антоново', 43.1500000, 26.1666700, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6965, 'Anton', 'Anton', 'Anton,Lashene,Lezhene,Ludzhene,Luzhene,Lăshene,Lŭdzhene,Lŭzhene,Антон', 42.7500000, 24.2833300, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6966, 'Alfatar', 'Alfatar', 'Alfatar,General Lazarovo,General Lazarow,Алфатар', 43.9500000, 27.2833300, 'BG', '2012-02-28', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6967, 'Aksakovo', 'Aksakovo', 'Adzemler,Adzhemler,Adžemler,Aksakov,Aksakovo,Aksakovo Municipality,Aksakowo,Comuna Aksakovo,Gmina Aksakowo,Obshhina Aksakovo,a ke sa ke wo shi,aksakaww,Аксаково,Община Аксаково,اکساکاوو,აკსაკოვოს თემი,阿克薩科沃市', 43.2500000, 27.8166700, 'BG', '2012-01-18', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6968, 'Ahtopol', 'Ahtopol', 'Achtepol,Achtopol,Agathopolis,Ahtapolu,Ahtopol,Akhtebol,Akhtopol,Ахтопол', 42.0976800, 27.9396100, 'BG', '2016-11-23', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6969, 'Zlatni Pyasatsi', 'Zlatni Pyasatsi', 'Golden Sands,Goldstrand,Zlatni pjasuci,Zlote Piaski,Zolotye Peski,Złote Piaski,Златни пясъци,Золотые Пески', 43.2850000, 28.0418000, 'BG', '2014-07-29', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6970, 'Aheloy', 'Aheloy', 'Akheloj,Ахелой', 42.6498700, 27.6483800, 'BG', '2013-09-06', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6971, 'Balgarevo', 'Balgarevo', 'Bolgarevo,Болгарево', 43.4029600, 28.4118900, 'BG', '2013-09-06', 35);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6652, 'Manga', 'Manga', 'Manga', 11.6636100, -1.0730600, 'BF', '2012-02-02', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6653, 'Léo', 'Leo', 'Leo,Lev,Léo,XLU,Лев', 11.1003300, -2.1065400, 'BF', '2017-05-21', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6654, 'Koupéla', 'Koupela', 'Koupela,Koupéla,Kupela', 12.1786400, -0.3510300, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6655, 'Koudougou', 'Koudougou', 'Kondougou,Koudougou,Kudugu,Kuduguo,khu du ku,ku du gu,kudo~ugu,kudugu,kwdwgw,Кудугу,کؤدؤگؤ,کودوگو,คูดูกู,クドゥグ,库杜古,쿠두구', 12.2526300, -2.3627200, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6656, 'Korsimoro', 'Korsimoro', 'Korsimoro', 12.8207000, -1.0673700, 'BF', '2017-01-16', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6657, 'Kongoussi', 'Kongoussi', 'Kongoussi,Kongusi,kwngwsy,Конгуси,کونگوسی', 13.3258300, -1.5347200, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6658, 'Kombissiri', 'Kombissiri', 'Kombisiri,Kombissiguiri,Kombissiri,kwmbysyry,Комбисири,کومبیسیری', 12.0609500, -1.3335500, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6659, 'Kokologo', 'Kokologo', 'Kokolgho,Kokologo', 12.1897200, -1.8855600, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6660, 'Kaya', 'Kaya', 'Kaja,Kaya,XKY,ka ya,kaya  brkyna fasw,Кая,کایا، برکینا فاسو,卡亞', 13.0916700, -1.0844400, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6661, 'Houndé', 'Hounde', 'Hounde,Houndé,Hunde', 11.5000000, -3.5166700, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6662, 'Gourcy', 'Gourcy', 'Gourcy,Goursi,Gursi', 13.2077600, -2.3589300, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6663, 'Goulouré', 'Gouloure', '', 12.2276000, -1.9292200, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6664, 'Gorom-Gorom', 'Gorom-Gorom', 'Gorom-Gorom,XGG', 14.4429000, -0.2346800, 'BF', '2013-09-06', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6665, 'Gayéri', 'Gayeri', 'Gayeri,Gayéri', 12.6482400, 0.4931400, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6666, 'Garango', 'Garango', 'Garango', 11.8000000, -0.5505600, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6667, 'Fada N''gourma', 'Fada N''gourma', 'FNG,Fada N''Gourma,Fada N''gourma,Fada Ngourma,Fada N’Gourma,Fada-n-Gurma', 12.0615700, 0.3584300, 'BF', '2013-05-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6668, 'Dori', 'Dori', 'DOR,Dori,Doris,duo li,dwry  brkyna fasw,Дори,Дорі,دوری، برکینا فاسو,多里', 14.0354000, -0.0345000, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6669, 'Djibo', 'Djibo', 'Djibo,Dzhibo,Jibo,XDJ,Джибо', 14.0994000, -1.6255400, 'BF', '2012-12-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6670, 'Diébougou', 'Diebougou', 'Diebougou,Diebugu,Diébougou,XDE', 10.9620900, -3.2496700, 'BF', '2017-05-21', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6671, 'Diapaga', 'Diapaga', 'DIP,Diapaga,Диапага', 12.0730500, 1.7883800, 'BF', '2012-06-05', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6672, 'Déou', 'Deou', 'Deou,Déou', 14.6008400, -0.7190100, 'BF', '2013-09-06', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6673, 'Dédougou', 'Dedougou', 'DGU,Dedougou,Dedugu,Dédougou,dai du gu,dydwgw,Дедугу,دیدؤگؤ,代杜古', 12.4633800, -3.4607500, 'BF', '2013-05-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6674, 'Dano', 'Dano', 'Dano', 11.1464000, -3.0578400, 'BF', '2013-01-10', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6675, 'Boussé', 'Bousse', 'Bousse,Boussé,Busse', 12.6576000, -1.8928800, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6676, 'Boulsa', 'Boulsa', 'Boulsa,Boulssa,Bulsa,XBO', 12.6666400, -0.5746900, 'BF', '2013-02-08', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6677, 'Boromo', 'Boromo', 'Borom,Boromo', 11.7454200, -2.9300600, 'BF', '2013-01-10', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6678, 'Bogandé', 'Bogande', 'Bogande,Bogandé,XBG', 12.9704000, -0.1495300, 'BF', '2017-05-21', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6679, 'Bobo-Dioulasso', 'Bobo-Dioulasso', 'BOY,Bobo Dioulasso,Bobo Diulasas,Bobo-Dioulasso,Bobo-Diulaco shaary,Bobo-Diulaso,Bobo-Diulasso,Bobodjulaso,bo bo di wu la suo,bobodiullaso,bwbw dywlasw,bwbw-dywlasw,bwbwdywlasw,Бобо-Диулаco шаары,Бобо-Диуласо,Бобо-Діуласо,بوبو دیولاسو,بوبو-دیؤلاسو,بوبوديولاسو,ボボ・ディウラッソ,博博迪乌拉索,보보디울라소', 11.1771500, -4.2979000, 'BF', '2017-05-21', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6680, 'Bilanga', 'Bilanga', 'Bilanga', 12.5465200, -0.0243800, 'BF', '2016-10-02', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6681, 'Batié', 'Batie', '', 9.8833300, -2.9166700, 'BF', '2010-08-02', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6682, 'Barani', 'Barani', 'Barani', 13.1691000, -3.8899000, 'BF', '2016-07-31', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6683, 'Banfora', 'Banfora', 'BNR,Banfora,Banforu,banfora,banfwra,bang fu la,bangpola,Банфора,Банфору,באנפורה,بانفورا,バンフォラ,邦福拉,방포라', 10.6333300, -4.7666700, 'BF', '2012-01-18', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6684, 'Gaoua', 'Gaoua', '', 10.2991700, -3.2508300, 'BF', '2010-08-02', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6685, 'Orodara', 'Orodara', 'Orodara,Orodaro', 10.9491700, -4.9341700, 'BF', '2012-06-06', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6686, 'Tin-Akoff', 'Tin-Akoff', 'Ti-n-Akof,Tin Akof,Tin-Akoff', 14.9654900, -0.1633500, 'BF', '2013-09-09', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6687, 'Mani', 'Mani', 'Mani,Manni', 13.2583300, -0.2130600, 'BF', '2016-07-31', 36);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6981, 'Makamba', 'Makamba', 'Makamba,Makampa,makamba,makamba  bwrwndy,Μακάμπα,Макамба,ماکامبا,ماکامبا، بوروندی', -4.1348000, 29.8040000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6982, 'Bururi', 'Bururi', 'Bourouri,Bururi,Bururis,Mont Bururi,bu lu li,bwrwry,bwrwry  bwrwndy,Μπουρούρι,Бурури,Бурурі,בורורי,بوروری,بوروری، بوروندی,布鲁里', -3.9487700, 29.6243800, 'BI', '2010-08-03', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6983, 'Rumonge', 'Rumonge', 'Rumonge', -3.9736000, 29.4386000, 'BI', '2016-06-14', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6984, 'Mwaro', 'Mwaro', 'Mwaro', -3.5112800, 29.7033400, 'BI', '2015-10-12', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6985, 'Isale', 'Isale', 'Isale,Isale-Mugaruro,Isare', -3.3489000, 29.4839000, 'BI', '2015-10-05', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6986, 'Bujumbura', 'Bujumbura', 'BJM,Boujoumboura,Budzumbura,Bujumbura,Bujumburo,Bujumbúra,Buj·umbura,Buyumbura,Buzhumbura,Buzumbura,Buĵumburo,Bużumbura,Bužumbura,Bužumbūra,Bújúmbúra,Bûjûmbûra,Gorad Buzhumbura,Mpouzoumpoura,Usumbura,bajmbwra,bu cum bur a,bu qiong bu la,bu song bu la,bujubura,bujumabura,bujumbula,bujumbura,bujunbura,buzhumbura,bwgwmbwrh,bwjwmbra,bwjwmbwra,pucumpura,Μπουζουμπούρα,Бужумбура,Буџумбура,Буҷумбура,Горад Бужумбура,Բուժումբուրա,בוגומבורה,בוזשומבורע,باجمبورا,بوجومبرا,بوجومبورا,बुजुंबुरा,ਬੁਜੁੰਬੁਰਾ,ବୁଜୁମବୁରା,புசும்புரா,บูจุมบูรา,བུ་ཇུམ་བུ་ར།,ბუჟუმბურა,ቡጁምቡራ,ブジュンブラ,布松布拉,布琼布拉,부줌부라', -3.3822000, 29.3644000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6987, 'Muramvya', 'Muramvya', 'Muramvya', -3.2682000, 29.6079000, 'BI', '2013-04-05', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6988, 'Gitega', 'Gitega', 'GID,Gitega,Gitege,Kitega,Гитеге', -3.4264000, 29.9308000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6989, 'Ruyigi', 'Ruyigi', 'Rouginki,Rujigi,Rujigis,Ruyigi,lu yi ji,rwyygy,rwyygy  bwrwndy,Ρουγίγκι,Руйиги,רוייגי,روئیگی,روییگی، بوروندی,鲁伊吉', -3.4763900, 30.2486100, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6990, 'Cankuzo', 'Cankuzo', 'Cankuzo,Chankuzo,Kankuzo,kankwzw,kankwzw  bwrwndy,Канкузо,Чанкузо,کانکوزو,کانکوزو، بوروندی', -3.2186000, 30.5528000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6991, 'Karuzi', 'Karuzi', 'Karuzi', -3.1013900, 30.1627800, 'BI', '2015-10-05', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6992, 'Bubanza', 'Bubanza', 'Bubanza,bu ban zha,bwbwnza,bwdanza  bwrwndy,Бубанза,بوبونزا,بودانزا، بوروندی,布班扎', -3.0804000, 29.3910000, 'BI', '2013-06-06', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6993, 'Cibitoke', 'Cibitoke', 'Cibitoke', -2.8869000, 29.1248000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6994, 'Buganda', 'Buganda', '', -2.9663000, 29.1944000, 'BI', '2014-07-05', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6995, 'Ngozi', 'Ngozi', 'N''nkozi,Ngozi,Ngozis,en ge qi,ngwzy,ngwzy  bwrwndy,Νγκόζι,Нгози,נגוזי,نگوزی,نگوزی، بوروندی,恩戈齊', -2.9075000, 29.8306000, 'BI', '2013-06-06', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6996, 'Kayanza', 'Kayanza', 'Kayanza', -2.9221000, 29.6293000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6997, 'Muyinga', 'Muyinga', 'Mujinga,Muyinga,Муйинга', -2.8451000, 30.3414000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6998, 'Kirundo', 'Kirundo', 'KRE,Kirundo,kyrwndw,kyrwndw  bwrwndy,Кирундо,Կիրունդո,کیروندو,کیروندو، بوروندی', -2.5845000, 30.0959000, 'BI', '2013-05-08', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(6999, 'Rutana', 'Rutana', 'Routana,Rutana,Rutenga,lu ta na,rwtana,rwtana  bwrwndy,Ρουτάνα,Рутана,Ռուտանա,روتانا,روتانا، بوروندی,魯塔納', -3.9279000, 29.9920000, 'BI', '2012-01-19', 37);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7035, 'Gustavia', 'Gustavia', 'Gorad Gustavija,Goustavia,Gustaf,Gustavi,Gustavia,Gustavija,Gustavio,Gustávia,Guthavia,Qustaviya,guseutabia,gustavhiya,gusutabia,gwiseutabia,gwstawya,ju si ta wei ya,ku s ta wi ya,kucutaviya,Γουσταβία,Горад Густавія,Густави,Густавия,Густавија,Густавія,گوستاویا,گوسٹاویا,गुस्ताव्हिया,குசுதாவியா,กุสตาวียา,გუსტავია,グスタビア,居斯塔维亚,구스타비아,귀스타비아', 17.8961800, -62.8497800, 'BL', '2017-06-20', 185);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7044, 'San Matías', 'San Matias', 'MQK,San Matias,San Matías', -16.3666700, -58.4000000, 'BO', '2017-02-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7045, 'Roboré', 'Robore', 'El Rabore,Fortin Robore,Fortín Roboré,RBO,Robore,Roboré', -18.3347300, -59.7614200, 'BO', '2017-02-06', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7046, 'Puerto Quijarro', 'Puerto Quijarro', 'Puerto Quijarro', -17.7833300, -57.7666700, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7047, 'Nueva Manoa', 'Nueva Manoa', 'Nueva Manoa,Nuevo Manoa', -9.7182800, -65.3954400, 'BO', '2014-07-28', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7048, 'Yamparáez', 'Yamparaez', 'Yamparaes,Yamparaez,Yamparáez,yamprayz,یامپرایز', -19.1892900, -65.1232900, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7049, 'Yacuiba', 'Yacuiba', 'BYC,Jakuiba,Yacuiba,Yacuíba,Якуиба', -22.0164300, -63.6775300, 'BO', '2014-11-30', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7050, 'Warnes', 'Warnes', 'Warnes,varnesi,wa er nei si,ვარნესი,瓦爾內斯', -17.5163000, -63.1677800, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7051, 'Viloco', 'Viloco', 'Viloco', -16.9500000, -67.5500000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7052, 'Villazón', 'Villazon', 'Vil''jason,Viljasonas,Willasun,bi ya song,biryason,biyason,viliasoni,Вильясон,ვილიასონი,ビリャソン,比亞松,비야손', -22.0865900, -65.5942200, 'BO', '2011-03-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7053, 'Villa Yapacaní', 'Villa Yapacani', 'Villa Yapacani,Villa Yapacaní', -17.4000000, -63.8333300, 'BO', '2012-02-02', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7054, 'Villa Serrano', 'Villa Serrano', 'El Pescado,Pescado,Villa Serrano', -19.1248900, -64.3234300, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7055, 'Yotala', 'Yotala', 'Villa Oropeza,Villa de Oropeza,Yotala', -19.1586100, -65.2641700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7056, 'Villamontes', 'Villamontes', 'VLM,Vil''ja-Montes,Villa Montes,Villamontes,bi ya meng te si,Вилья-Монтес,Вілья-Монтес,ვილიამონტესი,比亞蒙特斯', -21.2623500, -63.4690300, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7057, 'Villa Charcas', 'Villa Charcas', '', -20.7227800, -64.8847800, 'BO', '2017-03-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7058, 'Vallegrande', 'Vallegrande', 'Ciudad de Vallegrande,VAH,Vajegrande,Valjegrande,Valjegrandė,Vallegrande,ba ye ge lan de,valiegrande,Вайегранде,ვალიეგრანდე,巴耶格蘭德', -18.4892300, -64.1060900, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7059, 'Uyuni', 'Uyuni', 'UYU,Ujuni,Ujunis,Ujūnis,Uyuni,wu you ni,Уюни,Уюні,烏尤尼', -20.4596700, -66.8250300, 'BO', '2013-10-27', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7060, 'Urubichá', 'Urubicha', 'Uribicha,Urubicha,Urubichi,Urubichá,Uruvicho', -15.3928600, -62.9466100, 'BO', '2013-02-09', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7061, 'Tupiza', 'Tupiza', 'Tupisa,Tupiza,Turpiza,tu pi sa,ტუპისა,圖皮薩', -21.4434500, -65.7187500, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7062, 'Trinidad', 'Trinidad', 'Ciudad Trinidad,Kimsantin llaqta,La Santisima Trinidad,TDD,Trinidad,Trinidadas,te li ni da,teulinidadeu,torinida,trynydd,Тринидад,Тринідад,טרינידד,ٹرینیڈاڈ، بولیویا,ტრინიდადი,トリニダ,特立尼达,트리니다드', -14.8333300, -64.9000000, 'BO', '2014-06-02', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7063, 'Totoral', 'Totoral', 'Totora,Totoral', -18.4958700, -66.8738000, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7064, 'Totora', 'Totora', 'Tutura,tuo tuo la,托托拉', -17.7266200, -65.1932000, 'BO', '2007-09-28', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7065, 'Tomina', 'Tomina', '', -19.1833300, -64.5333300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7066, 'Eucaliptus', 'Eucaliptus', 'Eucaliptus', -17.5833300, -67.5166700, 'BO', '2012-12-03', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7067, 'Tiahuanaco', 'Tiahuanaco', 'Civilizacao Tiahuanaco,Civilização Tiahuanaco,Tiahuanaco,Tiavanaku,Tiuanako,Tiwanaku,tiwanaku,Тиуанако,טיאהואנקו,ティワナク', -16.5522800, -68.6795300, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7068, 'Tarija', 'Tarija', 'Ciudad Tarija,TJA,Taricha,Tarija,Tarikha,Tarixa,ta li ha,taliha,tariha,tarykha,Тариха,Таріха,تاریخا,ტარიხა,タリハ,塔里哈,타리하', -21.5354900, -64.7295600, 'BO', '2010-01-29', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7069, 'Tarata', 'Tarata', 'Tarata', -17.6089800, -66.0213500, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7070, 'Tarabuco', 'Tarabuco', 'Tarabuco,Tarapuku,ta la bu ke,talabuko,tarabuko,タラブコ,塔拉布科,타라부코', -19.1816800, -64.9151700, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7071, 'Sucre', 'Sucre', 'Chuqichaka,Chuquisaca,Ciudad Sucre,Gorad Sukreh,Ijoloti Sukre,SRE,Sik,Soukre,Sucre,Sucre toertenelmi ovarosa,Sucre történelmi óvárosa,Sukre,Sukri,Sukro,Sukrė,Súkre,su ke lei,su ker,sukare,sukeule,sukre,sukure,swkrh,swkry,swqrh,Σούκρε,Горад Сукрэ,Иёлоти Сукре,Сукре,Սուկրե,סוקרה,سوكري,سوکره,سکرے,سۇكرې,सुक्रे,ਸੂਕਰੇ,ซูเกร,སུ་ཁུ་རེ།,სუკრე,スクレ,苏克雷,蘇克雷,수크레', -19.0333200, -65.2627400, 'BO', '2010-05-30', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7072, 'Sotomayor', 'Sotomayor', '', -19.3400000, -64.9991700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7073, 'Sorata', 'Sorata', 'Sorata,Surata,suo la ta,索拉塔', -15.7666700, -68.6333300, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7074, 'Sipe Sipe', 'Sipe Sipe', 'Sipe Sipe', -17.4500000, -66.3833300, 'BO', '2012-05-06', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7075, 'Sapirangui', 'Sapirangui', 'Sapirangui,Sapiranqui', -19.9333300, -63.7833300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7076, 'Santiago del Torno', 'Santiago del Torno', 'El Torno,Santiago del Torno,Torno', -17.9867400, -63.3811800, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7077, 'Santa Rosa del Sara', 'Santa Rosa del Sara', 'Santa Rosa,Santa Rosa del Sara', -17.1091600, -63.5951400, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7078, 'Santa Rosa', 'Santa Rosa', 'SRB,Santa Rosa', -14.1666700, -66.8833300, 'BO', '2012-05-06', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7079, 'Santa Rita', 'Santa Rita', '', -17.9666700, -63.3500000, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7080, 'Santa Elena', 'Santa Elena', '', -20.5500000, -64.7833300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7081, 'Santa Cruz de la Sierra', 'Santa Cruz de la Sierra', 'Ciudad Santa Cruz,Ciudad de Santa Cruz de la Sierra,SRZ,Santa Cruz,Santa Cruz da Serra,Santa Cruz de la Sierra,Santa-Krus-de-la-Sierra,santakurusu,Санта-Крус-де-ла-Сиерра,سانتا کروز دلاسیه‌را,サンタクルス', -17.7862900, -63.1811700, 'BO', '2016-11-04', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7082, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', -20.9166700, -66.0500000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7083, 'San Ramón', 'San Ramon', 'San Ramon,San Ramón', -13.2833300, -64.7166700, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7084, 'San Pedro', 'San Pedro', '', -19.6166700, -64.5000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7085, 'San Pedro', 'San Pedro', 'San Pedro,San Pedro de Tiquina', -16.2371700, -68.8506300, 'BO', '2011-12-06', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7086, 'San Pablo', 'San Pablo', 'San Pablo,San Pablo de Tiquina,Tiguina,Tiquina', -16.2166700, -68.8333300, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7087, 'San Julian', 'San Julian', '', -17.7833300, -62.8666700, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7088, 'San Juan del Surutú', 'San Juan del Surutu', 'San Juan Surutu,San Juan del Surutu,San Juan del Surutú', -17.4833300, -63.7000000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7089, 'San Juan', 'San Juan', '', -21.2666700, -65.3000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7090, 'San Ignacio de Velasco', 'San Ignacio de Velasco', 'SNG,San Ignacio,San Ignacio Velasco,San Ignacio de Loyola,San Ignacio de Velasco,San Ignasio de Velaskas,San Inasyu,sheng yi ge na xi ao,სან-იგნასიო-დე-ველასკო,聖伊格納西奧', -16.3666700, -60.9500000, 'BO', '2017-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7091, 'San Francisco', 'San Francisco', '', -20.7166700, -64.7000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7092, 'San Carlos', 'San Carlos', '', -17.4000000, -63.7500000, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7093, 'San Borja', 'San Borja', '', -14.8166700, -66.8500000, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7094, 'Samaipata', 'Samaipata', 'Samaipata,Samaypata,sa mai pa ta,薩邁帕塔', -18.1800500, -63.8755200, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7095, 'Salitre', 'Salitre', 'El Salitre,Salitre', -20.8833300, -64.9166700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7096, 'Rurrenabaque', 'Rurrenabaque', 'RBQ,Rurenabake,Rurenabakė,Rurre,lu lei na wa ke,רורנבאקה,魯雷納瓦克', -14.4412500, -67.5278100, 'BO', '2008-03-22', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7097, 'Rosario del Ingre', 'Rosario del Ingre', '', -20.5833300, -63.9000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7098, 'Riberalta', 'Riberalta', 'RIB,Riberal''ta,Riberalta,li wei la er ta,libelalta,riberaruta,Рибералта,Риберальта,რიბერალტა,リベラルタ,里韋拉爾塔,리베랄타', -11.0065400, -66.0631200, 'BO', '2016-12-21', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7099, 'Reyes', 'Reyes', 'REY,Reyes', -14.2952000, -67.3362400, 'BO', '2015-06-13', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7100, 'Quime', 'Quime', 'Quime', -16.9833300, -67.2166700, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7101, 'Punata', 'Punata', 'Ciudad Punata,Punata', -17.5423400, -65.8347200, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7102, 'Pulqui', 'Pulqui', 'Pulque Velasco,Pulqui,Pulqui Alto,Valasco,Velasco', -19.2333300, -65.2166700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7103, 'Puesto de Pailas', 'Puesto de Pailas', 'Paila,Puerto Paila,Puerto Pailas,Puesto de Pailas', -17.6500000, -62.8000000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7104, 'Presto', 'Presto', '', -18.9294400, -64.9391700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7105, 'Potosí', 'Potosi', 'Ciudad Potosi,POI,Potosi,Potosí,Putusi,bo tuo xi,bwtwsy,po to si,potoshi,potosi,pwtwsy,Ποτοσί,Потоси,Потосі,Պոտոսի,פוטוסי,بوتوسي,پوتوسی,पोतोसी,โปโตซี,პოტოსი,ポトシ,波托西,포토시', -19.5836100, -65.7530600, 'BO', '2017-02-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7106, 'Potolo', 'Potolo', 'Comunidad Potolo,Potolo', -19.0055600, -65.5286100, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7107, 'Portachuelo', 'Portachuelo', 'Portachuelo', -17.3516800, -63.3928200, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7108, 'Poopó', 'Poopo', '', -18.3802600, -66.9669500, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7109, 'Pocpo', 'Pocpo', 'Pocpo,Pojpo', -18.8333300, -65.3666700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7110, 'Piocera', 'Piocera', 'Comunidad Piocera,Piocera', -18.7500000, -65.4000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7111, 'Pilaya', 'Pilaya', 'Estancia Pilaya,Pilaya', -20.9500000, -64.7500000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7112, 'Paurito', 'Paurito', 'Paurito', -17.8833300, -62.9666700, 'BO', '2013-05-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7113, 'Patacamaya', 'Patacamaya', 'Patacamaya,Patacmaya,Patakamaya,pa ta ka ma ya,帕塔卡馬亞', -17.2358000, -67.9216900, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7114, 'Pailón', 'Pailon', 'El Pailon,El Pailón,Pailon,Pailón,Puerto Ibanez,Puerto Ibañez,pai long,派隆', -17.6500000, -62.7500000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7115, 'Padilla', 'Padilla', 'Padilla,pa di ya,帕迪亞', -19.3087800, -64.3027300, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7116, 'Oruro', 'Oruro', 'Ciudad Oruro,Gruro,ORU,Oruras,Oruro,Uru Uru,Ururu,ao lu luo,awrwrw,awrwrw  bwlywya,olulo,oruro,Оруро,Օրուրո,أورورو,اورورو، بولیویا,ორურო,オルロ,奥鲁罗,오루로', -17.9833300, -67.1500000, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7117, 'Okinawa Número Uno', 'Okinawa Numero Uno', '', -17.2333300, -62.8166700, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7118, 'Montero', 'Montero', 'Monteras,Montero,Vibora,Víbora,meng te luo,montelo,montero,Монтеро,მონტერო,モンテロ,蒙特羅,몬테로', -17.3386600, -63.2505000, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7119, 'Monteagudo', 'Monteagudo', 'MHW,Monteagudo,Sauces,Villa Monteagudo,Монтеагудо', -19.7998900, -63.9546100, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7120, 'Mojotoro', 'Mojotoro', 'Mojocoro,Mojotoro', -18.9166700, -65.0666700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7121, 'Mojocoya', 'Mojocoya', 'Mojocoya,Mojocoyo', -18.7641000, -64.6197800, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7122, 'Mizque', 'Mizque', 'Ciudad Mizque,Ciudad de Mizqu,Ciudad de Mizque', -17.9410100, -65.3401600, 'BO', '2009-10-16', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7123, 'Mineros', 'Mineros', '', -17.1187600, -63.2310000, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7124, 'Maragua', 'Maragua', '', -19.0461100, -65.4286100, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7125, 'Mapiri', 'Mapiri', 'Mapiri', -15.2500000, -68.1666700, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7126, 'Mairana', 'Mairana', 'Mairana', -18.1191900, -63.9596500, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7127, 'Machacamarca', 'Machacamarca', 'Machacamarca,Machakamarka', -18.1725100, -67.0209900, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7128, 'Los Negros', 'Los Negros', 'Estancia Los Negros,Los Negros', -17.7333300, -63.4333300, 'BO', '2012-01-18', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7129, 'Llallagua', 'Llallagua', 'Llallagua,Llallawa,la la gua,拉拉瓜', -18.4242600, -66.5838800, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7130, 'Lintaca', 'Lintaca', '', -20.7666700, -65.3333300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7131, 'Limoncito', 'Limoncito', 'Limoncito', -18.0310400, -63.4052300, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7132, 'Las Carreras', 'Las Carreras', '', -21.2500000, -65.2833300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7133, 'Las Carreras', 'Las Carreras', '', -21.2084000, -65.2098800, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7134, 'La Paz', 'La Paz', 'A Paz,Chukiyawu,Chuqi Yapu,Chuqiyapu,Ciudad La Paz,Gorad La-Pas,LPB,La Pas,La Pasas,La Paz,La-Pas,La-Pas shaary,La-Pazo,Lapasa,Pax,Soukre/La Paz,la ba si,la paja,la pajha,la pas,la pasa,la paz,labaz,lapaja,lapas,lapaseu,lapaz,rapasu,Λα Πας,Σούκρε/Λα Παζ,Горад Ла-Пас,Ла Паз,Ла Пас,Ла-Пас,Ла-Пас шаары,Լա Պաս,לא פאז,לה פאס,لا پاز,لاباز,لاپاز,ला पाझ,ला पास,লা পাজ,ਲਾ ਪਾਸ,ଲାପାଜ,லா பாஸ்,ലാ പാസ്,ลาปาซ,ლა-პასი,ላፓዝ,ラパス,拉巴斯,라파스', -16.5000000, -68.1500000, 'BO', '2012-07-23', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7135, 'Lahuachaca', 'Lahuachaca', 'Lahuachaca', -17.3705400, -67.6750100, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7136, 'La Cueva', 'La Cueva', 'Cueva,La Cueva', -20.9333300, -64.9000000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7137, 'La Bélgica', 'La Belgica', 'La Belgica,La Bélgica', -17.5500000, -63.2166700, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7138, 'Jorochito', 'Jorochito', 'Jorochiba,Jorochita,Jorochito', -18.0551400, -63.4282100, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7139, 'Yumani', 'Yumani', 'Estancia Yumani,Isla del Sol', -16.0357400, -69.1484300, 'BO', '2013-11-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7140, 'Irpa Irpa', 'Irpa Irpa', 'Irpa Irpa', -17.7166700, -66.2666700, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7141, 'Independencia', 'Independencia', 'Ayopaya,Independencia', -17.0838900, -66.8180400, 'BO', '2017-03-04', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7142, 'Huayllas', 'Huayllas', '', -19.1697200, -65.3261100, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7143, 'Huatajata', 'Huatajata', '', -16.2000000, -68.6833300, 'BO', '2008-05-28', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7144, 'Huata', 'Huata', '', -19.0166700, -65.2500000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7145, 'Huarina', 'Huarina', 'Huarina', -16.2000000, -68.6333300, 'BO', '2013-05-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7146, 'Huanuni', 'Huanuni', 'Huanuni,Villa Huanuni', -18.2890000, -66.8358300, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7147, 'Huajlaya', 'Huajlaya', '', -20.6000000, -64.5500000, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7148, 'Huachacalla', 'Huachacalla', 'Cosillahui,Guachacalla,Huachacalla,Uachakal''ja,Wachakalla,Wachaqalla,wa cha ka ya,Уачакалья,瓦查卡亞', -18.7929800, -68.2615700, 'BO', '2017-02-28', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7149, 'Guayaramerín', 'Guayaramerin', 'GYA,Guajara-Mirim,Guajaramerin,Guajaramerinas,Guayaramerin,Guayaramerín,Puerto Sucre,Wayaramirin,gua ya la mei lin,guaiaramerini,gwayalamelin,Гуаярамерин,გუაიარამერინი,瓜亞拉梅林,과야라메린', -10.8367600, -65.3613600, 'BO', '2017-02-06', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7150, 'Guanay', 'Guanay', 'Guanay,Huanay', -15.4975600, -67.8833200, 'BO', '2014-07-27', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7151, 'Entre Ríos', 'Entre Rios', 'Entre Rios,Entre Ríos,San Luis', -21.5266100, -64.1729900, 'BO', '2012-08-16', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7152, 'Curahuara de Carangas', 'Curahuara de Carangas', 'Curaguara de Carangas,Curahuara,Curahuara de Carangas', -17.8666700, -68.4333300, 'BO', '2013-05-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7153, 'Culpina', 'Culpina', '', -20.8235800, -64.9449200, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7154, 'Cotoca', 'Cotoca', '', -17.8166700, -63.0500000, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7155, 'Cotoca', 'Cotoca', 'Cotoca,Qutuqa,ke tuo ka,კოტოკა,科托卡', -17.7495900, -62.8344200, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7156, 'Coroico', 'Coroico', 'Corioco,Koroikas,Korojko,Quruyqu,Villa de Sagarnaga,Villa de Sagárnaga,ke luo yi ke,Коройко,科羅伊科', -16.1938600, -67.7299800, 'BO', '2014-07-27', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7157, 'Coripata', 'Coripata', 'Coripata', -16.3000000, -67.6000000, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7158, 'Concepción', 'Concepcion', '', -16.4333300, -60.9000000, 'BO', '2006-01-17', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7159, 'Comarapa', 'Comarapa', 'Comarapa,Komarapa,Kumarapa,ke ma la pa,科馬拉帕', -17.9153700, -64.5316300, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7160, 'Colquiri', 'Colquiri', 'Colquiri', -17.3891800, -67.1267100, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7161, 'Colquechaca', 'Colquechaca', 'Ciudad Colquechaca,Ciudad de Colquechaca,Colquechaca', -18.7003100, -66.0039700, 'BO', '2012-08-16', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7162, 'Colomi', 'Colomi', 'Colomi', -17.3500000, -65.8666700, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7163, 'Colchani', 'Colchani', 'Colchani', -20.3000000, -66.9333300, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7164, 'Colchani', 'Colchani', 'Calcheni,Colchani', -17.3166700, -66.7166700, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7165, 'Cochabamba', 'Cochabamba', 'CBB,Ciudad Cochabamba,Cochabamba,Kocabamb,Kocabamba,Kochabamba,Kočabamb,Kočabamba,Kuchawampa,Quchapampa,ke qia ban ba,ko cha bam ba,kochabamba,kochabanba,kwchabamba,kwtshabamba,qwzbmbh,Кочабамба,קוצבמבה,كوتشابامبا,کوچابامبا,โกชาบัมบา,ཀོ་ཅ་བང་ལྦ་,კოჩაბამბა,コチャバンバ,科恰班巴,코차밤바', -17.3895000, -66.1568000, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7166, 'Cobija', 'Cobija', 'CIJ,Cobija,Cobila,Cobya,Kobicha,Kobikha,Kuwiha,Kuwixa,Puerto Cobija,ke wei ha,kobiha,kwbykha,Кобиха,Кобіха,کوبیخا,კობიხა,コビハ,科維哈,코비하', -11.0267100, -68.7691800, 'BO', '2010-08-21', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7167, 'Cliza', 'Cliza', 'Cliza', -17.5877700, -65.9325300, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7168, 'Chuqui Chuqui', 'Chuqui Chuqui', '', -18.8166700, -65.0666700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7169, 'Chulumani', 'Chulumani', '', -16.4085500, -67.5294000, 'BO', '2014-06-27', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7170, 'Chimoré', 'Chimore', 'CCA,Chimore,Chimoré', -16.9941700, -65.1533000, 'BO', '2016-10-02', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7171, 'Chaunaca', 'Chaunaca', 'Chahuanaca,Chahunaca,Chaunaca,Estancia Chaunaca', -19.0166700, -65.4666700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7172, 'Charagua', 'Charagua', '', -19.7915100, -63.1986400, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7173, 'Challapata', 'Challapata', 'Challapata', -18.9020800, -66.7704800, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7174, 'Carandayti', 'Carandayti', 'Carandaiti,Carandaiti Guazu,Carandaiti Guazú,Carandaity,Carandayti', -20.7500000, -63.0666700, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7175, 'Capinota', 'Capinota', 'Capinota', -17.7111300, -66.2608200, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7176, 'Camiri', 'Camiri', 'CAM,Camiri,Kamiri,Refineria Camiri,ka mi li,Камири,კამირი,卡米里', -20.0384900, -63.5183300, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7177, 'Camatindi', 'Camatindi', '', -20.9833300, -63.4333300, 'BO', '2011-07-31', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7178, 'Camargo', 'Camargo', 'Camargo,Cinti,ka ma ge,卡馬戈', -20.6406400, -65.2089300, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7179, 'Buena Vista', 'Buena Vista', 'Bella Vista,Buena Vista', -17.4583000, -63.6712600, 'BO', '2015-11-02', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7180, 'Boyuibe', 'Boyuibe', 'Boyuibe', -20.4322700, -63.2814700, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7181, 'Betanzos', 'Betanzos', '', -19.5529300, -65.4539500, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7182, 'Batallas', 'Batallas', 'Batallas', -16.3000000, -68.5333300, 'BO', '2013-05-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7183, 'Azurduy', 'Azurduy', 'Azurdui,Azurduy,Pomabamba,Villa Azurduy', -20.1061300, -64.4139800, 'BO', '2012-08-15', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7184, 'Atocha', 'Atocha', 'Atocha,Atucha,Municipio de Atocha', -20.9351500, -66.2213900, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7185, 'Ascensión', 'Ascension', 'Anez,Ascencion,Ascención,Ascension,Ascensión,Asencion,Añez', -15.7000000, -63.0833300, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7186, 'Arani', 'Arani', 'Arani', -17.5685400, -65.7688300, 'BO', '2013-05-08', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7187, 'Andamarca', 'Andamarca', 'Andamarca', -18.7793400, -67.5075300, 'BO', '2017-02-28', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7188, 'Amarete', 'Amarete', 'Amarete', -15.2333300, -68.9666700, 'BO', '2013-05-05', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7189, 'Aiquile', 'Aiquile', '', -18.2040800, -65.1806800, 'BO', '2009-10-16', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7190, 'Achacachi', 'Achacachi', 'Acakacis,Achacachi,Ačakačis,Jachakachi,Villa Lealtad,a cha ka qi,akasachy,אטשאקאטשי,اکاساچی,阿查卡奇', -16.0500000, -68.6833300, 'BO', '2012-01-19', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7191, 'Abapó', 'Abapo', 'Abapo,Abapó,Mision Abapo,Misión Abapó,a ba bo,abapw,آباپو,阿巴波', -18.8827900, -63.3802600, 'BO', '2013-01-11', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7192, 'Cruz de Machacamarca', 'Cruz de Machacamarca', '', -18.8839500, -68.4198900, 'BO', '2012-08-03', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7193, 'Santa Fe', 'Santa Fe', '', -17.9081800, -63.0395500, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7194, 'San Julian', 'San Julian', '', -17.8062300, -62.8953600, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7195, 'Puearto Pailas', 'Puearto Pailas', '', -17.6630000, -62.8122700, 'BO', '2015-06-12', 27);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7196, 'Upper Hell''s Gate', 'Upper Hell''s Gate', 'Hellsgate', 17.6430000, -63.2264900, 'BQ', '2011-02-05', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7197, 'The Bottom', 'The Bottom', 'Bottom,Leverock Town', 17.6259000, -63.2491900, 'BQ', '2010-12-19', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7198, 'Oranjestad', 'Oranjestad', 'EUX,Gorad Aran''estad,Oran''estad,Oranestad,Orange Town,Oraniestat,Oranjestad,Oranjestad pa Sint Eustatius,Oranjestad på Sint Eustatius,Oranjestadas,Oranjestado,Oranjested,Oranjestêd,ao la nie si ta de,awranyastad,olanyeseutateu,oraniesutaddo,Οράνιεστατ,Горад Араньестад,Ораньестад,Орањестад,أورانياستاد,اورنجسٹیڈ، سینٹ ایوسٹائیس,ორანესტადი,オラニエスタッド,奥拉涅斯塔德,오라녜스타트', 17.4826800, -62.9832400, 'BQ', '2016-09-30', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7199, 'Kralendijk', 'Kralendijk', 'Gorad Kralendehjk,Kralendajk,Kralendeikas,Kralendejk,Kralendijk,Kralendiyk,Kralentik,Playa,ke la lun dai ke,keulallendeikeu,kralndyk,kralyndayk,kurarendaiku,Κράλεντικ,Горад Кралендэйк,Кралендайк,Кралендајк,Кралендейк,Կրալենդիյկ,كراليندايك,کرالندیک,کرالن‌دیک,კრალენდეიკი,クラレンダイク,克拉伦代克,크랄렌데이크', 12.1500000, -68.2666700, 'BQ', '2014-08-19', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7200, 'Dorp Tera Kora', 'Dorp Tera Kora', 'Dorp Tera Cora,Dorp Tera Corá,Dorp Tera Kora,Terra Corra', 12.1333300, -68.2666700, 'BQ', '2010-12-19', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7201, 'Dorp Rincón', 'Dorp Rincon', 'Dorp Rincan,Dorp Rincon,Dorp Rincón,Rincon,Rincón', 12.2333300, -68.3333300, 'BQ', '2010-12-19', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7202, 'Dorp Antriol', 'Dorp Antriol', 'Deenterra,Dentera,Dorp Antriol,Entrejol', 12.1666700, -68.2666700, 'BQ', '2010-12-19', 28);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7203, 'Vitorino Freire', 'Vitorino Freire', 'Agua Branca,Centro dos Boas,Senador Vitorino Freire,Vitorino Freire,Água Branca', -4.0423800, -45.2377700, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7204, 'Vitória do Mearim', 'Vitoria do Mearim', 'Baixo Mearim,Mearim,Victoria do Baixo Mearim,Vitoria do Baixo Mearim,Vitória do Baixo Mearim', -3.4622200, -44.8705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7205, 'Vitória de Santo Antão', 'Vitoria de Santo Antao', 'Victoria,Vitoria,Vitorija-de-Santu-Antan,Vitória,Витория-де-Санту-Антан', -8.1180600, -35.2913900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7206, 'Viseu', 'Viseu', 'Vizeu', -1.1966700, -46.1400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7207, 'Conde', 'Conde', 'Conde,Jacoca', -7.2597200, -34.9075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7208, 'Vigia', 'Vigia', '', -0.8583300, -48.1416700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7209, 'Viçosa do Ceará', 'Vicosa do Ceara', 'Vicosa,Viçosa', -3.5622200, -41.0922200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7210, 'Viçosa', 'Vicosa', 'Assembleia,Assembléia,Visoza,wei suo sa,Висоза,Վիսոզա,维索萨', -9.3713900, -36.2408300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7211, 'Vicência', 'Vicencia', '', -7.6569400, -35.3266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7212, 'Viana', 'Viana', 'Viana,Vianna,Виана', -3.2202800, -45.0036100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7213, 'Várzea Alegre', 'Varzea Alegre', '', -5.3500000, -40.3833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7214, 'Varjota', 'Varjota', '', -4.1944400, -40.4766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7215, 'Vargem Grande', 'Vargem Grande', '', -3.5430600, -43.9158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7216, 'Valença do Piauí', 'Valenca do Piaui', 'Berlengas,Valenca,Valença', -6.4075000, -41.7455600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7217, 'Urucurituba', 'Urucurituba', '', -3.1284500, -58.1585600, 'BR', '2013-04-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7218, 'Uruçuí', 'Urucui', 'Urussuhy,Urussui,Urussuí', -7.2294400, -44.5561100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7219, 'Urucará', 'Urucara', '', -2.5363900, -57.7600000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7220, 'Uruburetama', 'Uruburetama', 'Arraial,Sao Joao de Uruburetama,São João de Uruburetama', -3.6250000, -39.5083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7221, 'Urbano Santos', 'Urbano Santos', '', -3.2077800, -43.4036100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7222, 'Upanema', 'Upanema', '', -5.6419400, -37.2577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7223, 'União dos Palmares', 'Uniao dos Palmares', 'Uniao,União', -9.1627800, -36.0319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7224, 'União', 'Uniao', '', -4.5858300, -42.8641700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7225, 'Umirim', 'Umirim', 'Riacho da Sela,Riacho da Sella,Riachuelo', -3.6772200, -39.3502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7226, 'Umbuzeiro', 'Umbuzeiro', '', -7.6955600, -35.6636100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7227, 'Umarizal', 'Umarizal', 'Divinopolis', -5.9905600, -37.8144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7228, 'Uiraúna', 'Uirauna', 'Belem,Belém,Canaa,Canaã', -6.5183300, -38.4122200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7229, 'Ubajara', 'Ubajara', '', -3.8544400, -40.9211100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7230, 'Uauá', 'Uaua', '', -9.8413900, -39.4816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7231, 'Tutóia', 'Tutoia', 'Tutoya', -2.7619400, -42.2744400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7232, 'Turiaçu', 'Turiacu', 'Turiassu,Turiassú,Tury-Assu,Tury-Assú', -1.6633300, -45.3716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7233, 'Tupanatinga', 'Tupanatinga', 'Santa Clara', -8.7533300, -37.3397200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7234, 'Tuntum', 'Tuntum', 'Tumtum', -5.2580600, -44.6488900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7235, 'Tucuruí', 'Tucurui', 'Alcobaca,Alcobaça,TUR', -3.7658500, -49.6792300, 'BR', '2014-08-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7236, 'Tucumã', 'Tucuma', '', -0.1833300, -50.0500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7237, 'Triunfo', 'Triunfo', '', -6.5666700, -38.6000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7238, 'Trindade', 'Trindade', '', -7.7619400, -40.2677800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7239, 'Trairi', 'Trairi', 'Trahiry', -3.2777800, -39.2688900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7240, 'Traipu', 'Traipu', 'Porto da Folha,Pôrto da Fôlha', -9.9705600, -37.0033300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7241, 'Touros', 'Touros', '', -5.1988900, -35.4608300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7242, 'Toritama', 'Toritama', 'Toritama,Torres,Торитама', -8.0066700, -36.0566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7243, 'Tomé Açu', 'Tome Acu', '', -2.4188900, -48.1522200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7244, 'Timon', 'Timon', 'Flores,Timon,Тимон', -5.0941700, -42.8366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7245, 'Timbiras', 'Timbiras', 'Monte Alegre,Urubu,Urubú', -4.2552800, -43.9405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7246, 'Timbaúba', 'Timbauba', 'Gurjao,Gurjão', -7.5052800, -35.3183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7247, 'Tianguá', 'Tiangua', 'Barracao,Barracão', -3.7322200, -40.9916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7248, 'Terra Santa', 'Terra Santa', '', -2.1041700, -56.4869400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7249, 'Teresina', 'Teresina', 'Gorad Tehrehzina,Poti,THE,Teresina,Terezina,Theresina,Therezina,Vila Nova do Poti,te lei xi na,te re si na,telejina,terejina,teresina,trzynh,tyrysyna,Горад Тэрэзіна,Терезина,Терезіна,תרזינה,تيريسينا,تیریسینا,টেরেসিনা,เตเรซีนา,ტერეზინა,テレジーナ,特雷西納,테레지나', -5.0891700, -42.8019400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7250, 'Teixeira', 'Teixeira', 'Tejshejra,Teyseyra,te xie la,Тейшейра,Տեյշեյրա,特谢拉', -7.2227800, -37.2541700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7251, 'Tavares', 'Tavares', '', -7.6358300, -37.8783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7252, 'São João dos Inhamuns', 'Sao Joao dos Inhamuns', 'Sao Joao dos Inhamuns,São João dos Inhamuns', -6.0000000, -40.2833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7253, 'Taquaritinga do Norte', 'Taquaritinga do Norte', 'Jaquaritinga do Norte,Taquaretinga,Taquaritinga', -7.9030600, -36.0441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7254, 'Taquarana', 'Taquarana', 'Cana Brava dos Pais,Cana-Brava,Canna Brava', -9.6450000, -36.4972200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7255, 'Taperoá', 'Taperoa', 'Batalhao,Batalhão', -7.2075000, -36.8266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7256, 'Tangará', 'Tangara', 'Riacho', -6.1994400, -35.8016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7257, 'Tamboril', 'Tamboril', 'Tambari', -4.8322200, -40.3205600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7258, 'Tamandaré', 'Tamandare', '', -8.7563200, -35.0999500, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7259, 'Taipu', 'Taipu', '', -5.6216700, -35.5966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7260, 'Tabira', 'Tabira', 'Espirito Santo,Madeira', -7.5908300, -37.5394400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7261, 'Surubim', 'Surubim', '', -7.8330600, -35.7547200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7262, 'Sumé', 'Sume', 'Sao Thome,Sao Tome,São Thomé,São Tomé', -7.6716700, -36.8800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7263, 'Sousa', 'Sousa', 'Souza', -6.7591700, -38.2280600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7264, 'Soure', 'Soure', 'SFK', -0.7166700, -48.5233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7265, 'Soledade', 'Soledade', 'Ibiapinopolis,Ibiapinópolis', -7.0572200, -36.3627800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7266, 'Solânea', 'Solanea', 'Moreno', -6.7550000, -35.5400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7267, 'Sobral', 'Sobral', 'Januaria de Acaracu,Januária de Acaracu,QBX,Sobral,Sobrat,Собрал', -3.6861100, -40.3497200, 'BR', '2013-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7268, 'Sirinhaém', 'Sirinhaem', 'Serinhaem,Sirinkhaem,Сиринхаем,סירינהאַéם', -8.5908300, -35.1161100, 'BR', '2012-04-16', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7269, 'Simplício Mendes', 'Simplicio Mendes', '', -7.8538900, -41.9102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7270, 'Simões', 'Simoes', '', -7.5988900, -40.8177800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7271, 'Severiano Melo', 'Severiano Melo', '', -5.7772200, -37.9577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7272, 'Sertânia', 'Sertania', 'Alagoa de Baixo', -8.0736100, -37.2644400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7273, 'Serra Talhada', 'Serra Talhada', 'Serra-Tal''jada,Vila Bela,Villa Bella,sai la ta li ya da,serara talahada,Серра-Тальяда,সেররা টালহাডা,塞拉塔利亚达', -7.9919400, -38.2983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7274, 'Serra Branca', 'Serra Branca', '', -6.5333300, -38.2666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7275, 'Senador Pompeu', 'Senador Pompeu', '', -5.5880600, -39.3716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7276, 'Senador José Porfírio', 'Senador Jose Porfirio', '', -2.5908300, -51.9541700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7277, 'Satuba', 'Satuba', '', -9.5633300, -35.8244400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7278, 'São Tomé', 'Sao Tome', 'Sao Thome,São Thomé', -5.9725000, -36.0752800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7279, 'São Sebastião', 'Sao Sebastiao', 'Salome,Salomé,San-Sebast''jan,Сан-Себастьян', -9.9336100, -36.5541700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7280, 'São Raimundo Nonato', 'Sao Raimundo Nonato', 'Raimundo Nonato,Sao Raymundo Nonato', -9.0152800, -42.6994400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7281, 'São Raimundo das Mangabeiras', 'Sao Raimundo das Mangabeiras', 'Sao Raymundo do Rio Neves,São Raymundo do Rio Neves', -7.0219400, -45.4811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7282, 'São Pedro do Piauí', 'Sao Pedro do Piaui', 'Sao Pedro,São Pedro', -5.9294400, -42.7186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7283, 'São Paulo do Potengi', 'Sao Paulo do Potengi', 'Potengy,Sao Paulo do Potengi,São Paulo do Potengi', -5.8950000, -35.7627800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7284, 'São Miguel do Tapuio', 'Sao Miguel do Tapuio', 'Deliciosa,San-Migel-du-Tapuju,Sao Miguel,São Miguel,Tapuio,sa''o miguraela do tapu''i''o,sheng mi ge er-du ta pu you,Сан-Мигел-ду-Тапую,সাও মিগুৱেল ডো টাপুইও,圣米格尔-杜塔普尤', -5.5036100, -41.3233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7285, 'São Miguel dos Campos', 'Sao Miguel dos Campos', 'San-Migel''-dus-Kampus,Sao Miguel,Sao Miguel De Campos,São Miguel,Сан-Мигель-дус-Кампус', -9.7811100, -36.0936100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7286, 'São Miguel do Guamá', 'Sao Miguel do Guama', 'Guama,Guamá', -1.6266700, -47.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7287, 'São Miguel', 'Sao Miguel', '', -5.4666700, -35.3666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7288, 'São Mateus do Maranhão', 'Sao Mateus do Maranhao', '', -4.0416700, -44.4750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7289, 'São Luís do Quitunde', 'Sao Luis do Quitunde', 'Sao Luiz de Quitunde,Sao Luiz do Quitunde,São Luiz de Quitunde,São Luiz do Quitunde', -9.3183300, -35.5611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7290, 'São Luís', 'Sao Luis', 'Maranhao,Maranhão,SLZ,San Luisas,San-Luis,Sao Louis,Sao Luis,Sao Luis do Maranhao,Sao Luiz,Sao Luiz de Maranhao,Sao Luiz do Maranhao,Saun Luis,Saun Luís,São Luis,São Luiz,São Luiz de Maranhão,São Luiz do Maranhão,São Luís,São Luís do Maranhão,cavo luyicu,sa''o lu''isa,san-luisi,sanglu-iseu,saw lwyys,saw lwyz,sayw lwyys  maranhaw,sheng lu yi si,Σάο Λουίς,Сан-Луис,Сан-Луіс,Сан-Луїс,Сао Луис,סאו לואיס,ساؤ لوئیس,ساؤ لوئیس، مارانہاؤ,سائو لوئیس، مارانهاو,ساو لويز,साओ लुईस,সাও লুইস,சாவோ லூயிசு,სან-ლუისი,サン・ルイス,圣路易斯,상루이스', -2.5297200, -44.3027800, 'BR', '2013-01-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7291, 'São Lourenço da Mata', 'Sao Lourenco da Mata', 'San-Lorensu-da-Mata,Sao Lourenco,Sao Lourenco da Matta,São Lourenço,São Lourenço da Matta,Сан-Лоренсу-да-Мата', -8.0022200, -35.0183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7292, 'São José do Egito', 'Sao Jose do Egito', 'Queimadas,Sao Jose da Ingazeira,Sao Jose das Queimadas,Sao Jose do Egypto,São José da Ingàzeira,São José das Queimadas,São José do Egypto', -7.4788900, -37.2744400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7293, 'São José do Campestre', 'Sao Jose do Campestre', 'Campestre', -6.3155600, -35.7138900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7294, 'São José do Belmonte', 'Sao Jose do Belmonte', 'Belmonte,Manicobal,Manissobal,Maniçobal', -7.8613900, -38.7597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7295, 'São José de Ribamar', 'Sao Jose de Ribamar', 'Ribamar,Sao-Jose-do-Ribamar,São-José-do-Ribamar', -2.5619400, -44.0541700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7296, 'São José de Piranhas', 'Sao Jose de Piranhas', 'Jatoba,Jatobá', -7.1205600, -38.5019400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7297, 'São José de Mipibu', 'Sao Jose de Mipibu', 'Sao Jose Do Mipibu', -6.0747200, -35.2377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7298, 'São José da Tapera', 'Sao Jose da Tapera', '', -9.5583300, -37.3811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7299, 'São José da Laje', 'Sao Jose da Laje', 'Jose da Lage,José da Lage,Sao Jose da Lage,São José da Lage', -9.0097200, -36.0583300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7300, 'São José da Coroa Grande', 'Sao Jose da Coroa Grande', 'Puiracu,Puirassu,Puirassú,Puiraçu', -8.8977800, -35.1477800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7301, 'São Joaquim do Monte', 'Sao Joaquim do Monte', 'Camaratuba,Sao Joaquim,São Joaquim', -8.4325000, -35.8044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7302, 'São João dos Patos', 'Sao Joao dos Patos', '', -6.4950000, -43.7022200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7303, 'São João do Piauí', 'Sao Joao do Piaui', 'San-Zhuan-du-Piaui,Sao Joao Do Piauhy,São Joao Do Piauhy,pi ao yi zhou sheng ruo ang,sa''o joya''o do piya''u''i,Сан-Жуан-ду-Пиауи,সাও জোয়াও ডো পিয়াউই,皮奥伊州圣若昂', -8.3580600, -42.2466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7304, 'São João de Pirabas', 'Sao Joao de Pirabas', '', -0.7747200, -47.1772200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7305, 'São João Batista', 'Sao Joao Batista', 'Ibipeuara', -2.9552800, -44.8069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7306, 'São João', 'Sao Joao', '', -8.8755600, -36.3666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7307, 'São Gonçalo do Amarante', 'Sao Goncalo do Amarante', 'Felipe Camarao,Felipe Camarão,Filipe Camarao,Filipe Camarão,Sao Goncalo,São Gonçalo', -5.7933300, -35.3294400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7308, 'São Gonçalo do Amarante', 'Sao Goncalo do Amarante', 'Anacetaba,Sao Goncalo,São Gonçalo', -3.6072200, -38.9683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7309, 'São Geraldo do Araguaia', 'Sao Geraldo do Araguaia', '', -6.4005600, -48.5550000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7310, 'São Félix do Xingu', 'Sao Felix do Xingu', 'SXX,Sao Felix,São Felix', -6.6447200, -51.9950000, 'BR', '2017-02-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7311, 'São Domingos do Maranhão', 'Sao Domingos do Maranhao', 'Pucuma,Pucumã', -5.5758300, -44.3852800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7312, 'São Caetano de Odivelas', 'Sao Caetano de Odivelas', 'Sao Caetano de Odivellas,São Caetano de Odivellas', -0.7500000, -48.0200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7313, 'São Bernardo', 'Sao Bernardo', 'Sao Bernardo do Parnahyba,São Bernardo do Parnahyba', -3.3613900, -42.4177800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7314, 'São Bento', 'Sao Bento', '', -6.2833300, -37.7500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7315, 'São Bento', 'Sao Bento', 'San-Bentu,Sao Benito dos Perizes,Sao Bento das Perdizes,Sao Bento dos Perizes,São Benito dos Perizes,São Bento das Perdizes,Сан-Бенту', -2.6958300, -44.8213900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7316, 'São Benedito do Rio Preto', 'Sao Benedito do Rio Preto', 'Curuzu,Sao Benedicto,Sao Benedito,São Benedicto,São Benedito', -3.3336100, -43.5283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7317, 'Santo Antônio do Tauá', 'Santo Antonio do Taua', 'Santo Antonio,Santo Antonio de Taua,Santo Antônio,Santo Antônio de Tauá', -1.1519400, -48.1294400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7318, 'Santo Antônio', 'Santo Antonio', 'Padre Miguelinho', -6.3105600, -35.4788900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7319, 'Santa Rita', 'Santa Rita', '', -7.1138900, -34.9780600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7320, 'Santa Rita', 'Santa Rita', 'Santa Rita,Санта Рита', -3.8635800, -43.8599900, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7321, 'Santarém', 'Santarem', 'STM,Santarem,Santarem i Brasil,Santaren,Santarenas,Santarém,Santarém i Brasil,sang ta rey,santaleng,santaren,santary  para,sheng ta lun,sntrm,Сантарем,Сантарен,סנטרם,سانتاری، پارا,ซังตาเรย์,サンタレン,聖塔倫,산타렝', -2.4430600, -54.7083300, 'BR', '2013-12-25', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7322, 'Santa Quitéria do Maranhão', 'Santa Quiteria do Maranhao', 'Bacuri,Bacurí,Santa Quiteria,Santa Quitéria', -3.5155600, -42.5466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7323, 'Santa Quitéria', 'Santa Quiteria', '', -4.3319400, -40.1566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7324, 'Santana do Mundaú', 'Santana do Mundau', 'Mundahu Mirim,Mundahú Mirim,Mundau Mirim,Mundaú Mirim', -9.1680600, -36.2222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7325, 'Santana do Matos', 'Santana do Matos', 'Sant''Anna dos Mattos', -5.9575000, -36.6555600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7326, 'Santana do Ipanema', 'Santana do Ipanema', 'Sant''Anna do Ipanema,Santana-du-Ipanema,Сантана-ду-Ипанема', -9.3783300, -37.2452800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7327, 'Santana do Acaraú', 'Santana do Acarau', 'Licania,Sant''Anna,Santana', -3.4605600, -40.2122200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7328, 'Santa Maria do Pará', 'Santa Maria do Para', 'Santa Maria', -1.3502800, -47.5755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7329, 'Santa Maria da Boa Vista', 'Santa Maria da Boa Vista', 'Boa Vista,Coripos,Coripós,Santa Maria Boa Vista', -8.8077800, -39.8255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7330, 'Santa Luzia', 'Santa Luzia', '', -7.6426500, -47.2173800, 'BR', '2013-06-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7331, 'Santa Luzia', 'Santa Luzia', '', -6.8722200, -36.9186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7332, 'Santa Inês', 'Santa Ines', 'Ines,Inês,Santa-Ines,Санта-Инес', -3.6666700, -45.3800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7333, 'Santa Helena', 'Santa Helena', '', -2.2311100, -45.3000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7334, 'Santa Cruz do Capibaribe', 'Santa Cruz do Capibaribe', 'Capibaribe,Santa Cruz,Santa-Krus-du-Kapibaribi,santa kruja do kapibaribe,sheng ke lu si-du ka pi ba li bi,Санта-Крус-ду-Капибариби,সান্টা ক্রুজ ডো কাপিবারিবে,圣克鲁斯-杜卡皮巴里比', -7.9575000, -36.2047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7335, 'Santa Cruz', 'Santa Cruz', 'Santa-Krus,sheng ke lu si,Санта-Крус,聖克魯斯', -6.2294400, -36.0227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7336, 'Salinópolis', 'Salinopolis', 'Salinas', -0.6136100, -47.3561100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7337, 'Salgueiro', 'Salgueiro', 'Salgejru,Salqueiro,Салгейру', -8.0741700, -39.1191700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7338, 'Salgado de São Félix', 'Salgado de Sao Felix', 'Abura,Aburá,Ibura,Salgada,Salgado', -7.3569400, -35.4405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7339, 'Russas', 'Russas', 'Rucas,Ruças,Sao Bernardo das Russas,São Bernardo das Russas', -4.9402800, -37.9758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7340, 'Rio Tinto', 'Rio Tinto', '', -6.8030600, -35.0805600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7341, 'Rio Largo', 'Rio Largo', '', -9.4783300, -35.8533300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7342, 'Rio Formoso', 'Rio Formoso', '', -8.6687700, -35.1627700, 'BR', '2012-12-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7343, 'Ribeirão', 'Ribeirao', '', -8.5144400, -35.3777800, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7344, 'Riachão', 'Riachao', 'Riachaq', -7.3619400, -46.6172200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7345, 'Reriutaba', 'Reriutaba', 'Santa Cruz', -4.1416700, -40.5822200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7346, 'Remígio', 'Remigio', 'Lagoa do Remigio,Lagôa do Remigio,Remigio,Remígio', -6.9464600, -35.7803900, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7347, 'Regeneração', 'Regeneracao', '', -6.2312200, -42.6869100, 'BR', '2014-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7348, 'Redenção', 'Redencao', 'Redempcao,Redempção', -4.2258300, -38.7305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7349, 'Recife', 'Recife', 'Arrecife,Fernambucum,Gorad Rehsifi,Mauricea,Mauricéa,Pernambuco,REC,Recife,Resife,Resifi,Resifė,hesiphi,hesipi,lei xi fei,li si fei,re sifi,recihpi,reshife,resiphe,resipi,risifi,rsyph,rysyf,rysyfy,Ρεσίφε,Горад Рэсіфі,Ресифе,Ресифи,Ресіфі,Ռեսիֆի,רסיפה,ريسيفي,ریسیف,रिसीफ़ी,रेसिफे,রেসিফে,হেসিফি,ரெசிஃபி,เรซีฟี,რესიფი,レシフェ,李斯腓,累西腓,헤시피', -8.0538900, -34.8811100, 'BR', '2014-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7350, 'Raposa', 'Raposa', '', -6.5166700, -44.1833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7351, 'Quixeré', 'Quixere', '', -5.0741700, -37.9886100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7352, 'Quixeramobim', 'Quixeramobim', 'Nova Vila do Campo Maior,Santo Antonio do Bogueirao de Quixeramobim,Santo Antônio do Bogueirão de Quixeramobim', -5.1991700, -39.2927800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7353, 'Quixadá', 'Quixada', '', -4.9713900, -39.0152800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7354, 'Quipapá', 'Quipapa', '', -8.8277800, -36.0116700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7355, 'Quebrangulo', 'Quebrangulo', 'Victoria,Vitoria,Vitória', -9.3188900, -36.4711100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7356, 'Puxinanã', 'Puxinana', '', -7.1611100, -35.9605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7357, 'Princesa Isabel', 'Princesa Isabel', 'Princesa,Princess Isabel,Princeza', -7.7366700, -37.9933300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7358, 'Presidente Dutra', 'Presidente Dutra', 'Curador,PDR', -5.2900000, -44.4900000, 'BR', '2017-07-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7359, 'Prainha', 'Prainha', '', -1.8000000, -53.4800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7360, 'Santana', 'Santana', 'Porto,Porto de Santana,Pôrto,Pôrto de Santana,Santana,Сантана', -0.0583300, -51.1816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7361, 'Porto Franco', 'Porto Franco', '', -6.3383300, -47.3991700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7362, 'Porto de Moz', 'Porto de Moz', 'PTQ,Porto de Mos,Pôrto de Mós', -1.7483300, -52.2383300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7363, 'Porto da Folha', 'Porto da Folha', '', -9.9172200, -37.2783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7364, 'Porto Calvo', 'Porto Calvo', '', -9.0450000, -35.3983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7365, 'Porto', 'Porto', 'Joao Pessoa,João Pessoa', -3.8933300, -42.7100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7366, 'Portel', 'Portel', '', -1.9355600, -50.8211100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7367, 'Pombos', 'Pombos', 'Sao Joao dos Pombos,São João dos Pombos', -8.1413900, -35.3958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7368, 'Pombal', 'Pombal', 'Pombal,peng ba er,Помбал,蓬巴尔', -6.7702800, -37.8016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7369, 'Poço das Trincheiras', 'Poco das Trincheiras', '', -9.3125000, -37.2855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7370, 'Poço Branco', 'Poco Branco', '', -5.6227800, -35.6627800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7371, 'Pocinhos', 'Pocinhos', 'Joffily,Jóffily,Posin''jus,Puteoli,bo xi niu si,posinahosa,Посиньюс,পোসিনহোস,波西纽斯', -7.0766700, -36.0611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7372, 'Poção de Pedras', 'Pocao de Pedras', 'Pocao de Pedra,Pocao de Pedro,Pocão de Pedro,Poção de Pedra', -4.6666700, -44.8500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7373, 'Pitimbu', 'Pitimbu', '', -7.4705600, -34.8086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7374, 'Pirpirituba', 'Pirpirituba', '', -6.7800000, -35.4986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7375, 'Piripiri', 'Piripiri', 'Periperi,Peripery,Periperí', -4.2733300, -41.7769400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7376, 'Pirapemas', 'Pirapemas', 'Arapema', -3.7266700, -44.2233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7377, 'Piracuruca', 'Piracuruca', '', -3.9280600, -41.7091700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7378, 'Pio XII', 'Pio XII', '', -3.8325000, -45.1525000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7379, 'Pio IX', 'Pio IX', 'Patrocinio,Patrocínio,Pio Nono,Pio Nôno,Umbuzeiro', -6.8375000, -40.5791700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7380, 'Pinheiro', 'Pinheiro', 'PHI,Pin''ejru,Pinheiros,Пиньейру', -2.5213900, -45.0825000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7381, 'Pindaré Mirim', 'Pindare Mirim', 'Engenho Central,Sao Pedro,Sao Pedro de Alcantara,São Pedro,São Pedro de Alcantara', -3.6083300, -45.3433300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7382, 'Pimenteiras', 'Pimenteiras', 'Pimenteira', -6.2452800, -41.4191700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7383, 'Pilar', 'Pilar', 'Manguaba,Pilar,Пилар', -9.5972200, -35.9566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7384, 'Pilar', 'Pilar', '', -7.2672200, -35.2600000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7385, 'Picuí', 'Picui', 'Picuhy', -6.5105600, -36.3469400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7386, 'Picos', 'Picos', 'PCS,Picos,Pikus,pi ku si,pikosa,pikuseu,pikusu,Пикус,পিকোস,ピークス,皮库斯,피쿠스', -7.0769400, -41.4669400, 'BR', '2013-11-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7387, 'Piancó', 'Pianco', '', -7.1980600, -37.9291700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7388, 'Petrolina', 'Petrolina', 'PNZ,Petrolina,bi de luo li na,petrolina,Петролина,পেট্রোলিনা,彼得羅利納', -9.3986100, -40.5008300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7389, 'Jatobá', 'Jatoba', 'Itaparica,Jatoba,Jatobe,Jatobá,Ятоба', -9.1830600, -38.2688900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7390, 'Pesqueira', 'Pesqueira', '', -8.3577800, -36.6963900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7391, 'Pentecoste', 'Pentecoste', '', -3.7927800, -39.2702800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7392, 'Pendências', 'Pendencias', 'Independencia,Pendencia,Pendência', -5.2600000, -36.7222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7393, 'Penalva', 'Penalva', '', -3.2941700, -45.1736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7394, 'Pedro Velho', 'Pedro Velho', '', -6.4391700, -35.2213900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7395, 'Pedro II', 'Pedro II', 'Itamaraty,Matoes,Matões,Pedro Segundo', -4.4247200, -41.4586100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7396, 'Pedras de Fogo', 'Pedras de Fogo', '', -7.4019400, -35.1163900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7397, 'Pedra Branca', 'Pedra Branca', 'Pedra-Branka,Tabuleiro da Peruca,Педра-Бранка', -5.4541700, -39.7172200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7398, 'Pedra', 'Pedra', '', -8.4969400, -36.9408300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7399, 'Paulo Ramos', 'Paulo Ramos', '', -4.2166700, -45.1833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7400, 'Paulo Afonso', 'Paulo Afonso', 'Barra,Brejo,PAV,Paulu-Afonsu,pa''ulo aphonso,Паулу-Афонсу,পাউলো আফোন্সো,პაულუ-ალფონსუ,保罗·阿方索城', -9.4061100, -38.2147200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7401, 'Paulista', 'Paulista', 'Paulista,Паулиста', -7.9408300, -34.8730600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7402, 'Paulista', 'Paulista', 'Paulista,Piranha,Паулиста', -6.5938900, -37.6241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7403, 'Patu', 'Patu', '', -6.1100000, -37.6366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7404, 'Patos', 'Patos', 'Patus,pa tu si,patosa,Патус,Պատուս,পাটোস,帕图斯', -7.0244400, -37.2800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7405, 'Pastos Bons', 'Pastos Bons', '', -6.6016700, -44.0766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7406, 'Passira', 'Passira', 'Malhada,Pacira,Pedra Tapada', -7.9950000, -35.5805600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7407, 'Passagem Franca', 'Passagem Franca', '', -6.1797200, -43.7836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7408, 'Parnarama', 'Parnarama', '', -5.6816700, -43.0933300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7409, 'Parnamirim', 'Parnamirim', 'Leopoldina', -8.0905600, -39.5783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7410, 'Parnamirim', 'Parnamirim', 'Eduardo Gomes,Parnamirim,Parnamirin,parnamirima,Парнамирин,পার্নামিরিম', -5.9155600, -35.2627800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7411, 'Parnaíba', 'Parnaiba', 'Feitoria,Parnahiba,Parnahyba,Parnaiba,Parnaimpa,Porto das Barcas,Pôrto das Barcas,Sao Joao da Parnahiba,São Joao da Parnahiba,ba na yi ba,parna''iba,Παρναΐμπα,Парнаиба,পার্নাইবা,巴纳伊巴', -2.9047200, -41.7766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7412, 'Parintins', 'Parintins', 'PIN,Parintins,Parintinsa,Паринтинса', -2.6283300, -56.7358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7413, 'Parelhas', 'Parelhas', '', -6.6877800, -36.6575000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7414, 'Parambu', 'Parambu', 'Cachoeirinha,Sao Pedro da Cachoeirinha,São Pedro da Cachoeirinha', -6.2111100, -40.6944400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7415, 'Paraipaba', 'Paraipaba', 'Tigre', -3.4394400, -39.1483300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7416, 'Paraibano', 'Paraibano', '', -6.4330600, -43.9836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7417, 'Paragominas', 'Paragominas', '', -2.9666700, -47.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7418, 'Paracuru', 'Paracuru', '', -3.4100000, -39.0305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7419, 'Pão de Açúcar', 'Pao de Acucar', 'Pao de Assucar,Páo de Assucar', -9.7483300, -37.4366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7420, 'Palmeirais', 'Palmeirais', 'Belem,Belém', -5.9777800, -43.0633300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7421, 'Palmares', 'Palmares', 'Palmaris,pa er ma li si,palamaresa,Палмарис,পালমারেস,帕尔马里斯', -8.6833300, -35.5916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7422, 'Pacatuba', 'Pacatuba', '', -3.9841700, -38.6202800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7423, 'Pacajus', 'Pacajus', 'Guarani,Guarany', -4.1725000, -38.4605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7424, 'Ouricuri', 'Ouricuri', 'Ouricury', -7.8825000, -40.0816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7425, 'Ourém', 'Ourem', '', -1.5519400, -47.1144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7426, 'Orós', 'Oros', 'Onos', -6.2444400, -38.9136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7427, 'Orobó', 'Orobo', 'Queimadas', -7.7450000, -35.6022200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7428, 'Oriximiná', 'Oriximina', 'ORX', -1.7655600, -55.8661100, 'BR', '2016-12-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7429, 'Olivença', 'Olivenca', 'Capim', -9.5186100, -37.1905600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7430, 'Olinda', 'Olinda', 'Olinda,ao lin da,olinda,ollinda,orinda,xo ling da,Олинда,Олінда,אולינדה,ওলিন্ডা,โอลิงดา,ოლინდა,オリンダ,奧林達,올린다', -8.0088900, -34.8552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7431, 'Oeiras do Pará', 'Oeiras do Para', 'Araticu', -2.0030600, -49.8544400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7432, 'Oeiras', 'Oeiras', 'Mocha,Uehjras,ao ai la si,Уэйрас,奥埃拉斯', -7.0252800, -42.1311100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7433, 'Ocara', 'Ocara', 'Jurema', -4.4908300, -38.5966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7434, 'Ábidos', 'Abidos', 'Obidos,Óbidos', -1.9175000, -55.5180600, 'BR', '2016-10-31', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7435, 'Novo Oriente', 'Novo Oriente', '', -5.5344400, -40.7741700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7436, 'Novo Lino', 'Novo Lino', '', -8.9150000, -35.6466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7437, 'Nova Russas', 'Nova Russas', '', -4.7066700, -40.5630600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7438, 'Nova Olinda do Norte', 'Nova Olinda do Norte', 'Boca do Fumaco,Bocca do Fumaco', -3.8917400, -59.0954200, 'BR', '2014-07-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7439, 'Nova Floresta', 'Nova Floresta', '', -6.4552800, -36.2033300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7440, 'Nova Cruz', 'Nova Cruz', '', -6.4780600, -35.4338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7441, 'Nísia Floresta', 'Nisia Floresta', 'Papari,Papary', -6.0911100, -35.2086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7442, 'Nhamundá', 'Nhamunda', 'Ilha das Cotias,Ilha das Cutias', -2.1861100, -56.7130600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7443, 'Nazaré da Mata', 'Nazare da Mata', 'Nazar-da-Mata,Nazare,Nazareth,Nazaré,Назар-да-Мата', -7.7416700, -35.2277800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7444, 'Natuba', 'Natuba', '', -7.6413900, -35.5500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7445, 'Natal', 'Natal', 'NAT,Natal,Natalo,Натал,נאטאל', -5.7950000, -35.2094400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7446, 'Murici', 'Murici', '', -9.3066700, -35.9433300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7447, 'Mulungu', 'Mulungu', 'Camarazal', -7.0244400, -35.4619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7448, 'Muaná', 'Muana', '', -1.5283300, -49.2166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7449, 'Morros', 'Morros', '', -9.4466700, -46.3002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7450, 'Moreno', 'Moreno', '', -8.1186100, -35.0922200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7451, 'Morada Nova', 'Morada Nova', 'Espirito Santo,Espírito Santo', -5.1066700, -38.3725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7452, 'Montes Altos', 'Montes Altos', 'Monte Alto', -5.8333300, -47.0666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7453, 'Monteiro', 'Monteiro', 'Alagoa do Monteiro,Alagôa do Monteiro,Monterio', -7.8894400, -37.1200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7454, 'Monte Alegre', 'Monte Alegre', '', -5.8897200, -36.3013900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7455, 'Monte Alegre', 'Monte Alegre', 'MTE,Monte Alegre,Monti-Alegri,QGD,Монти-Алегри', -2.0008200, -54.0810200, 'BR', '2013-11-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7456, 'Montanhas', 'Montanhas', 'Lagoa da Montanha,Lagôa da Montanha', -6.4858300, -35.2875000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7457, 'Monsenhor Gil', 'Monsenhor Gil', 'Gil,Natal', -5.5641700, -42.6077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7458, 'Monção', 'Moncao', 'Carara,Carará', -3.4916700, -45.2511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7459, 'Mombaça', 'Mombaca', 'Maria Pereira', -5.7430600, -39.6275000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7460, 'Moju', 'Moju', '', -1.8838900, -48.7688900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7461, 'Mogeiro', 'Mogeiro', 'Mojeiro', -7.2994400, -35.4794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7462, 'Mossoró', 'Mossoro', 'MVF,Mocoro,Mosoro,Moçoró,mo suo luo,mosasoro,mosoro,Мосоро,মোসসোরো,モソロー,莫索罗', -5.1875000, -37.3441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7463, 'Mocajuba', 'Mocajuba', '', -2.5841700, -49.5072200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7464, 'Missão Velha', 'Missao Velha', '', -7.2497200, -39.1430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7465, 'Mirador', 'Mirador', '', -6.3708300, -44.3630600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7466, 'Minador do Negrão', 'Minador do Negrao', 'Minador do Negro', -9.3052800, -36.8647200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7467, 'Milagres', 'Milagres', '', -7.3133300, -38.9455600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7468, 'Miguel Alves', 'Miguel Alves', '', -4.1655600, -42.8952800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7469, 'Messias', 'Messias', 'Floriano', -9.3833300, -35.8416700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7470, 'Mazagão', 'Mazagao', 'Mazaganopolis', -0.1150000, -51.2894400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7471, 'Maués', 'Maues', '', -3.3836100, -57.7186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7472, 'Matriz de Camaragibe', 'Matriz de Camaragibe', 'Matriz de Camaragibe', -9.1516700, -35.5333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7473, 'Matinha', 'Matinha', '', -3.1005600, -45.0336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7474, 'Matias Olímpio', 'Matias Olimpio', '', -3.7158300, -42.5555600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7475, 'Mata Grande', 'Mata Grande', 'Paulo Affonso,Paulo Afonso', -9.1175000, -37.7322200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7476, 'Massaranduba', 'Massaranduba', 'Macarandiba,Macaranduba,Massarandiba,Maçarandiba,Maçaranduba', -7.2002800, -35.7891700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7477, 'Maribondo', 'Maribondo', 'Maribondo', -9.5772200, -36.3052800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7478, 'Mari', 'Mari', 'Araca,Araça', -7.0600000, -35.3194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7479, 'Marechal Deodoro', 'Marechal Deodoro', 'Alagoas,Alagôas,Madalena', -9.7102800, -35.8950000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7480, 'Marco', 'Marco', '', -3.1238900, -40.1466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7481, 'Marapanim', 'Marapanim', '', -0.7175000, -47.6997200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7482, 'Maraial', 'Maraial', 'Marayal', -8.7825000, -35.8088900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7483, 'Maragogi', 'Maragogi', 'Gamela,Maragogi,Maragogy', -9.0122200, -35.2225000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7484, 'Maracanaú', 'Maracanau', '', -3.8766700, -38.6255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7485, 'Maracanã', 'Maracana', 'Cintra,Maracana,Maracanã', -0.7661400, -47.4537100, 'BR', '2013-04-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7486, 'Maracaçumé', 'Maracacume', 'Maracassume,Maracassumé,Maragassume', -2.0427800, -45.9591700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7487, 'Marabá', 'Maraba', 'MAB,Maraba,Marabá,ma la ba,malaba,maraba,Мараба,مارابا,মারাবা,马拉巴,마라바', -5.3814600, -49.1323200, 'BR', '2015-11-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7488, 'Manaíra', 'Manaira', 'Alagoa Nova,Alagôa Nova', -7.7061100, -38.1544400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7489, 'Mamanguape', 'Mamanguape', '', -6.8386100, -35.1261100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7490, 'Major Isidoro', 'Major Isidoro', 'Major Izidoro,Sertaosinho,Sertaozinho,Sertãosinho,Sertãozinho', -9.5322200, -36.9850000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7491, 'Maceió', 'Maceio', 'MCZ,Macayo,Maceio,Maceió,Masejas,Masejo,Maseyo,Maçayó,ma sai yue,ma se xo,masayw,mase''i''o,maseio,masyyw,msyyʼw,Масейо,Масејо,מסייאו,ماسئیو,ماسايو,মাসেইও,มาเซโอ,მასეიო,マセイオ,马塞约,마세이오', -9.6658300, -35.7352800, 'BR', '2010-01-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7492, 'Macau', 'Macau', 'Macao,Macáo,Makau,ma kao,makaw,Макау,ماکاو,مکاؤ، ریو گرانڈی ڈو نورٹی,馬考', -5.1150000, -36.6344400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7493, 'Macaparana', 'Macaparana', 'Macapa,Macapá', -7.5547200, -35.4530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7494, 'Macapá', 'Macapa', 'MCP,Macapa,Macapá,Makapa,ma ka pa,makaba,makapa,Макапа,מקאפה,ماكابا,ماکاپا,मकापा,মাকাপা,มากาปา,მაკაპა,マカパ,馬卡帕,마카파', 0.0388900, -51.0663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7495, 'Macaíba', 'Macaiba', 'Macahyba', -5.8583300, -35.3538900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7496, 'Luzilândia', 'Luzilandia', 'Joaquim Tavora,Joaquim Távora,Porto Alegre,Pôrto Alegre', -3.4577800, -42.3702800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7497, 'Luís Correia', 'Luis Correia', 'Amarracao,Amarração,Luis Correia,Luís Correia', -2.8791700, -41.6669400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7498, 'Limoeiro do Norte', 'Limoeiro do Norte', 'Limoeiro', -5.1455600, -38.0980600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7499, 'Limoeiro do Ajuru', 'Limoeiro do Ajuru', 'Limoeiro', -1.8952800, -49.3805600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7500, 'Limoeiro de Anadia', 'Limoeiro de Anadia', 'Limoeira,Limoeiro', -9.7405600, -36.5027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7501, 'Limoeiro', 'Limoeiro', '', -7.8747200, -35.4502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7502, 'Lavras da Mangabeira', 'Lavras da Mangabeira', 'Lavras', -6.7533300, -38.9644400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7503, 'Lajedo', 'Lajedo', 'Lagedo,Lazhedu,Лажеду', -8.6636100, -36.3200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7504, 'Lago da Pedra', 'Lago da Pedra', 'Lago da Pedra,Lago-da-Pedra,Lagoa da Pedra,Lagoa de Pedra,Лаго-да-Педра', -4.2867400, -45.2382400, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7505, 'Lagoa Seca', 'Lagoa Seca', 'Ipaarana,Ipauarana,Ipuarana', -7.1708300, -35.8536100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7506, 'Lagoa Nova', 'Lagoa Nova', '', -6.1000000, -36.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7507, 'Lagoa do Itaenga', 'Lagoa do Itaenga', '', -7.9361100, -35.2902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7508, 'Lagoa da Canoa', 'Lagoa da Canoa', 'Lagoa de Canoa,Lagôa de Canôa', -9.8297200, -36.7377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7509, 'Juruti', 'Juruti', 'Jurity Novo,Juruty Novo,Zhuruti,juruti,ru lu di,Журути,জুরুটি,茹魯蒂', -2.1522200, -56.0922200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7510, 'Juru', 'Juru', 'Barra,Ibiapina', -7.5369400, -37.8186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7511, 'Juripiranga', 'Juripiranga', 'Jupiranga,Serrinha', -7.3733300, -35.2380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7512, 'Junqueiro', 'Junqueiro', '', -9.9252800, -36.4758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7513, 'Jundiá', 'Jundia', '', -8.9347200, -35.5736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7514, 'Jucurutu', 'Jucurutu', 'Sao Miguel,Sao Miguel de Jucurutu,São Miguel,São Miguel de Jucurutú', -6.0338900, -37.0202800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7515, 'Jucás', 'Jucas', 'Sao Mateus,Sao Matheus,São Mateus,São Matheus', -6.5252800, -39.5275000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7516, 'Juazeiro do Norte', 'Juazeiro do Norte', 'JDO,Jaozeiro,Joazeiro,Juazeiro,Juazeiro do Norte,Zhuazeiro do Norte,Zhuazejru-du-Norti,Zuazeiro do Norte,bei ru a ze lu,juraajaye''iro do norte,Žuazeiro do Nortė,Жуазеиро до Норте,Жуазейру-ду-Норти,জুৱাজয়েইরো ডো নোর্টে,ჟუაზეირუ-დუ-ნორტი,北茹阿澤魯', -7.2130600, -39.3152800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7517, 'Juàzeirinho', 'Juazeirinho', '', -6.8166700, -38.0500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7518, 'José de Freitas', 'Jose de Freitas', 'Livramento', -4.7563900, -42.5755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7519, 'Joaquim Nabuco', 'Joaquim Nabuco', '', -8.6244400, -35.5333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7520, 'João Pessoa', 'Joao Pessoa', 'Cidade Felipea,Cidade Felipéa,Fredericia,Frederícia,Gorad Zhuan-Pesoa,JPA,Joan-Pesoo,Joao Pessoa,João Pessoa,Parahiba,Parahyba,Paraiba,Paraíba,Zhoao Pesoa,Zhuan-Pesoa,Zhuan-Pessoa,Zoan Pesoa,Zoao Pesoa,co xea pes so xa,ho''ava peso''a,joanpesoa,joya''o pesasoya,juangpesoa,jwaw byswa,jwaw pyswa,ruo ang pei suo a,zhwaw pswa  parayyba,zwʼʼw pswʼh,Ĵoan-Pesoo,Žoan Pesoa,Ζοάο Πεσόα,Горад Жуан-Песоа,Жоао Песоа,Жуан-Песоа,Жуан-Пессоа,ז''ואאו פזואה,זואאו פסואה,جوآو پیسوآ,جواو بيسوا,جواو پیسوا,ژواو پسوا، پارائیبا,होआव पेसोआ,জোয়াও পেসসোয়া,โจเอาเปสโซอา,ჟუან-პესოა,ジョアンペソア,若昂佩索阿,주앙페소아', -7.1150000, -34.8630600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7521, 'João Câmara', 'Joao Camara', 'Baixa Verde', -5.5375000, -35.8197200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7522, 'João Alfredo', 'Joao Alfredo', '', -7.8558300, -35.5883300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7523, 'Girau do Ponciano', 'Girau do Ponciano', 'Belo Horizonte,Giral do Ponceano,Girau do Ponciano,Ponciano', -9.8841700, -36.8288900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7524, 'Jardim do Seridó', 'Jardim do Serido', '', -6.5844400, -36.7744400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7525, 'Jardim de Piranhas', 'Jardim de Piranhas', 'Jardim de Pirahanas', -6.3786100, -37.3519400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7526, 'Jardim', 'Jardim', '', -3.4644400, -39.0566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7527, 'Jaicós', 'Jaicos', '', -7.3591700, -41.1377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7528, 'Jaguaruana', 'Jaguaruana', 'Uniao,União', -4.8338900, -37.7811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7529, 'Jaguaribe', 'Jaguaribe', 'Jaguaribe Mirim,Zhaguaribi,Жагуариби', -5.8905600, -38.6219400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7530, 'Jacareacanga', 'Jacareacanga', 'JCR', -6.2222200, -57.7527800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7531, 'Jacaraú', 'Jacarau', '', -6.6122200, -35.2927800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7532, 'Jaboatão', 'Jaboatao', '', -8.1802800, -35.0013900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7533, 'Itupiranga', 'Itupiranga', '', -5.1347200, -49.3266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7534, 'Itaueira', 'Itaueira', 'Peri-Peri,Piriperi', -7.6033300, -43.0255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7535, 'Itatuba', 'Itatuba', '', -7.3750000, -35.6283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7536, 'Itaquitinga', 'Itaquitinga', 'Areias', -7.6677800, -35.1016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7537, 'Itacoatiara', 'Itacoatiara', 'ITA,Itacoatiara,Serpa', -3.1430600, -58.4441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7538, 'Itaporanga', 'Itaporanga', 'Misericordia,Misericórdia', -7.3044400, -38.1502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7539, 'Itapissuma', 'Itapissuma', 'Itapicuma,Itapiçuma', -7.7763900, -34.8922200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7540, 'Itapipoca', 'Itapipoca', 'Imperatriz,Itapipoka,Итапипока', -3.4944400, -39.5786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7541, 'Itapecuru Mirim', 'Itapecuru Mirim', 'Itapicuru,Itapicuru-Mirim,Itapicurú-Mirim', -3.3925000, -44.3586100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7542, 'Itapagé', 'Itapage', 'Constituinte,Itapage,Itapagé,Santa Cruz do Uruburetama,Sao Francisco,Sao Francisco do Uruburetama,São Francisco,São Francisco do Uruburetama', -3.6866700, -39.5861100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7543, 'Itamaracá', 'Itamaraca', 'Baixa Verde,Pilar', -7.7477800, -34.8255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7544, 'Itaituba', 'Itaituba', 'ITB,Itaituba', -4.2761100, -55.9836100, 'BR', '2013-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7545, 'Itaitinga', 'Itaitinga', '', -3.9694400, -38.5280600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7546, 'Itainópolis', 'Itainopolis', 'Jenipapo', -7.4469400, -41.4783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7547, 'Itaíba', 'Itaiba', 'Pao Ferro,Pau Ferro,Páo Ferro', -8.9475000, -37.4227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7548, 'Itabaiana', 'Itabaiana', 'Itabayanna,Itambe,Tabaiana', -7.3286100, -35.3325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7549, 'Irituia', 'Irituia', '', -1.7711100, -47.4380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7550, 'Irauçuba', 'Iraucuba', '', -3.7461100, -39.7833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7551, 'Ipueiras', 'Ipueiras', '', -7.0333300, -40.4500000, 'BR', '2006-01-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7552, 'Ipubi', 'Ipubi', 'Poco-Verde,Poço-Verde', -7.6519400, -40.1488900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7553, 'Ipu', 'Ipu', '', -4.3222200, -40.7108300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7554, 'Ipojuca', 'Ipojuca', 'Ipozhuka,Pojuca,Ипожука', -8.3988900, -35.0638900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7555, 'Ipanguaçu', 'Ipanguacu', 'Ipauguacu,Ipauguaçu,Sacramento', -5.4983300, -36.8550000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7556, 'Inhuma', 'Inhuma', 'Inhumas', -6.6683300, -41.7077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7557, 'Inhapi', 'Inhapi', '', -9.2213900, -37.7486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7558, 'Ingá', 'Inga', '', -7.2808300, -35.6044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7559, 'Independência', 'Independencia', '', -5.3963900, -40.3086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7560, 'Imperatriz', 'Imperatriz', 'IMP,Imperatris,Imperatrisas,Imperatriz,Vila Nova de Imperatriz,imaperatrija,yin pei la te li si,Императриз,Императрис,ইমপেরাট্রিজ,იმპერატრისი,因佩拉特里斯', -5.5263900, -47.4916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7561, 'Imaculada', 'Imaculada', 'Immaculada', -7.3897200, -37.5091700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7562, 'Iguatu', 'Iguatu', 'QIG,Telha', -6.3594400, -39.2986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7563, 'Igarapé Miri', 'Igarape Miri', 'Igarape Miry,Igarape-Mirim,Igarapé Miry,Igarapé-Mirim', -1.9750000, -48.9597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7564, 'Igarapé Açu', 'Igarape Acu', 'Igarape-Assu,Igarapé-Assú,Joao Pessoa,João Pessoa', -1.1288900, -47.6200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7565, 'Igarassu', 'Igarassu', 'Igaracu,Igarasu,Igaraçu,Iguaracu,Iguarassu,Iguarassú,Iguaraçu,igarasasu,yi jia la su,Игарасу,ইগারাসসু,伊加拉苏', -7.8341700, -34.9063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7566, 'Igaci', 'Igaci', 'Olhos Dagua do Acioli,Olhos Dágua do Acioli', -9.5369400, -36.6336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7567, 'Icó', 'Ico', '', -6.4011100, -38.8622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7568, 'Icatu', 'Icatu', '', -2.7758300, -44.0658300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7569, 'Ibimirim', 'Ibimirim', 'Mirim', -8.5405600, -37.6902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7570, 'Ibiapina', 'Ibiapina', '', -3.9233300, -40.8894400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7571, 'Ibateguara', 'Ibateguara', 'Ibatequara,Piquete', -8.9725000, -35.9394400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7572, 'Humberto de Campos', 'Humberto de Campos', 'Miritiba,Miritiba de Sao Jose de Piria,Miritiba de São José de Piriá', -2.5983300, -43.4611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7573, 'Horizonte', 'Horizonte', '', -4.1000000, -38.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7574, 'Hidrolândia', 'Hidrolandia', '', -4.4080600, -40.4377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7575, 'Gurupá', 'Gurupa', 'Santo Antonio De Gurupa', -1.4050000, -51.6400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7576, 'Gurinhém', 'Gurinhem', 'Curinhaem,Curinhãem', -7.1238900, -35.4244400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7577, 'Guaraciaba do Norte', 'Guaraciaba do Norte', 'Campo Grande,Inhucu,Inhussu,Inhuçu', -4.1669400, -40.7475000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7578, 'Guarabira', 'Guarabira', 'Guarabira,gua la bi la,guraarabira,Гуарабира,গুৱারাবিরা,瓜拉比拉', -6.8547200, -35.4900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7579, 'Guajará', 'Guajara', '', -2.9666700, -57.6666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7580, 'Guaiúba', 'Guaiuba', 'Guayuba', -4.0397200, -38.6372200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7581, 'Guabiraba', 'Guabiraba', 'Barra,Barra de Sao Joao,Barra de São João,Guabiraba,Itapeco,Itapecô', -8.4166700, -35.6666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7582, 'Gravatá', 'Gravata', 'Gravata,Gravatá', -8.2011100, -35.5647200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7583, 'Granja', 'Granja', '', -3.1202800, -40.8261100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7584, 'Grajaú', 'Grajau', 'Grajahu,Grajahú,Gralau', -5.8194400, -46.1386100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7585, 'Governador Dix Sept Rosado', 'Governador Dix Sept Rosado', 'Sao Sebastiao,Sebastianopolis,Sebastianópolis,São Sebastião', -5.4588900, -37.5208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7586, 'Goianinha', 'Goianinha', 'Goyanninha', -6.2647200, -35.2125000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7587, 'Goiana', 'Goiana', 'Gojana,Goyanna,ge ya na,go''iyana,Гояна,গোইয়ানা,戈亚纳', -7.5605600, -35.0025000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7588, 'Glória do Goitá', 'Gloria do Goita', 'Gloria de Goyta,Gloria de Goytá', -8.0016700, -35.2927800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7589, 'Gilbués', 'Gilbues', 'Gilboes,Gilboés', -9.8316700, -45.3438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7590, 'Gararu', 'Gararu', 'Curral das Pedras', -9.9675000, -37.0833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7591, 'Garanhuns', 'Garanhuns', 'Garan''juns,QGP,Гараньюнс', -8.8820200, -36.5021600, 'BR', '2016-06-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7592, 'Gameleira', 'Gameleira', 'Camelleira,Gamelleira', -8.5844400, -35.3866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7593, 'Fortuna', 'Fortuna', '', -5.7333300, -44.1583300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7594, 'Fortaleza', 'Fortaleza', 'Ceara,Ceará,FOR,Fortalaetia,Fortaleza,Fortaleza Nova de Braganca,Fortaleza Nova de Bragança,Fortaleza de Nova Braganca,Fortaleza de Nova Bragança,Fortalezae,Fortalezo,Gorad Fartaleza,f xr tale sa,forutareza,fu ta lei sa,fwrtalyza,fwrtalza,phartalija,phortaleja,phortalejha,poleutalleja,pwrtlzh,Φορταλέζα,Горад Фарталеза,Форталезæ,Форталеза,פורטלזה,فورتالزا,فورتاليزا,फोर्तालेझा,ফর্তালিজা,ফোর্টালেজা,ฟอร์ตาเลซา,ფორტალეზა,フォルタレザ,福塔雷萨,福塔雷薩,포르탈레자', -3.7172200, -38.5430600, 'BR', '2014-07-16', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7595, 'Forquilha', 'Forquilha', '', -3.7983300, -40.2605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7596, 'Floriano', 'Floriano', 'Colonia,Colônia,FLB,Florian,Florianu,Manga,fu luo li ya nu,phloriyano,Флориан,Флориану,ফ্লোরিয়ানো,弗洛里亚努', -6.7669400, -43.0225000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7597, 'Floresta', 'Floresta', 'Floresta,fu luo lei si ta,Флореста,弗洛雷斯塔', -8.6011100, -38.5686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7598, 'Flores', 'Flores', 'Flores da Ribeira de Pajeu,Flôres da Ribeira de Pajeú', -7.8680600, -37.9747200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7599, 'Flexeiras', 'Flexeiras', 'Flexeiras,Frecheiras', -9.1975000, -35.7808300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7600, 'Feira Nova', 'Feira Nova', 'Jardim', -7.9508300, -35.3891700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7601, 'Farias Brito', 'Farias Brito', 'Quixara,Quixará', -6.9305600, -39.5655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7602, 'Fagundes', 'Fagundes', '', -7.3550000, -35.7750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7603, 'Exu', 'Exu', 'Novo Exu', -7.5119400, -39.7241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7604, 'Eusébio', 'Eusebio', 'Ehusebio,Euziebio,Эусебио', -3.8900000, -38.4505600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7605, 'Extremoz', 'Extremoz', 'Ehstremos,Extremos,Extremoz,Extremós,Extremóz,ai si te lei mu si,eksatremoja,Эстремос,এক্সট্রেমোজ,埃斯特雷穆斯', -5.7055600, -35.3072200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7606, 'Estreito', 'Estreito', '', -5.7833300, -43.2500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7607, 'Esperantinópolis', 'Esperantinopolis', 'Boa Esperanca do Mearim,Boa Esperança do Mearim', -4.8666700, -44.7083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7608, 'Esperantina', 'Esperantina', 'Boa Esperanca,Boa Esperança,Retiro da Boa Esperanca,Retiro da Boa Esperança', -3.9016700, -42.2336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7609, 'Esperança', 'Esperanca', '', -7.0330600, -35.8572200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7610, 'Escada', 'Escada', '', -8.3591700, -35.2236100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7611, 'Elesbão Veloso', 'Elesbao Veloso', 'Elesboa Veloso', -6.2019400, -42.1402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7612, 'Dona Inês', 'Dona Ines', 'Dona Ines,Dona Inês', -6.6135400, -35.6265400, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7613, 'Dom Pedro', 'Dom Pedro', 'Dom Pedro', -5.0374900, -44.4385700, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7614, 'Dois Riachos', 'Dois Riachos', '', -9.3925000, -37.1005600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7615, 'Desterro', 'Desterro', '', -7.2905600, -37.0938900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7616, 'Demerval Lobão', 'Demerval Lobao', 'Dermeval Lobao,Dermeval Lobão,Lobao,Lobão,Morrinho,Morrinhos', -5.3583300, -42.6763900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7617, 'Delmiro Gouveia', 'Delmiro Gouveia', 'Delmiro,Pedra', -9.3886100, -37.9991700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7618, 'Custódia', 'Custodia', '', -8.0875000, -37.6430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7619, 'Cururupu', 'Cururupu', 'CPU', -1.8283300, -44.8683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7620, 'Curuçá', 'Curuca', '', -0.7288900, -47.8480600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7621, 'Currais Novos', 'Currais Novos', 'Curraes Novos,Kurrajs-Novus,QCP,kurra''isa nobhosa,xin ku lai si,Куррайс-Новус,কুর্রাইস নোভোস,新库赖斯', -6.2608300, -36.5177800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7622, 'Curaçá', 'Curaca', '', -8.9902800, -39.9094400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7623, 'Cupira', 'Cupira', 'Cupyra', -8.6166700, -35.9500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7624, 'Cumaru', 'Cumaru', 'Malhada,Malhadinha', -8.0061100, -35.6972200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7625, 'Cuité', 'Cuite', 'Serra do Cuite,Serra do Cuité', -6.4836100, -36.1536100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7626, 'Cruz do Espírito Santo', 'Cruz do Espirito Santo', 'Espirito Santo,Maguari', -7.1400000, -35.0863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7627, 'Cruz', 'Cruz', 'Cruz,JJD', -2.9211000, -40.1758900, 'BR', '2017-03-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7628, 'Crato', 'Crato', 'Crato,Kratu,Vila Real do Crato,ke la tu,Крату,კრატუ,克拉图', -7.2341700, -39.4094400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7629, 'Crateús', 'Crateus', 'Cratheus,Cratheús,Piranhas,Principe Imperial,Príncipe Imperial', -5.1783300, -40.6775000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7630, 'Coroatá', 'Coroata', 'Croata,Croatá', -4.1300000, -44.1241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7631, 'Coremas', 'Coremas', 'Curema,Santa Rita da Curema', -7.0144400, -37.9458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7632, 'Coreaú', 'Coreau', 'Palma', -3.5333300, -40.6566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7633, 'Condado', 'Condado', 'Goianinha,Goyanninha', -7.5858300, -35.1058300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7634, 'Conceição do Araguaia', 'Conceicao do Araguaia', 'CDJ,Conceicao do Araguaia,Conceição do Araguaia', -8.2644100, -49.2698200, 'BR', '2015-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7635, 'Colônia Leopoldina', 'Colonia Leopoldina', 'Leopoldina', -8.9088900, -35.7250000, 'BR', '2006-12-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7636, 'Colinas', 'Colinas', 'Kolinas,Picos,Колинас', -6.0258300, -44.2491700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7637, 'Coité do Nóia', 'Coite do Noia', 'Coite do Noa,Coite do Nois,Coité do Noá', -9.6322200, -36.5786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7638, 'Coelho Neto', 'Coelho Neto', 'Curralinho,Curralzinho', -4.2566700, -43.0127800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7639, 'Codó', 'Codo', 'Codo,Codó,Urubu', -4.4552800, -43.8855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7640, 'Cocal', 'Cocal', '', -3.4719400, -41.5575000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7641, 'Chorozinho', 'Chorozinho', '', -4.3002800, -38.4977800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7642, 'Chapadinha', 'Chapadinha', '', -3.7416700, -43.3602800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7643, 'Chã Grande', 'Cha Grande', '', -8.2383300, -35.4616700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7644, 'Cerro Corá', 'Cerro Cora', '', -6.0455600, -36.3458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7645, 'Cedro', 'Cedro', '', -6.6066700, -39.0622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7646, 'Ceará Mirim', 'Ceara Mirim', '', -5.6344400, -35.4255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7647, 'Caxias', 'Caxias', 'Caxias das Aldeias Altas,Kashias,Kasias,Kasijasas,Kašijasas,ka xi ya si,Кашиас,Կաշիաս,კაშიასი,卡希亚斯', -4.8588900, -43.3561100, 'BR', '2013-05-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7648, 'Caucaia', 'Caucaia', 'Soure', -3.7361100, -38.6530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7649, 'Catolé do Rocha', 'Catole do Rocha', 'Catule-do-Rocha,Catulé-do-Rocha', -6.3438900, -37.7466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7650, 'Catende', 'Catende', '', -8.6666700, -35.7166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7651, 'Castelo do Piauí', 'Castelo do Piaui', 'Castello,Castelo,Costello,Marvao,Marvão,Rancho dos Patos,Vila de Castelo', -5.3222200, -41.5525000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7652, 'Castanhal', 'Castanhal', 'Kastan''jal,ka si ta ni ya er,kastanahala,Кастаньял,কাস্টানহাল,卡斯塔尼亞爾', -1.2938900, -47.9263900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7653, 'Cascavel', 'Cascavel', '', -4.1330600, -38.2419400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7654, 'Carutapera', 'Carutapera', 'CTP', -1.1950000, -46.0200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7655, 'Caruaru', 'Caruaru', 'CAU,Caruaru,Karuaru,Каруару', -8.2833300, -35.9761100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7656, 'Carpina', 'Carpina', 'Karpina,Карпина', -7.8508300, -35.2547200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7657, 'Carolina', 'Carolina', 'CLN,Carolina,Karolina,ka luo li na,karolina,Каролина,Կարոլինա,কারোলিনা,კაროლინა,卡罗利纳', -7.3356100, -47.4621800, 'BR', '2014-01-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7658, 'Carnaíba', 'Carnaiba', '', -8.7000000, -37.6666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7659, 'Caririaçu', 'Caririacu', 'Sao Pedro,Sao Pedro do Cariri,São Pedro,São Pedro do Carirí', -7.0422200, -39.2836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7660, 'Cariré', 'Carire', '', -3.9505600, -40.4733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7661, 'Careiro da Várzea', 'Careiro da Varzea', 'Careiro', -3.1969500, -59.8267400, 'BR', '2014-08-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7662, 'Caraúbas', 'Caraubas', 'Carahubas,Carauba,Caraúba', -5.7925000, -37.5566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7663, 'Capoeiras', 'Capoeiras', 'Capoeira', -8.7347200, -36.6266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7664, 'Capitão Poço', 'Capitao Poco', '', -1.7463900, -47.0594400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7665, 'Capela', 'Capela', 'Conceicao do Paraiba,Conceição do Paraíba,Euclydes Malta,Paraiba,Paraíba', -9.4075000, -36.0736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7666, 'Capanema', 'Capanema', '', -1.1958300, -47.1808300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7667, 'Canto do Buriti', 'Canto do Buriti', '', -8.1100000, -42.9444400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7668, 'Cantanhede', 'Cantanhede', '', -3.6333300, -44.3766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7669, 'Canindé de São Francisco', 'Caninde de Sao Francisco', 'Caninde,Canindé,Curituba', -9.6600000, -37.7894400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7670, 'Canindé', 'Caninde', 'Caninae,Kaninde,ka ning de,kaninade,Канинде,কানিনডে,კანინდე,卡宁德', -4.3588900, -39.3116700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7671, 'Canhotinho', 'Canhotinho', '', -8.8822200, -36.1911100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7672, 'Canguaretama', 'Canguaretama', 'Kanguaretama,kan gua lei ta ma,kanaguraaretama,Кангуаретама,কানগুৱারেটামা,坎瓜雷塔马', -6.3800000, -35.1288900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7673, 'Cândido Mendes', 'Candido Mendes', '', -1.4466700, -45.7166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7674, 'Campos Sales', 'Campos Sales', 'Campos Salles,Nova Roma,Varzea da Vaca,Várzea da Vaca', -7.0744400, -40.3761100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7675, 'Campo Maior', 'Campo Maior', 'Kampu-Major,kampo ma''i''or,kan pu ma yue er,Кампу-Майор,কাম্পো মাইওর্,坎普马约尔', -4.8277800, -42.1686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7676, 'Campo Alegre', 'Campo Alegre', 'Campo Alegre do Mosquito,Mosquito', -9.7819400, -36.3508300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7677, 'Campina Grande', 'Campina Grande', 'CPV,Campina Grande,Kampina Grande,Kampina Grandi,Kampina Grandė,Kampina-Grande,Kampina-Grandi,Kampinagrando,da kan pi na,kamapina grande,kampinageulanji,kanpinagurande,Кампина Гранде,Кампина Гранди,Кампина-Гранде,Кампина-Гранди,কামপিনা গ্রান্ডে,カンピナグランデ,大坎皮納,캄피나그란지', -7.2305600, -35.8811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7678, 'Camocim de São Félix', 'Camocim de Sao Felix', 'Camocim,Camocituba', -8.3586100, -35.7619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7679, 'Camocim', 'Camocim', 'CMC', -2.9022200, -40.8411100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7680, 'Cametá', 'Cameta', 'CMT', -2.2444400, -49.4958300, 'BR', '2017-06-02', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7681, 'Cajueiro', 'Cajueiro', 'Cajueiro,Caldeirao,Caldeirão', -9.7166700, -36.4500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7682, 'Cajazeiras', 'Cajazeiras', 'Kazhazejras,ka ya ze la si,kajajaye''irasa,Кажазейрас,কাজাজয়েইরাস,卡雅泽拉斯', -6.8902800, -38.5552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7683, 'Caicó', 'Caico', 'Kajko,ka''iko,kai ke,Кайко,কাইকো,凯科', -6.4583300, -37.0977800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7684, 'Caetés', 'Caetes', '', -8.7730600, -36.6225000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7685, 'Cacimbinhas', 'Cacimbinhas', 'Cacimbinha', -9.4002800, -36.9902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7686, 'Cacimba de Dentro', 'Cacimba de Dentro', 'Cacimbo de Dentro', -6.6416700, -35.7900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7687, 'Cachoeirinha', 'Cachoeirinha', '', -8.4863900, -36.2330600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7688, 'Cabrobó', 'Cabrobo', '', -8.5141700, -39.3100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7689, 'Cabo', 'Cabo', '', -8.2833300, -35.0333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7690, 'Cabedelo', 'Cabedelo', 'Cabedello,Cabedelos,Kabedelu,ka bei de lu,kabedelo,Кабеделу,Կաբեդելու,কাবেডেলো,卡贝德卢', -6.9811100, -34.8338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7691, 'Caaporã', 'Caapora', 'Boca-da-Mata,Bocca de Matta', -7.5155600, -34.9083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7692, 'Buriti dos Lopes', 'Buriti dos Lopes', 'Baixo Longa,Baixo Longá,Burity dos Lopes', -3.1750000, -41.8669400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7693, 'Buriti Bravo', 'Buriti Bravo', 'Burity Bravo', -5.8372200, -43.8336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7694, 'Bujaru', 'Bujaru', '', -1.5150000, -48.0447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7695, 'Buíque', 'Buique', 'Buiki,Vila Nova de Buique,Vila Nova de Buíque,Буики', -8.6230600, -37.1558300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7696, 'Breves', 'Breves', 'BVS', -1.6822200, -50.4802800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7697, 'Brejo Santo', 'Brejo Santo', 'Brejo dos Santos', -7.4933300, -38.9872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7698, 'Brejo da Madre de Deus', 'Brejo da Madre de Deus', 'Madre de Deus', -8.1458300, -36.3711100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7699, 'Brejo', 'Brejo', '', -3.6844400, -42.7502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7700, 'Brejinho', 'Brejinho', '', -6.1908300, -35.3566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7701, 'Bragança', 'Braganca', '', -1.0536100, -46.7655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7702, 'Borba', 'Borba', 'Borba,RBB,bo er ba,Борба,Բորբա,博爾巴', -4.3914300, -59.5886400, 'BR', '2014-06-29', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7703, 'Boqueirão', 'Boqueirao', 'Boqueirao,Boqueirão', -7.4823700, -36.1342200, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7704, 'Bonito', 'Bonito', '', -8.4702800, -35.7286100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7705, 'Bom Jesus', 'Bom Jesus', 'Bom Jesus do Gurgueia', -9.0744400, -44.3586100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7706, 'Bom Jardim', 'Bom Jardim', '', -7.7958300, -35.5872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7707, 'Bom Jardim', 'Bom Jardim', '', -7.0166700, -46.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7708, 'Bom Conselho', 'Bom Conselho', '', -9.1697200, -36.6797200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7709, 'Boa Viagem', 'Boa Viagem', '', -5.1275000, -39.7322200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7710, 'Bezerros', 'Bezerros', 'Bezerrus,Безеррус', -8.2333300, -35.7969400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7711, 'Bequimão', 'Bequimao', '', -2.4488900, -44.7825000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7712, 'Benevides', 'Benevides', '', -1.3613900, -48.2447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7713, 'Beneditinos', 'Beneditinos', 'Beneditinos', -5.4500000, -42.3666700, 'BR', '2012-08-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7714, 'Belo Jardim', 'Belo Jardim', 'Bello Jardim', -8.3355600, -36.4241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7715, 'Belém do Brejo do Cruz', 'Belem do Brejo do Cruz', '', -6.1886100, -37.5358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7716, 'Belém de São Francisco', 'Belem de Sao Francisco', 'Belem,Belem de Cabroba,Belem do Sao Francisco,Belém,Belém de Cabrobá,Belém do São Francisco,Jatina,Jatinã', -8.7538900, -38.9658300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7717, 'Belém', 'Belem', 'Belem,Belem de Caicara,Belen,Belém de Caiçara,Curimatau,Curimataú,bei lun,Белем,Белен,Բելեն,貝倫', -6.6916700, -35.5333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7718, 'Belém', 'Belem', 'BEL,Belem,Belem do Para,Belem do Pará,Belen,Belena,Belenas,Belém,Belém do Pará,Bethlehem,Para,Pará,Santa Maria de Belem do Grao Para,Santa Maria de Belém do Grão Pará,Vele,Velẽ,bei lun,belem,belema,beleng,beleni,belleng,beren,blm,bylym,Μπελέμ,Белем,Белен,בלם,بلم,بيليم,بیلیم,बेलेम,বেলেঁ,বেলেম,เบเลง,ბელენი,ベレン,贝伦,벨렝', -1.4558300, -48.5044400, 'BR', '2014-05-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7719, 'Bela Cruz', 'Bela Cruz', '', -3.0505600, -40.1677800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7720, 'Beberibe', 'Beberibe', 'Beberibe,Беберибе', -4.1797200, -38.1305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7721, 'Bayeux', 'Bayeux', '', -7.1250000, -34.9322200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7722, 'Baturité', 'Baturite', '', -4.3286100, -38.8847200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7723, 'Batalha', 'Batalha', '', -9.6777800, -37.1247200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7724, 'Batalha', 'Batalha', 'Campos Sales', -4.0250000, -42.0750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7725, 'Barroquinha', 'Barroquinha', '', -3.0188900, -41.1361100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7726, 'Barro', 'Barro', '', -6.7166700, -38.8666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7727, 'Barreiros', 'Barreiros', '', -8.8183300, -35.1863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7728, 'Barreirinhas', 'Barreirinhas', 'BRB', -2.7555600, -42.8259100, 'BR', '2013-04-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7729, 'Barreirinha', 'Barreirinha', '', -2.7933300, -57.0700000, 'BR', '2013-04-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7730, 'Barras', 'Barras', 'Barras,Barras do Maratahoan,Barras do Maratoam,Баррас', -4.2444400, -42.2944400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7731, 'Barra do Corda', 'Barra do Corda', 'BDC', -5.5055600, -45.2433300, 'BR', '2017-06-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7732, 'Barra de Santo Antônio', 'Barra de Santo Antonio', 'Barra de Santo Antonio Grande,Barra de Santo Antônio Grande,Coqueiral Cupe,Cupe,Cupê', -9.4047200, -35.5072200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7733, 'Barcarena', 'Barcarena', '', -1.5058300, -48.6258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7734, 'Barbalha', 'Barbalha', '', -7.3111100, -39.3041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7735, 'Baraúna', 'Barauna', 'Currais Barauna,Currais Baraúna', -5.0800000, -37.6166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7736, 'Bananeiras', 'Bananeiras', '', -6.7500000, -35.6333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7737, 'Balsas', 'Balsas', 'BSS,Bal''sas,Sant'' Antonio de Balsas,Santo Antonio de Balsas,Бальсас', -7.5325000, -46.0355600, 'BR', '2015-10-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7738, 'Baião', 'Baiao', '', -2.7905600, -49.6716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7739, 'Bacabal', 'Bacabal', 'Bacabal,Bakabal,Бакабал', -4.2916700, -44.7916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7740, 'Autazes', 'Autazes', 'Ambrosio Aires,Ambrósio Aires,Sao Longuilho', -3.5797200, -59.1305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7741, 'Aurora', 'Aurora', '', -6.9425000, -38.9675000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7742, 'Augusto Corrêa', 'Augusto Correa', '', -1.0216700, -46.6350000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7743, 'Atalaia', 'Atalaia', '', -9.5019400, -36.0227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7744, 'Assaré', 'Assare', 'Acare,Açaré', -6.8744400, -39.8750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7745, 'Aroeiras', 'Aroeiras', '', -7.5452800, -35.7075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7746, 'Arês', 'Ares', 'Arez', -6.1944400, -35.1602800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7747, 'Areia Branca', 'Areia Branca', '', -4.9561100, -37.1369400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7748, 'Areia', 'Areia', '', -6.9633300, -35.6916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7749, 'Arcoverde', 'Arcoverde', 'Arkoverdi,Rio Branco,Арковерди', -8.4188900, -37.0538900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7750, 'Araruna', 'Araruna', '', -6.5583300, -35.7416700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7751, 'Araripina', 'Araripina', 'Araripina,Sao Goncalo,São Gonçalo,Арарипина', -7.5761100, -40.4983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7752, 'Araripe', 'Araripe', 'Brejo Secco,Brejo Seco,Brejo Sêco', -7.2125000, -40.0461100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7753, 'Arari', 'Arari', 'Arary', -3.4536100, -44.7800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7754, 'Arara', 'Arara', 'Arara,Arara vald,a la la,alala,arara,raarara,xa ra ra,Αραρά,Арара,Արարա,ארארה,آرارا,أرارا,ৱারারা,அராரா,อารารา,არარა,アララ,阿拉拉,아라라', -6.8283300, -35.7583300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7755, 'Arapiraca', 'Arapiraca', 'APQ', -9.7525000, -36.6611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7756, 'Araioses', 'Araioses', 'Arayoses,Arayozes,Enjeitado,Sao Bernardo,Sao Bernardo do Parnaiba,São Bernardo,São Bernardo do Parnaíba', -2.8900000, -41.9030600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7757, 'Araguaína', 'Araguaina', 'AUX,Araguaina,Araguaína,Lontra,a la gua yi na,Арагуаина,阿拉瓜伊纳', -7.1911100, -48.2072200, 'BR', '2014-01-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7758, 'Araçoiaba', 'Aracoiaba', 'Arassoiaba,Cha do Estevam,Cha do Estevao,Châ do Estevam,Chã do Estêvão', -7.7902800, -35.0908300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7759, 'Aracoiaba', 'Aracoiaba', 'Aracoyaba', -4.3711100, -38.8141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7760, 'Aracati', 'Aracati', 'Aracaty,Arakati,a la ka di,raarakati,Аракати,ৱারাকাটি,არაკატი,阿拉卡蒂', -4.5616700, -37.7697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7761, 'Aquiraz', 'Aquiraz', '', -3.9013900, -38.3911100, 'BR', '2016-11-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7762, 'Apodi', 'Apodi', 'Apodi,Apody,a bo di,apodi,apwdy,Аподи,آپودی,আপোডি,阿波迪', -5.6641700, -37.7988900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7763, 'Angicos', 'Angicos', '', -5.6655600, -36.6011100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7764, 'Ananindeua', 'Ananindeua', 'Ananindeua,a na ning de wa,ananinde-ua,ananinderaa,ananindeua,Ананиндеуа,Ананіндеуа,Անանինդեուա,אננינדאואה,انانین‌دوا، پارا,আনানিন্ডেৱা,アナニンデウア,阿納寧德瓦,아나닌데우아', -1.3655600, -48.3722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7765, 'Anajatuba', 'Anajatuba', '', -3.2644400, -44.6197200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7766, 'Anadia', 'Anadia', '', -9.6844400, -36.3041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7767, 'Amontada', 'Amontada', 'Sao Bento,Sao Bento d''Amontada,Sao Bento da Amontada,São Bento,São Bento d''Amontada,São Bento da Amontada', -3.3616700, -39.8316700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7768, 'Amarante do Maranhão', 'Amarante do Maranhao', 'Amarante do Grajau', -5.5666700, -46.7422200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7769, 'Amarante', 'Amarante', 'Sao Goncalo,São Gonçalo', -6.2431600, -42.8454400, 'BR', '2014-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7770, 'Amaraji', 'Amaraji', 'Amaragi,Amaragy', -8.3830600, -35.4525000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7771, 'Altos', 'Altos', '', -5.0380600, -42.4600000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7772, 'Alto Longá', 'Alto Longa', 'Humildes', -5.2511100, -42.2102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7773, 'Altinho', 'Altinho', '', -8.4897200, -36.0594400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7774, 'Altamira', 'Altamira', 'ATM,Al''tamira,Altamira,Altamira vald,a er ta mi la,altamira,altmyra  para,Алтамира,Альтамира,Ալտամիրա,التمیرا، پارا,আল্টামিরা,阿爾塔米拉', -3.2033300, -52.2063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7775, 'Almeirim', 'Almeirim', 'Almejrin,Almerim,Алмейрин', -1.5233300, -52.5816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7776, 'Alhandra', 'Alhandra', '', -7.4386100, -34.9144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7777, 'Alexandria', 'Alexandria', 'Aleshandrija,alksandrya  ryw grnd dw nwrt,ya li shan da,Алешандрия,الکساندریا، ریو گرند دو نورت,亚历山大', -6.4125000, -38.0158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7778, 'Alenquer', 'Alenquer', 'ALT,Alemquer', -1.9416700, -54.7383300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7779, 'Alcântara', 'Alcantara', 'Alcantara,Alcântara,QAH', -2.4041000, -44.4166900, 'BR', '2013-04-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7780, 'Alagoinha', 'Alagoinha', 'Tauatuba', -6.9500000, -35.5450000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7781, 'Alagoa Nova', 'Alagoa Nova', 'Larangeiras,Laranjeiras', -7.0708300, -35.7583300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7782, 'Alagoa Grande', 'Alagoa Grande', '', -7.1583300, -35.6300000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7783, 'Águas Belas', 'Aguas Belas', 'Aguas Bellas', -9.1113900, -37.1230600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7784, 'Água Preta', 'Agua Preta', '', -8.7075000, -35.5305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7785, 'Água Branca', 'Agua Branca', '', -9.2608300, -37.9361100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7786, 'Água Branca', 'Agua Branca', '', -5.8922200, -42.6361100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7787, 'Agrestina', 'Agrestina', 'Bebedouro', -8.4580600, -35.9447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7788, 'Afuá', 'Afua', 'Affua', -0.1566700, -50.3866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7789, 'Afonso Bezerra', 'Afonso Bezerra', 'Alfonso Bezerra', -5.4983300, -36.5055600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7790, 'Afogados da Ingazeira', 'Afogados da Ingazeira', 'Afogados,Passagem dos Afogados', -7.7508300, -37.6391700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7791, 'Açu', 'Acu', 'Assu', -5.5766700, -36.9086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7792, 'Acopiara', 'Acopiara', 'Affonso Penna,Afonso-Pena,Lages,Lajes', -6.0952800, -39.4525000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7793, 'Acaraú', 'Acarau', 'Acarahu,Acarahú,Akarau,Акарау', -2.8855600, -40.1200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7794, 'Acará', 'Acara', '', -1.9608300, -48.1966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7795, 'Abreu e Lima', 'Abreu e Lima', 'Abreu e Lima,Abreu-i-Lima,Maricota,a bu lei wu ai li ma,abre''u e lima,abrw a lyma  prnambwka,Абреу-и-Лима,Абреу-і-Ліма,ابرو ا لیما، پرنامبوکا,আব্রেউ এ লিমা,阿布雷乌埃利马', -7.9116700, -34.9027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7796, 'Abaetetuba', 'Abaetetuba', 'Abaete,Abaetetuba,Abaeté', -1.7180600, -48.8825000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7797, 'Xique Xique', 'Xique Xique', 'Chique-Chique', -10.8229400, -42.7281500, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7798, 'Chavantes', 'Chavantes', 'Chavantes', -23.0388900, -49.7094400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7799, 'Xanxerê', 'Xanxere', 'AXE,Ruy Barbosa,Xanere,Xaneré', -26.8769400, -52.4041700, 'BR', '2017-07-06', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7800, 'Votuporanga', 'Votuporanga', 'VOT', -20.4227800, -49.9727800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7801, 'Votorantim', 'Votorantim', 'Voturantim', -23.5466700, -47.4377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7802, 'Volta Redonda', 'Volta Redonda', 'Gorad Volta-Rehdonda,V Redonda,Volta Redonda,Volta-Redonda,bholata redonda,wo er ta lei dong da,Волта Редонда,Волта-Редонда,Горад Волта-Рэдонда,ভোলটা রেডোন্ডা,沃尔塔雷东达', -22.5230600, -44.1041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7803, 'Vitória da Conquista', 'Vitoria da Conquista', 'Conquista,VDC,Vitoria da Conquista,Vitorija da Konkista,Vitorija-da-Konkista,Vitória da Conquista,bhitoriya da konaku''ista,wei duo li ya-da kong ji si ta,Витория-да-Конкиста,Виторија да Конкиста,ভিটোরিয়া ডা কোনকুইস্টা,ვიტორია-და-კონკისტა,ヴィトリア・ダ・コンキスタ,维多利亚-达孔基斯塔', -14.8661100, -40.8394400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7804, 'Vitória', 'Vitoria', 'VIX,Victoria,Vitoria,Vitorija,Vitória,bitoria,wytwryh,Витория,ויטוריה,ビトリア', -20.3194400, -40.3377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7805, 'Visconde do Rio Branco', 'Visconde do Rio Branco', 'Rio Branco', -21.0102800, -42.8405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7806, 'Viradouro', 'Viradouro', 'Viradoura', -20.8730600, -48.2969400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7807, 'Vinhedo', 'Vinhedo', 'Rocinha', -23.0297200, -46.9752800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7808, 'Vila Velha', 'Vila Velha', 'Vila Vela,Vila Velha,Vila Velja,Vila-Vel''ja,bhila bhelaha,billabellya,wei li ya zhen,wylh wlyh,Вила Веля,Вила Веља,Вила-Велья,וילה וליה,ভিলা ভেলহা,ヴィラ・ヴェーリャ,韦利亚镇,빌라벨랴', -20.3297200, -40.2925000, 'BR', '2014-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7809, 'Videira', 'Videira', 'Perdizes,VIA,Videjra,Видейра', -27.0083300, -51.1516700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7810, 'Viçosa', 'Vicosa', 'Visoza,bisoja,vu~isoza,wei suo sa,Висоза,Вісоза,Վիսոզա,ヴィソーザ,維索薩,비소자', -20.7538900, -42.8819400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7811, 'Vianópolis', 'Vianopolis', 'Viannopolis', -16.7419400, -48.5163900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7812, 'Viana', 'Viana', 'Jabaete,Jabaeté,Viana,Vianna,Виана', -20.3902800, -40.4961100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7813, 'Viamão', 'Viamao', 'Viaman,Viamao,Viamão,Vijamao,bhi''ama''o,wei ya mang,Виаман,Вијамао,ভিআমাও,维亚芒', -30.0811100, -51.0233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7814, 'Vespasiano', 'Vespasiano', '', -19.6919400, -43.9233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7815, 'Veranópolis', 'Veranopolis', 'Alfredo Chaves', -28.9361100, -51.5494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7816, 'Vera Cruz', 'Vera Cruz', '', -12.6333300, -41.0333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7817, 'Wenceslau Braz', 'Wenceslau Braz', 'Venceslau Braz,Vencesleu-Bras,Vencesleu-Brás,Wenceslau Braz', -23.8738900, -49.8027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7818, 'Venâncio Aires', 'Venancio Aires', 'Venancia Ayres,Venancio Ayres', -29.6063900, -52.1919400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7819, 'Vazante', 'Vazante', '', -17.9869400, -46.9077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7820, 'Vassouras', 'Vassouras', 'Vasoras,bhasasaurasa,wa suo la si,Васорас,ভাসসৌরাস,瓦索拉斯', -22.4038900, -43.6625000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7821, 'Varzelândia', 'Varzelandia', '', -15.7013900, -44.0275000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7822, 'Várzea Paulista', 'Varzea Paulista', 'Secundino Veiga', -23.2113900, -46.8283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7823, 'Várzea Grande', 'Varzea Grande', 'Varzea Grande,Várzea Grande', -15.6466700, -56.1325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7824, 'Várzea da Palma', 'Varzea da Palma', '', -17.5976000, -44.7336700, 'BR', '2014-12-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7825, 'Varginha', 'Varginha', 'VAG,Varzhin''ja,bharginaha,wa er ren a,Варжинья,ভার্গিনহা,瓦尔任阿', -21.5513900, -45.4302800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7826, 'Vargem Grande do Sul', 'Vargem Grande do Sul', 'Santa Ana do Vargem Grande,Vargem Grande,Varzhen-Grandi-du-Sul,Варжен-Гранди-ду-Сул', -21.8322200, -46.8936100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7827, 'Vargem Alta', 'Vargem Alta', '', -20.6713900, -41.0069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7828, 'Valparaíso', 'Valparaiso', '', -21.2277800, -50.8683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7829, 'Valinhos', 'Valinhos', 'Valin''jus,Vallinhos,bhala''inahosa,wa li ni wu si,Валиньюс,Валіньюс,ভালইনহোস,瓦利尼乌斯', -22.9705600, -46.9958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7830, 'Valente', 'Valente', '', -11.4122200, -39.4619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7831, 'Valença', 'Valenca', 'Marques de Valenca,Marquês de Valença,Valensa,ballensa,wa lun sa,Валенса,Վալենսա,瓦倫薩,발렌사', -22.2455600, -43.7002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7832, 'Valença', 'Valenca', 'VAL,Valenca,Valença', -13.3702800, -39.0730600, 'BR', '2014-04-19', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7833, 'Vacaria', 'Vacaria', 'Ibia''e,Ibia''é,Vaccaria,Vakarija,Вакария', -28.5122200, -50.9338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7834, 'Urussanga', 'Urussanga', 'Urucanga,Uruçanga', -28.5177800, -49.3208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7835, 'Urupês', 'Urupes', 'Mundo Novo', -21.2016700, -49.2900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7836, 'Uruguaiana', 'Uruguaiana', 'URG,Uruguaiana,Uruguajana,Uruguayana,Urugvajana,uruguraa''iyana,wu lu gua ya na,Уругваяна,Уругуаяна,উরুগুৱাইয়ানা,乌鲁瓜亚纳', -29.7547200, -57.0883300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7837, 'Uruçuca', 'Urucuca', 'Agua Preta,Urycuca,Uryçuca', -14.5930600, -39.2844400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7838, 'Uruana', 'Uruana', '', -15.5036000, -49.6826600, 'BR', '2015-06-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7839, 'Uruaçu', 'Uruacu', 'Sant''Anna,Santana,Uruasu,Urucu,Uruçu,Уруасу', -14.5247200, -49.1408300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7840, 'União da Vitória', 'Uniao da Vitoria', 'Unian-da-Vitorija,Uniao da Victoria,União da Victoria,i''uniya''u da bhitoriya,wu ni ang-da wei duo li ya,Униан-да-Витория,Уніан-да-Віторія,ইউনিয়াউ ডা ভিটোরিয়া,乌尼昂-达维多利亚', -26.2300000, -51.0863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7841, 'Unaí', 'Unai', 'Capim Branco,Unahy,Unaj,Унай', -16.3575000, -46.9061100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7842, 'Una', 'Una', 'UNA,Una', -15.2933300, -39.0752800, 'BR', '2013-06-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7843, 'Umuarama', 'Umuarama', 'UMU', -23.7663900, -53.3250000, 'BR', '2016-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7844, 'Umbaúba', 'Umbauba', 'Papemal', -11.3833300, -37.6577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7845, 'Uberlândia', 'Uberlandia', 'UDI,Uberlandia,Uberlandija,Uberlândia,ubeleullanjia,uberlandiya,uberuranjia,wu bei lan di ya,xu ber lang deiy,Уберландия,Уберландија,উবের্লান্ডিয়া,อูเบร์ลังเดีย,ウベルランジア,烏貝蘭迪亞,우베를란지아', -18.9186100, -48.2772200, 'BR', '2015-08-15', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7846, 'Uberaba', 'Uberaba', 'UBA,Uberaba,uberaba,wu bei la ba,Убераба,উবেরাবা,烏貝拉巴', -19.7483300, -47.9319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7847, 'Ubatuba', 'Ubatuba', 'UBT,Ubatuba,ubatuba,wu ba tu ba,Убатуба,উবাটুবা,乌巴图巴', -23.4338900, -45.0711100, 'BR', '2013-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7848, 'Ubatã', 'Ubata', 'Dois Irmaos,Dois Irmãos', -14.2090600, -39.5264100, 'BR', '2015-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7849, 'Ubaitaba', 'Ubaitaba', 'Itapira', -14.3125000, -39.3233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7850, 'Ubaíra', 'Ubaira', 'Areia', -13.2680600, -39.6627800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7851, 'Ubá', 'Uba', 'Uba,uba,wu ba,Уба,উবা,乌巴', -21.1200000, -42.9427800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7852, 'Turmalina', 'Turmalina', '', -17.2855600, -42.7300000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7853, 'Tupi Paulista', 'Tupi Paulista', 'Gracianopolis,Gracianópolis,QTG,Tupi', -21.3811100, -51.5705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7854, 'Tupanciretã', 'Tupancireta', 'Tupaceretan,Tupacireta,Tupaciretã,Tuparecetan', -29.0805600, -53.8358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7855, 'Tupaciguara', 'Tupaciguara', 'Tupacyguara,Tupasiguara,Тупасигуара', -18.5922200, -48.7050000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7856, 'Tupã', 'Tupa', 'Tupa,Tupan,tu pang,tupaya,Тупа,Тупан,টুপয়া,图庞', -21.9347200, -50.5136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7857, 'Tucano', 'Tucano', 'Ramphastinae,Tukanu,oohashi shang ke,tu ka nuo,tukano,twkanw  bahya,Тукану,Տուկանու,توکانو، باهیا,توکانو، باہیا,টুকানো,ტუკანუ,オオハシ上科,圖卡諾', -10.9581700, -38.7908400, 'BR', '2015-06-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7858, 'Tubarão', 'Tubarao', 'Tubaran,tu ba lang,tubara''o,Тубаран,টুবারাও,图巴朗', -28.4666700, -49.0069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7859, 'Triunfo', 'Triunfo', 'Bom Jesus de Triunfo,Bom Jesus do Triunfo,Triumfo,Triumpho', -29.9433300, -51.7180600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7860, 'Trindade', 'Trindade', 'Trindadi,te lin da di,trindade,Триндади,Տրինդադի,ট্রিন্ডাডে,ტრინდადი,特林达迪', -16.6494400, -49.4888900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7861, 'Três Rios', 'Tres Rios', 'Entre-Rios,QIH,Tres-Rius,te lei si li ao si,tresa ri''osa,Трес-Риус,ট্রেস রিওস,特雷斯里奥斯', -22.1166700, -43.2091700, 'BR', '2012-12-15', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7862, 'Três Pontas', 'Tres Pontas', 'Tres-Pontas,te lei si peng ta si,tresa pontasa,Трес-Понтас,ট্রেস পোন্টাস,特雷斯蓬塔斯', -21.3666700, -45.5125000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7863, 'Três Passos', 'Tres Passos', '', -27.4555600, -53.9319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7864, 'Três Lagoas', 'Tres Lagoas', 'Lagoas,TJL,Tres Lagoas,Tres-Lagoas,Três Lagoas,tresa lagoyasa,trys laghwas,Трес-Лагоас,تريس لاغواس,ট্রেস লাগোয়াস', -20.7876500, -51.7033800, 'BR', '2015-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7865, 'Três de Maio', 'Tres de Maio', '3 de Maio,3 do Maio,Trez de Maio', -27.7733300, -54.2400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7866, 'Três Coroas', 'Tres Coroas', 'Ibicacu,Ibicacú,Mundo Novo', -29.5169400, -50.7777800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7867, 'Três Corações', 'Tres Coracoes', 'Tres Coracoes,Tres Korasojns,Tres-Korasojns,Três Corações,te lei si ke la song yi si,tresa korakoyesa,Трес Корасойнс,Трес-Корасойнс,טרס קוראסואס,ট্রেস কোরাকোয়েস,特雷斯科拉松伊斯', -21.6969400, -45.2533300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7868, 'Três Barras', 'Tres Barras', '', -26.1063900, -50.3222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7869, 'Tremembé', 'Tremembe', '', -22.9583300, -45.5494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7870, 'Tremedal', 'Tremedal', '', -14.9758300, -41.4108300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7871, 'Tramandaí', 'Tramandai', 'Tramandahy', -29.9847200, -50.1336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7872, 'Torres', 'Torres', 'Torres,Torris,tuo li si,Торрес,Торрис,托里斯', -29.3352800, -49.7269400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7873, 'Tomar do Geru', 'Tomar do Geru', 'Geru,Gerú,Jeru,Tomar do Jeru', -11.3733300, -37.8405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7874, 'Toledo', 'Toledo', 'TOW,Toledo,Толедо', -24.7136100, -53.7430600, 'BR', '2013-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7875, 'Tocantins', 'Tocantins', '', -21.1750000, -43.0177800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7876, 'Tobias Barreto', 'Tobias Barreto', 'Campos,Nossa Senhora de Campos do Rio Real', -11.1838900, -37.9983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7877, 'Tiradentes', 'Tiradentes', 'Tiradentes', -21.1102800, -44.1780600, 'BR', '2012-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7878, 'Timóteo', 'Timoteo', 'Timofej,Timoteu,Timothea,di mo te wu,tima''ote''o,timoteo,Тимотеу,Тимофей,টিমওটেও,ティモテオ,蒂莫特乌', -19.5810600, -42.6495300, 'BR', '2014-10-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7879, 'Timbó', 'Timbo', '', -26.8233300, -49.2716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7880, 'Tijucas', 'Tijucas', 'Tizhukas,Тижукас', -27.2413900, -48.6336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7881, 'Tietê', 'Tiete', 'Tiete,ti''ete,tie te,Тиете,টিএটে,铁特', -23.1019400, -47.7147200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7882, 'Tibagi', 'Tibagi', 'Tibagy,Tibaji', -24.5094400, -50.4136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7883, 'Teutônia', 'Teutonia', '', -29.4480600, -51.8063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7884, 'Terra Roxa', 'Terra Roxa', 'Terra Roxa', -23.8557100, -50.0314000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7885, 'Terra Rica', 'Terra Rica', '', -22.7094400, -52.6169400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7886, 'Terra Nova', 'Terra Nova', '', -12.3666700, -40.6666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7887, 'Terra Boa', 'Terra Boa', '', -23.7680600, -52.4441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7888, 'Teresópolis', 'Teresopolis', 'Terezopolis,Therezopolis,te lei suo bo li si,teresopolisa,Терезополис,টেরেসোপোলিস,特雷索波利斯', -22.4167000, -42.9782200, 'BR', '2014-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7889, 'Terenos', 'Terenos', 'Terreno,Terrenos', -20.4422200, -54.8602800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7890, 'Teófilo Otoni', 'Teofilo Otoni', 'TFL,Teofilo Otoni,Teofilu-Otoni,Teófilo Otoni,Teófilo Otôni,Theophilo Ottoni,te ao fei lu ao tuo ni,te xxfi lu xo to ni,te''ophilo otoni,tywfylw awtwny,Теофилу-Отони,تيوفيلو أوتوني,টেওফিলো ওটোনি,เตออฟีลูโอโตนี,特奥菲卢奥托尼', -17.8575000, -41.5052800, 'BR', '2017-07-18', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7891, 'Teodoro Sampaio', 'Teodoro Sampaio', 'Teodoru-Sampaju,te ao duo lu sang pa you,te''odoro samapa''i''o,Теодору-Сампаю,টেওডোরো সামপাইও,特奧多魯桑帕尤', -22.5325000, -52.1675000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7892, 'Telêmaco Borba', 'Telemaco Borba', 'TEC,Telemachus Borba,Telemaco Borba,Telemako Borba,Telemaku-Borba,tayelemako borba,te lai ma ku bo er ba,Телемако Борба,Телемаку-Борба,টয়েলেমাকো বোর্বা,特莱马库博尔巴', -24.3238900, -50.6155600, 'BR', '2017-07-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7893, 'Taubaté', 'Taubate', 'Taubate,Taubatea,Taubatė,Tava yvate,Táva yvate,ta''ubate,tao ba te,taubate,tea ba te,Таубате,টাউবাটে,เตาบาเต,タウバテ,陶巴特', -23.0263900, -45.5552800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7894, 'Tatuí', 'Tatui', 'Tatuhy,Tatui,Tatuí,ta tu yi,tatu''i,Татуи,টাটুই,塔图伊', -23.3555600, -47.8569400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7895, 'Tarumã', 'Taruma', 'Turuma,Turuman,Turumã', -22.7466700, -50.5772200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7896, 'Taquarituba', 'Taquarituba', 'Taquari,Taquary', -23.5330600, -49.2444400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7897, 'Taquaritinga', 'Taquaritinga', 'Takuaritinga,ta kua li ting jia,takuraaritinga,takwarytyngha,Такуаритинга,تاكواريتينغا,টাকুৱারিটিঙ্গা,塔夸里廷加', -21.4061100, -48.5047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7898, 'Taquari', 'Taquari', 'Takuari,Taquary,Такуари', -29.7997200, -51.8644400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7899, 'Taquara', 'Taquara', '', -29.6505600, -50.7805600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7900, 'Tapiramutá', 'Tapiramuta', 'Espera d''Anta', -11.8472200, -40.7913900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7901, 'Tapes', 'Tapes', 'Porto de Tapes', -30.6733300, -51.3958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7902, 'Taperoá', 'Taperoa', 'Taperua,Taperuá', -13.5380600, -39.0986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7903, 'Tapejara', 'Tapejara', 'Teixeira', -28.0680600, -52.0138900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7904, 'Tapejara', 'Tapejara', '', -23.7330600, -52.8733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7905, 'Tanhaçu', 'Tanhacu', 'Lacos,Laços,Sao Sebastiao,São Sebastião', -14.0213900, -41.2480600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7906, 'Tanguá', 'Tangua', '', -22.7302800, -42.7141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7907, 'Tanabi', 'Tanabi', 'Tanaby', -20.6263900, -49.6491700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7908, 'Tambaú', 'Tambau', 'Tambahu,Tambahú', -21.7050000, -47.2744400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7909, 'Taiobeiras', 'Taiobeiras', 'Tajobejras,Tayobeiras,Тайобейрас', -15.8077800, -42.2330600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7910, 'Taguatinga', 'Taguatinga', 'QHN,Santa Maria,Santa Maria do Taguatinga', -12.4038900, -46.4361100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7911, 'Taboão da Serra', 'Taboao da Serra', 'Tabuao da Serra,Tabuão da Serra', -23.6261100, -46.7916700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7912, 'Tabatinga', 'Tabatinga', '', -21.7166700, -48.6875000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7913, 'Suzano', 'Suzano', 'Susano,Suzano,Suzanu,su zha nuo,sujano,suzano,Сузано,Сузану,সুজানো,スザノ,蘇扎諾', -23.5425000, -46.3108300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7914, 'Sumaré', 'Sumare', 'RWS,Reboucas,Rebouças,Sumare,Sumaré,su ma lei,sumare,Сумаре,সুমারে,蘇馬雷', -22.8219400, -47.2669400, 'BR', '2017-07-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7915, 'Sorocaba', 'Sorocaba', 'SOD,Sorocaba,Sorokaba,solokaba,sorokaba,suo luo ka ba,Сорокаба,সোরোকাবা,ソロカーバ,索羅卡巴,소로카바', -23.5016700, -47.4580600, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7916, 'Sombrio', 'Sombrio', '', -29.1138900, -49.6166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7917, 'Soledade', 'Soledade', '', -28.8183300, -52.5102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7918, 'Socorro', 'Socorro', 'Soccorro,Sokorro,Sokorru,suo ke lu,Сокорро,Сокорру,索科鲁', -22.5913900, -46.5288900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7919, 'Sobradinho', 'Sobradinho', '', -12.8333300, -39.1000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7920, 'Siqueira Campos', 'Siqueira Campos', 'Colonia Mineira', -23.6888900, -49.8338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7921, 'Simão Dias', 'Simao Dias', 'Anapolis,Annapolis,Anápolis,Siman-Dias,sima''o diyasa,xi mang di ya si,Симан-Диас,সিমাও ডিয়াস,西芒迪亞斯', -10.7383300, -37.8111100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7922, 'Silvânia', 'Silvania', 'Bomfim,Bonfim', -16.6588900, -48.6080600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7923, 'Silva Jardim', 'Silva Jardim', 'Capivari,Capivary', -22.6508300, -42.3916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7924, 'Sidrolândia', 'Sidrolandia', '', -20.9319400, -54.9613900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7925, 'Siderópolis', 'Sideropolis', 'Nova Beluno,Novo Bellamo', -28.5977800, -49.4244400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7926, 'Severínia', 'Severinia', '', -20.8094400, -48.8027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7927, 'Sete Lagoas', 'Sete Lagoas', 'Sete Lagoas,Seti-Lagoas,sete lagoyasa,Сете Лагоас,Сети-Лагоас,সেটে লাগোয়াস', -19.4658300, -44.2466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7928, 'Sertãozinho', 'Sertaozinho', '', -21.1377800, -47.9902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7929, 'Sertanópolis', 'Sertanopolis', '', -23.0586100, -51.0363900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7930, 'Serro', 'Serro', 'Serru,sai lu,seraro,Серру,সেররো,塞鲁', -18.6047200, -43.3794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7931, 'Serrinha', 'Serrinha', '', -11.6641700, -39.0075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7932, 'Serra Negra', 'Serra Negra', '', -22.6122200, -46.7005600, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7933, 'Serrana', 'Serrana', '', -21.2113900, -47.5955600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7934, 'Serra', 'Serra', 'Serra,Серра', -20.1286100, -40.3077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7935, 'Seropédica', 'Seropedica', 'Seropedika,sai luo pei di ka,sera''opedika,Серопедика,সেরওপেডিকা,塞罗佩迪卡', -22.7438900, -43.7075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7936, 'Senhor do Bonfim', 'Senhor do Bonfim', 'SEI,Senhor do Bonfim', -10.4613900, -40.1894400, 'BR', '2017-05-02', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7937, 'Sengés', 'Senges', '', -24.1133500, -49.4631500, 'BR', '2014-10-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7938, 'Senador Canedo', 'Senador Canedo', '', -16.7080600, -49.0930600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7939, 'Seabra', 'Seabra', 'Doutor Seabra', -12.4171300, -41.7704900, 'BR', '2015-06-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7940, 'Schroeder', 'Schroeder', 'Joaquim Wolf,Joaquim Wolff', -26.4125000, -49.0730600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7941, 'Saubara', 'Saubara', '', -12.7375000, -38.7686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7942, 'Sarzedo', 'Sarzedo', '', -20.0352800, -44.1447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7943, 'Sarandi', 'Sarandi', 'Colonia Sarandy,Sarandi,Саранди', -27.9438900, -52.9230600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7944, 'Sarandi', 'Sarandi', '', -23.4436100, -51.8738900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7945, 'Saquarema', 'Saquarema', '', -22.9200000, -42.5102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7946, 'Sapucaia', 'Sapucaia', 'Acapucai,Açapucaí,Guianuba,Güianuba,Sapucaia,Sapukaja,Сапукая', -29.8333300, -51.1500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7947, 'Sapucaia', 'Sapucaia', '', -21.9950000, -42.9144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7948, 'Sapiranga', 'Sapiranga', 'Sapyranga', -29.6380600, -51.0069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7949, 'São Vicente', 'Sao Vicente', 'San Visente,San Visentė,San-Visenti,Sao Visente,Sao Visenti,sangbisenchi,sheng wei sen te shi,Сан-Висенти,Сан-Вісенті,Сао Висенте,Сао Висенти,סאו ויסנטה,聖維森特市,상비센치', -23.9630600, -46.3919400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7950, 'São Simão', 'Sao Simao', 'San-Siman,sheng xi mang,Сан-Симан,聖西芒', -21.4791700, -47.5508300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7951, 'São Sepé', 'Sao Sepe', '', -30.1605600, -53.5652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7952, 'São Sebastião do Passé', 'Sao Sebastiao do Passe', 'Sao Sebastiao,São Sebastião', -12.5125000, -38.4952800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7953, 'São Sebastião do Paraíso', 'Sao Sebastiao do Paraiso', 'San-Sebast''jan-du-Paraiso,San-Sebast''jan-du-Paraizu,Sao Sebastiao Paraiso,Sao Sebastiao do Paraizo,São Sebastião Paraíso,São Sebastião do Paraizo,sa''o sebasatiya''o do para''iso,sheng sai ba si di ang-du pa la yi su,Сан-Себастьян-ду-Параизу,Сан-Себастьян-ду-Параисо,সাও সেবাসটিয়াও ডো পারাইসো,圣塞巴斯蒂昂-杜帕拉伊苏', -20.9169400, -46.9913900, 'BR', '2013-10-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7954, 'São Sebastião do Caí', 'Sao Sebastiao do Cai', 'Cai,Caí,Sao Sebastiao do Cahy,São Sebastião do Cahy', -29.5866700, -51.3755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7955, 'São Sebastião', 'Sao Sebastiao', 'San-Sebast''jan,sa''o sebasatiya''o,sheng sai ba si di ang,Сан-Себастьян,সাও সেবাসটিয়াও,聖塞巴斯蒂昂', -23.7600000, -45.4097200, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7956, 'São Roque', 'Sao Roque', '', -23.5291700, -47.1352800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7957, 'São Pedro do Sul', 'Sao Pedro do Sul', 'San Pedro,Sao Pedro,São Pedro', -29.6205600, -54.1788900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7958, 'São Pedro da Aldeia', 'Sao Pedro da Aldeia', 'San-Pedru-da-Aldeja,Sao Pedro d''Aldeia,São Pedro d''Aldeia,sa''o pedro da alade''iya,sheng pei de luo-da a er de ya,Сан-Педру-да-Алдея,সাও পেড্রো ডা আলডেইয়া,圣佩德罗-达阿尔德亚', -22.8391700, -42.1027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7959, 'São Pedro', 'Sao Pedro', 'San-Pedru,sheng pei de luo,Сан-Педру,聖佩德羅', -22.5486100, -47.9138900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7960, 'São Paulo', 'Sao Paulo', 'SAO,Sampa,San Paolo,San Paul ed Brasil,San Paulas,San Paulo,San Paulu,San Paulu du Brasili,San Paulu dû Brasili,San Pauluw,San Pawlo,San Polo del Braxil,San Poulo,San Poło del Braxil,San Pàul ëd Brasil,San-Paulo,San-Paulu,San-Paŭlo,Sanpaulu,Sao Paolo,Sao Paulo,Sao Paulo capital,Saun Paulu,Sawo Palo,Sawo Pålo,São Paolo,São Paulo,São Paulo capital,Urbs Paulistana,cavo pavulo,sa''o pa''ulo,sa''o paulo,samu pa''ulu,sangpaollo,sangpaollu,sangpaullo,sangpaullu,sankt. paulos,sanpauro,savea pealea,savo palo,saw bawlw,saw palw,saw pwlw,saywpaywlw,sea pea lu,sheng bao luo,Σάο Πάολο,Сан Пауло,Сан Паулу,Сан-Паулу,Сан-Паўлу,Сао Паоло,Сао Пауло,Սան Պաուլու,סאו פאולא,סאו פאולו,ساؤ پالو,ساؤ پولو,سائوپائولو,ساو باولو,ܣܐܘ ܦܐܘܠܘ,ސައޮ ޕައުލޯ,साओ पाउलो,সাঁউ পাউলু,সাও পাউলো,சாவோ பாவுலோ,శఒ పౌలొ,ಸಾವೊ ಪಾಲೊ,സാവോ പോളോ,เซาเปาลู,ဆောပိုလိုမြို့,სან-პაულუ,ሳው ፓውሉ,サンパウロ,聖保羅,상파올로,상파올루,상파울로,상파울루', -23.5475000, -46.6361100, 'BR', '2017-06-29', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7961, 'São Miguel do Iguaçu', 'Sao Miguel do Iguacu', 'Gaucha,Gaúcha', -25.3480600, -54.2377800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7962, 'São Miguel do Araguaia', 'Sao Miguel do Araguaia', '', -13.2750000, -50.1627800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7963, 'São Mateus do Sul', 'Sao Mateus do Sul', 'San-Mateus-du-Sul,Sao Mateus,Sao Matheus,São Mateus,São Matheus,Сан-Матеус-ду-Сул', -25.8741700, -50.3827800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7964, 'São Mateus', 'Sao Mateus', 'SBJ,San-Mateus,Sao Mateus,Sao Matheus,São Mateus,São Matheus,Сан-Матеус', -18.7201100, -39.8589100, 'BR', '2013-12-31', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7965, 'São Marcos', 'Sao Marcos', 'Sao Marecas,São Marecas', -28.9711100, -51.0680600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7966, 'São Manuel', 'Sao Manuel', 'San-Manuehl'',Sao Manoel do Paraizo,São Manoel do Paraizo,Сан-Мануэль', -22.7311100, -48.5705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7967, 'São Luiz Gonzaga', 'Sao Luiz Gonzaga', 'Sao Luiz,Sao Luiz Gonzaga,São Luiz,São Luiz Gonzaga', -28.4083300, -54.9608300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7968, 'São Luís de Montes Belos', 'Sao Luis de Montes Belos', '', -16.5250000, -50.3722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7969, 'São Lourenço do Sul', 'Sao Lourenco do Sul', 'SQY,San-Lorensu-du-Sul,Sao Lourenco,São Lourenço,Сан-Лоренсу-ду-Сул', -31.3652800, -51.9783300, 'BR', '2017-04-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7970, 'São Lourenço do Oeste', 'Sao Lourenco do Oeste', 'Sao Lourenco,Sao Lourenco do Oeste,São Lourenço,São Lourenço do Oeste', -26.3591700, -52.8511100, 'BR', '2016-11-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7971, 'São Lourenço da Serra', 'Sao Lourenco da Serra', '', -23.8525000, -46.9425000, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7972, 'São Lourenço', 'Sao Lourenco', 'SSO,San-Lorensu,Sao Lourenco,São Lourenço,Сан-Лоренсу', -22.1163900, -45.0544400, 'BR', '2013-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7973, 'São Leopoldo', 'Sao Leopoldo', 'San-Leopoldu,Sao Leopoldo,São Leopoldo,sa''o le''opolado,sangle-opoldu,sheng li ao bo er du,Сан-Леополду,Сао Леополдо,সাও লেওপোলডো,サン・レオポルド,圣利奥波尔杜,상레오폴두', -29.7602800, -51.1472200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7974, 'São José dos Pinhais', 'Sao Jose dos Pinhais', 'San-Zhoze-dus-Pin''jajs,Sao Jose dos Pinhaes,Sao Jose dos Pinhais,Sao Zhose dos Pinajs,São José dos Pinhaes,São José dos Pinhais,sa''o jose dosa pinaha''isa,saw khwzh dws pynhays,sheng ruo ze du si pi ni ai si,Сан-Жозе-дус-Пиньяйс,Сан-Жозе-дус-Піньяйс,Сао Жосе дос Пињајс,סאו זוזה דוס פיניאיס,ساو خوزه دوس پینهایس,সাও জোসে ডোস পিনহাইস,聖若澤杜斯皮尼艾斯', -25.5302000, -49.2083600, 'BR', '2014-08-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7975, 'São José dos Campos', 'Sao Jose dos Campos', 'SJC,SJCampos,SJK,San Zoze dos Kamposas,San Žozė dos Kamposas,San-Zhoze-dus-Kampus,Sao Jose dos Campos,Sao Zhose dos Kampos,Sao Zhoze dos Kampos,Sao jose dos Campos,São José dos Campos,São josé dos Campos,Vale Paraiba,Vale do Paraiba,Vale do Paraíba,sa''o jose dosa kamposa,sangjojeduseukampuseu,sayw khwzh dws kamps,sheng ruo ze duo si kan bo si,Сан-Жозе-дус-Кампус,Сао Жозе дос Кампос,Сао Жосе дос Кампос,سائو خوزه دوس کامپس,সাও জোসে ডোস কাম্পোস,サン・ジョゼ・ドス・カンポス,聖若澤多斯坎波斯,상조제두스캄푸스', -23.1794400, -45.8869400, 'BR', '2017-01-19', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7976, 'São José do Rio Preto', 'Sao Jose do Rio Preto', 'Rio Preto,SJP,San Zoze do Rio Pretas,San Žozė do Rio Pretas,San-Zhoze-du-Riu-Pretu,Sao Zhoze do Rio Preto,pu lei tu he pan sheng ruo ze,sa''o jose do ri''o preto,Сан-Жозе-ду-Риу-Прету,Сан-Жозе-ду-Ріу-Прету,Сао Жозе до Рио Прето,সাও জোসে ডো রিও প্রেটো,サン・ジョゼー・ド・リオ・プレト,普雷图河畔圣若泽', -20.8197200, -49.3794400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7977, 'São José do Rio Pardo', 'Sao Jose do Rio Pardo', '', -21.5955600, -46.8886100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7978, 'São José do Calçado', 'Sao Jose do Calcado', '', -21.0252800, -41.6544400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7979, 'São José', 'Sao Jose', '', -28.2117100, -49.1632000, 'BR', '2013-05-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7980, 'São Joaquim de Bicas', 'Sao Joaquim de Bicas', 'Bicas', -20.0491700, -44.2738900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7981, 'São Joaquim da Barra', 'Sao Joaquim da Barra', 'Sao Joaquim,São Joaquim', -20.5813900, -47.8547200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7982, 'São Joaquim', 'Sao Joaquim', 'Sao Joaquim da Costa da Serra,São Joaquim da Costa da Serra', -28.2938900, -49.9316700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7983, 'São João Nepomuceno', 'Sao Joao Nepomuceno', 'San-Zhuan-Nepomuseno,Сан-Жуан-Непомусено', -21.5400000, -43.0105600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7984, 'São João Evangelista', 'Sao Joao Evangelista', '', -18.5477800, -42.7633300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7985, 'São João do Paraíso', 'Sao Joao do Paraiso', 'Sao Joao do Paraizo,São João do Paraizo', -15.3136100, -42.0144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7986, 'São João de Meriti', 'Sao Joao de Meriti', 'Gorad San-Zhuan-dy-Meryty,Meriti,Merity,San Zuan de Meritis,San Žuan de Meritis,San-Zhuan-di-Meriti,Sao Zhoao de Meriti,Sao Zhoao di Meriti,sa''o joya''o de meriti,sheng ruo ang di mei li di,Горад Сан-Жуан-ды-Мерыты,Сан-Жуан-ди-Мерити,Сао Жоао де Мерити,Сао Жоао ди Мерити,সাও জোয়াও ডে মেরিটি,聖若昂迪梅里蒂', -22.8038900, -43.3722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7987, 'São João del Rei', 'Sao Joao del Rei', 'JDR,San-Zhuan-del-Rej,Sao Joao del Rei,Sao Joao del-Rei,Sao Jose del Rey,São José del Rey,São João del Rei,São João del-Rei,sa''o joya''o dela re''i,sangjoangjiulei,sheng ruo ang-de lei,Сан-Жуан-дел-Рей,সাও জোয়াও ডেল রেই,サン・ジョアン・デル・レイ,圣若昂-德雷,상조앙지우레이', -21.1355600, -44.2616700, 'BR', '2013-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7988, 'São João da Ponte', 'Sao Joao da Ponte', '', -15.9291700, -44.0077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7989, 'São João da Boa Vista', 'Sao Joao da Boa Vista', '', -21.9691700, -46.7980600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7990, 'São João da Barra', 'Sao Joao da Barra', 'San-Zhuan-da-Barra,Sao Joao De Barra,São Joao De Barra,Сан-Жуан-да-Барра', -21.6402800, -41.0511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7991, 'São João Batista', 'Sao Joao Batista', 'Sao Joao Baptista,São João Baptista', -27.2761100, -48.8494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7992, 'São Jerônimo', 'Sao Jeronimo', 'Sao Jeronymo,São Jeronymo', -29.9591700, -51.7222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7993, 'São Gotardo', 'Sao Gotardo', 'Sao Gothardo,São Gothardo', -19.3111100, -46.0488900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7994, 'São Gonçalo dos Campos', 'Sao Goncalo dos Campos', 'Sao Goncalo,São Gonçalo', -12.4333300, -38.9666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7995, 'São Gonçalo do Sapucaí', 'Sao Goncalo do Sapucai', 'Sao Goncalo,São Gonçalo', -21.8922200, -45.5952800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7996, 'São Gonçalo', 'Sao Goncalo', 'San Gonsalas,San-Gonsalu,Sao Gonsalo,san-gonsalu,sang-gonsallu,sangonsaro,saw ghwnsalw,sayw gwnsalw  ryw dw zhanyrw,sheng gong sa luo,Сан-Гонсалу,Сао Гонсало,سائو گونسالو، ریو دو ژانیرو,ساو غونسالو,სან-გონსალუ,サンゴンサロ,聖貢薩洛,상곤살루', -22.8269400, -43.0538900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7997, 'São Gabriel', 'Sao Gabriel', '', -30.3363900, -54.3200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7998, 'São Francisco do Sul', 'Sao Francisco do Sul', 'San Francisco del Sur,San-Fransisku-du-Sul,Sao Francisco,São Francisco,nan sheng fu lang xi si ke,sa''o phransisako do sula,Сан-Франсиску-ду-Сул,סאו פרנסיסקו דו סול,সাও ফ্রান্সিসকো ডো সুল,南圣弗朗西斯科', -26.2433300, -48.6380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(7999, 'São Francisco do Conde', 'Sao Francisco do Conde', 'San-Fransisku-du-Konde,Sao Francisco,São Francisco,Сан-Франсиску-ду-Конде', -12.6275000, -38.6800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8000, 'São Francisco de Paula', 'Sao Francisco de Paula', 'San-Fransisku-di-Paula,Sao Francisca da Paulo,São Francisca da Paulo,sa''o phransisako de pa''ula,sheng fu lang xi si ke-di bao la,Сан-Франсиску-ди-Паула,সাও ফ্রান্সিসকো ডে পাউলা,圣弗朗西斯科-迪保拉', -29.4480600, -50.5836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8001, 'São Francisco de Assis', 'Sao Francisco de Assis', 'San-Fransisku-di-Asis,sa''o phransisako de asasisa,sheng fu lang xi si ke-di a xi si,Сан-Франсиску-ди-Асис,সাও ফ্রান্সিসকো ডে আসসিস,圣弗朗西斯科-迪阿西斯', -29.5502800, -55.1311100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8002, 'São Francisco', 'Sao Francisco', 'San-Fransisku,sheng fu lang xi si ke,Сан-Франсиску,聖弗朗西斯科', -15.9486100, -44.8644400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8003, 'São Fidélis', 'Sao Fidelis', '', -21.6461100, -41.7469400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8004, 'São Felipe', 'Sao Felipe', 'Sao Felipe,Sao Filippe,São Felipe,São Filippe', -14.8386000, -41.3917400, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8005, 'São Domingos do Prata', 'Sao Domingos do Prata', 'Sao Domingos da Prata', -19.8650000, -42.9683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8006, 'São Domingos', 'Sao Domingos', '', -13.3983300, -46.3183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8007, 'São Desidério', 'Sao Desiderio', '', -12.3633300, -44.9733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8008, 'São Cristóvão', 'Sao Cristovao', 'San Kristovanas,San-Kristovan,Sao Christovao,São Christovão,sa''o karisatobhya''o,sangkeuliseutobang,sheng ke li si tuo wang,Сан-Кристован,সাও করিসটোভ্যাও,სან-კრისტოვანი,サン・クリストヴァン,聖克里斯托旺,상크리스토방', -11.0147200, -37.2063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8009, 'São Carlos', 'Sao Carlos', 'QSC,San Karlosas,San-Karlos,San-Karlus,Sao Carlos,Sao Carlos do Pinhal,Sao Karlos,São Carlos,São Carlos do Pinhal,Urbs Carlopolitana,sa''o karlosa,sangkaleulluseu,saw karlws,sheng ka luo si,Сан-Карлос,Сан-Карлус,Сао Карлос,ساو كارلوس,ساو کارلوس,সাও কার্লোস,聖卡洛斯,상카를루스', -22.0175000, -47.8908300, 'BR', '2013-04-14', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8010, 'São Caetano do Sul', 'Sao Caetano do Sul', 'QCX,San-Kaehtano-du-Sul,Sao Caetano do Sul,São Caetano do Sul,Сан-Каэтано-ду-Сул', -23.6230600, -46.5511100, 'BR', '2014-11-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8011, 'São Borja', 'Sao Borja', 'San-Borkha,Sao Borja,São Borja,Сан-Борха', -28.6605600, -56.0044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8012, 'São Bernardo do Campo', 'Sao Bernardo do Campo', 'QSB,SBC,SBCampo,San-Bernardo-du-Kampu,Sao Bernardo,Sao Bernardo do Campo,São Bernardo,São Bernardo do Campo,Сан-Бернардо-ду-Кампу', -23.6938900, -46.5650000, 'BR', '2014-03-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8013, 'São Bento do Sul', 'Sao Bento do Sul', 'San-Bentu-du-Sul,Sao Bento,Sao Bento do Sul,Serra Alta,São Bento,São Bento do Sul,Сан-Бенту-ду-Сул', -26.2502800, -49.3786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8014, 'Santos Dumont', 'Santos Dumont', 'Palmyra,Santus-Dumont,sang tuo si du meng te,santosa dumonta,Сантус-Думонт,সান্টোস ডুমোন্ট,桑托斯杜蒙特', -21.4566700, -43.5525000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8015, 'Santos', 'Santos', 'Baixada Santista,Gorad Santus,SSZ,Santos,Santosas,Santus,Santus khot,Santusa,Urbs Sanctorum,sang tuo si,sang tus,santosa,santosu,santuseu,santws,santws  saw pawlw,sntws,Σάντος,Горад Сантус,Сантос,Сантус,Сантус хот,סנטוס,سانتوس,سانتوس، ساؤ پاؤلو,সান্টোস,ซังตูส,サントス,桑托斯,산투스', -23.9608300, -46.3336100, 'BR', '2017-01-02', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8016, 'Santo Estêvão', 'Santo Estevao', '', -12.4302800, -39.2513900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8017, 'Santo Augusto', 'Santo Augusto', '', -27.8508300, -53.7772200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8018, 'Santo Antônio do Sudoeste', 'Santo Antonio do Sudoeste', 'San Antonio,San Antônio,Santo Antonio,Santo Antônio', -26.0736100, -53.7252800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8019, 'Santo Antônio do Monte', 'Santo Antonio do Monte', '', -20.0872200, -45.2936100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8020, 'Santo Antônio do Leverger', 'Santo Antonio do Leverger', 'Leverger,Santo Antonio,Santo Antonio do Rio Abaixo', -15.8655600, -56.0766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8021, 'Santo Antônio do Amparo', 'Santo Antonio do Amparo', '', -20.9463900, -44.9188900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8022, 'Santo Antônio de Posse', 'Santo Antonio de Posse', 'Posse,Posse de Ressaca', -22.6061100, -46.9194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8023, 'Santo Antônio de Pádua', 'Santo Antonio de Padua', 'Santo Antonio do Padua', -21.5394400, -42.1802800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8024, 'Santo Antônio de Jesus', 'Santo Antonio de Jesus', '', -12.9688900, -39.2613900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8025, 'Santo Antônio da Platina', 'Santo Antonio da Platina', 'Santo Antonio da Platino,Santu-Antoniu-da-Platina,Санту-Антониу-да-Платина', -23.2950000, -50.0772200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8026, 'Santo Ângelo', 'Santo Angelo', 'GEL,Santo Angelo,Santo Ângelo,Santu-Andzhelo,Santu-Anzhelu,santo anagelo,sheng an re lu,Санту-Анджело,Санту-Анжелу,সান্টো আনগেলো,圣安热卢', -28.2991700, -54.2630600, 'BR', '2013-05-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8027, 'Santo André', 'Santo Andre', 'Santo Andre,Santo André,Santu-Andre,Санту-Андре', -23.6638900, -46.5383300, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8028, 'Santo Anastácio', 'Santo Anastacio', '', -21.8383300, -51.6102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8029, 'Santo Amaro das Brotas', 'Santo Amaro das Brotas', 'Santo Amaro,Santo Amaro das Brotas', -10.7888900, -37.0544400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8030, 'Santo Amaro da Imperatriz', 'Santo Amaro da Imperatriz', 'Cambirela,Santo Amaro,Santo Amaro do Cubatao,Santo Amaro do Cubatão', -27.6880600, -48.7786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8031, 'Santo Amaro', 'Santo Amaro', 'Santo Amaro da Purificacao,Santo Amaro da Purificação,Santu Amaru,Santu-Amaru,sheng a ma lu,Санту-Амару,Սանտու Ամարու,სანტუ-ამარუ,圣阿马鲁', -12.5466700, -38.7119400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8032, 'Santiago', 'Santiago', 'Sant''jago,Santiago do Boqueirao,Santiago do Boqueirão,Сантьяго', -29.1916700, -54.8672200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8033, 'Santa Vitória do Palmar', 'Santa Vitoria do Palmar', 'CTQ,Santa Victoria,Santa Victoria do Palmar', -33.5188900, -53.3680600, 'BR', '2017-07-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8034, 'Santa Vitória', 'Santa Vitoria', 'Santa Victoria', -18.8386100, -50.1213900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8035, 'Santa Teresa', 'Santa Teresa', 'Santa Tereza,Santa Thereza,Santa-Tereza,sheng te lei sha,Санта-Тереза,Սանտա Թերեզա,სანტა-ტერეზა,聖特雷莎', -19.9355600, -40.6002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8036, 'Santa Rosa de Viterbo', 'Santa Rosa de Viterbo', 'Icaturama,Santa Rosa', -21.4727800, -47.3630600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8037, 'Santa Rosa', 'Santa Rosa', 'SRA', -27.8708300, -54.4813900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8038, 'Santa Rita do Sapucaí', 'Santa Rita do Sapucai', 'Porto Sapucahy,Pôrto Sapucahy,Santa Rita do Sapucahy,Santa-Rita-du-Sapukajja,Санта-Рита-ду-Сапукайя', -22.2522200, -45.7033300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8039, 'Santa Rita do Passa Quatro', 'Santa Rita do Passa Quatro', 'Santa Rita', -21.7102800, -47.4780600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8040, 'Santana do Paraíso', 'Santana do Paraiso', 'Santana-du-Paraiso,Santana-du-Paraizu,santana do para''iso,sheng an na-du pa la yi su,Сантана-ду-Параизу,Сантана-ду-Параисо,সান্টানা ডো পারাইসো,圣安娜-杜帕拉伊苏', -19.3636100, -42.5686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8041, 'Santana do Livramento', 'Santana do Livramento', 'LVB,Livramento,Sant''Anna do Livramento,Santana do Livramento,Santana-du-Livramentu,santana do libhramenato,sheng an na-li fu la men tu,sntnh dw lybrmntw,Сантана-ду-Ливраменту,סנטנה דו ליברמנטו,সান্টানা ডো লিভ্রামেনটো,サンタナ・ド・リヴラメント,圣安娜-利弗拉门图', -30.8908300, -55.5327800, 'BR', '2017-07-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8042, 'Santana de Parnaíba', 'Santana de Parnaiba', 'Parnahyba,Parnaiba,Parnaíba,Sant''Ana-de-Paranaiba,Sant''Ana-de-Paranaíba', -23.4441700, -46.9177800, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8043, 'Santana', 'Santana', '', -14.4666700, -41.8000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8044, 'Santa Maria do Suaçuí', 'Santa Maria do Suacui', 'Santa Maria de Suassuhy,Santa Maria do Suassui,Santa Maria do Suassuí', -18.1902800, -42.4141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8045, 'Santa Maria da Vitória', 'Santa Maria da Vitoria', 'Santa Maria,Santa-Marija-da-Vitorija,Санта-Мария-да-Витория', -13.3881400, -44.1986800, 'BR', '2016-11-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8046, 'Santa Maria', 'Santa Maria', 'RIA,Santa Maria da Boca do Monte,Santa Marija,Santa-Marija,san ta ma reiy,santa marya,santamalia,sheng ma li ya,snth mryh,Санта Марија,Санта-Мария,סנטה מריה,سانتا ماریا,ซานตามาเรีย,聖瑪麗亞,산타마리아', -29.6841700, -53.8069400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8047, 'Santa Luzia', 'Santa Luzia', 'Santa Lucia,Santa Luzija,Santa Lúcia,Santa-Lusija,Santa-Luzija,sheng lu xi ya,Санта Лузија,Санта-Лузия,Санта-Лусия,聖盧西亞', -19.7697200, -43.8513900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8048, 'Santaluz', 'Santaluz', 'Santa Luiza,Santa Luzia', -11.2558300, -39.3747200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8049, 'Santa Leopoldina', 'Santa Leopoldina', 'Cachoeiro de Santa Leopoldina', -20.1005600, -40.5297200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8050, 'Santa Isabel', 'Santa Isabel', 'Santa Izabel', -23.3155600, -46.2213900, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8051, 'Santa Inês', 'Santa Ines', 'Santa Ignez,Santa-Ines,Санта-Инес', -13.2922200, -39.8188900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8052, 'Santa Helena de Goiás', 'Santa Helena de Goias', 'Helena de Goias,Helena de Goiás,Ipeguari,Santa Helena,Santa-Ehlena-di-Gojas,Санта-Элена-ди-Гояс', -17.8136100, -50.5969400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8053, 'Santa Gertrudes', 'Santa Gertrudes', '', -22.4566700, -47.5302800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8054, 'Santa Fé do Sul', 'Santa Fe do Sul', '', -20.2111100, -50.9258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8055, 'Santa Cruz do Sul', 'Santa Cruz do Sul', 'CSU,Santa Cruz,Santa-Krus-du-Sul,nan sheng ke lu si,santa kruja do sula,Санта-Крус-ду-Сул,সান্টা ক্রুজ ডো সুল,南圣克鲁斯', -29.7175000, -52.4258300, 'BR', '2017-04-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8056, 'Santa Cruz do Rio Pardo', 'Santa Cruz do Rio Pardo', '', -22.8988900, -49.6325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8057, 'Santa Cruz das Palmeiras', 'Santa Cruz das Palmeiras', 'Palmeiras', -21.8269400, -47.2486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8058, 'Santa Cruz Cabrália', 'Santa Cruz Cabralia', 'Santa Cruz,Santa Cruz de Cabralia,Santa Cruz de Cabrália', -16.2780600, -39.0247200, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8059, 'Santa Cecília', 'Santa Cecilia', '', -26.9608300, -50.4269400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8060, 'Santa Branca', 'Santa Branca', '', -23.3966700, -45.8838900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8061, 'Santa Bárbara d''Oeste', 'Santa Barbara d''Oeste', 'Barbara do Oeste,Bárbara do Oeste,Santa Barbara do Oeste,Santa Bárbara do Oeste,Sata Barbar dOeste,Sata Bárbar dOeste', -22.7536100, -47.4136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8062, 'Santa Adélia', 'Santa Adelia', '', -21.2427800, -48.8041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8063, 'Sananduva', 'Sananduva', 'Savanduva', -27.9497200, -51.8066700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8064, 'Salvador', 'Salvador', 'Bahia,Baia,Baía,SSA,Sal''vador,Salvador,Salvador da Bahia,Salvador de Bahia,Salvador de Bahio,Salvador de Bahía,Salvadora,Salvadoras,Sao Salvador,Soteropolis,sa er wa duo,sal wad xr,salabhadora,salfadwr  bahya,salvadori,salvhadora da ba''iya,salwadwr,sarubadoru,saruvu~adoru,saubadoleu,slbdwr,slwadwr,Σαλβαδόρ,Салвадор,Сальвадор,סלבדור,سالفادور، باهيا,سالوادور,سلوادور,साल्व्हादोर दा बाईया,সালভাদোর,ซัลวาดอร์,სალვადორი,サルバドール,サルヴァドール,萨尔瓦多,사우바도르', -12.9711100, -38.5108300, 'BR', '2014-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8065, 'Salto de Pirapora', 'Salto de Pirapora', '', -23.6488900, -47.5733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8066, 'Salto', 'Salto', 'Sal''to,Salto do Itu,Salto do Itú,Saltu,sa er tu,Салту,Сальто,萨尔图', -23.2008300, -47.2869400, 'BR', '2012-07-29', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8067, 'Salinas', 'Salinas', 'Salinas,sa li na si,salinasa,Салинас,সালিনাস,萨利纳斯', -16.1702800, -42.2902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8068, 'Salgado', 'Salgado', '', -11.0319400, -37.4750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8069, 'Sacramento', 'Sacramento', 'Sakramentu,sa ke la men tuo,sakaramenato,Сакраменту,সাকরামেনটো,萨克拉门托', -19.8652800, -47.4400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8070, 'Sabinópolis', 'Sabinopolis', '', -18.6661100, -43.0838900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8071, 'Ruy Barbosa', 'Ruy Barbosa', 'Ruy Barbosa', -12.2838900, -40.4938900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8072, 'Rubiataba', 'Rubiataba', '', -15.1644400, -49.8033300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8073, 'Rosário Oeste', 'Rosario Oeste', 'Rosario Oueste,Rosario do Rio Acima,Rosário do Rio Acima', -14.8361100, -56.4275000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8074, 'Rosário do Sul', 'Rosario do Sul', 'Rosario,Rosario-du-Sul,Rosário,Росарио-ду-Сул', -30.2583300, -54.9141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8075, 'Rondonópolis', 'Rondonopolis', 'ROO,Rodonopolis,Rodonópolis,Rondonopolis,Rondonópolis', -16.4708300, -54.6355600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8076, 'Rolante', 'Rolante', '', -29.6505600, -50.5758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8077, 'Rolândia', 'Rolandia', 'Caviuna,Caviúna', -23.3097200, -51.3691700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8078, 'Rodeio', 'Rodeio', '', -26.9227800, -49.3663900, 'BR', '2017-04-16', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8079, 'Rio Verde de Mato Grosso', 'Rio Verde de Mato Grosso', 'Coronel Galvao,Coronel Galvão,Fazenda Rio Verde,Rio Verde', -18.9180600, -54.8441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8080, 'Rio Tavares', 'Rio Tavares', '', -27.6452900, -48.4748600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8081, 'Rio Real', 'Rio Real', 'Barracao,Barracão,Brejo Grande', -11.4847200, -37.9327800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8082, 'Rio Pomba', 'Rio Pomba', 'Pomba', -21.2747200, -43.1791700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8083, 'Rio Piracicaba', 'Rio Piracicaba', '', -19.9291700, -43.1741700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8084, 'Rio Pardo de Minas', 'Rio Pardo de Minas', 'Rio Pardo', -15.6097200, -42.5397200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8085, 'Rio Pardo', 'Rio Pardo', 'Poaca,Poacá,Rio-Pardo,Riu-Pardu,li ao pa er du,ri''o pardo,Рио-Пардо,Риу-Парду,রিও পার্ডো,里奥帕尔杜', -29.9897200, -52.3780600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8086, 'Rio Novo do Sul', 'Rio Novo do Sul', 'Itapoama,Rio Novo', -20.8625000, -40.9363900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8087, 'Rio Novo', 'Rio Novo', '', -21.4770300, -43.1258900, 'BR', '2013-03-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8088, 'Rio Negro', 'Rio Negro', '', -26.1058300, -49.7975000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8089, 'Rio Negrinho', 'Rio Negrinho', 'QNE', -26.2544400, -49.5183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8090, 'Riolândia', 'Riolandia', 'Veadinho,Veadinho do Porto,Veadinho do Pôrto', -19.9808300, -49.6819400, 'BR', '2013-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8091, 'Rio Grande da Serra', 'Rio Grande da Serra', '', -23.7441700, -46.3983300, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8092, 'Rio Grande', 'Rio Grande', 'RIG,Rio Grande,Rio Grande do Sul,Rio-Grande,San Pedro do Rio Grande,Sao Pedro do Rio Grande do Sul,São Pedro do Rio Grande do Sul,Рио-Гранде', -32.0350000, -52.0986100, 'BR', '2016-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8093, 'Rio do Sul', 'Rio do Sul', 'Itajahy do Sul,QRU,Rio Sul,Riu-du-Sul,nan he zhen,ri''o do sula,Риу-ду-Сул,রিও ডো সুল,南河镇', -27.2141700, -49.6430600, 'BR', '2013-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8094, 'Rio de Janeiro', 'Rio de Janeiro', 'Ciutat de Rio de Janeiro,Gorad Rya-deh-Zhanehjra,RIO,Rio,Rio De Janeiro,Rio d Janeiro,Rio de Janeiro,Rio de Janeiru,Rio de Janero,Rio de Janeyro,Rio de Janèro,Rio de Janêro,Rio de Zaneiras,Rio de Zaneiros,Rio de Zaneyro,Rio de Zhaneiro,Rio de Zhanejro,Rio de Žaneiras,Rio dé Janéyro,Rio dė Žaneiros,Rio nte Tzaneiro,Rio-de-Janejro,Rio-de-Janeyro,Rio-de-Zaneiro,Rio-de-Zanejro,Rio-de-Zaneyro,Rio-de-Zhanejro,Rio-de-janeiro,Rio-de-Ĵanejro,Rio-de-Žaneiro,Rio-de-Žaneýro,Riodezaneiro,Riodežaneiro,Riu de Janeiro,Riu de Janeiru,Riviethe de Janvyi,Riviéthe dé Janvyi,Río de Janeiro,Sao Sebastiao do Rio de Janeiro,São Sebastião do Rio de Janeiro,Urbs Fluminensis,iriyo ti ceniro,li yue re nei lu,liudejaneilu,rath ri xode ca ne ro,ri xode ca ne ro,ri''o di janero,ri''o di jeneri''o,ri''o di jeniro,rio-de-zhaneiro,riodejaneiro,rios. dis. djaneiros,riyea di janirea,riyo di janairo,riyo di janero,riyo di jeneriyo,riyo di jenero,riyo di jyaneriyo,ryw dh znyyrw,ryw dw zhanyrw,ryw dwzhanyrw,ryw dy janyrw,Ρίο ντε Τζανέιρο,Горад Рыа-дэ-Жанэйра,Рио де Жанеиро,Рио де Жанейро,Рио-де-Жанейро,Ріо де Жанейро,Ріо-де-Жанейро,Ռիո դե Ժանեյրո,ריא דע זשאנערא,ריו דה זניירו,ريو دى جانيرو,ريو دي جانيرو,ریو دو ژانیرو,ریو دوژانیرو,ریو دے جینیرو,ریو ڈی جینرو,ڕیۆ دێ ژانێرۆ,रियो डि जेनेरो,रियो दि जानेरो,रियो दि ज्यानेरियो,रियो दी जेनेरियो,রিও ডি জেনিরো,রিও দি জেনেরিও,ਰਿਓ ਡੀ ਜਨੇਰੋ,இரியோ டி செனீரோ,ರಿಯೋ ಡಿ ಜನೈರೊ,റിയോ ഡി ജനീറോ,รัฐรีโอเดจาเนโร,รีโอเดจาเนโร,རིའོ་ཌེ་ཇ་ནེའུ་རའོ།,ရီယို ဒီ ဂျီးနေးရိုးမြို့,რიო-დე-ჟანეირო,ሪዮ ዴ ጃኔይሮ,リオデジャネイロ,里約熱內盧,里约热内卢,리우데자네이루', -22.9027800, -43.2075000, 'BR', '2012-06-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8095, 'Rio das Pedras', 'Rio das Pedras', '', -22.8433300, -47.6061100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8096, 'Rio das Ostras', 'Rio das Ostras', '', -22.5269400, -41.9450000, 'BR', '2014-05-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8097, 'Rio Claro', 'Rio Claro', 'Itavera,Itaverá,Rio Claro,Riu-Klaru,Río Claro,li yue ke la luo,Риу-Клару,里约克拉罗', -22.7230600, -44.1355600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8098, 'Rio Claro', 'Rio Claro', 'QIQ', -22.4113900, -47.5613900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8099, 'Rio Casca', 'Rio Casca', '', -20.2261100, -42.6508300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8100, 'Rio Brilhante', 'Rio Brilhante', 'Caiuas,Caiuás,Entre Rios,Riu Brilianti,Riu-Bril''janti,li ao bu li lang di,ri''o brilahanate,Риу-Брильянти,Ռիու Բրիլիանտի,রিও ব্রিলহানটে,რიუ-ბრილიანტი,里奧布里朗蒂', -21.8019400, -54.5463900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8101, 'Rio Branco do Sul', 'Rio Branco do Sul', 'Rio Branco,Riu-Branku-du-Sul,Votuverava,Риу-Бранку-ду-Сул', -25.1900000, -49.3141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8102, 'Rio Bonito', 'Rio Bonito', '', -22.7086100, -42.6097200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8103, 'Rio Bananal', 'Rio Bananal', '', -19.2650000, -40.3333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8104, 'Ribeirópolis', 'Ribeiropolis', '', -10.5394400, -37.4166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8105, 'Ribeirão Preto', 'Ribeirao Preto', 'Entre Rios,RAO,Ribeiran Pretas,Ribeirao,Ribeirao Preto,Ribeirão,Ribeirão Preto,Ribejran-Pretu,Ribejrao Preto,hibeilangpeuletu,li bei lang pu lei tu,ribe''ira''o preto,Рибеирао Прето,Рибейран-Прету,Рибейрао Прето,Рібейран-Прету,রিবেইরাও প্রেটো,リベイラン・プレト,里貝朗普雷圖,히베이랑프레투', -21.1775000, -47.8102800, 'BR', '2015-06-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8106, 'Ribeirão Pires', 'Ribeirao Pires', '', -23.7105600, -46.4133300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8107, 'Ribeirão das Neves', 'Ribeirao das Neves', 'Neves,Nevez,Ribeirao das Neves,Ribeirão das Neves', -19.7669400, -44.0866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8108, 'Ribeirão da Ilha', 'Ribeirao da Ilha', 'Ribeirao,Ribeirão', -27.6993400, -48.5321900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8109, 'Ribeirão Branco', 'Ribeirao Branco', '', -24.2208300, -48.7655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8110, 'Ribeirão Bonito', 'Ribeirao Bonito', '', -22.0666700, -48.1761100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8111, 'Ribeira do Pombal', 'Ribeira do Pombal', 'Canabrava de Santa Teresa de Jesus dos Quiriris,Canna Brava,Pombal', -10.8344400, -38.5358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8112, 'Ribas do Rio Pardo', 'Ribas do Rio Pardo', 'Rio Pardo', -20.4430600, -53.7591700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8113, 'Rialma', 'Rialma', 'Rialmas', -15.3150000, -49.5844400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8114, 'Riacho de Santana', 'Riacho de Santana', 'Riacho de Sant''Anna,Riashu-di-Santana,Riasu di Santana,li ya shu-di sheng an na,Риашу-ди-Сантана,Ռիաշու դի Սանտանա,რიაშუ-დი-სანტანა,里亚舒-迪圣安娜', -13.6091700, -42.9388900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8115, 'Riachão do Jacuípe', 'Riachao do Jacuipe', 'Riachao,Riachao do Jacuhype,Riachão,Riachão do Jacuhype', -11.8069400, -39.3855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8116, 'Riachão do Dantas', 'Riachao do Dantas', 'Riachao,Riachão', -11.0688900, -37.7250000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8117, 'Riachão das Neves', 'Riachao das Neves', '', -11.7461100, -44.9100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8118, 'Resplendor', 'Resplendor', 'Resplendor,lei si pu lun du,resapalenador,Респлендор,রেসপলেনডোর্,雷斯普伦杜', -19.3255600, -41.2552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8119, 'Reserva', 'Reserva', '', -24.6502800, -50.8505600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8120, 'Resende', 'Resende', 'QRZ,REZ,Resende,Rezende,Rezendi,hejenji,lei sen di,rysndy,Резенди,Резенді,ریسندی,雷森迪,헤젠지', -22.4688900, -44.4466700, 'BR', '2013-05-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8121, 'Registro', 'Registro', '', -24.4875000, -47.8436100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8122, 'Regente Feijó', 'Regente Feijo', '', -22.2213900, -51.3027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8123, 'Recreio', 'Recreio', '', -21.5250000, -42.4691700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8124, 'Realeza', 'Realeza', '', -25.7688900, -53.5325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8125, 'Raposos', 'Raposos', 'Raposas', -19.9672200, -43.8041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8126, 'Rancharia', 'Rancharia', '', -22.2291700, -50.8930600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8127, 'Quirinópolis', 'Quirinopolis', '', -18.4483300, -50.4516700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8128, 'Quijingue', 'Quijingue', 'Triumpho,Triunfo', -10.7525000, -39.2091700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8129, 'Queimados', 'Queimados', '', -22.7161100, -43.5552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8130, 'Queimadas', 'Queimadas', 'Vila Bela de Santo Antonio das Queimadas,Vila Bela de Santo Antônio das Queimadas', -10.9783300, -39.6263900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8131, 'Quatro Barras', 'Quatro Barras', '', -25.3655600, -49.0769400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8132, 'Quatis', 'Quatis', '', -22.4072200, -44.2580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8133, 'Quatá', 'Quata', '', -22.2475000, -50.6983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8134, 'Quaraí', 'Quarai', 'Kuarai,Kuarajus,Quarahy,kua la yi,kuraara''i,Куараи,কুৱারাই,夸拉伊', -30.3875000, -56.4513900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8135, 'Prudentópolis', 'Prudentopolis', '', -25.2130600, -50.9777800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8136, 'Propriá', 'Propria', '', -10.2111100, -36.8402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8137, 'Promissão', 'Promissao', '', -21.5366700, -49.8580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8138, 'Presidente Venceslau', 'Presidente Venceslau', 'Presidente Wenceslau,Presidente Wenceslaú', -21.8761100, -51.8438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8139, 'Presidente Prudente', 'Presidente Prudente', 'PPB,Prezidente Prudente,Prezidente Prudentė,Prezidenti-Prudenti,per sideng chi pru deng chi,presidente prudente,pu lu deng te zong tong cheng,Президенте Пруденте,Президенти-Пруденти,Презіденті-Пруденті,প্রেসিডেন্টে প্রুডেন্টে,เปรซีเดงชีปรูเดงชี,普鲁登特总统城', -22.1255600, -51.3888900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8140, 'Presidente Olegário', 'Presidente Olegario', 'Patos,Santa Rita de Patos,Santa Rita dos Patos', -18.4177800, -46.4180600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8141, 'Presidente Epitácio', 'Presidente Epitacio', 'Presidente Epistacio,Presidente Epitaclo,Presidente Epitãclo', -21.7633300, -52.1155600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8142, 'Presidente Bernardes', 'Presidente Bernardes', '', -22.0061100, -51.5530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8143, 'Prata', 'Prata', '', -19.3072200, -48.9241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8144, 'Praia Grande', 'Praia Grande', 'Praja Grande,Praja-Grandi,Prajja-Grandi,da pu la ya,pra''iya grande,Прайя-Гранди,Прая-Гранди,Прая-Гранді,Праја Гранде,প্রাইয়া গ্রান্ডে,大普拉亚', -24.0058300, -46.4027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8145, 'Pradópolis', 'Pradopolis', '', -21.3594400, -48.0655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8146, 'Prado', 'Prado', 'PDF', -17.3411100, -39.2208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8147, 'Poxoréo', 'Poxoreo', '', -15.8372200, -54.3891700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8148, 'Pouso Alegre', 'Pouso Alegre', 'PPY,Pozu-Alegri,Puzu Alegri,bo su a lai ge li,pa''uso alegre,po su xa lek ri,Позу-Алегри,Пузу Алегри,পাউসো আলেগ্রে,โปซูอาเลกรี,波苏阿莱格里', -22.2300000, -45.9363900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8149, 'Posse', 'Posse', '', -14.0930600, -46.3694400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8150, 'Porto União', 'Porto Uniao', 'Porto Unicao,Porto Unicão,Porto do Uniao,Pôrto do Uniao,Uniao,União', -26.2380600, -51.0783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8151, 'Porto Seguro', 'Porto Seguro', 'BPS,Portu-Seguru,bwrtw syjwrw,parto seguro,sai gu lu gang,Порту-Сегуру,بورتو سيجورو,পর্টো সেগুরো,პორტუ-სეგურუ,ポルト・セグーロ,塞古鲁港', -16.4497200, -39.0647200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8152, 'Porto Real do Colégio', 'Porto Real do Colegio', 'Porto Real do Collegio', -10.1858300, -36.8400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8153, 'Porto Real', 'Porto Real', '', -22.4197200, -44.2902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8154, 'Porto Murtinho', 'Porto Murtinho', '', -21.6988900, -57.8825000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8155, 'Porto Ferreira', 'Porto Ferreira', 'Porto Ferreiro,Portu-Ferrejra,Порту-Феррейра', -21.8538900, -47.4791700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8156, 'Porto Feliz', 'Porto Feliz', 'Portu-Felis,Порту-Фелис', -23.2147200, -47.5238900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8157, 'Porto Belo', 'Porto Belo', 'Porto Bello', -27.1577800, -48.5530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8158, 'Pôrto Barra do Ivinheima', 'Porto Barra do Ivinheima', '', -22.9666700, -53.6666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8159, 'Porto Alegre', 'Porto Alegre', 'Gorad Portu-Alegry,POA,Porto Alegre,Porto Alegri,Porto Alegrė,Porto Alenkre,Porto de Sao Francisco dos Casaes,Porto-Alegro,Portu-Alegre,Portu-Alegri,Portualegri,Portus Alacer,Puerto Alegre,Pôrto de São Francisco dos Casaes,a lei ge li gang,bwrtw alyghry,parto alegre,poleutuallegeuli,portu alegri,pwrtw algrh,Πόρτο Αλέγκρε,Горад Порту-Алегры,Порто Алегре,Порто Алегри,Порту-Алегре,Порту-Алегри,Порту-Алегрі,פורטו אלגרה,بورتو أليغري,پورتو الگره,پورتو الیگرے,पोर्तू अलेग्री,পর্টো আলেগ্রে,პორტუ-ალეგრი,ポルト・アレグレ,阿雷格里港,포르투알레그리', -30.0330600, -51.2300000, 'BR', '2011-01-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8160, 'Porteirinha', 'Porteirinha', '', -15.7433300, -43.0283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8161, 'Portão', 'Portao', '', -29.7016700, -51.2419400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8162, 'Porecatu', 'Porecatu', 'Brasilia,Brasília', -22.7558300, -51.3791700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8163, 'Porciúncula', 'Porciuncula', '', -20.9627800, -42.0408300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8164, 'Porangatu', 'Porangatu', 'Descoberto,Porangatu,Порангату', -13.4408300, -49.1486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8165, 'Porangaba', 'Porangaba', '', -23.1758300, -48.1250000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8166, 'Ponto Novo', 'Ponto Novo', 'Porto Novo,Pórto Novo', -10.8627800, -40.1336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8167, 'Pontes e Lacerda', 'Pontes e Lacerda', 'LCB,Ponte e Lacerda,Pontes Lacerda,Pontes de Lacerda', -15.2261100, -59.3352800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8168, 'Ponte Nova', 'Ponte Nova', '', -20.4163900, -42.9086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8169, 'Ponta Porã', 'Ponta Pora', 'PMG,Ponta Pora,Ponta Porã,Ponta-Poran,Punta Pora,Punta Porá,ponta pora,Понта-Поран,পোন্টা পোরা', -22.5361100, -55.7255600, 'BR', '2017-05-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8170, 'Pontalina', 'Pontalina', 'Santa Rita do Pontal', -17.5250000, -49.4472200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8171, 'Pontal', 'Pontal', '', -21.0225000, -48.0372200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8172, 'Ponta Grossa', 'Ponta Grossa', 'PGZ,Ponta Grosa,Ponta Grossa,Ponta-Grosa,peng ta ge luo sa,pon ta krx s sa,ponta grosasa,pwnta grwsa,Понта Гроса,Понта-Гроса,پونتا گروسا,পোন্টা গ্রোসসা,โปนตากรอสซา,蓬塔格羅薩', -25.0950000, -50.1619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8173, 'Pompéu', 'Pompeu', 'Concecao do Pompeo,Conceção do Pompeó,Pompeo,Pompéo', -19.2244400, -44.9352800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8174, 'Pompéia', 'Pompeia', '', -22.1086100, -50.1716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8175, 'Pomerode', 'Pomerode', 'Rio do Testo,Testo', -26.7405600, -49.1769400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8176, 'Poço Verde', 'Poco Verde', '', -10.7083300, -38.1833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8177, 'Poços de Caldas', 'Pocos de Caldas', 'POO,Poco Caldas,Pocos de Caldas,Posus-di-Kaldas,Poço Caldas,Poços de Caldas,bo su si-di ka er da si,pokosa de kaladasa,Посус-ди-Калдас,পোকোস ডে কালডাস,波苏斯－迪卡尔达斯', -21.7877800, -46.5613900, 'BR', '2017-03-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8178, 'Poconé', 'Pocone', 'Pecone,Peconé', -16.2566700, -56.6227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8179, 'Poções', 'Pocoes', 'Djalma Dutra', -14.5297200, -40.3652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8180, 'Poá', 'Poa', '', -23.5280600, -46.3447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8181, 'Planaltina', 'Planaltina', 'Alta Mir,Altamira,Planaltina', -15.4527800, -47.6141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8182, 'Piúma', 'Piuma', '', -20.8377800, -40.7219400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8183, 'Piuí', 'Piui', 'Piumhy', -20.4652800, -45.9580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8184, 'Pitangui', 'Pitangui', 'Pitanguy', -19.6827800, -44.8902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8185, 'Pitangueiras', 'Pitangueiras', '', -21.0094400, -48.2216700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8186, 'Pitanga', 'Pitanga', 'Pitanga,pi tan jia,pitanga,Питанга,পিটাঙ্গা,皮坦加', -24.7572200, -51.7613900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8187, 'Piritiba', 'Piritiba', 'Cinco Vargens', -11.7302800, -40.5552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8188, 'Pires do Rio', 'Pires do Rio', 'Pires-du-Riu,Пирес-ду-Риу', -17.2997200, -48.2794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8189, 'Pirenópolis', 'Pirenopolis', 'Meia Ponte,Pyrenopolis', -15.8507200, -48.9608700, 'BR', '2014-12-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8190, 'Piraquara', 'Piraquara', 'Piraguara', -25.4422700, -49.0679500, 'BR', '2014-08-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8191, 'Pirapozinho', 'Pirapozinho', '', -22.2752800, -51.5000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8192, 'Pirapora do Bom Jesus', 'Pirapora do Bom Jesus', 'Pirapora', -23.3969400, -47.0022200, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8193, 'Pirapora', 'Pirapora', 'Pirapora,pi la bo la,pirapora,Пирапора,পিরাপোরা,皮拉波拉', -17.3450000, -44.9419400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8194, 'Piranhas', 'Piranhas', '', -16.4269400, -51.8222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8195, 'Pirajuí', 'Pirajui', 'Pirajuhy', -21.9986100, -49.4572200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8196, 'Piraju', 'Piraju', '', -23.1936100, -49.3838900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8197, 'Piraí do Sul', 'Pirai do Sul', 'Pirahy,Pirai,Pirai-Mirim,Pirai-du-Sul,Piraí,Piraí-Mirim,nan pi la yi,pira''i do sula,Пираи-ду-Сул,পিরাই ডো সুল,南皮拉伊', -24.5261100, -49.9486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8198, 'Piraí', 'Pirai', 'Pirahy', -22.6291700, -43.8980600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8199, 'Pirassununga', 'Pirassununga', 'Pirassinunga,Pirassununga,Pirasununga,QPS,pi la su nong jia,pirasasununga,Пирасунунга,পিরাসসুনুঙ্গা,皮拉苏农加', -21.9961100, -47.4258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8200, 'Piracicaba', 'Piracicaba', 'Piracicaba,Pirasikaba,Pirasykava,QHB,pi la xi ka ba,pirasikaba,Пирасикаба,Пірасікаба,পিরাসিকাবা,皮拉西卡巴', -22.7252800, -47.6491700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8201, 'Piracanjuba', 'Piracanjuba', 'Pouso Alto', -17.3027800, -49.0166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8202, 'Piracaia', 'Piracaia', '', -23.0538900, -46.3580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8203, 'Piquete', 'Piquete', '', -22.6136100, -45.1761100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8204, 'Pinheiros', 'Pinheiros', '', -29.7833300, -52.7333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8205, 'Pinheiro Machado', 'Pinheiro Machado', 'Cacimbinhas', -31.5783300, -53.3811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8206, 'Pinheiral', 'Pinheiral', 'Pinheiro', -22.5127800, -44.0005600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8207, 'Pinhão', 'Pinhao', '', -25.6955600, -51.6597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8208, 'Espírito Santo do Pinhal', 'Espirito Santo do Pinhal', 'Espirito Santo do Pinhal', -22.1158300, -46.6827800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8209, 'Pindorama', 'Pindorama', '', -21.1858300, -48.9072200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8210, 'Pindobaçu', 'Pindobacu', 'Pindobassu,Pindobassú', -10.7416700, -40.3608300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8211, 'Pindamonhangaba', 'Pindamonhangaba', 'Pindamon''jangaba,Pindamonhangaba,pindamonahanagaba,ping da mo ni yang jia ba,Пиндамоньянгаба,পিন্ডামোনহানগাবা,平达莫尼扬加巴', -22.9238900, -45.4616700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8212, 'Pilar do Sul', 'Pilar do Sul', 'Pilar', -23.8130600, -47.7163900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8213, 'Piedade', 'Piedade', '', -23.7119400, -47.4277800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8214, 'Piaçabuçu', 'Piacabucu', 'Piassabussu', -10.4055600, -36.4344400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8215, 'Petrópolis', 'Petropolis', 'Petropolis,Petròpolis,Petrópolis,bi de luo bo li si,peteulopolliseu,petoroporisu,petropolisa,ptrwpwlys,Петрополис,Петрополіс,פטרופוליס,পেট্রোপোলিস,ペトロポリス,彼得罗波利斯,페트로폴리스', -22.5050000, -43.1786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8216, 'Petrolina de Goiás', 'Petrolina de Goias', 'Goialina,Petrolina', -16.0950000, -49.3380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8217, 'Peruíbe', 'Peruibe', 'Peruhybe,Peruibi,caraguava,pei lu yi bi,peru''ibe,Перуиби,পেরুইবে,佩鲁伊比', -24.3200000, -46.9983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8218, 'Pereira Barreto', 'Pereira Barreto', 'Novo Oriente', -20.6383300, -51.1091700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8219, 'Perdões', 'Perdoes', '', -21.0908300, -45.0913900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8220, 'Penha', 'Penha', 'Pen''ja,Penha de Itapocoroy,Пенья', -26.7694400, -48.6458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8221, 'Penedo', 'Penedo', 'Sao Francisco,São Francisco', -10.2902800, -36.5863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8222, 'Penápolis', 'Penapolis', 'Penapolis,Pennapolis,Пенаполис', -21.4197200, -50.0775000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8223, 'Pelotas', 'Pelotas', 'PET,Pelotas,Pelotasas,Sao Francisco de Paula,São Francisco de Paula,pei luo ta si,pellotaseu,pelotasa,Пелотас,পেলোটাস,佩洛塔斯,펠로타스', -31.7719400, -52.3425000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8224, 'Pedro Leopoldo', 'Pedro Leopoldo', '', -19.6180600, -44.0430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8225, 'Pedreira', 'Pedreira', 'Pedreiras,Pedrejra,Педрейра', -22.7419400, -46.9013900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8226, 'Pedregulho', 'Pedregulho', '', -20.2569400, -47.4766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8227, 'Pedra Azul', 'Pedra Azul', 'Fortaleza,Forteleza', -16.0052800, -41.2972200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8228, 'Pederneiras', 'Pederneiras', '', -22.3516700, -48.7750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8229, 'Peçanha', 'Pecanha', '', -18.5486100, -42.5569400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8230, 'Peabiru', 'Peabiru', '', -23.9127800, -52.3430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8231, 'Paulínia', 'Paulinia', 'Paulinia,Paulinija,Pauliniya,Paulinjo,Urbs Paulinia,bao li ni ya,bbawlysta,pa''ula''iniya,paurinia,paywlynya,Паулиния,Паулінія,פאוליניה,بباوليستا,پائولینیا,পাউলইনিয়া,パウリニア,保利尼亚', -22.7611100, -47.1541700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8232, 'Pau Brasil', 'Pau Brasil', '', -15.4641700, -39.6511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8233, 'Patrocínio', 'Patrocinio', 'Patrosiniu,pa te luo xi ni wu,patroka''ini''o,Патросиниу,পাট্রোকইনিও,帕特罗西尼乌', -18.9438900, -46.9925000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8234, 'Patos de Minas', 'Patos de Minas', 'POJ,Patos,Patos de Minas,Patus-di-Minas,pa tu si di mi na si,patosa de minasa,Патус-ди-Минас,পাটোস ডে মিনাস,帕图斯迪米纳斯', -18.5788900, -46.5180600, 'BR', '2017-03-25', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8235, 'Pato Branco', 'Pato Branco', 'PTO,Pato Branco,Patu-Branku,pa tu bu lan ku,pato branko,Пату-Бранку,পাটো ব্রাঙ্কো,帕图布兰库', -26.2286100, -52.6705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8236, 'Paty do Alferes', 'Paty do Alferes', 'Pati-du-Alferis,Paty do Alferas,Пати-ду-Алферис', -22.4286100, -43.4186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8237, 'Passos', 'Passos', 'PSW,Passos,Pasus,pa su si,pasasosa,Пассос,Пасус,পাসসোস,帕苏斯', -20.7188900, -46.6097200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8238, 'Passo Fundo', 'Passo Fundo', 'PFB,Passo Fundo,Pasu-Fundu,pa su feng du,pas su fun du,pasaso phunado,Пасу-Фунду,পাসসো ফুনডো,ปาสซูฟูนดู,帕苏丰杜', -28.2627800, -52.4066700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8239, 'Passa Quatro', 'Passa Quatro', 'Pasa Kuatro,Pasa-Kuatru,Passa-Quatro,Passo Quatro,pa sa kua te lu,pasasa kuraatro,Паса Куатро,Паса-Куатру,পাসসা কুৱাট্রো,パッサ・クアトロ,帕萨夸特鲁', -22.3902800, -44.9666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8240, 'Parobé', 'Parobe', '', -29.6286100, -50.8347200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8241, 'Pariquera Açu', 'Pariquera Acu', 'Pariquera Assu,Pariquera Assú,Pariqueracu,Pariqueraçu', -24.7150000, -47.8811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8242, 'Paripiranga', 'Paripiranga', 'Malhada Vermelha,Patrocinio do Coite,Patrocinio do Coité', -10.6875000, -37.8616700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8243, 'Paraúna', 'Parauna', '', -16.9477800, -50.4486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8244, 'Paratinga', 'Paratinga', 'Rio Branco', -12.6905600, -43.1841700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8245, 'Paraty', 'Paraty', 'Paraty', -23.2177800, -44.7130600, 'BR', '2014-01-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8246, 'Paranhos', 'Paranhos', '', -23.8927800, -55.4311100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8247, 'Paranavaí', 'Paranavai', 'Fazenda Ivai,Fazenda Ivaí,PVI,Paranvai,Paranvaí', -23.0730600, -52.4652800, 'BR', '2017-07-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8248, 'Paranapanema', 'Paranapanema', 'Bom Successo,Bom Sucesso', -23.3863000, -48.7244100, 'BR', '2014-06-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8249, 'Paranaíba', 'Paranaiba', 'Paranaiba,Sant''Anna do Paranahyba,Sant''Anna do Paranaiba,Santa Ana do Paranaiba,Santana do Paranaiba,Santana do Paranaíba,parana''iba,Паранаиба,পারানাইবা', -19.6772200, -51.1908300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8250, 'Paranaguá', 'Paranagua', 'PNG,Paranagua,Paranaguá,Paranankoua,ba la na gua,paranagu''a,paranagua,Παραναγκουά,Паранагуа,পারানাগুআ,パラナグア,巴拉那瓜', -25.5162600, -48.5253700, 'BR', '2014-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8251, 'Paramirim', 'Paramirim', '', -13.4425000, -42.2388900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8252, 'Paraisópolis', 'Paraisopolis', '', -22.5541700, -45.7800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8253, 'Paraíso', 'Paraiso', '', -21.0163900, -48.7736100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8254, 'Paraíso das Águas', 'Paraiso das Aguas', 'Paraiso das Aguas,Paraíso das Águas', -19.0175000, -53.0122200, 'BR', '2014-03-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8255, 'Paraíba do Sul', 'Paraiba do Sul', 'Parahyba do Sul,Paraiba-du-Sul,Параиба-ду-Сул', -22.1584700, -43.2932100, 'BR', '2014-12-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8256, 'Paraguaçu Paulista', 'Paraguacu Paulista', 'Araguacu,Araguaçu,Paraguacu,Paraguassu,Paraguassú,Paraguaçu', -22.4127800, -50.5758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8257, 'Paraguaçu', 'Paraguacu', 'Paraguassu,Paraguassú', -21.5472200, -45.7375000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8258, 'Pará de Minas', 'Para de Minas', 'Para,Para-di-Minas,Pará,pa la di mi na si,para de minasa,Пара-ди-Минас,পারা ডে মিনাস,パラ・デ・ミナス,帕拉迪米纳斯', -19.8602800, -44.6083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8259, 'Paracatu', 'Paracatu', 'Parakatu,pa la ka tu,parakatu,Паракату,পারাকাটু,帕拉卡图', -17.2222200, -46.8747200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8260, 'Paracambi', 'Paracambi', 'Paracambi,Paracamby', -22.6082900, -43.7084000, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8261, 'Papagaios', 'Papagaios', '', -19.4491700, -44.7477800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8262, 'Pantano do Sul', 'Pantano do Sul', '', -27.7797200, -48.5086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8263, 'Panorama', 'Panorama', '', -21.3563900, -51.8597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8264, 'Pancas', 'Pancas', 'Santa Luzia', -19.2250000, -40.8513900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8265, 'Panambi', 'Panambi', 'Pindorama,Tabapira', -28.2925000, -53.5016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8266, 'Palotina', 'Palotina', '', -24.2838900, -53.8400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8267, 'Palmital', 'Palmital', '', -22.7888900, -50.2175000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8268, 'Palmeiras de Goiás', 'Palmeiras de Goias', 'Freire Alemao,Freire Alemão,Matauna,Mataúna,Palmeira de Goias,Palmeira de Goiás,Palmeiras', -16.8050000, -49.9258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8269, 'Palmeira das Missões', 'Palmeira das Missoes', 'Palmeira', -27.8994400, -53.3136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8270, 'Palmeira', 'Palmeira', 'Palmejra,pa er mei la,Палмейра,帕尔梅拉', -25.4294400, -50.0063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8271, 'Palmas de Monte Alto', 'Palmas de Monte Alto', 'Monte Alto', -14.2672200, -43.1619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8272, 'Palmas', 'Palmas', 'Pal''mas,Palmas,pa er ma si,parumasu,paumaseu,Палмас,Пальмас,パルマス,帕尔马斯,파우마스', -26.4841700, -51.9905600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8273, 'Palmares do Sul', 'Palmares do Sul', 'Emilio Meier,Emilio Meyer,Emílio Meyer,Emílio Méier,Juruma,Palmares', -30.2577800, -50.5097200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8274, 'Palhoça', 'Palhoca', 'Pal''osa,pa e sa,palahoka,Пальоса,পালহোকা,帕略萨', -27.6452800, -48.6677800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8275, 'Paiçandu', 'Paicandu', 'Paissandu', -23.4575000, -52.0486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8276, 'Padre Paraíso', 'Padre Paraiso', '', -17.0741700, -41.4844400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8277, 'Padre Bernardo', 'Padre Bernardo', 'Barroca,Padre Bernardo', -15.1659500, -48.2828100, 'BR', '2013-03-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8278, 'Pacatuba', 'Pacatuba', 'Pacatiba', -10.4533300, -36.6513900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8279, 'Pacaembu', 'Pacaembu', 'Guaraniuva,Guaraniúva', -21.5622200, -51.2605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8280, 'Ouro Preto', 'Ouro Preto', 'Oro Pretas,Oro Preto,Oru-Pretu,Ouro Preto,auro preto,olupeuletu,ou lu pu lei tu,xo ru per tu,Оро Прето,Ору-Прету,אורו פרטו,ঔরো প্রেটো,โอรูเปรตู,ორუ-პრეტუ,オウロ・プレット,欧鲁普雷图,오루프레투', -20.3948400, -43.5051700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8281, 'Ouro Branco', 'Ouro Branco', '', -20.5233400, -43.6948600, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8282, 'Ourinhos', 'Ourinhos', 'OUS,Orin''jus,Ourinhos,Urbs Parvauratana,aurinahosa,ou li ni ao si,Ориньюс,ঔরিনহোস,欧里尼奥斯', -22.9788900, -49.8705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8283, 'Otacílio Costa', 'Otacilio Costa', '', -27.4830600, -50.1219400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8284, 'Osvaldo Cruz', 'Osvaldo Cruz', '', -21.7966700, -50.8786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8285, 'Osório', 'Osorio', 'Conceicao do Arroio,Conceicao do Arrolo,Conceição do Arroio,Osorio,Ozoriu,ao suo li wu,osori''o,Озориу,Осорио,ওসোরিও,奥索里乌', -29.8866700, -50.2697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8286, 'Osasco', 'Osasco', 'Osasku,QOC,Осаску', -23.5325000, -46.7916700, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8287, 'Ortigueira', 'Ortigueira', 'Ortigeira,Queimadas,Urtigueira', -24.2083300, -50.9494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8288, 'Orleans', 'Orleans', 'Orleans,Orleans do Sul', -28.3588900, -49.2913900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8289, 'Orlândia', 'Orlandia', '', -20.7202800, -47.8866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8290, 'Orizona', 'Orizona', 'Arizona,Campo Formosa,Campo Formoso', -17.0313900, -48.2958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8291, 'Oliveira dos Brejinhos', 'Oliveira dos Brejinhos', 'Oliveira do Brejinho', -12.3169400, -42.8961100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8292, 'Oliveira', 'Oliveira', 'Olivejra,Olivera,ao li wei la,olibhe''ira,Оливейра,ওলিভেইরা,奥利韦拉', -20.6963900, -44.8272200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8293, 'Olindina', 'Olindina', 'Mucambo,Nova Olinda', -11.3666700, -38.3333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8294, 'Olímpia', 'Olimpia', 'Olimpija,Olympia,Олимпия', -20.7372200, -48.9147200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8295, 'Nuporanga', 'Nuporanga', '', -20.7309500, -47.7517700, 'BR', '2013-11-06', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8296, 'Novo Horizonte', 'Novo Horizonte', '', -21.4680600, -49.2208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8297, 'Novo Hamburgo', 'Novo Hamburgo', 'Novo Amburgo,Novo Hamburg,Novo Hamburgo,Novu-Amburgu,Potiguara,QHV,nobho hamaburgo,nobuambuleugu,nowu xam bur ku,xin han bao,Ново Амбурго,Нову-Амбургу,নোভো হামবুর্গো,โนวูอัมบูร์กู,ノヴォ・アンブルゴ,新漢堡,노부암부르구', -29.6783300, -51.1305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8298, 'Novo Cruzeiro', 'Novo Cruzeiro', 'Gravata', -17.4680600, -41.8752800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8299, 'Nova Viçosa', 'Nova Vicosa', 'Maroba,Marobá,Vicosa,Viçosa', -17.8919400, -39.3719400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8300, 'Nova Venécia', 'Nova Venecia', '', -18.7105600, -40.4005600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8301, 'Nova Soure', 'Nova Soure', 'Natuba,Soure', -11.2333300, -38.4833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8302, 'Nova Prata', 'Nova Prata', 'Caibate,Prata', -28.7838900, -51.6100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8303, 'Nova Petrópolis', 'Nova Petropolis', '', -29.3763900, -51.1144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8304, 'Nova Olímpia', 'Nova Olimpia', '', -14.7972200, -57.2880600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8305, 'Nova Odessa', 'Nova Odessa', '', -22.7775000, -47.2958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8306, 'Nova Londrina', 'Nova Londrina', '', -22.7658300, -52.9850000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8307, 'Nova Lima', 'Nova Lima', 'Nova Lima,Nova-Lima,Нова-Лима', -19.9855600, -43.8466700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8308, 'Nova Iguaçu', 'Nova Iguacu', 'Nova Iguacu,Nova Iguassu,Nova Iguassú,Nova Iguasu,Nova Iguaçu,Nova Iguaçú,Nova-Iguasu,nobaiguasu,nobha iguraaku,nova-iguasu,novha igvasu,xin yi gua su,Нова Игуасу,Нова-Ігуасу,Нова-Игуасу,नोव्हा इग्वासु,নোভা ইগুৱাকু,ნოვა-იგუასუ,ノヴァ・イグアス,新伊瓜蘇,노바이구아수', -22.7591700, -43.4511100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8309, 'Nova Granada', 'Nova Granada', 'Novo Granaoa', -20.5338900, -49.3141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8310, 'Nova Friburgo', 'Nova Friburgo', 'Nova Friburgo,Nova-Friburgu,Nueva Friburgo,QGJ,nobha phriburgo,xin fu li bao,Нова Фрибурго,Нова-Фрибургу,নোভা ফ্রিবুর্গো,新弗里堡', -22.2819400, -42.5311100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8311, 'Nova Era', 'Nova Era', 'Presidente Vargas,Sao Jose da Lagoa,São José da Lagôa', -19.7500000, -43.0375000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8312, 'Nova Aurora', 'Nova Aurora', '', -22.8666700, -52.5666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8313, 'Nossa Senhora do Socorro', 'Nossa Senhora do Socorro', 'Contiguiba,Cotinguiba,Cotingüiba,Soccorro,Socorro', -10.8550000, -37.1261100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8314, 'Nossa Senhora das Dores', 'Nossa Senhora das Dores', '', -10.4916700, -37.1933300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8315, 'Nossa Senhora da Glória', 'Nossa Senhora da Gloria', '', -10.2183300, -37.4202800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8316, 'Nortelândia', 'Nortelandia', '', -14.4547200, -56.8027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8317, 'Nobres', 'Nobres', 'Bananal Nobre', -14.7202800, -56.3275000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8318, 'Niterói', 'Niteroi', 'Nictheroi,Nictheroy,Niteroi,Niteroj,Niterói,Vila Real da Praia Grande,Villa Real da Praia Grande,niteroi,Нитерой,ニテロイ', -22.8833300, -43.1036100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8319, 'Niquelândia', 'Niquelandia', 'Nikelandija,Sao Jose De Tocantins,Sao Jose do Tocantins,São José do Tocantins,Никеландия', -14.4738900, -48.4597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8320, 'Nilópolis', 'Nilopolis', 'Nilopolis,ni luo bo li si,nilopolisa,Нилополис,নিলোপোলিস,尼洛波利斯', -22.8075000, -43.4138900, 'BR', '2013-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8321, 'Nhandeara', 'Nhandeara', '', -20.6897000, -50.0407000, 'BR', '2015-07-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8322, 'Nerópolis', 'Neropolis', 'Neropolis,Нерополис', -16.4063900, -49.2186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8323, 'Nepomuceno', 'Nepomuceno', '', -21.2334200, -45.2348800, 'BR', '2015-06-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8324, 'Neópolis', 'Neopolis', 'Vila Nova,Villa Nova', -10.3200000, -36.5794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8325, 'Nazaré', 'Nazare', 'Nazar,Nazare das Farinhas,Nazareth,Nazaré das Farinhas,Назар', -13.0350000, -39.0144400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8326, 'Naviraí', 'Navirai', 'Navirai,Porto Luiza,Pôrto Luiza,nabhira''i,Навираи,নাভিরাই', -23.0650000, -54.1905600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8327, 'Navegantes', 'Navegantes', 'NVT,Navegantis,Навегантис', -26.8988900, -48.6541700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8328, 'Natividade', 'Natividade', 'Natividade', -21.0422200, -41.9733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8329, 'Não Me Toque', 'Nao Me Toque', 'Nao Me Toques,Não Me Toques', -28.4591700, -52.8208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8330, 'Nanuque', 'Nanuque', 'Indiana,NNU', -17.8391700, -40.3538900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8331, 'Muzambinho', 'Muzambinho', '', -21.3758300, -46.5255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8332, 'Mutum', 'Mutum', 'Sao Manoel do Mutum,Sao Manoel du Mutum,Sao Manuel do Mutum,São Manoel do Mutum', -19.8000000, -41.4383300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8333, 'Mutuípe', 'Mutuipe', '', -13.2286100, -39.5047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8334, 'Muritiba', 'Muritiba', '', -12.9166700, -39.2500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8335, 'Muriaé', 'Muriae', 'Muriae,Muriaeh,Muriahe,Muriahé,Muriaé,Murihe,Murriae,mu li ya ai,muriyaye,Муриаэ,মুরিয়ায়ে,มูเรียแอ,穆里亚埃', -21.1305600, -42.3663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8336, 'Muniz Freire', 'Muniz Freire', '', -20.4641700, -41.4130600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8337, 'Mundo Novo', 'Mundo Novo', '', -11.8588900, -40.4725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8338, 'Mucurici', 'Mucurici', 'Alto Itauna,Alto Itaunas,Alto Itaúna,Alto Itaúnas', -18.0933300, -40.5158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8339, 'Mucuri', 'Mucuri', 'Mucury,Mukuri,Porto Alegre,Мукури', -18.0863900, -39.5508300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8340, 'Mozarlândia', 'Mozarlandia', 'Mozarlandia,Mozarlândia', -14.7447200, -50.5705600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8341, 'Morro do Chapéu', 'Morro do Chapeu', 'Morro de Chapeo,Morro do Chapeo,Morro do Chapéo', -11.5485200, -41.1580400, 'BR', '2014-06-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8342, 'Morro da Fumaça', 'Morro da Fumaca', '', -28.6508300, -49.2100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8343, 'Morro Agudo', 'Morro Agudo', '', -20.7313900, -48.0577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8344, 'Morrinhos', 'Morrinhos', '', -17.7311100, -49.0994400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8345, 'Moreira Sales', 'Moreira Sales', '', -24.0622200, -53.0069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8346, 'Monte Sião', 'Monte Siao', '', -22.4325000, -46.5725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8347, 'Montes Claros', 'Montes Claros', 'MOC,Montes Klaros,Montis Klaros,Montis-Klarus,meng di si ke la lu si,monatesa kalarosa,Монтес Кларос,Монтис Кларос,Монтис-Кларус,মোনটেস কলারোস,蒙蒂斯克拉鲁斯', -16.7350000, -43.8616700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8348, 'Monte Santo de Minas', 'Monte Santo de Minas', 'Monsanto,Monte Santo', -21.1897200, -46.9802800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8349, 'Monte Santo', 'Monte Santo', 'Monti Santu,Monti-Santu,monte santo,sheng shan zhen,Монти-Санту,Մոնտի Սանտու,মোন্টে সান্টো,მონტი-სანტუ,圣山镇', -10.4377800, -39.3327800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8350, 'Montenegro', 'Montenegro', 'Chernogorija,Montenegru,Sao Joao do Monte Negro,São João do Monte Negro,meng te nei ge lu,Монтенегру,Черногория,蒙特内格鲁', -29.6886100, -51.4611100, 'BR', '2012-07-29', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8351, 'Monte Mor', 'Monte Mor', '', -22.9466700, -47.3158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8352, 'Monte Carmelo', 'Monte Carmelo', 'Monte Carmello', -18.7247200, -47.4986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8353, 'Monte Azul Paulista', 'Monte Azul Paulista', 'Monte Azul,Monte Azul do Turvo', -20.9072200, -48.6413900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8354, 'Monte Azul', 'Monte Azul', 'Boa Vista do Tremendal,Tremedal', -15.1550000, -42.8747200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8355, 'Monte Aprazível', 'Monte Aprazivel', '', -20.7725000, -49.7141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8356, 'Monte Alto', 'Monte Alto', 'Mons Altus,Monti-Altu,meng di a er tu,monte alto,Монти-Алту,মোন্টে আল্টো,蒙蒂阿尔图', -21.2611100, -48.4963900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8357, 'Monte Alegre de Sergipe', 'Monte Alegre de Sergipe', 'Monte Alegre', -10.0272200, -37.5622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8358, 'Monte Alegre de Minas', 'Monte Alegre de Minas', 'Monte Alegre,Toribate,Toribatê', -18.8705600, -48.8808300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8359, 'Montanha', 'Montanha', 'Comercinho de Palha,Montana,Santo Antonio da Montanha,Santo Antônio da Montanha', -18.1269400, -40.3633300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8360, 'Mongaguá', 'Mongagua', '', -24.0930600, -46.6208300, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8361, 'Moita Bonita', 'Moita Bonita', '', -10.5775000, -37.3427800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8362, 'Mogi Mirim', 'Mogi Mirim', 'Mogi-Mirim,Mogy-Mirim,Moji-Mirim,Mozhi-Mirin,mo ji mi lin,moji-mirima,Можи-Мирин,মোজি-মিরিম,莫吉米林', -22.4319400, -46.9577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8363, 'Mogi Guaçu', 'Mogi Guacu', 'Mogi-Guacu,Mogi-Guaçu,Mogy Guassu,Mogy Guassú,Moji-Guacu,Moji-Guaçu,Mozhi-Guasu,mo ji gua su,mogi guraaku,Можи-Гуасу,মোগি গুৱাকু,莫吉瓜苏', -22.3677000, -46.9455200, 'BR', '2016-11-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8364, 'Mogi das Cruzes', 'Mogi das Cruzes', 'Mogy das Cruzes,Moji das Cruzes', -23.5227800, -46.1883300, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8365, 'Mococa', 'Mococa', 'QOA', -21.4677800, -47.0047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8366, 'Mirante do Paranapanema', 'Mirante do Paranapanema', '', -22.2919400, -51.9063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8367, 'Mirandopólis', 'Mirandopolis', 'Comandante Arbues,Mirandopolis,Мирандополис', -21.1336100, -51.1016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8368, 'Miranda', 'Miranda', 'Miranda,mi lan da,miranda,Миранда,Միրանդա,মিরান্ডা,მირანდა,米蘭達', -20.2405600, -56.3783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8369, 'Miraí', 'Mirai', 'Mirahy', -21.1952800, -42.6141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8370, 'Miracema', 'Miracema', 'Mirasema,Мирасема', -21.4122200, -42.1966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8371, 'Miracatu', 'Miracatu', 'Prainha', -24.2813900, -47.4597200, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8372, 'Mirabela', 'Mirabela', 'Bela Vista,Bella Vista', -16.2627800, -44.1644400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8373, 'Mineiros', 'Mineiros', '', -17.5694400, -52.5511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8374, 'Minas Novas', 'Minas Novas', '', -17.2186100, -42.5902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8375, 'Mimoso do Sul', 'Mimoso do Sul', 'Joao Pessoa,João Pessoa,Mimoso,Mimozu du Sul,Mimozu-du-Sul,mimoso do sula,mimozu-du-suli,nan mi mo su,Мимозу-ду-Сул,Միմոզու դու Սուլ,মিমোসো ডো সুল,მიმოზუ-დუ-სული,南米莫蘇', -21.0641700, -41.3663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8376, 'Miguel Pereira', 'Miguel Pereira', '', -22.4538900, -43.4688900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8377, 'Miguelópolis', 'Miguelopolis', '', -20.1794400, -48.0319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8378, 'Miguel Calmon', 'Miguel Calmon', 'Djalma Dutra', -11.4288900, -40.5950000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8379, 'Mendes', 'Mendes', '', -22.5266700, -43.7327800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8380, 'Medina', 'Medina', 'Santa Rita do Itinga,Santa Rita do Medina', -16.2225000, -41.4769400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8381, 'Medianeira', 'Medianeira', 'Medianejra,Nova Santa Medianeira,Медианейра', -25.2952800, -54.0938900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8382, 'Medeiros Neto', 'Medeiros Neto', '', -17.3738900, -40.2205600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8383, 'Mauá', 'Maua', 'Maua,mao a,maraa,Мауа,মাৱা,毛阿', -23.6677800, -46.4613900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8384, 'Matozinhos', 'Matozinhos', 'Mattosinhos', -19.5577800, -44.0813900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8385, 'Mato Verde', 'Mato Verde', 'Matto Verde', -15.3972200, -42.8663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8386, 'Matipó', 'Matipo', 'Sao Joao do Matipo,São João do Matipo', -20.2838900, -42.3411100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8387, 'Matias Barbosa', 'Matias Barbosa', 'Mathias Barbosa', -21.8691700, -43.3194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8388, 'Mateus Leme', 'Mateus Leme', 'Matheus Leme', -19.9863900, -44.4277800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8389, 'Matelândia', 'Matelandia', 'Metelandia,Metelândia', -25.2408300, -53.9963900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8390, 'Matão', 'Matao', 'Mattao,Mattão', -21.6033300, -48.3658300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8391, 'Mata de São João', 'Mata de Sao Joao', 'Mata-de-San-Zhuan,Matta de Sao Joao,Matta de São João,Мата-де-Сан-Жуан', -12.5302800, -38.2991700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8392, 'Mascote', 'Mascote', '', -15.5630600, -39.3025000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8393, 'Maruim', 'Maruim', 'Mariom,Maroim', -10.7375000, -37.0816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8394, 'Martinópolis', 'Martinopolis', 'Jose Teodoro,Jose Theodoro,José Teodoro,José Theodoro', -22.1458300, -51.1708300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8395, 'Martinho Campos', 'Martinho Campos', 'Abadia de Pitangui,Abadia de Pitanguí,Abadia do Pitangui,Abadia do Pitanguí,Abbadia', -19.3316700, -45.2369400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8396, 'Maringá', 'Maringa', 'MGF,Maringa,Maringá,ma lin jia,maling-ga,marinaga,maringa,Маринга,মারিনগা,マリンガ,馬林加,마링가', -23.4252800, -51.9386100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8397, 'Marília', 'Marilia', 'MII,Maril''ja,Marilia,Marilija,Marília,ma li li ya,mariliya,Марилия,Марилија,Марилья,মারিলিয়া,馬里利亞', -22.2138900, -49.9458300, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8398, 'Marilândia', 'Marilandia', '', -19.4127800, -40.5416700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8399, 'Maricá', 'Marica', '', -22.9194400, -42.8186100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8400, 'Mariana', 'Mariana', 'Mariana,Marianna,Marijana,ma li ya na,mariyana,Мариана,Маријана,মারিয়ানা,馬里亞納', -20.3777800, -43.4161100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8401, 'Marialva', 'Marialva', '', -23.4850000, -51.7916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8402, 'Marechal Floriano', 'Marechal Floriano', '', -20.4127800, -40.6830600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8403, 'Marechal Cândido Rondon', 'Marechal Candido Rondon', 'General Rondon', -24.5561100, -54.0566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8404, 'Mar de Espanha', 'Mar de Espanha', 'Mar d''Hespanha,Mar de Hespanha', -21.8672200, -43.0097200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8405, 'Marau', 'Marau', '', -28.4491700, -52.2000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8406, 'Maraú', 'Marau', 'Marahu,Marahú', -14.1039500, -39.0149000, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8407, 'Marataizes', 'Marataizes', '', -21.0433300, -40.8244400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8408, 'Maragogipe', 'Maragogipe', 'Maragojipe', -12.7777800, -38.9194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8409, 'Maracás', 'Maracas', '', -13.4411100, -40.4308300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8410, 'Maracaju', 'Maracaju', 'Maracaju,Maracajú,Marakazhu,Marakazu,ma la ka ru,marakaju,Маракажу,Մարակաժու,মারাকাজু,მარაკაჟუ,馬拉卡茹', -21.6144400, -55.1683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8411, 'Maracaí', 'Maracai', 'Maracahy', -22.6105600, -50.6672200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8412, 'Mantenópolis', 'Mantenopolis', 'Ametista,Manteninha', -18.8625000, -41.1227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8413, 'Manhumirim', 'Manhumirim', '', -20.3577800, -41.9580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8414, 'Manhuaçu', 'Manhuacu', 'Man''juasu,Manhuassu,Manhuassú,ma niu a su,manahoyaku,Маньюасу,মানহোয়াকু,马纽阿苏', -20.2580600, -42.0336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8415, 'Mangaratiba', 'Mangaratiba', 'Mangalatiba,Mangaratiba,man jia la di ba,mangaratiba,Мангаратиба,মাঙ্গারাটিবা,曼加拉蒂巴', -22.9597200, -44.0405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8416, 'Manga', 'Manga', '', -14.7558300, -43.9322200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8417, 'Mandaguari', 'Mandaguari', 'Lovat', -23.5475000, -51.6708300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8418, 'Mandaguaçu', 'Mandaguacu', 'Vila Guaira', -23.3472200, -52.0952800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8419, 'Malhador', 'Malhador', '', -10.6577800, -37.3047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8420, 'Malacacheta', 'Malacacheta', '', -17.8422200, -42.0766700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8421, 'Mairiporã', 'Mairipora', 'Mairipora,Mairiporã,Majriporan,QMC,Майрипоран', -23.3186100, -46.5866700, 'BR', '2013-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8422, 'Mairinque', 'Mairinque', 'Majrinki,Mayrink,Майринки', -23.5458300, -47.1833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8423, 'Mairi', 'Mairi', 'Majri,Mayri,Monte Alegre,ma''iri,mai li,mairi,Майри,Մայրի,মাইরি,მაირი,迈里', -11.7113900, -40.1488900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8424, 'Mafra', 'Mafra', 'Mafra,Mafre,QMF,Villa de Mafra,ma fu la,maphra,Мафра,Мафре,মাফ্রা,马夫拉', -26.1113900, -49.8052800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8425, 'Madre de Deus', 'Madre de Deus', 'Suape', -12.7408300, -38.6208300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8426, 'Machado', 'Machado', '', -21.6747200, -45.9197200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8427, 'Macaúbas', 'Macaubas', 'Macahubas', -13.0194400, -42.6986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8428, 'Macatuba', 'Macatuba', 'Bocaiuva,Bocayuva', -22.5022200, -48.7113900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8429, 'Macaé', 'Macae', 'MEA,Macae,Macahe,Macahé,Macaé,Makae,Makaeh,ma ka ai,makaye,Макае,Макаэ,মাকায়ে,马卡埃', -22.3848400, -41.7832400, 'BR', '2017-05-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8430, 'Luziânia', 'Luziania', 'Luzilandia,Luzilândia,Santa-Luzia', -16.2525000, -47.9502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8431, 'Luz', 'Luz', 'Nossa Senhora da Luz do Aterrado', -19.8013900, -45.6855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8432, 'Lucélia', 'Lucelia', '', -21.7202800, -51.0188900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8433, 'Lucas', 'Lucas', 'Flexas,Lucas,Lukas,Лукас', -16.3333300, -55.9333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8434, 'Louveira', 'Louveira', '', -23.0863900, -46.9505600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8435, 'Lorena', 'Lorena', 'Lorena,lorena,luo lei na,Лорена,লোরেনা,洛雷纳', -22.7308300, -45.1247200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8436, 'Londrina', 'Londrina', 'LDB,Londrina,londeulina,londrina,long de li na,lwndryna,rondorina,Лондрина,لوندرينا,لوندرینا,লোন্ড্রিনা,ロンドリーナ,隆德里納,론드리나', -23.3102800, -51.1627800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8437, 'Loanda', 'Loanda', 'Luanda', -22.9230600, -53.1372200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8438, 'Livramento do Brumado', 'Livramento do Brumado', 'Liveramento do Brumado,Livramento,Villa Velha', -13.6514500, -41.8456400, 'BR', '2015-06-19', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8439, 'Lins', 'Lins', 'Albuquerque Lins,LIP,Lins,lin si,lingseu,linsa,rinsu,Линс,লিন্স,リンス,林斯,링스', -21.6786100, -49.7425000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8440, 'Linhares', 'Linhares', 'Lin''jaris,linaharesa,Линьярис,লিনহারেস', -19.3911100, -40.0722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8441, 'Limeira', 'Limeira', 'Limeira,Limejra,QGB,li mei la,li mey ra,limaye''ira,Лимеира,Лимейра,লিময়েইরা,ลีเมย์รา,利梅拉', -22.5647200, -47.4016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8442, 'Lima Duarte', 'Lima Duarte', 'Lima-Duarti,li ma du a di,lima duyarte,Лима-Дуарти,লিমা ডুয়ার্টে,利马杜阿蒂', -21.8425000, -43.7930600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8443, 'Leopoldina', 'Leopoldina', 'LEP', -21.5319400, -42.6430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8444, 'Lençóis Paulista', 'Lencois Paulista', 'Lencoes,Lencois,Lençoes,Lençóis,Ubirama', -22.5986100, -48.8002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8445, 'Leme', 'Leme', 'Lem,Leme,Lemi,lai mi,leme,Лем,Леми,লেমে,莱米', -22.1855600, -47.3902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8446, 'Lavras', 'Lavras', 'Lavras,la fu la si,labhrasa,lfras,Лаврас,لفراس,লাভ্রাস,拉夫拉斯', -21.2452800, -44.9997200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8447, 'Lauro Muller', 'Lauro Muller', 'Louro Muller,Louro Müller', -28.3927800, -49.3966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8448, 'Laranjeiras do Sul', 'Laranjeiras do Sul', 'Iguacu,Iguassu,Iguassú,Iguaçu,Laranginha,Laranjeiras', -25.4077800, -52.4161100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8449, 'Laranjeiras', 'Laranjeiras', 'Larangeiras', -10.8063900, -37.1700000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8450, 'Laranjal Paulista', 'Laranjal Paulista', 'Laranjal', -23.0497200, -47.8366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8451, 'Laranja da Terra', 'Laranja da Terra', '', -19.8988900, -41.0566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8452, 'Lapão', 'Lapao', '', -11.3833300, -41.8319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8453, 'Lapa', 'Lapa', 'Lapa,la pa,lapa  parana,Лапа,لاپا، پارانا,拉帕', -25.7697200, -49.7158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8454, 'Lambari', 'Lambari', 'Lambary', -21.9755600, -45.3502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8455, 'Lajinha', 'Lajinha', 'Laginha', -20.1513900, -41.6227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8456, 'Lages', 'Lages', 'LAJ,Lages,Lajes,Lazesas,Lazhis,Laĵes,Lažesas,la re si,lagesa,Лажис,লাগেস,拉热斯', -27.8161100, -50.3261100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8457, 'Lajeado', 'Lajeado', 'Costao,Costão,Lageado,Lazheadu,la re a du,laje''ado,Лажеаду,লাজেআডো,拉热阿杜', -29.4669400, -51.9613900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8458, 'Laje', 'Laje', 'Abreus,Lage,Laje', -10.1870800, -40.9707600, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8459, 'Laguna', 'Laguna', 'Laguna,la gu na,laguna,lagwna,Лагуна,لاگونا,লাগুনা,拉古纳', -28.4825000, -48.7808300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8460, 'Lagoa Vermelha', 'Lagoa Vermelha', 'Lagoa-Vermel''ja,la ge a wei mei li ya,lagoya bhermelaha,Лагоа-Вермелья,লাগোয়া ভের্মেলহা,拉戈阿韦梅利亚', -28.2086100, -51.5258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8461, 'Lagoa Santa', 'Lagoa Santa', 'Lagoa-Santa,lagoya santa,sheng hu zhen,Лагоа-Санта,লাগোয়া সান্টা,ლაგოა-სანტა,聖湖鎮', -19.6300600, -43.9009000, 'BR', '2014-12-25', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8462, 'Lagoa Formosa', 'Lagoa Formosa', '', -18.7786100, -46.4075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8463, 'Lagoa da Prata', 'Lagoa da Prata', '', -20.0225000, -45.5436100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8464, 'Lagoa', 'Lagoa', '', -27.6049100, -48.4671300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8465, 'Lagarto', 'Lagarto', '', -10.9172200, -37.6500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8466, 'Ladário', 'Ladario', '', -19.0047200, -57.6016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8467, 'Juquitiba', 'Juquitiba', 'Jacuitiba,Jucuitiba', -23.9316700, -47.0683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8468, 'Juquiá', 'Juquia', 'Santo Antonio de Juquia,Santo António de Juquia', -24.3208300, -47.6347200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8469, 'Junqueirópolis', 'Junqueiropolis', '', -21.5147200, -51.4336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8470, 'Jundiaí', 'Jundiai', 'Jundiahy,Jundiai,Jundiaí,Jurundiay,QDV,Zhundiai,Zhundijai,Zundiajus,jundiya''i,jwndyay,rong di ya yi,Žundiajus,Жундиаи,Жундијаи,Жундіаї,جوندياي,জুন্ডিয়াই,容迪亞伊', -23.1863900, -46.8841700, 'BR', '2013-03-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8471, 'Júlio de Castilhos', 'Julio de Castilhos', 'Julio do Castilhos', -29.2269400, -53.6816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8472, 'Juiz de Fora', 'Juiz de Fora', 'JDF,Juiz de Fora,Zhuis-di-Fora,Zhuiz de Fora,Zhuiz di Fora,Zhuiz-di-Fora,Zuis de Fora,chwis di f xra,ju''ija de phora,ju-iseujipola,ru yi si di fu la,Žuis de Fora,Жуиз де Фора,Жуиз ди Фора,Жуис-ди-Фора,Жуїз-ді-Фора,জুইজ ডে ফোরা,ชวีซ์ดีฟอรา,ジュイス・デ・フォーラ,茹伊斯迪福拉,주이스지포라', -21.7641700, -43.3502800, 'BR', '2013-05-09', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8473, 'Juatuba', 'Juatuba', '', -19.9519400, -44.3427800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8474, 'José Bonifácio', 'Jose Bonifacio', '', -21.0527800, -49.6883300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8475, 'Joinville', 'Joinville', 'JOI,Joinville,Zhoinvile,Zhoinvili,Zhojnvili,Zoinvilis,jo''inabhilale,join''vu~ire,joinbilli,ruo yin wei lai,zwynwwyly,Žoinvilis,Жоинвиле,Жоинвили,Жойнвили,זוינווילי,জোইনভিললে,ジョインヴィレ,若茵维莱,조인빌리', -26.3044400, -48.8455600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8476, 'João Pinheiro', 'Joao Pinheiro', 'Zhuan-Pin''ejru,joya''o pinahe''iro,ruo ang pi nie lu,Жуан-Пиньейру,জোয়াও পিনহেইরো,若昂皮涅鲁', -17.7425000, -46.1725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8477, 'João Neiva', 'Joao Neiva', '', -19.7575000, -40.3855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8478, 'João Monlevade', 'Joao Monlevade', 'Joao,João,Monlevade,Zhuan-Monlevadi,joya''o monala''ibhade,ruo ang meng lai wa di,Жуан-Монлевади,জোয়াও মোনলইভাডে,若昂蒙莱瓦迪', -19.8100000, -43.1736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8479, 'Joanópolis', 'Joanopolis', 'Joannopolis', -22.9302800, -46.2755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8480, 'Joaíma', 'Joaima', 'Joahyma', -16.6541700, -41.0305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8481, 'Joaçaba', 'Joacaba', 'Cruzeiro,Cruzeiro do Sul,JCB,Joacaba,Joaçaba,Juacaba,Juaçaba,Limeira,Zhoasaba,joyakaba,ruo a sa ba,Жоасаба,জোয়াকাবা,若阿萨巴', -27.1780600, -51.5047200, 'BR', '2015-06-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8482, 'Jitaúna', 'Jitauna', '', -14.0127400, -39.8983300, 'BR', '2015-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8483, 'Jetibá', 'Jetiba', 'Jequitiba,Jetiba,Jetibá', -20.0206900, -40.6814500, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8484, 'Jerônimo Monteiro', 'Jeronimo Monteiro', 'Vala do Souza,Valla do Souza', -20.7894400, -41.3950000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8485, 'Jeremoabo', 'Jeremoabo', 'Geremoabo', -10.0750000, -38.4808300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8486, 'Jequitinhonha', 'Jequitinhonha', 'Sao Miguel de Jequitinhonha,São Miguel de Jequitinhonha,Zhekitin''on''ja,cheki ti n yonya,jeku''itinahonaha,re ji di ni ao ni ya,Жекитиньонья,জেকুইটিনহোনহা,เชกีตินโยนยา,热基蒂尼奥尼亚', -16.4338900, -41.0033300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8487, 'Jequié', 'Jequie', 'Jequie,Jequié,Jiquie,Jiquié,Jiquy,Zhekie,jekie,jeku''iye,re ji ye,Жекие,জেকুইয়ে,ჟეკიე,ジェキエー,热基耶', -13.8587500, -40.0851200, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8488, 'Jaú', 'Jau', 'Jahu,Jahú,Jau,Jaú,Zhau,ja''u,ya wu,Жау,জাউ,雅乌', -22.2963900, -48.5577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8489, 'Jataizinho', 'Jataizinho', 'Colonia Jatahy,Jatahy Parana,Jatahy Paraná,Jatai,Jatal,Jataí', -23.2541700, -50.9800000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8490, 'Jataí', 'Jatai', 'JTI,Jatahy,Jatai', -17.8793900, -51.7216600, 'BR', '2015-05-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8491, 'Jarinu', 'Jarinu', '', -23.1013900, -46.7283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8492, 'Jardinópolis', 'Jardinopolis', '', -21.0177800, -47.7638900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8493, 'Jardim', 'Jardim', 'Vuon,Vườn,Zardin,Zhardin,jardima,jrdm  jnwby matw grwsw,ya er ding,zhardini,Жардин,Ժարդին,جردم، جنوبی ماتو گروسو,জার্ডিম,ჟარდინი,雅爾丁', -21.4802800, -56.1380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8494, 'Jaraguá do Sul', 'Jaragua do Sul', 'Jaragua,Jaragua do Sul,Jaraguá,Jaraguá do Sul,Zharagua-du-Sul,jaragu''a do sula,nan ya la gua,Жарагуа-ду-Сул,জারাগুআ ডো সুল,南雅拉瓜', -26.4861100, -49.0666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8495, 'Jaraguá', 'Jaragua', 'Zaragua,Zharagua,ya la gua,zharagua,Жарагуа,Ժարագուա,ჟარაგუა,雅拉瓜', -15.7569400, -49.3344400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8496, 'Japoatã', 'Japoata', 'Jaboatao,Jaboatão', -10.3466700, -36.8011100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8497, 'Japeri', 'Japeri', '', -22.6430600, -43.6533300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8498, 'Japaratuba', 'Japaratuba', '', -10.5933300, -36.9402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8499, 'Januária', 'Januaria', 'Januaria,Januária', -15.4886600, -44.3598800, 'BR', '2013-01-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8500, 'Jandira', 'Jandira', '', -23.5275000, -46.9025000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8501, 'Jandaia do Sul', 'Jandaia do Sul', 'Jandaia', -23.6030600, -51.6433300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8502, 'Janaúba', 'Janauba', '', -15.8025000, -43.3088900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8503, 'Jales', 'Jales', 'JLS', -20.2688900, -50.5458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8504, 'Jaguaruna', 'Jaguaruna', 'JJG,Jaguaruna', -28.6214500, -49.0252900, 'BR', '2015-11-29', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8505, 'Jaguariúna', 'Jaguariuna', 'Jaguari,Jaguary,Jaguarí,Jaquary', -22.7055600, -46.9858300, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8506, 'Jaguariaíva', 'Jaguariaiva', 'Jaguariahyva,Jajuaryahiva', -24.2442300, -49.7093200, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8507, 'Jaguarari', 'Jaguarari', 'Jaguarary', -10.2638900, -40.1958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8508, 'Jaguarão', 'Jaguarao', '', -32.5661100, -53.3758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8509, 'Jaguaquara', 'Jaguaquara', '', -13.5305600, -39.9708300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8510, 'Jacutinga', 'Jacutinga', '', -22.2855600, -46.6122200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8511, 'Jacupiranga', 'Jacupiranga', '', -24.6925000, -48.0022200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8512, 'Jacobina', 'Jacobina', 'JCM,Zhakobina,jakobina,ya ke bi na,Жакобина,জাকোবিনা,ჟაკობინა,雅科比纳', -11.1814300, -40.5137200, 'BR', '2014-12-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8513, 'Jaciara', 'Jaciara', '', -15.9652800, -54.9683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8514, 'Jacarezinho', 'Jacarezinho', 'Jacaresinho,Zhakarezin''ju,Жакарезинью', -23.1605600, -49.9694400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8515, 'Jacareí', 'Jacarei', 'Jacarehy,Jacarei,Jacareí,Zhakarei,jakare''i,ya ka lei yi,Жакареи,জাকারেই,雅卡雷伊', -23.3052800, -45.9658300, 'BR', '2014-05-15', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8516, 'Jaboticabal', 'Jaboticabal', 'Jaboticabal,Zhabotikabal,jabotikabala,ya bo di ka ba er,Жаботикабал,জাবোটিকাবাল,雅博蒂卡巴尔', -21.2547200, -48.3222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8517, 'Ivoti', 'Ivoti', 'Bom Jardim', -29.5911100, -51.1605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8518, 'Iúna', 'Iuna', 'Rio Pardo', -20.3458300, -41.5358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8519, 'Ituverava', 'Ituverava', '', -20.3394400, -47.7805600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8520, 'Iturama', 'Iturama', 'Camelia,Camélia,Iturama,Santa Rosa,Итурама', -19.7280600, -50.1955600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8521, 'Itupeva', 'Itupeva', '', -23.1530600, -47.0577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8522, 'Itumbiara', 'Itumbiara', 'ITR,Itumbiara,Paranaiba,Paranaíba,Santa Rita,Santa Rita do Paranahyba,Santa Rita do Paranaib,Santa Rita do Paranaiba,Santa Rita do Paranaiha,Santa Rita do Paranaíba,itsunbiara,itumabiraara,yi tong bi ya la,Итумбиара,ইটুমবিৱারা,イツンビアラ,伊通比亚拉', -18.4191700, -49.2152800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8523, 'Ituiutaba', 'Ituiutaba', 'Itijutaba,Ituiutaba,Ituyutaba,itu''i''utaba,yi tu you ta ba,Итиютаба,ইটুইউটাবা,伊图尤塔巴', -18.9742800, -49.4621200, 'BR', '2014-12-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8524, 'Ituberá', 'Itubera', 'ITE,Itubera,Ituberá,Santarem,Santarém', -13.7353800, -39.1478500, 'BR', '2017-04-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8525, 'Ituaçu', 'Ituacu', 'Ituassu,Ituassú', -13.8133300, -41.2966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8526, 'Itu', 'Itu', 'Itu,QTU,Ytu,Ytua,ito~u,itu,yi tu,Іту,Иту,ইটু,イトゥー,伊图,이투', -23.2641700, -47.2991700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8527, 'Itororó', 'Itororo', 'Itapui,Itapuí', -15.1169400, -40.0702800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8528, 'Itiruçu', 'Itirucu', 'Itirussu', -13.5316700, -40.1502800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8529, 'Itirapina', 'Itirapina', 'Ityrapina', -22.2527800, -47.8227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8530, 'Itinga', 'Itinga', '', -16.6130600, -41.7652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8531, 'Itaúna', 'Itauna', 'Itauna,ita''una,yi ta wu na,Итауна,Իտաունա,ইটাউনা,伊塔乌纳', -20.0752800, -44.5763900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8532, 'Itaú de Minas', 'Itau de Minas', '', -20.7394400, -46.7522200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8533, 'Itatinga', 'Itatinga', 'Sao Joao de Itatinga,Sao Joao do Itatinga,São João de Itatinga,São João do Itatinga', -23.1016700, -48.6158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8534, 'Itatiba', 'Itatiba', '', -23.0058300, -46.8388900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8535, 'Itatiaia', 'Itatiaia', 'Campo Bello,Campo Belo', -22.4961100, -44.5633300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8536, 'Itararé', 'Itarare', 'Itarare,Итараре', -24.1125000, -49.3316700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8537, 'Itarantim', 'Itarantim', '', -15.6597200, -40.0655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8538, 'Itarana', 'Itarana', 'Figueira,Figueira de Santa Joanna', -19.8738900, -40.8752800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8539, 'Itaqui', 'Itaqui', 'ITQ,Itaka,Itaqui,Itaquy,Итака', -29.1252800, -56.5530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8540, 'Itaquaquecetuba', 'Itaquaquecetuba', 'Itaquaquicetuba', -23.4861100, -46.3483300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8541, 'Itapuranga', 'Itapuranga', 'Xixa,Xixá', -15.5622200, -49.9486100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8542, 'Itapuí', 'Itapui', 'Bica de Pedra', -22.2333300, -48.7191700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8543, 'Itaporanga', 'Itaporanga', '', -23.7077800, -49.4897200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8544, 'Itápolis', 'Itapolis', '', -21.5955600, -48.8127800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8545, 'Itapirapuã', 'Itapirapua', 'Itaperapoan,Itaperapua,Itaperapuan,Itaperapuã,Itapirapuan', -15.8233300, -50.6133300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8546, 'Itapira', 'Itapira', 'Itapira,itapira,yi ta pi la,Итапира,ইটাপিরা,伊塔皮拉', -22.4361100, -46.8216700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8547, 'Itapicuru', 'Itapicuru', 'Missao,Missão', -11.3166700, -38.2333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8548, 'Itapevi', 'Itapevi', 'Itapevy', -23.5488900, -46.9341700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8549, 'Itapeva', 'Itapeva', 'Faxina', -23.9822200, -48.8755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8550, 'Itapetininga', 'Itapetininga', 'Itapetinga,Itapetininga,ZTP,itapetininga,yi ta pei di ning jia,Ітапетінінга,Итапетининга,ইটাপেটিনিঙ্গা,イタペティニンガ,伊塔佩蒂宁加', -23.5916700, -48.0530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8551, 'Itapetinga', 'Itapetinga', 'Itatinga,QIT', -15.2488900, -40.2477800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8552, 'Itaperuna', 'Itaperuna', 'ITP,Itaperuna,itaperuna,xi tapi ru na,yi ta pei lu na,Итаперуна,ইটাপেরুনা,อีตาปิรูนา,伊塔佩鲁纳', -21.2050000, -41.8877800, 'BR', '2017-03-02', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8553, 'Itaperuçu', 'Itaperucu', '', -25.2200000, -49.3477800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8554, 'Itapemirim', 'Itapemirim', 'Itapemirin,itapemirima,yi ta pei mi lin,Итапемирин,Իտապեմիրին,ইটাপেমিরিম,იტაპემერინი,伊塔佩米林', -21.0111100, -40.8338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8555, 'Itapema', 'Itapema', 'Itapema,Итапема', -27.0902800, -48.6113900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8556, 'Itapecerica da Serra', 'Itapecerica da Serra', 'Itapecerica,Itapeserika-da-Serra,Итапесерика-да-Серра', -23.7169400, -46.8491700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8557, 'Itapecerica', 'Itapecerica', '', -20.4725000, -45.1255600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8558, 'Itaparica', 'Itaparica', '', -12.8883300, -38.6786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8559, 'Itapaci', 'Itapaci', '', -14.9508300, -49.5494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8560, 'Itaocara', 'Itaocara', 'Itacoara,Itacoára', -21.6691700, -42.0761100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8561, 'Itanhém', 'Itanhem', 'Nossa Senhora do Itanhem', -17.1663900, -40.3300000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8562, 'Itanhandu', 'Itanhandu', '', -22.2958300, -44.9347200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8563, 'Itanhaém', 'Itanhaem', 'Itan''jaehn,Itanhaen,Nossa Senhora da Conceicao de Itanhaem,Nossa Senhora da Conceição de Itanhaém,itanahayema,yi ta ni ya en,Итаньяэн,ইটানহায়েম,伊塔尼亚恩', -24.1830600, -46.7888900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8564, 'Itambé', 'Itambe', '', -15.2450000, -40.6244400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8565, 'Itambacuri', 'Itambacuri', 'ITI,Itambacuri,Itambacury,Itambakuri,yi tan ba ku li,Итамбакури,伊坦巴库里', -18.0311100, -41.6850000, 'BR', '2016-11-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8566, 'Itamarandiba', 'Itamarandiba', 'Itamarandyba', -17.8572200, -42.8588900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8567, 'Itamaraju', 'Itamaraju', '', -17.0391700, -39.5311100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8568, 'Itajuípe', 'Itajuipe', 'Pirangi,Piranj', -14.6780600, -39.3750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8569, 'Itajubá', 'Itajuba', 'Itazhuba,itajuba,yi ta ru ba,Ітажуба,Итажуба,ইটাজুবা,伊塔茹巴', -22.4255600, -45.4527800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8570, 'Itajobi', 'Itajobi', 'Itajoby,Itajuby', -21.3180600, -49.0544400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8571, 'Itagibá', 'Itagiba', 'Destampina,Itagiba,Itagibá', -14.2836100, -39.8427800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8572, 'Itajaí', 'Itajai', 'Itajahi,Itajahy,Itajai,Itajaí,Itazhai,itaja''i,yi da gu yi,Итажаи,ইটাজাই,伊達賈伊', -26.9077800, -48.6619400, 'BR', '2017-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8573, 'Itaí', 'Itai', 'Itahy', -23.4177800, -49.0905600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8574, 'Itaguaí', 'Itaguai', 'Itaguai,Itaquahy,itaguraa''i,yi ta gua yi,Итагуаи,ইটাগুৱাই,伊塔瓜伊', -22.8522200, -43.7752800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8575, 'Itaguaçu', 'Itaguacu', 'Boa Familia,Bôa Familia,Itaguassu,Itaguassú', -19.8019400, -40.8555600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8576, 'Itagi', 'Itagi', 'Itaji', -14.1627800, -40.0061100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8577, 'Itacaré', 'Itacare', 'Barra do Rio de Contas', -14.2789000, -38.9958400, 'BR', '2014-10-09', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8578, 'Itacarambi', 'Itacarambi', 'Itacaramby,Jacare,Porto Jacare,Pôrto Jacaré', -15.1022200, -44.0919400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8579, 'Itabuna', 'Itabuna', 'ITN,Itabuna,itabuna,yi ta bu na,Итабуна,ইটাবুনা,იტაბუნა,イタブーナ,伊塔布纳', -14.7855600, -39.2802800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8580, 'Itaboraí', 'Itaborai', 'Itaborahy,Itaborai,itabora''i,yi ta bo la yi,Итабораи,ইটাবোরাই,伊塔博拉伊', -22.7444400, -42.8594400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8581, 'Itabirito', 'Itabirito', '', -20.2533300, -43.8013900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8582, 'Itabira', 'Itabira', 'Itabira,Itabira de Mato Dentro,Itabira de Matto Dentro,Presidente Vargas,itabira,yi ta bi la,Итабира,ইটাবিরা,伊塔比拉', -19.6191700, -43.2269400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8583, 'Itaberaí', 'Itaberai', 'Itaberahy,Itaberai,Itaborahy,Итабераи', -16.0202800, -49.8102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8584, 'Itaberaba', 'Itaberaba', '', -12.5275000, -40.3069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8585, 'Itaberá', 'Itabera', '', -23.8619400, -49.1372200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8586, 'Itabaianinha', 'Itabaianinha', 'Itabayanninha', -11.2738900, -37.7900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8587, 'Itabaiana', 'Itabaiana', '', -10.6850000, -37.4252800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8588, 'Irupi', 'Irupi', 'Cachoeira', -20.3452800, -41.6411100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8589, 'Irecê', 'Irece', 'IRE', -11.3041700, -41.8558300, 'BR', '2017-06-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8590, 'Irati', 'Irati', 'Iraty', -25.4672200, -50.6511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8591, 'Irará', 'Irara', '', -12.0500000, -38.7666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8592, 'Iraquara', 'Iraquara', 'Irakara,Joao Pessoa,João Pessoa,irakuraara,yi la kua la,Иракара,Իրակարա,ইরাকুৱারা,ირაკარა,伊拉夸拉', -12.2486100, -41.6194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8593, 'Iracemápolis', 'Iracemapolis', 'Iracemopolis', -22.5805600, -47.5186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8594, 'Ipuã', 'Ipua', 'Olhos d''Agua', -20.4380600, -48.0122200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8595, 'Iporã', 'Ipora', '', -24.0030600, -53.7041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8596, 'Iporá', 'Ipora', 'Ipora,Itajuba,Itajubá,Ипора', -16.4419400, -51.1177800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8597, 'Ipirá', 'Ipira', 'Camisao,Camisão', -12.1583300, -39.7372200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8598, 'Ipiaú', 'Ipiau', 'IPU,Ipiau,Rio Novo,Ипиау', -14.1344900, -39.7394800, 'BR', '2017-06-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8599, 'Iperó', 'Ipero', '', -23.3502800, -47.6886100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8600, 'Ipauçu', 'Ipaucu', 'Ipaussu,Ipaussú', -23.0566700, -49.6263900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8601, 'Ipatinga', 'Ipatinga', 'IPN,Ipatinga,ipachinga,ipatinga,yi pa ting jia,Ипатинга,ইপাটিঙ্গা,イパチンガ,伊帕廷加', -19.4683300, -42.5366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8602, 'Ipameri', 'Ipameri', 'Ipamery', -17.7219400, -48.1597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8603, 'Ipaba', 'Ipaba', '', -19.4136100, -42.4194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8604, 'Inhumas', 'Inhumas', '', -16.3577800, -49.4961100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8605, 'Inhapim', 'Inhapim', '', -19.5491700, -42.1200000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8606, 'Inhambupe', 'Inhambupe', 'Inhambupo', -11.7844400, -38.3530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8607, 'Indiaroba', 'Indiaroba', 'Espirito Santo,Espírito Santo', -11.5191700, -37.5116700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8608, 'Indaiatuba', 'Indaiatuba', 'Indaiatuba,Indajatuba,inda''iyatuba,yin da ya tu ba,Индаятуба,ইন্ডাইয়াটুবা,因达亚图巴', -23.0884200, -47.2119000, 'BR', '2014-06-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8609, 'Indaial', 'Indaial', 'Indaval', -26.8977800, -49.2316700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8610, 'Imbituva', 'Imbituva', 'Santo Antonio de Imbituva', -25.2300000, -50.6044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8611, 'Imbituba', 'Imbituba', 'Henrique Lage,Henrique Laje', -28.2400000, -48.6702800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8612, 'Ilhéus', 'Ilheus', 'IOS,Il''eus,Ileus,Ilheos,Ilheus,Ilhéos,Ilhéus,Iljeusas,Sao Jorge dos Ilheos,São Jorgé dos Ilhéos,ilahe''usa,ileusi,iryeusu,yi lie wu si,Ильеус,Иљеус,ইলহেউস,ილეუსი,イリェウス,伊列乌斯', -14.7936400, -39.0394900, 'BR', '2015-06-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8613, 'Ilha Solteira', 'Ilha Solteira', 'ILB,Il''ja-Soltejra,Ilha Solteira,ilaha solate''ira,yi li ya suo er tai la,Илья-Солтейра,ইলহা সোলটেইরা,伊利亚索尔泰拉', -20.4327800, -51.3425000, 'BR', '2017-03-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8614, 'Ilhabela', 'Ilhabela', 'Formosa,Vilabela,Villa Bella', -23.7780600, -45.3580600, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8615, 'Ijuí', 'Ijui', 'IJU,Ijuhy,Izhui,iju''i,yi ru yi,Ижуи,ইজুই,伊茹伊', -28.3877800, -53.9147200, 'BR', '2017-06-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8616, 'Iguatemi', 'Iguatemi', 'Igatemi,Igatemí,Sacaron', -23.6802800, -54.5611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8617, 'Iguape', 'Iguape', 'Bom Jesus da Ribeira,Iguapi,iguraape,yi gua pei,Игуапи,איגואפה,ইগুৱাপে,伊瓜佩', -24.7080600, -47.5552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8618, 'Iguaí', 'Iguai', '', -14.7563900, -40.0891700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8619, 'Iguaba Grande', 'Iguaba Grande', '', -22.8391700, -42.2288900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8620, 'Igrejinha', 'Igrejinha', 'Igrezhin''ja,igrejinaha,yi ge lei ri ni ya,Игрежинья,ইগ্রেজিনহা,伊格雷日尼亚', -29.5744400, -50.7902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8621, 'Igreja Nova', 'Igreja Nova', 'Triumfo,Triumpho,Triunfo', -10.1252800, -36.6619400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8622, 'Igarapé', 'Igarape', '', -20.0702800, -44.3016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8623, 'Igarapava', 'Igarapava', '', -20.0383300, -47.7469400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8624, 'Igaraçu do Tietê', 'Igaracu do Tiete', 'Igarassu,Igarassú', -22.5091700, -48.5577800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8625, 'Iconha', 'Iconha', 'Ikon''ja,Ikonia,ikonaha,yi ke ni ya,Иконья,Իկոնիա,ইকোনহা,იკონია,伊科尼亞', -20.7930600, -40.8111100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8626, 'Içara', 'Icara', 'Aliatar,Isara,Исара', -28.7133300, -49.3000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8627, 'Ibotirama', 'Ibotirama', 'Bom Jardim,Jardinocolis,Jardinopolis,Jardinópolis', -12.1852800, -43.2205600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8628, 'Ibiúna', 'Ibiuna', 'Una', -23.6563900, -47.2225000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8629, 'Ibitinga', 'Ibitinga', '', -21.7577800, -48.8288900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8630, 'Ibirubá', 'Ibiruba', '', -28.6275000, -53.0897200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8631, 'Ibirité', 'Ibirite', 'Ibirite,Ибирите', -20.0219400, -44.0588900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8632, 'Ibirataia', 'Ibirataia', 'Tesouras,Ubirataia', -14.0669400, -39.6405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8633, 'Ibirapitanga', 'Ibirapitanga', 'Ibirapitinga', -14.1641700, -39.3736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8634, 'Ibirama', 'Ibirama', 'Hammonia,Hamonia,Hamônia', -27.0569400, -49.5177800, 'BR', '2017-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8635, 'Ibiraçu', 'Ibiracu', 'Pao Gigante,Pau Gigante,Páo Gigante', -19.8319400, -40.3697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8636, 'Ibiporã', 'Ibipora', 'Sao Pedro de Alcantara,São Pedro de Alcantara', -23.2691700, -51.0480600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8637, 'Ibipeba', 'Ibipeba', 'Tiririca do Assurua,Tiririca do Assuruá', -11.6408300, -42.0111100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8638, 'Ibicuí', 'Ibicui', '', -14.8416700, -39.9866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8639, 'Ibicaraí', 'Ibicarai', 'Palestina', -14.8650000, -39.5875000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8640, 'Ibiá', 'Ibia', 'Sao Pedro d''Alcantara,São Pedro d''Alcantara', -19.4783300, -46.5388900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8641, 'Ibatiba', 'Ibatiba', 'Rosario,Rosário', -20.2338900, -41.5105600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8642, 'Ibaté', 'Ibate', 'Ibaete,Ibaeté', -21.9547200, -47.9966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8643, 'Ibaiti', 'Ibaiti', 'Barra Bonita', -23.8486100, -50.1877800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8644, 'Iaçu', 'Iacu', 'Iassi,Iassí,Paraguacu,Paraguassu,Paraguassú,Paraguaçu,Sitio Novo', -12.7672200, -40.2116700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8645, 'Iaciara', 'Iaciara', 'Iacara,Iassiara,Iaçara', -14.0958300, -46.6316700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8646, 'Hortolândia', 'Hortolandia', 'Hortolandia,Hortolândia,Ortolandija,ao tuo lan di ya,hortolandiya,Ортоландия,হোর্টোলান্ডিয়া,奥托兰迪亚', -22.8583300, -47.2200000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8647, 'Horizontina', 'Horizontina', 'HRZ,Horizontina', -27.6258300, -54.3077800, 'BR', '2016-10-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8648, 'Hidrolândia', 'Hidrolandia', 'Grimpas,Hydrolandia', -16.9622200, -49.2280600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8649, 'Herval', 'Herval', 'Erval', -32.0236100, -53.3955600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8650, 'Gurupi', 'Gurupi', 'GRP,Gurupi,Гурупи', -11.7291700, -49.0686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8651, 'Guiratinga', 'Guiratinga', 'Lageado,Lajeado', -16.3453400, -53.7617700, 'BR', '2014-10-09', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8652, 'Guia Lopes da Laguna', 'Guia Lopes da Laguna', 'Guia Lopes', -21.4577800, -56.1141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8653, 'Guaxupé', 'Guaxupe', '', -21.3052800, -46.7127800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8654, 'Guarulhos', 'Guarulhos', 'GRU,Guarulhos,QCV', -23.4627800, -46.5333300, 'BR', '2013-12-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8655, 'Guarujá', 'Guaruja', 'Guaruzha,Guyrajara,Guyrajára,Gvaruzha,gua lu ya,guaruja,guraaruja,Гваружа,Гуаружа,গুৱারুজা,グアルジャ,瓜魯雅', -23.9930600, -46.2563900, 'BR', '2015-06-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8656, 'Guariba', 'Guariba', '', -21.3600000, -48.2283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8657, 'Guaratuba', 'Guaratuba', '', -25.8827800, -48.5747200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8658, 'Guaratinguetá', 'Guaratingueta', 'Guaratingeta,guraaratinguyeta,Гуаратингета,Гуаратінгета,গুৱারাটিঙ্গুয়েটা', -22.8163900, -45.1925000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8659, 'Guaratinga', 'Guaratinga', 'Guaratinga', -16.5856400, -39.7818900, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8660, 'Guararema', 'Guararema', '', -23.4150000, -46.0350000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8661, 'Guararapes', 'Guararapes', '', -21.2608300, -50.6427800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8662, 'Guarapuava', 'Guarapuava', 'GPB,Guarapuava,gua la pu a wa,guraarapuraabha,Гуарапуава,গুৱারাপুৱাভা,瓜拉普阿瓦', -25.3904800, -51.4654100, 'BR', '2014-12-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8663, 'Guarapari', 'Guarapari', 'GUZ,Guarapari,Гуарапари,גוארפארי', -20.6718200, -40.5019600, 'BR', '2017-07-15', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8664, 'Guaraniaçu', 'Guaraniacu', '', -25.1008300, -52.8780600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8665, 'Guaranésia', 'Guaranesia', 'Guarnesia', -21.2991700, -46.8025000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8666, 'Guaramirim', 'Guaramirim', 'Bananal', -26.4730600, -49.0027800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8667, 'Guará', 'Guara', '', -20.4283300, -47.8241700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8668, 'Guaporé', 'Guapore', 'Guaporema', -28.8455600, -51.8902800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8669, 'Guapó', 'Guapo', 'Ribeirao,Ribeirão', -16.8305600, -49.5319400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8670, 'Guapimirim', 'Guapimirim', 'Guapimirin,Guapy-mirim,Гуапимирин', -22.5372200, -42.9819400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8671, 'Guapiaçu', 'Guapiacu', 'Cuapiacu,Cuapiaçu,Guapiassu,Guapiassú,Ribeirao Claro,Ribeirão Claro', -20.7950000, -49.2202800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8672, 'Guanhães', 'Guanhaes', '', -18.7750000, -42.9325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8673, 'Guanambi', 'Guanambi', 'GNM,Guanambi,Guanamby,gua nan bi,guanambi,guraanamabi,Гуанамби,গুৱানামবি,გუანამბი,瓜南比', -14.2233300, -42.7813900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8674, 'Guaíra', 'Guaira', 'Guahyra,Guajra,Guayra,Гуайра', -20.3183300, -48.3105600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8675, 'Guaçuí', 'Guacui', 'Guasui,Siqueira Campos,gua su yi,guasui,guraaku''i,Гуасуи,Գուասուի,গুৱাকুই,გუასუი,瓜蘇伊', -20.7755600, -41.6794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8676, 'Gravataí', 'Gravatai', 'Gravatahy,Gravatai,Gravataí,Karavatay,ge la wa ta yi,grabhata''i,Граватаи,গ্রাভাটাই,格拉瓦塔伊', -29.9421800, -50.9927800, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8677, 'Governador Valadares', 'Governador Valadares', 'Figueira,GVR,Gov. Valadares,Governador Valadares,Governador Valadaresas,Governador Valadaris,Governador-Valadares,Governador-Valadaris,Valadares,gobeleunadoleuballadaleseu,gobhernador bhaladaresa,ko wer na dor wa la da ris,wa la da li si zhou zhang shi,Говернадор Валадарес,Говернадор Валадарис,Говернадор-Валадарес,Говернадор-Валадарис,Գովերնադոր Վալադարիս,গোভের্নাডোর্ ভালাডারেস,โกเวร์นาโดร์วาลาดาริส,ゴベルナドール・バラダレス,瓦拉達里斯州長市,고베르나도르발라다레스', -18.8511100, -41.9494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8678, 'Goiatuba', 'Goiatuba', 'Bananeiras,Gojatuba,Гоятуба', -18.0125000, -49.3547200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8679, 'Goiás', 'Goias', 'Goaiz,Goiaz,Goyaz', -15.9344400, -50.1402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8680, 'Goianira', 'Goianira', 'Gojanira,Sao Geraldo,São Geraldo,Гоянира', -16.4961100, -49.4263900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8681, 'Goiânia', 'Goiania', 'Ciutat de Goiania,Ciutat de Goiânia,GYN,Goiana,Goiania,Goianá,Goiânia,Gojani,Gojanija,Goyania,Goyaniya,ge ya ni ya,ghwyanya,go''iyaniya,goiania,gwyyanya,ko ya neiy,Гояни,Гояния,Гоянія,Гојанија,גואיאניה,غويانيا,گوئیانیا,গোইয়ানিয়া,โกยาเนีย,გოიანია,ゴイアニア,戈亚尼亚,고이아니아', -16.6786100, -49.2538900, 'BR', '2010-01-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8682, 'Goianésia', 'Goianesia', '', -15.3175000, -49.1175000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8683, 'Goianápolis', 'Goianapolis', 'Goianopolis,Goianópolis', -16.5105600, -49.0238900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8684, 'Giruá', 'Girua', 'Jirua,Jiruá', -28.0283300, -54.3497200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8685, 'General Salgado', 'General Salgado', '', -20.6483300, -50.3605600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8686, 'Gaspar', 'Gaspar', 'Gaspar,gasapar,jia si pa,Гаспар,গাসপার্,加斯帕', -26.9313900, -48.9588900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8687, 'Garibaldi', 'Garibaldi', '', -29.2561100, -51.5336100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8688, 'Garça', 'Garca', '', -22.2105600, -49.6561100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8689, 'Gandu', 'Gandu', 'Gandu,gan du,gandu,Ганду,Գանդու,গান্ডু,განდუ,甘杜', -13.7438900, -39.4866700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8690, 'Fundão', 'Fundao', '', -19.9340800, -40.4047300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8691, 'Frutal', 'Frutal', 'Fructal,Frutal,Фрутал', -20.0247200, -48.9405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8692, 'Frei Paulo', 'Frei Paulo', 'Sao Paulo,São Paulo', -10.5494400, -37.5344400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8693, 'Frederico Westphalen', 'Frederico Westphalen', '', -27.3591700, -53.3944400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8694, 'Franco da Rocha', 'Franco da Rocha', 'Francisco da Rocha', -23.3216700, -46.7269400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8695, 'Francisco Sá', 'Francisco Sa', 'Brejo das Almas', -16.4758300, -43.4883300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8696, 'Francisco Morato', 'Francisco Morato', '', -23.2816700, -46.7452800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8697, 'Francisco Beltrão', 'Francisco Beltrao', 'Beltran-Francisko,FBE,Francisco Beltrao,Francisco Beltrão,Fransisku-Beltran,bei er de lang,phransisako belatra''o,Белтран-Франциско,Франсиску-Белтран,ফ্রান্সিসকো বেলট্রাও,贝尔德朗', -26.0811100, -53.0550000, 'BR', '2017-05-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8698, 'Franca', 'Franca', 'FRC,Franca,Franka,Franko,franka,fu lang ka,furanka,phranka,Франка,Франко,فرانكا,ফ্রাঙ্কা,フランカ,弗朗卡', -20.5386100, -47.4008300, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8699, 'Foz do Iguaçu', 'Foz do Iguacu', 'Fos do Iguasu,Fos-du-Iguasu,Foz de Iguassu,Foz de Iguazu,Foz do Iguacu,Foz do Iguassu,Foz do Iguassú,Foz do Iguasu,Foz do Iguaçu,IGU,Iguassu,Iguassú,fwz dw ayghwasw,fwz dw lwachw,phoja do iguraaku,poseudu-iguasu,yi gua su,Фоз до Игуасу,Фос до Игуасу,Фос-ду-Іґуасу,Фос-ду-Игуасу,פאס דו איגוואסו,פוז דו איגואסו,فوز دو إيغواسو,فوز دو لوآچو,ফোজ ডো ইগুৱাকু,フォス・ド・イグアス,伊瓜苏,포스두이구아수', -25.5477800, -54.5880600, 'BR', '2016-10-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8700, 'Forquilhinha', 'Forquilhinha', 'Forkil''in''ja,Forquilinho,Форкильинья', -28.7475000, -49.4722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8701, 'Formosa do Rio Preto', 'Formosa do Rio Preto', 'Formosa,Itajui,Itajuí', -11.0483300, -45.1930600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8702, 'Formosa', 'Formosa', 'Formosa,fu mo sa,poleumoja,福莫薩,포르모자', -15.5372200, -47.3344400, 'BR', '2016-06-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8703, 'Formiga', 'Formiga', 'Formiga,fu mi jia,phormiga,Формига,ফোর্মিগা,福米加', -20.4644400, -45.4263900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8704, 'Paulista Flórida', 'Paulista Florida', 'Aguapei do Alto,Aguapeí do Alto,Paulista Florida,Paulista Flórida', -21.6000000, -51.2000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8705, 'Florianópolis', 'Florianopolis', 'Destero,Desterro,FLN,Florianopolis,Florianópolis,Florijanopolis,Floripa,Florjanopolisa,Nossa Senhora do Desterro,Nossa Senhora do Destêrro,flwryanwbwlys,flwryanwplys,flwryanwpwls,fol reiyn x polis,fpolis,fu luo li ya nuo bo li si,furorianoporisu,peullolianopolliseu,phloriyanopolisa,Флорианополис,Флоријанополис,Флоріанополіс,פלוריאנופוליס,فلوريانوبوليس,فلوریانوپلیس,فلوریانوپولس,ফ্লোরিয়ানোপোলিস,โฟลเรียนอโปลิส,ფლორიანოპოლისი,フロリアノーポリス,弗洛里亚诺波利斯,플로리아노폴리스', -27.5966700, -48.5491700, 'BR', '2012-05-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8706, 'Florestópolis', 'Florestopolis', '', -22.8633300, -51.3872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8707, 'Flores da Cunha', 'Flores da Cunha', '', -29.0288900, -51.1816700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8708, 'Firminópolis', 'Firminopolis', '', -16.5819400, -50.3050000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8709, 'Ferraz de Vasconcelos', 'Ferraz de Vasconcelos', '', -23.5408300, -46.3686100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8710, 'Fernandópolis', 'Fernandopolis', '', -20.2838900, -50.2463900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8711, 'Feira de Santana', 'Feira de Santana', 'FEC,Feira,Feira De Saint Anna,Feira de Sant''Anna,Feira de Santana,Fejra di Santana,Fejra-de-Santana,Fejra-di-Santana,fei la di sheng an na,peilajisantana,phe''ira de santana,Феира де Сантана,Фейра ди Сантана,Фейра-де-Сантана,Фейра-ди-Сантана,ফেইরা ডে সান্টানা,ფეირა-დი-სანტანა,フェイラ・デ・サンタナ,費拉迪聖安娜,페이라지산타나', -12.2666700, -38.9666700, 'BR', '2017-06-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8712, 'Faxinal', 'Faxinal', 'Faxinal de Sao Sebastiao,Faxinal de São Sebastião,Sao Sebastiao,São Sebastião', -24.0002800, -51.3194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8713, 'Fartura', 'Fartura', '', -23.3883300, -49.5100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8714, 'Farroupilha', 'Farroupilha', '', -29.2250000, -51.3477800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8715, 'Extrema', 'Extrema', '', -22.8547200, -46.3183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8716, 'Eunápolis', 'Eunapolis', '', -16.3775000, -39.5802800, 'BR', '2017-03-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8717, 'Euclides da Cunha', 'Euclides da Cunha', 'Cumbe,Evklid-da-Kun''ja,Евклид-да-Кунья', -10.5075000, -39.0158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8718, 'Estrela', 'Estrela', '', -28.0611100, -50.9383300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8719, 'Esteio', 'Esteio', '', -29.8613900, -51.1791700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8720, 'Estância Velha', 'Estancia Velha', 'Genuino Sampaio', -29.6483300, -51.1738900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8721, 'Estância', 'Estancia', '', -11.2683300, -37.4383300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8722, 'Espumoso', 'Espumoso', '', -28.7247200, -52.8497200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8723, 'Esplanada', 'Esplanada', '', -11.7961100, -37.9450000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8724, 'Espinosa', 'Espinosa', 'ESI', -14.9261100, -42.8191700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8725, 'Espera Feliz', 'Espera Feliz', '', -20.6502800, -41.9072200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8726, 'Esmeraldas', 'Esmeraldas', 'Ehsmeral''das,Santa Quiteria,Эсмеральдас', -19.7625000, -44.3138900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8727, 'Erechim', 'Erechim', 'Boa Vista do Erechim,Bôa Vista do Erechim,ERM,Ehreshin,Erechim,Erequim,Erexim,Jose Bonifacio,José Bonifacio,Paiol Grande,ai lei xin,ereca''ima,Эрешин,এরেচইম,埃雷欣', -27.6346100, -52.2754000, 'BR', '2014-12-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8728, 'Entre Rios', 'Entre Rios', 'Nossa Senhora dos Prazeres do Inhambupe', -11.9419400, -38.0844400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8729, 'Engenheiro Beltrão', 'Engenheiro Beltrao', '', -23.7972200, -52.2691700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8730, 'Encruzilhada do Sul', 'Encruzilhada do Sul', 'Encruzilhada', -30.5438900, -52.5219400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8731, 'Encruzilhada', 'Encruzilhada', '', -15.5313900, -40.9094400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8732, 'Encantado', 'Encantado', '', -29.2361100, -51.8697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8733, 'Embu Guaçu', 'Embu Guacu', 'Imbu-Guacu,Imbu-Guaçu', -23.8322200, -46.8113900, 'BR', '2010-02-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8734, 'Embu', 'Embu', 'Ehmba,Embu Arte,Embu das Artes,Imbu,M''Boy,Эмба', -23.6488900, -46.8522200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8735, 'Elói Mendes', 'Eloi Mendes', 'Eloy Mendes', -21.6100000, -45.5652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8736, 'Elias Fausto', 'Elias Fausto', '', -23.0427800, -47.3738900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8737, 'Eldorado', 'Eldorado', 'Itapopo,Itapopó,Porto Itapopo,Pôrto Itapopó', -23.7869400, -54.2836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8738, 'Edéia', 'Edeia', 'Alegrete', -17.3383300, -49.9313900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8739, 'Ecoporanga', 'Ecoporanga', 'Ehkoporanga,Ekoporanga,Patrimonio da Serra,Patrimonio do Serro,Patrimônio da Serra,Patrimônio do Sêrro,ai ke bo lan jia,ekoporanga,Экопоранга,Էկոպորանգա,একোপোরাঙ্গা,ეკოპორანგა,埃科波蘭加', -18.3733300, -40.8305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8740, 'Duque de Caxias', 'Duque de Caxias', 'Caxias,Duke de Kashijas,Duke de Kasijasas,Duke de Kašijasas,Duki di Kashias,Duki di Kasias,Duki-di-Kashias,QDQ,duki ci ka cheiy s,dukijikasiaseu,dukuye de kaksa''iyasa,dwky dy kashys  ryw dw zhanyrw,dwq dy kaksyas,ka xi ya si gong jue cheng,Дуке де Кашијас,Дуки ди Кашиас,Дуки-ди-Кашиас,Դուկի դի Կաշիաս,دوق دي كاكسياس,دوکی دی کاشیس، ریو دو ژانیرو,ডুকুয়ে ডে কাক্সইয়াস,ดูกีจีกาเชียส,დუკი-დი-კაშიასი,ドゥケ・デ・カシアス,卡希亞斯公爵城,두키지카시아스', -22.7855600, -43.3116700, 'BR', '2014-11-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8741, 'Duartina', 'Duartina', '', -22.4144400, -49.4038900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8742, 'Dourados', 'Dourados', 'DOU,Doradus,Dourados,do''uradosa,duo la du si,dwradws,Дорадус,دورادوس,ডোউরাডোস,多拉杜斯', -22.2211100, -54.8055600, 'BR', '2014-01-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8743, 'Dores do Indaiá', 'Dores do Indaia', 'Dores do Indaya,Dôres do Indayá,Indaya,Indayá', -19.4633300, -45.6016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8744, 'Dom Pedrito', 'Dom Pedrito', '', -30.9827800, -54.6730600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8745, 'Domingos Martins', 'Domingos Martins', '', -20.3633300, -40.6591700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8746, 'Dois Vizinhos', 'Dois Vizinhos', 'Dojs-Vizin''jus,do''isa bhijinahosa,duo yi si wei qi ni wu si,Дойс-Визиньюс,ডোইস ভিজিনহোস,多伊斯维齐尼乌斯', -25.7336100, -53.0572200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8747, 'Dois Córregos', 'Dois Corregos', 'Dous Corregos', -22.3661100, -48.3802800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8748, 'Divinópolis', 'Divinopolis', 'DIQ,Divinopolis,Divinópolis,di wei nuo bo li si,dibhinopolisa,Дивинополис,ডিভিনোপোলিস,迪维诺波利斯', -20.1435500, -44.8906500, 'BR', '2015-06-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8749, 'Divino das Laranjeiras', 'Divino das Laranjeiras', 'Divino de Laranjeiras', -18.7777800, -41.4797200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8750, 'Diamantino', 'Diamantino', 'Alto Paraguai do Diamantino,DMT,Diamentina', -14.4086100, -56.4461100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8751, 'Diamantina', 'Diamantina', 'DTI,Diamantina,Tejuco,Диамантина', -18.2469200, -43.6034500, 'BR', '2015-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8752, 'Diadema', 'Diadema', 'Diadema,QDW,Диадема', -23.6861100, -46.6227800, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8753, 'Descalvado', 'Descalvado', '', -21.9038900, -47.6194400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8754, 'Curvelo', 'Curvelo', 'Curvello,Kurvelu,ku er wei lu,kurbhelo,Курвелу,কুর্ভেলো,库尔韦卢', -18.7563900, -44.4308300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8755, 'Curitibanos', 'Curitibanos', 'Curitybanos,Kuritibanus,QCR,Куритибанус', -27.2827800, -50.5844400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8756, 'Curitiba', 'Curitiba', 'CWB,Corityba,Curitiba,Curityba,Curytiba,Gorad Kurytyba,Kouritiba,Kouritimpa,Kuritib,Kuritiba,Kuritibae,Kuritibo,Kuritiwa,Kuritiyba,Kuriytyva,Kuriytýva,Kuriṭiba,Kuryciba,Kurytyba,Kùrìtíbà,gu li ti ba,ku li qi ba,ku ri ti ba,kulichiba,kurichiba,kuritcibas,kuritiba,kuritipe,kwrytyba,qwrytybh,Κουριτίμπα,Горад Курытыба,Коуритиба,Куритибæ,Куритиба,Курыціба,Կուրիտիբա,קוריטיבא,קוריטיבה,كوريتيبا,کوریتیبا,ܩܘܪܝܛܝܒܐ,कुरितिबा,কুরিটিবা,কুরিতিবা,ਕੁਰੀਤੀਬਾ,குரிடிபே,కురితీబా,ಕುರಿಟಿಬ,กูรีตีบา,კურიტიბა,ኩሪቺባ,ᎫᎵᏘᎦ,クリチバ,古里提巴,庫里奇巴,쿠리치바,', -25.4277800, -49.2730600, 'BR', '2014-01-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8757, 'Cunha', 'Cunha', '', -23.0744400, -44.9597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8758, 'Cuiabá', 'Cuiaba', 'CGB,Cuiaba,Cuiabá,Cuyaba,Cuyabá,Kouiampa,Kujaba,Kuyaba,Vila Real do Senhor Bom Jesus de Cuiaba,Vila Real do Senhor Bom Jesus de Cuiabá,ku ya ba,ku-iaba,kuiaba,kuyaba,kwyaba,kwyyaba,Κουιαμπά,Куяба,Кујаба,קויאבה,كويابا,کوئیابا,کویابا,कुयाबा,কুয়াবা,กุยาบา,კუიაბა,クイアバ,库亚巴,쿠이아바', -15.5961100, -56.0966700, 'BR', '2010-01-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8759, 'Cubatão', 'Cubatao', '', -23.8950000, -46.4252800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8760, 'Cruzília', 'Cruzilia', 'Cruzilha,Encruzilhada', -21.8386100, -44.8083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8761, 'Cruzeiro do Oeste', 'Cruzeiro do Oeste', 'Cruzeiro do Norte,Kruzejru-du-Uehsti,krujaye''iro do o''este,xi ke lu sai luo,Крузейру-ду-Уэсти,ক্রুজয়েইরো ডো ওএস্টে,西克鲁赛罗', -23.7850000, -53.0733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8762, 'Cruzeiro', 'Cruzeiro', 'Kruzejru,ke lu sai luo,Крузейру,克鲁赛罗', -22.5731600, -44.9710800, 'BR', '2014-12-25', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8763, 'Cruz das Almas', 'Cruz das Almas', '', -12.6700000, -39.1019400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8764, 'Cruz Alta', 'Cruz Alta', 'CZB,Cruz Alta,Krus-Alta,shang ke lu si,Крус-Алта,上克鲁斯', -28.6439700, -53.6063300, 'BR', '2017-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8765, 'Crixás', 'Crixas', 'Crichas', -14.5488900, -49.9691700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8766, 'Cristinápolis', 'Cristinapolis', 'Cristianopolis,Cristianópolis,Cristina,Vila Cristina,Villa Christina', -11.4755600, -37.7552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8767, 'Cristalina', 'Cristalina', 'Cristalino,Crystallina,Kristalina,karisatalina,ke li si ta li na,Кристалина,করিসটালিনা,克里斯塔利娜', -16.7676900, -47.6153000, 'BR', '2015-06-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8768, 'Criciúma', 'Criciuma', 'CCM,Creciuna,Creciúna,Cresciuma,Cresciúma,Criciuma,Criciúma,Krisiuma,karisi''uma,ke li xi wu ma,Крисиума,করিসিউমা,克里西烏馬', -28.6775000, -49.3697200, 'BR', '2017-02-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8769, 'Cravinhos', 'Cravinhos', '', -21.3402800, -47.7294400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8770, 'Coxim', 'Coxim', 'Herculanea,Herculania,Herculânea,Herculânia,Koshin,koksima,Кошин,কোক্সিম', -18.5066700, -54.7600000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8771, 'Cotia', 'Cotia', 'Cutia', -23.6038900, -46.9191700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8772, 'Costa Rica', 'Costa Rica', 'Costa Rica,Silvino Aquino', -23.4166700, -54.6500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8773, 'Cosmópolis', 'Cosmopolis', '', -22.6458300, -47.1961100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8774, 'Coruripe', 'Coruripe', 'Cururipe', -10.1255600, -36.1755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8775, 'Corupá', 'Corupa', 'Hansa', -26.4252800, -49.2430600, 'BR', '2017-06-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8776, 'Corumbá', 'Corumba', 'CMG,Corumba,Corumbá,Korumba,kolumba,korumaba,korunba,kwrwmba,Корумба,كورومبا,কোরুমবা,コルンバ,코룸바', -19.0091700, -57.6533300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8777, 'Correntina', 'Correntina', '', -13.3433300, -44.6366700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8778, 'Correia Pinto', 'Correia Pinto', 'Correa Pinto', -27.5847200, -50.3611100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8779, 'Coronel Vivida', 'Coronel Vivida', '', -25.9797200, -52.5677800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8780, 'Coronel Fabriciano', 'Coronel Fabriciano', 'Koronel-Fabrisianu,Koronelfabrisjanu,fa bu li xi ya nuo shang xiao cheng,koronela phabrisiyano,Коронел-Фабрисиану,Коронел-Фабрісіану,কোরোনেল ফাব্রিসিয়ানো,コロネル・ファブリシアーノ,法布里西亚诺上校城', -19.5186100, -42.6288900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8781, 'Coromandel', 'Coromandel', 'Koromandel,ke luo man de er,koromandela,Коромандел,কোরোমান্ডেল,科罗曼德尔', -18.4733300, -47.2002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8782, 'Cornélio Procópio', 'Cornelio Procopio', 'CKO,Cor Procopio,Korneliu-Prokopiu,ke nei li wu-pu luo ke pi wu,korneli''o prokopi''o,Корнелиу-Прокопиу,কোর্নেলিও প্রোকোপিও,科内利乌-普罗科皮乌', -23.1811100, -50.6466700, 'BR', '2017-07-02', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8783, 'Corinto', 'Corinto', 'Corintho,Korinto,Коринто', -18.3808300, -44.4563900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8784, 'Cordeirópolis', 'Cordeiropolis', 'Cordeiro,Cordeiros', -22.4819400, -47.4566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8785, 'Cordeiro', 'Cordeiro', '', -22.0286100, -42.3608300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8786, 'Corbélia', 'Corbelia', '', -24.7988900, -53.3066700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8787, 'Coração de Maria', 'Coracao de Maria', '', -12.2333300, -38.7500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8788, 'Coração de Jesus', 'Coracao de Jesus', '', -16.6852800, -44.3650000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8789, 'Contagem', 'Contagem', 'Kontazhen,kong ta ren,kontagema,kontajen,kontajeng,Контажен,কোন্টাগেম,コンタジェン,孔塔任,콘타젱', -19.9316700, -44.0536100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8790, 'Conselheiro Pena', 'Conselheiro Pena', 'Konsel''ejru-Pena,Lajao,Lajão,konselahe''iro pena,pei na gu wen cheng,Консельейру-Пена,কোন্সেলহেইরো পেনা,佩纳顾问城', -19.1722200, -41.4722200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8791, 'Conselheiro Lafaiete', 'Conselheiro Lafaiete', 'Conselheiro Lafaiete,Conselheiro Lafayete,Konsel''ejru-Lafaeti,Konseljeiro Lafajete,Konseljeiro Lafajetė,Lafaiete,QDF,konselahe''iro lapha''iyete,la fa ye di gu wen cheng,Консельейру-Лафаети,কোন্সেলহেইরো লাফাইয়েটে,拉法耶蒂顾问城', -20.6602800, -43.7861100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8792, 'Congonhas', 'Congonhas', 'Congonhas do Campo,Gongonhas,Kongon''jas,Конгоньяс', -20.5052500, -43.8588000, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8793, 'Conde', 'Conde', 'Itapicuru de Baixo,Nossa Senhora do Monte de Itapicuru da Praia', -11.8136100, -37.6105600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8794, 'Concórdia', 'Concordia', 'Konkordija,Конкордия', -27.2341700, -52.0277800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8795, 'Conchas', 'Conchas', '', -23.0152800, -48.0105600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8796, 'Conchal', 'Conchal', 'Konshal,konacala,kong sha er,Коншал,কোনচাল,孔沙尔', -22.3302800, -47.1725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8797, 'Conceição do Rio Verde', 'Conceicao do Rio Verde', '', -21.8808300, -45.0852800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8798, 'Conceição do Mato Dentro', 'Conceicao do Mato Dentro', 'Conceicao,Conceição', -19.0372200, -43.4250000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8799, 'Conceição do Coité', 'Conceicao do Coite', 'Coite,Coité,Conceicao Coite,Cuite,Cuité', -11.5638900, -39.2827800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8800, 'Conceição do Castelo', 'Conceicao do Castelo', 'Conceicao do Castello,Konsejsan-du-Kastelu,Konseysan du Kastelu,kong sai sang du ka si te luo,konse''ikaya''o do kasatelo,Консейсан-ду-Кастелу,Կոնսեյսան դու Կաստելու,কোন্সেইকয়াও ডো কাসটেলো,კონსეისან-დუ-კასტელუ,孔塞桑杜卡斯特洛', -20.3683300, -41.2438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8801, 'Conceição do Almeida', 'Conceicao do Almeida', 'Affonso Penna,Afonso Pena', -12.7794400, -39.1700000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8802, 'Conceição do Jacuípe', 'Conceicao do Jacuipe', 'Concaicao do Jacuipe,Concaição do Jacuípe', -12.3166700, -38.7666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8803, 'Conceição das Alagoas', 'Conceicao das Alagoas', '', -19.9147200, -48.3883300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8804, 'Conceição da Feira', 'Conceicao da Feira', '', -12.5058300, -38.9986100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8805, 'Conceição da Barra', 'Conceicao da Barra', 'Barra de Sao Mateus,Barra de São Mateus,Konsejsan-da-Barra,Konseysan da Bara,kang sai sang da ba la,konse''ikaya''o da barra,Консейсан-да-Барра,Կոնսեյսան դա Բառա,কোন্সেইকয়াও ডা বার্রা,კონსეისან-და-ბარა,康塞桑達巴拉', -18.5933300, -39.7322200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8806, 'Colorado', 'Colorado', '', -22.8375000, -51.9730600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8807, 'Colombo', 'Colombo', 'Kolombo,Kolombu,ge lun bu,kollombu,kolomabo,koronbo,Коломбо,Коломбу,কোলোমবো,コロンボ,哥伦布,콜롬부', -25.2916700, -49.2241700, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8808, 'Colatina', 'Colatina', 'Colatina,Collatina,Kolatina,QCH,kolatina,qwltynh,Колатина,קולטינה,কোলাটিনা', -19.5394400, -40.6305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8809, 'Cocal', 'Cocal', '', -28.6032100, -49.3276700, 'BR', '2013-05-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8810, 'Coaraci', 'Coaraci', 'Guaraci,Itacare,Itacaré,Quaraci', -14.6408300, -39.5511100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8811, 'Clevelândia', 'Clevelandia', '', -26.3958300, -52.4708300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8812, 'Cláudio', 'Claudio', '', -20.4433300, -44.7658300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8813, 'Cipó', 'Cipo', 'Sipo,Sipó', -11.0997200, -38.5136100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8814, 'Cidreira', 'Cidreira', '', -30.1811100, -50.2055600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8815, 'Cícero Dantas', 'Cicero Dantas', 'Bom Conselho', -10.6000000, -38.3833300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8816, 'Cianorte', 'Cianorte', 'Sianorte,Сианорте', -23.6633300, -52.6050000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8817, 'Chuí', 'Chui', 'Chuy,Xui,Xuí', -33.6911100, -53.4566700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8818, 'Chopinzinho', 'Chopinzinho', 'Chopim,Chopin', -25.8558300, -52.5233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8819, 'Charqueadas', 'Charqueadas', 'Charqueada,Pacencia,Xarqueada,Xarqueda', -29.9547200, -51.6252800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8820, 'Charqueada', 'Charqueada', 'Chargeada,Xarqueada', -22.5097200, -47.7780600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8821, 'Chapecó', 'Chapeco', 'Chapeco,Chapecó,Shapeko,XAP,Xapeco,Xapecó,capeko,sha pei ke,Шапеко,চাপেকো,沙佩科', -27.0963900, -52.6183300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8822, 'Chapada dos Guimarães', 'Chapada dos Guimaraes', 'Chapada,Chapada do Guimaraes,Chapada do Guimarães,Santa Ana Da Chapada,Santa Anna da Chapada,Santana da Chapada', -15.4605600, -55.7497200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8823, 'Cerro Largo', 'Cerro Largo', 'Cerro Azul', -28.1486100, -54.7380600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8824, 'Cerquilho', 'Cerquilho', '', -23.1650000, -47.7436100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8825, 'Cerqueira César', 'Cerqueira Cesar', 'Cerqueira Cezar', -23.0355600, -49.1661100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8826, 'Ceres', 'Ceres', '', -15.3083300, -49.5983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8827, 'Centralina', 'Centralina', '', -18.5838900, -49.1994400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8828, 'Centenário do Sul', 'Centenario do Sul', '', -22.8211100, -51.5952800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8829, 'Celso Ramos', 'Celso Ramos', '', -27.6344400, -51.3363900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8830, 'Caxias do Sul', 'Caxias do Sul', 'CXJ,Caxias,Caxias do Sul,Caxius do Sul,Kashias do Sul,Kashias-du-Sul,Kashijas do Sul,Kasijas do Sulas,Kašijas do Sulas,kaksa''iyasa do sula,kasiaseudusul,nan ka xi ya si,Кашиас до Сул,Кашиас-ду-Сул,Кашијас до Сул,কাক্সইয়াস ডো সুল,カシアス・ド・スル,南卡希亞斯,카시아스두술', -29.1680600, -51.1794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8831, 'Caxambu', 'Caxambu', '', -21.9772200, -44.9325000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8832, 'Cavalcante', 'Cavalcante', 'Cavalcanti', -13.7975000, -47.4583300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8833, 'Catu', 'Catu', 'Sant''Anna de Catu,Sant''Anna de Catú', -12.3530600, -38.3788900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8834, 'Catanduva', 'Catanduva', 'Catanduva,Katanduva,katanadubha,Катандува,কাটানডুভা', -21.1377800, -48.9727800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8835, 'Catalão', 'Catalao', '', -18.1658300, -47.9463900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8836, 'Cataguases', 'Cataguases', 'Cataguases,Cataguazes,Kataguazis,QCG,ka ta gua xi si,ka tak wa sis,kataguraasesa,Катагуазис,কাটাগুৱাসেস,กาตากวาซิส,卡塔瓜西斯', -21.3891700, -42.6966700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8837, 'Castro Alves', 'Castro Alves', '', -12.7655600, -39.4283300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8838, 'Castro', 'Castro', 'QAC', -24.7892700, -50.0122500, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8839, 'Castilho', 'Castilho', 'Alfredo Castilho', -20.8722200, -51.4875000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8840, 'Castelo', 'Castelo', 'Castello,Estancia do Castello,Kashtelu,Kastelo,Kastelu,ka si te lu,kasatelo,Кастелу,Каштелу,Կաստելու,কাসটেলো,კასტელუ,卡斯特盧', -20.6036100, -41.1847200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8841, 'Cassilândia', 'Cassilandia', 'CSS', -19.1133300, -51.7341700, 'BR', '2017-02-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8842, 'Cássia', 'Cassia', 'Santa Rita de Cassia', -20.5830600, -46.9219400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8843, 'Casimiro de Abreu', 'Casimiro de Abreu', 'Casemiro de Abreu,Kazimiru-di-Abreu,ka xi mi lu-di a bu lei wu,kasimiro de abre''u,Казимиру-ди-Абреу,কাসিমিরো ডে আব্রেউ,卡西米鲁-迪阿布雷乌', -22.4805600, -42.2041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8844, 'Cascavel', 'Cascavel', 'CAC,Cascavel,Kaskavel,Kaskavelas,Krotalias,Naer-ourouler,Serpentes tintinnabulati,Tłʼiish áníní,Ular derik,bang-ulbaem,ka si ka wei er,kasakabhela,mar zngy,ngu hang krading,Κροταλίας,Каскавел,עכסנים,الأفعى ذات الجرس,مار زنگی,কাসকাভেল,র‌্যাটল সাপ,റാറ്റിൽസ്നേക്,งูหางกระดิ่ง,卡斯卡韋爾,방울뱀', -24.9558300, -53.4552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8845, 'Casa Branca', 'Casa Branca', '', -21.7738900, -47.0863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8846, 'Carmo do Rio Verde', 'Carmo do Rio Verde', '', -15.3536100, -49.7075000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8847, 'Carmo do Rio Claro', 'Carmo do Rio Claro', '', -20.9719400, -46.1188900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8848, 'Carmo do Paranaíba', 'Carmo do Paranaiba', 'Carmo do Paranahyba', -19.0008300, -46.3161100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8849, 'Carmo do Cajuru', 'Carmo do Cajuru', 'Carmo de Cajuru,Carmo de Cajurú', -20.1841700, -44.7711100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8850, 'Carmo', 'Carmo', '', -21.9336100, -42.6086100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8851, 'Carlos Chagas', 'Carlos Chagas', 'Urucu,Urucú', -17.7030600, -40.7663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8852, 'Carlos Barbosa', 'Carlos Barbosa', '', -29.2975000, -51.5036100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8853, 'Carira', 'Carira', '', -10.3608300, -37.7011100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8854, 'Carinhanha', 'Carinhanha', '', -14.3047200, -43.7650000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8855, 'Cardoso', 'Cardoso', '', -20.0819400, -49.9141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8856, 'Carazinho', 'Carazinho', 'Carasinho,Karazin''ju,QRE,Каразинью', -28.2838900, -52.7863900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8857, 'Caratinga', 'Caratinga', 'Karatinga,QTL,ka la ting jia,ka ra ti ngka,karatinga,Каратинга,কারাটিঙ্গা,การาตีงกา,卡拉廷加', -19.7897200, -42.1391700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8858, 'Caarapó', 'Caarapo', 'Caarapo,Caarapó,Porto Primeiro,Porto Priméiro,Rio Primeiro', -22.6341700, -54.8222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8859, 'Carapicuíba', 'Carapicuiba', '', -23.5227200, -46.8350000, 'BR', '2013-07-09', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8860, 'Carangola', 'Carangola', 'Karangola,ka lan ge la,karanagola,Карангола,কারানগোলা,卡兰戈拉', -20.7330600, -42.0294400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8861, 'Carandaí', 'Carandai', 'Carandahy', -20.9536100, -43.8063900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8862, 'Carambeí', 'Carambei', 'Carambehy', -24.9526000, -50.1159000, 'BR', '2014-10-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8863, 'Caraí', 'Carai', 'Carahy', -17.1888900, -41.6947200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8864, 'Caraguatatuba', 'Caraguatatuba', 'Caragua,Karaguatatuba,QCQ,Карагуататуба', -23.6202800, -45.4130600, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8865, 'Capivari', 'Capivari', 'Capivary,Kapivari,Капивари', -22.9950000, -47.5077800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8866, 'Capitólio', 'Capitolio', 'Sao Sebastiao dos Franciscos,São Sebastião dos Franciscos', -20.6152800, -46.0500000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8867, 'Capinzal', 'Capinzal', 'Rio Capinzal', -27.3436100, -51.6119400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8868, 'Capinópolis', 'Capinopolis', '', -18.6819400, -49.5697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8869, 'Capim Grosso', 'Capim Grosso', '', -11.3811100, -40.0127800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8870, 'Capelinha', 'Capelinha', 'Capellinha,Kapelin''ja,ka pei li ni ya,kapelinaha,Капелинья,কাপেলিনহা,卡佩利尼亚', -17.6913900, -42.5158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8871, 'Capela do Alto', 'Capela do Alto', '', -23.4705600, -47.7347200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8872, 'Capela', 'Capela', 'Capella', -10.5033300, -37.0527800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8873, 'Capão da Canoa', 'Capao da Canoa', 'Capo da Canoa', -29.7455600, -50.0097200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8874, 'Capâo Bonito', 'Capao Bonito', '', -24.0058300, -48.3494400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8875, 'Cantagalo', 'Cantagalo', 'Cantagallo', -21.9811100, -42.3680600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8876, 'Canoinhas', 'Canoinhas', 'Ouro Verde', -26.1772200, -50.3900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8877, 'Canoas', 'Canoas', 'Canoas,Kanoas,Kanoasas,ka nuo a si,kanoasu,kanoyasa,Каноас,কানোয়াস,カノアス,卡諾阿斯', -29.9177800, -51.1836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8878, 'Canguçu', 'Cangucu', 'Cangussu,Cangussú', -31.3950000, -52.6755600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8879, 'Canela', 'Canela', 'Canella,Kanela,QCN,Канела', -29.3562200, -50.8135700, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8880, 'Cândido Mota', 'Candido Mota', 'Candido Motta', -22.7463900, -50.3869400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8881, 'Cândido de Abreu', 'Candido de Abreu', '', -24.5669400, -51.3333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8882, 'Candelária', 'Candelaria', '', -29.6691700, -52.7888900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8883, 'Canavieiras', 'Canavieiras', 'CNV,Cannavieiras', -15.6750000, -38.9472200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8884, 'Canarana', 'Canarana', 'Canabrava do Miranda,Canna Brava do Miranda,Miranda', -11.6847200, -41.7688900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8885, 'Cananéia', 'Cananeia', 'Cananea,Cananéa', -25.0147200, -47.9266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8886, 'Campo Verde', 'Campo Verde', '', -20.4166700, -54.0666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8887, 'Campos Novos', 'Campos Novos', 'Kampus-Novus,kamposa nobhosa,kan pu si nuo wu si,Кампус-Новус,কাম্পোস নোভোস,坎普斯诺武斯', -27.4016700, -51.2250000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8888, 'Campos Gerais', 'Campos Gerais', 'Campos Geraes,Kampus-Zherajs,Кампус-Жерайс', -21.2350000, -45.7586100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8889, 'Campos do Jordão', 'Campos do Jordao', 'Kampus-du-Zhordau,kamposa do jorda''o,kan pu si-du ruo er dang,Кампус-ду-Жордау,কাম্পোস ডো জোর্ডাও,カンポス・ド・ジョルドン,坎普斯-杜若尔当', -22.7394400, -45.5913900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8890, 'Campos Belos', 'Campos Belos', 'Campos Bellos', -13.0366700, -46.7716700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8891, 'Campos Altos', 'Campos Altos', '', -19.6961100, -46.1713900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8892, 'Campos dos Goytacazes', 'Campos dos Goytacazes', 'CAW,Campos dos Goitacazes,Campos dos Goytacazes,Kampos,Kampus-dus-Gojtakazis,Sao Salvador dos Campos,São Salvador dos Campos,kamposa dosa goyatakajasa,kan pu si ge yi ta ka ji si,Кампос,Кампус-дус-Гойтаказис,Кампус-дус-Гойтаказіс,কাম্পোস ডোস গোয়টাকাজাস,坎普斯戈伊塔卡濟斯', -21.7522700, -41.3304400, 'BR', '2016-11-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8893, 'Campo Mourão', 'Campo Mourao', 'CBW,Mourao,Mourão', -24.0430900, -52.3792900, 'BR', '2017-02-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8894, 'Campo Largo', 'Campo Largo', 'Kampu-Largu,kampo largo,kan pu la gu,Кампу-Ларгу,কাম্পো লার্গো,坎普拉古', -25.4595500, -49.5301400, 'BR', '2014-10-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8895, 'Campo Grande', 'Campo Grande', 'CGR,Campo Grande,Campus Magnus,Gorad Kampu-Grandy,Kampo Grande,Kampo Grandi,Kampo Grandė,Kampu-Grande,Kampu-Grandi,Kampu-Grandy,ge lan de ying,kambw ghrandy,kampo grande,kampugeulanji,kampwgrandh,kang pu krang ci,kympw grandے,kʼampʼu-grandi,qmpw grʼndh,Горад Кампу-Гранды,Кампо Гранде,Кампо Гранди,Кампу-Гранде,Кампу-Гранди,Кампу-Гранды,Кампу-Гранді,קמפו גראנדה,كامبو غراندي,کامپوگرانده,کیمپو گراندے,কাম্পো গ্রান্ডে,กังปูกรังจี,კამპუ-გრანდი,カンポ・グランデ,格蘭德營,캄푸그란지', -20.4427800, -54.6463900, 'BR', '2014-01-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8896, 'Campo Grande', 'Campo Grande', '', -10.2333300, -36.5000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8897, 'Campo Formoso', 'Campo Formoso', '', -10.5075000, -40.3213900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8898, 'Campo do Brito', 'Campo do Brito', '', -10.7333300, -37.4933300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8899, 'Campo Belo', 'Campo Belo', 'Campo Bello,Kampu-Belu,kampo belo,kan pu bei lu,Кампу-Белу,কাম্পো বেলো,坎普贝卢', -20.8972200, -45.2772200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8900, 'Campina Verde', 'Campina Verde', '', -19.5379100, -49.4881300, 'BR', '2015-06-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8901, 'Campinas', 'Campinas', 'CPQ,Campinas,Campinas e Regiao,Campinas e Região,Conceicao de Campinas,Conceição de Campinas,Gorad Kampinas,Kampinas,Kampinasas,Regiao de Campinas,Região de Campinas,kamapinasa,kambynas,kampinaseu,kan pi na si,kanpinasu,kmpynas,Горад Кампінас,Кампинас,Кампінас,קמפינאס,كامبيناس,کمپیناس,কামপিনাস,კამპინასი,カンピーナス,坎皮纳斯,캄피나스', -22.9055600, -47.0608300, 'BR', '2017-07-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8902, 'Campina Grande do Sul', 'Campina Grande do Sul', 'Campina Grande,Kampina-Grande-du-Sul,Kampina-Grandi-du-Sul,Timbu,kamapina grande do sula,nan da kan pi na,Кампина-Гранде-ду-Сул,Кампина-Гранди-ду-Сул,কামপিনা গ্রান্ডে ডো সুল,南大坎皮纳', -25.3055600, -49.0552800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8903, 'Campestre', 'Campestre', 'Compestre', -21.7111100, -46.2463900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8904, 'Campanha', 'Campanha', '', -21.8361100, -45.4005600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8905, 'Cambuquira', 'Cambuquira', '', -21.8522200, -45.2958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8906, 'Cambuí', 'Cambui', 'Cambuhy', -22.6122200, -46.0575000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8907, 'Cambuci', 'Cambuci', 'Cambucy', -21.5752800, -41.9111100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8908, 'Cambé', 'Cambe', 'Nova Dantzig', -23.2758300, -51.2783300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8909, 'Cambará', 'Cambara', '', -23.0463900, -50.0736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8910, 'Camaquã', 'Camaqua', 'Sao Joao de Camaquam,São João de Camaquam', -30.8511100, -51.8122200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8911, 'Camapuã', 'Camapua', 'Camapoa,Camapoan,Camapoã,Camapuan,Camaquam', -19.5313900, -54.0438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8912, 'Camanducaia', 'Camanducaia', 'Jaguary', -22.7552800, -46.1447200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8913, 'Camamu', 'Camamu', '', -13.9447200, -39.1038900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8914, 'Camaçari', 'Camacari', 'Camacari,Camacary,Camassari,Camassary,Camaçari,Kamasari,QCC,ka ma sa li,kamakari,kamasari,Камасари,কামাকারি,კამასარი,カマサリ,卡馬薩里', -12.6975000, -38.3241700, 'BR', '2015-05-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8915, 'Caldas Novas', 'Caldas Novas', 'CLV,Kaldas-Novas,Koldas Novas,ka er da si nuo wa si,kaladasa nobhasa,Калдас-Новас,Կոլդաս Նովաս,কালডাস নোভাস,კალდას-ნოვასი,卡尔达斯诺瓦斯', -17.7443100, -48.6278900, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8916, 'Cajuru', 'Cajuru', '', -21.2752800, -47.3041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8917, 'Cajati', 'Cajati', '', -24.7361100, -48.1227800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8918, 'Cajamar', 'Cajamar', 'Agua Fria,Água Fria', -23.3561100, -46.8769400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8919, 'Caieiras', 'Caieiras', '', -23.3641700, -46.7405600, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8920, 'Caiapônia', 'Caiaponia', 'Rio Bonito,Torres Do Rio Bonito', -16.9566700, -51.8102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8921, 'Cafelândia', 'Cafelandia', '', -21.8025000, -49.6100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8922, 'Cafarnaum', 'Cafarnaum', 'Capernaum,Capernaúm', -11.6936100, -41.4683300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8923, 'Caetité', 'Caetite', 'Caitete,Caiteté,Kaehtite,ka ai di te,kayetite,Каэтите,কায়েটিটে,კაეტიტე,卡埃蒂特', -14.0694400, -42.4750000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8924, 'Caeté', 'Caete', 'Kaehte,Каэте', -19.8800000, -43.6697200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8925, 'Caculé', 'Cacule', '', -14.5033300, -42.2222200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8926, 'Caçu', 'Cacu', 'Cassu,Cassú', -18.5566700, -51.1308300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8927, 'Caconde', 'Caconde', '', -21.5294400, -46.6438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8928, 'Cachoeiro de Itapemirim', 'Cachoeiro de Itapemirim', 'CDI,Cacheiro,Cachoeiro de Itapemirim,Cachoeiro do Itapemirim,Kashuehjru-di-Itapemirin,Kasoeiro de Itapemirinas,Kašoeiro de Itapemirinas,QXD,aytabymyrym dy katshwyrw,kakahoye''iro de itapemirima,qswʼyyrw dh ʼytpmyryn,Кашуэйру-ди-Итапемирин,קשואיירו דה איטפמירין,ايتابيميريم دي كاتشويرو,কাকহোয়েইরো ডে ইটাপেমিরিম,カショエイロ・ジ・イタペミリン', -20.8488900, -41.1127800, 'BR', '2014-04-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8929, 'Cachoeirinha', 'Cachoeirinha', 'Cachoeirinha', -29.9511100, -51.0938900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8930, 'Cachoeiras de Macacu', 'Cachoeiras de Macacu', 'Cachoeiras', -22.4625000, -42.6530600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8931, 'Cachoeira do Sul', 'Cachoeira do Sul', 'Cachoeira,Kashuehjra-du-Sul,Кашуэйра-ду-Сул', -30.0391700, -52.8938900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8932, 'Cachoeira', 'Cachoeira', 'CCQ,Cachoeira,Kashuehjra,ka shu ai la,kakahoye''ira,Кашуэйра,কাকহোয়েইরা,კაშუეირა,卡舒埃拉', -12.6013900, -38.9657600, 'BR', '2016-03-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8933, 'Cacequi', 'Cacequi', 'Cacequy', -29.8836100, -54.8250000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8934, 'Caçapava do Sul', 'Cacapava do Sul', 'Cacapava,Caçapava,Kasapava-du-Sul,kakapabha do sula,nan ka sa pa wa,Касапава-ду-Сул,কাকাপাভা ডো সুল,南卡萨帕瓦', -30.5143600, -53.4849600, 'BR', '2014-10-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8935, 'Caçapava', 'Cacapava', '', -23.1008300, -45.7069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8936, 'Caçador', 'Cacador', 'CFC,Cacador,Caçador,Kasador,Rio Cacador,Rio Caçador,ka sa duo er,kakador,Касадор,কাকাডোর্,卡萨多尔', -26.7752800, -51.0150000, 'BR', '2013-05-16', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8937, 'Cabreúva', 'Cabreuva', 'Cabriuva,Cabriúva,Kabreuva,Кабреува', -23.3075000, -47.1327800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8938, 'Cabo Frio', 'Cabo Frio', 'CFB,Cabo Frio,Cabo Frío,Caput Frigidum,Kabu-Friu,QCK,ka bo fu li ao,kabo phri''o,Кабу-Фриу,কাবো ফ্রিও,卡波弗里奧', -22.8871700, -42.0262200, 'BR', '2016-06-19', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8939, 'Butiá', 'Butia', 'Butio,Butió', -30.1197200, -51.9622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8940, 'Buritizeiro', 'Buritizeiro', '', -17.3511100, -44.9622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8941, 'Buritis', 'Buritis', 'Burity', -15.6177800, -46.4233300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8942, 'Buriti Alegre', 'Buriti Alegre', 'Burity Alegre', -18.1400000, -49.0402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8943, 'Buritama', 'Buritama', '', -21.0661100, -50.1472200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8944, 'Buri', 'Buri', 'Buri,Bury,bu li,buri,Бури,বুরি,布里', -23.7975000, -48.5927800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8945, 'Boquim', 'Boquim', 'Boquim', -11.1469400, -37.6205600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8946, 'Buerarema', 'Buerarema', 'Buerarama,Macuco', -14.9594400, -39.2997200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8947, 'Bueno Brandão', 'Bueno Brandao', 'Campo Mistico,Campo Mystico,Campo Místico', -22.4408300, -46.3508300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8948, 'Brusque', 'Brusque', 'Bruski,brusakuye,bu lu si ke,Бруски,ব্রুসকুয়ে,布吕斯克', -27.0979500, -48.9128100, 'BR', '2015-06-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8949, 'Brumado', 'Brumado', 'BMS,Bom Jesus dos Meiras,Bom Jesús dos Meiras,Brumadu,brumado,brumadu,bu lu ma du,Брумаду,ব্রুমাডো,ბრუმადუ,布鲁马杜', -14.2036100, -41.6652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8950, 'Brumadinho', 'Brumadinho', '', -20.1433300, -44.1997200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8951, 'Brotas', 'Brotas', '', -22.2841700, -48.1266700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8952, 'Brodósqui', 'Brodosqui', 'Brodovsky,Brodowski', -20.9913900, -47.6586100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8953, 'Brasília de Minas', 'Brasilia de Minas', 'Brasilia,Brasília,Brazilia,Brazilija-di-Minas,Бразилия-ди-Минас', -16.2063900, -44.4333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8954, 'Brasília', 'Brasilia', 'BSB,Bahsihleihya,Brasilia,Brasiliopolis,Brasilía,Brasília,Braxilia,Braxiłia,Braxìlia,Brazileje,Brazilia,Braziliavaros,Brazilija,Brazilija shaary,Brazilja,Braziljo,Brazilėjė,Brazília,Brazíliaváros,Breselya,Bràsílíà,Gorad Brazilija,Mprazilia,ba xi li ya,beulajillia,bra si leiy,brajhiliya,brasili''a,brasiliya,brasylya,brazili''a,brazilia,brazylya,bresiliya,brzylyh,burajiria,byrazylya,piraciliya,Μπραζίλια,Бразилиа,Бразилия,Бразилия шаары,Бразилија,Бразиліа,Горад Бразілія,Ҳавзаи федералии Бразилиа,Բրազիլիա,בראזיליא,ברזיליה,بئرازیلیا,برازيليا,برازیلیا,برازیلیہ,براسیلیا,بەڕازیلیا,ބްރަސީލިއާ,ब्रसिलिया,ब्राझिलिया,ब्रासीलिया,ব্রাসিলিয়া,ਬ੍ਰਾਜ਼ੀਲੀਆ,ବ୍ରାସିଲିଆ,பிரசிலியா,ಬ್ರೆಸಿಲಿಯಾ,ബ്രസീലിയ,บราซีเลีย,པུ་རུ་ཟི་ལི་ཡ།,ဘရာစေးလေးယားမြို့,ბრაზილია,ብራዚሊያ,ブラジリア,巴西利亚,巴西利亞,브라질리아', -15.7797200, -47.9297200, 'BR', '2012-11-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8955, 'Bragança Paulista', 'Braganca Paulista', 'BJP,Baraganca,Baragança,Braganca,Bragansa-Paulista,Bragança,bra kang sa pea li s ta,braga''anaka pa''ulista,bu la gan sa-bao li si ta,Браганса-Паулиста,ব্রাগআনকা পাউলিস্টা,บรากังซาเปาลิสตา,布拉干薩-保利斯塔', -22.9527000, -46.5441800, 'BR', '2015-06-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8956, 'Braço do Norte', 'Braco do Norte', 'Brasu-du-Norti,bei bu la suo,brako do norte,Брасу-ду-Норти,ব্রাকো ডো নোর্টে,北布拉索', -28.2750000, -49.1655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8957, 'Botucatu', 'Botucatu', 'Botucatu,Botukatu,QCJ,bo tu ka tu,botukatu,Ботукату,বোটুকাটু,博图卡图', -22.8858300, -48.4450000, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8958, 'Botelhos', 'Botelhos', 'Sao Jose dos Botelhos,São José dos Botelhos', -21.6333300, -46.3950000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8959, 'Borda da Mata', 'Borda da Mata', 'Borda da Matta', -22.2741700, -46.1652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8960, 'Borborema', 'Borborema', '', -21.6197200, -49.0736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8961, 'Boracéia', 'Boraceia', 'Floresta', -22.1930600, -48.7788900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8962, 'Boquira', 'Boquira', 'Assuncao,Assuncão', -12.8230600, -42.7305600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8963, 'Bonito', 'Bonito', 'BYO,Bonito,Bonitu,bo ni ta,bonito,Бониту,Բոնիտու,বোনিটো,ბონიტუ,博尼塔', -21.1211100, -56.4819400, 'BR', '2013-05-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8964, 'Bom Sucesso', 'Bom Sucesso', 'Bom Successo', -21.0330600, -44.7580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8965, 'Bom Jesus dos Perdões', 'Bom Jesus dos Perdoes', 'Ajuritiba,Perdoes,Perdões', -23.1350000, -46.4652800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8966, 'Bom Jesus do Itabapoana', 'Bom Jesus do Itabapoana', 'Bom Jesus de Itabapoana,Bon-Zhezus-du-Itabapoana,Бон-Жезус-ду-Итабапоана', -21.1338900, -41.6797200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8967, 'Bom Jesus do Galho', 'Bom Jesus do Galho', '', -19.8288900, -42.3161100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9214, 'West End', 'West End', 'WTD,West End,West End Settlement', 26.6871100, -78.9770200, 'BS', '2014-09-21', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9215, 'Spanish Wells', 'Spanish Wells', 'SWL,Spanish Wells,Spanish Wells Settlement', 25.5471700, -76.7640500, 'BS', '2014-01-19', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9216, 'San Andros', 'San Andros', 'SAQ,San Andros,San Andros Bahama Village', 25.0666700, -78.0500000, 'BS', '2013-08-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9217, 'Port Nelson', 'Port Nelson', 'Port Nelson,RCY', 23.6496700, -74.8415700, 'BS', '2014-01-18', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9218, 'Nassau', 'Nassau', 'City of Nassau,Gorad Nasau,NAS,Nasau,Nasauo,Nasaŭo,Naso,Nassaou,Nassau,Nassau City,Nassau pa Bahamas,Nassau på Bahamas,Nasáu,na sao,nasa''u,nasau,nasaw,nasayw,nasea,naso,nasso,neco,nsaw,Νασσάου,Горад Насау,Насау,Нассау,Նասաու,נסאו,ناسائو,ناساو,نساؤ,नासाउ,নাসাউ,ਨਸਾਊ,நேசோ,നാസോ,แนสซอ,ན་སའོ།,ნასაუ,ናሶ,ナッソー,拿騷,拿骚,나사우,나소', 25.0582300, -77.3430600, 'BS', '2017-07-05', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9219, 'Matthew Town', 'Matthew Town', 'IGA,Mathew Town,Matthew Town', 20.9498200, -73.6734600, 'BS', '2014-01-18', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9220, 'Masons Bay', 'Masons Bay', '', 22.5435200, -73.8778000, 'BS', '2013-07-11', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9221, 'Marsh Harbour', 'Marsh Harbour', 'MHH,Marsh Harbour', 26.5412400, -77.0636000, 'BS', '2014-01-18', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9222, 'Lucaya', 'Lucaya', 'Lucaya', 26.5333300, -78.6666700, 'BS', '2012-01-18', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9223, 'High Rock', 'High Rock', 'High Rock,High Rock Village,High Rocks', 26.6099900, -78.2786300, 'BS', '2013-05-05', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9224, 'Hard Bargain', 'Hard Bargain', 'Hard Bargain,Hard Bargin', 26.3166700, -77.5666700, 'BS', '2012-02-12', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9225, 'Governor’s Harbour', 'Governor''s Harbour', 'Governor Harbor,Governor Harbour,Governor''s Harbour,Governors Harbor,Governor’s Harbour', 25.1666700, -76.2333300, 'BS', '2013-07-07', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9226, 'George Town', 'George Town', 'GGT,George Town', 23.5161600, -75.7866500, 'BS', '2013-08-02', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9227, 'Freeport', 'Freeport', 'FPO,Freeport,Freeport City,Friport,Фрипорт', 26.5333300, -78.7000000, 'BS', '2014-10-15', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9228, 'Dunmore Town', 'Dunmore Town', 'Dunmore Town,Harbour Island', 25.5021600, -76.6363300, 'BS', '2014-01-19', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9229, 'Duncan Town', 'Duncan Town', 'DCT,Duncan Town', 22.1908300, -75.7258300, 'BS', '2013-05-05', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9230, 'Cooper’s Town', 'Cooper''s Town', 'Cooper''s Town,Cooper’s Town', 26.8713700, -77.5113100, 'BS', '2016-04-10', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9231, 'Colonel Hill', 'Colonel Hill', 'CRI,Colonel Hill', 22.7545000, -74.2041500, 'BS', '2013-05-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9232, 'Cockburn Town', 'Cockburn Town', 'Cockburn Town,Riding Rocks', 24.0517900, -74.5313800, 'BS', '2015-03-01', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9233, 'Clarence Town', 'Clarence Town', 'Clarence,Clarence Town', 23.1000000, -74.9833300, 'BS', '2012-02-19', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9234, 'Black Point', 'Black Point', '', 24.1000000, -76.3833300, 'BS', '2013-08-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9235, 'Arthur’s Town', 'Arthur''s Town', 'ATC,Arthur Town,Arthur''s Town,Arthur’s Town', 24.6224000, -75.6715100, 'BS', '2013-08-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9236, 'Andros Town', 'Andros Town', 'ASD,Andros Town,Fresh Creek', 24.7050200, -77.7691200, 'BS', '2016-10-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9237, 'Alice Town', 'Alice Town', 'Alice Town', 25.7280000, -79.2972100, 'BS', '2015-08-11', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9238, 'Abraham’s Bay', 'Abraham''s Bay', 'Abraham Bay,Abraham''s Bay,Abraham’s Bay,The Charlton', 22.3666700, -72.9666700, 'BS', '2013-08-08', 17);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9350, 'Indura', 'Indura', 'Indura,Індура,Индура', 53.4605000, 23.8823000, 'BY', '2013-07-11', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9351, 'Skidal’', 'Skidal''', 'Skidal'',Skidal’,Skidel'',Skidel’,Скидель,Скідаль', 53.5904000, 24.2478000, 'BY', '2012-02-01', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9352, 'Znamenka', 'Znamenka', 'Durichi,Durychy,Znamenka,Дуричи,Дурычы,Знаменка', 51.8816800, 23.6554500, 'BY', '2016-01-13', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9353, 'Horad Zhodzina', 'Horad Zhodzina', 'Gorad Zhodzina,Gorod Zhodino,Horad Zhodzina,Schodsina,Zhodino,Zhodzina,Zodino,Zodzina,Żodino,Горад Жодзіна,Жодзiна,Жодзіна,Жодино', 54.0985000, 28.3331000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9354, 'Zhlobin', 'Zhlobin', 'Korpilovka,Zhlobin,Zlobin,Жлобин,Жлобін', 52.8926000, 30.0240000, 'BY', '2012-02-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9355, 'Zhytkavichy', 'Zhytkavichy', 'Gorad Zhytkavichy,Jitkovichi,Jytkavitchy,Zhitkavichi,Zhitkovichi,Zhytkavichy,Zhytkavychy,Zjytkavytjy,Zytkavicai,Zytkavicy,Zytkavitsy,Zytkowicze,Żytkowicze,Žytkavitšy,Žytkavičai,Žytkavičy,Горад Жыткавічы,Житкавичи,Житковичи,Житковичі,Жыткавычы', 52.2168000, 27.8561000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9356, 'Zhyrovichy', 'Zhyrovichy', 'Zhirovichi,Zhirovitsy,Zhyrovichy,Zhyrovitse,Zyrowice,Żyrowice,Жировичи,Жыровічы', 53.0131000, 25.3443000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9357, 'Zhaludok', 'Zhaludok', 'Zhaludok,Zheludok,Zholudok,Zoludek,Żołudek,Жалудок,Желудок', 53.5974000, 24.9828000, 'BY', '2016-08-31', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9358, 'Zhdanovichy', 'Zhdanovichy', 'Zhdanovicha,Zhdanovichi,Zhdanovichy,Ждановичи,Ждановічы', 53.9432000, 27.4250000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9359, 'Zhabinka', 'Zhabinka', 'Stara Sabinka,Zabinaa,Zabinka,Zhabinka,Żabinka,Жабинка,Жабінка', 52.1984000, 24.0115000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9360, 'Zyembin', 'Zyembin', 'Zembin,Zyembin,Зембин,Зембін', 54.3579000, 28.2207000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9361, 'Zel’va', 'Zel''va', 'Zehl''va,Zel''va,Zelwa,Zel’va,Зельва,Зэльва', 53.1504000, 24.8153000, 'BY', '2013-06-04', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9362, 'Zaslawye', 'Zaslawye', 'Gorad Zaslaue,Saslauje,Zaslaue,Zaslauje,Zaslav,Zaslavje,Zaslavl'',Zaslavl’,Zaslavul,Zaslaw,Zaslawye,Zaslaŭje,Zasław,Zasłaŭje,zasuraue,zha si la fu er,Горад Заслаўе,Заславль,Заславъл,Заславје,Заслаўе,זסלאוויה,ザスラーウエ,扎斯拉夫爾', 54.0114000, 27.2695000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9363, 'Zamostochcha', 'Zamostochcha', 'Zamostoch''ye,Zamostochcha,Zamostoch’ye,Замосточча', 53.8198000, 27.8685000, 'BY', '2012-03-25', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9364, 'Yel’sk', 'Yel''sk', 'El''sk,Elsk,Karolin,Yel''sk,Yel’sk,Ельск', 51.8141000, 29.1522000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9365, 'Yalizava', 'Yalizava', 'Elizovo,Jalizava,Oktyabr'',Oktyabr’,Yalizava,Yelizovo,Елизово,Ялізава', 53.3994000, 29.0048000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9366, 'Vysokaye', 'Vysokaye', 'Vysokae,Vysokaye,Vysoke-Litevske,Vysoko-Litovsk,Vysokoe,Vysokoye,Wysokie Litewski,Wysokie Litewskie,Wysokie Litowski,Высокае,Высокое', 52.3709100, 23.3708300, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9367, 'Voranava', 'Voranava', 'Varanavas,Verenov,Voranava,Voronov,Voronovo,Voronuv,Werenow,Werenów,Воранава,Вороново', 54.1492000, 25.3112000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9368, 'Vitebsk', 'Vitebsk', 'VTB,Vicebsk,Vicebsko,Vicebszk,Viciebsk,Vit''b''sku,Vitebs''k,Vitebscum,Vitebsk,Vitebska,Vitebskas,Vitepsk,Vitsebsk,Vitsemp''sk,Vitsiebsk,Vitsyebsk,Vítebsk,Vítsiebsk,Witebsk,Wizebsk,bichebseukeu,fytybsk,vu~itsu~epusuku,wei jie bu si ke,wi tebskh,wtybsk,wytbsq,Βιτσέμπσκ,Витебск,Витепск,Витьбьскъ,Вітебськ,Віцебск,Վիտեբսկ,וויטעבסק,ויטבסק,فيتيبسك,وتیبسک,วีเต็บสค์,ვიტებსკი,ヴィーツェプスク,维捷布斯克,비쳅스크', 55.1904000, 30.2049000, 'BY', '2014-03-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9369, 'Vishow', 'Vishow', 'Khutora Vishovskiye,Vishou,Vishov,Vishovo,Vishow,Вишов,Вішоў', 53.9805000, 29.9925000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9370, 'Vishnyeva', 'Vishnyeva', 'Vishnev,Vishneva,Vishnevo,Vishnyeva,Wiszniew,Вишнево,Вішнева', 54.7102000, 26.5228000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9371, 'Vilyeyka', 'Vilyeyka', 'Vileika,Vilejka,Vileyka,Vilyeyka,Wilejka,Вилейка,Вілейка', 54.4914000, 26.9111000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9372, 'Vidzy', 'Vidzy', 'Vidze,Vidziai,Vidzy,Vidžiai,Widze,Видзы,Відзы', 55.3945000, 26.6305000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9373, 'Veyno', 'Veyno', 'Veina,Vejno,Вейно', 53.8333300, 30.3833300, 'BY', '2012-04-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9374, 'Vyetka', 'Vyetka', 'Vetka,Vyetka,Ветка', 52.5591000, 31.1794000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9375, 'Vyerkhnyadzvinsk', 'Vyerkhnyadzvinsk', 'Drissa,Dryassa,Verkhnedvinsk,Verkhnjadzvinsk,Vyerkhnyadzvinsk,Верхнедвинск,Верхнядзвінск', 55.7777000, 27.9389000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9376, 'Vawkavysk', 'Vawkavysk', 'Gorad Vaukavysk,Valkaviskas,Vaukavisk,Vaukavysk,Vavkavisk,Vavkaviska,Vavkaviszk,Vawkavysk,Vaŭkavisk,Vaŭkavysk,Volkovisk,Volkovysk,Vovkovis''k,Waukawysk,Wolkowysk,Wołkowysk,fawkafysk,vu~aukavu~isuku,wa fu ka wei si ke,wawkwysk,wwlqwbysq,Вавкависк,Ваўкавыск,Вовковиськ,Волковиск,Волковыск,Горад Ваўкавыск,וואלקאוויסק,וולקוביסק,فاوكافيسك,واوکویسک,ヴァウカヴィスク,瓦夫卡維斯克', 53.1561000, 24.4513000, 'BY', '2014-04-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9377, 'Vasilyevichy', 'Vasilyevichy', 'Vasilevichi,Vasilevichy,Vasilyevichy,Василевичи,Васілевічы', 52.2512000, 29.8288000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9378, 'Valozhyn', 'Valozhyn', 'Valozhyn,Volozhin,Volozhy''n,Volozhy’n,Wolozyn,Wołożyn,Валожын,Воложин', 54.0892000, 26.5266000, 'BY', '2014-03-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9379, 'Uzda', 'Uzda', 'Uzda,Узда', 53.4627000, 27.2137000, 'BY', '2012-03-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9380, 'Ushachy', 'Ushachy', 'Garadski pasjolak Ushachy,Usacy,Usatsy,Ushach'',Ushachi,Ushachy,Ushach’,Usjatjy,Uszacz,Ušatšy,Ušačy,wu sha qi,Гарадскі пасёлак Ушачы,Ушачи,Ушачы,Ушачі,אושאצי,烏沙奇', 55.1790000, 28.6158000, 'BY', '2014-09-12', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9381, 'Urechcha', 'Urechcha', 'Urech''e,Urech''ye,Urechcha,Urech’ye,Urehchcha,Uretschje,Уречье,Урэчча', 52.9479000, 27.8930000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9382, 'Turaw', 'Turaw', 'Turau,Turaw,Turov,Turow,Тураў,Туров', 52.0683000, 27.7350000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9383, 'Talachyn', 'Talachyn', 'Talachyn,Tolochin,Tolochino,Талачын', 54.4087000, 29.6955000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9384, 'Tsimkavichy', 'Tsimkavichy', 'Cimkavichy,Timkovichi,Tsimkavichy,Тимковичи,Цімкавічы', 53.0672000, 26.9902000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9385, 'Tsyelyakhany', 'Tsyelyakhany', 'Celjakhany,Telechany,Telekhany,Tsyelyakhany,Телеханы,Целяханы', 52.5175000, 25.8429000, 'BY', '2015-06-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9386, 'Svislach', 'Svislach', 'Gorad Svislach,Svislac,Svislaca,Svislach,Svislatch,Svislatj,Svislats,Svislatš,Svislača,Svisloch,Svisloch'',Svisloch’,Svislocius,Svisločius,Svisłač,Swislocz,Szviszlacs,si wei si luo qi,swwyslwz,Świsłocz,Горад Свіслач,Свислач,Свислоч,Свислочь,Свіслач,Свіслоч,סוויסלוץ,סיסלעוויטש,斯維斯洛奇', 53.0368000, 24.0957000, 'BY', '2014-07-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9387, 'Svir', 'Svir', 'Svieriai,Svir,Svir'',Swir,Świr,Свирь,Свір', 54.8517000, 26.3950000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9388, 'Svyetlahorsk', 'Svyetlahorsk', 'Shatilki,Shatsilki,Svetlagorsk,Svetlogorsk,Svyetlahorsk,Светлагорск,Светлогорск', 52.6329000, 29.7389000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9389, 'Stowbtsy', 'Stowbtsy', 'Gorad Stoubcy,Stolbci,Stolbcy,Stolbtsy,Stolbtzy,Stolpcai,Stolpce,Stolptse,Stolptsy,Stolpze,Stoubcy,Stoubtsy,Stovbci,Stovpci,Stowbtsy,Stołpce,Stoŭbcy,Stoŭbtsy,Sztovbci,si tuo er bu qi,stwwbzy,stwypz,Горад Стоўбцы,Стовпци,Столбци,Столбцы,Столбці,Стоўбцы,סטוובצי,סטויפץ,斯托爾布齊', 53.4785000, 26.7434000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9390, 'Stolin', 'Stolin', 'Gorad Stolin,Stolin,Stolina,Stoline,Stoļina,si tuo lin,stwlyn,sutorin,Горад Столін,Столин,Столін,Ստոլին,סטולין,ストリン,斯托林', 51.8911500, 26.8459700, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9391, 'Staryya Darohi', 'Staryya Darohi', 'Starye Dorogi,Staryja Darogi,Staryya Darohi,Staryye Dorogi,Старые Дороги,Старыя Дарогі', 53.0402000, 28.2670000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9392, 'Starobin', 'Starobin', 'Starobin,Starobino,Старобин,Старобін', 52.7267000, 27.4606000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9393, 'Stan’kava', 'Stan''kava', 'Stan''kava,Stan''kovo,Stan’kava,Stan’kovo,Станькава', 53.6292000, 27.2290000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9394, 'Sasnovy Bor', 'Sasnovy Bor', 'Sasnovy Bor,Sasnovyj Bor,Sosnovyj Bor,Sosnovyy Bor,Сасновый Бор,Сосновый Бор', 52.5194000, 29.5988000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9395, 'Sapotskin', 'Sapotskin', 'Sapockin,Sapotskin,Sopockin,Sopockinie,Sopotskin,Sopoćkinie,Сапоцкін,Сопоцкин', 53.8329000, 23.6598000, 'BY', '2013-04-17', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9396, 'Soly', 'Soly', 'Salos,Soly,Солы', 54.5130100, 26.1938100, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9397, 'Snow', 'Snow', 'Snou,Snov,Snow,Snuv,Снов,Сноў', 53.2201000, 26.4010000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9398, 'Smarhon’', 'Smarhon''', 'Smargon'',Smarhon'',Smarhon’,Smorgon'',Smorgone,Smorgonie,Smorgon’,Smurgainys,Смаргонь,Сморгонь', 54.4798000, 26.3957000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9399, 'Horad Smalyavichy', 'Horad Smalyavichy', 'Gorad Smaljavichy,Horad Smalyavichy,Smalyavichy,Smolevichi,Smolewitsch,Горад Смалявічы,Смолевичи', 54.0249000, 28.0894000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9400, 'Smilavichy', 'Smilavichy', 'Smilavichy,Smilovichi,Смиловичи,Смілавічы', 53.7496000, 28.0115000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9401, 'Slutsk', 'Slutsk', 'Gorad Sluck,Sloetsk,Sloutsk,Sluc''k,Sluck,Slucka,Sluckas,Slutsk,Sluzk,Słuck,seullucheukeu,si lu ci ke,slutskh,slwzq,suutsuku,Горад Слуцк,Слуцк,Слуцьк,סלוצק,สลูตสค์,スウツク,斯盧茨克,슬루츠크', 53.0274000, 27.5597000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9402, 'Slonim', 'Slonim', 'Slanimas,Slonim,Slonima,Sloņima,Słonim,seullonim,si luo ni mu,slonimi,slwnym,suronimu,Слоним,Слонім,סלאנים,סלונים,სლონიმი,スロニム,斯洛尼姆,슬로님', 53.0869000, 25.3163000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9403, 'Slabada', 'Slabada', 'Slabada,Sloboda,Слабада,Слобода', 54.0087000, 27.8866000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9404, 'Slawharad', 'Slawharad', 'Gorad Slaugarad,Propoisk,Propoysk,Slaugarad,Slauharad,Slavgarad,Slavgorod,Slawharad,Slawograd,Slaŭharad,Szlavharad,Sławograd,si la fu ge luo de,surauharado,Горад Слаўгарад,Славгарад,Славгород,Слаўгарад,סלאבהראד,スラウハラド,斯拉夫哥羅德', 53.4429000, 31.0014000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9405, 'Shklow', 'Shklow', 'Shklou,Shklov,Shklow,Шклов,Шклоў', 54.2131000, 30.2877000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9406, 'Shchuchyn', 'Shchuchyn', 'Shchuchin,Shchuchyn,Shhuchin,Szczuczyn,Шчучын,Щучин', 53.6014000, 24.7465000, 'BY', '2017-05-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9407, 'Sharkawshchyna', 'Sharkawshchyna', 'Sharkaushchyna,Sharkawshchyna,Sharkovshchina,Sharkovshchizna,Sharkovshchyzna,Sharkovshhina,Sharkowshchyna,Szarkowszczyzna,Шаркаўшчына,Шарковщина', 55.3689000, 27.4686000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9408, 'Syanno', 'Syanno', 'Senno,Sjanno,Syanno,Syenno,Сенно,Сянно', 54.8108000, 29.7086000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9409, 'Syenitsa', 'Syenitsa', 'Senica,Senitsa,Sennica,Syenitsa,Сенница,Сеніца', 53.8313000, 27.5343000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9410, 'Syomkava', 'Syomkava', 'Semkovo,Sjomkava,Syomkava,Sëmkovo,Сёмкава', 54.0101000, 27.4410000, 'BY', '2012-04-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9411, 'Sarachy', 'Sarachy', 'Sarachi,Sarachy,Sorochi,Сарачы', 52.7867000, 28.0186000, 'BY', '2012-05-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9412, 'Samakhvalavichy', 'Samakhvalavichy', 'Poselok Samokhvalovichi,Posëlok Samokhvalovichi,Samakhvalavichy,Samokhvalovichi,Самахвалавічы,Самохваловичи', 53.7396000, 27.5037000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9413, 'Salihorsk', 'Salihorsk', 'Chizhevichi,Saligorsk,Salihorsk,Salihorska,Salihorskas,Salyhorsk,Saļihorska,Soligors''k,Soligorsk,Szalihorszk,salliholeuseukeu,salyhwrsk,suo li ge er si ke,Салигорск,Салігорск,Солигорск,Солігорськ,سالیهورسک,索利戈尔斯克,살리호르스크', 52.7876000, 27.5415000, 'BY', '2015-11-11', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9414, 'Ruzhany', 'Ruzhany', 'Rozana,Ruzhana,Ruzhany,Różana,Ружаны', 52.8632200, 24.8935700, 'BY', '2013-08-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9415, 'Rudzyensk', 'Rudzyensk', 'Rudensk,Rudzensk,Rudzyensk,Руденск,Рудзенск', 53.5983000, 27.8621000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9416, 'Rasony', 'Rasony', 'Rasony,Rossono,Rossony,Расоны,Россоны', 55.9058000, 28.8135000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9417, 'Ros’', 'Ros''', 'Ros'',Ross'',Ross’,Ros’,Россь,Рось', 53.2858000, 24.4128000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9418, 'Rahachow', 'Rahachow', 'Gorad Ragachou,Ragachou,Ragachov,Rahachow,Rahacou,Rahacovas,Rahatchow,Rahatjou,Rahatjoŭ,Rahatschou,Rahatsou,Rahatšou,Rahaĉoŭ,Rahačovas,Rahačoŭ,Rogachev,Rogachjov,Rogachov,Rogachëv,Rogatschew,Rohaczow,Rohaczów,luo jia qiao fu,rahachou,rhzwb,Горад Рагачоў,Рагачов,Рагачоў,Рогачев,Рогачов,Рогачёв,ראגאטשאוו,רהצוב,ラハチョウ,羅加喬夫', 53.0934000, 30.0495000, 'BY', '2012-02-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9419, 'Rechytsa', 'Rechytsa', 'Rechica,Rechitsa,Rechysta,Rechytsa,Rehchyca,Ryechitsa,Речица,Рэчыца', 52.3617000, 30.3916000, 'BY', '2012-02-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9420, 'Rakaw', 'Rakaw', 'Rakau,Rakaw,Rakov,Rakow,Rakuv,Raków,Ракаў,Раков', 53.9674000, 27.0562000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9421, 'Radashkovichy', 'Radashkovichy', 'Radashkovichy,Radoshkoviche,Radoshkovichi,Radoshkovichy,Radoszkowice,Radoszkowicze,Rodoszkowice,Радашковічы,Радошковичи', 54.1554000, 27.2412000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9422, 'Pukhavichy', 'Pukhavichy', 'Puchowitschi,Pukhavichy,Pukhovichi,Пухавічы,Пуховичи', 53.5297000, 28.2467000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9423, 'Pruzhany', 'Pruzhany', 'Pruzana,Pruzhana,Pruzhany,Пружаны', 52.5560000, 24.4573000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9424, 'Prawdzinski', 'Prawdzinski', 'Praudzinski,Pravdinskij,Pravdinskiy,Prawdzinski,Правдинский,Праўдзінскі', 53.5248000, 27.8303000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9425, 'Polatsk', 'Polatsk', 'Gorad Polack,Podolsk,Polack,Polatsk,Polazk,Poloc''k,Polock,Polocka,Polockas,Polot''sku,Polotia,Polotk,Polotsk,Polozk,Poloțk,Potolsk,Połack,Połock,Pòlatsk,Pólatsk,bo luo ci ke,pollacheukeu,poratsuku,Горад Полацк,Полацк,Полотьскъ,Полоцк,Полоцьк,Պոլոցկ,פולאצק,პოლოცკი,ポラツク,波洛茨克,폴라츠크', 55.4879000, 28.7856000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9426, 'Plyeshchanitsy', 'Plyeshchanitsy', 'Pleshchanicy,Pleshchenitsa,Pleshchenitsy,Pleshhenicy,Plyeshchanitsy,Плешчаніцы,Плещеницы', 54.4235000, 27.8301000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9427, 'Pinsk', 'Pinsk', 'Pins''k,Pinscum,Pinsk,Pinska,Pinskas,Pinszk,Pińsk,ping si ke,pinseukeu,pinsuku,pynsq,Пинск,Пінск,Пінськ,פינסק,ピンスク,平斯克,핀스크', 52.1229000, 26.0951000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9428, 'Pyatryshki', 'Pyatryshki', 'Petrishki,Pietryszki,Pjatryshki,Pyatryshki,Петришки,Пятрышкі', 54.0686000, 27.2179000, 'BY', '2012-08-31', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9429, 'Pyetrykaw', 'Pyetrykaw', 'Petrikov,Petrikovo,Petrykau,Pyetrykaw,Петриков,Петрыкаў', 52.1289000, 28.4921000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9430, 'Pastavy', 'Pastavy', 'Gorad Pastavy,Pastavi,Pastavy,Pastawy,Pastovys,Pasztavi,Postavi,Postavy,Postawy,bo si ta wei,Горад Паставы,Пастави,Постави,Поставы,פסטאווי,波斯塔維', 55.1167600, 26.8326300, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9431, 'Parychy', 'Parychy', 'Parichi,Partchi,Parychy,Паричи,Парычы', 52.8042000, 29.4176000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9432, 'Azyartso', 'Azyartso', 'Azjarco,Azyartso,Ozerco,Ozertso,Азярцо,Озерцо', 53.8397000, 27.3917000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9433, 'Osveya', 'Osveya', 'Asveja,Osveja,Osveya,Освея', 56.0147000, 28.1104900, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9434, 'Astravyets', 'Astravyets', 'Astravas,Astravec,Astravets,Astraviec,Astraviets,Astravjeca,Astravyets,Gorad Astravec,Ostrov,Ostrovec,Ostrovec'',Ostrovets,Ostrowiec,ao si te luo wei ci,Астравец,Горад Астравец,Островец,Островець,奧斯特羅韋茨', 54.6137800, 25.9553700, 'BY', '2015-01-14', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9435, 'Astrashytski Haradok', 'Astrashytski Haradok', 'Astrashycki Garadok,Astrashytski Haradok,Gorodok,Ostroshickij Gorodok,Ostroshitski Gorodok,Ostroshitskiy Gorodok,Астрашыцкі Гарадок,Острошицкий Городок', 54.0651000, 27.6950000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9436, 'Asnyezhytsy', 'Asnyezhytsy', 'Asnezhycy,Asnyezhytsy,Os''nezhitse,Osnejicy,Osnezhicy,Osnezhitsy,Osneĵicy,Osniezyce,Osnieżyce,Os’nezhitse,Аснежыцы,Оснежицы', 52.1891000, 26.1299000, 'BY', '2012-08-30', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9437, 'Asipovichy', 'Asipovichy', 'Asipopovichy,Asipovichy,Osipovichi,Ospipovichi,Ossipowitschi,Sipovichi,Асіпоповічы,Осиповичи', 53.3011000, 28.6386000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9438, 'Orsha', 'Orsha', 'Orsa,Orscha,Orsha,Orsza,Orŝa,Orša,Vorsja,ao er sha,boleusya,vu~orusha,Орша,ヴォルシャ,奥尔沙,보르샤', 54.5081000, 30.4172000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9439, 'Aktsyabrski', 'Aktsyabrski', 'Akcjabrski,Aktsyabrski,Karpilovka,Oktjabr''skij,Oktyabr''skiy,Oktyabr’skiy,Акцябрскі,Октябрьский', 52.6440000, 28.8801000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9440, 'Novy Svyerzhan’', 'Novy Svyerzhan''', 'Novy S''verzhen'',Novy Sverzhan'',Novy Svyerzhan'',Novy Svyerzhan’,Novy S’verzhen’,Novyy Sverzhen'',Novyy Sverzhen’,Swierzen Nowy,Świerżeń Nowy,Новы Свержань', 53.4542000, 26.7301000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9441, 'Kadino', 'Kadino', 'Kadino,Novyy Lyubuzh,Кадино', 53.8838900, 30.5202800, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9442, 'Novoye Medvezhino', 'Novoye Medvezhino', 'Medvezhino,Novoye Medvezhino,Медвежино', 53.8833300, 27.4500000, 'BY', '2014-06-25', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9443, 'Novosel’ye', 'Novosel''ye', 'Navaselle,Navasyellye,Novosel''e,Novosel''ye,Novosel’ye,Наваселле,Новоселье', 53.9162000, 27.2009000, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9444, 'Novolukoml’', 'Novolukoml''', 'Novolukoml'',Новолукомль', 54.6619200, 29.1501600, 'BY', '2011-02-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9445, 'Novaya Huta', 'Novaya Huta', 'Nova Guta,Novaja Guta,Novaja Huta,Novaya Guta,Novaya Huta,Нова Гута,Новая Гута', 52.1032000, 30.9837000, 'BY', '2016-01-14', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9446, 'Nasilava', 'Nasilava', 'Nasilava,Nasilovo,Nasilowo,Nasiłowo,Nosilovo,Насілава', 54.3044100, 26.7820900, 'BY', '2013-03-30', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9447, 'Nyasvizh', 'Nyasvizh', 'Gorad Njasvizh,Nes''vezh,Nesvizh,Nesvyzius,Nesvyžius,Nes’vezh,Nieswiez,Nieśwież,Njasviz,Njasvizh,Njasviž,Njaswisch,Nyasvizh,Nyaszvizs,Горад Нясвіж,Несвиж,Нясвіж', 53.2189000, 26.6779000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9448, 'Nyakhachava', 'Nyakhachava', 'Nekhachevo,Nekhachjovo,Nekhachëvo,Njakhachava,Нехачево,Нехачёво,Няхачава', 52.6440000, 25.2027000, 'BY', '2013-07-11', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9449, 'Navapolatsk', 'Navapolatsk', 'Navapolack,Navapolackas,Navapolatsk,Navapołack,Navapólatsk,Nawapolazk,Novopoloc''k,Novopolock,Novopolocka,Novopolotsk,Nowopolock,Nowopołock,Polotskiy,nabapollacheukeu,nwfwbwlwtsk,xin bo luo ci ke,Наваполацк,Новополоцк,Новополоцьк,نوفوبولوتسك,新波洛茨克,나바폴라츠크', 55.5318000, 28.5987000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9450, 'Navahrudak', 'Navahrudak', 'Gorad Navagrudak,Naugardukas,Navagrudak,Navahradak,Navahroedak,Navahroudak,Navahrudak,Navahrudaka,Nawahradak,Novogrodek,Novogroudok,Novogrudek,Novogrudok,Nowogrodek,Nowogródek,nabaheuludakeu,navu~afurudaku,nbhrdq,xin ge lu duo ke,Горад Навагрудак,Навагрудак,Новогрудок,נבהרדק,ナヴァフルダク,新格鲁多克,나바흐루다크', 53.5942000, 25.8191000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9451, 'Narowlya', 'Narowlya', 'Naroulja,Narovlya,Narowlya,Нароўля', 51.7961000, 29.5004000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9452, 'Narach', 'Narach', 'Narach,Naroch'',Naroch’,Нарач,Нарочь', 54.9102000, 26.7080000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9453, 'Narach', 'Narach', 'Narach,Naroch'',Naroch’,Narocz,Нарач,Нарочь', 54.5652000, 26.7314000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9454, 'Myshkavichy', 'Myshkavichy', 'Khutora Mishkovskiye,Mishkovskiye,Myshkavichy,Myshkovichi,Мышкавічы,Мышковичи', 53.2172000, 29.5120000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9455, 'Myadzyel', 'Myadzyel', 'Medilas,Mjadel'',Mjadzel,Myadel'',Myadel’,Myadzyel,Мядель,Мядзел', 54.8789000, 26.9371000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9456, 'Mstsislaw', 'Mstsislaw', 'Gorad Mscislau,Horad Mstsislau,Horad Mstsislaŭ,Mscislau,Mscislav,Mscislavas,Mscislaw,Mstislavl'',Mstislavl’,Mstislavul,Mstsislau,Mstsislaw,Mszislau,Mścisław,mstyslb,mu si qi si la fu,musutsu~isurau,Горад Мсціслаў,Мстиславль,Мстиславъл,Мсцислав,Мсціслаў,מסטיסלב,ムスツィスラウ,姆斯齊斯拉夫', 54.0185000, 31.7217000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9457, 'Motal’', 'Motal''', 'Motal'',Motal’,Motol'',Motol’,Моталь,Мотоль', 52.3138000, 25.6072000, 'BY', '2015-06-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9458, 'Mosar', 'Mosar', 'Mosar,Mosar'',Mosary,Mosarz,Mosazh,Мосар', 55.2232000, 27.4609000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9459, 'Mir', 'Mir', 'Garadski pasjolak Mir,Mir,Myrius,Mіr,myr,Гарадскі пасёлак Мір,Мир,Мір,מיר', 53.4544000, 26.4670000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9460, 'Myory', 'Myory', 'Mery,Miory,Miyory,Mjory,Myory,Миоры,Мёры', 55.6222000, 27.6281000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9461, 'Minsk', 'Minsk', 'Gorad Minsk,MSQ,Mins''k,Minsc,Minscum,Minsk,Minsk - Minsk,Minsk - Мінск,Minsk osh,Minska,Minskaj,Minskas,Minsko,Minszk,Mińsk,Myensk,Myenyesk,Mînsk,ming si ke,ming si ke shi,minseukeu,minsk,minsuku,mnsk,mynsk,mynsq,mynysky,Μινσκ,Горад Мінск,Минск,Минск ош,Минскай,Мінск,Мінськ,Мѣньскъ,Մինսկ,מינסק,منسک,مىنىسكى,مينسك,مینسک,मिन्‍स्‍क,மின்ஸ்க்,ಮಿನ್ಸ್ಕ್,മിൻസ്ക്,มินสก์,མིན་སིཀ།,მინსკი,ミンスク,明斯克,明斯克市,민스크', 53.9000000, 27.5666700, 'BY', '2013-11-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9462, 'Mikashevichy', 'Mikashevichy', 'Makasheviche,Mikasheviche,Mikashevichi,Mikashevichy,Mikaszewicze,Микашевичи,Мікашевічы', 52.2173000, 27.4760000, 'BY', '2013-07-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9463, 'Myazhysyatki', 'Myazhysyatki', 'Mezhisjatki,Mezhisyatki,Mjazhysjatki,Myazhysyatki,Межисятки,Мяжысяткі', 53.7776000, 30.1765000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9464, 'Mazyr', 'Mazyr', 'Masyr,Mazir,Mazira,Mazyr,Mozir,Mozyr,Mozyr'',Mozyrius,Mozyrz,Mozyr’,majileu,mazu~iru,mo ji li,moziri,Мазыр,Мозир,Мозырь,מאזיר,მოზირი,マズィル,莫济里,마지르', 52.0495000, 29.2456000, 'BY', '2014-03-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9465, 'Mosty', 'Mosty', 'Gorad Masty,Mastai,Masti,Masty,Mosti,Mosty,mo si te,Горад Масты,Масти,Масты,Мости,Мосты,莫斯特', 53.4122000, 24.5387000, 'BY', '2017-05-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9466, 'Mar’’ina Horka', 'Mar''''ina Horka', 'Mar''''ina Horka,Mar''ina Gorka,Maryina Gorka,Mar’ina Gorka,Mar’’ina Horka,Марьина Горка,Мар’іна Горка', 53.5090000, 28.1470000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9467, 'Malaryta', 'Malaryta', 'Malaryta,Malorita,Maloryta,Маларыта', 51.7905000, 24.0740000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9468, 'Maladzyechna', 'Maladzyechna', 'Maladzechna,Maladzyechna,Molodechno,Molodeczno,Маладзечна,Молодечно', 54.3167000, 26.8540000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9469, 'Mahilyow', 'Mahilyow', 'MVQ,Magiljou,Maguilov,Mahileu,Mahiliou,Mahilioŭ,Mahiljou,Mahiljov,Mahiljow,Mahiljoŭ,Mahilou,Mahiloŭ,Mahilyow,Mahilëŭ,Mogil''ov,Mogilev,Mogileva,Mogilew,Mogiliavas,Mogiliovas,Mogiljov,Mogilov,Mogilëv,Mogiļeva,Moguilev,Mohylew,Магілёў,Могилев,Могильов,Могилёв,Могиљов', 53.9168000, 30.3449000, 'BY', '2017-05-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9470, 'Machulishchy', 'Machulishchy', 'Machulische,Machulishche,Machulishchi,Machulishchy,Machulishhi,Mochulischi,Мачулищи,Мачулішчы', 53.7788000, 27.5948000, 'BY', '2012-03-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9471, 'Lyubcha', 'Lyubcha', 'Ljubcha,Lubcz,Lyubch,Lyubcha,Любча', 53.7522000, 26.0603000, 'BY', '2012-03-24', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9472, 'Lyuban’', 'Lyuban''', 'Ljuban'',Luban,Lyuban'',Lyuban’,Любань', 52.7985000, 28.0048000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9473, 'Lyntupy', 'Lyntupy', 'Lentupis,Lintupis,Lyntupy,Лынтупы', 55.0516000, 26.3103000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9474, 'Lyepyel’', 'Lyepyel''', 'Lepel'',Lepel’,Lyepyel'',Lyepyel’,Лепель', 54.8814000, 28.6990000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9475, 'Lyakhavichy', 'Lyakhavichy', 'Lachowicze,Ljakhavichy,Ljakhovichi,Lyakhavichy,Lyakhoviche,Lyakhovichi,Ляхавічы,Ляховичи', 53.0388000, 26.2656000, 'BY', '2012-03-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9476, 'Luninyets', 'Luninyets', 'Luninec,Luninets,Luniniec,Luniniez,Luninyets,Łuniniec,Лунинец,Лунінец', 52.2472000, 26.8047000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9477, 'Luhavaya Slabada', 'Luhavaya Slabada', 'Lugavaja Slabada,Lugovaya Sloboda,Lugovskaya Sloboda,Luhavaya Slabada,Лугавая Слабада', 53.7823000, 27.8434000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9478, 'Loyew', 'Loyew', 'Loeu,Loev,Lojew,Loyev,Loyew,Лоев,Лоеў', 51.9458000, 30.7953000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9479, 'Loshnitsa', 'Loshnitsa', 'Loshnica,Loshnitsa,Лошница,Лошніца', 54.2796000, 28.7649000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9480, 'Lahoysk', 'Lahoysk', 'Lagojsk,Lahoysk,Logojsk,Logoysk,Лагойск,Логойск', 54.2064000, 27.8512000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9481, 'Lyozna', 'Lyozna', 'Lezno,Liozno,Ljozna,Lyezna,Lyozna,Lyëzna,Лиозно,Лёзна', 55.0247000, 30.7970000, 'BY', '2015-03-04', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9482, 'Lida', 'Lida', 'Lida,Lieda,Lyda,li da,lida,lyda,rida,Ļida,Лида,Ліда,לידא,ليدا,ლიდა,リダ,利达,리다', 53.8833300, 25.2997200, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9483, 'Lyel’chytsy', 'Lyel''chytsy', 'Lel''chitsy,Lel''chycy,Lel’chitsy,Lyel''chytsy,Lyel’chytsy,Лельчыцы', 51.7862000, 28.3288000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9484, 'Lahishyn', 'Lahishyn', 'Lagishyn,Lahishyn,Logichin,Logishin,Logishyn,Lohiszym,Лагішын,Логишин', 52.3390000, 25.9867000, 'BY', '2013-11-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9485, 'Krychaw', 'Krychaw', 'Krichev,Krichëv,Krychau,Krychaw,Krytchev,Кричев,Крычаў', 53.7125000, 31.7170000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9486, 'Krupki', 'Krupki', 'Gorad Krupki,Kroupki,Krupka,Krupki,Krupkos,ke lu pu ji,Горад Крупкі,Крупки,Крупкі,克魯普基', 54.3178000, 29.1374000, 'BY', '2016-05-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9487, 'Kruhlaye', 'Kruhlaye', 'Kruglae,Krugloe,Krugloye,Kruhlaye,Круглае,Круглое', 54.2497000, 29.7968000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9488, 'Kryvichy', 'Kryvichy', 'Krivichi,Kryvichy,Krzywicze,Kshyviche,Кривичи,Крывічы', 54.7132000, 27.2886000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9489, 'Kreva', 'Kreva', 'Agragaradok Krehva,Krehva,Kreva,Krevo,Krewo,Krėva,qrbw,Аграгарадок Крэва,Крево,Крэва,קרבו,კრევო', 54.3118000, 26.2916000, 'BY', '2015-01-14', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9490, 'Krasnyy Bereg', 'Krasnyy Bereg', 'Krasny Bereg,Krasnyj Bereg,Krasnyy Bereg,Красный Берег', 53.3291000, 30.1929000, 'BY', '2016-09-01', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9491, 'Krasnaye', 'Krasnaye', 'Kasnoye,Krasnae,Krasnaye,Krasne,Krasnoe,Krasnoye,Краснае,Красное', 54.2438000, 27.0758000, 'BY', '2012-08-31', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9492, 'Krasnasyel’ski', 'Krasnasyel''ski', 'Krasnasel''ski,Krasnasyel''ski,Krasnasyel’ski,Krasne Selo,Krasnosel''skij,Krasnosel''skiy,Krasnosel’skiy,Krasnoye Selo,Краснасельскі,Красносельский', 53.2645000, 24.4301000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9493, 'Krasnapollye', 'Krasnapollye', 'Krasnapolle,Krasnapollye,Krasnopol''e,Krasnopol''ye,Krasnopole,Krasnopol’ye,Краснаполле,Краснополье', 53.3353000, 31.3999000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9494, 'Chyrvonaya Slabada', 'Chyrvonaya Slabada', 'Chyrvonaja Slabada,Chyrvonaya Slabada,Krasnaja Sloboda,Krasnaya Sloboda,Красная Слобода,Чырвоная Слабада', 52.8522000, 27.1698000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9495, 'Kastsyukowka', 'Kastsyukowka', 'Kascjukouka,Kastsyukowka,Kostjubowka,Kostjukovka,Kostyukovka,Касцюкоўка,Костюковка', 52.5387000, 30.9173000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9496, 'Kastsyukovichy', 'Kastsyukovichy', 'Kascjukovichy,Kastsyukovichy,Kommunary,Kostjukovichi,Kostokovya,Kostyukovichi,Касцюковічы,Костюковичи', 53.3525000, 32.0514000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9497, 'Kosava', 'Kosava', 'Gorad Kosava,Kosava,Kosov,Kosovo,Kosow,Kossava,Kossov,Kossovo,Kossow,Kossuv,Kosów,ke sa wa,kosaba,kosavu~a,qwswbh,Горад Косава,Косава,Косово,Коссово,קאסעוו,קוסובה,コサヴァ,科萨瓦,코사바', 52.7583000, 25.1554000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9498, 'Korolëv Stan', 'Korolev Stan', 'Korolev Stan,Koroljov Stan,Korolëv Stan,Королёв Стан', 53.9865000, 27.7982000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9499, 'Karma', 'Karma', 'Karma,Korma,Карма,Корма', 53.1301000, 30.8016000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9500, 'Karanyowka', 'Karanyowka', 'Karanjouka,Karanyowka,Korenevka,Korenëvka,Korinevka,Каранёўка', 52.3506000, 31.1121000, 'BY', '2014-09-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9501, 'Karelichy', 'Karelichy', 'Garadski pasjolak Karehlichy,Karehlichy,Karelicai,Karelichi,Karelichy,Karelicsi,Karelicy,Karelitjy,Karelitschy,Karelitsy,Karelitšy,Kareličai,Kareličy,Korelichi,Korelicze,qrlyz,Гарадскі пасёлак Карэлічы,Кареличи,Карэлічы,Кореличи,Кореличі,קארעליץ,קרליץ', 53.5648000, 26.1406000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9502, 'Kapyl’', 'Kapyl''', 'Kapyl,Kapyl'',Kapyl’,Kopil,Kopyl'',Kopyl’,Капыль,Копыль', 53.1516000, 27.0913000, 'BY', '2014-04-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9503, 'Konstantinovo', 'Konstantinovo', 'Konstantinovo,Константиново', 54.6593000, 29.2684000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9504, 'Kalodzishchy', 'Kalodzishchy', 'Kalodzishchy,Kolodishchi,Kolodishhi,Калодзішчы,Колодищи', 53.9440000, 27.7823000, 'BY', '2012-03-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9505, 'Kokhanava', 'Kokhanava', 'Kokhanava,Kokhanovo,Коханава,Коханово', 54.4611000, 30.0018000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9506, 'Kobryn', 'Kobryn', 'Gorad Kobryn,Kobrin,Kobrin'',Kobrina,Kobriny,Kobryn,Kobrynas,Kobryń,Kóbriny,ke bu lin,koburu~in,qwbryn,Горад Кобрын,Кобрин,Кобринь,Кобрын,קאברין,קוברין,コブルィン,科布林', 52.2138000, 24.3564000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9507, 'Klimavichy', 'Klimavichy', 'Gorad Klimavichy,Klimavicai,Klimavichi,Klimavichy,Klimavitchy,Klimavitjy,Klimavitsy,Klimavitšy,Klimavičai,Klimawitschy,Klimovichi,Klimowicze,Klimowitschi,ke li mo wei qi,qlymwbyz,Горад Клімавічы,Климавичи,Климовичи,Климовичі,Клімавічы,קלימוביץ,克利莫維奇', 53.6079000, 31.9586000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9239, 'Wangdue Phodrang', 'Wangdue Phodrang', 'Du Phodrang,Wangdiphodrang,Wangdu Phodrang,Wangdue Phodrang,Wangdü Phodrang', 27.4861500, 89.8991500, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9240, 'Trongsa', 'Trongsa', 'Tongsa,Tongsa Dzong,Trongsa,Тонгса', 27.5026000, 90.5071600, 'BT', '2012-02-01', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9241, 'Thimphu', 'Thimphu', 'Gorad Tkhimpkhu,Tempu,Thimbu,Thimfou,Thimpago,Thimphou,Thimphu,Thimpu,Timbu,Timbuo,Timfou,Timfu,Timfú,Timphu,Timpou (therine) Pounaka (cheimerine),Timpu,Timpû,Tkhimpkhu,Tėmpu,thim phu,thimphu,thimpu,thiphu,thymphw,timbu,timphu,timpu,ting bu,tinpu,tymfw,tymfww,tympw,Θίμφου,Τιμπού (θερινή) Πουνάκα (χειμερινή),Горад Тхімпху,Тимбу,Тхимпху,Тхімпху,Թհիմփհու,טהימפהו,تىمپۇ,تيمفو,تھمپو,تیمفو,تیمفوو,تیمپو,ٹھمپھو,थिंफू,थिम्पु,थिम्पू,थिम्फू,থিম্ফু,ਥਿੰਫੂ,ଥିମ୍ପୁ,திம்பு,థింపూ,ಥಿಂಪು,തിംഫു,තිම්පු,ทิมพู,ཐིམ་ཕུ།,ཐིམ་ཕུུུུ,თიმფუ,ጢምጱ,ティンプー,廷布,팀부', 27.4660900, 89.6419100, 'BT', '2010-05-30', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9242, 'Trashi Yangtse', 'Trashi Yangtse', 'Tashi Tang-tsi Dzong,Tashi Yang-tsi Dzong,Tashi Yangtse,Tashi Yāng-tsi Dzong,Tashigang,Tashigangtsi,Trashi Yangtse', 27.6116000, 91.4980000, 'BT', '2012-02-01', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9243, 'Trashigang', 'Trashigang', 'Benkar,Tashi Gang Dzong,Tashigang,Trashigang,YON', 27.3331000, 91.5542400, 'BT', '2014-08-19', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9244, 'Daga', 'Daga', 'Daga,Ta-Ga-Na,Taga Dzong', 27.0752900, 89.8768800, 'BT', '2012-02-01', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9245, 'Shemgang', 'Shemgang', 'Shamgong Dzong,Shangong Dzong,Shemgang,Zhemgang,Шемганг', 27.2168900, 90.6579300, 'BT', '2012-02-01', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9246, 'Sarpang', 'Sarpang', 'Sarbhang,Sarbhāng,Sarpang', 26.8639500, 90.2674500, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9247, 'Punākha', 'Punakha', 'Distrito de Punakha,Dzongkhag Punakha,Punaka,Punakha,Punakkha,Punakla,Punāka,Punākla,pu na ka,Пунакха,སྤུ་ན་ཁ་,普那卡', 27.5913700, 89.8774300, 'BT', '2013-08-11', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9248, 'Phuntsholing', 'Phuntsholing', 'Gorad Pkhuncholing,Phuentsholing,Phuentsolingo,Phuentŝolingo,Phunchholing,Phuntsoling,Pkhuncholing,Puncolingas,Punčolingas,peng cuo lin,phuncholinga,puncholling,Горад Пхунчолінг,Пхунчолинг,Пхунчолінг,پھونتشولنگ,फुन्छोलिङ्ग,ཕུན་ཚོགས་གླིང་,彭措林,푼촐링', 26.8516400, 89.3883700, 'BT', '2010-03-31', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9249, 'Paro', 'Paro', 'Gorad Paro,PBH,Paras,Paro,Paro Dzong,Rimpung Dzong,pa luo,palo,paro,paro-bhutana,Πάρο,Горад Паро,Паро,پارو، بھوٹان,पारो-भूटान,პარო,パロ,帕羅,파로', 27.4305000, 89.4133400, 'BT', '2014-08-18', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9250, 'Pajo', 'Pajo', 'Pajo', 27.5333300, 89.8833300, 'BT', '2012-10-18', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9251, 'Mongar', 'Mongar', 'Mongar,Mongar Dzong,Монгар', 27.2747100, 91.2396300, 'BT', '2012-02-01', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9252, 'Lhuentse', 'Lhuentse', 'Lenlung,Lhuentse,Lhuntshi,Lhuntsi Dzong,Lingshi Dzong', 27.6678700, 91.1839300, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9253, 'Ha', 'Ha', 'Ha,Ha Dzong', 27.3874700, 89.2807400, 'BT', '2013-06-27', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9254, 'Gasa', 'Gasa', 'Gasa,Gasa Dzong', 27.9037200, 89.7268900, 'BT', '2013-08-26', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9255, 'Daphu', 'Daphu', 'Daphu', 26.9666700, 89.3833300, 'BT', '2013-08-18', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9256, 'Tsirang', 'Tsirang', 'Chirang,Tsirang', 27.0219000, 90.1229100, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9257, 'Tsimasham', 'Tsimasham', 'Chhukha,Chhukha Dzong,Chukha,Chukkha,Tsimasham,Чукха', 27.0989000, 89.5360400, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9258, 'Jakar', 'Jakar', 'BUT,Bjakar,Bya-kar,Dzakar,Dzakaras,Dzhakar,Džakaras,Jakar,Jakaro,Jokhar Dzong,jakr,Џакар,Джакар,جاکر', 27.5491800, 90.7525000, 'BT', '2014-08-20', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9259, 'Panbang', 'Panbang', 'Panbang', 26.8666700, 90.9833300, 'BT', '2012-01-19', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9260, 'Samtse', 'Samtse', 'Samchi,Samtse', 26.8990300, 89.0995100, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9261, 'Pemagatshel', 'Pemagatshel', 'Pemagatsel,Pemagatshel', 27.0379500, 91.4030500, 'BT', '2013-08-08', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9262, 'Samdrup Jongkhar', 'Samdrup Jongkhar', 'Samdrup Jongkhar', 26.8006900, 91.5051900, 'BT', '2013-08-02', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9263, 'Lungtenzampa', 'Lungtenzampa', '', 27.4682100, 89.6444100, 'BT', '2015-03-15', 26);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9264, 'Werda', 'Werda', 'Werda', -25.2666700, 23.2833300, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9265, 'Tshabong', 'Tshabong', 'Cabongas,Chabong,Gorad Chabong,TBY,Tsabong,Tsampon''nk,Tshabong,cha bang,chabong,tshabwng  bwtswana,tsu~abon,Čabongas,Τσαμπόνγκ,Горад Чабонг,Чабонг,טסאבונג,تشابونگ، بوتسوانا,ツァボン,察邦,차봉', -26.0500000, 22.4500000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9266, 'Tsau', 'Tsau', '', -20.1500000, 22.4500000, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9267, 'Tonota', 'Tonota', 'Tonota,Tonoto', -21.4423600, 27.4615300, 'BW', '2012-04-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9268, 'Tobane', 'Tobane', 'Tobane', -21.9500000, 27.9000000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9269, 'Thamaga', 'Thamaga', 'Thamaga', -24.6701400, 25.5397500, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9270, 'Tamasane', 'Tamasane', '', -22.4184000, 27.4012700, 'BW', '2011-02-08', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9271, 'Sua', 'Sua', '', -20.0500000, 26.2000000, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9272, 'Shakawe', 'Shakawe', 'SWX,Shakawe', -18.3653600, 21.8421900, 'BW', '2013-06-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9273, 'Serowe', 'Serowe', 'Serooue,Serova,Serove,Serovė,Serowe,sai luo wei,selowe,serou~e,srwbh,srwwh  bwtswana,Σερόουε,Серова,Серове,סרובה,سرووه، بوتسوانا,セロウェ,塞罗韦,세로웨', -22.3875400, 26.7107700, 'BW', '2012-04-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9274, 'Selebi-Phikwe', 'Selebi-Phikwe', 'PKW,Phikwe,Pikwe,Pikwe-Selibe,Selebi,Selebi Pikve,Selebi Pikvė,Selebi Pikwe,Selebi-Phikwe,Selebi-Pikwe,Selebi-Pkhikve,Selempi-Fikoue,Selibe,Selibe Phikwe,Selibe-Phikwe,Selibe-Pikwe Mine Lease Area,sai lai bi-pi kui,sellebipikwe,slyb fykwh  bwtswana,Σελέμπι-Φίκουε,Селеби-Пхикве,Селебі-Пхікве,سلیب فیکوه، بوتسوانا,سیلیبی-فیکوے,セレビ・ピクウェ,塞莱比-皮奎,셀레비피퀘', -21.9789500, 27.8429600, 'BW', '2012-04-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9275, 'Sekoma', 'Sekoma', '', -24.4000000, 23.8833300, 'BW', '2011-07-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9276, 'Sehithwa', 'Sehithwa', 'Sehithwa,Sehithwe', -20.4666700, 22.7166700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9277, 'Sefophe', 'Sefophe', 'Sefophe', -22.1833300, 27.9666700, 'BW', '2013-04-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9278, 'Sebina', 'Sebina', '', -20.8666700, 27.2500000, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9279, 'Ratholo', 'Ratholo', 'Ratholo,Ratolo', -22.7245400, 27.5719900, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9280, 'Ramotswa', 'Ramotswa', 'Ramotswa,Ramoutsa', -24.8715800, 25.8698900, 'BW', '2014-04-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9281, 'Ramokgonami', 'Ramokgonami', 'Ramakonami,Ramokgonami', -22.8645000, 27.4239100, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9282, 'Rakops', 'Rakops', 'Bakops,Rakops,Tsienyane', -21.0225700, 24.3605200, 'BW', '2013-08-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9283, 'Pilikwe', 'Pilikwe', '', -22.7990400, 27.1937600, 'BW', '2011-07-10', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9284, 'Pilane', 'Pilane', 'Pilane', -24.4500000, 26.1333300, 'BW', '2012-02-02', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9285, 'Pandamatenga', 'Pandamatenga', '', -18.5277900, 25.6269800, 'BW', '2011-10-28', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9286, 'Palapye', 'Palapye', 'Palap''e,Palapaye Road,Palape,Palapie,Palapye,Palapye Road,Palatswe,QPH,pa la pei,palapy  bwtswana,Παλάπιε,Палапье,Палапє,پالاپی، بوتسوانا,帕拉佩', -22.5460500, 27.1250700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9287, 'Otse', 'Otse', 'Ootsi,Ootsi Siding,Otse', -25.0166700, 25.7333300, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9288, 'Orapa', 'Orapa', 'ORP,Orapa,Орапа', -21.3115000, 25.3764200, 'BW', '2013-08-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9289, 'Nokaneng', 'Nokaneng', 'Nokanen,Nokaneng,Nokaning', -19.6666700, 22.2666700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9290, 'Nata', 'Nata', 'Nata', -20.2166700, 26.1833300, 'BW', '2014-04-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9291, 'Mosopa', 'Mosopa', 'Moshupa,Mosopa', -24.7718000, 25.4215600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9292, 'Mosetse', 'Mosetse', '', -20.7500000, 26.6500000, 'BW', '2013-08-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9293, 'Mopipi', 'Mopipi', 'Mopipi', -21.1833300, 24.8833300, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9294, 'Mookane', 'Mookane', 'Mookane', -23.6880500, 26.6594800, 'BW', '2013-04-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9295, 'Maunatlala', 'Maunatlala', 'Maunatlala,Monnatlala', -22.5970100, 27.6300600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9296, 'Molepolole', 'Molepolole', 'Molepolole,Molepololė,mo lai bo luo lai,mollepollolle,moreporore,mwlpwlwlh,mwlpwlwlh  bwtswana,Μολεπολόλε,Молепололе,מולפולולה,مولپولوله، بوتسوانا,モレポロレ,莫萊波洛萊,몰레폴롤레', -24.4065900, 25.4950800, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9297, 'Makobeng', 'Makobeng', 'Makobeng,Mokobeng', -22.9963700, 27.6676600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9298, 'Moijabana', 'Moijabana', 'Moijabana,Moiyabana', -22.4333300, 26.4166700, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9299, 'Mogoditshane', 'Mogoditshane', 'Mogoditsane,Mogoditshane', -24.6269400, 25.8655600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9300, 'Mogapinyana', 'Mogapinyana', '', -22.3666700, 27.6000000, 'BW', '2006-01-17', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9301, 'Mogapi', 'Mogapi', 'Mogapi', -22.3230100, 27.8349200, 'BW', '2013-04-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9302, 'Mochudi', 'Mochudi', 'Mochudi,Mochudi Village,Mocudis,Motsounti,Močudis,mo qiu di,mochudi,mwchwdy  bwtswana,Μοτσούντι,Мочуди,Мочуді,موچودی، بوتسوانا,モチュディ,莫丘迪,모추디', -24.4166700, 26.1500000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9303, 'Mmathubudukwane', 'Mmathubudukwane', 'Mathobudukwane,Mathubudukwane,Mmathubudkwane,Mmathubudukwane', -24.6000000, 26.4333300, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9304, 'Maun', 'Maun', 'Gorad Maun,MUB,Maoun,Maun,Maunas,ma weng,maun,mawn  bwtswana,Μαούν,Горад Маўн,Маун,מאון,ماون، بوتسوانا,マウン,馬翁,마운', -19.9833300, 23.4166700, 'BW', '2014-07-21', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9305, 'Mathakola', 'Mathakola', 'Mathakola,Matlakola', -22.7212500, 27.3105700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9306, 'Mathathane', 'Mathathane', 'Mathathane', -22.2687500, 28.7494600, 'BW', '2013-04-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9307, 'Mathambgwane', 'Mathambgwane', 'Matangwan,Matangwan Stad,Mathambgwane', -20.9907500, 27.3315800, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9308, 'Masunga', 'Masunga', 'Masunga,Masungas', -20.6245500, 27.4487500, 'BW', '2014-04-14', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9309, 'Manyana', 'Manyana', 'Manyana,Manyane', -23.4000000, 21.7166700, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9310, 'Makwata', 'Makwata', '', -23.2833300, 27.3000000, 'BW', '2011-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9311, 'Makoba', 'Makoba', '', -23.4833300, 27.1166700, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9312, 'Makaleng', 'Makaleng', '', -20.9000000, 27.2833300, 'BW', '2006-01-17', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9313, 'Mahalapye', 'Mahalapye', 'Gorad Makhalape,Mahalapje,Mahalapjė,Mahalapye,Mahalatswe,Makhalap''e,ma ha la pei,mahalapyh  bwtswana,mahallapie,maharapie,Горад Махалапе,Махалапье,ماهالاپیه، بوتسوانا,マハラピエ,馬哈拉佩,마할라피에', -23.1040700, 26.8142100, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9314, 'Magothla', 'Magothla', '', -23.5666700, 27.0000000, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9315, 'Machaneng', 'Machaneng', 'Machaneng,Machenen', -23.1862100, 27.4885600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9316, 'Mabuli', 'Mabuli', '', -25.7833300, 24.6000000, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9317, 'Maapi', 'Maapi', '', -22.7578500, 27.3500100, 'BW', '2011-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9318, 'Lokwabe', 'Lokwabe', '', -24.1666700, 21.8333300, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9319, 'Lobatse', 'Lobatse', 'LOQ,Lobace,Lobatse,Lobatsi,Lompatse,lobache,luo ba ce,lwbats  bwtswana,robatsu~e,Λομπάτσε,Лобаце,لوباتس، بوتسوانا,لوباٹسے,ロバツェ,洛巴策,로바체', -25.2243500, 25.6772800, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9320, 'Letlhakeng', 'Letlhakeng', 'Letlaking,Letlhakeng', -24.0944200, 25.0297700, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9321, 'Letlhakane', 'Letlhakane', 'Lethakane,Letlhakane,Letlhakawe', -21.4149400, 25.5926300, 'BW', '2013-08-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9322, 'Lenchwe Le Tau', 'Lenchwe Le Tau', '', -24.3833300, 25.8500000, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9323, 'Lehututu', 'Lehututu', 'Lehututu', -23.9666700, 21.8666700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9324, 'Letsheng', 'Letsheng', 'Lechen,Letsheng', -22.6638400, 27.2239000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9325, 'Kurametsi', 'Kurametsi', 'Kudumatsi,Kurametse,Kurametsi', -23.4000000, 27.0666700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9326, 'Kopong', 'Kopong', 'Kopong,Kopong Villages', -24.4833300, 25.8833300, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9327, 'Khudumelapye', 'Khudumelapye', 'Khudumelapye,Kudumalapshwe', -23.8833300, 24.7500000, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9328, 'Khakhea', 'Khakhea', 'Kakia,Khakhea', -24.6895400, 23.4940300, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9329, 'Kasane', 'Kasane', 'BBK,Kasane,ka sa nei,kasan  bwtswana,kasane,Касане,کاسان، بوتسوانا,カサネ,卡薩內,카사네', -17.8166700, 25.1500000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9330, 'Kanye', 'Kanye', 'Gorad Kane,Kan''e,Kane,Kanie,Kanje,Kanjė,Kanye,ka nei,kanie,kanyh  bwtswana,qnyh,Κάνιε,Горад Кане,Канье,Каньє,Кање,קניה,کانیه، بوتسوانا,カニエ,卡內,카니에', -24.9667500, 25.3327300, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9331, 'Kang', 'Kang', '', -23.6751800, 22.7876200, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9332, 'Kalamare', 'Kalamare', 'Kalamare', -22.9336900, 26.5703200, 'BW', '2013-04-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9333, 'Janeng', 'Janeng', '', -25.4166700, 25.5500000, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9334, 'Hukuntsi', 'Hukuntsi', 'HUK,Hukuntsi', -23.9988000, 21.7796200, 'BW', '2013-06-09', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9335, 'Gweta', 'Gweta', 'Gweta', -20.1833300, 25.2333300, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9336, 'Gobojango', 'Gobojango', 'Gobojango,Gubujango,Kobajango,Kobojango', -21.8327000, 28.7288200, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9337, 'Ghanzi', 'Ghanzi', 'GNZ,Ganzi,Ghanzi,Khanzi,Nkanzi,ganji,ghanzy  bwtswana,gnzy,hang ji,hantsu~i,Γκάνζι,Ганзи,Ганзі,גנזי,گهانزی، بوتسوانا,ハンツィ,杭濟,간지', -21.6978500, 21.6458100, 'BW', '2016-03-31', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9338, 'Gaborone', 'Gaborone', 'GBE,Gaberones,Gaberones Village,Gaberono,Gaboron,Gaboronas,Gaborone,Gaboròn,Gaboróne,Gorad Gabaroneh,IGaborone,Nkamporone,Qaborone,gabolone,gaborone,gaboroni,gabwrwn,gbrwn,gebaroni,goborni,haborone,jabwrwn,jia bai long li,jia bo long li,ka bo rone,kaparoni,Γκαμπορόνε,Габороне,Горад Габаронэ,Գաբորոնե,גאבאראן,גאבורון,جابورون,گابورون,گابۆرۆن,گبرون,गॅबारोनी,गोबोर्नी,ਗਾਬੋਰੋਨੀ,காபரோனி,กาโบโรเน,ག་བོ་རོ་ནི།,გაბორონე,ጋበሮኔ,ጋቦሮን,ハボローネ,嘉柏隆里,嘉波隆里,가보로네', -24.6545100, 25.9085900, 'BW', '2010-05-30', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9339, 'Gabane', 'Gabane', 'Gabane,Khabane', -24.6666700, 25.7822200, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9340, 'Francistown', 'Francistown', 'FRW,Francistown,Fransistaoun,Fransistaun,Frensistaun,Frensistaunas,Gorad Fransistaun,fransystwwn  bwtswana,fu lang xi si dui,furanshisutaun,peulaensiseutaun,Φράνσισταουν,Горад Франсістаўн,Франсистаун,פרנסיסטאון,فرانسس ٹاؤن,فرانسیستوون، بوتسوانا,แฟรนซิสทาวน์,フランシスタウン,弗朗西斯敦,프랜시스타운', -21.1699500, 27.5078700, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9341, 'Dutlwe', 'Dutlwe', 'Dutlwe,Luzwe', -23.9833300, 23.9000000, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9342, 'Dukwe', 'Dukwe', 'Dukwe,Dukwe Quarantine Camp', -20.5833300, 26.4166700, 'BW', '2013-08-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9343, 'Dekar', 'Dekar', 'Dekar', -21.5333300, 21.9333300, 'BW', '2014-10-29', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9344, 'Botlhapatlou', 'Botlhapatlou', 'Botlapatla,Botlhapatlou', -24.0259100, 25.4897600, 'BW', '2012-01-18', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9345, 'Bokaa', 'Bokaa', 'Bokaa', -24.4500000, 26.0166700, 'BW', '2013-06-06', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9346, 'Gaphatshwe', 'Gaphatshwe', '', -24.5738900, 25.8341700, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9347, 'Metsemotlhaba', 'Metsemotlhaba', '', -24.5513900, 25.8030600, 'BW', '2006-01-27', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9348, 'Mmopone', 'Mmopone', 'Mmopane Lands,Mmopone', -24.5669400, 25.8741700, 'BW', '2017-02-04', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9349, 'Nkoyaphiri', 'Nkoyaphiri', '', -24.6322200, 25.8313900, 'BW', '2006-01-17', 30);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8968, 'Bom Jesus da Lapa', 'Bom Jesus da Lapa', 'Bon-Zhezus-da-Lapa,LAZ,Lapa,Senhor Bom Jesus da Lapa,Бон-Жезус-да-Лапа', -13.2550000, -43.4180600, 'BR', '2017-07-15', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8969, 'Bom Despacho', 'Bom Despacho', 'Bon Despasu,Bon-Despashu,bo mu de si pa ke,boma desapakaho,Бон-Деспашу,Բոն Դեսպաշու,বোম ডেসপাকহো,ბონ-დესპაშუ,博姆德斯帕科', -19.7363900, -45.2522200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8970, 'Boituva', 'Boituva', '', -23.2833300, -47.6722200, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8971, 'Bocaiúva', 'Bocaiuva', 'Bocayuva', -17.1077800, -43.8150000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8972, 'Boa Esperança do Sul', 'Boa Esperanca do Sul', 'Boa Esperanca,Bôa Esperança', -21.9925000, -48.3908300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8973, 'Boa Esperança', 'Boa Esperanca', 'Boa Esperansa,Boa-Ehsperansa,Dores da Boa Esperanca,bo a ai si pei lan sa,Боа-Эсперанса,Բոա Էսպերանսա,博阿埃斯佩兰萨', -21.0900000, -45.5658300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8974, 'Boa Esperança', 'Boa Esperanca', '', -18.5400000, -40.2958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8975, 'Blumenau', 'Blumenau', 'BNU,Blumenau,balumena''u,beullumenau,blwmynaw,bu lu mei nao,burumenau,Блуменау,بلوميناو,বলুমেনাউ,ブルメナウ,布盧梅瑙,블루메나우', -26.9194400, -49.0661100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8976, 'Biritiba Mirim', 'Biritiba Mirim', 'Burityba-Mirim', -23.5725000, -46.0386100, 'BR', '2012-09-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8977, 'Birigui', 'Birigui', 'Biriguei,Birigui,Biriguy,Birigüi,QCF,bi li ji,birigu''i,Биригуи,বিরিগুই,比里吉', -21.2886100, -50.3400000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8978, 'Biguaçu', 'Biguacu', 'Biguassu,Biguassú', -27.4941700, -48.6555600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8979, 'Bicas', 'Bicas', '', -21.7252800, -43.0594400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8980, 'Betim', 'Betim', 'Betim,Betin,QBK,bechin,bei ting,betima,Бетим,Бетин,বেটিম,ベチン,貝廷', -19.9677800, -44.1983300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8981, 'Bertioga', 'Bertioga', 'Bertioga,bei er di ao jia,berti''oga,Бертиога,বের্টিওগা,贝尔蒂奥加', -23.8544400, -46.1386100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8982, 'Bernardino de Campos', 'Bernardino de Campos', '', -23.0130600, -49.4741700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8983, 'Bento Gonçalves', 'Bento Goncalves', 'BGV,Bento Goncalves,Bento Gonçalves', -29.1713900, -51.5191700, 'BR', '2017-06-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8984, 'Belo Oriente', 'Belo Oriente', '', -19.2200000, -42.4836100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8985, 'Belo Horizonte', 'Belo Horizonte', 'B.H.,BH,BHZ,Bel-Horizonto,Bello Horizonte,Belo Horizonte,Belo Horizontė,Belo Hte,Belo Khorizonte,Belo Orizonte,Belo Orizonti,Belu Orizonti,Belu-Orizonti,Bhte,Cidade de Minas,Gorad Belu-Aryzonty,Urbs Pulchri Horizontis,bailo orizonti,bei luo ao li cang te,belluolijonchi,belo horijhonte,belo horijonte,belo xo ri sxn chi,beroorizonchi,beroorizonte,blw hwryzwnth,bylw hwryzwnty,pelo aricanc,Μπέλο Οριζόντε,Бело Оризонте,Бело Оризонти,Бело Хоризонте,Белу-Оризонти,Белу-Оризонті,Горад Белу-Арызонты,בלו הוריזונטה,بلو هوریزونته,بيلو هوريزونتي,بیلو ہوریزونتے,बेलो होरिझोन्ते,বেলো হোরিজোন্টে,ਬੈਲੋ ਓਰੀਜ਼ੋਂਤੀ,பெலோ அரிசாஞ்ச்,เบโลโอรีซอนชี,ბელუ-ორიზონტი,ベロオリゾンチ,ベロオリゾンテ,貝洛奥里藏特,贝洛奥里藏特,벨루오리존치', -19.9208300, -43.9377800, 'BR', '2014-05-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8986, 'Belmonte', 'Belmonte', 'BVM', -15.8610400, -38.8814300, 'BR', '2014-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8987, 'Belford Roxo', 'Belford Roxo', 'Belford Rosho,Belford Roxo,Belford-Roshu,bei er fu luo shu,belaphorda rokso,Белфорд Рошо,Белфорд-Рошу,বেলফোর্ড রোক্সো,ベルフォード・ロッショ,貝爾福羅舒', -22.7641700, -43.3994400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8988, 'Bela Vista do Paraíso', 'Bela Vista do Paraiso', '', -22.9966700, -51.1905600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8989, 'Bela Vista de Goiás', 'Bela Vista de Goias', 'Bela Vista,Bella Vista,Sucuapara,Sussuapara,Suçuapara', -16.9727800, -48.9533300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8990, 'Bela Vista', 'Bela Vista', 'Bela Vista,Bela-Vista,Bella Vista,bei la wei si ta,bela bhista,Бела-Виста,Բելա Վիստա,বেলা ভিস্টা,ბელა-ვისტა,貝拉維斯塔', -22.1088900, -56.5211100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8991, 'Bebedouro', 'Bebedouro', 'QAU', -20.9494400, -48.4791700, 'BR', '2013-04-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8992, 'Bauru', 'Bauru', 'Bauru,JTC,Yvauru,ba wu lu,ba''uru,bauru,Бауру,באורו,বাউরু,バウル,巴烏魯', -22.3147200, -49.0605600, 'BR', '2013-03-16', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8993, 'Batatais', 'Batatais', 'Batataes,Batatajs,Бататайс', -20.8911100, -47.5850000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8994, 'Bataiporã', 'Bataipora', 'Baitapora,Baitaporã', -22.2952800, -53.2711100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8995, 'Bastos', 'Bastos', '', -21.9219400, -50.7338900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8996, 'Barueri', 'Barueri', 'Baruehri,Barueri,Tambore,Tamboré,ba lu ai li,barueri,baruyeri,Баруери,Баруері,Баруэри,বারুয়েরি,バルエリ,巴魯埃里', -23.5105600, -46.8761100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8997, 'Barroso', 'Barroso', 'Barozu,Barrozu,ba luo su,barozu,barroso,Баррозу,Բառոզու,বার্রোসো,ბაროზუ,巴罗苏', -21.1869400, -43.9758300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8998, 'Barro Alto', 'Barro Alto', '', -14.9708300, -48.9158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(8999, 'Barro Alto', 'Barro Alto', '', -11.7608300, -41.9116700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9000, 'Barrinha', 'Barrinha', '', -21.1936100, -48.1638900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9001, 'Barretos', 'Barretos', 'BAT,Baretosas,Barretos,Barretus,ba lei tu si,barretosa,barrytws,Барретус,بارريتوس,বার্রেটোস,巴雷图斯', -20.5572200, -48.5677800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9002, 'Barreiro do Jaíba', 'Barreiro do Jaiba', '', -15.6153200, -43.5918700, 'BR', '2012-12-05', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9003, 'Barreiras', 'Barreiras', 'BRA,Barrejras,Баррейрас', -12.1527800, -44.9900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9004, 'Barra Velha', 'Barra Velha', '', -26.6322200, -48.6847200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9005, 'Barra Mansa', 'Barra Mansa', 'Bara Mansa,Barra Mansa,Barra-Mansa,QBN,ba la man sa shi,barra mansa,Барра-Манса,বার্রা মান্সা,巴拉曼萨市', -22.5441700, -44.1713900, 'BR', '2013-04-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9006, 'Barra dos Coqueiros', 'Barra dos Coqueiros', '', -10.9088900, -37.0386100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9007, 'Barra do Piraí', 'Barra do Pirai', 'Bara do Pirajus,Barra do Parai,Barra do Pirahy,Barra do Pirai,Barra do Piraí,Barra-du-Pirai,QBD,ba la du pi lai,barra do pira''i,Барра-ду-Пираи,বার্রা ডো পিরাই,巴拉杜皮莱', -22.4700000, -43.8255600, 'BR', '2013-04-28', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9008, 'Barra do Garças', 'Barra do Garcas', 'BPG,Barra do Garcas,Barra do Garças,Barra-du-Garsas,ba la-du jia sa si,Барра-ду-Гарсас,巴拉-杜加萨斯', -15.8900000, -52.2566700, 'BR', '2014-04-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9009, 'Barra do Bugres', 'Barra do Bugres', 'Barra Dos Bugres,Barra do Rio dos Bugres', -15.0725000, -57.1811100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9010, 'Barra de São Francisco', 'Barra de Sao Francisco', 'Barra-de-San-Francisko,Sao Francisco,São Francisco,Барра-де-Сан-Франциско', -18.7550000, -40.8908300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9011, 'Barra da Estiva', 'Barra da Estiva', '', -13.6261100, -41.3269400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9012, 'Barra Bonita', 'Barra Bonita', '', -22.4947200, -48.5580600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9013, 'Barra', 'Barra', 'BQQ,Barra,Barra Do Rio Grande,Барра', -11.0894400, -43.1416700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9014, 'Bariri', 'Bariri', 'Bariry', -22.0744400, -48.7402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9015, 'Barbacena', 'Barbacena', 'QAK', -21.2258300, -43.7736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9016, 'Barão de Melgaço', 'Barao de Melgaco', 'Chacorore,Chacororé,Melgaco,Melgaço', -16.1944400, -55.9675000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9017, 'Barão de Cocais', 'Barao de Cocais', 'Morro Grande', -19.9458300, -43.4872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9018, 'Bandeirantes', 'Bandeirantes', '', -23.1100000, -50.3675000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9019, 'Bambuí', 'Bambui', 'Bambuhy', -20.0063900, -45.9769400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9020, 'Balneário Camboriú', 'Balneario Camboriu', 'Balneario,Balneario Camboriu,Balneario Camboriú,Balneariu-Kamboriu,Balneário,Balneário Camboriú,Camboriu,Camboriú,ba nei a li yue kan bo li wu,balane''ari''o kamabori''u,Балнеариу-Камбориу,בלנאריו קמבוריו,বালনেআরিও কামবোরিউ,巴内阿里约坎博里乌', -26.9905600, -48.6347200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9021, 'Baixo Guandu', 'Baixo Guandu', 'Bajshu-Guandu,ba''ikso guraanadu,Байшу-Гуанду,বাইক্সো গুৱানডু', -19.5188900, -41.0158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9022, 'Baixa Grande', 'Baixa Grande', '', -11.9597200, -40.1680600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9023, 'Bagé', 'Bage', 'BGX,Bag,Bage,Bagé,Baje,Bajé,Baze,Bazhe,Bažė,ba re,bage,Баг,Баже,বাগে,巴熱', -31.3313900, -54.1069400, 'BR', '2017-06-14', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9024, 'Baependi', 'Baependi', 'Baependy', -21.9588900, -44.8900000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9025, 'Bady Bassitt', 'Bady Bassitt', 'Bady Brassitt,Barboleta,Borboleta', -20.9180600, -49.4452800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9026, 'Avaré', 'Avare', '', -23.0986100, -48.9258300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9027, 'Auriflama', 'Auriflama', '', -20.6855600, -50.5547200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9028, 'Atibaia', 'Atibaia', 'Atibaja,QTA,a di ba ya,achibaia shi,atiba''iya,Атибая,আটিবাইয়া,アチバイア市,阿蒂巴亚', -23.1169400, -46.5502800, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9029, 'Astorga', 'Astorga', 'QWN', -23.2325000, -51.6655600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9030, 'Astolfo Dutra', 'Astolfo Dutra', 'Porto de Santo Antonio,Pôrto de Santo Antonio', -21.3152800, -42.8622200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9031, 'Assis', 'Assis', 'AIF,Assis,Assis Sao Paulo,Assis São Paulo,Assis  SP,Assiz,Ассис', -22.6616700, -50.4122200, 'BR', '2016-03-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9032, 'Assaí', 'Assai', 'Acai,Açaí', -23.3733300, -50.8413900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9033, 'Arujá', 'Aruja', 'Aruja,Arujá,Uruja,Urujá,ZFU', -23.3961100, -46.3208300, 'BR', '2013-08-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9034, 'Artur Nogueira', 'Artur Nogueira', 'Arthur Nogueira', -22.5730600, -47.1725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9035, 'Arroio Grande', 'Arroio Grande', 'Federacao,Federação', -32.2375000, -53.0869400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9036, 'Arroio dos Ratos', 'Arroio dos Ratos', '', -30.0772200, -51.7291700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9037, 'Arroio do Meio', 'Arroio do Meio', 'Gaspar Martins', -29.4011100, -51.9450000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9038, 'Arraial do Cabo', 'Arraial do Cabo', 'Aldeia do Cabo', -22.9661100, -42.0277800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9039, 'Armação de Búzios', 'Armacao de Buzios', 'Armacao dos Buzios,Armação dos Búzios,BZC,Buzios,Búzios,Saco de Fora', -22.7469400, -41.8816700, 'BR', '2013-04-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9040, 'Armação', 'Armacao', 'Armacao,Armação,Praia da Armacao,Praia da Armacao do Pantano do Sul,Praia da Armação,Praia da Armação do Pântano do Sul', -27.7496300, -48.5071300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9041, 'Arinos', 'Arinos', 'Affonso Arinos', -15.9169400, -46.1055600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9042, 'Arenápolis', 'Arenapolis', '', -14.4502800, -56.8461100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9043, 'Areia Branca', 'Areia Branca', '', -10.7577800, -37.3152800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9044, 'Areal', 'Areal', '', -22.2305600, -43.1055600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9045, 'Areado', 'Areado', '', -21.3586100, -46.1455600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9046, 'Arcos', 'Arcos', 'Arkos,Arkus,QRK,a er ke si,arkosa,Аркос,Аркус,Արկուս,আর্কোস,阿尔科斯', -20.2819400, -45.5394400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9047, 'Araxá', 'Araxa', 'Arasha,Araxa,Araxá,Ouro Minas Araxa,Ouro Minas Araxá,a la sha,raaraksa,Араша,ৱারাক্সা,阿拉沙', -19.5933300, -46.9405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9048, 'Araucária', 'Araucaria', 'Araucaria,Araucária,Araukarija,Араукария', -25.5930600, -49.4102800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9049, 'Arauá', 'Araua', '', -11.2622200, -37.6197200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9050, 'Araruama', 'Araruama', 'Araruama,a la lu a ma,raararu''ama,Араруама,ৱারারুআমা,阿拉鲁阿马', -22.8727800, -42.3430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9051, 'Araras', 'Araras', 'Araras,a la la si,raararasa,Арарас,ৱারারাস,阿拉拉斯', -22.3569400, -47.3841700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9052, 'Araraquara', 'Araraquara', 'AQA,Ararakuara,Ararakvara,Araraquara,a la la kua la,ararakuara,raararakuraara,Араракуара,ৱারারাকুৱারা,アララクアラ,阿拉拉夸拉', -21.7944400, -48.1755600, 'BR', '2013-12-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9053, 'Araranguá', 'Ararangua', 'Ararangua,Campinas,Арарангуа', -28.9357500, -49.4953800, 'BR', '2014-12-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9054, 'Arapongas', 'Arapongas', 'APX,Araponga,Arapongas,a la peng jia si,raarapongasa,Арапонгас,ৱারাপোঙ্গাস,阿拉蓬加斯', -23.4194400, -51.4244400, 'BR', '2013-04-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9055, 'Araguari', 'Araguari', 'Araguar,Araguari,Araguary,Aragvaris,a la gua li,raaraguraari,Арагуари,ৱারাগুৱারি,阿拉瓜里', -18.6472200, -48.1872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9056, 'Araguaiana', 'Araguaiana', 'Araguiana,Registro do Araguaia', -15.7338900, -51.8313900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9057, 'Aragarças', 'Aragarcas', 'ARS', -15.8975000, -52.2508300, 'BR', '2017-07-20', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9058, 'Araçuaí', 'Aracuai', 'Arassuahy,Arassuai,Arassuaí,Arassui,Arasuai,Arássuí,Арасуаи', -16.8497200, -42.0702800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9059, 'Aracruz', 'Aracruz', 'Arakrus,Sauacu,Sauaçu,a la ke lu si,raarakruja,Аракрус,Արակրուս,ৱারাক্রুজ,არაკრუსი,阿拉克魯斯', -19.8202800, -40.2733300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9060, 'Araçoiaba da Serra', 'Aracoiaba da Serra', 'Campo Largo', -23.5052800, -47.6141700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9061, 'Araci', 'Araci', 'Aracy,Raso', -11.3333300, -38.9666700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9062, 'Araçatuba', 'Aracatuba', 'ARU,Aracatuba,Arasatuba,Araçatuba,a la sa tu ba,raarakatuba,Арасатуба,ৱারাকাটুবা,阿拉萨图巴', -21.2088900, -50.4327800, 'BR', '2016-10-13', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9063, 'Aracaju', 'Aracaju', 'AJU,Aracaju,Arakazhu,Arakazu,Arakažu,Gorad Arakazhu,a la ka ru,alakaju,arakaju,arakajw,xa ra ka cu,ʼrʼqzw,Аракажу,Горад Аракажу,אראקזו,اراکاجو,আরাকাজু,อารากาจู,არაკაჟუ,アラカジュ,阿拉卡茹,아라카주', -10.9111100, -37.0716700, 'BR', '2013-04-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9064, 'Aquidauana', 'Aquidauana', 'Aquidavana', -20.4711100, -55.7872200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9065, 'Aquidabã', 'Aquidaba', 'Aquidaban', -10.2813900, -37.0186100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9066, 'Apucarana', 'Apucarana', 'APU', -23.5508300, -51.4608300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9067, 'Apiaí', 'Apiai', 'Apiahy', -24.5094400, -48.8425000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9068, 'Aparecida do Taboado', 'Aparecida do Taboado', 'Aparecida do Tabuado', -20.0866700, -51.0936100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9069, 'Aparecida', 'Aparecida', 'Aparesida,Apparecida,a pa lei xi da,aparesida,Апаресида,אפארסידה,আপারেসিডা,阿帕雷西達', -22.8469400, -45.2297200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9070, 'Antonina', 'Antonina', 'Antonina,an dong ni na,anatonina,Антонина,আনটোনিনা,安东尼娜', -25.4286100, -48.7119400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9071, 'Anitápolis', 'Anitapolis', 'Anitapolis,Annitapolis,Анитаполис', -27.9019400, -49.1286100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9072, 'Anicuns', 'Anicuns', 'Novo Horizonte', -16.4611100, -49.9616700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9073, 'Anguera', 'Anguera', 'Almas', -12.1511100, -39.2463900, 'BR', '2014-04-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9074, 'Angra dos Reis', 'Angra dos Reis', 'Angra,Angra dos Reis,Angra-dus-Rejs,an ge la du si lei si,anagra dosa re''isa,Ангра-дус-Рейс,আনগ্রা ডোস রেইস,安格拉杜斯雷斯', -23.0066700, -44.3180600, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9075, 'Angatuba', 'Angatuba', '', -23.4897200, -48.4127800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9076, 'Andrelândia', 'Andrelandia', 'Andrelandija,Turvo,Vila Bela do Turvo,an de lie lan di ya,anadrelandiya,Андреландия,আনড্রেলান্ডিয়া,安德烈兰迪亚', -21.7397200, -44.3091700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9077, 'Andradina', 'Andradina', '', -20.8961100, -51.3794400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9078, 'Andradas', 'Andradas', 'Andradas,Caracol,an de la da si,anadradasa,Андрадас,আনড্রাডাস,安德拉达斯', -22.0680600, -46.5691700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9079, 'Anastácio', 'Anastacio', '', -20.4836100, -55.8069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9080, 'Anápolis', 'Anapolis', 'APS,Anapolis,Anápolis,a na bo li si,anapolisa,anaporisu,Анаполис,আনাপোলিস,アナポリス,阿纳波利斯', -16.3266700, -48.9527800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9081, 'Anagé', 'Anage', 'Anaje,Joanopolis,Joanópolis,Sao Joao da Vila Nova,Sao Jose da Villa Nova,São José da Villa Nova,São João da Vila Nova', -14.6122200, -41.1355600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9082, 'Ampére', 'Ampere', '', -25.9150000, -53.4727800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9083, 'Amparo', 'Amparo', 'Amparu,amaparo,an pa luo,Ампару,আমপারো,安帕羅', -22.7011100, -46.7644400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9084, 'Américo Brasiliense', 'Americo Brasiliense', '', -21.7244400, -48.1016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9085, 'Americana', 'Americana', 'Amerikana,QWJ,Vila Americana,Villa Americana,amrykna  sayw paywlw,ya mei li jia na,Американа,امریکنا، سائو پائولو,亚美利加纳', -22.7391700, -47.3313900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9086, 'América Dourada', 'America Dourada', '', -11.4552800, -41.4361100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9087, 'Amargosa', 'Amargosa', '', -13.0302800, -39.6047200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9088, 'Alvorada', 'Alvorada', '', -12.4800000, -49.1247200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9089, 'Alvinópolis', 'Alvinopolis', '', -20.1066700, -43.0488900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9090, 'Álvares Machado', 'Alvares Machado', '', -22.0794400, -51.4719400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9091, 'Alto Piquiri', 'Alto Piquiri', '', -24.0280600, -53.4405600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9092, 'Alto Paraná', 'Alto Parana', '', -23.1288900, -52.3188900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9093, 'Altãnia', 'Altania', 'Itonia,Itônia', -23.8744400, -53.9016700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9094, 'Alto Araguaia', 'Alto Araguaia', 'Santa Rita do Araguaia,Santa Rita do Araguaya', -17.3147200, -53.2152800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9095, 'Altinópolis', 'Altinopolis', '', -21.0255600, -47.3738900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9096, 'Alterosa', 'Alterosa', 'Serra Negra', -21.2491700, -46.1430600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9097, 'Alpinópolis', 'Alpinopolis', '', -20.8636100, -46.3880600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9098, 'Almirante Tamandaré', 'Almirante Tamandare', 'Almiranti-Tamandare,Tamandare,Tamandaré,Timaneira,Timoneira,a er mi lan te ta man da lei,alamirante tamandare,almyranth tamandarh,Алмиранти-Тамандаре,آلمیرانته تامانداره,আলমিরান্টে টামান্ডারে,阿尔米兰特塔曼达雷', -25.3247200, -49.3100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9099, 'Almenara', 'Almenara', 'AMJ,Al''menara,Almenara,Sao Joao de Vigia,São João de Vigia,Vigia,a er mei na la,alamenara,almenara,Алменара,Альменара,Ալմենարա,আলমেনারা,ალმენარა,阿尔梅纳拉', -16.1836100, -40.6944400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9100, 'Alfredo Chaves', 'Alfredo Chaves', 'Alfredo Chavez', -20.6350000, -40.7497200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9101, 'Alfenas', 'Alfenas', 'Alfenas,QXW,a er fei na si,alaphenasa,Алфенас,আলফেনাস,阿尔费纳斯', -21.4291700, -45.9472200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9102, 'Além Paraíba', 'Alem Paraiba', 'Alem Parahyba', -21.8877800, -42.7044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9103, 'Alegrete', 'Alegrete', 'ALQ,Alegrete,Alegreti,alegrete,Алегрети,আলেগ্রেটে', -29.7830600, -55.7919400, 'BR', '2013-05-19', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9104, 'Alegre', 'Alegre', '', -20.7636100, -41.5330600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9105, 'Alagoinhas', 'Alagoinhas', 'Alagoin''jas,Alagoinhas,Alagoinjasas,QGS,a la ge yi ni ya si,alago''inahasa,alagoniasi,Алагоиньяс,আলাগোইনহাস,ალაგონიასი,阿拉戈伊尼亚斯', -12.1355600, -38.4191700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9106, 'Aimorés', 'Aimores', 'Ajmores,Aymores,Aymorés,a''imoresa,ai mo lei si,Айморес,আইমোরেস,艾莫雷斯', -19.4958300, -41.0638900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9107, 'Águia Branca', 'Aguia Branca', '', -18.9830600, -40.7402800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9108, 'Agudos', 'Agudos', '', -22.4691700, -48.9875000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9109, 'Águas Vermelhas', 'Aguas Vermelhas', 'Agua Vermelha', -15.7472200, -41.4600000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9110, 'Águas Formosas', 'Aguas Formosas', 'Aguas Belas,Aguas Bellas,Sao Boaventura d''Agua Bella,Sao Jose das Aguas Belas,São Bôaventura d''Agua Bella,São José das Aguas Belas,Águas Belas', -17.0822200, -40.9358300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9111, 'Águas de Lindóia', 'Aguas de Lindoia', '', -22.4763900, -46.6327800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9112, 'Aguaí', 'Aguai', 'Cascavel', -22.0594400, -46.9786100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9113, 'Afonso Cláudio', 'Afonso Claudio', 'Affonso Claudio', -20.0741700, -41.1238900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9114, 'Adamantina', 'Adamantina', '', -21.6852800, -51.0725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9115, 'Açucena', 'Acucena', 'Travessao,Travessão', -19.0730600, -42.5463900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9116, 'Acajutiba', 'Acajutiba', 'Cajueiro', -11.6622200, -38.0172200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9117, 'Abaeté', 'Abaete', 'Abaehte,Абаэте', -19.1600000, -45.4458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9118, 'Abadiânia', 'Abadiania', '', -16.2041700, -48.7069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9119, 'Guaíba', 'Guaiba', 'Guaiba,Guaíba', -30.1138900, -51.3250000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9120, 'Palmas', 'Palmas', 'PMW,Palmas,plms,Палмас,פלמס', -10.1674500, -48.3276600, 'BR', '2013-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9121, 'Pontal do Paraná', 'Pontal do Parana', '', -25.6736100, -48.5111100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9122, 'Uarini', 'Uarini', '', -2.9900000, -65.1083300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9123, 'Tonantins', 'Tonantins', 'Tocantins', -2.8730600, -67.8022200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9124, 'Tefé', 'Tefe', 'Ega,TFF,Tefe,Teffe,Teffé,Tefé', -3.3684100, -64.7205400, 'BR', '2014-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9125, 'Marechal Thaumaturgo', 'Marechal Thaumaturgo', 'Taumaturgo,Villa Thaumaturgo', -8.9411100, -72.7916700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9126, 'Tarauacá', 'Tarauaca', 'Foz do Muru,Seabra,TRQ,Tarauaca,Tarauacá', -8.1613900, -70.7655600, 'BR', '2013-04-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9127, 'Tabatinga', 'Tabatinga', 'TBT,Tabatinga', -4.2311600, -69.9385800, 'BR', '2014-07-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9128, 'Sena Madureira', 'Sena Madureira', 'Purus,Purús,Sena Madureira,Senna Madureira,ZMD', -9.0634100, -68.6724500, 'BR', '2014-07-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9129, 'São Paulo de Olivença', 'Sao Paulo de Olivenca', '', -3.3783300, -68.8725000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9130, 'São Gabriel da Cachoeira', 'Sao Gabriel da Cachoeira', 'Sao Gabriel,São Gabriel', -0.1181000, -67.0852700, 'BR', '2014-07-17', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9131, 'Santo Antônio do Içá', 'Santo Antonio do Ica', 'Santo Antonio,Santo Antonio do Inca', -3.1022200, -67.9397200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9132, 'Santa Isabel do Rio Negro', 'Santa Isabel do Rio Negro', 'IRZ,Santa Isabel,Santa Isabel Rio Negro,Santa Izabel,Tapuracuara,Tapurucuara,Tapuruqua,Tapuruquara,Tapuruquá,Tapuruquára', -0.4138900, -65.0191700, 'BR', '2013-05-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9133, 'Rio Branco', 'Rio Branco', 'Penapolis,Penápolis,RBR,Rio Bran''ko,Rio Branco,Rio Brankas,Rio Branko,Riu Branco,Riu-Branku,Riubranku,Río Branco,hiubeulangku,li yue bu lan ke,ri xu brang ku,ri''o branko,rioburanko,riyo branko,ryw brankw,ryw brnqw,Ρίο Μπράνκο,Рио Бранко,Риу-Бранку,Ріу-Бранку,ריו ברנקו,ريو برانكو,ریو برانکو,रियो ब्रांको,রিও ব্রাঙ্কো,รีอูบรังกู,რიუ-ბრანკუ,リオブランコ,里約布蘭科,히우브랑쿠', -9.9747200, -67.8100000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9134, 'Porto Walter', 'Porto Walter', 'Humaita,Humaitá,Humayta,Humaytá,Porto Valter,Porto Walter,Pôrto Válter,Pôrto Walter,Villa Humayta', -8.2686100, -72.7438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9135, 'Porto Velho', 'Porto Velho', 'PVH,Porto Vel''o,Porto Velho,Porto Veljas,Porto Velo,Portu-Vel''ju,Portu-Velju,Pôrto Velho,Velho,bwrtw falyw,parto bhelaho,poleutubellyu,por tu wel yu,pwrtw wlyw,wei liu gang,Порто Вельо,Порто Вељо,Порту-Велью,Порту-Велю,פורטו ולאהו,פורטו וליו,بورتو فاليو,پورتو ویلہو,পর্টো ভেলহো,โปร์ตูเวลยู,პორტუ-ველიუ,ポルト・ヴェーリョ,韋柳港,포르투벨류', -8.7619400, -63.9038900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9136, 'Pauini', 'Pauini', '', -7.7136100, -66.9763900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9137, 'Novo Aripuanã', 'Novo Aripuana', 'Boca Aripuana,Boca Aripuanã,Foz do Aripuana,Foz do Aripuanã,NVP', -5.1205600, -60.3797200, 'BR', '2016-12-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9138, 'Maraã', 'Maraa', '', -1.8240300, -65.3588300, 'BR', '2014-07-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9139, 'Manoel Urbano', 'Manoel Urbano', 'Manoel Urbano', -8.8388900, -69.2597200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9140, 'Manicoré', 'Manicore', '', -5.8091700, -61.3002800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9141, 'Mâncio Lima', 'Mancio Lima', 'Japiim,Japuim,Villa Nuncio Lima', -7.6141700, -72.8958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9142, 'Manaus', 'Manaus', 'Barra do Rio Negro,MAO,Manaos,Manaus,Manos,Manáos,ma nao si,manausu,Манаус,Манаўс,מנאוס,マナウス,马瑙斯', -3.1019400, -60.0250000, 'BR', '2016-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9143, 'Manaquiri', 'Manaquiri', 'Manaquery,Manaquiri', -3.3166700, -60.3500000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9144, 'Manacapuru', 'Manacapuru', 'Manakapuru,Манакапуру', -3.2997200, -60.6205600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9145, 'Jutaí', 'Jutai', '', -5.1833300, -68.9000000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9146, 'Humaitá', 'Humaita', 'HUW,Humaita,Humaitá,Humayta,Humaytá,Umajta,wu mai ta,Умайта,אומאיטה,烏邁塔', -7.5165100, -63.0310500, 'BR', '2014-07-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9147, 'Fonte Boa', 'Fonte Boa', 'FBA,Fonte Boa', -2.5138900, -66.0916700, 'BR', '2013-05-08', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9148, 'Feijó', 'Feijo', 'FEJ,Feijo,Feijó', -8.1654000, -70.3548600, 'BR', '2013-11-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9149, 'Envira', 'Envira', 'Emvira,Envira', -7.3000000, -70.2166700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9150, 'Eirunepé', 'Eirunepe', 'Joao Pessoa,João Pessôa,Sao Felipe,Sao Felippe,Sao Filipe,Sao Phelippe,São Felipe,São Felippe,São Filipe,São Phelippe', -6.6602800, -69.8736100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9151, 'Cruzeiro do Sul', 'Cruzeiro do Sul', 'CZS,Jurua,Juruá,Kruzejro do Sul,Kruzejru-du-Sul,Kruzeyru du Sul,krwzyrw dw swl,nan ke lu sai luo,qrwzyyrw dw swl,Крузейро до Сул,Крузейру-ду-Сул,Կրուզեյրու դու Սուլ,קרוזיירו דו סול,کروزیرو دو سول,南克魯賽羅', -7.6275900, -72.6775600, 'BR', '2014-07-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9152, 'Codajás', 'Codajas', 'Codajaz,Codajáz', -3.8366700, -62.0569400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9153, 'Coari', 'Coari', 'CIZ,Choary,Coari Amazonas,Coary,Koari,Quari,Quarí,Коари', -4.0850000, -63.1413900, 'BR', '2013-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9154, 'Carauari', 'Carauari', 'CAF,Carauary,Caravari,Xibaua,Xibauá', -4.8827800, -66.8958300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9155, 'Canutama', 'Canutama', '', -6.5338900, -64.3830600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9156, 'Boca do Acre', 'Boca do Acre', 'BCR,Bocca do Acre,Foz do Acre,Santa Maria da Boca do Acre,Santa Maria da Bôca do Acre', -8.7522200, -67.3977800, 'BR', '2017-02-14', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9157, 'Boa Vista', 'Boa Vista', 'BVB,Boa Vista,Boa Vista (Roraima),Boa Vista do Rio Branco,Boa Višta,Boa-Vista,Боа-Виста,בואה ויסטה', 2.8197200, -60.6733300, 'BR', '2017-07-06', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9158, 'Benjamin Constant', 'Benjamin Constant', 'Benjamim Constant,Benjamin Constant,Benzhamin-Konstant,QAV,Бенжамин-Констант', -4.3755500, -70.0317900, 'BR', '2014-07-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9159, 'Barcelos', 'Barcelos', 'BAZ,Barcellos,Barselos,Barselosas,Barselus,ba sai luo si,Барселос,Барселус,Բարսելուս,巴塞洛斯', -0.9735700, -62.9269000, 'BR', '2014-06-27', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9160, 'Ariquemes', 'Ariquemes', 'Arikemes,Arikemis,arikoyemesa,Арикемис,আরিকোয়েমেস', -9.9133300, -63.0408300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9161, 'Aripuanã', 'Aripuana', 'Aripuana,Aripuanan,Aripuanã,Campina,Арипуанан', -9.1666700, -60.6333300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9162, 'Anori', 'Anori', 'Annory,Anory', -3.7727800, -61.6441700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9163, 'Alvarães', 'Alvaraes', 'Caicara,Caissara,Caiçara', -3.2208300, -64.8041700, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9164, 'Iranduba', 'Iranduba', 'Iranduba Grande', -3.2847200, -60.1861100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9165, 'Xapuri', 'Xapuri', 'Xapury', -10.6516700, -68.5044400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9166, 'Vilhena', 'Vilhena', 'BVH,Vilena,Vilhena,Вилена', -12.7405600, -60.1458300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9167, 'Senador Guiomard', 'Senador Guiomard', '', -10.1497000, -67.7374100, 'BR', '2015-06-18', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9168, 'Presidente Médici', 'Presidente Medici', 'Presidente,Presidente Hermes', -11.1752800, -61.9013900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9169, 'Pôsto Fiscal Rolim de Moura', 'Posto Fiscal Rolim de Moura', 'Posto Fiscal Rolim de Moura,Pôsto Fiscal Rolim de Moura,Rolim de Moura', -13.0827100, -62.2772600, 'BR', '2013-04-04', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9170, 'Plácido de Castro', 'Placido de Castro', 'Barraca Rapirran,Boca do Rapirra,Bocca do Rapirra', -10.3352800, -67.1855600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9171, 'Pimenta Bueno', 'Pimenta Bueno', 'PBQ', -11.6725000, -61.1936100, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9172, 'Ouro Preto do Oeste', 'Ouro Preto do Oeste', 'Oru-Pretu-du-Uehsti,Ouro Preto do Oeste,Ouro Prêto do Oeste,Ору-Прету-ду-Уэсти', -10.7480600, -62.2158300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9173, 'Ji Paraná', 'Ji Parana', 'JPR', -10.8852800, -61.9516700, 'BR', '2013-05-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9174, 'Jaru', 'Jaru', 'Juru,Zhara,Жара', -10.4388900, -62.4663900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9175, 'Guajará Mirim', 'Guajara Mirim', 'GJM,Guayaramerim', -10.7827800, -65.3394400, 'BR', '2016-12-26', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9176, 'Cacoal', 'Cacoal', 'Cacoal,Cacual,Kakoal,OAL,Какоал', -11.4386100, -61.4472200, 'BR', '2013-10-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9177, 'Brasiléia', 'Brasileia', 'Brasilia,Brasília', -11.0161100, -68.7480600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9178, 'Alta Floresta', 'Alta Floresta', 'AFL', -9.8755600, -56.0861100, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9179, 'Aparecida de Goiânia', 'Aparecida de Goiania', 'Aparesida de Gojanija,Aparesida di Gojanija,Aparesida-di-Gojanija,a pa lei xi da di ge ya ni ya,aparesida de go''iyaniya,Апаресида де Гојанија,Апаресида ди Гояния,Апаресида-ди-Гояния,আপারেসিডা ডে গোইয়ানিয়া,アパレシダ・デ・ゴイアニア,阿帕雷西達迪戈亞尼亞', -16.8233300, -49.2438900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9180, 'Araguanã', 'Araguana', '', -2.9463900, -45.6609800, 'BR', '2014-12-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9181, 'Campinas', 'Campinas', '', -27.5944400, -48.6069400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9182, 'Campo Limpo Paulista', 'Campo Limpo Paulista', '', -23.2063900, -46.7844400, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9183, 'Fernando de Noronha (Distrito Estadual)', 'Fernando de Noronha (Distrito Estadual)', 'peleunando de nolona,페르난도 데 노로나', -3.8402800, -32.4108300, 'BR', '2017-06-22', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9184, 'Jaboatão dos Guararapes', 'Jaboatao dos Guararapes', 'Zhaboatan-dus-Guararapis,Zhaboatao dos Guararapis,Zhaboatao dos Gvararapes,Zhabuatan-dus-Guararapis,jaboatangduseugualalapeseu,jaboraata''o dosa guraararapesa,re bo a tao,Жабоатан-дус-Гуарарапис,Жабоатао дос Гварарапес,Жабоатао дос Гуарарапис,Жабуатан-дус-Гуарарапіс,জাবোৱাটাও ডোস গুৱারারাপেস,ジャボアタン・ドス・グアララペス,熱博阿陶,자보아탕두스구아라라페스', -8.1127800, -35.0147200, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9185, 'Lago dos Rodrigues', 'Lago dos Rodrigues', '', -4.6130400, -44.9800900, 'BR', '2014-09-23', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9186, 'Lauro de Freitas', 'Lauro de Freitas', '', -12.8944400, -38.3272200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9187, 'Paulo Ramos', 'Paulo Ramos', '', -4.4438900, -45.2405600, 'BR', '2014-05-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9188, 'Pinhais', 'Pinhais', '', -25.4447200, -49.1925000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9189, 'Portelândia', 'Portelandia', '', -17.3536100, -52.6786100, 'BR', '2013-08-24', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9190, 'Rio Preto da Eva', 'Rio Preto da Eva', '', -2.6979500, -59.7017200, 'BR', '2014-06-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9191, 'Simões Filho', 'Simoes Filho', '', -12.7844400, -38.4038900, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9192, 'Sinop', 'Sinop', 'OPS', -11.8641700, -55.5025000, 'BR', '2013-01-09', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9193, 'Teixeira de Freitas', 'Teixeira de Freitas', 'TXF,Teixeira de Freitas', -17.5350000, -39.7419400, 'BR', '2015-06-07', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9194, 'Vargem Grande Paulista', 'Vargem Grande Paulista', '', -23.6033300, -47.0263900, 'BR', '2012-03-10', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9195, 'Cambebba', 'Cambebba', '', -3.6209200, -38.8291300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9196, 'Itacorubi', 'Itacorubi', '', -27.5831500, -48.4950300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9197, 'Corrego Grande', 'Corrego Grande', '', -27.6014100, -48.5059300, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9198, 'Santa Monica', 'Santa Monica', '', -27.5913700, -48.5075600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9199, 'Carvoeira', 'Carvoeira', '', -27.5989800, -48.5261800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9200, 'Trindade', 'Trindade', '', -27.5861200, -48.5233500, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9201, 'Morro da Cruz', 'Morro da Cruz', '', -27.5849000, -48.5356200, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9202, 'Saco dos Limoes', 'Saco dos Limoes', '', -27.6086400, -48.5360500, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9203, 'Pantanal', 'Pantanal', '', -27.6098500, -48.5164800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9204, 'Costeira do Pirajubae', 'Costeira do Pirajubae', '', -27.6358600, -48.5212000, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9205, 'Carianos', 'Carianos', '', -27.6608800, -48.5431800, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9206, 'Tapera', 'Tapera', '', -27.6852800, -48.5512400, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9207, 'Freguesia do Ribeirao da Ilha', 'Freguesia do Ribeirao da Ilha', '', -27.7177300, -48.5626600, 'BR', '2012-08-03', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9208, 'Atins', 'Atins', '', -2.5701700, -42.7422900, 'BR', '2013-09-30', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9209, 'Residencia Moacir PU5BHV', 'Residencia Moacir PU5BHV', '', -26.9096700, -49.3654700, 'BR', '2017-04-21', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9210, 'Beira Rio', 'Beira Rio', '', -12.2543800, -42.7552900, 'BR', '2014-08-01', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9211, 'Butia Inferior', 'Butia Inferior', '', -28.0711500, -54.8853300, 'BR', '2014-11-14', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9212, 'Nova Olina do Marnhao', 'Nova Olina do Marnhao', '', -2.8420600, -45.6978900, 'BR', '2014-12-12', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9213, 'Planaltina', 'Planaltina', 'Planaltina,gao yuan,高園', -15.6179100, -47.6487400, 'BR', '2016-06-11', 32);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9508, 'Klichaw', 'Klichaw', 'Klichau,Klichaw,Klichev,Кличев,Клічаў', 53.4923000, 29.3356000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9509, 'Klyetsk', 'Klyetsk', 'Kleck,Kletsk,Klyetsk,Клецк', 53.0635000, 26.6321000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9510, 'Kirawsk', 'Kirawsk', 'Kirausk,Kirawsk,Kirovsk,Startsy,Кировск,Кіраўск', 53.2693000, 29.4752000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9511, 'Khoyniki', 'Khoyniki', 'Choiniki,Khojniki,Khoyniki,Khoynki,Хойники,Хойнікі', 51.8911000, 29.9552000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9512, 'Khotsimsk', 'Khotsimsk', 'Chotimsk,Khocimsk,Khotimsk,Khotsimsk,Хотимск,Хоцімск', 53.4086000, 32.5780000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9513, 'Kholopenichi', 'Kholopenichi', 'Khalapenichy,Khalopenichy,Khalopyenichy,Kholopenichi,Халапенічы,Халопенічы,Холопеничи', 54.5174600, 28.9564500, 'BY', '2016-05-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9514, 'Khodasy', 'Khodasy', 'Khodasy,Khodosy,Ходасы,Ходосы', 53.9266000, 31.4779000, 'BY', '2012-08-31', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9515, 'Khal’ch', 'Khal''ch', 'Khal''ch,Khal’ch,Хальч', 52.5643000, 31.1364000, 'BY', '2014-08-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9516, 'Kamyanyuki', 'Kamyanyuki', 'Kameniki,Kamenjuki,Kamenyuki,Kamieniki,Kamjanjuki,Kamyanyuki,Каменюки,Камянюкі', 52.5575700, 23.8052500, 'BY', '2013-07-11', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9517, 'Kamyennyya Lavy', 'Kamyennyya Lavy', 'Kamennye Lavy,Kamennyja Lavy,Kamennyye Lavy,Kamyennyya Lavy,Каменные Лавы,Каменныя Лавы', 54.0898000, 30.2962000, 'BY', '2015-03-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9518, 'Kamyanyets', 'Kamyanyets', 'Kamenec,Kamenets,Kamenets-Litevske,Kamenets-Litevski,Kamenets-Litovsk,Kamenets-Litovskiy,Kamieniec Litewski,Kamjanec,Kamyanyets,Kmenets-Litovskiy,Каменец,Камянец', 52.4001300, 23.8100000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9519, 'Kalinkavichy', 'Kalinkavichy', 'Kalinkavichy,Kalinkovichi,Kalinkowitschi,Калинкавичы,Калинковичи', 52.1323000, 29.3257000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9520, 'Iwye', 'Iwye', 'Iue,Iv''e,Iv''ye,Iv’ye,Iwie,Iwje,Iwye,Vija,Іўе,Ивье', 53.9299000, 25.7727000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9521, 'Ivyanyets', 'Ivyanyets', 'Ivenec,Ivenets,Ivjanec,Ivyanyets,Iwienjec,Івянец,Ивенец', 53.8864000, 26.7432000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9522, 'Ivatsevichy', 'Ivatsevichy', 'Fol''vark Ivatseviche,Fol’vark Ivatseviche,Ivacehvichy,Ivacevichi,Ivantsevichi,Ivatsevichi,Ivatsevichy,Iwacewicze,Twacewicze,Івацэвічы,Ивацевичи', 52.7090000, 25.3401000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9523, 'Ivanava', 'Ivanava', 'Ivanava,Ivanovo,Janow,Janów,Yanov,Yanuv,Іванава,Иваново', 52.1451000, 25.5365000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9524, 'Il’ya', 'Il''ya', 'Il''ja,Il''ya,Ilia,Iliya,Ilja,Il’ya,Ілья,Илья', 54.4167000, 27.2958000, 'BY', '2012-04-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9525, 'Hrodna', 'Hrodna', 'GNA,Gardinas,Gorad Grodna,Goradnia,Grodna,Grodno,Grodņa,Hrodna,furodona,ge luo de nuo,ghrwdnw,grwdna,heulodeuna,hwrdnh,krxd no,Горад Гродна,Гродна,Гродно,הורדנה,غرودنو,گرودنا,กรอดโน,フロドナ,格罗德诺,흐로드나', 53.6884000, 23.8258000, 'BY', '2017-05-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9526, 'Horki', 'Horki', 'Gorad Gorki,Gorki,Horkai,Horki,ge er ji,hwrky,hwrqy,Горад Горкі,Горки,Горкі,הורקי,هوركي,戈爾基', 54.2862000, 30.9863000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9527, 'Gomel', 'Gomel', 'GME,Gomel,Gomel'',Gomela,Gomelis,Gomel’,Gomeļa,Gorad Gomel'',Gómel,Homel,Homel'',Homeľ,Homiel,Homyel,Homyel'',Homyel’,Hòmiel,ge mei li,ghwmyl,gwml,homel,homeri,hwml,komel,kx mel,Γόμελ,Гомел,Гомель,Гомељ,Горад Гомель,הומל,غوميل,گومل,கோமெல்,กอเมล,ホメリ,戈梅利,호멜', 52.4345000, 30.9754000, 'BY', '2014-03-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9528, 'Hlybokaye', 'Hlybokaye', 'Glebokie,Glenboke,Glubokoe,Glubokoye,Glybokae,Glębokie,Hlybokaye,Глубокое,Глыбокае', 55.1384000, 27.6905000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9529, 'Hantsavichy', 'Hantsavichy', 'Gancavichi,Gancavichy,Gancevichi,Gantseviche,Gantsevichi,Gorad Gancavichy,Hancavicai,Hancavici,Hancavicy,Hancavičai,Hancaviči,Hancavičy,Hancewicze,Hantsavichy,Hantsavitchy,Hantsavitsy,Hantsavitšy,Hanzawitschy,gan cai wei qi,hnzbyzy,Ганцавичи,Ганцавічы,Ганцевичи,Ганцевичі,Горад Ганцавічы,הנצביצי,甘采維奇', 52.7580000, 26.4300000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9530, 'Hotsk', 'Hotsk', 'Gock,Gotsk,Gotskaya,Hock,Hotsk,Гоцк', 52.5215000, 27.1385000, 'BY', '2013-12-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9531, 'Haradok', 'Haradok', 'Garadok,Gorad Garadok,Gorodok,Haradok,Haradoka,Haradokas,Horodek,ge luo duo ke,hrdwq,Гарадок,Горад Гарадок,Городок,הרדוק,戈羅多克', 55.4624000, 29.9845000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9532, 'Haradzishcha', 'Haradzishcha', 'Garadzishcha,Gorodishche,Gorodishhe,Gorodyshche,Haradzishcha,Horodyszcze,Гарадзішча,Городище', 53.3247000, 26.0107000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9533, 'Haradzyeya', 'Haradzyeya', 'Garadzeja,Gorodeja,Gorodey,Gorodeya,Gorodzey,Haradzyeya,Horodziej,Гарадзея,Городея', 53.3121000, 26.5380000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9534, 'Hal’shany', 'Hal''shany', 'Alsenai,Alšėnai,Gal''shany,Gol''shany,Gol’shany,Hal''shany,Hal’shany,Holszany,Ol''shany,Ol’shany,Гальшаны,Гольшаны', 54.2585000, 26.0144000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9535, 'Hlusk', 'Hlusk', 'Glusk,Glussk,Hlusk,Глуск', 52.9030000, 28.6845000, 'BY', '2013-05-12', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9536, 'Hlusha', 'Hlusha', 'Glusha,Hlusha,Глуша', 53.0868000, 28.8567000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9537, 'Hyeranyony', 'Hyeranyony', 'Geranainys,Geraneny,Geranjony,Geranony,Geranëny,Hyeranyony,Геранены,Геранёны', 54.1159000, 25.5773000, 'BY', '2016-08-31', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9538, 'Hatava', 'Hatava', 'Gatava,Gatovo,Hatava,Гатава,Гатово', 53.7829000, 27.6407000, 'BY', '2012-03-22', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9539, 'Dzyarzhynsk', 'Dzyarzhynsk', 'Dsjarschynsk,Dzerjinsk,Dzerzhins''k,Dzerzhinsk,Dzerĵinsk,Dziarjynsk,Dziarzjynsk,Dziarzynsk,Dziarzynskas,Dziaržynsk,Dziaržynskas,Dzierzynsk,Dzierżyńsk,Dzjarzhinsk,Dzjarzhynsk,Dzjarzinska,Dzjarzsinszk,Dzjarzynsk,Dzjaržinska,Dzjaržynsk,Dzyarzhynsk,Gorad Dzjarzhynsk,Kaiden,Kaydanovo,Koydanava,Koydanovo,dzyarjynsk,jie er ren si ke,Горад Дзяржынск,Дзержинск,Дзержинськ,Дзяржынск,Дзјаржинск,دزيارجينسك,捷爾任斯克', 53.6832000, 27.1380000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9540, 'Dzyatlava', 'Dzyatlava', 'Djatlovo,Dyatlovo,Dzentsel,Dzjatlava,Dzyatlava,Zdzentsyul,Zdzieciol,Zdzięcioł,Дзятлава,Дятлово', 53.4631000, 25.4068000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9541, 'Dukora', 'Dukora', 'Dukora,Дукора', 53.6786000, 27.9400000, 'BY', '2013-04-01', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9542, 'Dubrowna', 'Dubrowna', 'Dubrouna,Dubrovka,Dubrovno,Dubrowna,Дубровно,Дуброўна', 54.5716000, 30.6910000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9543, 'Drybin', 'Drybin', 'Dribin,Drybin,Staryy Dribin,Дрибин,Дрыбін', 54.1192000, 31.0939000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9544, 'Druya', 'Druya', 'Druja,Druya,Друя', 55.7906000, 27.4505000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9545, 'Drahichyn', 'Drahichyn', 'Dragichyn,Drahichyn,Drogichin,Drohiczyn,Драгічын,Дрогичин', 52.1874000, 25.1597000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9546, 'Dowsk', 'Dowsk', 'Dousk,Dovsk,Dowsk,Довск,Доўск', 53.1571000, 30.4601000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9547, 'Damachava', 'Damachava', 'Damacava,Damachava,Damacsava,Damatschawa,Damačava,Domacheva,Domacheve,Domachevo,Domachovo,Domachëvo,Domaczewo,dwmz''b,Дамачава,Домачеве,Домачово,דומצ''ב', 51.7500000, 23.6000000, 'BY', '2016-02-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9548, 'Dokshytsy', 'Dokshytsy', 'Dokchytsy,Dokshici,Dokshicy,Dokshitsy,Dokshycy,Dokshytse,Dokshytsy,Doksici,Doksjytsy,Doksycy,Doksytsy,Dokszyce,Dokšici,Dokšycy,Dokšytsy,Gorad Dokshycy,duo ke xi qi,dwqsyzh,Горад Докшыцы,Докшици,Докшицы,Докшиці,Докшыцы,דוקשיצה,多克希齊', 54.8918000, 27.7667000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9549, 'Dobrush', 'Dobrush', 'Dobrush,Добруш', 52.4089000, 31.3237000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9550, 'Dzisna', 'Dzisna', 'Disna,Dzisna,Дзісна,Дисна', 55.5676000, 28.2076000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9551, 'Davyd-Haradok', 'Davyd-Haradok', 'David Garadok,David-Gorodok,Davidgrodek,Davidharadoka,Davyd Haradokas,Davyd-Garadok,Davyd-Haradok,Dawid-Grodek,Dawid-Gródek,Dawidgrodek,Dawidgródek,Gorad Davyd-Garadok,dwyd-hrdwq,Горад Давыд-Гарадок,Давид Гарадок,Давид-Городок,Давыд-Гарадок,דויד-הרדוק,ダヴィド・ハラドク', 52.0566000, 27.2161000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9552, 'Dashkawka', 'Dashkawka', 'Dashkauka,Dashkawka,Dashkovka,Дашкаўка,Дашковка', 53.7352000, 30.2625000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9553, 'Chervyen’', 'Chervyen''', 'Chehrven'',Cherven'',Cherven’,Chervyen'',Chervyen’,Igumen,Tscherwen,Червень,Чэрвень', 53.7059000, 28.4313000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9554, 'Charnawchytsy', 'Charnawchytsy', 'Charnauchycy,Charnawchytsy,Chernavchicy,Chernavchitse,Chernavchitsy,Czernawczyce,Чарнаўчыцы,Чернавчицы', 52.2194800, 23.7404300, 'BY', '2013-07-11', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9555, 'Cherykaw', 'Cherykaw', 'Chehrykau,Cherikov,Cherykaw,Tscherikow,Чериков,Чэрыкаў', 53.5689000, 31.3831000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9556, 'Chachersk', 'Chachersk', 'Cacersk,Cacerska,Chachehrsk,Chachersk,Chechers''k,Chechersk,Csacserszk,Czeczersk,Gorad Chachehrsk,Tchatchersk,Tjatjersk,Tsatsersk,Tšatšersk,chacherusuku,zzrsq,Čačersk,Čačerska,Горад Чачэрск,Чачерск,Чачэрск,Чечерск,Чечерськ,צצרסק,チャチェルスク', 52.9164000, 30.9179000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9557, 'Chavusy', 'Chavusy', 'Cavusai,Chausi,Chausy,Chavusi,Chavusy,Czausy,Gorad Chavusy,Tchavoussy,Tjavusy,Tsavusy,Tschawussy,Tšavusy,chausi,qiao se,Čavusai,Горад Чавусы,Чавуси,Чавусы,Чауси,Чаусы,צאבוסי,喬瑟,차우시', 53.8098000, 30.9717000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9558, 'Chashniki', 'Chashniki', 'Chashniki,Чашники,Чашнікі', 54.8584000, 29.1608000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9559, 'Bykhaw', 'Bykhaw', 'Bikhav,Bikhov,Bychau,Bychavas,Bychaŭ,Bychow,Bychów,Byh''au,Byh’au,Bykhau,Bykhaw,Bykhov,Gorad Bykhau,Star Bykhov,Staryy Bykhov,bei huo fu,bihapeu,bihau,byhwb,Бихав,Бихов,Быхаў,Быхов,Горад Быхаў,ביחוב,ビハウ,貝霍夫,비하프', 53.5210000, 30.2454000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9560, 'Byaroza', 'Byaroza', 'Bereza,Bereza Kartuska,Bereza-Kartuskaya,Bereza-Kartuzskaya,Berjoza,Berëza,Bjaroza,Byaroza,Kartuz-Bereza,Берёза,Бяроза', 52.5314000, 24.9786000, 'BY', '2013-12-10', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9561, 'Buynichy', 'Buynichy', 'Bujnichi,Bujnichy,Bunichi,Buynichi,Buynichy,Буйничи,Буйнічы', 53.8536000, 30.2671000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9562, 'Buda-Kashalyova', 'Buda-Kashalyova', 'Bouda-Kachaliova,Buda Kasaliova,Buda Kashalova,Buda Kašaliova,Buda Koszelewska,Buda-Kasaljova,Buda-Kashaljova,Buda-Kashalyova,Buda-Kašaljova,Buda-Koshel''ovo,Buda-Koshelevo,Buda-Koshelevskaya,Buda-Kosheljovo,Buda-Koshelëvo,Gorad Buda-Kashaljova,bu da ka sha liao wa,bwdh-qwslbw,Буда Кашаљова,Буда-Кашалёва,Буда-Кошелево,Буда-Кошельово,Буда-Кошелёво,Горад Буда-Кашалёва,בודה-קושלבו,布達卡沙廖瓦', 52.7179000, 30.5701000, 'BY', '2012-02-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9563, 'Brest', 'Brest', 'BQT,Beras''ce,Berestja,Brehst,Bressicia,Brest,Brest Litovsk,Brest i Kviterussland,Brest-Litovsk,Brest-Litowsk,Bresta,Brestas,Bresto,Breszt,Brzesc,Brzesc nad Bugiem,Brzesc-Litewsk,Brzesc-Litewski,Brześć,Brześć nad Bugiem,Brześć-Litewsk,Brześć-Litewski,Brėst,Byeras''tsye,Byeras’tsye,be rst,beuleseuteu,bresta,brst,brst  blarws,brysq,bu lie si te,buresuto,Берасьце,Берестя,Брест,Брэст,בריסק,ברסט,برست,برست، بلاروس,بریسٹ، بیلاروس,ब्रेस्त,เบรสต์,ბრესტი,ブレスト,布列斯特,브레스트', 52.0975500, 23.6877500, 'BY', '2017-05-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9564, 'Braslaw', 'Braslaw', 'Braslau,Braslav,Braslava,Braslaw,Braslaŭ,Brastaw,Braszlav,Brasław,Brasłaŭ,Breslauja,Gorad Braslau,brslb,bu la si la fu,burasurau,Браслав,Браслаў,Горад Браслаў,ברסלב,ブラスラウ,布拉斯拉夫', 55.6413000, 27.0418000, 'BY', '2015-01-15', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9565, 'Brahin', 'Brahin', 'Bragin,Brahin,Брагин,Брагін', 51.7870000, 30.2677000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9566, 'Turets-Bayary', 'Turets-Bayary', 'Bojary,Boyary,Turehc-Bajary,Turets-Bayary,Turets-Boyary,Турэц-Баяры', 54.3785000, 26.6581000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9567, 'Baruny', 'Baruny', 'Baruny,Boruny,Баруны,Боруны', 54.3171000, 26.1376000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9568, 'Vyaliki Trastsyanets', 'Vyaliki Trastsyanets', 'Bol''shoy Trostenets,Bol’shoy Trostenets,Vjaliki Trascjanec,Vyaliki Trastsyanets,Вялікі Трасцянец', 53.8510000, 27.7139000, 'BY', '2012-03-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9569, 'Vyalikaya Byerastavitsa', 'Vyalikaya Byerastavitsa', 'Berestovitsa,Bol''saja Berestovica,Bol''shaja Berestovica,Bol''shaya Berestovitsa,Bol’shaya Berestovitsa,Bol’šaja Berestovica,Brzostowica Wielka,Vel''ke Bzhostovitsa,Velikaya Berestovitsa,Velikaya Bzhostovitsa,Vel’ke Bzhostovitsa,Vjalikaja Berastavica,Vyalikaya Byerastavitsa,Большая Берестовица,Вялікая Бераставіца', 53.1960000, 24.0166000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9570, 'Bobr', 'Bobr', 'Bobr,Бобр', 54.3420000, 29.2736000, 'BY', '2012-06-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9571, 'Blon’', 'Blon''', 'Blon'',Blon’,Блонь', 53.5269000, 28.1732000, 'BY', '2012-03-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9572, 'Berëzovka', 'Berezovka', 'Berezovka,Berjozovka,Berëzovka,Берёзовка', 53.7214300, 25.4992700, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9573, 'Byerazino', 'Byerazino', 'Berazino,Berezino,Byerazino,Беразіно,Березино', 53.8391000, 28.9879000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9574, 'Byalynichy', 'Byalynichy', 'Belynichi,Bjalynichy,Byalynichy,Byelinichi,Белыничи,Бялынічы', 53.9994000, 29.7141000, 'BY', '2012-05-05', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9575, 'Byelaazyorsk', 'Byelaazyorsk', 'Belaazjorsk,Beloozersk,Berezovskiy,Byelaazyorsk,Белаазёрск,Белоозерск', 52.4731000, 25.1784000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9576, 'Byahoml’', 'Byahoml''', 'Begoml'',Begomlya,Begoml’,Bjagoml'',Byahoml'',Byahoml’,Бегомль,Бягомль', 54.7316000, 28.0577000, 'BY', '2012-02-28', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9577, 'Horad Barysaw', 'Horad Barysaw', 'Barysaw,Borisov,Borissow,Gorad Barysau,Gorod Borisov,Horad Barysaw,Горад Барысаў,Город Борисов', 54.2279000, 28.5050000, 'BY', '2017-07-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9578, 'Baranovichi', 'Baranovichi', 'Baranavichy,Baranavitsjy,Baranawitschy,Baranoviche,Baranovichi,Baranovichi - Baranavichy,Baranovichi - Баранавiчы,Baranoviciai,Baranovitchi,Baranovitsi,Baranovitši,Baranovičiai,Baranowicze,Баранавічы,Барановичи', 53.1327000, 26.0139000, 'BY', '2014-03-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9579, 'Baran’', 'Baran''', 'Baran'',Baran’,Барань', 54.4784000, 30.3159000, 'BY', '2014-06-27', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9580, 'Babruysk', 'Babruysk', 'Babroejsk,Babruisk,Babrujsk,Babruysk,Bobruisk,Bobruiskas,Bobrujsk,Bobruysk,bwbrwysq,Бабруйск,Бобруйск,בוברויסק', 53.1384000, 29.2214000, 'BY', '2012-01-18', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9581, 'Ashmyany', 'Ashmyany', 'Achmiany,Aschmjany,Ashmiany,Ashmjani,Ashmjany,Ashmyany,Asjmjany,Asmena,Asmiany,Asmjani,Asmjany,Ašmena,Ašmiany,Ašmjani,Ašmjany,Gorad Ashmjany,Oshmjani,Oshmjany,Oshmyana,Oshmyany,Oszmiana,ao shen mi ya nei,Ашмяны,Ашмјани,Горад Ашмяны,Ошмяни,Ошмяны,אשמיאני,奧什米亞內', 54.4210000, 25.9360000, 'BY', '2015-01-14', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9582, 'Antopal’', 'Antopal''', 'Antopal'',Antopal’,Antopol'',Antopol’,Антопаль,Антополь', 52.2038000, 24.7863000, 'BY', '2014-06-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9583, 'Balbasava', 'Balbasava', 'Balbasava,Bolbasovo,Балбасава', 54.4207000, 30.2909000, 'BY', '2012-05-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9584, 'Ramanavichy', 'Ramanavichy', 'Ramanavichy,Romanovichi,Раманавічы,Романовичи', 53.8653000, 30.5597000, 'BY', '2014-09-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9585, 'Palykavichy Pyershyya', 'Palykavichy Pyershyya', 'Palykavichy Pershyja,Palykavichy Pyershyya,Polyk''vichi,Polykovichi,Polykovichi Pervyye,Polyk’vichi,Палыкавічы Першыя,Полыковичи', 53.9854000, 30.3600000, 'BY', '2012-06-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9586, 'Horad Kobryn', 'Horad Kobryn', 'Gorad Kobryn,Gorod Kobrin,Horad Kobryn,Горад Кобрын', 52.2161100, 24.3663900, 'BY', '2012-01-19', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9587, 'Horad Luninyets', 'Horad Luninyets', 'Gorad Luninec,Gorod Luninets,Horad Luninyets,Горад Лунінец', 52.2502800, 26.7994400, 'BY', '2012-01-19', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9588, 'Horad Pinsk', 'Horad Pinsk', 'Gorad Pinsk,Gorod Pinsk,Horad Pinsk,Горад Пінск', 52.1213900, 26.0727800, 'BY', '2012-01-19', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9589, 'Horad Orsha', 'Horad Orsha', 'Gorad Orsha,Gorod Orsha,Horad Orsha,Горад Орша', 54.5152800, 30.4052800, 'BY', '2012-05-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9590, 'Horad Rechytsa', 'Horad Rechytsa', 'Gorad Rehchyca,Gorod Rechitsa,Horad Rechytsa,Горад Рэчыца', 52.3638900, 30.3947200, 'BY', '2012-02-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9591, 'Horad Krychaw', 'Horad Krychaw', 'Gorad Krychau,Gorod Krichev,Horad Krychaw,Горад Крычаў', 53.6988900, 31.7141700, 'BY', '2012-06-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9592, 'Fanipol', 'Fanipol', 'Fanipal,Fanipal'',Fanipaĺ,Fanipol,Fanipol'',Фанiпаль,Фаниполь', 53.7499800, 27.3333800, 'BY', '2014-08-03', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9593, 'Khatsyezhyna', 'Khatsyezhyna', 'Khacezhyna,Khatezhino,Khatsyezhyna,Хатежино,Хацежына', 53.9094000, 27.3069000, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9594, 'Schomyslitsa', 'Schomyslitsa', 'Shchomyslica,Shchomyslitsa,Шчомысліца', 53.8211000, 27.4522000, 'BY', '2015-12-04', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9595, 'Yubilyeyny', 'Yubilyeyny', 'Jubilejny,Yubileynyy,Yubilyeyny,Юбілейны', 53.8191000, 27.5215000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9596, 'Atolina', 'Atolina', 'Atolina,Atolino,Атоліна', 53.7817000, 27.4346000, 'BY', '2012-03-26', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9597, 'Pryvol’ny', 'Pryvol''ny', 'Privol''nyy,Privol’nyy,Pryvol''ny,Pryvol’ny,Прывольны', 53.7969000, 27.7967000, 'BY', '2012-04-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9598, 'Enyerhyetykaw', 'Enyerhyetykaw', 'Ehnergetikov,Ehnergetykau,Energetikov,Enyerhyetykaw,Энергетиков,Энергетыкаў', 53.5871000, 27.0535000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9599, 'Svislach', 'Svislach', 'Svislach,Svisloch'',Svisloch’,Свіслач', 53.6404000, 27.9199000, 'BY', '2012-04-06', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9600, 'Druzhny', 'Druzhny', 'Druzhny,Druzhnyy,Poselok Druzhnyy,Posëlok Druzhnyy,Дружны', 53.6238000, 27.8977000, 'BY', '2013-12-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9601, 'Malinovka', 'Malinovka', 'Malinovka,Малиновка', 53.8579000, 27.4374000, 'BY', '2012-03-23', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9602, 'Peramoga', 'Peramoga', 'Peramoga,Peremoga,Pieramoha,Pobeda,Перамога,Перемога,Победа', 52.3973000, 31.0710000, 'BY', '2017-06-12', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9603, 'Borovlyany', 'Borovlyany', 'Barauljany,Borovljany,Borovlyany,Бараўляны,Боровляны', 54.0022000, 27.6754000, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9604, 'Chyst’', 'Chyst''', 'Chist'',Chysc'',Чисть,Чысць', 54.2698000, 27.1067000, 'BY', '2013-11-16', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9605, 'Lyeskawka', 'Lyeskawka', 'Leskauka,Leskovka,Lyeskawka,Лескаўка', 54.0024000, 27.7108000, 'BY', '2012-04-07', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9606, 'Lyasny', 'Lyasny', 'Lesnoj,Lesnoy,Ljasny,Lyasny,Лесной,Лясны', 54.0072000, 27.6963000, 'BY', '2012-04-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9607, 'Bal’shavik', 'Bal''shavik', 'Bal''shavik,Bal’shavik,Bol''shevik,Bol’shevik,Sovkhoz Bol''shevik,Sovkhoz Bol’shevik,Бальшавік,Большевик', 54.0036000, 27.5669000, 'BY', '2012-04-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9608, 'Усяж', 'Usjazh', 'Usiazh,Usjazh,Усяж', 54.0759800, 28.0069800, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9609, 'Октябрьский', 'Oktjabr''skij', 'Kastrychnicki,Oktjabr''skij,Кастрычніцкі,Октябрьский', 54.0405900, 28.1981300, 'BY', '2012-04-09', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9610, 'Michanovichi', 'Michanovichi', 'Mikhanavichy,Mikhanovichi,Михановичи,Міханавічы', 53.7393700, 27.6927600, 'BY', '2012-05-08', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9611, 'Posëlok Voskhod', 'Poselok Voskhod', 'Poselok Voskhod,Posjolok Voskhod,Posëlok Voskhod,Uskhod,Посёлок Восход,Усход', 53.7766000, 30.3497000, 'BY', '2014-10-02', 21);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9612, 'Shipyard', 'Shipyard', 'Shipyard', 17.8938200, -88.6545200, 'BZ', '2014-02-08', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9613, 'San Pedro', 'San Pedro', 'Gorad San-Pedra,SPR,San Pedras,San Pedro Town,San-Pedro,sheng pei de luo,sn pdrw,Горад Сан-Педра,Сан-Педро,סן פדרו,聖佩德羅', 17.9159800, -87.9659000, 'BZ', '2014-02-08', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9614, 'San Ignacio', 'San Ignacio', 'Cayo,Cayo Town,El Cayo de San Ignacio,SQS,San Ignacio,San Ignacio/Santa Elena,San Ignasijus,San-Ignasio,San-Ignasio-Kajo,san agnasyw  bylyz,sheng yi ge na xi ao,sn ʼygnsyw,Сан-Ігнасіо-Кайо,Сан-Игнасио,סן איגנסיו,سان اگناسیو، بیلیز,聖伊格納西奧', 17.1588000, -89.0696000, 'BZ', '2016-10-16', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9615, 'Punta Gorda', 'Punta Gorda', 'P.G,PND,Punta Gorda,Punta-Gorda,peng ta ge er da,pnta gwrda  bylyz,pwnth gwrdh,Пунта Горда,Пунта-Горда,פונטה גורדה,پنتا گوردا، بیلیز,蓬塔戈爾達', 16.0983500, -88.8097000, 'BZ', '2013-06-27', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9616, 'Placencia', 'Placencia', 'PLJ,Placencia,Placencia Village,Placentia,Placentia Village,Plasencia,Point Placentia,Punta Placencia', 16.5141900, -88.3664700, 'BZ', '2017-05-09', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9617, 'Orange Walk', 'Orange Walk', 'ORZ,Orange Walk', 18.0812400, -88.5632800, 'BZ', '2013-11-16', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9618, 'Dangriga', 'Dangriga', 'DGA,Dangriga,Dangriga Town  Dangriga,Stann Creek,Stann Creek Town,Stann Creek Village,Stanncrek', 16.9697000, -88.2331300, 'BZ', '2014-08-03', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9619, 'Corozal', 'Corozal', 'CZH,Corasal,Corazal,Corosal,Corozal', 18.3937500, -88.3884900, 'BZ', '2013-06-27', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9620, 'Benque Viejo del Carmen', 'Benque Viejo del Carmen', 'Bengue Viejo,Benique Viejo del Carmen,Benque Viejo,Benque Viejo del Carmen,Cayo', 17.0750000, -89.1391700, 'BZ', '2012-01-18', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9621, 'Belmopan', 'Belmopan', 'BCV,Bel''mopan,Belmopan,Belmopana,Belmopanas,Belmopano,Belmopanum,Belmopán,Belmópan,Bèlmopan,Gorad Bel''mapan,Hattieville,Mopan,Mpelmopan,bailamopana,bei er mo bang,bei er mo pan,belmopan,belmopana,berumopan,blmwban,blmwpan,blmwpn,bylmwpan,pelmoppan,Μπελμοπάν,Белмопан,Бельмопан,Горад Бельмапан,Բելմոպան,בלמופן,בעלמאפאן,بلموبان,بلموپان,بیلموپان,बेल्मोपान,ਬੈਲਮੋਪਾਨ,பெல்மோப்பான்,เบลโมแพน,པེར་མོ་ཕན།,ბელმოპანი,ቤልሞፓን,ベルモパン,貝爾墨邦,貝爾莫潘,벨모판', 17.2500000, -88.7666700, 'BZ', '2012-01-18', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9622, 'Belize City', 'Belize City', 'Altepetl Belice,BZE,Bandaraya Belize,Belice,Beliz,Beliz Siti,Belizas,Belize,Belize Ceety,Belize City,Belize-stad,Belizurbo,Cidade de Belize,Ciudad de Belice,Dinas Belize,Kota Belize,Poli tou Beliz,Syudad han Belize,Thanh pho Belize,Thành phố Belize,be lis si ti,belijha siti,beliza siti,bellijeusiti,berizushiti,blyz syty,bo li ci shi,Πόλη του Μπελίζ,Белиз,Белиз Сити,Белизе,Беліз,בליז סיטי,بلیز سیتی,بیلیز شہر,بېلىز شەھىرى,बेलीज़ सिटी,बेलीझ सिटी,เบลีซซิตี,ဘလိဇ်မြို့,ベリーズシティ,伯利兹市,벨리즈시티', 17.4995200, -88.1975600, 'BZ', '2013-09-27', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9623, 'Valley of Peace', 'Valley of Peace', 'Valley of Peace', 17.3347200, -88.8347200, 'BZ', '2012-01-20', 23);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9624, 'Abbotsford', 'Abbotsford', 'Abbotsford,Abotsford,Abotsfordas,YXX,abottsufodo,abwtsfwrd,abwtsfwrd  brytysh klmbya,aebeocheupeodeu,ya bo si fu,Абботсфорд,Аботсфорд,أبوتسفورد,ابوتسفورد، بریتیش کلمبیا,ایباٹسفورڈ,ایبٹس فورڈ، برٹش کولمبیا,アボッツフォード,亞博斯福,애버츠퍼드', 49.0579800, -122.2525700, 'CA', '2013-04-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9625, 'Acton Vale', 'Acton Vale', 'Akton Veil,Akton Vejl,Aktonvejl,aktwn wal  kbk,Άκτον Βέιλ,Актон Вејл,Актонвейл,اکتون وال، کبک,ایکٹن والی', 45.6500700, -72.5658200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9626, 'Adstock', 'Adstock', 'adstwk,adstwk  kbk,أدستوك,ادستوک، کبک', 46.0500700, -71.0823500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9627, 'Agassiz', 'Agassiz', '', 49.2329800, -121.7692600, 'CA', '2011-10-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9628, 'Airdrie', 'Airdrie', 'Erdri,ai er de li,ayrdray,ayrdry,eeodeuli,Ердри,إيردراي,ائرڈرائ,ائیرڈرائی، البرٹا,ایردری,艾尔德里,에어드리', 51.3001100, -114.0352800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9629, 'Ajax', 'Ajax', 'Adzhaks,Ehjdzhaks,Ejdzaks,ajaks,ajaks  antaryw,eijaegseu,eijakkusu,ya ji shi,Аджакс,Ејџакс,Эйджакс,أجاكس,اجاکس، انتاریو,エイジャックス,亞積士,에이잭스', 43.8501200, -79.0328800, 'CA', '2011-12-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9630, 'Albanel', 'Albanel', '', 48.8832400, -72.4486700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9631, 'Alberton', 'Alberton', 'Alberton,albrtwn  jzyrh prns adward,Албертон,آلبرتون، جزیره پرنس ادوارد', 46.8168500, -64.0654200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9632, 'Alma', 'Alma', 'Al''ma,Alma,YTF,alma,alma  kbk,alma  kybk,Алма,Альма,آلما,آلما، کبک,ألما، كيبك', 48.5500900, -71.6491000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9633, 'Altona', 'Altona', 'Altona,altwna  manytwba,Алтона,التونا، مانیتوبا,الٹونا، مینی ٹوبا', 49.1046900, -97.5596100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9634, 'Amherst', 'Amherst', 'a mo si te,amhrst,amhrst  nwa askatya,أمهرست,امهرست، نوا اسکاتیا,阿默斯特', 45.8334500, -64.1987400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9635, 'Amherstburg', 'Amherstburg', '', 42.1167900, -83.0498500, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9636, 'Amos', 'Amos', 'Amos,YEY,amws,amws  kbk,amws  kybk,Амос,آموس، کبک,أموس، كيبك,اموس', 48.5668800, -78.1162400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9637, 'Ange-Gardien', 'Ange-Gardien', 'Ange-Gardien', 45.3500800, -72.9324400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9638, 'Angus', 'Angus', '', 44.3168100, -79.8829500, 'CA', '2006-01-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9639, 'Anmore', 'Anmore', '', 49.3163700, -122.8526300, 'CA', '2013-08-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9640, 'Antigonish', 'Antigonish', 'Antigonis,antygwnysh. nwa askwshya,آنتیگونیش٬ نوا اسکوشیا', 45.6168500, -61.9985800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9641, 'Armstrong', 'Armstrong', 'Armstrong,a mu si te lang,armstrang  brytysh klmbya,Армстронг,آرمسترانگ، بریتیش کلمبیا,آرمسٹرانگ,آرمسٹرانگ، برٹش کولمبیا,阿姆斯特朗', 50.4497900, -119.2023500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9642, 'Arnprior', 'Arnprior', 'Arnprajor,anpuraia,arnprywr,Арнпрајор,آرنپریور,アーンプライアー', 45.4334100, -76.3493900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9643, 'Asbestos', 'Asbestos', 'Asbestos', 45.7667800, -71.9324000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9644, 'Ashcroft', 'Ashcroft', 'Ashcroft,YZA,ashkrwft,أشكروفت', 50.7237200, -121.2820700, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9645, 'Assiniboia', 'Assiniboia', 'Asiniboja,asynybwyya  saskachwan,Асинибоја,آسینیبوئیا، ساسکاچوان', 49.6333600, -105.9844600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9646, 'Athabasca', 'Athabasca', 'Atabaska,a sa ba si ka,Атабаска,阿萨巴斯卡', 54.7168700, -113.2853700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9647, 'Atikokan', 'Atikokan', 'Atikokan,YIB', 48.7566700, -91.6240900, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9648, 'Aylmer', 'Aylmer', '', 42.7667900, -80.9830200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9649, 'Baie-Comeau', 'Baie-Comeau', 'Baie-Comeau,Be Komo,Be-Komo,YBC,bay kamyw,bh-kwmw,byh kwmw  kybk,Бе Комо,Бе-Комо,بائ کامیو,به-کومو,بيه كومو، كيبك', 49.2167900, -68.1489400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9650, 'Baie-D''Urfé', 'Baie-D''Urfe', '', 45.4139700, -73.9158600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9651, 'Bancroft', 'Bancroft', '', 45.0575200, -77.8570200, 'CA', '2008-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9652, 'Banff', 'Banff', 'Banf,Banfas,Banff,YBA,baenpeu,ban fu,banf,banfu,banpi,bnf,Банф,Банфф,بانف,بنف,ბანფი,バンフ,班夫,밴프', 51.1762200, -115.5698200, 'CA', '2010-06-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9653, 'Barraute', 'Barraute', '', 48.4334900, -77.6327900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9654, 'Barrhead', 'Barrhead', 'Barhedas,Barkhed,ba er hei de,Бархед,巴尔黑德', 54.1334500, -114.4021100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9655, 'Barrie', 'Barrie', 'Bari,Baris,Barri,Barrie,Berri,YLK,ba li,baeli,bari,bary,bry  antaryw,Бари,Барри,Беррі,باري,باری,باری، اونٹاریو,بری، انتاریو,バリー,巴里,배리', 44.4001100, -79.6663400, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9656, 'Bassano', 'Bassano', '', 50.7834200, -112.4685400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9657, 'Bay Roberts', 'Bay Roberts', 'bay rwbrts,باي روبرتس', 47.5998900, -53.2647800, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9658, 'Beaconsfield', 'Beaconsfield', 'Bikonsfild,bykwnsfyld,bykwnsfyld  kbk,Биконсфилд,بيكونسفيلد,بیکنزفیلڈ,بیکونسفیلد، کبک', 45.4334100, -73.8658600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9659, 'Beauharnois', 'Beauharnois', 'Boarnoa,bwarnwa  kbk,bwarnwa  kybk,Боарноа,بوآرنوآ، کبک,بوأرنوا، كيبك,بیوہارنوئس', 45.3134100, -73.8725000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9660, 'Beaumont', 'Beaumont', 'Bomont,Бомонт', 53.3501300, -113.4187100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9661, 'Beausejour', 'Beausejour', '', 50.0622000, -96.5166900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9662, 'Beaverlodge', 'Beaverlodge', 'Biverlodz,Биверлоџ', 55.2166400, -119.4360500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9663, 'Bécancour', 'Becancour', 'Becancour,Bekankur,Bécancour,bkankwr  kbk,bykankwr  kybk,byknkwr,Беканкур,بيكانكور، كيبك,بکانکور، کبک,بیکنکور', 46.3333600, -72.4324100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9664, 'Bedford', 'Bedford', '', 45.1167800, -72.9824400, 'CA', '2014-01-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9665, 'Belfast', 'Belfast', '', 46.0834100, -62.8819700, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9666, 'Belleville', 'Belleville', 'Bel''vil'',Belleville,Belvil,Bilivailas,XVV,bei er wei er,belbil,berubiru,blwyl  antaryw,bylfy,Белвил,Бельвиль,Бельвіль,بلویل، انتاریو,بيلفي,بیلول، اونٹاریو,بیلی ولے,ベルビル,贝尔维尔,벨빌', 44.1668200, -77.3827700, 'CA', '2016-09-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9667, 'Bells Corners', 'Bells Corners', 'Bells Corners,Bels-Korners,Ottawa Bells Corners,Белс-Корнерс', 45.3158800, -75.8301200, 'CA', '2010-03-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9668, 'Beloeil', 'Beloeil', 'Beloeil,Beloej,Belœil,blwy  kbk,blwyl,byl awy  kybk,Белоеј,بلوئل,بلوی، کبک,بيل أوي، كيبك', 45.5683900, -73.2056800, 'CA', '2017-01-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9669, 'Berthierville', 'Berthierville', 'Berthierville', 46.0833600, -73.1824500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9670, 'Berwick', 'Berwick', '', 45.0501500, -64.7320800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9671, 'Biggar', 'Biggar', 'Bigar,Бигар', 52.0668000, -108.0013500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9672, 'Black Diamond', 'Black Diamond', '', 50.7001100, -114.2353000, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9673, 'Blackfalds', 'Blackfalds', '', 52.3834200, -113.7853000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9674, 'Blainville', 'Blainville', '', 45.6667800, -73.8824900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9675, 'Bluewater', 'Bluewater', '', 43.4667900, -81.5997700, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9676, 'Boisbriand', 'Boisbriand', '', 45.6167800, -73.8324900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9677, 'Bois-des-Filion', 'Bois-des-Filion', '', 45.6667800, -73.7491800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9678, 'Boissevain', 'Boissevain', '', 49.2306200, -100.0558600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9679, 'Bon Accord', 'Bon Accord', '', 53.8334500, -113.4187200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9680, 'Bonavista', 'Bonavista', '', 48.6498900, -53.1147400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9681, 'Bonnyville', 'Bonnyville', 'Bonivil,YBY,Бонивил', 54.2668400, -110.7350500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9682, 'Botwood', 'Botwood', '', 49.1499400, -55.3481900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9683, 'Boucherville', 'Boucherville', 'Bushervil,Bushervil'',bushavu~iru,bwshrwyl,bwshyfyl  kybk,Бушервил,Бушервиль,باؤچرولے,بوشرویل,بوشيفيل، كيبك,ブーシャーヴィル', 45.5910400, -73.4360500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9684, 'Bouctouche', 'Bouctouche', 'Baktush,Бактуш', 46.4684400, -64.7390500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9685, 'Bourget', 'Bourget', '', 45.4334000, -75.1493000, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9686, 'Bowen Island', 'Bowen Island', '', 49.3847000, -123.3362200, 'CA', '2013-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9687, 'Bow Island', 'Bow Island', '', 49.8667600, -111.3684300, 'CA', '2013-12-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9688, 'Bracebridge', 'Bracebridge', 'Brejsbridz,brysbrydj,bureisuburijji,Брејсбриџ,بريسبريدج,ブレイスブリッジ', 45.0334100, -79.3163300, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9689, 'Brampton', 'Brampton', 'Brampton,Bramptonas,Bramptono,Bramptun,XPN,baraimpatana,beulaemteon,braimpatana,brambtwn,bramptan,bramtana,bremptana,brmptwn  antaryw,bu lan pu dun,buranputon,piramptan,Брамптон,Брамптън,برامبتون,برامپٹن، انٹاریو,برمپتون، انتاریو,بریمپٹن,ब्राम्टन,ब्रैंपटन,ਬਰੈਂਪਟਨ,બ્રેમ્પ્ટન,பிராம்ப்டன்,బ్రాంప్టన్,ബ്രംപ്ടൺ,බ්‍රැම්ටන්,ブランプトン,布兰普顿,브램턴', 43.6834100, -79.7663300, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9690, 'Brandon', 'Brandon', 'Brandon,Branton,Brehndon,Brendon,YBR,bu lan deng,burandon,Μπράντον,Брандон,Брендон,Брэндон,برینڈن,ブランドン,布兰登', 49.8469200, -99.9530600, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9691, 'Brant', 'Brant', '', 43.1334000, -80.3496700, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9692, 'Brantford', 'Brantford', 'Brantford,Brantfordas,XFV,beulaenteupeodeu,brantfwrd,brntfwrd  antaryw,bu lan te fu de,burantofodo,Брантфорд,برانتفورد,برانٹفورڈ,برنتفورد، انتاریو,برینٹفورڈ,ブラントフォード,布兰特福德,브랜트퍼드', 43.1334000, -80.2663600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9693, 'Bridgewater', 'Bridgewater', 'bryj watr,بریج واتر', 44.3785600, -64.5188200, 'CA', '2015-06-26', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9694, 'Brockville', 'Brockville', 'Brokvil,Brokvil'',Brokvill,Brukvailas,Gorad Brokvil,XBR,brakwyl,brwk-wl,brwkfyl,bu luo ke wei er,burokkubiru,Броквил,Броквилл,Броквіль,Горад Броквіл,براکویل,بروكفيل,بروک ولے,بروک-ول,ブロックビル,布羅克維爾', 44.5913200, -75.6870500, 'CA', '2013-05-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9695, 'Bromont', 'Bromont', 'Bromon,Bromont,ZBM,brwmwn,brwmwn  kbk,Бромон,برومون,برومون، کبک,برومونٹ', 45.3167800, -72.6491200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9696, 'Brooks', 'Brooks', 'Broks,Bruks,beulugseu,brwks,brwks  albrٹa,bu lu ke si,Брукс,بروکس,بروکس، البرٹا,ბროკსი,布鲁克斯,브룩스', 50.5834100, -111.8850900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9697, 'Brossard', 'Brossard', 'Brosar,bao le sha,brwsar,burosado,Бросар,بروسار,بروسارڈ,ブロサード,寶樂沙', 45.4500800, -73.4658300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9698, 'Brownsburg-Chatham', 'Brownsburg-Chatham', '', 45.6834200, -74.4159000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9699, 'Burgeo', 'Burgeo', '', 47.6166800, -57.6151600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9700, 'Burlington', 'Burlington', 'Berlington,barinton,beollingteon,bo ling dun,brlngٹn  awnٹaryw,brlyngtwn  antaryw,byrlynjtwn,Берлингтон,Берлінгтон,برلنگٹن,برلنگٹن، اونٹاریو,برلینگتون، انتاریو,بيرلينجتون,バーリントン,伯灵顿,벌링턴', 43.3862100, -79.8371300, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9701, 'Burnaby', 'Burnaby', 'Barnabis,Bernabi,Bernabija,Bjornabi,Burnabi,Burnaby,Bērnabija,banabi,banabi shi,ben na bi,beoneobi,brnaby,brnabے,brnyby,bwrnby,Бернаби,Бернабі,Бърнаби,Бёрнаби,Бөрнаби,برنابی,برنابے,برنیبی,بورنبي,バーナビー,バーナビー市,本拿比,本那比,버너비', 49.2663600, -122.9526300, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9702, 'Burns Lake', 'Burns Lake', 'Burns Lake,YPZ', 54.2297200, -125.7608400, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9703, 'Cache Creek', 'Cache Creek', 'katsh kryk,كاتش كريك', 50.8101100, -121.3246000, 'CA', '2010-10-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9704, 'Calgary', 'Calgary', 'Calgaria,Calgary,Gorad Kalgary,Kalgari,Kalgario,Kalgaris,Kalnkari,Kalqari,Kelgery,YYC,ka er jia li,ka jia li,kaelgeoli,kailagari,kalgari,kalghary,kalgry,kalkari,karugari,kelgari,klgry,kyalgari,kylgry,qlgry,Κάλγκαρι,Горад Калгары,Калгари,Калгарі,Կալգարի,קלגרי,كالغاري,کالگری,کلگری,کیلگری,कॅल्गारी,कैलगरी,ਕੈਲਗਰੀ,கால்கரி,కాల్గరీ,ಕ್ಯಾಲ್ಗರಿ,แคลกะรี,ကယ်လ်ဂရီမြို့,კალგარი,カルガリー,卡加利,卡尔加里,캘거리', 51.0501100, -114.0852900, 'CA', '2015-04-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9705, 'Calmar', 'Calmar', '', 53.2668300, -113.8187400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9706, 'Cambridge', 'Cambridge', 'Kejmbridzh,Kembridz,Kembridzh,Kembrigo,Kembriĝo,jian qiao,kambrydj,keimbeuliji,kenburijji,kmbryj  antaryw,kymbrj,Кеймбридж,Кембридж,Кембриџ,كامبريدج,کمبریج، انتاریو,کیمبرج,کیمبرج، انٹاریو,ケンブリッジ,剑桥,케임브리지', 43.3601000, -80.3126900, 'CA', '2010-04-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9707, 'Camlachie', 'Camlachie', '', 43.0359600, -82.1616000, 'CA', '2011-11-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9708, 'Campbell River', 'Campbell River', 'Kampel River,Kehmpbell-River,Kembel River,Kempbell-River,YBL,kaembellibeo,kambl ryfr,kan bei er li fu,kmbl rywr  brytysh klmbya,kyanberuriba,Κάμπελ Ρίβερ,Кембел Ривер,Кемпбелл-Рівер,Кэмпбелл-Ривер,كامبل ريفر,کمبل ریور، بریتیش کلمبیا,کیمپبل ریور، برٹش کولمبیا,キャンベルリバー,坎贝尔里弗,캠벨리버', 50.0163400, -125.2445900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9709, 'Camrose', 'Camrose', 'Kamros'',Kamrouz,Keimrozas,ka mu luo si,kamrwz,kmrwz,kymrwz  albrٹa,Камрось,Камроуз,كامروز,کمروز,کیمروز، البرٹا,卡姆罗斯', 53.0168400, -112.8352500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9710, 'Candiac', 'Candiac', 'Kandjak,kandyak  kbk,kandyak  kybk,Кандјак,كاندياك، كيبك,کاندیاک، کبک,کینڈیک', 45.3833800, -73.5158700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9711, 'Canmore', 'Canmore', 'Kanmor,Kenmor,kan mo er,Канмор,Кенмор,坎莫尔', 51.0833500, -115.3520600, 'CA', '2015-07-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9712, 'Canora', 'Canora', 'Kanora,Канора', 51.6332800, -102.4342500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9713, 'Cap-Chat', 'Cap-Chat', 'Cap-Chat,Kap Sha,kab sha,kap-sha  kbk,Кап Ша,كاب شا,کاپ-شا، کبک,کیپ چیٹ', 49.1000900, -66.6821200, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9714, 'Carberry', 'Carberry', 'Karberi,Карбери', 49.8689300, -99.3602100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9715, 'Carbonear', 'Carbonear', '', 47.7331900, -53.2147800, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9716, 'Cardston', 'Cardston', 'Kardston,Кардстон', 49.1999800, -113.3019000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9717, 'Carignan', 'Carignan', 'Carignan,Karinan,kargnan,karynyan  kbk,karynywn,Карињан,كارينيون,کارگنان,کارینیان، کبک', 45.4500800, -73.2991600, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9718, 'Carleton Place', 'Carleton Place', 'Karlton Plejs,Karlton-Plejs,ka er dun pu lei si,karltwn blas,karltwn plys,Карлтон Плејс,Карлтон-Плейс,كارلتون بلاس,کارلتون پلیس,卡爾頓普雷斯', 45.1334100, -76.1493800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9719, 'Carlyle', 'Carlyle', '', 49.6333400, -102.2676500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9720, 'Carman', 'Carman', 'Karman,Карман', 49.4992000, -98.0015600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9721, 'Carstairs', 'Carstairs', '', 51.5668100, -114.1020000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9722, 'Casselman', 'Casselman', 'XZB', 45.3168000, -75.0826000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9723, 'Castlegar', 'Castlegar', 'Kaslgar,YCG,ka si er jia,kaslghar,kslgr  brytysh klmbya,Каслгар,كاسلغار,کسلگر، بریتیش کلمبیا,کیسلگر، برٹش کولمبیا,卡斯尔加', 49.2998400, -117.6689400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9724, 'Catalina', 'Catalina', '', 48.5165900, -53.0813500, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9725, 'Chambly', 'Chambly', 'Chambly,Shambli,chymbly,shambly  kbk,shwmbly  kybk,Шамбли,Шамблі,شامبلی، کبک,شومبلي، كيبك,چیمبلی', 45.4500800, -73.2824600, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9726, 'Chambord', 'Chambord', 'Chambord,XCI,chmbwrd  kbk,shwmbwr,شومبور,چمبورد، کبک', 48.4333900, -72.0658300, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9727, 'Channel-Port aux Basques', 'Channel-Port aux Basques', 'Channel-Port-aux-Basques,Port aux Basques', 47.5702100, -59.1367400, 'CA', '2009-07-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9728, 'Chapais', 'Chapais', 'Chapais', 49.7834400, -74.8491900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9729, 'Charlemagne', 'Charlemagne', '', 45.7167800, -73.4824700, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9730, 'Charlottetown', 'Charlottetown', 'Baile Shearlot,Baile Sheàrlot,Carlotauno,Carolinapolis,Charlottetown,Sarlotetaunas,Sarlottaoun,Sarlottaun,Sharlottaun,Sharluttaun,YYG,carlattavun,saralatata''una,sharottotaun,syalleostaun,tsharlwt tawn,xia luo te dun,Ĉarlotaŭno,Şarlottaun,Šarlotetaunas,Σάρλοτταουν,Шарлоттаун,Шарлъттаун,שרלוטטאון,تشارلوت تاون,شارلوت‌تاون,شارلٹٹاؤن,ਸ਼ਾਰਲਟਟਾਊਨ,சார்லட்டவுன்,შარლოტტაუნი,シャーロットタウン,夏洛特顿,샬럿타운', 46.2389900, -63.1341400, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9731, 'Chase', 'Chase', '', 50.8165000, -119.6857100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9732, 'Châteauguay', 'Chateauguay', 'Chateauguay,Châteauguay,Shatoge,shatwgh  kbk,shatwghyh  kybk,Шатоге,شاتوغيه، كيبك,شاتوگه، کبک,چیتیآگوے', 45.3833800, -73.7491900, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9733, 'Chatham', 'Chatham', 'Chatham,XCM', 42.4122400, -82.1849400, 'CA', '2017-07-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9734, 'Chertsey', 'Chertsey', 'Chertsey', 46.0710900, -73.8909500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9735, 'Chester', 'Chester', 'chstr. nwa askwshya,tshstr,تشستر,چستر٬ نوا اسکوشیا', 44.5422500, -64.2389100, 'CA', '2015-02-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9736, 'Chestermere', 'Chestermere', 'Chestermir,Честермир', 51.0334100, -113.8186700, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9737, 'Chetwynd', 'Chetwynd', 'YCQ', 55.6998800, -121.6362700, 'CA', '2012-05-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9738, 'Chibougamau', 'Chibougamau', 'Chibougamau,Shibugamo,YMT,chbwgamaw,shybwghamw,shybwkamw,Шибугамо,شيبوغامو,شیبوکامو,چبوگاماؤ', 49.9168400, -74.3658600, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9739, 'Chilliwack', 'Chilliwack', 'YCW', 49.1663800, -121.9525700, 'CA', '2013-07-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9740, 'Chute-aux-Outardes', 'Chute-aux-Outardes', '', 49.1167900, -68.3989600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9741, 'Clarence-Rockland', 'Clarence-Rockland', '', 45.5501000, -75.2910100, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9742, 'Clarenville-Shoal Harbour', 'Clarenville-Shoal Harbour', '', 48.1805000, -53.9698200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9743, 'Claresholm', 'Claresholm', '', 50.0333200, -113.5852400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9744, 'Clyde River', 'Clyde River', 'YCY', 70.4691600, -68.5914300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9745, 'Coaldale', 'Coaldale', '', 49.7167000, -112.6185400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9746, 'Coalhurst', 'Coalhurst', '', 49.7464000, -112.9324600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9747, 'Coaticook', 'Coaticook', 'Coaticook,Koatikuk,kwtykwk  kbk,kwtykwk  kybk,Коатикук,كوتيكوك، كيبك,کوتیکوک، کبک,کوٹیکوک', 45.1333900, -71.7990700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9748, 'Cobourg', 'Cobourg', 'Cobourg,Koburg,XGJ,ke bao,kwbwrgh,Кобург,كوبورغ,科堡', 43.9597700, -78.1651500, 'CA', '2013-11-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9749, 'Cochrane', 'Cochrane', 'Kokran,Кокран', 51.1834100, -114.4687100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9750, 'Cold Lake', 'Cold Lake', 'Kold Leikas,Kold Lejk,Kold Leyk,Kold-Lejk,YOD,kld lyk,kwld layk,kwlڈ lyk  albrٹa,leng hu shi,Колд Лейк,Колд Лејк,Колд-Лейк,كولد لايك,کلد لیک,کولڈ لیک، البرٹا,冷湖市', 54.4652500, -110.1815400, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9751, 'Collingwood', 'Collingwood', 'Kolingvud,kalyngwwd  antaryw,kwlynjwwd,Колингвуд,Колінгвуд,كولينجوود,کالینگوود، انتاریو', 44.4834000, -80.2163800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9752, 'Colwood', 'Colwood', 'Kolvud,kal wwd  brytysh klmbya,ke er wu de,kol-udeu,kwlwwd,Колвуд,كولوود,کال وود، بریتیش کلمبیا,کول وڈ، برٹش کولمبیا,科尔伍德,콜우드', 48.4329300, -123.4859100, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9753, 'Conception Bay South', 'Conception Bay South', 'کونسیپشن بے ساؤتھ', 47.4998900, -52.9980600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9754, 'Concord', 'Concord', '', 43.8001100, -79.4829100, 'CA', '2012-03-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9755, 'Contrecoeur', 'Contrecoeur', 'Contrecoeur', 45.8500800, -73.2324500, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9756, 'Cookshire-Eaton', 'Cookshire-Eaton', '', 45.4167500, -71.6324000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9757, 'Coquitlam', 'Coquitlam', 'Coquitlam,kokittoramu,kokittoramu shi,kokuittoramu,コキットラム,コキットラム市,コクイットラム', 49.2829700, -122.7526200, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9758, 'Corner Brook', 'Corner Brook', 'Korner-Bruk,YNF,karnr brwk,ke na bu lu ke,konaburukku,koneobeulug,qwrnr brwq,Корнер-Брук,קורנר ברוק,کارنر بروک,コーナーブルック,科纳布鲁克,코너브룩', 48.9500100, -57.9520200, 'CA', '2013-08-10', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9759, 'Cornwall', 'Cornwall', 'Kornuoll,Корнуолл', 46.2265200, -63.2180900, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9760, 'Cornwall', 'Cornwall', 'Kornvol,YCC,kang wo er,karnwal,kon''u~oru,kon-wol,kwrnwal,kwrnwal  antaryw,Корнвол,كورنوال,کارنوال,کورنوال، انتاریو,کورنوال، انٹاریو,コーンウォール,康沃尔,콘월', 45.0180900, -74.7281500, 'CA', '2009-07-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9761, 'Côte-Saint-Luc', 'Cote-Saint-Luc', '', 45.4653600, -73.6658500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9762, 'Courtenay', 'Courtenay', 'Courtenay,Kortni,Kurteneh,YCA,kao te ni,kwrtny,kwrtynay,Кортни,Кортні,Куртенэ,كورتيناي,کورتنی,کورٹینی، برٹش کولمبیا,考特尼', 49.6865700, -124.9936000, 'CA', '2013-10-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9763, 'Cowansville', 'Cowansville', 'Cowansville,Kauansvil,kawnswyl  kbk,kwwansfyl  kybk,Кауансвил,كووانسفيل، كيبك,کاونسویل، کبک,کونزولے', 45.2000800, -72.7491300, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9764, 'Crabtree', 'Crabtree', '', 45.9667700, -73.4658600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9765, 'Cranbrook', 'Cranbrook', 'Kranbruk,YXC,ke lan bu lu ke,kranbrwk,krnbrwk,Кранбрук,كرانبروك,کرنبروک,کرین بروک، برٹش کولمبیا,克兰布鲁克', 49.4999100, -115.7687900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9766, 'Creston', 'Creston', 'CFQ', 49.0998700, -116.5021100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9767, 'Crossfield', 'Crossfield', '', 51.4334100, -114.0352800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9768, 'Cumberland', 'Cumberland', '', 49.6163400, -125.0361300, 'CA', '2017-03-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9769, 'Dalmeny', 'Dalmeny', '', 52.3333900, -106.7679200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9770, 'Danville', 'Danville', '', 45.7833700, -72.0158000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9771, 'Dartmouth', 'Dartmouth', 'dateumeoseu,ഡാർട്മൗത്,다트머스', 44.6713400, -63.5771900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9772, 'Dauphin', 'Dauphin', 'Dofen,Dofin,YDN,duo fen,Дофен,Дофін,ڈافن، مینی ٹوبا,ڈوفن,多芬', 51.1494100, -100.0502300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9773, 'Daveluyville', 'Daveluyville', '', 46.2000600, -72.1323900, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9774, 'Dawson Creek', 'Dawson Creek', 'Doson Krik,Doson-Krik,YDQ,dao sen ke li ke,dawswn kryk,doseunkeulig,dwsn kryk,dxw san kh rik,Досон Крик,Досон-Крик,داوسون کریک,دوسن كريك,ڈاسن کریک,ڈاسنکریک,ดอว์สันครีก,道森克里克,도슨크릭', 55.7598400, -120.2403000, 'CA', '2015-01-09', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9775, 'Deep River', 'Deep River', 'Dip River,dipuriba,Дип Ривер,ディープリバー', 46.1001200, -77.4994900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9776, 'Deer Lake', 'Deer Lake', 'Deer Lake,YDF', 49.1667100, -57.4316300, 'CA', '2016-04-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9777, 'Delaware', 'Delaware', '', 42.9167900, -81.4164600, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9778, 'Deloraine', 'Deloraine', '', 49.1908200, -100.4947700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9779, 'Delson', 'Delson', 'Delson', 45.3667800, -73.5491700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9780, 'Delta', 'Delta', 'Del''ta,Delta,delta,deruta,dlth,dylta,san jiao zhou,Делта,Дельта,דלתה,ديلتا,デルタ,三角洲,델타', 49.1439900, -122.9068000, 'CA', '2010-02-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9781, 'Deseronto', 'Deseronto', '', 44.2001200, -77.0494400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9782, 'Deux-Montagnes', 'Deux-Montagnes', '', 45.5345500, -73.9016800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9783, 'Devon', 'Devon', 'Devon,Девон', 53.3668300, -113.7353300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9784, 'Didsbury', 'Didsbury', 'Didsberi,Дидсбери', 51.6668100, -114.1352900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9785, 'Dieppe', 'Dieppe', 'D''ep,di ye pu,dieppu,dyyp  nyw brnzwyk,Дьеп,دیئپ، نیو برنزویک,ڈیپی,ディエップ,迪耶普', 46.0784400, -64.6873500, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9786, 'Digby', 'Digby', 'YDG,dygby,دیگبی', 44.6218800, -65.7586000, 'CA', '2014-11-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9787, 'Dolbeau-Mistassini', 'Dolbeau-Mistassini', 'Dolbeau-Mistassini,Dolbo Mistasini,YDO,dwlbw mystasyny  kybk,dwlbw-mystasyny  kbk,Долбо Мистасини,دولبو ميستاسيني، كيبك,دولبو-میستاسینی، کبک,ڈالبیاؤ مسٹاسنی', 48.8786000, -72.2314200, 'CA', '2016-02-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9788, 'Dollard-Des Ormeaux', 'Dollard-Des Ormeaux', 'Dolar dez Ormo,Dollard-Des-Ormeaux,Dollard-des-Ormeaux,dwlar dyzwrmw  kybk,dwlar-dh-awrmw,Долар дез Ормо,دولار ديزورمو، كيبك,دولار-ده-اورمو,ڈولارڈ ڈس اورمیوکس', 45.4945200, -73.8241900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9789, 'Dorchester', 'Dorchester', '', 42.9833900, -81.0664300, 'CA', '2013-07-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9790, 'Dorval', 'Dorval', 'Dorval,Dorval'',dwrfal  kybk,dwrwal,Дорвал,Дорваль,دورفال، كيبك,دوروال,ڈورول', 45.4473000, -73.7533500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9791, 'Drayton Valley', 'Drayton Valley', 'Drejton Vali,Drejton-Valli,YDC,Дрейтон-Валли,Дрејтон Вали', 53.2168200, -114.9854400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9792, 'Drummondville', 'Drummondville', 'Drammondvill,Drammonvil'',Dramondvil,Drummondville,XDM,de la meng shi,doramonbiru,drwmwndwyl,drwmwnfyl,Драммонвіль,Драммондвилл,Драмондвил,دروموندویل,درومونفيل,ڈرمنڈولے,ڈرمونڈویل,ドラモンビル,德拉蒙市', 45.8833600, -72.4824100, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9793, 'Dryden', 'Dryden', 'YHD', 49.7833400, -92.7503200, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9794, 'Duncan', 'Duncan', 'DUQ,Dankan,Duncan,Dunkan,deng ken,Данкан,Дункан,ڈنکن، برٹش کولمبیا,邓肯', 48.7829300, -123.7026600, 'CA', '2013-07-21', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9795, 'Dunham', 'Dunham', 'Dunham', 45.1333800, -72.7991300, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9796, 'Ear Falls', 'Ear Falls', '', 50.6395500, -93.2352600, 'CA', '2013-07-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9797, 'East Angus', 'East Angus', 'Ist Angus,ayst anghs,ayst angws  kbk,Ист Ангус,أيست أنغس,ایست انگوس، کبک,ایسٹ انگس', 45.4833800, -71.6657700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9798, 'Edmonton', 'Edmonton', 'Edmonton,Edmontona,Edmontonas,Edmontono,Edmundopolis,Edmuntun,Ehdmonton,Entmonton,Gorad Ehdmantan,YEA,admwntwn,ai de meng dun,aidamatana,edamantana,edeumeonteon,edomonton,etmantan,xe dman tan,Édmonton,Έντμοντον,Горад Эдмантан,Едмонтон,Едмънтън,Эдмонтон,Էդմոնտոն,אדמונטון,إدمونتون,ادمونتون,ایڈمنٹن,एडमंटन,ਐਡਮੰਟਨ,எட்மன்டன்,เอดมันตัน,ཨེ་ཏི་མོན་ཐོན།,ედმონტონი,ᐊᒥᐢᑲᐧᒋᐊᐧᐢᑲᐦᐃᑲᐣ,エドモントン,埃德蒙顿,에드먼턴', 53.5501400, -113.4687100, 'CA', '2010-07-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9799, 'Edson', 'Edson', 'Edson,YET,Едсон', 53.5834500, -116.4355900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9800, 'Elkford', 'Elkford', '', 50.0500700, -114.8854000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9801, 'Elk Point', 'Elk Point', '', 53.9001700, -110.9017000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9802, 'Elliot Lake', 'Elliot Lake', 'Eliot Lejk,YEL,alywt layk,alywt lyk,eriottoreiku,Елиот Лејк,إليوت لايك,الیوت لیک,الیٹ لیک,エリオットレイク', 46.3833600, -82.6331500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9803, 'Enderby', 'Enderby', 'Enderbi,Ендерби,اینڈربائ,اینڈربی، برٹش کولمبیا', 50.5498000, -119.1523400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9804, 'Englehart', 'Englehart', '', 47.8168600, -79.8664000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9805, 'Espanola', 'Espanola', 'Espanola,Española,ai si pa nuo la,esupanora,Еспанола,エスパノーラ,埃斯帕諾拉', 46.2583700, -81.7664900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9806, 'Esterhazy', 'Esterhazy', '', 50.6500100, -102.0842600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9807, 'Estevan', 'Estevan', 'Ehstevan,Estevan,YEN,astyfn,Естеван,Эстеван,إستيفن', 49.1333700, -102.9842200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9808, 'Etobicoke', 'Etobicoke', 'Ehtobiko,Etobiko,etobiko,etopikok,itobiko,yi tao bi gu,Етобіко,Этобико,எடோபிகோக்,エトビコ,怡陶碧谷,이토비코', 43.6542100, -79.5671100, 'CA', '2012-02-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9809, 'Fairview', 'Fairview', 'Fairview  Alberta,Fervju,Фервју,فیئرویو، البرٹا', 56.0667500, -118.3860600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9810, 'Falher', 'Falher', 'Falher', 55.7333900, -117.2026200, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9811, 'Farnham', 'Farnham', 'Farnham', 45.2833800, -72.9824400, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9812, 'Ferme-Neuve', 'Ferme-Neuve', '', 46.7001100, -75.4492900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9813, 'Fermont', 'Fermont', '', 52.7834500, -67.0820400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9814, 'Fernie', 'Fernie', 'Ferni,Ферни,فرنی، برٹش کولمبیا', 49.4999600, -115.0687100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9815, 'Flin Flon', 'Flin Flon', 'Flin Flon,Flin-Flon,YFO,fln flwn,flyn flwn,Флин Флон,Флин-Флон,Флін-Флон,فلن فلان، مینی ٹوبا,فلن فلون,فلین فلون', 54.7670300, -101.8743300, 'CA', '2016-04-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9816, 'Foam Lake', 'Foam Lake', '', 51.6500100, -103.5343100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9817, 'Fort-Coulonge', 'Fort-Coulonge', 'fwr kwlwnj,fwrt-kwlwny  kbk,فور كولونج,فورت-کولونی، کبک', 45.8501100, -76.7327200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9818, 'Fort Erie', 'Fort Erie', 'Fort Erie,Fort Iri,Fort Érié,Fort-Eri,fotoeri,fwrt ayry,yi li bao,Форт Ири,Форт-Ері,فورت إيري,フォートエリー,伊利堡', 42.9001200, -78.9328600, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9819, 'Fort Frances', 'Fort Frances', 'Fort Franses,YAG,fotofuranshisu,fu lang xi si bao,fwrt fransys,Форт Франсес,فورت فرانسيس,フォートフランシス,弗朗西斯堡', 48.5998800, -93.4003000, 'CA', '2011-12-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9820, 'Fort Macleod', 'Fort Macleod', 'Fort Maklaud,Fort Makleodas,Форт Маклауд', 49.7167100, -113.4185700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9821, 'Fort McMurray', 'Fort McMurray', 'Fort Makmari,Fort-MakMerrej,Fort-MakMerrey,YMM,fotomakumare,fwrt makmwray,mai ke mo li bao,poteumaegmeoli,Форт Макмари,Форт-МакМеррей,فورت ماكموراي,فورت مک‌موری,フォートマクマレー,麦克默里堡,포트맥머리', 56.7267600, -111.3810300, 'CA', '2011-10-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9822, 'Fort McPherson', 'Fort McPherson', 'Fort McPherson,Fort-Makferson,Telit-Zhe,ZFM,Телит-Же,Форт-Макферсон', 67.4386300, -134.8854300, 'CA', '2013-11-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9823, 'Fort Nelson', 'Fort Nelson', 'YYE,fwrt nlswn,فورت نلسون', 58.8053300, -122.7002000, 'CA', '2016-10-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9824, 'Fort Saskatchewan', 'Fort Saskatchewan', 'Fort Saskacevanas,Fort Saskachevan,Fort Saskačevanas,Fort-Saskachevan,frt saskachwan,fwrt saskatshwan,sa si ka che wen bao,Форт Саскачеван,Форт-Саскачеван,فرت ساسکاچوان,فورت ساسكاتشوان,فورٹ ساسکیچوان,萨斯喀彻温堡', 53.7168400, -113.2187000, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9825, 'Fort Smith', 'Fort Smith', 'Fort Smith,Thebacha,YSM', 60.0043900, -111.8887100, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9826, 'Fort St. John', 'Fort St. John', 'Fort Sent DZon,Fort-Sent-Dzhon,YXJ,fwrt sant jwn,fwrt snt jan,sheng yue han bao,Форт Сент Џон,Форт-Сент-Джон,فورت سانت جون,فورت سنت جان,فورٹ سینٹ جان، برٹش کولمبیا,聖約翰堡', 56.2498800, -120.8529200, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9827, 'Fox Creek', 'Fox Creek', 'Foks Krik,Фокс Крик', 54.4000700, -116.8023800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9828, 'Franklin', 'Franklin', 'Franklin', 45.0333800, -73.9159100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9829, 'Fredericton', 'Fredericton', 'Fredericopolis,Fredericton,Frederikton,Frederiktonas,Frederiktono,Frederiktun,Gorad Frehdehryktan,Phrentrikton,YFC,frdryktwn,frydryktwn,fu lei de li ke dun,furederikuton,hpireteriktan,peuledeoligteon,phredariktana,prdryqtwn,Φρέντρικτον,Горад Фрэдэрыктан,Фредериктон,Фредериктън,Фредеріктон,פרדריקטון,فردریکتون,فريدريكتون,فریڈرکٹن,فریڈریکٹن,फ्रेडरिक्टन,ஃபிரெடெரிக்டன்,ფრედერიკტონი,フレデリクトン,弗雷德里克頓,프레더릭턴', 45.9454100, -66.6655800, 'CA', '2010-07-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9830, 'Fruitvale', 'Fruitvale', '', 49.1165400, -117.5522200, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9831, 'Gambo', 'Gambo', '', 48.7832000, -54.2148200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9832, 'Gananoque', 'Gananoque', 'XGW', 44.3334200, -76.1660700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9833, 'Gaspé', 'Gaspe', 'Gaspe,Gaspé,Gaspė,YGP,gasph  kbk,gasupe,ghasbyh,gysp,Гаспе,גאספה,غاسبيه,گاسپه، کبک,گیسپ,ᗴᔅᗫ,ガスペ', 48.8334100, -64.4819400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9834, 'Gatineau', 'Gatineau', 'Gatineau,Gatino,Sablono:TabelKapoLauCarta,gatino,gatynw,ghatynw,gytynw,jia di nuo,jia di nuo shi,kettinov,Ŝablono:TabelKapoLaŭĈarta,Гатино,Гатіно,غاتينو,گاتینو,گیتینؤ,گیٹینیو,கெட்டினோவ்,გატინო,ガティノー,加蒂諾,加蒂诺市,가티노', 45.4772300, -75.7016400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9835, 'Gibbons', 'Gibbons', '', 53.8334500, -113.3353100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9836, 'Gibsons', 'Gibsons', '', 49.3953900, -123.5055500, 'CA', '2013-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9837, 'Gimli', 'Gimli', 'Gimli,YGM,gimali,Гимли,गिमली', 50.6336200, -96.9906600, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9838, 'Gjoa Haven', 'Gjoa Haven', 'Uqsuqtuuq,YHK', 68.6260200, -95.8783600, 'CA', '2012-07-25', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9839, 'Glace Bay', 'Glace Bay', 'Glasbaidh', 46.1969500, -59.9569800, 'CA', '2008-08-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9840, 'Goderich', 'Goderich', 'Goderich,Godrich,ge de li qi,godoritchi,Годрич,گوڈرچ، اونٹاریو,ゴドリッチ,戈德里奇', 43.7417100, -81.7133900, 'CA', '2016-07-10', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9841, 'Golden', 'Golden', 'گولڈن، برٹش کولمبیا', 51.2999500, -116.9689000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9842, 'Granby', 'Granby', 'Gorad Granbi,Granbi,Granby,ge lan bi,ghranby,granby  kbk,grymby,Горад Гранбі,Гранби,Гранбі,غرانبي,گرانبی، کبک,گریمبی,格兰比', 45.4000800, -72.7324300, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9843, 'Grand Bank', 'Grand Bank', '', 47.0999500, -55.7650400, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9844, 'Grande Cache', 'Grande Cache', 'Grand Kesh,YGC,Гранд Кеш', 53.8833500, -119.1358500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9845, 'Grande Prairie', 'Grande Prairie', 'Gorad Grand-Prehry,Gran Preri,Grand Preri,Grand-Preri,Grande Prairie,Qrand-Preri,YQU,da cao yuan cheng,geulaendipeuleli,ghrand brary,grnd pryry,Горад Гранд-Прэры,Гранд Прери,Гранд-Прери,Гранд-Прері,غراند براري,گرانڈ پرائری,گرند پریری,گرینڈ پریری,გრანდე-პრერია,大草原城,그랜디프레리', 55.1666700, -118.8027100, 'CA', '2016-04-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9846, 'Grand Falls-Windsor', 'Grand Falls-Windsor', '', 48.9332400, -55.6649200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9847, 'Grand Forks', 'Grand Forks', 'Grand Forks,Grand-Forks,ZGF,Гранд Форкс,Гранд-Форкс,گرینڈ فورکس، برٹش کولمبیا', 49.0330900, -118.4356000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9848, 'Greater Sudbury', 'Greater Sudbury', 'Bol''shoj Sadberi,Gran Sudbury,Grand Sudbury,Granda Sudbury,Greater Sudbury,Sadberi,Sadberis,Sudbury,Veliki Sadberi,YSB,catpari perumpakam,da sa de bo li,ghrytr swdbwry,gryytr sdbry,sadbry bzrg,sadobari,seodeubeli,Большой Садбери,Велики Садбери,Садбері,גרייטר סדברי,سادبری بزرگ,غريتر سودبوري,گریٹر سڈبری,சட்பறி பெரும்பாகம்,サドバリー,大薩德伯里,서드베리', 46.4900000, -80.9900100, 'CA', '2014-05-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9849, 'Gravelbourg', 'Gravelbourg', '', 49.8833600, -106.5512200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9850, 'Gravenhurst', 'Gravenhurst', 'Gravenhurst i Ontario,Grejvenkherst,ge lei wen he si te,gureibunhasuto,jrafnhwrst,Грејвенхерст,جرافنهورست,グレイブンハースト,格雷文赫斯特', 44.9168100, -79.3663300, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9851, 'Greater Napanee', 'Greater Napanee', 'Napanee', 44.2501200, -76.9494400, 'CA', '2010-04-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9852, 'Greenstone', 'Greenstone', '', 49.7334300, -87.1666800, 'CA', '2012-07-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9853, 'Greenwood', 'Greenwood', 'YZX', 44.9741300, -64.9316900, 'CA', '2015-06-26', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9854, 'Grimshaw', 'Grimshaw', 'Grimsho,Гримшо', 56.1833900, -117.6027000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9855, 'Guelph', 'Guelph', 'Guehlf,Guelfas,Guelph,Gvelf,XIA,gerufu,ghwylf,gui hu,gwelpeu,gwlf,gwylf,gywlf,Гвелф,Гуэлф,غويلف,گولف,گویلف,گیولف,ゲルフ,貴湖,궬프', 43.5459400, -80.2559900, 'CA', '2013-11-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9856, 'Haines Junction', 'Haines Junction', 'YHT', 60.7521600, -137.5108200, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9857, 'Hamilton', 'Hamilton', 'Gamil''ton,Gamilton,Gorad Gamil''tan,Hamilton,Hamilton i Ontario,Hamiltona,Hamiltonas,Hamiltono,Khamilton,Khamiltun,amiltan,ha mi er dun,haemilteon,hamiruton,hamyltwn,hemiltana,hmyltwn,hmyltwn  antaryw,Гамильтон,Гамільтон,Горад Гамільтан,Хамилтон,Хамилтън,Համիլտոն,המילטון,هاميلتون,همیلتون، انتاریو,ہاملٹن,ہیملٹن، انٹاریو,हॅमिल्टन,ஆமில்டன்,හැමිල්ටන්,ჰამილტონი,ハミルトン,哈密尔顿,해밀턴', 43.2501100, -79.8496300, 'CA', '2013-02-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9858, 'Hampstead', 'Hampstead', '', 45.4806400, -73.6630700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9859, 'Hampton', 'Hampton', '', 45.5287600, -65.8535400, 'CA', '2014-04-14', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9860, 'Hanceville', 'Hanceville', '', 51.9192200, -123.0445800, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9861, 'Hanna', 'Hanna', 'Khana,Хана,Һанна', 51.6334300, -111.9018100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9862, 'Hanover', 'Hanover', 'Khanover,Хановер', 44.1500900, -81.0330300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9863, 'Hantsport', 'Hantsport', '', 45.0668500, -64.1654400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9864, 'Happy Valley-Goose Bay', 'Happy Valley-Goose Bay', 'Happy Valley-Goose Bay,YYR,הפי וואלי-גוס ביי,ہیپی ویلی-گوز بے', 53.3038000, -60.3257600, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9865, 'Harbour Breton', 'Harbour Breton', '', 47.4832500, -55.7983300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9866, 'Havre-Saint-Pierre', 'Havre-Saint-Pierre', 'Havre-Saint-Pierre,Havre-St-Pierre,YGV', 50.2434200, -63.6026400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9867, 'Hawkesbury', 'Hawkesbury', 'Hawkesbury,Khoksberi,hawksbry,hawkysbyry,Хоксбери,هاوكيسبيري,هاوکسبری', 45.6000900, -74.6159500, 'CA', '2016-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9868, 'Hay River', 'Hay River', 'YHY', 60.8155500, -115.7999300, 'CA', '2011-12-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9869, 'Headingley', 'Headingley', '', 49.8753000, -97.4089600, 'CA', '2013-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9870, 'Hearst', 'Hearst', 'Kherst,YHF,Херст', 49.6835100, -83.6665400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9871, 'High Level', 'High Level', 'High Level,Khaj Level,YOJ,Хај Левел', 58.5168800, -117.1360500, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9872, 'High Prairie', 'High Prairie', 'Khaj Preri,ZHP,Хај Прери', 55.4334000, -116.4858000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9873, 'High River', 'High River', 'Khaj River,Хај Ривер', 50.5834100, -113.8686700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9874, 'Hinton', 'Hinton', 'Hinton,Khinton,YJP,Хинтон,ہنٹن، البرٹا', 53.4000900, -117.5856700, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9875, 'Hope', 'Hope', 'Goup,Hope,YHE,he pu,hwb,Гоуп,هوب,合普', 49.3829900, -121.4414400, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9876, 'Hornepayne', 'Hornepayne', 'Hornepayne,YHN', 49.2145100, -84.7761700, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9877, 'Houston', 'Houston', 'Houston,ZHO', 54.3997600, -126.6700800, 'CA', '2013-07-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9878, 'Hudson', 'Hudson', '', 45.4500800, -74.1492200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9879, 'Hudson Bay', 'Hudson Bay', 'Hudson Bay,YHB', 52.8500300, -102.3842500, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9880, 'Humboldt', 'Humboldt', 'Khambolt,Хамболт', 52.2000500, -105.1255000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9881, 'Huntingdon', 'Huntingdon', '', 45.0833900, -74.1659300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9882, 'Huntsville', 'Huntsville', 'Khantsvil,Khantsvill,hantsfyl,hantsubiru,heng ci wei er,Хантсвил,Хантсвилл,هانتسفيل,ハンツビル,亨茨維爾', 45.3334100, -79.2163200, 'CA', '2009-05-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9883, 'Huron East', 'Huron East', 'Khjuron Ist,hwrn ayst,Хјурон Ист,هورن أيست', 43.6167900, -81.2997500, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9884, 'Indian Head', 'Indian Head', '', 50.5333600, -103.6677500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9885, 'Ingersoll', 'Ingersoll', 'Ingersol,Ingersoll,XIB,anjrswl,Інгерсолл,Ингерсол,إنجرسول', 43.0333900, -80.8830200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9886, 'Innisfil', 'Innisfil', '', 44.3001100, -79.6496400, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9887, 'Inuvik', 'Inuvik', 'Inuvik,YEV,anwyk,inubig,inuvu~ikku,yin niu wei ke,İnuvik,Инувик,انوئک,イヌヴィック,因纽维克,이누빅', 68.3498600, -133.7218100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9888, 'Invermere', 'Invermere', '', 50.5166600, -116.0353800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9889, 'Iqaluit', 'Iqaluit', 'Crystal Two,Frobisher Bay,Gorad Ikaluit,Ikalouit,Ikaluit,Ikaluita,Ikaluitas,Ikaluito,Iqaluit,YFB,aykalwyt,ikallu-iteu,ikaruito,ikkaluyit,ikvalyu''ita,yi kui te,Ικαλούιτ,Ікалуїт,Горад Ікалуіт,Икалуит,איקאלואיט,إيكالويت,اکالوئٹ,ایکالویت,इक्वाल्युईत,இக்காலுயிட்,იკალუიტი,ᐃᖃᓗᐃᑦ,イカルイト,伊魁特,이칼루이트', 63.7469700, -68.5172700, 'CA', '2016-04-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9890, 'Iroquois Falls', 'Iroquois Falls', '', 48.7668800, -80.6830700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9891, 'Irricana', 'Irricana', '', 51.3237200, -113.6047500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9892, 'Jasper Park Lodge', 'Jasper Park Lodge', '', 52.8863300, -118.0562500, 'CA', '2015-01-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9893, 'Joliette', 'Joliette', 'Joliette,XJL,Zhol''et,Zholijet,jwlyyt  kybk,zhwlyt,Жолијет,Жольєт,جولييت، كيبك,جولیٹ,ژولیت', 46.0164000, -73.4236000, 'CA', '2016-06-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9894, 'Kamloops', 'Kamloops', 'Kamloops,Kamlups,YKA,kaimalupasa,kamlwbs,kamlwps,kamurupusu,kan lu pu si,Камлупс,קאמלופס,كاملوبس,کاملوپس,ਕੈਮਲੂਪਸ,カムループス,坎卢普斯', 50.6664800, -120.3192000, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9895, 'Kamsack', 'Kamsack', '', 51.5666800, -101.9009300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9896, 'Kapuskasing', 'Kapuskasing', 'Kapuskasing,Kapuskejsing,YYU,kabwskasyngh,Капускейсінг,Капускејсинг,Капъскейсинг,كابوسكاسينغ', 49.4169400, -82.4330800, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9897, 'Kelowna', 'Kelowna', 'Kelouna,Kelowna,YLW,ji long na,kellona,kerouna,klwna,kylwna,kylwwna,qlwnh,Келоуна,קלונה,كيلونا,کلونا,کیلوونا,ケロウナ,基隆拿,켈로나', 49.8830700, -119.4856800, 'CA', '2011-02-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9898, 'Kensington', 'Kensington', '', 46.4334300, -63.6487100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9899, 'Kentville', 'Kentville', '', 45.0771000, -64.4960500, 'CA', '2014-08-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9900, 'Kerrobert', 'Kerrobert', '', 51.9168200, -109.1347900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9901, 'Keswick', 'Keswick', '', 44.2501100, -79.4663200, 'CA', '2010-08-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9902, 'Killam', 'Killam', '', 52.7834400, -111.8517500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9903, 'Killarney', 'Killarney', '', 49.1833200, -99.6636400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9904, 'Kimberley', 'Kimberley', 'Gorad Kimberli,Kimberley,Kimberli,YQE,kymbyrly,Горад Кімберлі,Кимберли,كيمبيرلي,کمبرلے، برٹش کولمبیا', 49.6707100, -115.9776000, 'CA', '2014-02-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9905, 'Kincardine', 'Kincardine', 'Kincardine,Kinkardin,YKD,jin ka ding,kynkardyn,Кинкардин,كينكاردين,金卡丁', 44.1833900, -81.6330700, 'CA', '2015-11-09', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9906, 'Kindersley', 'Kindersley', 'Kindersley,YKY', 51.4668100, -109.1681800, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9907, 'Kingsey Falls', 'Kingsey Falls', '', 45.8500700, -72.0658000, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9908, 'Kingston', 'Kingston', 'Cataraqui,Kingstan,Kingston,Kingstonas,Kingstun,YGK,jin si dun,jing shi dun,kingseuteon,kingusuton,kynghstwn,kyngstwn  antaryw,Кингстон,Кингстън,Кінгстан,Кінгстон,كينغستون,کنگسٹن,کنگسٹن، اونٹاریو,کینگستون، انتاریو,キングストン,京士頓,金斯顿,킹스턴', 44.2297600, -76.4809800, 'CA', '2014-05-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9909, 'Kirkland', 'Kirkland', 'Kirkland,krklnd  kbk,kyrkland  kybk,Киркланд,كيركلاند، كيبك,کرکلند، کبک,کرکلینڈ', 45.4500800, -73.8658600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9910, 'Kirkland Lake', 'Kirkland Lake', 'Kirkland Lejk,YKX,keokeullaendeuleikeu,kyrkland lyk,Киркланд Лејк,كيركلاند ليك,커클랜드레이크', 48.1446100, -80.0376700, 'CA', '2012-01-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9911, 'Kitchener', 'Kitchener', 'Gorad Kitchehner,Kiceneris,Kicenero,Kichener,Kitchener,Kiĉenero,Kičeneris,ji qin na,kchnr,khitche nex r,kichineo,kitchina,kychnr,kytshnr,qyznr,Горад Кітчэнер,Китченер,Киченер,Кіченер,קיצנר,كيتشنر,کچنر,کیچنر,คิตเชเนอร์,კიტჩენერი,キッチナー,基秦拿,키치너', 43.4253700, -80.5112000, 'CA', '2014-11-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9912, 'Kitimat', 'Kitimat', 'kytymat,كيتيمات', 54.0524400, -128.6534200, 'CA', '2010-05-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9913, 'Kugluktuk', 'Kugluktuk', 'Coppermine,Kugluktuk,YCO,kg lk tk  nnawt,ku ge lu ke tu ke,Куглуктук,کگ لک تک، نناوت,库格鲁克图克', 67.8274300, -115.0964900, 'CA', '2013-08-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9914, 'Labelle', 'Labelle', 'Labelle', 46.2833900, -74.7325500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9915, 'Labrador City', 'Labrador City', 'Urbs Estotilandiensis,la bu la duo shi,lbrdwr syty,לברדור סיטי,拉布拉多市', 52.9462600, -66.9113700, 'CA', '2008-09-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9916, 'La Broquerie', 'La Broquerie', '', 49.5168800, -96.5002900, 'CA', '2013-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9917, 'Lac-Brome', 'Lac-Brome', 'Lac Brome', 45.2167800, -72.5158100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9918, 'Lac du Bonnet', 'Lac du Bonnet', '', 50.2536000, -96.0611600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9919, 'Lachute', 'Lachute', 'Lashit,lashwt,lshwt,Лашит,لاشوت,لاچوٹ,لشوت', 45.6500800, -74.3325300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9920, 'Lac La Biche', 'Lac La Biche', 'Lac La Biche,YLB,لاک لا بیچی، البرٹا', 54.7669000, -111.9686100, 'CA', '2013-04-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9921, 'Lac-Mégantic', 'Lac-Megantic', 'Lac-Megantic,Lac-Mégantic,Lak Megantik,lak mghantyk,lak-mgantyk  kbk,mei gan ti ke hu,Лак Мегантик,لاك مغانتيك,لاک-مگانتیک، کبک,لیک میگانٹک,梅干提克湖', 45.5833800, -70.8823400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9922, 'Lacolle', 'Lacolle', '', 45.0833800, -73.3658500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9923, 'Lacombe', 'Lacombe', 'Lakom,la ke mu,lakwmb,lkwmb,Лаком,لاكومب,لاکومب، البرٹا,لکومب,拉科姆', 52.4668100, -113.7353000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9924, 'La Conception', 'La Conception', 'La Conception', 46.1500900, -74.6992500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9925, 'Ladysmith', 'Ladysmith', 'Ladysmith,Lejdismit,XEH,laydy smyth,lyydysmyt,Лейдисмит,ליידיסמית,لايدي سميث', 48.9901600, -123.8169900, 'CA', '2014-02-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9926, 'Lake Cowichan', 'Lake Cowichan', '', 48.8249500, -124.0546100, 'CA', '2011-09-14', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9927, 'Lambton Shores', 'Lambton Shores', 'Lamton Shors,Thedford,lmbtwn shwrys,Ламтон Шорс,لمبتون شوريس', 43.1667800, -81.9330900, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9928, 'La Minerve', 'La Minerve', 'La Minerve', 46.2500900, -74.9325700, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9929, 'Lamont', 'Lamont', 'Lamont,Ламонт,لامونٹ، البرٹا', 53.7668600, -112.8019500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9930, 'Langenburg', 'Langenburg', '', 50.8499900, -101.7176300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9931, 'Langford', 'Langford', 'Langford,XEJ,lan fu de,langhfwrd,lngfwrd,Лангфорд,لانغفورد,لنگفورد,蘭福德', 48.4496300, -123.5026100, 'CA', '2014-02-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9932, 'Langham', 'Langham', '', 52.3668000, -106.9679300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9933, 'Langley', 'Langley', 'Ciudad de Langley,Langley,Langley  British Columbia,Langli,YLY,laeng-geulli,lan li shi,langhly  kwlwmbya albrytanyt,lyngly,ranguri,Лангли,لانغلي، كولومبيا البريطانية,لینگلی,ラングリー,蘭里市,랭글리', 49.1010700, -122.6588300, 'CA', '2013-06-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9934, 'Langley', 'Langley', 'Distretu de Langley,Distrikto Langley,Distrito de Langley,Distritu de Langley,Langley  British Columbia,Lengli,Township of Langley,lan li qu,lan li zhen,ranguri,Ленглі,لینگلی، برٹش کولمبیا,ラングリー,蘭里區,蘭里鎮', 49.0829700, -122.5858900, 'CA', '2011-02-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9935, 'Lanigan', 'Lanigan', '', 51.8500600, -105.0344300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9936, 'Lanoraie', 'Lanoraie', 'Lanoraie', 45.9667700, -73.2158500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9937, 'La Prairie', 'La Prairie', 'La Preri,la bryry,la prry  kbk,Ла Прери,لا بريري,لا پرری، کبک', 45.4167800, -73.4991700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9938, 'La Ronge', 'La Ronge', 'YVC', 55.1001300, -105.2842200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9939, 'La Sarre', 'La Sarre', 'La Sar,La Sarre,La-Sar,SSQ,la sar  kbk,la sary,Ла Сар,Ла-Сар,لا سار، کبک,لا ساري', 48.8001900, -79.1996400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9940, 'L''Assomption', 'L''Assomption', '', 45.8231800, -73.4294000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9941, 'La Tuque', 'La Tuque', 'La Tik,La Tuque,La-Tjuk,YLQ,la tu ke,latak,latwk,Ла Тик,Ла-Тюк,لاتاك,لاتوک,拉圖克', 47.4333700, -72.7824000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9942, 'Laval', 'Laval', 'Gorad Laval'',Laval,Laval'',Lavalis,Lavalo,la wa lei,lafal,lawal  kbk,lawl,ravu~aru,Λαβάλ,Горад Лаваль,Лавал,Лаваль,לאוואל,لافال,لاوال، کبک,لاول,ラヴァル,拉瓦勒', 45.5699500, -73.6920000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9943, 'Lavaltrie', 'Lavaltrie', 'Lavaltrie', 45.8833800, -73.2824500, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9944, 'Lebel-sur-Quévillon', 'Lebel-sur-Quevillon', 'Lebel-sur-Quevillon,Lebel-sur-Quévillon,YLS', 49.0501800, -76.9827300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9945, 'Leduc', 'Leduc', 'Leduk,lei du ke,lideog,lwdwk,lydwk,Ледук,لودوک,ليدوك,لیڈک، البرٹا,勒杜克,리덕', 53.2668200, -113.5520100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9946, 'L''Épiphanie', 'L''Epiphanie', '', 45.8500800, -73.4824600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9947, 'Les Cèdres', 'Les Cedres', '', 45.3000800, -74.0492200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9948, 'Les Coteaux', 'Les Coteaux', '', 45.2833800, -74.2325400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9949, 'Lethbridge', 'Lethbridge', 'Letbric,Letbridz,Letbridzas,Letbridzh,Letbridžas,Lethbridge,YQL,lai si bu li qi,leseubeuliji,ltbrydg,lythbrydj,resuburijji,Летбридж,Летбриџ,לתברידג,لث‌بریج,ليثبريدج,لیتھ برج,لیتھبریج,レスブリッジ,萊斯布里奇,레스브리지', 49.6999900, -112.8185600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9950, 'Lewisporte', 'Lewisporte', '', 49.2499300, -55.0481600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9951, 'L''Île-Perrot', 'L''Ile-Perrot', 'L''Ile Perrot', 45.3833800, -73.9492000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9952, 'Lions Bay', 'Lions Bay', '', 49.4521800, -123.2376000, 'CA', '2013-09-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9953, 'Little Current', 'Little Current', '', 45.9792700, -81.9248000, 'CA', '2011-12-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9954, 'Lloydminster', 'Lloydminster', 'Llojdminster,Lojdminster,YLL,lao ai de ming si te,lwydmnstr,lwydmynstr,Ллойдминстер,Ллойдмінстер,Лојдминстер,لائڈ منسٹر,لويدمنستر,لویدمینستر,劳埃德明斯特', 53.2834600, -110.0015700, 'CA', '2013-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9955, 'Logan Lake', 'Logan Lake', '', 50.4997600, -120.8025300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9956, 'London', 'London', 'Landona,London,Londonas,Londono,YXU,leondeon,lndn,lndn  antaryw,londoni,lun dui,lun dun,lwndwn,rondon,Лондон,לונדון,لندن,لندن، انتاریو,لندن، اونٹاریو,ლონდონი,ロンドン,伦敦,런던', 42.9833900, -81.2330400, 'CA', '2012-08-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9957, 'Longueuil', 'Longueuil', 'Gorad Langjoj,Long''oj,Longej,Longejlo,Longjoj,Longueuil,lang ji er,long-goei,lwnghwy,lwngwl,lwngwy,rongeru,Горад Лангёй,Лонгеј,Лонгьой,Лонгёй,لونغوي,لونگؤل,لونگوی,ロンゲール,朗基爾,롱괴이', 45.5312100, -73.5180600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9958, 'Lorraine', 'Lorraine', '', 45.6833800, -73.7824900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9959, 'Louiseville', 'Louiseville', 'Luivil,lwyyzwyl  kbk,lwyzfyl,Луивил,لاؤسولے,لويزفيل,لوییزویل، کبک', 46.2559400, -72.9414500, 'CA', '2016-02-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9960, 'Lumby', 'Lumby', '', 50.2497900, -118.9690400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9961, 'Lumsden', 'Lumsden', '', 50.6500900, -104.8678300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9962, 'Lunenburg', 'Lunenburg', 'Lunenberg,Lunenburg,Lunenburq,Lunnenburg,lannbwrg  nwa askwshya,lu nen bao,lunenburgi,lwnnbwrg,mdynt wnynbwrj,runenbagu,Луненберг,Луненбург,לוננבורג,لاننبورگ، نوا اسکوشیا,مدينة ونينبورج,ლუნენბურგი,ルーネンバーグ,盧嫩堡', 44.3784700, -64.3165800, 'CA', '2015-02-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9963, 'Lutes Mountain', 'Lutes Mountain', 'Ljut Mauntin,Лют Маунтин', 46.1354400, -64.9050400, 'CA', '2016-06-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9964, 'Macamic', 'Macamic', '', 48.7501800, -78.9996200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9965, 'Macklin', 'Macklin', '', 52.3334400, -109.9348400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9966, 'Magog', 'Magog', 'Magog,Mejgog,maghwgh  kybk,magogu,magwg,magwg  kbk,mygwg  kywbyk,Магог,Мейгог,ماغوغ، كيبك,ماگوگ,ماگوگ، کبک,میگوگ، کیوبیک,マゴグ', 45.2667800, -72.1490900, 'CA', '2016-05-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9967, 'Magrath', 'Magrath', 'Magro,Магро', 49.4166800, -112.8685600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9968, 'Malartic', 'Malartic', '', 48.1334800, -78.1328300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9969, 'Mandeville', 'Mandeville', 'Mandeville', 46.3667700, -73.3491500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9970, 'Maniwaki', 'Maniwaki', 'Manivaki,Maniwaki,YMW,manywaky,manywaky  kbk,Маниваки,مانيواكي,مانیواکی,مانیواکی، کبک', 46.3834100, -75.9660500, 'CA', '2016-10-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9971, 'Manning', 'Manning', 'Mening,Менинг', 56.9168300, -117.6194500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9972, 'Maple Creek', 'Maple Creek', '', 49.9167800, -109.4848100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9973, 'Maple Ridge', 'Maple Ridge', '', 53.5017200, -113.3627400, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9974, 'Maple Ridge', 'Maple Ridge', 'Mehpl-Ridzh,feng shu ling,mabl rydj,meipeulliji,meipururijji,Мэпл-Ридж,مابل ريدج,メイプルリッジ,楓樹嶺,메이플리지', 49.2193900, -122.6019300, 'CA', '2010-02-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9975, 'Marathon', 'Marathon', 'Marafon,Maraton,YSP,Маратон,Марафон,میراتھن، اونٹاریو', 48.7501000, -86.4332200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9976, 'Marieville', 'Marieville', 'Marieville', 45.4333800, -73.1658500, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9977, 'Markham', 'Markham', 'Markam,Markem,Markhamo,Markum,makamu,markam,markam  antaryw,wan jin shi,Маркам,Маркем,Маркъм,ماركام,مارکام، انتاریو,مارکھم، انٹاریو,マーカム,萬錦市', 43.8668200, -79.2663000, 'CA', '2011-12-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9978, 'Martensville', 'Martensville', '', 52.2833900, -106.6679200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9979, 'Marystown', 'Marystown', '', 47.1666300, -55.1482900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9980, 'Mascouche', 'Mascouche', 'Maskush,maskwch,maskwsh,maskwsh  kybk,Маскуш,ماسكوش، كيبك,ماسکوش,ماسکوچ', 45.7496500, -73.5995600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9981, 'Maskinongé', 'Maskinonge', '', 46.2286000, -73.0191700, 'CA', '2016-02-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9982, 'Matagami', 'Matagami', 'Matagami,YNM,matagamy,mataghamy,Матагами,ماتاغامي,ماتاگامی,ماٹاگامی', 49.7501800, -77.6327700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9983, 'Mattawa', 'Mattawa', 'Matava,Матава', 46.3168100, -78.6995700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9984, 'Mayerthorpe', 'Mayerthorpe', '', 53.9501500, -115.1354700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9985, 'Meadow Lake', 'Meadow Lake', 'Meadow Lake,Medou Lejk,YLJ,medoureiku,Медоу Лејк,メドウレイク', 54.1334800, -108.4347100, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9986, 'Medicine Hat', 'Medicine Hat', 'Medicine Hat,Medikan Hat,Medisin Hetas,Medisin Khat,Medisin-Get,Medisin-Khat,YXH,mdsyn hat,mdysyn ht,mei di xin ha te,Медисин Хат,Медисин-Гет,Медисин-Хат,مدسين هات,مدیسین هت,میڈیسن ہیٹ,梅迪辛哈特', 50.0392800, -110.6766100, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9987, 'Melfort', 'Melfort', 'Melfort,Мелфорт', 52.8667300, -104.6176800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9988, 'Melita', 'Melita', 'Melita,Мелита', 49.2681100, -100.9966900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9989, 'Melville', 'Melville', 'Melvil,Melvill,Мелвил,Мелвилл,Мелвілл', 50.9167100, -102.8009900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9990, 'Mercier', 'Mercier', '', 45.3167800, -73.7491900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9991, 'Merritt', 'Merritt', 'Merit,YMB,myryt,Мерит,ميريت,میریٹ، برٹش کولمبیا', 50.1122500, -120.7942000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9992, 'Metchosin', 'Metchosin', '', 48.3829300, -123.5359100, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9993, 'Middleton', 'Middleton', 'Am Baile Meadhanach,mydltwn,میدلتون', 44.9428400, -65.0702200, 'CA', '2014-11-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9994, 'Midland', 'Midland', 'Midland,mei de lan,mydland,mydlnd  antaryw,Мидланд,Мідланд,ميدلاند,میدلند، انتاریو,美德兰', 44.7501000, -79.8829600, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9995, 'Millet', 'Millet', '', 53.1001300, -113.4687000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9996, 'Milton', 'Milton', 'Gorad Miltan,Milton,mi er dun,miruton,myltwn,Горад Мілтан,Милтон,Мілтон,ميلتون,ミルトン,米尔顿', 43.5168100, -79.8829400, 'CA', '2013-07-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9997, 'Minnedosa', 'Minnedosa', 'Minedosa,Минедоса', 50.2453200, -99.8436400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9998, 'Mirabel', 'Mirabel', 'Mirabel,Mirabel'',myrabl  kbk,myrabyl  kybk,Мирабел,Мирабель,ميرابيل، كيبك,میرابل، کبک', 45.6500800, -74.0825100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(9999, 'Miramichi', 'Miramichi', 'Miramichi,Miramishi,YCH,Мирамиши,Мірамічі,میرامچھی', 47.0289500, -65.5018600, 'CA', '2013-08-10', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10000, 'Mississauga', 'Mississauga', 'Misisaga,Misisoga,Misisogo,Missisoga,Mississauga,Mississoga,mi xi sha jia,mishisaga,misisaga,misisogeo,mss saga,mssaga,mysysaga,mysysagha,mysyswgh,mysyswja,Мисисага,Мисисога,Миссиссога,Міссісога,מיסיסוגה,مسس ساگا,مسساگا,ميسيساغا,ميسيسوجا,میسیساگا,मिसिसागा,ਮਿਸੀਸਾਗਾ,මිසිසාගා,ミシサガ,密西沙加,미시소거', 43.5789000, -79.6583000, 'CA', '2012-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10001, 'Moncton', 'Moncton', 'Mon''kton,Moncton,Monkton,Monktonas,Monktono,YQM,meng ke dun,meongkeuteon,monkuton,mwnktwn,mwnqtwn,mx ngk tan,Μόνκτον,Монктон,מונקטון,مانکٹن,مونكتون,مونکتون,مونکٹون,มองก์ตัน,モンクトン,蒙克顿,멍크턴', 46.0945400, -64.7965000, 'CA', '2015-08-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10002, 'Montague', 'Montague', 'Montagju,Монтагју', 46.1668100, -62.6486600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10003, 'Mont-Laurier', 'Mont-Laurier', 'Mon Lorje,Mon-Lor''e,Mont-Laurier,mwn-lwryh,mwnt lwryl,Мон Лорје,Мон-Лорьє,مون-لوریه,مونت لوريل', 46.5501100, -75.4993000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10004, 'Montréal', 'Montreal', 'Lungsod ng Montreal,Lungsod ng Montréal,Monreal,Monreal'',Monreala,Monrealis,Monreyal,Monreāla,Mons Regius,Mont-real,Montreal,Montreal - Montreal,Montreal - Montréal,Montreal City,Montreali,Montrealo,Montréal,YMQ,meng te li er,monreali,monteuliol,montorioru,mwntral,mwntryal,Μοντρεαλ,Μόντρεαλ,Монреал,Монреаль,Монтреал,מונטריאול,مونترآل,مونتریال,مونترېئال,მონრეალი,ᒧᕆᐊᓪ,モントリオール,蒙特利尔,몬트리올', 45.5088400, -73.5878100, 'CA', '2015-09-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10005, 'Montréal-Est', 'Montreal-Est', 'Montreal East,Montreal-Est,Montréal-Est', 45.6320200, -73.5075000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10006, 'Montréal-Ouest', 'Montreal-Ouest', 'Montreal West', 45.4528600, -73.6491800, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10007, 'Mont-Royal', 'Mont-Royal', 'Mon Roajal,Mount Royal,mwn rwyal  kbk,mwnt rwyal,Мон Роајал,مون رویال، کبک,مونت رويال', 45.5167500, -73.6491800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10008, 'Mont-Saint-Grégoire', 'Mont-Saint-Gregoire', 'Mont-Saint-Gregoire,Mont-Saint-Grégoire', 45.3333800, -73.1658500, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10009, 'Mont-Saint-Hilaire', 'Mont-Saint-Hilaire', 'Mon Sent Iler,mwn-sn-aylr  kbk,mwnt san hylyr,Мон Сент Илер,مون-سن-ایلر، کبک,مونت سان هيلير', 45.5651500, -73.1868000, 'CA', '2017-01-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10010, 'Mont-Tremblant', 'Mont-Tremblant', 'Mon Tramblan,Mon-Tramblan,Mont-Tremblant,YTM,montoranburan,mwn-trwmblan  kbk,mwnt trymblant  kybk,Мон Трамблан,Мон-Трамблан,مون-ترومبلان، کبک,مونت تريمبلانت، كيبك,モントランブラン', 46.2127400, -74.5843800, 'CA', '2013-08-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10011, 'Moose Jaw', 'Moose Jaw', 'Moose Jaw,Mus DZo,Mus Dzo,Mus-Dzho,Muus-dzho,Mūs Džo,YMJ,mu si qiao,museujo,mwsjaw,Мус Џо,Мус-Джо,Муус-джо,موسجاو,穆斯乔,무스조', 50.4000500, -105.5344500, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10012, 'Moosomin', 'Moosomin', '', 50.1333200, -101.6676600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10013, 'Morden', 'Morden', 'Morden,Морден,مورڈن، مینی ٹوبا', 49.1919000, -98.1013600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10014, 'Morin-Heights', 'Morin-Heights', 'Morin-Heights', 45.9000900, -74.2492200, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10015, 'Morinville', 'Morinville', '', 53.8001400, -113.6520300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10016, 'Morris', 'Morris', '', 49.3549900, -97.3656700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10017, 'Morrisburg', 'Morrisburg', '', 44.9001000, -75.1826100, 'CA', '2017-06-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10018, 'Mount Pearl', 'Mount Pearl', '', 47.5165900, -52.7813500, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10019, 'Nackawic', 'Nackawic', 'Nakavik,Накавик', 45.9966600, -67.2402800, 'CA', '2012-08-21', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10020, 'Nakusp', 'Nakusp', '', 50.2498700, -117.8022600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10021, 'Nanaimo', 'Nanaimo', 'Nanaimo,Nanajmo,YCD,na nai mo,nanaimo,nanaymw,nanaymw  brytysh klmbya,nanyamw ay,nnayymw,Нанаймо,Нанајмо,نانائمو,نانایمو,نانایمو، بریتیش کلمبیا,نانيامو إي,ننائیمو,ナナイモ,纳奈莫,나나이모', 49.1663800, -123.9400300, 'CA', '2013-06-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10022, 'Nanton', 'Nanton', '', 50.3500800, -113.7686600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10023, 'Napierville', 'Napierville', 'Napierville', 45.1864800, -73.4046800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10024, 'Neebing', 'Neebing', '', 48.1668000, -89.4168300, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10025, 'Neepawa', 'Neepawa', '', 50.2289200, -99.4664200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10026, 'Nelson', 'Nelson', 'Nel''son,Nelson,neruson,nylswn,Нелсон,Нельсон,نيلسون,نیلسن، برٹش کولمبیا,ネルソン', 49.4998500, -117.2855300, 'CA', '2012-02-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10027, 'New Glasgow', 'New Glasgow', 'Glaschu Ur,Glaschu Ùr,Glaschu Úr,Nova Glasgow,nyw glasgw,نیو گلاسگو', 45.5834400, -62.6486300, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10028, 'Newmarket', 'Newmarket', 'N''jumarket,Njumarket,niu ma ke te,nyumakes,nyumaketto,nywmarkt,nywmarkt  antaryw,Њумаркет,Ньюмаркет,نيوماركت,نیومارکت، انتاریو,ニューマーケット,纽马克特,뉴마켓', 44.0501100, -79.4663100, 'CA', '2011-12-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10029, 'New Westminster', 'New Westminster', 'N''ju-Uehstminster,New Westminister,New Westminster,Nju Vestminster,YBD,nyuuesutominsuta,nyuweseuteuminseuteo,nyw wstmynstr,nyw wystmynystr,xin wei si min si te,xin xi min,Њу Вестминстер,Нью-Уэстминстер,ניו וסטמינסטר,نيو ويستمينيستر,نیو وسٹمنسٹر,نیو ویسٹ منسٹر,ニューウエストミンスター,新威斯敏斯特,新西敏,뉴웨스트민스터', 49.2067800, -122.9109200, 'CA', '2014-02-09', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10030, 'Niagara Falls', 'Niagara Falls', 'Najagara Fols,Niagara Falls,Niagara Folsas,Niagara-Folls,Niagara-Fols,XLV,naiagalapolseu,naiagaraforuzu,ni ya jia la pu bu cheng,nyagara falz  antaryw,nyagra falz,nyajara fwlz,Најагара Фолс,Ниагара-Фолс,Ніагара-Фоллс,نياجارا فولز,نیاگارا فالز، انتاریو,نیاگرا فالز,نیاگرا فالز، انٹاریو,ナイアガラフォールズ,尼亚加拉瀑布城,나이아가라폴스', 43.1001200, -79.0662700, 'CA', '2009-06-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10031, 'Nicolet', 'Nicolet', 'Nikole,Nikolet,nykwlh  kbk,Николе,Николет,نیکوله، کبک', 46.2167600, -72.6158200, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10032, 'Nipawin', 'Nipawin', '', 53.3667800, -104.0009200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10033, 'Niverville', 'Niverville', '', 49.6055900, -97.0423400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10034, 'Norfolk County', 'Norfolk County', '', 42.8334000, -80.3829700, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10035, 'Normandin', 'Normandin', '', 48.8332800, -72.5320900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10036, 'Norman Wells', 'Norman Wells', 'Norman Wells,YVQ', 65.2820100, -126.8329000, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10037, 'North Battleford', 'North Battleford', 'Nort Betlford,Nort-Betlford,North Battleford,YQW,bei bei te er fu de,nwrth batlfwrd,Норт Бетлфорд,Норт-Бетлфорд,نورث باتلفورد,北贝特爾福德', 52.7797200, -108.2967000, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10038, 'North Bay', 'North Bay', 'Gorad Nort-Bej,Nort Bej,Nort-Bej,YYB,bei wan,nosubei,nwrth bay,nwrth by,Горад Норт-Бей,Норт Беј,Норт-Бей,نارتھ بے,نورث باي,نورث بی,ノースベイ,北灣', 46.3168000, -79.4663300, 'CA', '2014-07-14', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10039, 'North Cowichan', 'North Cowichan', 'kawytshan alshmalyt,كاويتشان الشمالية', 48.8413300, -123.6859600, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10040, 'North Perth', 'North Perth', 'Nort Pert,nwrth byrth,Норт Перт,نورث بيرث', 43.7251000, -80.9672300, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10041, 'North Saanich', 'North Saanich', '', 48.6663400, -123.4193300, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10042, 'North Vancouver', 'North Vancouver', 'Nort Vankuver,Nort-Vankuver,Vancouver Utara  British Columbia,bei wen ge hua shi,noseubaenkubeo,nosubankuba,wnkwwr shmaly,Норт Ванкувер,Норт-Ванкувер,نارتھ وینکوور,ونکوور شمالی,ノースバンクーバー,北溫哥華市,노스밴쿠버', 49.3163600, -123.0693400, 'CA', '2013-08-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10043, 'North York', 'North York', 'Nort-Jork,bei yue ke,nort york,nosuyoku,Норт-Йорк,நோர்த் யோர்க்,ノースヨーク,北約克', 43.7668100, -79.4163000, 'CA', '2011-12-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10044, 'Notre-Dame-de-l''Île-Perrot', 'Notre-Dame-de-l''Ile-Perrot', '', 45.3667800, -73.9325000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10045, 'Notre-Dame-des-Prairies', 'Notre-Dame-des-Prairies', '', 46.0500700, -73.4324500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10046, 'Oak Bay', 'Oak Bay', 'awk bay,xiang shu wan,أوك باي,橡樹灣', 48.4496400, -123.3026000, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10047, 'Oakville', 'Oakville', 'Okvil,Okvill,XOK,ao ke wei er,awkfyl,okeubil,okubiru,Оквил,Оквилл,Оквілл,أوكفيل,اوک‌ویل,オークビル,奥克维尔,오크빌', 43.4501100, -79.6829200, 'CA', '2012-01-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10048, 'Oka', 'Oka', 'Oka,awka,awka  kbk,أوكا,اوکا، کبک', 45.4648900, -74.0889200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10049, 'Okotoks', 'Okotoks', 'Okotoks,ao ke tuo ke si,okotogseu,Окотокс,奥克托克斯,오코톡스', 50.7288500, -113.9828100, 'CA', '2009-03-25', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10050, 'Olds', 'Olds', 'Oulds,Оулдс', 51.7834100, -114.1019900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10051, 'Oliver', 'Oliver', '', 49.1830600, -119.5524000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10052, 'Orangeville', 'Orangeville', '', 43.9168000, -80.0996700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10053, 'Orillia', 'Orillia', 'Orilija,Orillija,ao li li ya,awrylya,awrylya  antaryw,oriria,Орилија,Ориллия,Оріллія,أوريليا,اوریلیا,اوریلیا، انتاریو,オリリア,奧里利亞', 44.6086800, -79.4206800, 'CA', '2009-07-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10054, 'Ormstown', 'Ormstown', '', 45.1333800, -73.9992200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10055, 'Oromocto', 'Oromocto', '', 45.8351200, -66.4791700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10056, 'Oshawa', 'Oshawa', 'Osava,Oshava,Ošava,QWA,YOO,ao sha hua,awshawa,oshava,oshawa,osyawa,Ошава,أوشاوا,اوشاوا,ოშავა,オシャワ,奧沙華,오샤와', 43.9001200, -78.8495700, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10057, 'Osoyoos', 'Osoyoos', 'Osujus,Осуюс', 49.0330600, -119.4523700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10058, 'Ottawa', 'Ottawa', 'Gorad Atava,Otava,Otavo,Otawa,Ottaba,Ottahua,Ottava,Ottavae,Ottawa,YOW,atawa,atoya,attava,awtawa,otava,otawa,ottava,wo tai hua,xxttawa,AA¬²±,Οττάβα,Οτταβα,Горад Атава,Отава,Оттавæ,Оттава,Օտտավա,אוטווה,אטאווא,أوتاوا,ئۆتاوا,اتاوا,اوتآوآ,اوٹاوا,اٹاوہ,ओटावा,অটোয়া,ਓਟਾਵਾ,ଓଟାୱା,ஒட்டாவா,ಆಟ್ಟಾವಾ,ഓട്ടവ,ออตตาวา,ཨོ་ཏ་ཝ།,အော့တဝမြို့,ოტავა,ኦታዋ,ᎠᏔᏩ,ᐊᑐᕚ/atavaa,オタワ,渥太華,오타와', 45.4111700, -75.6981200, 'CA', '2016-01-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10059, 'Otterburn Park', 'Otterburn Park', '', 45.5333800, -73.2158500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10060, 'Outlook', 'Outlook', '', 51.5000800, -107.0512800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10061, 'Owen Sound', 'Owen Sound', 'Ouehn-Saund,Oven Saund,YOS,awwn sawnd,awyn sawnd,ou~ensaundo,Овен Саунд,Оуэн-Саунд,أوين ساوند,اوون ساؤنڈ,اوون ساوند,オーウェンサウンド', 44.5671700, -80.9434900, 'CA', '2009-07-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10062, 'Oxbow', 'Oxbow', '', 49.2333500, -102.1676000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10063, 'Oxford', 'Oxford', '', 45.7334500, -63.8654200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10064, 'Pangnirtung', 'Pangnirtung', 'Pangnirtang,Pangnirtung,YXP,png nrtng  nnawt,Пангниртунг,Пангніртанг,پنگ نرتنگ، نناوت', 66.1464200, -65.6999600, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10065, 'Papineauville', 'Papineauville', '', 45.6168000, -75.0159900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10066, 'Parksville', 'Parksville', 'Jewel of Vancouver Island,Parksvil,Parksville,XPB,barksfyl,pa ke si wei er,Парксвил,باركسفيل,پارکسولے,پارکسویل، برٹش کولمبیا,帕克斯維爾', 49.3194700, -124.3157500, 'CA', '2016-09-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10067, 'Parrsboro', 'Parrsboro', '', 45.4056700, -64.3258500, 'CA', '2014-10-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10068, 'Parry Sound', 'Parry Sound', 'Pari Saund,Parri-Saund,YPD,pa li wan,parisaundo,Пари Саунд,Паррі-Саунд,パリーサウンド,帕里灣', 45.3473200, -80.0352700, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10069, 'Pasadena', 'Pasadena', '', 49.0167100, -57.5983700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10070, 'Peace River', 'Peace River', 'Peace River,Pis River,Pis-River,Riviere-la-Paix,Rivière-la-Paix,YPE,pi si li fu,Пис Ривер,Піс-Рівер,皮斯里弗', 56.2371500, -117.2917600, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10071, 'Peachland', 'Peachland', '', 49.7664700, -119.7356800, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10072, 'Pemberton', 'Pemberton', 'bymbrtwn,بيمبرتون', 50.3164100, -122.8027300, 'CA', '2011-10-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10073, 'Pembroke', 'Pembroke', 'YTA', 45.8168100, -77.1161600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10074, 'Penhold', 'Penhold', '', 52.1334200, -113.8687000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10075, 'Penticton', 'Penticton', 'Pentikton,YYF,byntyktwn,peng di ke dun,Пентиктон,بينتيكتون,پینٹکٹان,پینٹیکٹن,彭蒂克顿', 49.4806200, -119.5858400, 'CA', '2009-07-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10076, 'Perth', 'Perth', 'Pert,pasu,po si,prt  antaryw,Перт,پرت، انتاریو,パース,珀斯', 44.9001100, -76.2493900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10077, 'Petawawa', 'Petawawa', 'Petawawa,YWA', 45.8945200, -77.2800700, 'CA', '2013-10-26', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10078, 'Peterborough', 'Peterborough', 'Peterborough,Piterboro,YPQ,bi de bao,bytyrbwrwgh,pitaboro,piteobeoleo,pytrbwrw  antaryw,Питерборо,Пітерборо,بيتيربوروغ,پیتربورو، انتاریو,پیٹربرو، انٹاریو,پیٹربروہ,ピーターボロ,彼得堡,피터버러', 44.3001200, -78.3162300, 'CA', '2016-07-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10079, 'Petrolia', 'Petrolia', '', 42.8667800, -82.1498100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10080, 'Pickering', 'Pickering', 'Pikering,bykryngh,pi ke ling,pikaringu,pikeoling,pkrng,pykryng  antaryw,Пикеринг,Пікерінг,بيكرينغ,پکرنگ,پیکرینگ، انتاریو,ピカリング,皮克靈,피커링', 43.9001200, -79.1328900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10081, 'Picton', 'Picton', 'pikuton,ピクトン', 44.0001200, -77.1327500, 'CA', '2013-02-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10082, 'Pictou', 'Pictou', 'Piogto,pyktw,پیکتو', 45.6787500, -62.7093600, 'CA', '2014-04-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10083, 'Picture Butte', 'Picture Butte', '', 49.8833000, -112.7851600, 'CA', '2013-12-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10084, 'Piedmont', 'Piedmont', 'Piedmont', 45.9000800, -74.1325100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10085, 'Pierreville', 'Pierreville', '', 46.0703400, -72.8112500, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10086, 'Pilot Butte', 'Pilot Butte', '', 50.4667800, -104.4177800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10087, 'Pincher Creek', 'Pincher Creek', 'Pincher Krik,WPC,Пинчер Крик', 49.4832800, -113.9519500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10088, 'Pincourt', 'Pincourt', '', 45.3833800, -73.9825000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10089, 'Pitt Meadows', 'Pitt Meadows', 'Pit Medous,Pitt Meadows,Pitt-Medous,Pitts Meadows,byt mydwz,pi te cao yuan,piteumedoseu,pittomedouzu,Пит Медоус,Питт-Медоус,بيت ميدوز,پٹ میڈوز,ピットメドウズ,匹特草原,피트메도스', 49.2211900, -122.6896500, 'CA', '2010-04-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10090, 'Pointe-Calumet', 'Pointe-Calumet', 'Pointe-Calumet', 45.5000800, -73.9659000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10091, 'Pointe-Claire', 'Pointe-Claire', 'Poent Kler,bu wan ka li,bwynt klyr,pwynt-klr,Поент Клер,بوينت كلير,پوئنت-کلر,布彎卡利', 45.4486800, -73.8166900, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10092, 'Ponoka', 'Ponoka', 'Ponoka,Понока', 52.6768000, -113.5814700, 'CA', '2010-12-16', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10093, 'Pont Rouge', 'Pont Rouge', '', 48.8833200, -72.0824700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10094, 'Portage la Prairie', 'Portage la Prairie', 'Portage la Prairie,Portedzh-la-Preri,Portidz la Preri,Portidzh-la-Preri,YPG,prtagy la prayry,Портедж-ла-Прері,Портидж-ла-Прери,Портиџ ла Прери,پرتاگی لا پرائری,پورٹیج لا پریری، مینی ٹوبا', 49.9728200, -98.2926300, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10095, 'Port Alberni', 'Port Alberni', 'Port Alberni,Port Almperni,YPB,ai bo ni gang,bwrt albyrny,Πορτ Άλμπερνι,Порт Алберни,بورت ألبيرني,پورٹ البرنی,پورٹ البرنی، برٹش کولمبیا,艾伯尼港', 49.2413300, -124.8028000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10096, 'Port-Cartier', 'Port-Cartier', 'Por Kartje,Port-Cartier,bwrt kartyr,ka jie gang,pwrt-kartyh  kbk,Пор Картје,بورت كارتير,پورت-کارتیه، کبک,卡捷港', 50.0333900, -66.8654500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10097, 'Port Colborne', 'Port Colborne', 'Port Kolborn,Port-Kolborn,bwrt kwlbwrn,poteukolbon,potokorubon,pwrt kwlbwrn,Порт Колборн,Порт-Колборн,بورت كولبورن,پورت کولبورن,پورٹ کولبورن,ポートコルボーン,포트콜본', 42.9001200, -79.2328800, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10098, 'Port Hawkesbury', 'Port Hawkesbury', 'YPS', 45.6168500, -61.3485300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10099, 'Port Moody', 'Port Moody', 'Port Mudi,bwrt mwdy,man de bao,poteumudi,potomudi,Порт Муди,بورت مودي,پورٹ موڈی,ポートムーディ,滿地寶,포트무디', 49.2829700, -122.8526300, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10100, 'Powassan', 'Powassan', '', 46.0334000, -79.3496100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10101, 'Powell River', 'Powell River', 'Pauel River,Powell River,YPW,bwyl ryfr,Пауел Ривер,بويل ريفر', 49.8327800, -124.5236800, 'CA', '2016-04-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10102, 'Preeceville', 'Preeceville', '', 51.9499800, -102.6676600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10103, 'Prescott', 'Prescott', 'Prescott,Preskot,Preskott,XII,prskat  antaryw,Прескот,Прескотт,پرسکات، انتاریو', 44.7168100, -75.5160400, 'CA', '2013-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10104, 'Prévost', 'Prevost', 'Prevost,Prévost', 45.8667800, -74.0825100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10105, 'Prince Albert', 'Prince Albert', 'Prince Albert,Prins Albert,Prins-Al''bert,Saskatoon,YPA,ai bo te qin wang cheng,bryns albrt,pryns albrt,Принс Алберт,Принс-Альберт,برينس ألبرت,پرینس آلبرت,プリンス・アルバート,艾伯特亲王城', 53.2000800, -105.7677200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10106, 'Prince Edward', 'Prince Edward', 'Prince Edward,Prince Edward County', 44.0001200, -77.2494600, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10107, 'Prince George', 'Prince George', 'Prince George,Prins DZordz,Prins-Dzhordzh,YXS,bryns jwrj,peulinseujoji,phrins cxrc,prns jrj  brytysh klmbya,pryns gwrg,qiao zhi wang zi cheng,Принс Џорџ,Принс-Джордж,Прінс-Джордж,פרינס גורג,برينس جورج,پرنس جارج، برٹش کولمبیا,پرنس جرج، بریتیش کلمبیا,พรินซ์จอร์จ,乔治王子城,프린스조지', 53.9166000, -122.7530100, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10108, 'Prince Rupert', 'Prince Rupert', 'Prins Rupert,Prins-Rupert,YPR,bryns rwbyrt,lu po te wang zi gang,peulinseulupeoteu,purinsurupato,Принс Руперт,Принс-Руперт,Прінс-Руперт,برينس روبيرت,پرنس رپرٹ، برٹش کولمبیا,プリンスルパート,鲁珀特王子港,프린스루퍼트', 54.3150700, -130.3209800, 'CA', '2013-10-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10109, 'Princeton', 'Princeton', 'Prinston,Принстон', 49.4580200, -120.5107600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10110, 'Princeville', 'Princeville', '', 45.7668400, -61.2985300, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10111, 'Provost', 'Provost', '', 52.3501400, -110.2682800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10112, 'Quesnel', 'Quesnel', 'Kvenel,YQZ,kwyznl,kynyl,Квенел,كينيل,کوئزنل,کوئیسنل، برٹش کولمبیا', 52.9784200, -122.4931000, 'CA', '2012-07-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10113, 'Quinte West', 'Quinte West', 'Kvinti Vest,kuinteuesuto,kwyynt ghrby,qwynt wyst,Квинти Вест,قوينت ويست,کوئنتے ویسٹ,کوئینت غربی,کونٹ وسٹ,クインテウエスト', 44.1834200, -77.5661800, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10114, 'Rankin Inlet', 'Rankin Inlet', 'Rankin Inlet,Rankin-Inlet,YRT,Ранкин-Инлет,Ранкін-Інлет,رنکن ان لٹ، نناوت', 62.8090600, -92.0853400, 'CA', '2016-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10115, 'Rawdon', 'Rawdon', 'Rawdon', 46.0500700, -73.7158700, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10116, 'Raymond', 'Raymond', 'Rejmond,Рејмонд,ریمنڈ، البرٹا', 49.4499800, -112.6518500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10117, 'Rayside-Balfour', 'Rayside-Balfour', '', 46.6087300, -81.2076300, 'CA', '2013-07-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10118, 'Red Deer', 'Red Deer', 'Red Deer,Red Dir,Red Dyras,Red-Dir,YQF,hong lu shi,rd dyr,reddodia,ryڈ ڈyyr  albrٹa,Ред Дир,Ред-Дир,Ред-Дір,רד דיר,رد دير,رد دیر,ریڈ ڈئر,ریڈ ڈئیر، البرٹا,レッドディア,红鹿市', 52.2668200, -113.8020000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10119, 'Red Lake', 'Red Lake', 'Red Lake,Red Lejk,YRL,Ред Лејк', 51.0167800, -93.8273600, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10120, 'Regina', 'Regina', 'Gorad Rehdzhajna,Redzaina,Redzajna,Redzhajna,Redzhajnae,Redžaina,Regina,Regina i Saskatchewan,Regino,Rejayna,Rengina,Reĝino,Ridzaina,Ridzhajna,Ridžaina,Régina,Urbs Reginae,YQR,li gu na,li jia na,lijaina,rejaina,rejina,rgyynh,rija''ina,rjayna,ryjayna,ryjyna  saskchywan,Ρεγγίνα,Горад Рэджайна,Реджайнæ,Реджайна,Реџајна,Риджайна,Ռեջայնա,רגיינה,رجاینا,ريجاينا,ریجینا، ساسکچیوان,रेजिना,ਰਿਜਾਇਨਾ,ரெஜைனா,რეჯაინა,レジャイナ,里賈納,里贾纳,리자이나', 50.4500800, -104.6178000, 'CA', '2010-07-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10121, 'Renfrew', 'Renfrew', 'Renfru,renfuru,rnfrw  antaryw,Ренфру,رنفرو، انتاریو,レンフルー', 45.4668100, -76.6827200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10122, 'Repentigny', 'Repentigny', 'Repantin''i,Repantini,Repentigny,rpantyny  kbk,rybntynyy,Репантиньи,Репантињи,ريبنتينيي,رپانتینی، کبک', 45.7422200, -73.4500800, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10123, 'Revelstoke', 'Revelstoke', 'Revelstoke,Revelstouk,YRV,ryfylstwk,Ревелстоук,ريفيلستوك,ریول سٹوک,ریولسٹوک، برٹش کولمبیا', 50.9971200, -118.1953000, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10124, 'Richelieu', 'Richelieu', '', 45.4433600, -73.2460200, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10125, 'Richibucto', 'Richibucto', 'Richibouctou,Rishibakto,Ришибакто', 46.6807300, -64.8804400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10126, 'Richmond', 'Richmond', 'Richmond', 45.6667700, -72.1491000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10127, 'Richmond', 'Richmond', 'Richmond,Richmund,Ricmondas,Ričmondas,lichimeondeu,lie zhi wen,ricamada,ritchimondo,rytshmwnd,Ричмонд,Ричмънд,Річмонд,ريتشموند,رچمنڈ، برٹش کولمبیا,رچمونڈ,ਰਿਚਮੰਡ,リッチモンド,列治文,리치먼드', 49.1700300, -123.1368300, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10128, 'Richmond Hill', 'Richmond Hill', 'Richmond Khil,Richmond-Gill,Richmond-Khill,lichimeondeuhil,lie zhi wen shan,ritchimondohiru,rychmwnd hyl  antaryw,rytshmwnd hyl,Ричмонд Хил,Ричмонд-Гілл,Ричмонд-Хилл,ريتشموند هيل,ریچموند هیل، انتاریو,リッチモンドヒル,列治文山,烈治文山,리치먼드힐', 43.8711100, -79.4372500, 'CA', '2014-10-27', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10129, 'Rideau Park', 'Rideau Park', '', 53.4789900, -113.5047000, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10130, 'Rigaud', 'Rigaud', 'rygw  kbk,ریگو، کبک', 45.4792700, -74.3023800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10131, 'Rimbey', 'Rimbey', '', 52.6334000, -114.2353200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10132, 'Rivers', 'Rivers', 'YYI', 50.0308100, -100.2402900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10133, 'Rivière-Rouge', 'Riviere-Rouge', 'Rivjer Ruzh,rywyyr-rwzh  kbk,Ривјер Руж,ریوییر-روژ، کبک', 46.4167900, -74.8659600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10134, 'Roberval', 'Roberval', 'Roberval,YRJ', 48.5168000, -72.2324400, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10135, 'Roblin', 'Roblin', '', 51.2299900, -101.3565000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10136, 'Rock Forest', 'Rock Forest', 'Rock Forest', 45.3569900, -71.9967600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10137, 'Rocky Mountain House', 'Rocky Mountain House', 'YRM', 52.3668300, -114.9188000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10138, 'Rosemère', 'Rosemere', 'Rozmer,rwzmr  kbk,rwzmyry,Розмер,روزمر، کبک,روزميري', 45.6333800, -73.7991900, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10139, 'Rosetown', 'Rosetown', '', 51.5501000, -108.0013600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10140, 'Rossland', 'Rossland', 'Rosland,luo si lan,Росланд,روسلینڈ,روسلینڈ، برٹش کولمبیا,羅斯蘭', 49.0831300, -117.8022400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10141, 'Rosthern', 'Rosthern', '', 52.6667900, -106.3344600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10142, 'Rougemont', 'Rougemont', 'Rougemont', 45.4333800, -73.0491400, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10143, 'Rouyn-Noranda', 'Rouyn-Noranda', 'Rouyn-Noranda,Ruehn-Noranda,Ruen-Noranda,Ruin Noranda,YUY,rwwan nwranda,rwyn-nwranda,Руен-Норанда,Руин Норанда,Руэн-Норанда,رووان نوراندا,روین-نوراندا', 48.2365600, -79.0231100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10144, 'Sackville', 'Sackville', 'Sakvill,XKV,Саквилл,سکولے، نیو برنسوک', 45.9187500, -64.3845500, 'CA', '2010-06-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10145, 'Saguenay', 'Saguenay', 'Sagene,Sagenej,Sagenė,Sagne,Saguenay,YBG,sa ge nai,sageune,saghynyh,sagune,sagwnh  kbk,Сагеней,Сагне,סאגנה,ساغينيه,ساگونه، کبک,سگینے، کیوبک,サグネ,薩格奈,사그네', 48.4167500, -71.0657300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10146, 'Saint-Adolphe-d''Howard', 'Saint-Adolphe-d''Howard', 'Saint-Adolphe-d''Howard', 45.9667900, -74.3325300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10147, 'Saint-Ambroise', 'Saint-Ambroise', '', 48.5500900, -71.3323800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10148, 'Saint-André-Avellin', 'Saint-Andre-Avellin', '', 45.7168000, -75.0659900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10149, 'Saint Andrews', 'Saint Andrews', '', 45.0737000, -67.0531200, 'CA', '2014-09-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10150, 'Saint-Augustin', 'Saint-Augustin', '', 51.2260200, -58.6501700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10151, 'Saint-Basile-le-Grand', 'Saint-Basile-le-Grand', 'Saint-Basile-le-Grand,Sen Bazil le Gran,san basyly ly jrand,sn-bazyl-lw-grand  kbk,Сен Базил ле Гран,سان باسيلي لي جراند,سن-بازیل-لو-گراند، کبک,سینٹ-بسلے-لے-گرینڈ، کیوبک', 45.5333800, -73.2824600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10152, 'Saint-Bruno', 'Saint-Bruno', '', 48.4667900, -71.6491000, 'CA', '2017-05-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10153, 'Saint-Bruno-de-Guigues', 'Saint-Bruno-de-Guigues', '', 47.4668500, -79.4329600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10154, 'Saint-Bruno-de-Montarville', 'Saint-Bruno-de-Montarville', 'Sen Brino de Montarvil,san brwnw dy mwntrafly,sn-brwnw-dw-mwntarwyl,Сен Брино де Монтарвил,سان برونو دي مونترافلي,سن-برونو-دو-مونتارویل,سینٹ-برونو-دے-مونترولے', 45.5334100, -73.3491600, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10155, 'Saint-Césaire', 'Saint-Cesaire', 'Saint-Cesaire,Saint-Césaire', 45.4167800, -72.9991400, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10156, 'Saint-Colomban', 'Saint-Colomban', '', 45.7333800, -74.1325100, 'CA', '2014-03-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10157, 'Saint-Côme--Linière', 'Saint-Come--Liniere', '', 46.0667700, -70.5157300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10158, 'Saint-Constant', 'Saint-Constant', 'Saint-Constant,Sen Konstan,san kwnstant,sn-kwnstan  kbk,Сен Констан,سان كونستانت,سن-کونستان، کبک,سینٹ-کانسٹنٹ، کیوبک', 45.3667800, -73.5658800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10159, 'Saint-Cyrille-de-Wendover', 'Saint-Cyrille-de-Wendover', '', 45.9333600, -72.4324100, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10160, 'Saint-Damase', 'Saint-Damase', '', 45.5334100, -72.9991400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10161, 'Saint-Denis-sur-Richelieu', 'Saint-Denis-sur-Richelieu', 'sn-dwny-swr-ryshwlyw  kbk,سن-دونی-سور-ریشولیو، کبک,سینٹ-ڈینس-سر-ریچلیو، کیوبک', 45.7833800, -73.1491500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10162, 'Sainte-Adèle', 'Sainte-Adele', 'Sainte-Adele,Sainte-Adèle,Ste-Adele,Ste-Adèle', 45.9500800, -74.1325100, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10163, 'Sainte-Agathe-des-Monts', 'Sainte-Agathe-des-Monts', 'Sent Agat de Mon,Sent-Agat-de-Mon,sant aghath ds mwnts,snt-agat-dh-mwn,Сент Агат де Мон,Сент-Агат-де-Мон,سانت أغاث دس مونتس,سنت-آگات-ده-مون,سین-اگاٹھے-دس-مونٹس,サンタガット・デ・モン', 46.0500900, -74.2825200, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10164, 'Sainte-Anne-de-Bellevue', 'Sainte-Anne-de-Bellevue', 'Sent An de Belvi,Sent-Ann-de-Bel''vju,snt-an-dw-blww  kbk,Сент Ан де Белви,Сент-Анн-де-Бельвю,سنت-آن-دو-بلوو، کبک,سین-این-دے-بلووے، کیوبک', 45.4061800, -73.9456000, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10165, 'Sainte-Anne-des-Monts', 'Sainte-Anne-des-Monts', 'Sent An de Mon,snt-an-dh-mwn  kbk,Сент Ан де Мон,سنت-آن-ده-مون، کبک,سین-این-دس-مونٹس، کیوبک', 49.1240200, -66.4924300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10166, 'Sainte-Anne-des-Plaines', 'Sainte-Anne-des-Plaines', 'Sent An de Plen,sant an dy blyn,snt-an-dh-pln  kbk,syn-ayn-ds-playns  kywbk,Сент Ан де Плен,سانت آن دي بلين,سنت-آن-ده-پلن، کبک,سین-این-دس-پلائنس، کیوبک', 45.7646800, -73.8115600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10167, 'Sainte-Béatrix', 'Sainte-Beatrix', 'Sainte-Beatrix,Sainte-Béatrix', 46.2000700, -73.6158700, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10168, 'Sainte-Catherine', 'Sainte-Catherine', 'Sainte-Catherine,Sent Katrin,sant kathryn,sheng ka te lin na,snt-katryn  kbk,Сент Катрин,سانت كاثرين,سنت-کاترین، کبک,سین-کیتھرین، کیوبک,圣卡特琳娜', 45.4000800, -73.5824800, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10169, 'Sainte-Catherine', 'Sainte-Catherine', '', 46.3183600, -72.5663200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10170, 'Saint-Édouard', 'Saint-Edouard', 'Saint-Edouard,Saint-Édouard', 45.2333800, -73.5158800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10171, 'Sainte-Julie', 'Sainte-Julie', 'Sent Zhili,sant jwly,snt-zhwly  kbk,Сент Жили,سانت جولي,سنت-ژولی، کبک,سین-جلے، کیوبک', 45.5833800, -73.3324600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10172, 'Sainte-Julienne', 'Sainte-Julienne', '', 45.9667700, -73.7158700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10173, 'Sainte-Marthe-sur-le-Lac', 'Sainte-Marthe-sur-le-Lac', '', 45.5333800, -73.9325000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10174, 'Sainte-Martine', 'Sainte-Martine', '', 45.2500800, -73.7991900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10175, 'Sainte-Sophie', 'Sainte-Sophie', '', 45.8167800, -73.8991900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10176, 'Sainte-Thècle', 'Sainte-Thecle', 'snt-tkl  kbk,سنت-تکل، کبک,سین-تھکلے، کیوبک', 46.8167600, -72.4991100, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10177, 'Sainte-Thérèse', 'Sainte-Therese', '', 45.6392200, -73.8275700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10178, 'Saint-Eustache', 'Saint-Eustache', 'Fanum Sancti Eustachii,Saint-Eustache,Sent Estash,Sent-Ehstash,sant awstash,sn-awstash  kbk,Сент Есташ,Сент-Эсташ,سانت أوستاش,سن-اوستاش، کبک', 45.5650000, -73.9055400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10179, 'Saint-Félicien', 'Saint-Felicien', 'Saint-Felicien,Saint-Félicien,Sen Felisjen,Sen-Felis''en,san fylysyan,sn-flysyn  kbk,Сен Фелисјен,Сен-Фелисьен,Сен-Фелісьєн,سان فيليسيان,سن-فلیسین، کبک,سینٹ-فلیکیں ، کیوبک', 48.6500700, -72.4490600, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10180, 'Saint-Félix-de-Valois', 'Saint-Felix-de-Valois', 'Saint-Felix-de-Valois,Saint-Félix-de-Valois', 46.1697700, -73.4252500, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10181, 'Saint-Félix-de-Valois', 'Saint-Felix-de-Valois', '', 46.1667700, -73.4324500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10182, 'Saint-Gabriel', 'Saint-Gabriel', '', 46.3000700, -73.3824500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10183, 'Saint-Gédéon', 'Saint-Gedeon', '', 48.5000900, -71.7658100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10184, 'Saint-Germain-de-Grantham', 'Saint-Germain-de-Grantham', '', 45.8333700, -72.5658200, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10185, 'Saint-Hippolyte', 'Saint-Hippolyte', 'Saint-Hippolyte,St-Hippolyte', 45.9333800, -74.0159000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10186, 'Saint-Hyacinthe', 'Saint-Hyacinthe', 'Gorad Sen-Iasent,Saint-Hyacinthe,Sankt-Giacint,Sent Ijasent,Sent-Iasent,XIM,san hyasnt  kybk,sn-ayysnt  kbk,Горад Сен-Іасент,Санкт-Гиацинт,Сент Ијасент,Сент-Іасент,Сент-Иасент,سان هياسنت، كيبك,سن-اییسنت، کبک', 45.6307600, -72.9569900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10187, 'Saint-Jacques', 'Saint-Jacques', '', 45.9500700, -73.5658600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10188, 'Saint-Jacques-le-Mineur', 'Saint-Jacques-le-Mineur', 'Saint-Jacques-le-Mineur', 45.2833800, -73.4158700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10189, 'Saint-Jean-sur-Richelieu', 'Saint-Jean-sur-Richelieu', 'Saint-Jean-sur-Richelieu,Sen Zhan sir Rishele,Sen-Zhan-sjur-Rishel''e,Sen-Zhan-sjur-Rishel''jo,YJN,san jan swr ryshlyw,sn-zhan-swr-ryshwlyw,Сен Жан сир Ришеље,Сен-Жан-сюр-Ришелье,Сен-Жан-сюр-Рішельйо,سان جان سور ريشليو,سن-ژان-سور-ریشولیو,سینٹ-ژاں -سر-ریچلیو', 45.3071300, -73.2625900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10190, 'Saint-Jérôme', 'Saint-Jerome', 'Saint-Jerome,Saint-Jérôme,Sen Zherom,Sen-Zherom,san jyrwm,sn-zhrwm  kbk,Сен Жером,Сен-Жером,سان جيروم,سن-ژروم، کبک', 45.7803600, -74.0036500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10191, 'Saint John', 'Saint John', 'Gorad Sent-Dzhon,Saint John,Saint-Jean,Sejnt Dzhon,Sent DZon,Sent-Dzhon,Urbs Sancti Ioannis Canadensis,YSJ,seinteujon,senta jona,sentcxhn,sentojon,sheng yue han,snt gwn,snt jan,Горад Сент-Джон,Сейнт Джон,Сент Џон,Сент-Джон,סנט גון,سنت جان,سینٹ جان,سینٹ جان، نیو برنسوک,सेंट जॉन,เซนต์จอห์น,სენტ-ჯონი,セントジョン,セント・ジョン,圣约翰,세인트존', 45.2727100, -66.0676600, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10192, 'Saint-Joseph-de-Coleraine', 'Saint-Joseph-de-Coleraine', '', 45.9667700, -71.3657700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10193, 'Saint-Joseph-du-Lac', 'Saint-Joseph-du-Lac', 'Saint-Joseph-du-Lac', 45.5333800, -73.9992000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10194, 'Saint-Laurent', 'Saint-Laurent', 'Saint-Laurent,Sen Loran,Sen-Loran,St Laurent,Ville Saint-Laurent,Ville St Laurent,Сен Лоран,Сен-Лоран,سینٹ-لارنٹ، کیوبک', 45.5000800, -73.6658500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10195, 'Saint-Lazare', 'Saint-Lazare', 'Saint-Lazare,Sen Lazar,san lazar  kybk,sn-lazar  kbk,Сен Лазар,سان لازار، كيبك,سن-لازار، کبک', 45.4000800, -74.1325600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10196, 'Saint-Léonard', 'Saint-Leonard', '', 45.5877300, -73.5950100, 'CA', '2013-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10197, 'Saint-Lin-Laurentides', 'Saint-Lin-Laurentides', '', 45.8500800, -73.7658800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10198, 'Saint-Marc-des-Carrières', 'Saint-Marc-des-Carrieres', '', 46.6833500, -72.0491000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10199, 'Saint-Mathieu', 'Saint-Mathieu', 'Saint-Mathieu', 45.3167800, -73.5158700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10200, 'Saint-Michel-des-Saints', 'Saint-Michel-des-Saints', 'Saint-Michel-des-Saints', 46.6833800, -73.9158900, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10201, 'Saint-Nazaire', 'Saint-Nazaire', '', 48.5894400, -71.5524700, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10202, 'Saint-Philippe-de-La Prairie', 'Saint-Philippe-de-La Prairie', '', 45.3572300, -73.4770600, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10203, 'Saint-Pie', 'Saint-Pie', '', 45.5027700, -72.9089000, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10204, 'Saint-Pie-V', 'Saint-Pie-V', '', 46.0035100, -72.7468900, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10205, 'Saint-Pierre-les-Becquets', 'Saint-Pierre-les-Becquets', '', 46.5000500, -72.1991000, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10206, 'Saint-Polycarpe', 'Saint-Polycarpe', '', 45.3000900, -74.2992400, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10207, 'Saint-Raymond', 'Saint-Raymond', 'Saint-Raymond de Portneuf', 45.4669800, -73.6094800, 'CA', '2013-07-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10208, 'Saint-Rémi', 'Saint-Remi', '', 45.2667800, -73.6158800, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10209, 'Saint-Rémi-de-Tingwick', 'Saint-Remi-de-Tingwick', '', 45.8667700, -71.8158100, 'CA', '2016-07-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10210, 'Saint-Sauveur', 'Saint-Sauveur', '', 45.8868600, -74.1794300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10211, 'Saint-Thomas', 'Saint-Thomas', 'Saint-Thomas', 46.0167700, -73.3491500, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10212, 'Saint-Tite', 'Saint-Tite', 'Saint-Tite,Sen Tit,sn-tyt  kbk,Сен Тит,سن-تیت، کبک', 46.7333600, -72.5658100, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10213, 'Saint-Zotique', 'Saint-Zotique', 'Saint-Zotique', 45.2500900, -74.2492400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10214, 'Salaberry-de-Valleyfield', 'Salaberry-de-Valleyfield', 'Salaberi de Valefeld,Salaberri-de-Vallifild,Salaberry-de-Valleyfield,salabry-dw-wlyfyld,salbyry dy falyfyld,Салабери де Валефелд,Салаберри-де-Валлифилд,سالابری-دو-ولیفیلد,سالبيري دي فاليفيلد', 45.2500800, -74.1325300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10215, 'Salisbury', 'Salisbury', '', 46.0390500, -65.0462800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10216, 'Salmo', 'Salmo', '', 49.1998600, -117.2689000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10217, 'Salmon Arm', 'Salmon Arm', 'Sehlmon-Arm,YSN,Сэлмон-Арм', 50.6998000, -119.3023700, 'CA', '2008-05-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10218, 'Sarnia', 'Sarnia', 'Gorad Sarnija,Sarnia,Sarnija,YZR,carniya,sa ni ya shi,sania,sarnya,Горад Сарнія,Сарния,Сарнија,Сарнія,سارنيا,سارنیا,سارنیہ,சார்னியா,サーニア,薩尼亞市,사니아', 42.9786600, -82.4040700, 'CA', '2014-11-30', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10219, 'Saskatoon', 'Saskatoon', 'Gorad Saskatun,Saskatoon,Saskatoun,Saskatun,Saskatuna,Saskatunas,Saskatuno,Saskatūna,Saskatūnas,YXE,caskatun,sa si ka tong,saeseukeotun,saskatuna,saskatwn,sasukato~un,ssqtwn,Σασκατούν,Горад Саскатун,Саскатун,Սասկատուն,ססקטון,ساسكاتون,ساسکاتون,ساسکاٹون,सास्काटून,சாஸ்கடூன்,სასკატუნი,サスカトゥーン,萨斯卡通,새스커툰', 52.1323800, -106.6689200, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10220, 'Sault Ste. Marie', 'Sault Ste. Marie', 'Sault Sainte Marie,Sault Ste. Marie,Sault-Sainte-Marie,Su Sent Mari,Su-Sent-Mari,YAM,su sent ma ri,su sheng ma li,suseinteumali,susentomari,sw saynt mary,Су Сент Мари,Су-Сент-Мари,Су-Сент-Марі,سالٹ سٹی ماری,سو ساينت ماري,سو سنت‌ماری,سو سینت ماری، انٹاریو,ซูเซนต์มารี,სუ-სენტ-მარი,スーセントマリー,蘇聖瑪麗,수세인트마리', 46.5167700, -84.3332500, 'CA', '2013-11-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10221, 'Sechelt', 'Sechelt', 'YHS', 49.4751200, -123.7590300, 'CA', '2013-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10222, 'Selkirk', 'Selkirk', 'Selkirk,slkrk,Селкирк,Селкірк,سل کرک، مینی ٹوبا,سلکرک', 50.1436000, -96.8845200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10223, 'Senneterre', 'Senneterre', 'Senneterre,XFK', 48.3930200, -77.2395100, 'CA', '2015-08-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10224, 'Sept-Îles', 'Sept-Iles', 'Sept-Iles,Sept-Îles,Set Il,Set-Il'',YZV,sat ayl,st-ayl  kbk,Сет Ил,Сет-Іль,Сет-Иль,سات إيل,ست-ایل، کبک', 50.2001100, -66.3820800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10225, 'Sexsmith', 'Sexsmith', 'Seksmit,Сексмит', 55.3499800, -118.7860200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10226, 'Shaunavon', 'Shaunavon', '', 49.6500500, -108.4181000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10227, 'Shawinigan', 'Shawinigan', 'Shavinigan,Shawinigan,XFL,shau~inigan,shawynygan,shawynyghan,Шавиниган,شاوينيغان,شاوینیگان,シャウィニガン', 46.5667500, -72.7491300, 'CA', '2016-11-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10228, 'Shawville', 'Shawville', '', 45.6001100, -76.4827000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10229, 'Shediac', 'Shediac', 'Shed''jak,Shediac,Shédiac,Шедьяк', 46.2198100, -64.5410700, 'CA', '2008-07-25', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10230, 'Shelburne', 'Shelburne', 'shlbrn  nwa askwshya,شلبرن، نوا اسکوشیا', 43.7632500, -65.3235500, 'CA', '2014-12-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10231, 'Shelburne', 'Shelburne', 'Shelbern,Шелберн', 44.0787000, -80.2040800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10232, 'Shellbrook', 'Shellbrook', '', 53.2167900, -106.4010900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10233, 'Sherbrooke', 'Sherbrooke', 'Gorad Shehrbruk,Serbrukas,Sherbrooke,Sherbruk,YSC,she bu lu,she bu lu ke,sheruburukku,shrbrwk,shyrbrwk,syeleubeulukeu,Šerbrukas,Горад Шэрбрук,Шербрук,شربروک,شيربروك,شیربروک,შერბრუკი,シェルブルック,舍布碌,舍布魯克,셰르브루크', 45.4000800, -71.8990800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10234, 'Sherwood Park', 'Sherwood Park', 'Shervud Park,Шервуд Парк', 53.5168400, -113.3187000, 'CA', '2007-02-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10235, 'Sicamous', 'Sicamous', '', 50.8331200, -118.9856500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10236, 'Slave Lake', 'Slave Lake', 'Slave Lake,Slejv Lejk,YZH,Слејв Лејк', 55.2834400, -114.7689600, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10237, 'Smithers', 'Smithers', 'Smithers,YYD,smydhrz,سميذرز', 54.7803600, -127.1742800, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10238, 'Smiths Falls', 'Smiths Falls', 'Smiths Falls,YSH', 44.9045200, -76.0233300, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10239, 'Smoky Lake', 'Smoky Lake', '', 54.1168700, -112.4686300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10240, 'Sooke', 'Sooke', '', 48.3746300, -123.7276200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10241, 'Sorel-Tracy', 'Sorel-Tracy', 'Sorel,Sorel Trasi,Sorel''-Trasi,Sorel''-Trehsi,Sorel''-Trejsi,swrl-trasy,swryl-trysy,Сорел Траси,Сорель-Трасі,Сорель-Трейси,Сорель-Трэси,سورل-تراسی,سوريل-تريسي', 46.0333600, -73.1158500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10242, 'Souris', 'Souris', 'Suris,Сурис', 46.3501000, -62.2486200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10243, 'Souris', 'Souris', '', 49.6172000, -100.2612000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10244, 'South Huron', 'South Huron', '', 43.3167900, -81.5164700, 'CA', '2013-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10245, 'South River', 'South River', '', 45.8334000, -79.3829300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10246, 'Sparwood', 'Sparwood', '', 49.7333200, -114.8853200, 'CA', '2012-08-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10247, 'Spirit River', 'Spirit River', '', 55.7832700, -118.8360700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10248, 'Springhill', 'Springhill', '', 45.6501500, -64.0487300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10249, 'Spruce Grove', 'Spruce Grove', 'Spras Grouvas,Sprus Grouv,Sprus-Grouv,Spryus-Qruv,asprws grww,sbrws ghrwwf,si pu lu si ge luo fu,sprws grww,Спрус Гроув,Спрус-Гроув,اسپروس گروو,سبروس غرووف,سپروس گروو,斯普鲁斯格罗夫', 53.5334400, -113.9187400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10250, 'St. Albert', 'St. Albert', 'Saint Albert,Saint-Albert,Sen Alberas,Sent Albert,sant albrt,seinteuaelbeoteu,sheng ai bo te,snt albrt,Сент Алберт,سانت ألبرت,سنت آلبرت,سینٹ البرٹ,سینٹ البرٹ، البرٹا,სენტ-ალბერტი,圣艾伯特,세인트앨버트', 53.6334400, -113.6353300, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10251, 'St. Catharines', 'St. Catharines', 'Gorad Sent-Kataryns,Saint Catharines,Sankta Katarino,Sent Katerinsas,Sent Ketrins,Sent-Katarins,Sent-Keterins,St. Catharines,YCM,sant kathrynz,seinteukaeseolinseu,sentokyasarinzu,sheng kai se lin si,snt katrynz  antaryw,Горад Сент-Катарынс,Сент Кетринс,Сент-Катаринс,Сент-Кетерінс,Սենթ Քաթարինս,سانت كاثرينز,سنت کاترینز، انتاریو,سینٹ کیتھرائنز,เซนต์แคเทอรีนส์,სენტ-კატარინსი,セントキャサリンズ,圣凯瑟琳斯,세인트캐서린스', 43.1712600, -79.2426700, 'CA', '2015-06-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10252, 'Steinbach', 'Steinbach', 'Stajnbak,Stajnbek,si tan ba ke,Стайнбак,Стайнбек,Стајнбак,سٹین بیچ، مانیٹوبا,سٹینباخ,斯坦巴克', 49.5257900, -96.6845100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10253, 'Stephenville', 'Stephenville', 'YJT', 48.5500100, -58.5818000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10254, 'Stephenville Crossing', 'Stephenville Crossing', '', 48.5000100, -58.4318000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10255, 'Stettler', 'Stettler', 'Stetler,Стетлер', 52.3168300, -112.7186100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10256, 'Stonewall', 'Stonewall', 'Stounvol,Стоунвол', 50.1344100, -97.3267600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10257, 'Stony Plain', 'Stony Plain', 'Stoni Plejn,si tuo ni pu lai en,Стони Плејн,斯托尼普莱恩', 53.5334300, -114.0020500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10258, 'Stratford', 'Stratford', 'Stratford,Stretford,astratfwrd  antaryw,seuteulaespeodeu,si te la te fu,startfwrd,sutoratofodo,Стратфорд,Стретфорд,استراتفورد، انتاریو,ستارتفورد,سٹارٹ فورڈ,ストラトフォード,斯特拉特福,스트랫퍼드', 43.3667900, -80.9497200, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10259, 'Strathmore', 'Strathmore', 'Stratmor,Стратмор', 51.0501100, -113.3852300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10260, 'St. Thomas', 'St. Thomas', 'Saint Thomas,Sent Tomas,St. Thomas,YQS,sant twmas,sentotomasu,sheng tang ma shi,snt twmas  antaryw,Сент Томас,سانت توماس,سنت توماس، انتاریو,سینٹ تھامس,سینٹ تھامس، اونٹاریو,セントトーマス,聖湯瑪士', 42.7736100, -81.1803800, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10261, 'Summerland', 'Summerland', '', 49.5997700, -119.6691100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10262, 'Summerside', 'Summerside', 'Samersajd,Summerside,YSU,sa mo sai de,samrsayd,Самерсајд,سامرساید,萨默赛德', 46.3959300, -63.7876200, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10263, 'Sundre', 'Sundre', '', 51.8001000, -114.6353200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10264, 'Surrey', 'Surrey', 'Sari,Suri,Surrej,sare,seoli,su li,swry,swry  kwlwmbya albrytanyt,Сари,Суррей,Съри,סארי,سوري، كولومبيا البريطانية,سوری,サレー,素里,서리', 49.1063500, -122.8250900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10265, 'Sussex', 'Sussex', '', 45.7226600, -65.5066300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10266, 'Sutton', 'Sutton', 'Sutton', 45.1000800, -72.6158200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10267, 'Swan Hills', 'Swan Hills', '', 54.7168100, -115.4022600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10268, 'Swan River', 'Swan River', 'Svon River,ZJN,tian e he,Свон Ривер,天鹅河', 52.1058000, -101.2675900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10269, 'Swift Current', 'Swift Current', 'Svift Karent,Svift-Kerrent,Swift Current,YYN,si wei fu te ka lun te,swyft kwrnt,Свифт Карент,Свіфт-Керрент,سويفت كورنت,斯威夫特卡伦特', 50.2833700, -107.8013500, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10270, 'Sylvan Lake', 'Sylvan Lake', 'Silvan Lejk,Силван Лејк', 52.3168100, -114.0853000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10271, 'Taber', 'Taber', 'Tejber,Тејбер', 49.7870300, -112.1460300, 'CA', '2012-07-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10272, 'Témiscaming', 'Temiscaming', 'Temiskaming,tmyskamng  kbk,Темискаминг,تمیسکامنگ، کبک', 46.7212200, -79.0971200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10273, 'Temiskaming Shores', 'Temiskaming Shores', 'New Liskeard,Temiskaming Shors,di mi si ka ming hu an shi,timisukamingushoazu,tymyskymynj shwrz,Темискаминг Шорс,تيميسكيمينج شورز,ٹیمسکامنگ شورز,ティミスカミングショアーズ,蒂米斯卡明湖岸市', 47.4937600, -79.7152900, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10274, 'Terrace', 'Terrace', 'Teras,YXT,tyras,Терас,تيراس,ٹیریس، برٹش کولمبیا', 54.5163400, -128.6034500, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10275, 'Terrebonne', 'Terrebonne', 'Terbon,trbwn  kbk,tyrbwn,Тербон,تربون، کبک,تيربون', 45.7000400, -73.6473200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10276, 'The Pas', 'The Pas', 'De Pa,De-Pa,Le Pas,The Pas,YQD,Де Па,Де-Па,دی پاس، مینی ٹوبا', 53.8250900, -101.2541300, 'CA', '2013-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10277, 'Thessalon', 'Thessalon', '', 46.2500600, -83.5666000, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10278, 'Thompson', 'Thompson', 'Thompson,Tompson,YTH,tang pu sen,twmbswn,Томпсон,تومبسون,تھامپسن، مینی ٹوبا,تھومپسن,汤普森', 55.7435000, -97.8557900, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10279, 'Thorold', 'Thorold', 'Torold,sororudo,thwrwld,Торолд,تھورولڈ,ثورولد,ソロルド', 43.1168200, -79.1995800, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10280, 'Three Hills', 'Three Hills', '', 51.7001200, -113.2686300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10281, 'Thunder Bay', 'Thunder Bay', 'Tander Bej,Tander Bejus,Tander Bėjus,Tander-Bej,Thunder Bay,Tundurbej,YQT,sandabei,sang de bei,seondeobei,thandr bay,thandr by,Тандер Беј,Тандер-Бей,Тъндърбей,תאנדר ביי,تھنڈر بے,تھنڈربے، انٹاریو,ثاندر باي,ثاندر بی,തണ്ടർ ബേ,サンダーベイ,桑德贝,선더베이', 48.3820200, -89.2501800, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10282, 'Thurso', 'Thurso', '', 45.6001000, -75.2493100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10283, 'Timmins', 'Timmins', 'Timins,Timmins,YTS,di ming si,timinseu,timinzu,tymyns,tymyns  antaryw,tymynz,Тиминс,Тіммінс,טימינס,تيمينز,تیمینس، انتاریو,ٹیمنز,ティミンズ,蒂明斯,티민스', 48.4668600, -81.3331200, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10284, 'Tisdale', 'Tisdale', 'YTT', 52.8500200, -104.0509600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10285, 'Tobermory', 'Tobermory', '', 45.2500700, -81.6664700, 'CA', '2012-01-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10286, 'Tofield', 'Tofield', '', 53.3668400, -112.6686200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10287, 'Torbay', 'Torbay', '', 47.6665900, -52.7313500, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10288, 'Toronto', 'Toronto', 'Gorad Taronta,Torontas,Toronto,Torontu,Torontum,Torontó,YTO,duo lun duo,roranro,taronto,teareantea,tho rxn to,tolonto,toramto,toranto,toronto,twrntw,twrwntw,Τορόντο,Горад Таронта,Торонто,Տորոնտո,טאראנטא,טורונטו,تورنتو,تورونتو,ٹورانٹو,ٹورنٹو,टोरण्टो,टोरन्टो,टोराँटो,तोरन्तो,টরোন্টো,ਟੋਰਾਂਟੋ,ரொறன்ரோ,టొరంటో,ಟೊರಾಂಟೋ,ടോറോണ്ടോ,โทรอนโต,တိုရွန်တိုမြို့,ტორონტო,トロント,多伦多,多倫多,토론토', 43.7001100, -79.4163000, 'CA', '2015-04-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10289, 'Trail', 'Trail', 'Trejl,YZZ,trayl,Трејл,ترايل,ٹریل، برٹش کولمبیا', 49.0998300, -117.7022300, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10290, 'Trois-Rivières', 'Trois-Rivieres', 'Gorad Trua-Ryuer,Troa Rivier,Troa Rivjer,Trois-Rivieres,Trois-Rivières,Trua Rivjeras,Trua-Riv''er,Trua-River,Urbs Trifluvianensis,YRQ,san he shi,teulualibieleu,torowaribieru,torowarivu~ieru,trw-rywyayr,trwa ryfyyr,trwa rywyr,Горад Труа-Рыўер,Троа Ривиер,Троа Ривјер,Труа-Ривьер,Труа-Рівєр,ترو-ریویائر,تروا ريفيير,تروا ریویر,トロワリビエール,トロワリヴィエール,三河市,트루아리비에르', 46.3451500, -72.5477000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10291, 'Truro', 'Truro', 'Truro,XLZ,trwrw  nwa askwshya,Труро,ترورو، نوا اسکوشیا', 45.3668500, -63.2653800, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10292, 'Tumbler Ridge', 'Tumbler Ridge', 'TUX,Tumbler Ridge', 55.1302700, -120.9941500, 'CA', '2017-03-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10293, 'Two Hills', 'Two Hills', '', 53.7168600, -111.7518100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10294, 'Ucluelet', 'Ucluelet', 'Gioukloulet,Juklulet,you ke lu li te,ywklwlt,Γιούκλουλετ,Юклулет,اکلویلیٹ,یوکلولت,尤克盧利特', 48.9415300, -125.5463500, 'CA', '2013-09-14', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10295, 'Unity', 'Unity', '', 52.4501400, -109.1681600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10296, 'Uxbridge', 'Uxbridge', 'Uksbridzh,ywksbrydj,Уксбридж,يوكسبريدج', 44.1001200, -79.1162800, 'CA', '2015-01-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10297, 'Valcourt', 'Valcourt', 'Valcourt,Valkur,walkwr  kbk,Валкур,والکور، کبک', 45.5000800, -72.3158100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10298, 'Val-David', 'Val-David', 'Val-David', 46.0333800, -74.2159200, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10299, 'Val-des-Monts', 'Val-des-Monts', '', 45.6501000, -75.6660400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10300, 'Val-d''Or', 'Val-d''Or', 'Val d''Or,Val''-d''Or,Val-d''Or,Val-d’Or,YVO,fal dwr  kybk,wal-dwr,Вал д''Ор,Валь-д''Ор,فال دور، كيبك,وال-دور', 48.0974000, -77.7973700, 'CA', '2015-09-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10301, 'Valleyview', 'Valleyview', 'Valivju,falyfyw,Валивју,فاليفيو,ولی‌ویو، آلبرتا', 55.0667300, -117.2858500, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10302, 'Val-Morin', 'Val-Morin', 'Val-Morin', 46.0000800, -74.1825100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10303, 'Vancouver', 'Vancouver', 'Ban''kouber,Fankuver,Fankûver,Gorad Vankuver,Vancouver,Vancover,Vancuverium,Vancôver,Vanguve,Vangúve,Vankuver,Vankuvera,Vankuveris,Vankuvero,Vankuvur,Vankūvera,Venkuver,Venkûver,Wankuwer,Wankuwér,YVR,baenkubeo,bankuba,bankuba shi,bhyanakubhara,fankwfr,vainakuvara,vainkuvara,vankuvar,vhamkuvhara,wen ge hua,wnkwwr,wnkwwr  brytysh klmbya,wnqwbr,wynkwwr,Βανκούβερ,Ванкувер,Ванкувър,Горад Ванкувер,Վանկուվեր,ונקובר,فانكوفر,ونکوور,ونکوور، بریتیش کلمبیا,وینکوور,वैंकूवर,व्हँकूव्हर,ভ্যানকুভার,ਵੈਨਕੂਵਰ,வான்கூவர்,แวนคูเวอร์,ཝན་ཁུ་ཝེར།,ဗန်ကူးဗားမြို့,ვანკუვერი,ቫንኩቨር,バンクーバー,バンクーバー市,溫哥華,밴쿠버', 49.2496600, -123.1193400, 'CA', '2016-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10304, 'Vanderhoof', 'Vanderhoof', 'Vanderkhuf,fan de hu fu,fandrhwf,wndrhwf  brytysh klmbya,Вандерхуф,فاندرهوف,وندرهوف، بریتیش کلمبیا,范德胡夫', 54.0165700, -124.0198200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10305, 'Varennes', 'Varennes', 'Varen,Varennes,warn  kbk,Варен,وارن، کبک', 45.6833800, -73.4324600, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10306, 'Vaudreuil-Dorion', 'Vaudreuil-Dorion', 'Vodrej Dorion,Vodrej-Dorion,fwdrwydwrywn,wwdrwy-dwrywn,Водрей-Доріон,Водреј Дорион,فودرويدوريون,وودروی-دوریون', 45.4000800, -74.0325100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10307, 'Vaughan', 'Vaughan', 'Von,bon,fawjan,vu~on,wan,wang shi,Вон,فاوجان,وان,وان، انٹاریو,واگھن,ヴォーン,旺市,본', 43.8361000, -79.4982700, 'CA', '2011-12-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10308, 'Vegreville', 'Vegreville', 'Vegrevil,Vegrevil'',Vegrevill,wgrwyl  albrta,Вегревил,Вегревилл,Веґревіль,وگرویل، آلبرتا', 53.5001500, -112.0518200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10309, 'Venise-en-Québec', 'Venise-en-Quebec', 'Venise-en-Quebec,Venise-en-Québec', 45.0833800, -73.1324500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10310, 'Verchères', 'Vercheres', 'wrshr  kbk,ورشر، کبک', 45.7833800, -73.3491600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10311, 'Vermilion', 'Vermilion', 'Vermilion,YVG,wrmylywn  albrta,Вермилион,ورمیلیون، آلبرتا', 53.3540900, -110.8584900, 'CA', '2013-08-25', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10312, 'Vernon', 'Vernon', 'Vernon,YVE,fu nong,fyrnwn,wrnn  brytysh klmbya,wrnn  brٹsh kwlmbya,Вернон,فيرنون,ورنن، برٹش کولمبیا,ورنن، بریتیش کلمبیا,弗农', 50.2672900, -119.2733700, 'CA', '2015-01-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10313, 'Victoria', 'Victoria', 'Victoria,Victòria,Viktori,Viktoria,Viktoria Vretanikis Kolomvias,Viktorija,Viktorio,Viktoriya,Wiktoriye,YYJ,bigtolia,bikutoria,fktwrya,vhiktoriya,vikatori''a,viktoriya,vu~ikutoria,wei duo li ya,wiktxreiy,wyktwrya  brytysh klmbya,wyqtwryh,Βικτώρια Βρετανικής Κολομβίας,Виктори,Виктория,Викторија,Вікторія,Վիկտորիա,ויקטוריה,فكتوريا,وکٹوریا,وکٹوریا، برٹش کولمبیا,ویکتوریا، بریتیش کلمبیا,व्हिक्टोरिया,ਵਿਕਟੋਰੀਆ,விக்டோரியா,วิกตอเรีย,ვიქტორია,ビクトリア,ヴィクトリア,維多利亞,빅토리아', 48.4329400, -123.3693000, 'CA', '2015-06-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10314, 'Victoriaville', 'Victoriaville', 'Victoriaville,Viktoriavill,Viktorijavil,Viktorijavil'',bikutoriabiru,fyktwrya fyl,wyktwryawyl,Викториавилл,Викторијавил,Вікторіявіль,فيكتوريا فيل,ویکتوریاویل,ビクトリアビル', 46.0500700, -71.9657900, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10315, 'Viking', 'Viking', 'Vajking,Вајкинг', 53.1001400, -111.7684400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10316, 'Ville-Marie', 'Ville-Marie', '', 47.3334500, -79.4329700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10317, 'Virden', 'Virden', 'Verden,Верден,ورڈن، مینی ٹوبا', 49.8508000, -100.9326200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10318, 'Vulcan', 'Vulcan', 'Valkan,Валкан', 50.4000800, -113.2518900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10319, 'Wabana', 'Wabana', '', 47.6331900, -52.9480600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10320, 'Wadena', 'Wadena', '', 51.9499900, -103.8010200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10321, 'Wainwright', 'Wainwright', 'Vejnrajt,Wainwright,Вејнрајт', 52.8348200, -110.8534200, 'CA', '2016-12-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10322, 'Wakefield', 'Wakefield', '', 45.6668000, -75.8326500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10323, 'Walpole Island', 'Walpole Island', '', 42.6152000, -82.5139800, 'CA', '2014-11-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10324, 'Warman', 'Warman', 'Vorman,Ворман', 52.3167900, -106.5679100, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10325, 'Warwick', 'Warwick', '', 45.9500700, -71.9824000, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10326, 'Wasaga Beach', 'Wasaga Beach', 'Wasaga,Wasaga Beach', 44.5168000, -80.0163700, 'CA', '2010-03-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10327, 'Waswanipi', 'Waswanipi', 'Waswanipi', 49.7334600, -76.1660400, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10328, 'Waterloo', 'Waterloo', 'Vaterloo,Ватерлоо', 45.3500800, -72.5158200, 'CA', '2016-02-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10329, 'Waterloo', 'Waterloo', 'Uoterlu,Vaterloo,Voterlu,hua tie lu,u~otaru,watrlw,watrlw  antaryw,woteollu,Ватерлоо,Вотерлу,Уотерлу,واترلو,واترلو، انتاریو,واٹرلو، انٹاریو,ウォータールー,滑鐵盧,워털루', 43.4668000, -80.5163900, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10330, 'Watrous', 'Watrous', '', 51.6667700, -105.4678800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10331, 'Watson Lake', 'Watson Lake', 'Uotson-Lejk,Watson Lake,YQH,Уотсон-Лейк', 60.0634900, -128.7089300, 'CA', '2016-05-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10332, 'Welland', 'Welland', 'Veland,Velland,u~erando,wei lan,wellaendeu,wlnd  antaryw,wyland,Веланд,Велланд,ولند، انتاریو,ويلاند,ویلینڈ,ウェランド,威蘭,웰랜드', 42.9834200, -79.2495800, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10333, 'Wembley', 'Wembley', '', 55.1499500, -119.1360200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10334, 'West End', 'West End', '', 49.2833300, -123.1333300, 'CA', '2013-09-09', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10335, 'Westlock', 'Westlock', '', 54.1501600, -113.8687600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10336, 'Westmount', 'Westmount', 'Uehstmaunt,Uestmaunt,Vestmaunt,uesutomaunto,wstmwnt  kbk,wysmawnt,Вестмаунт,Уестмаунт,Уэстмаунт,وستمونت، کبک,ويسماونت,ウエストマウント', 45.4834100, -73.5991800, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10337, 'Wetaskiwin', 'Wetaskiwin', 'Vetaskisin,Vetaskivin,Vetaskivinas,Vetaskişin,wei ta si ji wen,wetaseukiwin,wtaskwyn,wtaskywyn,Ветаскивин,وتاسكوين,وتاسکیوین,ویٹاسکیون,韦塔斯基温,웨타스키윈', 52.9668300, -113.3686900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10338, 'Weyburn', 'Weyburn', 'Vejbern,wybrn,Вейберн,Вејберн,ويبرن', 49.6667500, -103.8510900, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10339, 'Whistler', 'Whistler', 'Uislur,Uistler,Visler,Vistler,Vistlera,Vistleris,Whistler,Whistler Village,Whistler i British Columbia,YWS,hwiseulleo,u~isura,wei shi na,wyslr  kwlwmbya albrytanyt,Вислер,Вістлер,Уислър,Уистлер,ويسلر، كولومبيا البريطانية,ウィスラー,威士拿,휘슬러', 50.1164000, -122.9694600, 'CA', '2015-05-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10340, 'White City', 'White City', '', 50.4333800, -104.3677800, 'CA', '2006-01-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10341, 'Whitecourt', 'Whitecourt', 'Vajtkort,YZU,Вајткорт', 54.1501500, -115.6854800, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10342, 'Whitehorse', 'Whitehorse', 'Equus Albus,Gorad Uajtkhors,Gouaitchors,Uaithors,Uajtkhors,Vaithorsas,Vajtkhors,Vaythors,Whitehorse,YXY,bai ma shi,howaitohosu,hwaiteuhoseu,vait''hars,wayt hwrs,wayٹ ہars  ywkwn,wyythwrs,Γουάιτχορς,Вайтхорс,Вајтхорс,Горад Уайтхорс,Уайтхорс,וייטהורס,وائٹ ہارس، یوکون,وايت هورس,وایت‌هورس، یوکان,வைட்ஹார்ஸ்,უაიტჰორსი,ホワイトホース,白馬市,화이트호스', 60.7161100, -135.0537500, 'CA', '2010-07-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10343, 'White Rock', 'White Rock', 'Vajt Rok,White Rock,bai shi,howaitorokku,hwaiteulog,wayt rak   brytysh klmbya,wayt rwk,Вајт Рок,وائٹ راک,وائٹ راک، برٹش کولمبیا,وايت روك,وایت راک ، بریتیش کلمبیا,ホワイトロック,白石,화이트록', 49.0163600, -122.8026000, 'CA', '2013-08-28', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10344, 'Wilkie', 'Wilkie', '', 52.4168300, -108.7014200, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10345, 'Williams Lake', 'Williams Lake', 'Columetza,Vilijams Lejk,Williams,Williams Lake,YWL,wei lian mu si hu,wlymzlyk,wylyamz lyk,Вилијамс Лејк,ولیمزلیک,ويليامز ليك,威廉姆斯湖', 52.1415300, -122.1445100, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10346, 'Windsor', 'Windsor', 'Uinsor,Vindzor,wyndswr. nwa askwshya,Виндзор,Уинсор,ویندسور٬ نوا اسکوشیا', 44.9834500, -64.1320400, 'CA', '2010-01-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10347, 'Windsor', 'Windsor', 'Vindzor,Виндзор', 45.5667800, -71.9990900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10348, 'Windsor', 'Windsor', 'Uindzur,Uinsor,Vindzor,Vindzoras,Windsor,YQG,u''indasara,uindzori,uinza,u~inza,wen sha,winjeo,wndswr,wyndzwr,wynzr  antaryw,Виндзор,Віндзор,Уиндзър,Уинсор,וינדזור,وندسور,ونڈسر، انٹاریو,ونڈسور,وینزر، انتاریو,উইন্ডসর,უინძორი,ウィンザー,ウインザー,温莎,윈저', 42.3000800, -83.0165400, 'CA', '2012-05-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10349, 'Wingham', 'Wingham', 'wyngham  antaryw,وینگهام، انتاریو', 43.8879300, -81.3114500, 'CA', '2009-07-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10350, 'Winkler', 'Winkler', 'Uinkler,Vinkler,wnklr,Винклер,Вінклер,Уинклер,ونکلر,ونکلر، مینی ٹوبا', 49.1817000, -97.9410400, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10351, 'Winnipeg', 'Winnipeg', 'Gorad Vinipeg,Gouinipenk,Uinipeg,Uinnipeg,Vinipeg,Vinipega,Vinipegas,Vinipego,Vinnipeg,Vinnipega,Vinnipeq,WPG,Winnipeg,Winnipeg City,Winnipég,YWG,u~inipegu,vinipaiga,vinipega,vinippek,wen ni bo,win ni phek,winipeg,wny pyg,wnypg,wynybygh,wynypg,Γουίνιπεγκ,Винипег,Виннипег,Вінніпег,Вінніпеґ,Горад Вініпег,Уинипег,Уиннипег,Վիննիպեգ,ויניפג,ونی پیگ,ونیپگ,وينيبيغ,وینیپگ,विनिपेग,ਵਿਨੀਪੈਗ,வினிப்பெக்,วินนิเพก,ဝင်နီပက်မြို့,უინიპეგი,ᐄᐧᓂᐯᐠ,ウィニペグ,温尼伯,위니펙', 49.8844000, -97.1470400, 'CA', '2013-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10352, 'Wolfville', 'Wolfville', 'wlf wyl,ولف ویل', 45.0834500, -64.3654600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10353, 'Woodstock', 'Woodstock', 'Vudstok,hu shi tuo,uddosutokku,wwdstak  antaryw,wwdstwk,Вудсток,وودستاک، انتاریو,وودستوك,وڈسٹوک,ウッドストック,胡士托', 43.1333900, -80.7497000, 'CA', '2014-10-29', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10354, 'Wynyard', 'Wynyard', '', 51.7667400, -104.1843600, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10355, 'Yamachiche', 'Yamachiche', 'yamashysh  kbk,یاماشیش، کبک,یاماچچے ، کیوبک', 46.2667600, -72.8324300, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10356, 'Yarmouth', 'Yarmouth', 'Jarmut,YQI,Yarmouth,yameoseu,yarmwt,Ярмут,یارموت,یارموتھ، نوا سکوٹیا,야머스', 43.8334500, -66.1155700, 'CA', '2008-04-11', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10357, 'Yellowknife', 'Yellowknife', 'Cultellus Flavus,Ellounajf,Geloounaif,Gorad Elaunajf,Jehllounajf,Jellounajf,Jelounaifa,Jelounaifas,Jelounajf,YZF,Yellounayf,Yellowknife,huang dao zhen,ielounaipi,ieronaifu,ye luo na fu,yellonaipeu,yelonaihp,ylwknyfے,ylwnayf,ylwnyyp,Γελοουνάιφ,Єллоунайф,Јелоунајф,Горад Елаўнайф,Йеллоунайф,Йелоунайф,Йэллоунайф,ילונייף,يلونايف,یلونایف,یلوکنیفے,யெலோனைஃப்,იელოუნაიფი,イエローナイフ,耶罗纳夫,黃刀鎮,옐로나이프', 62.4541100, -114.3724800, 'CA', '2016-04-02', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10358, 'Yorkton', 'Yorkton', 'Jorkton,YQV,Yorkton,yue ke dun,ywrktn,ywrktwn,Јорктон,Йорктон,يوركتن,یورکتون,约克顿', 51.2167000, -102.4676600, 'CA', '2013-10-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10359, 'Beauceville', 'Beauceville', 'Bosvil,CWHV,bwsfyl,bwswyl  kbk,Босвил,بوسفيل,بوسویل، کبک,بیوسولے', 46.2178500, -70.7787300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10360, 'Halifax', 'Halifax', 'Galifaks,Halifax,YHZ,Галифакс', 44.6453300, -63.5723900, 'CA', '2014-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10361, 'St. John''s', 'St. John''s', 'Agios Ioannis Neas Gis,Baile Naoimh Eoin,Baile Naoimh Eòin,Baile Sheain,Baile Sheáin,Gorad Sent-Dzhons,Saint John,Saint John''s,Saint-Jean,Saint-Jean de Terre-Neuve,San Juan de Terranova,Sanctus Ioannes Terrae Novae,Sejnt Dzhons,Sent DZons,Sent Dzonsas,Sent Džonsas,Sent-Dzhons,St Johns,St. John''s,St. John''s pa Newfoundland,St. John''s på Newfoundland,St. John’s,YYT,ceyint jans,sant jwnz,seinteujonseu,sentojonzu,sheng yue han si,snt g''wns,Άγιος Ιωάννης Νέας Γης,Горад Сент-Джонс,Сейнт Джонс,Сент Џонс,Сент-Джонс,סנט ג''ונס,سانت جونز,سینٹ جان,سینٹ جانز، نیوفنلینڈ اور لیبراڈار,செயின்ட் ஜான்ஸ்,სენტ-ჯონზი,セントジョンズ,聖約翰斯,세인트존스', 47.5649400, -52.7093100, 'CA', '2014-07-21', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10362, 'Beaupré', 'Beaupre', 'Beaupre,Beaupré', 47.0442800, -70.8952900, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10363, 'Château-Richer', 'Chateau-Richer', '', 46.9603100, -71.0321900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10364, 'Québec', 'Quebec', 'Altepetl Quebec,Bandaraya Quebec,Cathair Quebec,Cathair Québec,Ciutat de Quebec,Gorad Kvebek,Jiji la Quebec,Kebec Vile,Kebek,Kebeko,Kebeku,Kempek,Kevek tava,Kota Quebec,Kuehbehk,Kvebek,Kvebeka,Kvebekas,Kwebek,Kwebek Shehiri,Kwébék,Kwébék Shehiri,Kébéc Vile,Kévek táva,Lungsod ng Quebec,Lungsod ng Québec,Quebec,Quebec Ceety,Quebec City,Quebec Hiria,Quebec llaqta,Quebec-chhi,Quebec-su,Quebecborg,Quebecceaster,Quebecstad,Quebecum urbs,Québec,Québec-chhī,Québec-sṳ,Québecborg,Siudad ti Quebec,Tchubec,Thanh pho Quebec,Thành phố Québec,Vila de Quebec,Vila de Quebèc,Ville de Quebec,Ville de Québec,YQB,kbk,kebaika sahira,kh wibek,kiyupek nakaram,kui bei ke shi,kvebeka siti,kwebeg,kyubeka nagara,mdynt kybk,qwwybq syty,Κεμπέκ,Горад Квебек,Квебек,Куэбэк,Քվեբեկ,קוויבק סיטי,مدينة كيبك,کبک,کیوبک شہر,क्यूबेक नगर,क्वेबेक सिटी,ਕੇਬੈਕ ਸ਼ਹਿਰ,கியூபெக் நகரம்,ควิเบก,კვებეკი,ケベック・シティー,魁北克市,퀘벡', 46.8122800, -71.2145400, 'CA', '2014-11-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10365, 'L''Ange-Gardien', 'L''Ange-Gardien', 'L''Ange-Gardien', 46.9197600, -71.0825300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10366, 'Lévis', 'Levis', 'Levi,li wei,lwy  kbk,lyfys,lyws,revu~i,Леви,Леві,لوی، کبک,ليفيس,لیوس,レヴィ,利维', 46.8032600, -71.1779300, 'CA', '2015-09-04', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10367, 'Montmagny', 'Montmagny', 'Monmani,Montmagny,St. Thomas de Montmagny,mwnmayyny  kbk,mwntmaghny  kybk,Монмані,Монмањи,مونتماغني، كيبك,مونمایینی، کبک', 46.9804300, -70.5549300, 'CA', '2017-04-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10368, 'Neuville', 'Neuville', 'Nevil,nwwyl  kbk,nywfyl,Невил,نوویل، کبک,نيوفيل', 46.6982300, -71.5827500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10369, 'Portneuf', 'Portneuf', 'Pornef,Portneuf,bwrtnywf,pwrtnwf  kbk,Порнеф,بورتنيوف,پورتنوف، کبک', 46.6905800, -71.8901100, 'CA', '2016-04-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10370, 'Rimouski', 'Rimouski', 'Rimouski,Rimuski,YXK,rymwsky,Римуски,Рімускі,ريموسكي,ریموسکی,ᕆᒧᔅᑭ', 48.4487900, -68.5239600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10371, 'Rivière-du-Loup', 'Riviere-du-Loup', 'Riv''er-dju-Lu,River-dju-Lju,Riviere-du-Loup,Rivière-du-Loup,Rivjer di Lu,YRI,ryfry dw lwb,rywyyr-dw-lw,Ривьер-дю-Лу,Ривјер ди Лу,Рівєр-дю-Лю,ريفري دو لوب,ریوییر-دو-لو,ᑲᐱᑎᑌᒍᐁᔅ', 47.8269900, -69.5424300, 'CA', '2013-08-24', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10372, 'Sydney', 'Sydney', 'Baile Shidni,Sidni,Sydney,YQY,shidoni,sydny. nwa askwshya,Сидни,سیدنی٬ نوا اسکوشیا,シドニー', 46.1351000, -60.1831000, 'CA', '2016-04-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10373, 'Tofino', 'Tofino', 'Tofino,YAZ,tu fen nu,Τοφίνο,Тофино,吐芬奴', 49.1531400, -125.9074400, 'CA', '2014-09-21', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10374, 'L''Ancienne-Lorette', 'L''Ancienne-Lorette', '', 46.7939200, -71.3519100, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10375, 'Edmundston', 'Edmundston', 'Edmundston,Ehdmundston,ai de meng ci dun,edomonsuton,Едмундстон,Эдмундстон,اڈمنڈسٹن,エドモンストン,埃德蒙兹顿', 47.3737000, -68.3251200, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10376, 'St-Jean-Port-Joli', 'St-Jean-Port-Joli', 'Saint-Jean-Port-Joli', 47.2141800, -70.2696900, 'CA', '2017-04-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10377, 'Saint-Georges', 'Saint-Georges', 'Saint-Georges', 46.1135300, -70.6652600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10378, 'Sainte Catherine de la Jacques Cartier', 'Sainte Catherine de la Jacques Cartier', '', 46.8524400, -71.6205600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10379, 'Baie-Saint-Paul', 'Baie-Saint-Paul', 'Baie-Saint-Paul,Be Sen Pol,Be-Sen-Pol'',bay syn pal,bh-sn-pl  kbk,byh san bwl,Бе Сен Пол,Бе-Сен-Поль,بائ سین پال,به-سن-پل، کبک,بيه سان بول', 47.4410900, -70.4985800, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10380, 'Carleton-sur-Mer', 'Carleton-sur-Mer', 'Karlton sir Mer,karltwn swr myr,karltwn-swr-mr,Карлтон сир Мер,كارلتون سور مير,کارلتون-سور-مر,کارلیٹن سر مر', 48.1074900, -66.1280000, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10381, 'Cacouna', 'Cacouna', 'Cacouna,kakwna  kbk,کاکونا، کبک', 47.9165700, -69.5005400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10382, 'Campbellton', 'Campbellton', 'Kehmpbelton,kan bei er dun,Кэмпбелтон,کیمپبلٹن,坎贝尔顿', 48.0075100, -66.6727200, 'CA', '2010-09-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10383, 'Bathurst', 'Bathurst', 'Baterst,ZBF,ba se si te,basasuto,Батерст,باتھرسٹ,バサースト,巴瑟斯特', 47.6181400, -65.6511200, 'CA', '2013-07-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10384, 'Matane', 'Matane', 'Matan,Matane,YME,matan,matan  kybk,Матан,ماتان,ماتان، كيبك,ᒪᑕᓀ', 48.8285700, -67.5219700, 'CA', '2016-04-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10385, 'Paris', 'Paris', 'پیرس، انٹاریو', 43.2000000, -80.3833300, 'CA', '2009-06-25', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10386, 'Amqui', 'Amqui', 'Amkvi,Amqui,amky,aymkwy,Амкви,آمکی,أمكي,ایمکوئ,ᐊᒻᕿ', 48.4638200, -67.4313400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10387, 'Dawson City', 'Dawson City', 'Altepetl Dawson,Dawson,Dawson City,Douson,Douson-Siti,YDA,dao sen shi,doseunsiti,dwswn syty,Доусон,Доусон-Сіті,דוסון סיטי,ڈاوسن شہر,ドーソン・シティ,道森市,도슨시티', 64.0601300, -139.4332800, 'CA', '2016-04-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10388, 'Chandler', 'Chandler', 'Chandler,XDL', 48.3493500, -64.6792600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10389, 'Bonaventure', 'Bonaventure', 'Bonaventure,YVB', 48.0457300, -65.4925900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10390, 'New-Richmond', 'New-Richmond', '', 48.1605900, -65.8582300, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10391, 'Thetford-Mines', 'Thetford-Mines', 'Thetford-Mines', 46.0937100, -71.3053900, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10392, 'New Carlisle', 'New Carlisle', 'New Carlisle,XEL', 48.0095600, -65.3362100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10393, 'Cabano', 'Cabano', 'Cabano', 47.6806500, -68.8781000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10394, 'Sacré-Coeur', 'Sacre-Coeur', 'Sacre-Coeur,Sacré-Coeur', 48.2297000, -69.8006100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10395, 'Forestville', 'Forestville', 'Forestville,YFE', 48.7380800, -69.0847800, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10396, 'Mont-Joli', 'Mont-Joli', 'Mon Zholi,Mont-Joli,YYY,mwn-zhwly,mwnt jwly,Мон Жоли,مون-ژولی,مونت جولي', 48.5838800, -68.1921400, 'CA', '2013-08-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10397, 'Lillooet', 'Lillooet', '', 50.6856000, -121.9420000, 'CA', '2011-10-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10398, 'La Malbaie', 'La Malbaie', 'La Malbaie,La Malbe,YML,la malbh  kbk,lamalbay,malby,Ла Малбе,لا مالبه، کبک,لامالبائ,مالبي', 47.6540000, -70.1526800, 'CA', '2013-08-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10399, 'Sainte-Marie', 'Sainte-Marie', '', 46.4340100, -71.0116800, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10400, 'Plessisville', 'Plessisville', '', 46.2185600, -71.7620100, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10401, 'Maliotenam', 'Maliotenam', 'Maliotenam', 50.2111900, -66.1816400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10402, 'Scarborough', 'Scarborough', 'Skarboro,icukkarparo,seukabeoleo,shi jia bao,sukabaro,Скарборо,இசுக்கார்பரோ,スカーバロー,士嘉堡,스카버러', 43.7722300, -79.2566600, 'CA', '2015-01-31', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10403, 'Les Escoumins', 'Les Escoumins', 'Les Escoumins,lh askwmn  kbk,lys ayskwmyns,له اسکومن، کبک,ليس إيسكومينس', 48.3519100, -69.4072400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10404, 'Fossambault-sur-lac', 'Fossambault-sur-lac', '', 46.8766200, -71.6154100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10405, 'Cole Harbour', 'Cole Harbour', '', 44.6724400, -63.4750600, 'CA', '2010-03-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10406, 'Okanagan', 'Okanagan', 'Okanagan,Okanagan Country,Okanagan Valley,okanagan,オカナガン', 50.3638600, -119.3499700, 'CA', '2012-01-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10407, 'West Kelowna', 'West Kelowna', 'District of West Kelowna,West Kelowna,uesutokerouna,u~esutokerouna,xi ji long na,ویسٹ کیلونا,ウェストケロウナ,ウエストケロウナ,西基隆拿', 49.8625000, -119.5833300, 'CA', '2011-02-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10408, 'Tracadie-Sheila', 'Tracadie-Sheila', 'Tracadie–Sheila,Trakadi-Shajla,Тракади-Шайла', 47.5144400, -64.9180600, 'CA', '2010-06-13', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10409, 'Sydney Mines', 'Sydney Mines', '', 46.2366900, -60.2176700, 'CA', '2010-07-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10410, 'Jonquière', 'Jonquiere', 'Jonquiere,Jonquière,XJQ,Zhonk''er,Жонкьер', 48.4164800, -71.2488400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10411, 'Cap-Santé', 'Cap-Sante', '', 46.6715900, -71.7881200, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10412, 'Saint-Augustin-de-Desmaures', 'Saint-Augustin-de-Desmaures', 'Sent Ogisten de Demor,san awghwstn dy dymarws,sn-awgwstn-dw-dmwr  kbk,Сент Огистен де Демор,سان أوغوستن دي ديماروس,سن-اوگوستن-دو-دمور، کبک,سینٹ-اوگسٹن-دے-دسمرس', 46.7406400, -71.4513100, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10413, 'Donnacona', 'Donnacona', '', 46.6804200, -71.7239000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10414, 'La Pocatière', 'La Pocatiere', 'La Pocatiere,La Pocatière,La Pokatjer,Ste. Anne de la Pocatiere,Ste. Anne de la Pocatière,la bwkaryh,la pwkatyyr  kbk,Ла Покатјер,لا بوكاريه,لا پوکاتییر، کبک', 47.3673300, -70.0348400, 'CA', '2017-04-03', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10415, 'Saint-Joseph-de-Beauce', 'Saint-Joseph-de-Beauce', 'Sen Zhozef de Bos,sn-zhwzf-dw-bws  kbk,Сен Жозеф де Бос,سن-ژوزف-دو-بوس، کبک,سینٹ-جوسف-دے-بوکے، کیوبک', 46.3000000, -70.8666700, 'CA', '2010-09-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10416, 'Metabetchouan-Lac-a-la-Croix', 'Metabetchouan-Lac-a-la-Croix', 'Métabetchouan–Lac-à-la-Croix', 48.4100000, -71.7800000, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10417, 'Ladner', 'Ladner', '', 49.0893800, -123.0824100, 'CA', '2010-11-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10418, 'Walnut Grove', 'Walnut Grove', '', 49.1647300, -122.6404200, 'CA', '2011-02-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10419, 'Aldergrove', 'Aldergrove', '', 49.0580100, -122.4708700, 'CA', '2011-02-19', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10420, 'Saint-Léonard', 'Saint-Leonard', 'Saint Leonard,Saint-Leonard,Saint-Léonard,YSL,سینٹ-لیونارڈ، نیو برنسوک', 47.1631700, -67.9246000, 'CA', '2013-08-10', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10421, 'Harrison Brook', 'Harrison Brook', '', 47.2130400, -67.9284700, 'CA', '2011-03-21', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10422, 'Omemee', 'Omemee', '', 44.2989700, -78.5598900, 'CA', '2011-05-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10423, 'East York', 'East York', 'Ist Jork,Istochni Jork,isutoyoku,Ист Јорк,Источни Јорк,イーストヨーク', 43.6905300, -79.3279400, 'CA', '2016-07-06', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10424, 'Napanee Downtown', 'Napanee Downtown', '', 44.2483200, -76.9506900, 'CA', '2011-06-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10425, 'Skatepark', 'Skatepark', '', 44.2512200, -76.9442400, 'CA', '2011-06-20', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10426, 'Breakeyville', 'Breakeyville', '', 46.6803700, -71.2232700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10427, 'Saint-Antoine-de-Tilly', 'Saint-Antoine-de-Tilly', '', 46.6634600, -71.5733500, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10428, 'Ancaster', 'Ancaster', 'Ankaster,ankstr  antaryw,Анкастер,انکستر، انتاریو', 43.2180600, -79.9871600, 'CA', '2012-05-07', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10429, 'Shannon', 'Shannon', 'Shannon,YOY', 46.8802600, -71.5146400, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10430, 'Saint-Henri', 'Saint-Henri', 'Saint-Henri-de-Lauzon,Saint-Henri-de-Levis,Saint-Henri-de-Lévis', 46.6931400, -71.0692700, 'CA', '2013-07-15', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10431, 'Pohénégamook', 'Pohenegamook', '', 47.4631500, -69.2266600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10432, 'Pont-Rouge', 'Pont-Rouge', '', 46.7546800, -71.6956600, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10433, 'Princeville', 'Princeville', '', 46.1716300, -71.8746200, 'CA', '2016-02-23', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10434, 'West Vancouver', 'West Vancouver', 'Vancouver Barat,West Vancouver,West Vankuver,Zapaden Vankuvur,fankwfr alghrbyt,u~esutobankuba,weseuteubaenkubeo,wnkwwr ghrby,xi wen ge hua,Западен Ванкувър,فانكوفر الغربية,ونکوور غربی,ウェストバンクーバー,西溫哥華,웨스트밴쿠버', 49.3667200, -123.1665200, 'CA', '2013-06-05', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10435, 'Saint-Siméon', 'Saint-Simeon', 'Saint-Simeon,Saint-Siméon', 47.8443100, -69.8783700, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10436, 'Willowdale', 'Willowdale', 'Willowdale', 43.7667200, -79.3990900, 'CA', '2013-07-08', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10437, 'Florenceville-Bristol', 'Florenceville-Bristol', 'برسٹل، نیو برنزویک', 46.4435300, -67.6153600, 'CA', '2013-07-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10438, 'Saint-Pascal', 'Saint-Pascal', 'Saint-Pascal', 47.5181300, -69.8030100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10439, 'Vallée-Jonction', 'Vallee-Jonction', 'Vallee-Jonction,Vallée-Jonction,wlh-zhwnksywn  kbk,وله-ژونکسیون، کبک', 46.3744100, -70.9188100, 'CA', '2016-06-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10440, 'Saint-Antonin', 'Saint-Antonin', 'sn-antwnn  kbk,سن-آنتونن، کبک,سینٹ-انٹونیں ، کیوبک', 47.7607000, -69.4774500, 'CA', '2014-08-22', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10441, 'Lower Sackville', 'Lower Sackville', '', 44.7759900, -63.6786500, 'CA', '2016-10-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10442, 'le Plateau', 'le Plateau', '', 45.4351400, -75.7803000, 'CA', '2015-08-18', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10443, 'Rural Municipality of Yellowhead', 'Rural Municipality of Yellowhead', '', 50.4846000, -100.4826700, 'CA', '2016-05-17', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10444, 'Wild Rose', 'Wild Rose', '', 53.4708000, -113.3811900, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10445, 'Silver Berry', 'Silver Berry', '', 53.4578700, -113.3817000, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10446, 'Laurel', 'Laurel', '', 53.4466700, -113.3819700, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10447, 'Tamarack', 'Tamarack', '', 53.4644100, -113.3623500, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10448, 'Larkspur', 'Larkspur', '', 53.4794200, -113.3814200, 'CA', '2016-07-12', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10449, 'Hérouxville', 'Herouxville', 'Herouxville,Hérouxville', 46.6661700, -72.6251200, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10450, 'Saint-Norbert', 'Saint-Norbert', 'Saint-Norbert', 46.1694900, -73.3149400, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10451, 'Sainte-Élisabeth', 'Sainte-Elisabeth', 'Sainte-Elisabeth,Sainte-Élisabeth', 46.0950200, -73.3517600, 'CA', '2017-02-01', 41);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10452, 'West Island', 'West Island', '', -12.1568100, 96.8225100, 'CC', '2010-08-16', 48);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10453, 'Yangambi', 'Yangambi', 'YAN', 0.7675500, 24.4397300, 'CD', '2016-11-29', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10454, 'Watsa', 'Watsa', 'Watsa', 3.0371600, 29.5355100, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10455, 'Wamba', 'Wamba', 'Wamba', 2.1483800, 27.9946600, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10456, 'Uvira', 'Uvira', 'Uvinza,Uvira,Увира', -3.3953400, 29.1377900, 'CD', '2012-12-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10457, 'Tshikapa', 'Tshikapa', 'Chikapa,TSH,Tshikapa,qi ka pa,tshykaba,tsu~ikapa,Чикапа,تشيكابا,ツィカパ,奇卡帕', -6.4162100, 20.7999500, 'CD', '2016-11-28', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10458, 'Sake', 'Sake', 'Sake', -1.5738600, 29.0433900, 'CD', '2012-12-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10459, 'Mwene-Ditu', 'Mwene-Ditu', 'Mvene-Ditu,Mwene-Ditu,Мвене-Диту', -7.0090600, 23.4527800, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10460, 'Mweka', 'Mweka', 'MEW,Mueka,Mveka,Mweka,Мвека', -4.8518700, 21.5595000, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10461, 'Mbuji-Mayi', 'Mbuji-Mayi', 'Bakwanga,MJM,Mbuji-Mayi,Mbuy Mayi,Mbuzhi-Maji,Мбужи-Майи', -6.1360300, 23.5897900, 'CD', '2012-06-11', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10462, 'Lusambo', 'Lusambo', 'LBO,Lusambo,Luzambo,Лусамбо', -4.9750300, 23.4439100, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10463, 'Luebo', 'Luebo', 'Luebo', -5.3521800, 21.4219200, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10464, 'Lubao', 'Lubao', 'Lubao,Senteri,Sentery,Sentiry', -5.3877100, 25.7488500, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10465, 'Lodja', 'Lodja', 'LJA,Lodja,Lodzh,Loja,Лодж', -3.5210500, 23.6005000, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10466, 'Lisala', 'Lisala', 'LIQ,Lisala,Lisale,Lizala,Лисале', 2.1512700, 21.5167200, 'CD', '2012-05-31', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10467, 'Kongolo', 'Kongolo', 'KOO,Kangolo,Kongolo,Конголо', -5.3853200, 27.0002900, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10468, 'Kisangani', 'Kisangani', 'FKI,Kisan''nkani,Kisangani,Kisanganis,Kisangáni,Singitini,Stanleystad,Stanleyville,ji sang jia ni,kisang-gani,kisangani,Κισανγκάνι,Кисангани,Кісангані,Կիսանգանի,キサンガニ,基桑加尼,키상가니', 0.5152800, 25.1909900, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10469, 'Kindu', 'Kindu', 'KND,Kindu,Kindu-Port-Empain,Port de Kindu,Port-Empain,jin du,kindo~u,kindu,kndw,Кинду,Кінду,کندو,キンドゥ,金杜,킨두', -2.9437300, 25.9223700, 'CD', '2013-02-08', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10470, 'Kasongo', 'Kasongo', 'Kasongo,Kazongo,Tongoni,Tongoni Kapaya,Касонго', -4.4274100, 26.6665600, 'CD', '2012-04-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10471, 'Kananga', 'Kananga', 'KGA,Kananga,Kanange,Lulua,Luluabourg,Luluaburg,ka nan jia,kanang-ga,kananga,kanangha,Кананга,Կանանգա,كانانغا,カナンガ,卡南加,카낭가', -5.8962400, 22.4165900, 'CD', '2016-12-31', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10472, 'Kampene', 'Kampene', '', -3.5967800, 26.6671500, 'CD', '2012-12-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10473, 'Kamina', 'Kamina', 'KMN,Kamina,Kaminy,Камины', -8.7350800, 24.9979800, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10474, 'Kalemie', 'Kalemie', 'Albertstad,Albertville,FMI,Kalemi,Kalemie,Kalemije,Kalemijė,ka lai mi,kallemi,karemi,Калеми,Калемие,Калеміє,カレミ,卡萊米,칼레미', -5.9474900, 29.1947100, 'CD', '2016-11-28', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10475, 'Kabinda', 'Kabinda', 'KBN,Kabinda', -6.1379100, 24.4817900, 'CD', '2013-06-09', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10476, 'Kabare', 'Kabare', '', -2.4968200, 28.7908100, 'CD', '2012-12-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10477, 'Kabalo', 'Kabalo', 'KBO,Kabalo', -6.0525500, 26.9143000, 'CD', '2016-11-29', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10478, 'Isiro', 'Isiro', 'IRP,Isirio,Isiro,Paulis,Исиро', 2.7739100, 27.6160300, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10479, 'Ilebo', 'Ilebo', 'Franqui,Ilebo,PFR,Port-Francqui,Илебо', -4.3311100, 20.5863800, 'CD', '2017-07-10', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10480, 'Goma', 'Goma', 'GOM,Goma,Ngoma,Nkoma,ge ma,ghwma,goma,gwma,Γκόμα,Гома,غوما,گوما,ゴマ,戈马,고마', -1.6740900, 29.2284500, 'CD', '2012-12-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10481, 'Gbadolite', 'Gbadolite', 'BDT,Bado,Badolite,Gbadolite,Гбадолите', 4.2790000, 21.0028400, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10482, 'Gandajika', 'Gandajika', 'GDJ,Gandajika', -6.7450400, 23.9532800, 'CD', '2015-01-07', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10483, 'Demba', 'Demba', 'Demba', -5.4957300, 22.2696200, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10484, 'Butembo', 'Butembo', 'Butembo,RUE,Бутембо', 0.1416400, 29.2911700, 'CD', '2013-01-02', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10485, 'Buta', 'Buta', 'BZU,But,Buta,Бут', 2.7858200, 24.7299700, 'CD', '2017-07-10', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10486, 'Businga', 'Businga', 'Businga', 3.3386300, 20.8857700, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10487, 'Bunia', 'Bunia', 'BUX,Bunia,Bunija,Bunya,Búnya,bu ni ya,Буниа,Буния,Буніа,布尼亞', 1.5594100, 30.2522400, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10488, 'Bumba', 'Bumba', 'BMB,Bumba,Бумба', 2.1877100, 22.4682700, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10489, 'Bukavu', 'Bukavu', 'BKY,Bukavu,Costermansstad,Costermansville,Букаву', -2.4907700, 28.8428100, 'CD', '2015-05-25', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10490, 'Bukama', 'Bukama', 'Bukama', -9.2044300, 25.8547500, 'CD', '2016-11-29', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10491, 'Bongandanga', 'Bongandanga', 'Bongandanga', 1.5069500, 21.0726000, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10492, 'Bondo', 'Bondo', 'Bondo', 3.8146100, 23.6866500, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10493, 'Boende', 'Boende', 'BNB,Boende', -0.2816300, 20.8805300, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10494, 'Beni', 'Beni', 'BNC,Beni,Бени', 0.4911300, 29.4730600, 'CD', '2012-06-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10495, 'Basoko', 'Basoko', 'Basoko', 1.2390900, 23.6159800, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10496, 'Aketi', 'Aketi', 'Aketi,Port Chaltin', 2.7387700, 23.7832600, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10522, 'Zemio', 'Zemio', 'IMO,Zemio,Zémio', 5.0314400, 25.1361400, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10523, 'Ouango', 'Ouango', 'Ouango,Quango,Uango', 4.3132500, 22.5552400, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10524, 'Ouadda', 'Ouadda', 'ODA,Ouadda,Quadda,Uadda', 8.0777100, 22.4007500, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10525, 'Obo', 'Obo', 'MKI,Obo', 5.3958600, 26.4921100, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10526, 'Ndélé', 'Ndele', 'N''Delle,NDL,Nadele,Nadélé,Ndele,Ndélé,N’Delle', 8.4109100, 20.6472800, 'CF', '2017-04-17', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10527, 'Mobaye', 'Mobaye', 'Mobaye,Mobie', 4.3190200, 21.1786100, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10528, 'Kembé', 'Kembe', 'Kembe,Kembé', 4.6227500, 21.8864500, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10529, 'Ippy', 'Ippy', 'Ippi,Ippy', 6.2679300, 21.2246800, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10530, 'Gambo', 'Gambo', 'Gambo', 4.6481600, 22.2633100, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10531, 'Bria', 'Bria', 'BIV,Bria,Бриа', 6.5423300, 21.9863300, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10532, 'Birao', 'Birao', 'Birao,IRO', 10.2848800, 22.7881800, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10533, 'Bangassou', 'Bangassou', 'BGU,Bangassou,Bangassu,Bangasu,Бангасу', 4.7413200, 22.8183800, 'CF', '2017-04-17', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10534, 'Bambari', 'Bambari', 'BBY,Bambari,Бамбари', 5.7679500, 20.6756500, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10535, 'Alindao', 'Alindao', 'Alinda,Alindao,Alindo', 5.0266700, 21.2087600, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10536, 'Sibut', 'Sibut', 'Fort-Sibut,Sibut,Сибут', 5.7180100, 19.0738900, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10537, 'Paoua', 'Paoua', 'Pahua,Paoua', 7.2426900, 16.4405900, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10538, 'Nola', 'Nola', 'Nola', 3.5249400, 16.0458300, 'CF', '2014-09-07', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10539, 'Mongoumba', 'Mongoumba', 'Mongoumba', 3.6415300, 18.5936400, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10540, 'Mbaïki', 'Mbaiki', 'Mbaiki,Mbaïki', 3.8678100, 17.9892300, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10541, 'Kouango', 'Kouango', 'Kouango,Kuango', 4.9933700, 19.9618600, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10542, 'Kaga Bandoro', 'Kaga Bandoro', 'Crampel,Fort-Crampel,Kaga Bandoro,Kaga-Bandoro', 6.9896100, 19.1874400, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10543, 'Kabo', 'Kabo', 'Kabo', 7.6993700, 18.6290300, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10544, 'Gamboula', 'Gamboula', 'Gamboula,Gamoula', 4.1177500, 15.1392600, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10545, 'Damara', 'Damara', 'Damara,Дамара', 4.9607500, 18.7035000, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10546, 'Carnot', 'Carnot', 'CRF,Carnot', 4.9427300, 15.8773500, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10547, 'Bozoum', 'Bozoum', 'BOZ,Bosum,Bozoum,Bozum,Bozume,Бозуме', 6.3193300, 16.3799200, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10548, 'Bouca', 'Bouca', 'BCF,Bouca,Bouka,Buka', 6.5073400, 18.2767000, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10549, 'Bouar', 'Bouar', 'BOP,Bouar,Buar,Buara,Buare,Buâra,Bvaras,bu a er,bualeu,buwaru,bwar,Буар,Буаре,بؤار,ブワル,布阿爾,부아르', 5.9340400, 15.5959900, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10550, 'Bossangoa', 'Bossangoa', 'Amangba,BSN,Bosangoa,Bossango,Bossangoa,Босангоа', 6.4926300, 17.4551800, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10551, 'Boda', 'Boda', 'Boda', 4.3188700, 17.4695300, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10552, 'Boali', 'Boali', 'Boali,Bouali', 4.8004800, 18.1274700, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10553, 'Bimbo', 'Bimbo', 'Bimbo,Bimo', 4.2567100, 18.4158300, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10554, 'Berbérati', 'Berberati', 'BBT,Berberati,Berbérati,Берберати', 4.2611600, 15.7921600, 'CF', '2017-04-17', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10555, 'Batangafo', 'Batangafo', 'BTG,Batangafo,Devo,Dévo', 7.3008200, 18.2833000, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10556, 'Baoro', 'Baoro', 'Baoro,Baoro-Boubangoui,Baoro-Boudinghe,Baoro-Boudinghé', 5.6666700, 15.9666700, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10557, 'Bangui', 'Bangui', 'BGF,Bangi,Bangis,Bangui,Mpan''nkoui,ban ji,bang-gi,bangi,bangwyy,Μπανγκουί,Банги,Бангі,בנגואי,بانگوئی,ባንጊ,バンギ,班基,방기', 4.3612200, 18.5549600, 'CF', '2016-06-22', 43);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10558, 'Sibiti', 'Sibiti', 'SIB,Sibidi,Sibiti', -3.6819200, 13.3498500, 'CG', '2011-10-26', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10559, 'Sémbé', 'Sembe', 'Sembe,Ssembe,Sémbé', 1.6480600, 14.5805600, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10560, 'Pointe-Noire', 'Pointe-Noire', 'PNR,Pointe-Noire,Puehnt-Nuar,Puent Nuaras,puaengteunualeu,Пуэнт-Нуар,푸앵트누아르', -4.7760900, 11.8635200, 'CG', '2013-08-27', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10561, 'Owando', 'Owando', 'FTX,Fort Pousset,Fort-Rousset,Ouando,Ovando,Owando,Овандо', -0.4819300, 15.8998800, 'CG', '2011-10-27', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10562, 'Ouésso', 'Ouesso', 'Ouesso,Ouésso', 1.6136100, 16.0516700, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10563, 'Mossendjo', 'Mossendjo', 'MSX,Massendjo,Mossendio,Mossendjo', -2.9496800, 12.7042300, 'CG', '2013-05-09', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10564, 'Makoua', 'Makoua', 'MKJ,Makoua,Makoue', 0.0069400, 15.6333300, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10565, 'Madingou', 'Madingou', 'Madingo,Madingou,Madingu,Мадингу', -4.1536100, 13.5500000, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10566, 'Dolisie', 'Dolisie', 'DIS,Dolisi,Dolisie,Dolisje,Dolizi,Dolosie,Loubomo,Lubomo,dolliji,dorishi,duo li xi,dwlysy,Долиси,Лубомо,دولیسی,ドリシー,多利西,돌리지', -4.1983400, 12.6666400, 'CG', '2013-04-22', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10567, 'Loango', 'Loango', '', -4.6519400, 11.8125000, 'CG', '2014-03-06', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10568, 'Loandjili', 'Loandjili', 'Loandjili,Louantili', -4.7561100, 11.8577800, 'CG', '2014-03-06', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10569, 'Kinkala', 'Kinkala', 'Kinkala', -4.3613900, 14.7644400, 'CG', '2012-02-01', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10570, 'Kayes', 'Kayes', 'Jacob,Kai,Kajes,Kaye,Kayes,Kaï,Кайес', -4.2049300, 13.2860800, 'CG', '2013-04-13', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10571, 'Impfondo', 'Impfondo', 'Desbordesville,ION,Impfondo,Imponfo,Импфондо', 1.6180400, 18.0598100, 'CG', '2013-05-08', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10572, 'Gamboma', 'Gamboma', 'GMM,Gamboma', -1.8763900, 15.8644400, 'CG', '2012-05-05', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10573, 'Ewo', 'Ewo', 'EWO,Eouo,Ewo', -0.8725000, 14.8205600, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10574, 'Djambala', 'Djambala', 'DJM,Dambala,Djambala,Djamballa', -2.5447200, 14.7533300, 'CG', '2012-01-17', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10575, 'Brazzaville', 'Brazzaville', 'BZV,Braza,Brazavil,Brazavilis,Brazavilo,Brazzavil'',Brazzaville,Maya-Maya,Mprazabil,N''Tamo,beulajabil,brazafyl,brazawyl,brzwwyl,bu la chai wei er,burazavu~iru,Μπραζαβίλ,Браззавиль,ברזוויל,برازافيل,برازاویل,ብራዛቪል,ブラザヴィル,布拉柴维尔,브라자빌', -4.2661300, 15.2831800, 'CG', '2012-04-25', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10576, 'Nkayi', 'Nkayi', 'NKY', -4.1839600, 13.2859000, 'CG', '2013-04-13', 51);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10497, 'Lubumbashi', 'Lubumbashi', 'E''ville,Elisabethville,Elizabethstad,Elizabethville,E’ville,FBM,Gorad Lubumbashy,Lubumbashi,Lubumbashi shaary,Lubumbasi,Lubumbasis,Lubumbaši,Lubumbašis,Lumumbashi,lu ben ba xi,lubumabasi,lubumbasi,lubumbasi si,lwbmbashy,lwbwmbashy,rubunbashi,Élisabethville,Горад Лубумбашы,Лубумбаши,Лубумбаши шаары,Лубумбаші,לובומבאשי,لوبمباشی,لوبومباشي,لوبومباشی,ਲੂਬੁਮਬਾਸ਼ੀ,ルブンバシ,盧本巴希,루붐바시,루붐바시 시', -11.6608900, 27.4793800, 'CD', '2016-11-23', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10498, 'Likasi', 'Likasi', 'Jadotstad,Jadotsville,Jadotville,Likasi,Likasis,li ka xi,likasi,rikashi,Ликаси,Лікасі,リカシ,利卡西,리카시', -10.9830300, 26.7384000, 'CD', '2016-11-28', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10499, 'Kolwezi', 'Kolwezi', 'KWZ,Kolvezi,Kolwezi,Колвези', -10.7148400, 25.4667400, 'CD', '2016-11-28', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10500, 'Kipushi', 'Kipushi', 'Kipushi,Кипуши', -11.7609700, 27.2513500, 'CD', '2016-11-29', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10501, 'Kambove', 'Kambove', 'Kambove', -10.8735200, 26.5974600, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10502, 'Tshela', 'Tshela', 'Tshela', -4.9970700, 12.9484000, 'CD', '2013-01-10', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10503, 'Nioki', 'Nioki', 'NIO,Nioki', -2.7203700, 17.6900100, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10504, 'Mushie', 'Mushie', '', -3.0172800, 16.9223800, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10505, 'Mbanza-Ngungu', 'Mbanza-Ngungu', 'Mbanza-Ngungu,Thystad,Thysville,Мбанза-Нгунгу', -5.2583700, 14.8583800, 'CD', '2012-06-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10506, 'Mbandaka', 'Mbandaka', 'Bandaka,Cocquilhatville,Coquilhalville,Coquilhatstad,Coquilhatville,MDK,Mbandaka,Mbándáká,Wangata,eumbandaka,mbandaka,mu ban da ka,mubandaka,Мбандака,مبانداکا,ムバンダカ,姆班达卡,음반다카', 0.0486500, 18.2603400, 'CD', '2016-12-30', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10507, 'Matadi', 'Matadi', 'Gorad Matady,MAT,Matadi,Matadis,Matidi,Matádi,ma ta di,matadi,matady,Горад Матады,Матади,Матаді,מאטדי,ماتادی,マタディ,马塔迪,마타디', -5.8386100, 13.4630600, 'CD', '2017-01-04', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10508, 'Mangai', 'Mangai', 'Mangai', -4.0232800, 19.5338500, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10509, 'Lukolela', 'Lukolela', '', -1.0604600, 17.1821000, 'CD', '2013-06-07', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10510, 'Libenge', 'Libenge', 'LIE,Libenge', 3.6533200, 18.6356600, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10511, 'Kinshasa', 'Kinshasa', 'FIH,Gorad Kinshasa,Kincasa,Kinchasa,Kinchassa,Kinsas,Kinsasa,Kinsaso,Kinshasa,Kinshase,Kinsjasa,Kinszasa,Kinsásá,Kinxasa,Kinŝaso,Kinşasa,Kinšas,Kinšasa,Kînşasa,Leopoldstad,Leopoldville,Léopoldville,Quinxassa,jin sha sa,jin xia sha,kin cha sa,kinasasa,kinsaca,kinsasa,kinshasa,kinsyasa,knshasa,kynshasa,Κινσάσα,Горад Кіншаса,Киншаса,Киншасе,Кіншаса,Կինշասա,קינשאזע,קינשאסה,كينشاسا,کنشاسا,کنشاسہ,کینشاسا,किन्शासा,ਕਿਨਸ਼ਾਸਾ,கின்ஷாசா,കിൻഷസ,กินชาซา,ཀིན་ཤ་ས།,ကင်ရှာဆာမြို့,კინშასა,ኪንሻሳ,キンシャサ,金夏沙,金沙薩,킨샤사', -4.3275800, 15.3135700, 'CD', '2016-10-27', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10512, 'Kikwit', 'Kikwit', 'KKW,Kicwite,Kikvit,Kikvitas,Kikvite,Kikwit,Kitwit,ji kui te,kikuu~ito,kikwiteu,Киквит,Киквите,Кіквіт,キクウィト,基奎特,키퀴트', -5.0409800, 18.8161900, 'CD', '2017-07-10', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10513, 'Kasongo-Lunda', 'Kasongo-Lunda', 'KGN,Kasongo-Lunda', -6.4783300, 16.8173500, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10514, 'Kasangulu', 'Kasangulu', 'Kasangulu', -4.5833000, 15.1655400, 'CD', '2015-02-06', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10515, 'Inongo', 'Inongo', 'INO,Inongo', -1.9275000, 18.2881000, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10516, 'Gemena', 'Gemena', 'GMA,Gemena,Gemene,Гемене', 3.2565100, 19.7723400, 'CD', '2012-04-05', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10517, 'Bulungu', 'Bulungu', 'Bulungu', -4.5443700, 18.6036400, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10518, 'Bosobolo', 'Bosobolo', 'Bosobolo', 4.1898000, 19.8833000, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10519, 'Bolobo', 'Bolobo', 'Bolobo', -2.1580000, 16.2324900, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10520, 'Bandundu', 'Bandundu', 'Bandundu,Bandundu Boelgesi,Bandundu Bölgesi,Bandundu Province,Bandundu tartomany,Bandundu tartomány,Banningville,FDU,Pravincyja Bandundu,Provincia di Bandundu,Provinco Bandundu,Provinsi Bandundu,ban dun du sheng,bandandw,bando~undo~u zhou,bandundu ju,bandundu pranta,Бандунду,Правінцыя Бандунду,באנדונדו,بانداندو,باندوندو صوبہ,बान्दुन्दु प्रान्त,バンドゥンドゥ州,班顿杜省,반둔두 주', -3.3168700, 17.3806300, 'CD', '2016-11-22', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10521, 'Masina', 'Masina', '', -4.3836100, 15.3913900, 'CD', '2007-05-31', 52);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10577, 'Zwingen', 'Zwingen', 'Cvingen,ci wen gen,Цвинген,茨溫根', 47.4382500, 7.5302700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10578, 'Zweisimmen', 'Zweisimmen', 'Cvajzimmen,Zweisimmen,Zweisimmeni vald,ci wei xi men,Цвайзиммен,茨韋西門', 46.5553900, 7.3730200, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10579, 'Zuzwil', 'Zuzwil', 'Zuzwil,Zuzwil SG', 47.4745200, 9.1119600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10580, 'Bad Zurzach', 'Bad Zurzach', 'Bad Zurzach,Bad-Curcakh,Zurzach,Zurzacha,bad tswrtsy,bad zywrzash,chu er cha he,Бад-Цурцах,باد تسورتسی,باد زيورزاش,楚爾察赫', 47.5876400, 8.2936500, 'CH', '2015-11-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10581, 'Zürich', 'Zurich', 'Cirihe,Cirikh,Ciurichas,Cjurikh,Cjurikh khot,Cuerih,Curych,Cürih,Cīrihe,Gorad Cjurykh,Lungsod ng Zuerich,Lungsod ng Zürich,Su-la-sie,Suerix,Syurix,Sürix,Sŭ-là̤-sié,Tsuerix,Tsurique,Tsürix,Turicum,Turitg,ZRH,Zeurich,Zirich,Zirik,Zuerich,Zuerigh,Zuerih,Zuric,Zurich,Zuricu,Zurigh,Zurigo,Zuriko,Zurique,Zurych,Zurìcu,Zyriche,Zyrihu,Zúric,Zúrich,Zürich,Zürigh,Zürih,churihhi,chwilihi,curikku,jhyurika,jurikha,su li shi,su rik,suricc,tsiurikhi,tsyryk,zi''urikha,zwrykh,zyryk,zyurikha,zywrch,zywrh,zywrkh,Ζυρίχη,Горад Цюрых,Цирих,Цюрих,Цюрих хот,Ցյուրիխ,ציריך,زوريخ,زوریخ,زيورخ,زیورخ,زیورچ,سيۇرىخ,څوریخ,ܙܝܘܪܚ,ܬܣܝܪܝܟ,ज़्यूरिख़,झ्युरिक,জুরিখ,ਜ਼ਿਊਰਿਖ,சூரிக்கு,സൂറിച്ച്,ซูริก,ဇူးရစ်ချ်မြို့,ციურიხი,ዙሪክ,チューリッヒ,苏黎世,蘇黎世,취리히', 47.3666700, 8.5500000, 'CH', '2015-07-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10582, 'Zuoz', 'Zuoz', 'Cuoc,Zuoz,Zuses,Zutz,Zuz,chu ao ci,tsuotsu,Цуоц,ツオーツ,楚奧茨', 46.6020600, 9.9596500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10583, 'Zunzgen', 'Zunzgen', 'Cuncgen,Zunzgen,cong ci gen,Цунцген,聰茨根', 47.4492500, 7.8078900, 'CH', '2014-02-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10584, 'Zumikon', 'Zumikon', 'Cumikon,chu mi kong,Цумикон,楚米孔', 47.3315800, 8.6227100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10585, 'Zug', 'Zug', 'Cug,Tugium,ZLM,Zoug,Zug,Zugo,Цуг', 47.1724200, 8.5174500, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10586, 'Zuchwil', 'Zuchwil', 'Cukhvil'',chu he wei er,Цухвиль,楚赫維爾', 47.2017300, 7.5664900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10587, 'Zollikon', 'Zollikon', 'Collikon,Zollikon,Zollikon Dorf,cuo li kong,zwlykwn,Цолликон,زولیکون,措利孔', 47.3401900, 8.5740700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10588, 'Zollikofen', 'Zollikofen', 'Colikofen,Collikofen,cuo li ke fen,Цолликофен,Цолікофен,措利科芬', 46.9990500, 7.4580900, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10589, 'Zofingen', 'Zofingen', 'Cofingen,ZLL,Zofingen,Zofingo,Zofingue,Zofinguen,choping-gen,tsu~ofingen,zu fen gen,zwfngn,zwfnzhan,zwfynjyn,Цофинген,زوفنژان,زوفنگن,زوفينجين,ツォフィンゲン,祖芬根,초핑겐', 47.2877900, 7.9458600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10590, 'Zizers', 'Zizers', 'Cicers,Zezras,Zir,Zizers,Zizuris,qi ce si,Цицерс,齊策斯', 46.9357500, 9.5649100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10591, 'Zernez', 'Zernez', 'Cernec,Gumpus de Ernece,Zernes,Zernez,ce er nei ci,tsu~erunettsu,Цернец,ツェルネッツ,策爾內茨', 46.6986200, 10.0926800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10592, 'Zermatt', 'Zermatt', 'Cermat,Cermatt,Prat-Borgno,Pratobornum,Prât-Borgno,QZB,Zermatt,cai er ma te,cheleumateu,tsu~erumatto,zrmat,zrmt,zyrmat,Цермат,Церматт,צרמט,زرمات,زيرمات,ცერმატი,ツェルマット,采尔马特,체르마트', 46.0199800, 7.7486300, 'CH', '2016-09-13', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10593, 'Zell', 'Zell', 'Zell,Zell LU', 47.1367300, 7.9249500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10594, 'Zäziwil', 'Zaziwil', 'Cecivil'',ce qi wei er,Цецивиль,策齊維爾', 46.9019600, 7.6618500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10595, 'Yvonand', 'Yvonand', 'yi wo nan,伊沃南', 46.8003400, 6.7424900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10596, 'Yverdon-les-Bains', 'Yverdon-les-Bains', 'Aebura,Eburodunum,Iverdon le Ben,Iverdon-Le-Ben,Iverdon-le-Ben,Iverdonas,Yverden,Yverdon,ZLJ,aywrdwn lbn,ibeleudonglebaeng,yafrdwn lyh bayn,yi wei er dong,Ивердон ле Бен,Ивердон-Ле-Бен,Ивердон-ле-Бен,איוורדון-לה-בן,ایوردون لبن,يافردون ليه باين,イヴェルドン・レ・バン,伊韋爾東,이베르동레뱅', 46.7785200, 6.6411500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10597, 'Wyssachen', 'Wyssachen', 'Visakhen,Wyssachen,wei sa xing,Висахен,維薩興', 47.0785100, 7.8292200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10598, 'Wynigen', 'Wynigen', 'Vinigen,Wynigen,wei ni gen,Виниген,維尼根', 47.1058600, 7.6668100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10599, 'Wynau', 'Wynau', 'Vinau,wei nao,Винау,維瑙', 47.2557000, 7.8162600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10600, 'Würenlos', 'Wurenlos', 'Vjurenlos,Wurenlos,Würenlos,wei lun luo si,Вюренлос,維倫洛斯', 47.4420800, 8.3643900, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10601, 'Würenlingen', 'Wurenlingen', 'Vjurenlingen,Wuerenlingen,Wurenling,Würenling,Würenlingen,wei lun lin gen,Вюренлинген,維倫林根', 47.5335600, 8.2566600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10602, 'Worben', 'Worben', 'Vorben,wo er ben,Ворбен,沃爾本', 47.1027900, 7.2951800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10603, 'Worb', 'Worb', 'Vorb,Worb,wo er bu,wwrb,Ворб,وورب,沃爾布', 46.9298400, 7.5630600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10604, 'Wollerau', 'Wollerau', 'Vollerau,Wollerau,fwlraw,wwlraw,Воллерау,فولراو,وولراؤ', 47.1947800, 8.7190300, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10605, 'Wolhusen', 'Wolhusen', 'Vol''khuzen,Wolhusen,wo hu sen,Вольхузен,沃胡森', 47.0598300, 8.0738900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10606, 'Wolfwil', 'Wolfwil', 'Vol''fvil'',Wolfwil,wo er fu wei er,Вольфвиль,沃爾夫維爾', 47.2681900, 7.7896700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10607, 'Wölflinswil', 'Woelflinswil', 'Vjol''flinsvil'',Wolflinswil,Wölflinswil,wei fu lin si wei er,Вёльфлинсвиль,韋夫林斯維爾', 47.4607000, 7.9983500, 'CH', '2013-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10608, 'Wolfenschiessen', 'Wolfenschiessen', 'Vol''fenshissen,Wolfenschiessen,Вольфеншиссен', 46.9032200, 8.3942300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10609, 'Wohlen', 'Wohlen', 'Wohlen,Wohlen AG', 47.3523600, 8.2787700, 'CH', '2016-12-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10610, 'Wohlen', 'Wohlen', '', 46.9711800, 7.3568500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10611, 'Wittnau', 'Wittnau', '', 47.4813900, 7.9757700, 'CH', '2013-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10612, 'Wittenbach', 'Wittenbach', 'Vittenbakh,Wittenbach,Wittenbach SG,wei teng ba he,Виттенбах,維滕巴赫', 47.4610800, 9.3860100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10613, 'Zürich (Kreis 7) / Witikon', 'Zuerich (Kreis 7) / Witikon', 'Witikon', 47.3575100, 8.5910500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10614, 'Winterthur', 'Winterthur', 'Eulachstadt,Gorad Vintehrtur,Vintertour,Vintertur,Vintertura,Vinterturas,Vinterturi,Vinterturo,Vintertūra,Vintertūras,Vitudurum,Winterthour,Winterthur,ZLI,binteotueo,fyntrtwr,vu~intato~uru,wen te tu er,wntrtwr,Βίντερτουρ,Винтертур,Вінтертур,Горад Вінтэртур,فينترتور,ونترتور,ونٹرتھر,ვინტერთური,ヴィンタートゥール,温特图尔,빈터투어', 47.5056400, 8.7241300, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10615, 'Windisch', 'Windisch', '', 47.4789900, 8.2184200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10616, 'Wimmis', 'Wimmis', 'Vimmis,Wimmis,wei mi si,Виммис,維米斯', 46.6758700, 7.6397200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10617, 'Willisau', 'Willisau', 'Villizau,Willisau Stadt,wei li shao,wyl lyzw,Виллизау,ویل لیزو,維利紹', 47.1218300, 7.9941800, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10618, 'Wildhaus', 'Wildhaus', 'Vil''dkhaus,Wildhaus,Wildhaus SG,Вильдхаус,وائلڈہاؤس', 47.2058300, 9.3540200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10619, 'Wilderswil', 'Wilderswil', 'Vil''dersvil'',Wilderswil,vu~irudasuvu~iru,wei er de si wei er,Вильдерсвиль,ヴィルダースヴィル,維爾德斯維爾', 46.6636900, 7.8617500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10620, 'Wilchingen', 'Wilchingen', 'Vil''khingen,Wilchingen,Вильхинген', 47.6674500, 8.4677400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10621, 'Wila', 'Wila', '', 47.4192800, 8.8452400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10622, 'Wil', 'Wil', 'Vil,Vil'',Vilis,Wil,Wil SG,wei er,wyl,Вил,Виль,ويل,ویل، سن‌گلان,維爾', 47.4615200, 9.0455200, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10623, 'Wikon', 'Wikon', '', 47.2633900, 7.9680100, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10624, 'Wigoltingen', 'Wigoltingen', 'Vigol''tingen,Wigoltingen,wei ge er ting gen,Вигольтинген,維戈爾廷根', 47.5977000, 9.0314100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10625, 'Wiesendangen / Wiesendangen (Dorf)', 'Wiesendangen / Wiesendangen (Dorf)', 'Wiesendangen,Wiesendangen (Dorf)', 47.5217000, 8.7896700, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10626, 'Wiedlisbach', 'Wiedlisbach', 'Wiedlisbach', 47.2519400, 7.6461000, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10627, 'Zürich (Kreis 3) / Alt-Wiedikon', 'Zuerich (Kreis 3) / Alt-Wiedikon', 'Alt-Wiedikon', 47.3620100, 8.5149700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10628, 'Wetzikon', 'Wetzikon', 'Vecikon,Vetcikon,Wetzikon,Wetzikon ZH,wei qi kong,wtzykwn,wytzykwn,Ветцикон,Вецикон,وتزیکون,ويتزيكون,韋齊孔', 47.3264000, 8.7977900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10629, 'Wettingen', 'Wettingen', 'Vetingenas,Vetingo,Vettingen,Wettingen,ZLF,wei ting gen,wtnzhan,wytynghyn,Веттинген,وتنژان,ويتينغين,韋廷根', 47.4704900, 8.3163600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10630, 'Werthenstein', 'Werthenstein', 'Vertenshtajn,Werthenstein,wei teng si tai yin,Вертенштайн,韋滕斯泰因', 47.0557800, 8.1018200, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10631, 'Welschenrohr', 'Welschenrohr', 'Vel''shenror,Welschenrohr,wei er shen luo er,Вельшенрор,韋爾申羅爾', 47.2802900, 7.5263400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10632, 'Weisslingen', 'Weisslingen', '', 47.4306300, 8.7678700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10633, 'Weiningen', 'Weiningen', 'Vajningen,Weiningen ZH,wei ning gen,Вайнинген,魏寧根', 47.4202200, 8.4364400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10634, 'Weinfelden', 'Weinfelden', 'Vajnfel''den,Vajnfelden,Weinfeld,Weinfelden,ZLD,wei yin fei er deng,Вайнфельден,Вајнфелден,韋因費爾登', 47.5666700, 9.1000000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10635, 'Weggis', 'Weggis', 'Veggis,Weggis,vu~eggisu,wei ji si,Веггис,ヴェッギス,韋吉斯', 47.0320800, 8.4321900, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10636, 'Wegenstetten', 'Wegenstetten', 'Vegenshtetten,Wegenstetten,wei gen shi tai teng,Вегенштеттен,韋根施泰滕', 47.4979400, 7.9315900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10637, 'Weesen', 'Weesen', 'Vezen,wei sen,wysn,Везен,ویسن,韋森', 47.1344700, 9.0964400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10638, 'Wauwil', 'Wauwil', 'Vauvil'',Wauwil,wo wei er,Ваувиль,沃維爾', 47.1845700, 8.0210000, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10639, 'Wattwil', 'Wattwil', 'Vattvil'',Wattwil,wa te wei er,Ваттвиль,瓦特維爾', 47.2995500, 9.0865700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10640, 'Wattenwil', 'Wattenwil', 'Vattenvil'',Wattenwil,Wattenwil BE,wa teng wei er,Ваттенвиль,瓦滕維爾', 46.7697300, 7.5083500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10641, 'Wängi', 'Wangi', 'Vengi,Wangi,Wängi,wen ji,Венги,文吉', 47.4965400, 8.9532500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10642, 'Wangen an der Aare', 'Wangen an der Aare', 'Vangen-na-Are,Wangen,Wangen an der Aare,Wangen ce Aro,Wangen ĉe Aro,a lei he pan wang gen,wazhan an dr ar,Ванген-на-Аре,واژان آن در ار,阿勒河畔旺根', 47.2319900, 7.6544800, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10643, 'Wangen', 'Wangen', 'Wangen,Wangen b. Olten', 47.3436500, 7.8698200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10644, 'Walzenhausen', 'Walzenhausen', 'Val''cenkhauzen,Walzenhausen,Вальценхаузен', 47.4486700, 9.6049500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10645, 'Waltenschwil', 'Waltenschwil', 'Val''tenshvil'',Waltenschwil,wa teng shi wei er,Вальтеншвиль,瓦滕施維爾', 47.3349300, 8.3034400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10646, 'Wallisellen', 'Wallisellen', 'Vallizellen,wa li sai lun,wlyzwlan,Валлизеллен,ولیزولان,瓦利塞倫', 47.4149900, 8.5967200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10647, 'Walenstadt', 'Walenstadt', 'Valenshtadt,Valenurbo,Walenstadt,Wallendstadt,Wallenstadt,wa lun shi ta te,wlanstdt,Валенштадт,ولانستدت,瓦倫施塔特', 47.1241100, 9.3119400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10648, 'Walkringen', 'Walkringen', 'Val''kringen,Walkringen,Валькринген', 46.9485600, 7.6204000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10649, 'Waldstatt', 'Waldstatt', 'Val''dshtatt,Val''dstat,Waldstatt,Вальдстат,Вальдштатт,والدشٹاٹ', 47.3562700, 9.2834500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10650, 'Waldkirch', 'Waldkirch', 'Waldkirch', 47.4685900, 9.2866500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10651, 'Waldenburg', 'Waldenburg', 'Val''denburg,Valntenmpournk,Waldenburg,Waldenburg BL,Waldenburg i Sveits,wa er deng bao,wldanbwrg  swyys,Βάλντενμπουργκ,Вальденбург,ولدانبورگ، سوئیس,瓦尔登堡', 47.3833300, 7.7500000, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10652, 'Wald', 'Wald', 'Val''d,Wald,Wald ZH,Wald i Zuerich,Wald i Zürich,wa er de,Вальд,瓦爾德', 47.2759500, 8.9140500, 'CH', '2015-10-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10653, 'Wald', 'Wald', '', 46.8166700, 7.8500000, 'CH', '2012-04-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10654, 'Walchwil', 'Walchwil', 'Walchwil', 47.1016900, 8.5169300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10655, 'Wahlern', 'Wahlern', 'Valern,Wahlern,Walern,Валерн,واہلرن', 46.8280600, 7.3531800, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10656, 'Wahlen', 'Wahlen', 'Wahlen,Wahlen bei Laufen', 47.4022600, 7.5151100, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10657, 'Wagenhausen', 'Wagenhausen', 'Vagenkhauzen,Wagenhausen,Wagenhausen TG,wa gen hao sen,Вагенхаузен,瓦根豪森', 47.6600300, 8.8478200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10658, 'Wädenswil', 'Wadenswil', 'Vedensvil,Vedensvil'',wdnswyl,wei deng si wei er,Веденсвил,Веденсвиль,ودنسویل,韋登斯維爾', 47.2268300, 8.6687000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10659, 'Vuadens', 'Vuadens', 'Vuadens,Wuadingen,Wüadingen,wei a dang,維阿當', 46.6154500, 7.0173200, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10660, 'Vouvry', 'Vouvry', 'Vouvry,wu fu li,武夫里', 46.3374600, 6.8895000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10661, 'Vorderthal', 'Vorderthal', 'Vorder Waggithal,Vorder Wäggithal,Vordertal,Vorderthal', 47.1217200, 8.9022500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10662, 'Vordemwald', 'Vordemwald', 'Fordemval''d,wo de mu wa de,Фордемвальд,沃德姆瓦德', 47.2758500, 7.9011400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10663, 'Volketswil / Volketswil (Dorf)', 'Volketswil / Volketswil (Dorf)', 'Volketswil,Volketswil (Dorf)', 47.3901600, 8.6908500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10664, 'Vitznau', 'Vitznau', 'Vicnau,Vitznau,fittsunau,wei ci nao,Вицнау,フィッツナウ,維茨瑙', 47.0101400, 8.4842000, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10665, 'Visperterminen', 'Visperterminen', 'fei si po tai er mi nen,菲斯珀泰爾米嫩', 46.2589900, 7.9019200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10666, 'Visp', 'Visp', 'Fisp,Viege,Visp i Sveits,Vispo,Viège,ZLB,fei si pu,wysp,Фисп,ویسپ,菲斯普', 46.2937000, 7.8814900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10667, 'Vionnaz', 'Vionnaz', 'Viona,wei ao na,維奧納', 46.3110100, 6.9006200, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10668, 'Villnachern', 'Villnachern', 'Fil''nakhern,fei er na he en,Фильнахерн,菲爾納赫恩', 47.4709800, 8.1597500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10669, 'Villmergen', 'Villmergen', 'Fil''mergen,Villmergen,fei er mo gen,Фильмерген,菲爾默根', 47.3491700, 8.2458300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10670, 'Villigen', 'Villigen', 'Filligen,fei li gen,Филлиген,菲利根', 47.5268200, 8.2148600, 'CH', '2015-05-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10671, 'Villeneuve', 'Villeneuve', 'Vil''njov,Villeneuve,Villeneuve VD,Villeneuve i Vaud,Viln''ov,vilnevi,wei lei ne wo,wynw  ww,Вилньов,Вильнёв,وینو، وو,ვილნევი,维勒讷沃', 46.3986900, 6.9265400, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10672, 'Villaz-Saint-Pierre', 'Villaz-Saint-Pierre', 'Villaz-St-Pierre,wei la sheng pi ai er,維拉聖皮埃爾', 46.7207400, 6.9563800, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10673, 'Villars-sur-Ollon', 'Villars-sur-Ollon', 'Vijjar-sjur-Olon,Vilar sur Oljonas,Villar,Villar-sjur-Olon,Villars,Villars / Ollon,ZLA,Вийяр-сюр-Олон,Виллар,Виллар-сюр-Олон,וילאר-סור-אולון', 46.2983200, 7.0563100, 'CH', '2017-05-09', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10674, 'Villars-sur-Glâne', 'Villars-sur-Glane', 'Villars ce Glano,Villars ĉe Glano,ge la ne he pan wei la er,格拉訥河畔維拉爾', 46.7905400, 7.1171700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10675, 'Viganello', 'Viganello', '', 46.0134200, 8.9687900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10676, 'Vicques', 'Vicques', 'Vicques,Vicques JU,Vicques i Sveits,wei ke,維克', 47.3510100, 7.4026600, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10677, 'Veyrier', 'Veyrier', 'Verier,Veyrier GE,Vêriér,beilie,vu~eirie,wei li ye,ヴェイリエ,韦里耶,베이리에', 46.1669900, 6.1843600, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10678, 'Vex', 'Vex', 'Vex,Vex VS,wei ke si,韋克斯', 46.2123900, 7.3982600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10679, 'Vevey', 'Vevey', 'Lungsod ng Vevey,V''ove,Veve,Vevey,Vevê,Vevė,Vibiscum,ZKZ,beube,fyfy,veve,vuvu~ei,wo wei,ww wh,wwh,Βεβέ,Веве,Вьове,ווה,فيفي,وو وه,เวอแว,ვევე,ヴヴェイ,沃韦,브베', 46.4629900, 6.8434500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10680, 'Vétroz', 'Vetroz', 'Vetro,Vetroz,Vètro,Vétroz,wei te luo,韋特羅', 46.2217100, 7.2785800, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10681, 'Versoix', 'Versoix', 'Versoix,Versoix-la-Raison,Versouex,Versua,Vèrsouèx,beleusua,fyrswks,vu~erusowa,wei er su wa,wrswa zhh aw,Версуа,فيرسوكس,ورسوآ ژه او,ヴェルソワ,韦尔苏瓦,베르수아', 46.2838200, 6.1621400, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10682, 'Verscio', 'Verscio', 'Versc,Verscio,wei er si qiao,韋爾斯喬', 46.1848200, 8.7322400, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10683, 'Vernier', 'Vernier', 'Vernie,Vernier,Vernije,Vèrniér,beleunie,fyrnayr,vu~erunie,wei er nie,wrnyh  swyys,Верние,Верније,فيرناير,ورنیه، سوئیس,ヴェルニエ,韦尔涅,베르니에', 46.2170200, 6.0849700, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10684, 'Vernayaz', 'Vernayaz', 'wei er na ya,韋爾納亞', 46.1366700, 7.0390600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10685, 'Verbier', 'Verbier', 'Verb''e,Verbier,ZKY,vu~erubie,wrbyr,Вербье,وربئر,ヴェルビエ', 46.1002000, 7.2265100, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10686, 'Veltheim (Kreis 5)', 'Veltheim', 'Veltheim (Kreis 5)', 47.5141900, 8.7170000, 'CH', '2010-04-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10687, 'Veltheim', 'Veltheim', '', 47.4379600, 8.1472200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10688, 'Vechigen', 'Vechigen', 'Fekhigen,Vechigen,wei xi gen,Фехиген,韋希根', 46.9461600, 7.5606500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10689, 'Varen', 'Varen', '', 46.3186000, 7.6074300, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10690, 'Vandœuvres', 'Vandoeuvres', 'Vandoeuvres,Vandœuvres,Vendoeuvres,vu~ando~uvuru,wang de fu er,ヴァンドゥーヴル,旺德夫尔', 46.2217900, 6.2028500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10691, 'Vals Platz', 'Vals Platz', 'Platz,Val,Vals,Vals Platz', 46.6164700, 9.1802500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10692, 'Vallorbe', 'Vallorbe', 'wa luo er bu,瓦洛尔布', 46.7125600, 6.3789400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10693, 'Uzwil', 'Uzwil', 'Ucvil'',Uzvilis,Uzwil,ZKX,awzwyl,wu ci wei er,ywzwyl,Уцвиль,اوزویل,يوزويل,烏茨維爾', 47.4365300, 9.1342200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10694, 'Uznach', 'Uznach', 'Ucnakh,Uznach,awznk,wu ci na he,Уцнах,اوزنک,烏茨納赫', 47.2242100, 8.9826300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10695, 'Utzenstorf', 'Utzenstorf', 'Utcenstorf,Utzenstorf,wu cen si tuo fu,Утценсторф,烏岑斯托夫', 47.1324800, 7.5535500, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10696, 'Uttwil', 'Uttwil', 'Uttwil', 47.5844000, 9.3410100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10697, 'Uttigen', 'Uttigen', 'Uttigen,wu di gen,Уттиген,烏蒂根', 46.7943500, 7.5778900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10698, 'Uster', 'Uster', 'Uster,awsth,usuta,wu si te shi,Устер,اوسته,ウスター,乌斯特市', 47.3471300, 8.7209100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10699, 'Urtenen', 'Urtenen', 'Urtenen', 47.0266700, 7.5008100, 'CH', '2015-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10700, 'Urnäsch', 'Urnasch', 'Urnaesch,Urnasch,Urnesh,Urnäsch,Урнеш', 47.3166900, 9.2795000, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10701, 'Wetzikon / Unter-Wetzikon', 'Wetzikon / Unter-Wetzikon', 'Unter-Wetzikon', 47.3163700, 8.7936900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10702, 'Untervaz', 'Untervaz', 'Untervac,Untervaz,Vaz Sut,wen te wa ci,Унтервац,溫特瓦茨', 46.9275000, 9.5342200, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10703, 'Untersiggenthal', 'Untersiggenthal', 'Unter-Siggental,Untersiggenthal,Unterziggental'',antrsyghyntal,xia xi gen ta er,Унтерзиггенталь,انترسيغينتال,下錫根塔爾', 47.5021300, 8.2555400, 'CH', '2015-06-24', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10704, 'Unterseen', 'Unterseen', 'Unterseen,Unterzeen,Unterzen,antrsyan,untazen,xia sen,Унтерзеен,Унтерзен,انترسئان,ウンターゼーン,下森', 46.6853000, 7.8472200, 'CH', '2015-05-25', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10705, 'Unterlunkhofen', 'Unterlunkhofen', 'Unterlunkhofen,Unterlunkkhofen,xia lun huo fen,Унтерлункхофен,下倫霍芬', 47.3212000, 8.3810200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10706, 'Unterkulm', 'Unterkulm', 'Kulm,Unterkul''m,Unterkulm,xia ku er mu,Унтеркульм,下庫爾姆', 47.3099800, 8.1137100, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10707, 'Illnau / Unter-Illnau', 'Illnau / Unter-Illnau', 'Unter-Illnau', 47.4078700, 8.7260700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10708, 'Unteriberg', 'Unteriberg', 'Unteriberg,Унтериберг', 47.0625800, 8.8052000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10709, 'Unterengstringen', 'Unterengstringen', 'Unterengstringen,xia en si te lin gen,Унтеренгстринген,下恩斯特林根', 47.4139600, 8.4476100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10710, 'Ehrendingen', 'Ehrendingen', 'Ehrendingen,Oberehrendingen,Unterehrendingen,ai lun ding gen,Эрендинген,埃倫丁根', 47.5025000, 8.3472900, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10711, 'Unterägeri', 'Unterageri', 'Ageri,Agregia Inferior,Unteraegeri,Unterageri,Unteregeri,Unteräegeri,Unterägeri,Ägeri,Унтерегери', 47.1364500, 8.5853000, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10712, 'Uitikon', 'Uitikon', 'Uitikon,Uitikon Waldegg,Uitikon am Albis,Ujtikon,wu yi di kong,Уитикон,Уйтикон,烏伊蒂孔', 47.3691100, 8.4569900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10713, 'Uhwiesen', 'Uhwiesen', '', 47.6707400, 8.6354200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10714, 'Uetikon', 'Uetikon', 'Uetikon,Uetikon am See', 47.2644100, 8.6792500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10715, 'Uetendorf', 'Uetendorf', 'Itendorf,Uetendorf,Utendorf,yu he duo fu,Ütendorf,Итендорф,于赫多夫', 46.7739200, 7.5725100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10716, 'Uerkheim', 'Uerkheim', 'Uerkheim', 47.3028900, 8.0237100, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10717, 'Uerikon', 'Uerikon', '', 47.2367200, 8.7573000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10718, 'Ueberstorf', 'Ueberstorf', 'Uberstorf,Ueberstorf,yu bo shi tuo fu,Überstorf,于伯施托夫', 46.8658700, 7.3099800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10719, 'Udligenswil', 'Udligenswil', 'Udligenswil', 47.0900500, 8.4033500, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10720, 'Turtmann', 'Turtmann', 'Tourtemagne,Turtmann,tu er te man,圖爾特曼', 46.3002800, 7.7020000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10721, 'Turgi', 'Turgi', 'Turgi,tu er ji,Турги,圖爾吉', 47.4920100, 8.2541200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10722, 'Turbenthal', 'Turbenthal', 'Turbental,Turbental'',tu ben ta er,Турбенталь,圖本塔爾', 47.4363300, 8.8462900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10723, 'Tuggen', 'Tuggen', 'Tuggen,Тугген', 47.2029100, 8.9489600, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10724, 'Trun', 'Trun', 'Taurontum,Trun,Trun GR,Truns,te lun,to~urun,Трун,トゥルン,特倫', 46.7429200, 8.9871600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10725, 'Trubschachen', 'Trubschachen', 'Trubschachen,Trubshakhen,te lu bu sha xing,Трубшахен,特魯布沙興', 46.9222800, 7.8452000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10726, 'Trub', 'Trub', 'Trub,te lu bu,Труб,特魯布', 46.9416800, 7.8799600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10727, 'Troistorrents', 'Troistorrents', 'te lu wa tuo lang,特魯瓦托朗', 46.2289000, 6.9158900, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10728, 'Trogen', 'Trogen', 'Trogen,Trogen AR', 47.4078200, 9.4649800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10729, 'Trimmis', 'Trimmis', 'Termin,Tremunis,Trimis,Trimmis,Trimmis Dorf,te li mi si,Тримис,Триммис,特里米斯', 46.9007500, 9.5612000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10730, 'Trimbach', 'Trimbach', 'Trimbach,Trimbach SO,Trimbach i Sveits,Trimbakh,te lin ba he,trymbakh,Тримбах,تریمباخ,特林巴赫', 47.3656100, 7.8868000, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10731, 'Triengen', 'Triengen', 'Triengen,Tringen,te li en gen,Тринген,特里恩根', 47.2337500, 8.0772900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10732, 'Treyvaux', 'Treyvaux', 'Treyvaux,Treyvaux FR,te lei wo,特雷沃', 46.7279600, 7.1376900, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10733, 'Trélex', 'Trelex', '', 46.4153800, 6.2081300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10734, 'Travers', 'Travers', '', 46.9401800, 6.6759500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10735, 'Tramelan', 'Tramelan', 'Tramelan,Tramlan,te la mei lan,Трамлан,特拉梅蘭', 47.2239300, 7.0995000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10736, 'Trachselwald', 'Trachselwald', 'Trachselwald,Traksel''val''d,te la he sai er wa er de,Траксельвальд,特拉赫塞爾瓦爾德', 47.0169900, 7.7363900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10737, 'Töss (Kreis 4)', 'Toss', 'Toess (Kreis 4),Töss (Kreis 4),Winterthur Toss,Winterthur Töss', 47.4789000, 8.7021500, 'CH', '2016-09-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10738, 'Toffen', 'Toffen', 'Toffen,tuo fen,Тоффен,托芬', 46.8603100, 7.4921600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10739, 'Tiefencastel', 'Tiefencastel', 'Castellum Impitinis,Casti,Tiefencastel,Tifenkastel'',di fen ka si te er,Тифенкастель,蒂芬卡斯特爾', 46.6601400, 9.5788300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10740, 'Thusis', 'Thusis', 'Thusis,Tosanna,Tusaun,Tuzis,tu xi si,twzy,Тузис,توزی,圖西斯', 46.6972400, 9.4393800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10741, 'Thundorf', 'Thundorf', 'Thundorf,Thundorf TG,Thundorf i Sveits,Tundorf,tong duo fu,Тундорф,通多夫', 47.5459400, 8.9635800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10742, 'Thun', 'Thun', 'Thoune,Thun,Timium,Tun,Tunas,Tune,ZTK,thwn,to~un,tu en,tun,tuni,twn,Тун,תון,تون,تھن,ثون,ടൂൺ,თუნი,トゥーン,图恩,툰', 46.7511800, 7.6216600, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10743, 'Thierachern', 'Thierachern', 'Thierachern,Tierachern,Tirakhern,di la xie en,Тирахерн,蒂拉歇恩', 46.7531900, 7.5744200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10744, 'Therwil', 'Therwil', 'Tervil'',Therwil,te wei er,Тервиль,特維爾', 47.5011700, 7.5528600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10745, 'Thayngen', 'Thayngen', 'Tajngen,ta ying gen,Тайнген,塔英根', 47.7471700, 8.7072400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10746, 'Thalwil', 'Thalwil', 'Tal''vil'',ta er wei er,tl wyl,Тальвиль,تل ویل,塔爾維爾', 47.2917500, 8.5635100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10747, 'Teufenthal', 'Teufenthal', 'Teufental,Teufenthal,Tojfental'',tuo yi fen ta er,Тойфенталь,托伊芬塔爾', 47.3286300, 8.1207400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10748, 'Teufen', 'Teufen', 'Teufen,Teufen AR,Tojfen,Тойфен', 47.3908000, 9.3864400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10749, 'Tesserete', 'Tesserete', 'Tesserete', 46.0681300, 8.9650100, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10750, 'Tegerfelden', 'Tegerfelden', 'Tegerfel''den,Tegerfelden,tai ge fei er deng,Тегерфельден,泰格費爾登', 47.5580900, 8.2891400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10751, 'Tavannes', 'Tavannes', 'Tavan,Tavann,ta wa ne,Таван,Таванн,塔瓦訥', 47.2207900, 7.1975900, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10752, 'Täuffelen', 'Tauffelen', 'Tauffelen,Tojffelen,Täuffelen,tuo yi fei lun,Тойффелен,托伊費倫', 47.0663000, 7.1988300, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10753, 'Tann', 'Tann', '', 47.2689800, 8.8502400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10754, 'Tanay', 'Tanay', 'Taney,Tannay', 46.3450300, 6.8304100, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10755, 'Tamins', 'Tamins', 'Tamins,Tumein,ta ming si,Таминс,塔明斯', 46.8296400, 9.4064800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10756, 'Tägerwilen', 'Tagerwilen', 'Tagerwilen,Tegervilen,Tägerwilen,te ge wei lun,Тегервилен,特格維倫', 47.6569800, 9.1399900, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10757, 'Tafers', 'Tafers', 'Tafers,Tavel,ta fei er,塔費爾', 46.8148300, 7.2185200, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10758, 'Sursee', 'Sursee', 'Gorad Zurzehe,Sursee,Surze,ZKU,Zurze,Zurzee,su er sai,swrsh,Горад Зурзэе,Зурзе,Зурзее,Сурзе,سورسه,蘇爾塞', 47.1708800, 8.1111300, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10759, 'Sumiswald', 'Sumiswald', 'Sumiswald,Zumisval''d,su mi si wa er de,Зумисвальд,蘇米斯瓦爾德', 47.0274700, 7.7452600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10760, 'Sulz', 'Sulz', 'Sulz,Sulz AG', 47.5360200, 8.0962800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10761, 'Sulgen', 'Sulgen', 'Sulgen,Sulgen TG,Zul''gen,su er gen,Зульген,蘇爾根', 47.5396700, 9.1858500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10762, 'Suhr', 'Suhr', 'Suhr,Suhr AG', 47.3717200, 8.0796700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10763, 'Subingen', 'Subingen', 'Subingen,Zubingen,su bin gen,Зубинген,蘇賓根', 47.1985200, 7.6194900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10764, 'Strengelbach', 'Strengelbach', 'Shtrengel''bakh,si te lun ge ba he,Штренгельбах,斯特倫格巴赫', 47.2791700, 7.9289500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10765, 'Stettlen', 'Stettlen', 'Shtetlen,Stettlen,si tai te lun,Штетлен,斯泰特倫', 46.9583500, 7.5250800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10766, 'Stettfurt', 'Stettfurt', 'Shtetfurt,Stettfurt,si tai te fu er,Штетфурт,斯泰特富爾', 47.5258800, 8.9531700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10767, 'Steinhausen', 'Steinhausen', 'Steinhausen', 47.1951000, 8.4858100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10768, 'Steinen', 'Steinen', 'Steinen', 47.0497500, 8.6121400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10769, 'Stein am Rhein', 'Stein am Rhein', 'Shtajn-Am-Rajn,Shtajn-am-Rajn,Shtajn-na-Rejne,Stein ce Rejno,Stein ĉe Rejno,stn am rn,styn am rhyn,Штайн-Ам-Райн,Штайн-ам-Райн,Штайн-на-Рейне,שטיין אם ריין,ستن ام رن,ستين أم رهين', 47.6593300, 8.8596400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10770, 'Stein', 'Stein', '', 47.5440300, 7.9525600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10771, 'Steffisburg', 'Steffisburg', 'Shteffisburg,Steffisburg,shi te fei si bao,stfysbwrg,Штеффисбург,ستفیسبورگ,施特菲斯堡', 46.7780700, 7.6324900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10772, 'Steckborn', 'Steckborn', 'Shtekborn,Steckborn,shi tai ke bo en,stkbwrn,Штекборн,ستکبورن,施泰克博恩', 47.6666700, 8.9833300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10773, 'Staufen', 'Staufen', 'Staufen', 47.3837200, 8.1660600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10774, 'Stansstad', 'Stansstad', 'Shtansshtad,Shtanstad,Stannis,Stansstad,Штанстад,Штансштад', 46.9768000, 8.3355300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10775, 'Stans', 'Stans', 'Gorad Shtans,Shhans,Shtans,Stans,Stansas,Tannis,shi tan si,shtans,shutansu,stan  swyys,stans,syutanseu,Štansas,Горад Штанс,Штанс,Щанс,Շտանս,زٹانز,ستان، سوئیس,ستانس,شتانس,シュタンス,施坦斯,슈탄스', 46.9580500, 8.3660900, 'CH', '2015-04-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10776, 'Stalden', 'Stalden', 'Stalden VS,shi ta er deng,施塔爾登', 46.2334100, 7.8727300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10777, 'Staffelbach', 'Staffelbach', '', 47.2839500, 8.0420800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10778, 'Stäfa', 'Stafa', 'Shtefa,shi tai fa,stfa,Штефа,ستفا,施泰法', 47.2425400, 8.7234200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10779, 'Stabio', 'Stabio', 'Stabi,Stabio,si ta bi ao,斯塔比奧', 45.8484600, 8.9364200, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10780, 'Spreitenbach', 'Spreitenbach', 'Shprajtenbakh,Spreitenbach,si pu lai teng ba he,sprh tanbk,Шпрайтенбах,سپره تانبک,斯普賴滕巴赫', 47.4201600, 8.3630100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10781, 'Spiez', 'Spiez', 'Shpic,Spiez,sbyz,shi pi ci,spyh,Шпиц,سبيز,سپیه,施皮茨', 46.6847300, 7.6911100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10782, 'Speicher', 'Speicher', 'Shpajkher,Speicher,Speicher AR,Шпайхер', 47.4109000, 9.4433500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10783, 'Sottens', 'Sottens', 'Sottens', 46.6552100, 6.7419700, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10784, 'Sorengo', 'Sorengo', 'Sorengh,Sorengo,suo lei ni ao,索雷尼奧', 45.9976600, 8.9378300, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10785, 'Solothurn', 'Solothurn', 'Gorad Zalaturn,Soletta,Soleura,Soleure,Solloturni,Solodurum,Solothurn,Soloturn,Soloturno,Solura,Suleta,ZKS,Zoloturn,Zoloturnas,jollotuleun,solo thur n,suo luo tu en,swlwtwrn,zoloturni,zoroto~urun,zwlwtwrn,Горад Залатурн,Золотурн,זולותורן,سولوتورن,โซโลทูร์น,ზოლოთურნი,ゾロトゥルン,索洛图恩,졸로투른', 47.2079100, 7.5371400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10786, 'Sissach', 'Sissach', 'Zissakh,xi sa he,Зиссах,錫薩赫', 47.4640800, 7.8088800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10787, 'Sirnach', 'Sirnach', 'Zirnakh,xi na he,Зирнах,錫納赫', 47.4622200, 8.9976300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10788, 'Sitten', 'Sitten', 'Gorad S''jon,S''jon,S''on,SIR,Sedunum,Siao,Sion,Sion i Sveits,Sionas,Sitten,Sitten VS,Sião,shion,siong,sioni,sywn,sywn  swyys,xi yong,Горад Сьён,Сион,Сьйон,Сьон,סיון,سیؤن,سیون، سوئیس,სიონი,シオン,锡永,시옹', 46.2273900, 7.3555900, 'CH', '2016-08-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10789, 'Sins', 'Sins', 'Sins', 47.1929600, 8.3938400, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10790, 'Silvaplana', 'Silvaplana', 'Silvapiana,Silvaplana,Silvaplauna', 46.4581000, 9.7951400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10791, 'Silenen', 'Silenen', 'Silenen', 46.7891000, 8.6732500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10792, 'Sigriswil', 'Sigriswil', 'Sigriswil,Zigrisvil'',xi ge li si wei er,Зигрисвиль,錫格里斯維爾', 46.7165600, 7.7133500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10793, 'Signau', 'Signau', 'Signau,Zignau,xi ge nao,Зигнау,錫格瑙', 46.9194400, 7.7241800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10794, 'Sierre', 'Sierre', 'S''erre,Siders,Sierro,Sijer/Ziders,Siérro,sayr,shieru,syr,xie er,Сијер/Зидерс,Сьерре,ساير,سیر,シエール,谢尔', 46.2919200, 7.5355900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10795, 'Siebnen', 'Siebnen', '', 47.1744900, 8.8978100, 'CH', '2016-09-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10796, 'Sevelen', 'Sevelen', 'Sevelen SG,Zefelen,Zevelen,sai wo lun,Зевелен,Зефелен,塞沃倫', 47.1221300, 9.4860100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10797, 'Seuzach / Seuzach (Dorf)', 'Seuzach / Seuzach (Dorf)', 'Seuzach (Dorf)', 47.5354500, 8.7372800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10798, 'Seon', 'Seon', 'Seon', 47.3449000, 8.1560700, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10799, 'Sennwald', 'Sennwald', 'Sennwald,Zennval''d,Zenvald,sen wa de,Зенвалд,Зеннвальд,森瓦德', 47.2606300, 9.5026800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10800, 'Sempach', 'Sempach', 'Zempakh,sampk,sen pa he,Земпах,سامپک,森帕赫', 47.1357700, 8.1914900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10801, 'Sementina', 'Sementina', 'sai men di na,塞門蒂納', 46.1836300, 8.9916200, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10802, 'Selzach', 'Selzach', 'Zel''cakh,sai er cha he,Зельцах,塞爾察赫', 47.2053100, 7.4552100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10803, 'Seltisberg', 'Seltisberg', 'Seltisberg', 47.4594700, 7.7172900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10804, 'Seftigen', 'Seftigen', 'Seftigen,Zeftigen,sai fu di gen,Зефтиген,塞弗蒂根', 46.7876500, 7.5393700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10805, 'Seengen', 'Seengen', 'Seengen,Zeengen,Zengen,sen gen,Зеенген,Зенген,森根', 47.3285200, 8.2050900, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10806, 'Seedorf', 'Seedorf', 'Seedorf,Seedorf BE,Seedorf i Bern,Zedorf,Zeedorf,sai duo fu,Зедорф,Зеедорф,塞多夫', 47.0344500, 7.3124900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10807, 'Seedorf', 'Seedorf', 'Seedorf,Seedorf UR,Seedorf i Uri,Zedorf,Zeedorf,zedorufu,Зедорф,Зеедорф,ゼードルフ', 46.8819900, 8.6161100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10808, 'Seeberg', 'Seeberg', 'Seeberg', 47.1558500, 7.6656700, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10809, 'Zürich (Kreis 11) / Seebach', 'Zuerich (Kreis 11) / Seebach', 'Seebach', 47.4218100, 8.5477900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10810, 'Scuol', 'Scuol', 'Schulles,Schuls,Scuol,Skuol,Skuol'',shi ku ao er,shukuoru,skwl,Скуол,Скуоль,سكول,シュクオル,施庫奧爾', 46.7967100, 10.2980400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10811, 'Schwyz', 'Schwyz', 'Schwytz,Schwyz,Shvic,Shvits,Suitius,Svico,Svit,Svitto,Svittu,Sviz,ZKK,ashwwts,shi wei ci,shuvu~itsu,shwyts,shwyz,syubicheu,Ŝvico,Швиц,Швіц,اشووتس,شوائز شہر,شويز,شویتس,シュヴィーツ,施維茨,슈비츠', 47.0207600, 8.6541400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10812, 'Schwellbrunn', 'Schwellbrunn', 'Schwellbrunn,Shvel''brun,Швельбрун', 47.3525500, 9.2489400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10813, 'Schwarzenberg', 'Schwarzenberg', 'Schwarzenberg,Schwarzenberg LU', 47.0170500, 8.1726100, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10814, 'Schwanden', 'Schwanden', 'Schwanden,Schwanden GL,Shvanden,Шванден', 46.9954100, 9.0701000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10815, 'Schwaderloch', 'Schwaderloch', 'Shvaderlokh,shi wa de luo he,Швадерлох,施瓦德洛赫', 47.5854100, 8.1445500, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10816, 'Schüpfheim', 'Schuepfheim', 'Schuepfheim LU,Schupfheim,Schüpfheim,Schüpfheim LU,Shjupfkhajm,xu pu fu hai mu,Шюпфхайм,許普弗海姆', 46.9516100, 8.0172300, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10817, 'Schüpfen', 'Schupfen', 'Schupfen,Schüpfen,Shjupfen,xu pu fen,Шюпфен,許普芬', 47.0366100, 7.3772300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10818, 'Schübelbach', 'Schubelbach', 'Shjubel''bakh,Шюбельбах', 47.1732600, 8.9281100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10819, 'Schötz', 'Schoetz', 'Schotz,Schötz,Shjoc,she ci,Шёц,舍茨', 47.1689600, 7.9887000, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10820, 'Schönenwerd', 'Schonenwerd', 'Schonenwerd,Schönenwerd,Shjonenverd,she nen wei de,Шёненверд,舍嫩韋德', 47.3691000, 8.0016700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10821, 'Schönenbuch', 'Schonenbuch', 'Shjonenbukh,she nen bu he,Шёненбух,舍嫩布赫', 47.5385300, 7.5057200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10822, 'Schöftland', 'Schoftland', 'Schoftland,Schöftland,Shjoftland,she fu te lan,Шёфтланд,舍夫特蘭', 47.3057200, 8.0513800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10823, 'Schmitten', 'Schmitten', 'Schmitten,Schmitten FR,Schmitten i Fribourg,shi mi teng,施米滕', 46.8575000, 7.2503100, 'CH', '2016-09-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10824, 'Schmerikon', 'Schmerikon', '', 47.2253800, 8.9483600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10825, 'Schlieren', 'Schlieren', 'Shliren,shi li lun,shylwran  zwrykh,Шлирен,شیلوران، زوریخ,施利倫', 47.3966800, 8.4476300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10826, 'Schleitheim', 'Schleitheim', 'Shlajtajm,Shlajtkhajm,Шлайтайм,Шлайтхайм', 47.7481800, 8.4821300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10827, 'Schinznach Dorf', 'Schinznach Dorf', 'Schinznach,Schinznach Dorf', 47.4465000, 8.1408900, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10828, 'Schinznach Bad', 'Schinznach Bad', 'Bad Schinznach', 47.4499200, 8.1683300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10829, 'Schindellegi', 'Schindellegi', '', 47.1746000, 8.7134500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10830, 'Schiers', 'Schiers', 'Aschera,Schiers,Shirs,xi er si,Ширс,席爾斯', 46.9697300, 9.6872000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10831, 'Schenkon', 'Schenkon', 'Shenkon,shen kong,Шенкон,申孔', 47.1683000, 8.1438400, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10832, 'Schattdorf', 'Schattdorf', 'Schattdorf,Shatdorf,Шатдорф', 46.8655000, 8.6546500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10833, 'Schänis', 'Schanis', 'Schanis,Schänis,Shenis,she ni si,Шенис,舍尼斯', 47.1599500, 9.0454900, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10834, 'Schafisheim', 'Schafisheim', 'Schafisheim,Shafiskhajm,sha fei sha yi mu,Шафисхайм,沙菲沙伊姆', 47.3752900, 8.1407600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10835, 'Schaffhausen', 'Schaffhausen', 'Safhauzenas,Safhauzene,Safhauzo,Scafusa,Schaffhausen,Schaffhouse,Schaffusa,Schofhausen,Sciaffusa,Sciafuesa,Sciafüsa,Shaffgauzen,Shaffkhauzen,Shafkhauzen,Szafuza,ZKJ,chaff hea sein,sha fu hao sen,shafhawzn,shafuhauzen,shfwzan,syapeuhaujen,Ŝafhaŭzo,Šafhauzenas,Šafhauzene,Шаффгаузен,Шаффхаузен,Шафхаузен,שפהאוזן,شافهاوزن,شافہاؤزن,شافہاوزن,شفوزان,ชาฟฟ์เฮาเซิน,シャフハウゼン,沙夫豪森,샤프하우젠', 47.6973200, 8.6349300, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10836, 'Saxon', 'Saxon', 'Sasson,Saxon,Saxon VS,Saxon i Sveits,sa ke song,薩克松', 46.1493700, 7.1751400, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10837, 'Savigny', 'Savigny', '', 46.5384400, 6.7322200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10838, 'Savièse', 'Saviese', 'Saviese,Savièse,Saviése,sa wei ye si,薩維耶斯', 46.2511500, 7.3455800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10839, 'Sattel', 'Sattel', 'Sattel,Sattel SZ,Zattel'',Заттель', 47.0824600, 8.6356500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10840, 'Satigny', 'Satigny', 'Satin''i,sa di ni,satini,Сатиньи,サティニー,萨蒂尼', 46.2146200, 6.0355300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10841, 'Sarnen', 'Sarnen', 'Gorad Zarnen,Sarnen,Sarno,ZKC,Zarnen,Zarnenas,jaleunen,sa er nen,sarnyn,srnan,srnn,srnyn,zarnn,zarunen,Горад Зарнен,Зарнен,סרנן,زارنن,سارنين,سرنان,سرنین,ザルネン,薩爾嫩,자르넨', 46.8961100, 8.2453100, 'CH', '2015-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10842, 'Sarmenstorf', 'Sarmenstorf', 'Sarmenstorf,Zarmenstorf,sa men si tuo fu,Зарменсторф,薩門斯托夫', 47.3102200, 8.2494900, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10843, 'Sargans', 'Sargans', 'Sargans,Senegaunis,ZKA,Zargans,sa gan si,srgan,Зарганс,سرگان,薩甘斯', 47.0489600, 9.4410300, 'CH', '2013-03-25', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10844, 'Santa Maria in Calanca', 'Santa Maria in Calanca', 'Santa Maria,Santa Maria in Cama,Santa-Marija-in-Kalanka,Sta. Maria in Calanca,Санта-Мария-ин-Каланка', 46.2628500, 9.1448500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10845, 'Sankt Stephan', 'Sankt Stephan', 'Sankt Stephan,Sankt-Shtefan,Sankt-Stefano BE,St. Stephan,sheng si di fen,Санкт-Штефан,聖斯蒂芬', 46.5082700, 7.3955900, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10846, 'Sankt Peterzell', 'Sankt Peterzell', 'Sankt Peterzell,St. Peterzell', 47.3178200, 9.1759900, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10847, 'Sankt Niklaus', 'Sankt Niklaus', 'Sankt Niklaus,St. Niklaus VS', 46.1771700, 7.8034900, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10848, 'Saint Moritz', 'Saint Moritz', 'SMV,Saint Moritz,Saint-Moritz,San Murezzan,Sankt Moritz,Sankt Moritz-Dorf,Sankt Murezzan,Sankta Maurico,Sankta Maŭrico,Sao Moritz,St. Moritz,São Moritz,sanmorittsu,サンモリッツ', 46.4993700, 9.8432700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10849, 'Sankt Margrethen', 'Sankt Margrethen', 'Sankt Margrethen,St. Margrethen SG', 47.4525300, 9.6374100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10850, 'Sankt Gallenkappel', 'Sankt Gallenkappel', 'Sankt Gallenkappel,St. Gallenkappel', 47.2436800, 8.9643800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10851, 'Sankt Gallen', 'Sankt Gallen', 'Saint Gallen,Saint-Gall,San Gallo,San Gallu,San Galo,Sanctogallum,Sankt Gallen,Sankt-Gallen,Sankt-Galo,Son Gagl,St. Gallen,sant ghaln,Санкт-Галлен,سانت غالن', 47.4239100, 9.3747700, 'CH', '2015-07-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10852, 'Sankt Antoni', 'Sankt Antoni', 'Saint-Antoine,Sankt Antoni,St. Antoni,St. Antoni FR', 46.8220700, 7.2609100, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10853, 'Samedan', 'Samedan', 'Samaden,Samedan', 46.5339900, 9.8727600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10854, 'Salvan', 'Salvan', 'Salvan,Salvan VS,Salvan i Sveits,sa er wang,薩爾旺', 46.1189000, 7.0207800, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10855, 'Salmsach', 'Salmsach', 'Salmsach', 47.5543300, 9.3722900, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10856, 'Salgesch', 'Salgesch', 'Salgesch,Salquenen,sa er ge shi,薩爾格施', 46.3115500, 7.5712000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10857, 'Sâles', 'Sales', 'Sal'',Sales,Sâles,sa lei,Саль,薩勒', 46.6347300, 6.9733600, 'CH', '2017-04-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10858, 'Saint-Prex', 'Saint-Prex', 'sheng pu lei,圣普雷', 46.4796300, 6.4599200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10859, 'Saint-Maurice', 'Saint-Maurice', 'Agaunum,Saint-Maurice,Saint-Maurice VS,Saint-Maurice i Sveits,San Mauricio,Sent-Moris,Sent-Môris,sheng mo li si,سن‌موریس,聖莫里斯', 46.2182600, 7.0032000, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10860, 'Saint-Livres', 'Saint-Livres', 'Saint-Livres', 46.5079400, 6.3875300, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10861, 'Saint-Léonard', 'Saint-Leonard', 'Saint-Leonard,Saint-Leonard VS,Saint-Leonard i Sveits,Saint-Léonard,Saint-Léonard VS,Saint-Léonard i Sveits,Sen-Leonar,sheng lun na de,Сен-Леонар,聖倫納德', 46.2515200, 7.4171400, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10862, 'Saint-Imier', 'Saint-Imier', 'Saint-Imier,Sankt Immer,Sent-Im''e,sheng yi mi ye,Сент-Имье,聖伊米耶', 47.1528400, 6.9969200, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10863, 'Sainte-Croix', 'Sainte-Croix', 'Sainte-Croix VD,Sainte-Croix i Sveits,sheng ke wa,圣科瓦', 46.8220300, 6.5028300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10864, 'Saint-Cergue', 'Saint-Cergue', 'Saint-Cergue,sheng sai er ge,圣塞尔格', 46.4459000, 6.1573700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10865, 'Saint-Blaise', 'Saint-Blaise', 'Saint-Blaise,Saint-Blaise NE,Saint-Blaise i Neuchatel,Saint-Blaise i Neuchâtel,sheng bu lai si,聖布萊斯', 47.0151100, 6.9883200, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10866, 'Saint-Aubin-Sauges', 'Saint-Aubin-Sauges', 'sheng ou ban suo re,聖歐班索熱', 46.8941900, 6.7725100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10867, 'Saillon', 'Saillon', 'Saillon,sa yong,sywn,سیون,قلعہ سائلون,薩永', 46.1703500, 7.1877100, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10868, 'Saignelégier', 'Saignelegier', 'Saignelegier,Saignelégier,sai ni e lai ji ye,賽尼厄萊吉耶', 47.2561900, 6.9964800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10869, 'Safenwil', 'Safenwil', 'Safenwil,Zafenvil'',sa fen wei er,Зафенвиль,薩芬維爾', 47.3214000, 7.9812200, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10870, 'Sachseln', 'Sachseln', 'Sachseln,Zaksel''n,Заксельн', 46.8671800, 8.2334400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10871, 'Saas-Grund', 'Saas-Grund', 'sa si ge lun de,薩斯格倫德', 46.1228100, 7.9365100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10872, 'Saas-Fee', 'Saas-Fee', 'Saas Fee,ZKI,Zas-Fe,sa si fei,sas-fyy,zasufe,Зас-Фе,סאס פה,סאס-פע,ساس-فيي,ザースフェー,薩斯費', 46.1080500, 7.9274100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10873, 'Saanen', 'Saanen', 'Saanen,Zanen,sa nen,Занен,萨嫩', 46.4894500, 7.2600300, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10874, 'Rüti', 'Rueti', 'Rjuti,Rueti ZH,Rueti i Zuerich,Rüti ZH,Rüti i Zürich,lu di,rwty  zwrykh,Рюти,روتی، زوریخ,呂蒂', 47.2560300, 8.8555200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10875, 'Rüthi', 'Ruthi', 'Ruethi,Rüthi', 47.2948000, 9.5385700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10876, 'Ruswil', 'Ruswil', 'Rusvil'',Ruswil,lu si wei er,Русвиль,魯斯維爾', 47.0842500, 8.1264500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10877, 'Russikon', 'Russikon', '', 47.3966900, 8.7751500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10878, 'Rüschlikon', 'Ruschlikon', 'Rjushlikon,lu shi li kong,Рюшликон,呂施利孔', 47.3068800, 8.5513500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10879, 'Rüschegg', 'Ruschegg', 'Rjusheg,Rjushegg,Rueschegg,Ruschegg,Rüeschegg,Rüschegg,lu she ge,Рюшег,Рюшегг,呂舍格', 46.7797700, 7.3916700, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10880, 'Rupperswil', 'Rupperswil', 'Ruppersvil'',Rupperswil,lu po si wei er,Рупперсвиль,魯珀斯維爾', 47.4013100, 8.1287700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10881, 'Rümlang', 'Rumlang', 'Rjumlang,lu mu lang,Рюмланг,呂姆朗', 47.4504100, 8.5299300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10882, 'Rüeggisberg', 'Rueggisberg', 'Rjueggisberg,Rjuehggisberg,Rueggisberg,Rüeggisberg,lu ai ji si bei ge,Рюеггисберг,Рюэггисберг,呂埃吉斯貝格', 46.8221600, 7.4389000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10883, 'Rue', 'Rue', 'Rue FR,Rue i Sveits,lu zhen,rw  swyys,رو، سوئیس,呂鎮', 46.6191600, 6.8222500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10884, 'Rudolfstetten', 'Rudolfstetten', 'Rudolfstetten', 47.3710100, 8.3808300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10885, 'Rüderswil', 'Ruderswil', 'Ruderswil,Rüderswil', 46.9837400, 7.7216700, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10886, 'Rubigen', 'Rubigen', '', 46.8986800, 7.5446000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10887, 'Rotkreuz', 'Rotkreuz', 'Rotkreuz', 47.1405900, 8.4293400, 'CH', '2016-09-20', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10888, 'Rothrist', 'Rothrist', 'Rothrist,Rothrist-Dorf,Rotrist,luo te li si te,Ротрист,羅特里斯特', 47.3050800, 7.8919600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10889, 'Rothenthurm', 'Rothenthurm', 'Rotenturm,Rothenthurm', 47.1042000, 8.6758500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10890, 'Röschenz', 'Roschenz', 'Rjoshenc,Roschenz,Röschenz,lei shen ci,Рёшенц,勒申茨', 47.4236600, 7.4802400, 'CH', '2015-06-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10891, 'Rorschach', 'Rorschach', 'Rorschach,Rorshakh,ZJZ,luo er sha he,Роршах,رورشک، سن‌گلان,羅爾沙赫', 47.4780000, 9.4903000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10892, 'Rorbas', 'Rorbas', 'Rorbas,Rorbas-Freienstein', 47.5309200, 8.5755500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10893, 'Root', 'Root', 'Root', 47.1145800, 8.3902100, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10894, 'Romont', 'Romont', 'Romont FR,Romont i Fribourg,Rotundus Mons,luo meng,rwmwn  frybwrg,رومون، فریبورگ,羅蒙', 46.6965200, 6.9189800, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10895, 'Römerswil', 'Roemerswil', 'Rjomersvil'',Roemerswil LU,Romerswil,Römerswil,Römerswil LU,lei mo si wei er,Рёмерсвиль,勒默斯維爾', 47.1681300, 8.2464300, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10896, 'Romanshorn', 'Romanshorn', 'Romanshorn,Romanskhorn,luo man si huo en,Романсхорн,羅曼斯霍恩', 47.5658600, 9.3786900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10897, 'Romanel-sur-Lausanne', 'Romanel-sur-Lausanne', 'Romanel,Romanel-sur-Lausanne', 46.5640300, 6.6053800, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10898, 'Rolle', 'Rolle', 'Rolle VD,Rolle i Sveits,Rolo,luo lei,roru,rwl,رول,ロール,罗勒', 46.4582000, 6.3349900, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10899, 'Rohrbach', 'Rohrbach', 'Rohrbach BE,Rohrbach i Sveits,Rorbakh,luo er ba he,Рорбах,羅爾巴赫', 47.1352100, 7.8133400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10900, 'Rohr', 'Rohr', 'Rohr,Rohr SO,Rohr i Solothurn,Ror,luo er,Рор,羅爾', 47.4102900, 7.9533300, 'CH', '2014-08-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10901, 'Roggwil', 'Roggwil', 'Roggwil,Roggwil TG,Roggwil i Thurgau,Rogvil'',luo ge wei er,Рогвиль,羅格維爾', 47.4998100, 9.3958000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10902, 'Roggwil', 'Roggwil', 'Roggwil BE,Roggwil i Bern,Rogvil'',luo ge wei er,Рогвиль,羅格維爾', 47.2411900, 7.8214100, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10903, 'Rodersdorf', 'Rodersdorf', 'Rodersdorf,luo de si duo fu,Родерсдорф,羅德斯多夫', 47.4822100, 7.4576000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10904, 'Riva San Vitale', 'Riva San Vitale', 'Riva,Riva San Vitale,Vicus Subinates,rywa sn wytl,sheng wei ta lai he cun,ریوا سن ویتل,聖維塔萊河村', 45.9012300, 8.9716700, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10905, 'Ringgenberg', 'Ringgenberg', 'Ringgenberg,Ringgenberg BE,lin gen bei ge,Ринггенберг,林根貝格', 46.7011400, 7.8944500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10906, 'Effretikon / Rikon', 'Effretikon / Rikon', 'Rikon', 47.4467400, 8.7952800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10907, 'Riggisberg', 'Riggisberg', 'Riggisberg,li ji si bei ge,Риггисберг,里吉斯貝格', 46.8102800, 7.4801400, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10908, 'Riedholz', 'Riedholz', 'Ridkhol''c,Riedholz SO,li de huo er ci,Ридхольц,里德霍爾茨', 47.2315800, 7.5682900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10909, 'Riddes', 'Riddes', 'li de,里德', 46.1727600, 7.2236000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10910, 'Rickenbach', 'Rickenbach', 'Rickenbach,Rickenbach TG,Rickenbach b. Wil,Rickenbach bei Wil,Rickenbach i Thurgau,Rikkenbakh,li ken ba he,Риккенбах,里肯巴赫', 47.4493900, 9.0484300, 'CH', '2016-03-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10911, 'Richterswil', 'Richterswil', 'Rikhtersvil'',li xi te si wei er,rykth wyl,Рихтерсвиль,ریکته ویل,里希特斯維爾', 47.2062200, 8.6968600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10912, 'Riaz', 'Riaz', 'Riaz,li ya,里亞', 46.6422400, 7.0618300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10913, 'Rheinfelden', 'Rheinfelden', '', 47.5543700, 7.7940300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10914, 'Rheineck', 'Rheineck', 'Rajnek,Rheineck SG,lai yin ai ke,lainekeu,rainekku,rnk,Райнек,رنک,ライネック,萊茵埃克,라이네크', 47.4663000, 9.5902800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10915, 'Rhäzüns', 'Rhaezuens', 'Razen,Razén,Recjuns,Rhaezuens,Rhäzüns,lei qin si,Рецюнс,雷欽斯', 46.7989100, 9.3976400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10916, 'Renens', 'Renens', 'Renan,Renens,lei nan,rwnan,Ренан,רנאן,رونان,勒南', 46.5398900, 6.5881000, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10917, 'Reinach', 'Reinach', 'Reinach,Reinach AG', 47.2573200, 8.1809100, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10918, 'Reigoldswil', 'Reigoldswil', 'Rajgol''dsvil'',Reigoldswil,lai ge de si wei er,Райгольдсвиль,賴戈德斯維爾', 47.3982400, 7.6871800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10919, 'Reiden', 'Reiden', 'Rajden,lai deng,Райден,賴登', 47.2471900, 7.9713500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10920, 'Reichenburg', 'Reichenburg', 'Rajkhenburg,Reichenburg,Райхенбург', 47.1709700, 8.9770400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10921, 'Rehetobel', 'Rehetobel', 'Rehetobel', 47.4261100, 9.4830000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10922, 'Regensdorf', 'Regensdorf', 'Regensdorf,lei gen si duo fu,rwzhanzdwrf,Регенсдорф,روژانزدورف,雷根斯多夫', 47.4341000, 8.4687400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10923, 'Reconvilier', 'Reconvilier', 'Rekonvil''e,lei kong wei li ye,Реконвилье,雷孔維利耶', 47.2343100, 7.2223900, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10924, 'Rechthalten', 'Rechthalten', 'Rechthalten,lei he ta er teng,雷赫塔爾滕', 46.7676600, 7.2402800, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10925, 'Rebstein', 'Rebstein', 'Rebstein', 47.3981200, 9.5850300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10926, 'Elsau-Räterschen / Räterschen', 'Elsau-Raeterschen / Raeterschen', 'Raeterschen,Räterschen', 47.4992700, 8.7960000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10927, 'Raron', 'Raron', 'Rarogne,Rarognus,Rarona,Rarono,Raroña,la long,拉龙', 46.3119600, 7.8002900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10928, 'Rapperswil', 'Rapperswil', 'Raperswil,Rappersvil'',Rapperswil,Rapperswil SG,la po si wei er,ryprswl,Рапперсвиль,ریپرسول,拉珀斯维尔', 47.2255700, 8.8222800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10929, 'Randogne', 'Randogne', 'Randogne,lan duo nie,蘭多涅', 46.3095200, 7.5005800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10930, 'Ramsen', 'Ramsen', 'Ramsen', 47.7079700, 8.8094900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10931, 'Rafz', 'Rafz', '', 47.6043800, 8.5430500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10932, 'Radelfingen', 'Radelfingen', 'Radel''fingen,Radelfingen,Radelfingen BE,Radelfingen b. Aarberg,la de er fen gen,Радельфинген,拉德爾芬根', 47.0214600, 7.2717800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10933, 'Quarten', 'Quarten', 'Kvarten,Quartus,kua er teng,Квартен,夸爾滕', 47.1070000, 9.2419900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10934, 'Pura', 'Pura', 'Puera,Pura TI,Pura i Sveits,Püra,pu la,普拉', 45.9864700, 8.8687700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10935, 'Pully', 'Pully', 'pi li,pwly,پولی,皮利', 46.5102700, 6.6618300, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10936, 'Puidoux', 'Puidoux', 'Puidoux,pu yi du,普伊杜', 46.5009300, 6.7824900, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10937, 'Promontogno', 'Promontogno', 'Promontogno', 46.3393900, 9.5575900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10938, 'Prilly', 'Prilly', 'pry  swyys,pu li yi,پری، سوئیس,普里伊', 46.5369800, 6.6045600, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10939, 'Pregassona', 'Pregassona', '', 46.0202100, 8.9742900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10940, 'Pratteln', 'Pratteln', 'Prattel''n,prtln,pu la te en,Праттельн,پرتلن,普拉特恩', 47.5207100, 7.6935600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10941, 'Praroman', 'Praroman', 'Praroman', 46.7514500, 7.1777800, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10942, 'Prangins', 'Prangins', 'Prangins,Pranzhen,pu lang ran,Пранжен,普朗然', 46.3951800, 6.2496000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10943, 'Poschiavo', 'Poschiavo', 'Pesclavium,Poschiavo,Poschiavu,Posk''javo,Puscciaf,Puscciâf,Puschlav,bo si ji ya wo,posukiavu~o,Поскьяво,ポスキアーヴォ,波斯基亞沃', 46.3244100, 10.0582300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10944, 'Porrentruy', 'Porrentruy', 'Porentru,Porrentruy,Pruntrut,Purrentrum,bo lang te lu,bwryntry,pwrantrwyy,Порентру,بورينتري,پورانترویی,波朗特呂', 47.4153300, 7.0752200, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10945, 'Pontresina', 'Pontresina', 'Pons Sarisina,Pontresina,Pontrezina,Puntraschigna,ZJV,peng te lei xi na,pontorejina,Понтрезина,Понтрезіна,პონტრეზინა,ポントレジーナ,蓬特雷西納', 46.4955000, 9.9012600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10946, 'La Punt Chamues-ch', 'La Punt Chamues-ch', 'La Punt,La Punt-Chamues-ch,Ponte,Ponte Campovasto', 46.5788700, 9.9201500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10947, 'Plan-les-Ouates', 'Plan-les-Ouates', 'Plan-Les-Ouates,Plan-les-Ouates,Plan-les-Ouattes,Plan-lez-Uat,pu lang lai wu te,puran=re=zu~uato,План-лез-Уат,プラン＝レ＝ズゥアト,普朗莱乌特', 46.1678900, 6.1166400, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10948, 'Plaffeien', 'Plaffeien', 'Plaffeien,Planfayon,pu la fa en,普拉法恩', 46.7419800, 7.2866600, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10949, 'Pieterlen', 'Pieterlen', 'Perles,Piterlen,pi te lun,Питерлен,皮特倫', 47.1750100, 7.3379100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10950, 'Pfyn', 'Pfyn', 'Fines Helvetiorum,Pfin,Pfyn,pu fen,Пфин,普芬', 47.5969300, 8.9542000, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10951, 'Pfungen', 'Pfungen', '', 47.5139400, 8.6423000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10952, 'Pfaffhausen', 'Pfaffhausen', 'Pfaffhausen,Pfaffhusen', 47.3647600, 8.6237500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10953, 'Pfeffingen', 'Pfeffingen', 'Pfeffingen,Pfeffingen BL,pu fei fen gen,Пфеффинген,普費芬根', 47.4598400, 7.5897500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10954, 'Pfaffnau', 'Pfaffnau', 'Pfaffnau,pu fa fu nao,Пфаффнау,普法夫瑙', 47.2277200, 7.8971900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10955, 'Pfäffikon', 'Pfaffikon', 'Faffinchova,Pfaeffikon,Pfaeffikon ZH,Pfaeffikon i Zuerich,Pfeffikon,Pfefikon,Pfäffikon ZH,Pfäffikon i Zürich,pu fei fei kong,Пфефикон,Пфеффикон,普費菲孔', 47.3645300, 8.7920200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10956, 'Pfäffikon', 'Pfaeffikon', 'Pfaeffikon,Pfaeffikon SZ,Pfeffikon,Pfäffikon,Pfäffikon SZ,Пфеффикон', 47.2010900, 8.7781600, 'CH', '2016-09-20', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10957, 'Peseux', 'Peseux', '', 46.9870400, 6.8890300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10958, 'Péry', 'Pery', 'Peri,pei li,Пери,佩里', 47.1939800, 7.2491300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10959, 'Perroy', 'Perroy', 'Perroy', 46.4669000, 6.3534900, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10960, 'Penthalaz', 'Penthalaz', 'pang ta la,庞塔拉', 46.6107700, 6.5251900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10961, 'Payerne', 'Payerne', 'Pajern,Payerna,Payerne,Payèrna,pa ye ne,payeleun,pyrn,Пайерн,Пајерн,پیرن,帕耶讷,파예른', 46.8219200, 6.9381700, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10962, 'Paudex', 'Paudex', '', 46.5054800, 6.6681900, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10963, 'Pampigny', 'Pampigny', 'pang pi ni,庞皮尼', 46.5809300, 6.4294100, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10964, 'Palézieux', 'Palezieux', 'Palezieux,Palezioex,Palèziœx,Palézieux', 46.5419100, 6.8398900, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10965, 'Pailly', 'Pailly', 'Pailly VD', 46.7012300, 6.6754000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10966, 'Ottenbach', 'Ottenbach', '', 47.2822800, 8.4043200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10967, 'Othmarsingen', 'Othmarsingen', 'Othmarsingen,Otmarzingen,ao te ma er xin gen,Отмарзинген,奧特馬爾辛根', 47.4014900, 8.2185200, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10968, 'Otelfingen', 'Otelfingen', 'Otel''fingen,ao te fen gen,Отельфинген,奧特芬根', 47.4605300, 8.3914100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10969, 'Ostermundigen', 'Ostermundigen', 'Ostermundigen,Ostermundingen,ao si te meng di gen,awstrmndyzhan,Остермундиген,Остермундинген,اوسترمندیژان,奧斯特蒙迪根', 46.9569400, 7.4901900, 'CH', '2015-08-09', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10970, 'Orvin', 'Orvin', 'Orven,ao er wen,Орвен,奧爾溫', 47.1606800, 7.2136800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10971, 'Orsières', 'Orsieres', 'Ursiores,ao xi ye er,awrsyr,اورسیر,奧西耶爾', 46.0290300, 7.1443700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10972, 'Orpund', 'Orpund', 'Orpond,Orpund,ao er peng de,Орпунд,奧爾蓬德', 47.1389100, 7.3077500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10973, 'Oron-la-Ville', 'Oron-la-Ville', 'Oron-la-Ville', 46.5709400, 6.8255700, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10974, 'Ormalingen', 'Ormalingen', 'Ormalingen,ao ma lin gen,Ормалинген,奧馬林根', 47.4693600, 7.8724800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10975, 'Orbe', 'Orbe', '', 46.7250400, 6.5306900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10976, 'Opfikon', 'Opfikon', 'Opfikon,Opfikon-Glattbrugg,ao pu fei kong,awpfykwn,Опфикон,اوپفیکون,奧普菲孔', 47.4316900, 8.5758800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10977, 'Onex', 'Onex', 'One,Onex,Onèx,ao nei,awnks  swyys,awnyks,one,Оне,أونيكس,اونکس، سوئیس,オネ,奥内', 46.1839600, 6.1023700, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10978, 'Olten', 'Olten', 'Ol''ten,Olten,ZJU,ao er teng,awltan,awltn,olten,oruten,Олтен,Ольтен,أولتن,اولتان,オルテン,奧爾滕,올텐', 47.3499900, 7.9032900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10979, 'Ollon', 'Ollon', 'Ollon VD,ou long,אולון,欧隆', 46.2952400, 6.9931400, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10980, 'Oftringen', 'Oftringen', 'Oftringen,ao fu te lin gen,awftrnzhan,awftrynjyn,Офтринген,أوفترينجين,اوفترنژان,奧夫特林根', 47.3138200, 7.9253300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10981, 'Oetwil', 'Oetwil am See', 'Oetwil,Oetwil am See', 47.2704900, 8.7202300, 'CH', '2015-05-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10982, 'Zürich (Kreis 11) / Oerlikon', 'Zuerich (Kreis 11) / Oerlikon', 'Oerlikon', 47.4082300, 8.5425800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10983, 'Oensingen', 'Oensingen', 'Ehnzingen,OEnsingen,Oensingen,e xin gen,Önsingen,Энзинген,厄辛根', 47.2863900, 7.7230500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10984, 'Obfelden', 'Obfelden', 'Obfel''den,ao bu fei deng,Обфельден,奧布費登', 47.2641300, 8.4215000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10985, 'Oberwil', 'Oberwil', 'Obervil'',Oberwil BL,awbrwyl,shang wei er,Обервиль,أوبرويل,上維爾', 47.5140700, 7.5578600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10986, 'Wetzikon / Ober-Wetzikon', 'Wetzikon / Ober-Wetzikon', 'Ober-Wetzikon', 47.3251400, 8.8000500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10987, 'Oberuzwil', 'Oberuzwil', 'Oberucvil'',shang wu zi wei er,Оберуцвиль,上烏茲維爾', 47.4307600, 9.1272400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10988, 'Urdorf', 'Ober Urdorf', 'Urdorf,wu duo fu,Урдорф,烏多夫', 47.3850700, 8.4258100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10989, 'Obersiggenthal', 'Obersiggenthal', 'Ober-Siggental,Obersiggenthal,Oberziggental'',shang xi gen ta er,Оберзиггенталь,上錫根塔爾', 47.4875000, 8.2965200, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10990, 'Oberschrot', 'Oberschrot', 'Oberschrot,shang shi luo te,上施羅特', 46.7412600, 7.2814900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10991, 'Oberrüti', 'Oberruti', 'Oberrjuti,shang lu di,Оберрюти,上呂蒂', 47.1667300, 8.3944100, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10992, 'Oberriet', 'Oberriet', 'Oberried,Oberriet,Oberriet SG,Oberrit,oberurito,shang li te,Оберрит,オーベルリート,上里特', 47.3208800, 9.5680800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10993, 'Oberrieden', 'Oberrieden', '', 47.2744400, 8.5783800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10994, 'Oberlunkhofen', 'Oberlunkhofen', 'Oberlunkhofen,Oberlunkkhofen,shang lun huo fen,Оберлункхофен,上倫霍芬', 47.3115000, 8.3914200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10995, 'Oberkirch', 'Oberkirch', 'Oberkirch', 47.1564200, 8.1156700, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10996, 'Oberhelfenschwil', 'Oberhelfenschwil', '', 47.3567300, 9.1107600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10997, 'Obergösgen', 'Obergosgen', 'Obergjosgen,Obergosgen,Obergösgen,shang ge si gen,Обергёсген,上格斯根', 47.3640600, 7.9527500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10998, 'Oberglatt', 'Oberglatt', 'Oberglat,Oberglatt,Oberglatt ZH,shang ge la te,Оберглат,Оберглатт,上格拉特', 47.4757600, 8.5189600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(10999, 'Oberentfelden', 'Oberentfelden', 'Entfelden,Oberentfel''den,shang en te fei er deng,Оберентфельден,上恩特費爾登', 47.3563900, 8.0459400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11000, 'Oberengstringen', 'Oberengstringen', '', 47.4084100, 8.4651500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11001, 'Oberendingen', 'Oberendingen', 'Endingen,Oberendingen', 47.5363600, 8.2933900, 'CH', '2017-04-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11002, 'Oberegg', 'Oberegg', 'Obereg,Oberegg,Oberegg AI,Oberegg District,Оберег,Оберегг', 47.4253100, 9.5513400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11003, 'Oberdorf', 'Oberdorf', 'Oberdorf,Oberdorf BL,Oberdorf i Basel-Landschaft,shang duo fu,Обердорф,上多夫', 47.3930800, 7.7512200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11004, 'Oberdiessbach', 'Oberdiessbach', 'Oberdisbakh,shang di si ba he,Обердисбах,上迪斯巴赫', 46.8411700, 7.6173000, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11005, 'Oberburg', 'Oberburg', 'Oberburg', 47.0366500, 7.6274500, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11006, 'Oberbuchsiten', 'Oberbuchsiten', 'Oberbuksiten,shang bu he xi he,Обербукситен,上布赫錫赫', 47.3133400, 7.7683600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11007, 'Oberbipp', 'Oberbipp', 'Oberbip,Oberbipp,shang bi pu,Обербип,Обербипп,上比普', 47.2607000, 7.6635900, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11008, 'Nyon', 'Nyon', 'Noviodunum,Nyon,ZRN,n''on,Ньон', 46.3831800, 6.2395500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11009, 'Nürensdorf', 'Nurensdorf', '', 47.4481400, 8.6490800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11010, 'Nunningen', 'Nunningen', 'Nunningen,nong ning gen,Нуннинген,農寧根', 47.3945000, 7.6212200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11011, 'Novazzano', 'Novazzano', 'Novazzan,nuo wa zha nuo,諾瓦扎諾', 45.8407300, 8.9823600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11012, 'Nottwil', 'Nottwil', 'Nottvil'',Nottwil,nuo te wei er,Ноттвиль,諾特維爾', 47.1346900, 8.1377400, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11013, 'Niederwichtrach', 'Niederwichtrach', 'Wichtrach', 46.8501000, 7.5774800, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11014, 'Niederurnen', 'Niederurnen', 'Niderurnen,Нидерурнен', 47.1259800, 9.0542800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11015, 'Niederrohrdorf', 'Niederrohrdorf', 'Niderrordorf,Niederrohrdorf,Rohrdorf,xia luo er duo fu,Нидеррордорф,下羅爾多夫', 47.4235200, 8.3064300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11016, 'Niederlenz', 'Niederlenz', 'Niderlenc,xia lun ci,Нидерленц,下倫茨', 47.4007900, 8.1764000, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11017, 'Niederhelfenschwil', 'Niederhelfenschwil', '', 47.4748700, 9.1854300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11018, 'Niedergösgen', 'Niedergosgen', 'Goesgen,Gösgen,Nidergjosgen,Niedergoesgen,Niedergösgen,xia ge si gen,Нидергёсген,下格斯根', 47.3721700, 7.9912200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11019, 'Niedererlinsbach', 'Niedererlinsbach', 'Erlinsbach,Niedererlinsbach', 47.3975300, 8.0079700, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11020, 'Niederbüren', 'Niederburen', 'Buren,Büren,Niederbueren,Niederbüren', 47.4654700, 9.2056800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11021, 'Niederbipp', 'Niederbipp', 'Niderbip,Niderbipp,Niederbipp,xia bi pu,Нидербип,Нидербипп,下比普', 47.2661300, 7.6946100, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11022, 'Nidau', 'Nidau', 'Nidau,ni dao,nydw,Нидау,نیدو,尼道', 47.1254500, 7.2403300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11023, 'Neunkirch', 'Neunkirch', 'Nojnkirkh,nkyrk,nuo yin ji xi,Нойнкирх,نکیرک,諾因基希', 47.6901200, 8.4998100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11024, 'Neuhausen', 'Neuhausen', 'Neuhausen,Neuhausen am Rheinfall', 47.6857900, 8.6147400, 'CH', '2014-05-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11025, 'Neuenkirch', 'Neuenkirch', 'Neuenkirch,Nojenkirkh,nuo yi en ji er he,Нойенкирх,諾伊恩基爾赫', 47.0998900, 8.2041600, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11026, 'Neuenhof', 'Neuenhof', 'Neuenhof', 47.4526000, 8.3257700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11027, 'Neudorf', 'Neudorf', 'Neudorf', 47.1769900, 8.2091100, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11028, 'Neuchâtel', 'Neuchatel', 'Gorad Njoushatehl'',N''oshatel,Nesatelis,Neshatel,Neuchatel,Neuchâtel,Neuenburg,Neusatelo,Nevshatel'',Nešatelis,Neŭŝatelo,Nochathel,Novicastrum,Nôchâthél,QNC,n''yusatela,na sha tai er,noesyatel,nushateru,nwshatl,nwshatyl,nywshatyl,Горад Нёўшатэль,Невшатель,Нешател,Ньошател,נשאטל,نوشاتل,نوشاتيل,نیوشاتیل,न्यूशातेल,ヌーシャテル,纳沙泰尔,뇌샤텔', 46.9917900, 6.9310000, 'CH', '2015-03-16', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11029, 'Netstal', 'Netstal', 'Netstal', 47.0633700, 9.0573400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11030, 'Neftenbach / Dorf Neftenbach', 'Neftenbach / Dorf Neftenbach', 'Dorf Neftenbach,Neftenbach', 47.5276400, 8.6649000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11031, 'Nebikon', 'Nebikon', 'Nebikon', 47.1918500, 7.9776900, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11032, 'Naters', 'Naters', 'Nares,na te,nateleuseu,nateoseu,neiteoseu,納特,나터스,나테르스,네이터스', 46.3253600, 7.9891200, 'CH', '2017-06-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11033, 'Nänikon', 'Nanikon', '', 47.3697500, 8.6889400, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11034, 'Näfels', 'Nafels', 'Nafels,Nefel''s,Näfels,naflz,Нефельс,نافلز', 47.0977500, 9.0636100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11035, 'Muttenz', 'Muttenz', 'Muttenc,mu teng ci,mwtanz,Муттенц,موتانز,穆滕茨', 47.5227100, 7.6451100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11036, 'Murten/Morat', 'Murten/Morat', 'Morat,Morato,Muratum,Murten,Murten/Morat,mu er teng,mwrtan,Муртен,Муртен/Морат,مورتان,穆爾滕', 46.9282700, 7.1171500, 'CH', '2015-12-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11037, 'Muri', 'Muri', 'Muri,Muri AG', 47.2742800, 8.3385400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11038, 'Muri', 'Muri', 'Muri,Muri b. Bern,Muri bei Bern', 46.9312200, 7.4865800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11039, 'Murgenthal', 'Murgenthal', 'Murgental,Murgental'',Murgenthal,Мургенталь', 47.2714500, 7.8393500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11040, 'Muotathal', 'Muotathal', 'Muotatal,Muotatal'',Muotathal,Муотаталь', 46.9767600, 8.7649900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11041, 'Muolen', 'Muolen', 'Muolen', 47.5210200, 9.3248400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11042, 'Müntschemier', 'Muentschemier', 'Monsmier', 46.9954800, 7.1462600, 'CH', '2017-06-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11043, 'Münsterlingen', 'Munsterlingen', 'Mjunsterlingen,Muensterlingen TG,Munsterlingen,Münsterlingen,Münsterlingen TG,ming si te lin gen,Мюнстерлинген,明斯特林根', 47.6319700, 9.2327100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11044, 'Münsingen', 'Munsingen', '', 46.8729800, 7.5610000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11045, 'Münchwilen', 'Munchwilen', 'Mjunkhvilen,Muenchwilen,Muenchwilen TG,Muenchwilen i Thurgau,Münchwilen,Münchwilen TG,Münchwilen i Thurgau,ming bu wei lun,Мюнхвилен,明布維倫', 47.4771900, 8.9967700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11046, 'Münchenstein', 'Munchenstein', 'Miunchenstainas,Miunchenštainas,Mjunkhenshtajn,ming xing shi tai yin,mwnshanstn,mynshynstayn,Мюнхенштайн,مونشانستن,مينشينستاين,明興施泰因', 47.5184800, 7.6096600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11047, 'Münchenbuchsee', 'Munchenbuchsee', 'Mjunkhenbukhzee,Mjunkhenbukse,ming xing bu he sai,Мюнхенбуксе,Мюнхенбухзее,明興布赫塞', 47.0217500, 7.4503600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11048, 'Mumpf', 'Mumpf', 'Mumpf,meng pu fu,Мумпф,蒙普夫', 47.5456300, 7.9212300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11049, 'Müllheim', 'Mullheim', 'Mjul''khajm,Mjull''khajm,Muellheim Dorf,Muellheim TG,Muellheim i Sveits,Mullheim,Müllheim,Müllheim Dorf,Müllheim TG,Müllheim i Sveits,mi er hai mu,Мюлльхайм,Мюльхайм,米爾海姆', 47.6019500, 9.0035700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11050, 'Mühlethurnen', 'Muhlethurnen', 'Mjuleturnen,Muehlethurnen,Mühlethurnen,mi lei tu er nen,Мюлетурнен,米勒圖爾嫩', 46.8134500, 7.5088100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11051, 'Mühleberg', 'Muhleberg', 'Mjuleberg,Muehleberg BE,Mühleberg BE,mi lei bei ge,Мюлеберг,米勒貝格', 46.9546600, 7.2610200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11052, 'Muhen', 'Muhen', 'Mittel-Muhen,Muehn,Muhen,mu heng,Муэн,穆亨', 47.3367100, 8.0540800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11053, 'Moutier', 'Moutier', 'Monasterium Grandis Vallis,Moutier,Mut''e,Picswiss BE-97-04 Moutier.jpg|thumb|left|300px|Vy oever Moutier,Picswiss BE-97-04 Moutier.jpg|thumb|left|300px|Vy över Moutier,mu jie,mwtyh,Мутье,موتیه,穆捷', 47.2781800, 7.3695100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11054, 'Moudon', 'Moudon', 'Moudon,mu dong,mwdwn  swyys,مودون، سوئیس,穆东', 46.6675800, 6.7978100, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11055, 'Mosnang', 'Mosnang', 'Mosnang,mo si nan,Моснанг,莫斯南', 47.3625200, 9.0429600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11056, 'Mörschwil', 'Morschwil', 'Mjorshvil'',Morschwil,Mörschwil,mo shi wei er,Мёршвиль,默施維爾', 47.4709700, 9.4227800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11057, 'Morges', 'Morges', 'Morgia,Morzh,ZJQ,mo er ri,moleuju,moruju,mwrjys,mwrzh,Морж,مورجيس,مورژ,モルジュ,莫尔日,모르주', 46.5112700, 6.4985400, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11058, 'Morbio Inferiore', 'Morbio Inferiore', 'Morbi da Sott,Morbio,Morbio Inferiore,Morbius Inferior,xia mo er bi ao,下莫爾比奧', 45.8491500, 9.0190700, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11059, 'Montreux', 'Montreux', 'Montr''o,Montre,Montreux,Montreux VD,Montrjo,Montroe,Montrö,Montrė,ZJP,meng te lei,mongteuloe,montoru,montriyu,mwntrh,mwntrw,Μοντρέ,Монтре,Монтрьо,Монтрё,מאנטרע,מונטרה,مونترو,मोंट्रियू,მონტრე,モントルー,蒙特勒,몽트뢰', 46.4330100, 6.9114300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11060, 'Monthey', 'Monthey', 'Monte,Monthey,Montê,meng tai,mongte,monte,mwnth,mwnthy,Монте,מונטה,مونته,مونثي,モンテー,蒙泰,몽테', 46.2545100, 6.9540600, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11061, 'Monte Carasso', 'Monte Carasso', 'Monte Carasso-Sementina', 46.1864900, 8.9989200, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11062, 'Montana', 'Montana', 'Montana,Montana VS,Montana Vermala,Montana i Sveits,meng ta na,蒙塔納', 46.3133800, 7.4883900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11063, 'Montagny', 'Montagny', 'Montagny-pres-Yverdon,Montagny-près-Yverdon', 46.7928900, 6.6122200, 'CH', '2010-04-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11064, 'Montagnola', 'Montagnola', 'Montagnola', 45.9832300, 8.9178600, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11065, 'Mönchaltorf', 'Monchaltorf', '', 47.3095800, 8.7202900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11066, 'Mollis', 'Mollis', 'Mollis,Моллис', 47.0887800, 9.0724200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11067, 'Mollens', 'Mollens', 'Mollens', 46.5776000, 6.3632000, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11068, 'Möhlin', 'Mohlin', 'Mjolin,Moehlin AG,Möhlin AG,mo lin,Мёлин,默林', 47.5591500, 7.8432900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11069, 'Mogelsberg', 'Mogelsberg', 'Mogelsberg', 47.3622200, 9.1354100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11070, 'Minusio', 'Minusio', 'Menuxius,Minues,Minuzio,Minüs,mi nu xiao,Минузио,米努肖', 46.1776900, 8.8147300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11071, 'Mézières', 'Mezieres', '', 46.6795800, 6.9263000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11072, 'Meyrin', 'Meyrin', 'Meren,Merin,Mêrin,mei lan,meiran,myrn,myryn,Мерен,ميرين,میرن,メイラン,梅兰', 46.2342400, 6.0802500, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11073, 'Mettmenstetten', 'Mettmenstetten', 'Metmenshtetten,mei te men si te teng,Метменштеттен,梅特門斯特滕', 47.2452900, 8.4634700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11074, 'Messen', 'Messen', 'Messen,Messen SO,mei sen,Мессен,梅森', 47.0912800, 7.4495700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11075, 'Mesocco', 'Mesocco', 'Mesocco,Mesoch,Mesoko,Mezokko,Misox,mei suo ke,Мезокко,梅索科', 46.3939000, 9.2333300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11076, 'Merenschwand', 'Merenschwand', 'Merenschwand,Merenshvand,mei lun shen wan de,Мереншванд,梅倫什萬德', 47.2587000, 8.3753200, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11077, 'Menznau', 'Menznau', 'Mencnau,Menznau,men ci nao,Менцнау,門茨瑙', 47.0836400, 8.0397100, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11078, 'Menzingen', 'Menzingen', 'Mencingen,Menzingen,Menzingen ZG,Менцинген', 47.1776400, 8.5921500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11079, 'Menziken', 'Menziken', 'Menciken,Menziken,Менцикен', 47.2424900, 8.1904700, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11080, 'Mendrisio', 'Mendrisio', 'Mendris,Mendrisio,Mendrium,Mendrizio,mandryzyw,men de li xi ao,Мендризио,ماندریزیو,門德里西奧', 45.8701900, 8.9816000, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11081, 'Mellingen', 'Mellingen', 'Mellinga,Mellingen,Mellingen AG', 47.4190300, 8.2733100, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11082, 'Melide', 'Melide', 'Melide TI,Melide i Sveits,Melii,mei li de,梅利德', 45.9545500, 8.9472500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11083, 'Melchnau', 'Melchnau', 'Mel''khnau,Melchnau,mai xi nao,Мельхнау,邁希瑙', 47.1821300, 7.8512800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11084, 'Melano', 'Melano', 'Melan,Melano,Mellanum,mei la nuo,梅拉諾', 45.9220200, 8.9843500, 'CH', '2016-12-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11085, 'Meisterschwanden', 'Meisterschwanden', 'Majstershvanden,mai si te shi wan deng,Майстершванден,邁斯特施萬登', 47.2948900, 8.2286700, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11086, 'Meiringen', 'Meiringen', 'Majringen,Meiringen,Meyringen,mai lin gen,Майринген,迈林根', 46.7270900, 8.1872000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11087, 'Meinisberg', 'Meinisberg', 'Majnisberg,Montmenil,Montménil,mai ni si bei ge,Майнисберг,邁尼斯貝格', 47.1596500, 7.3480100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11088, 'Meilen', 'Meilen', 'Majlen,Meilana,mai lun,myan,Майлен,Мајлен,میان,邁倫', 47.2723200, 8.6461700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11089, 'Meierskappel', 'Meierskappel', 'Meierskappel', 47.1247000, 8.4427400, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11090, 'Meggen', 'Meggen', '', 47.0469100, 8.3746700, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11091, 'Mauensee', 'Mauensee', 'Mauensee', 47.1684700, 8.0661700, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11092, 'Matzingen', 'Matzingen', 'Matcingen,Matzingen,ma qin gen,Матцинген,馬欽根', 47.5195700, 8.9336500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11093, 'Matzendorf', 'Matzendorf', 'Matcendorf,Matzendorf SO,ma cen duo fu,Матцендорф,馬岑多夫', 47.3037400, 7.6282000, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11094, 'Matten', 'Matten', 'Matten,Matten b.I.,Matten bei Interlaken', 46.6783300, 7.8688900, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11095, 'Massagno', 'Massagno', 'Massagn,Massagno,Maxanius,ma sa ni ao,馬薩尼奧', 46.0125700, 8.9435400, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11096, 'Martigny-Ville', 'Martigny-Ville', 'Martigny', 46.1027600, 7.0724500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11097, 'Martigny-Combe', 'Martigny-Combe', 'ma di ni-kong bu,馬蒂尼-孔布', 46.0781700, 7.0509900, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11098, 'Marthalen', 'Marthalen', 'Martalen,Martella,ma ta lun,Мартален,馬塔倫', 47.6291300, 8.6532600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11099, 'Märstetten-Dorf', 'Maerstetten-Dorf', 'CH MAR,Maerstetten,Marestetin,Marstettin,Märstetten', 47.5925200, 9.0685100, 'CH', '2013-05-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11100, 'Marsens', 'Marsens', 'Marsens,ma er sang,馬爾桑', 46.6564400, 7.0594800, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11101, 'Marly', 'Marly', '', 46.7761100, 7.1645900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11102, 'Männedorf', 'Mannedorf', 'Mennedorf,men nei duo fu,Меннедорф,門內多夫', 47.2568600, 8.6989300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11103, 'Malvaglia', 'Malvaglia', 'Malvaglia,Malvaja', 46.4058800, 8.9819000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11104, 'Malters', 'Malters', 'Mal''ters,Malters,ma er te si,Мальтерс,馬爾特斯', 47.0362800, 8.1819300, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11105, 'Malleray', 'Malleray', 'Mal''re,Mall''re,Malleray-Bevilard,Malleray-Bévilard,ma lei lai,Малльре,Мальре,馬勒賴', 47.2383900, 7.2728600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11106, 'Malans', 'Malans', 'Malans,Malans GR,ma lan si,Маланс,馬蘭斯', 46.9809600, 9.5752700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11107, 'Maienfeld', 'Maienfeld', 'Lupinum,Maiavilla,Maienfeld,Maienfeld GR,Majenfel''d,Majenfeld,mai en fei er de,maienferuto,maienpelteu,maynfyld,myanfld,Майенфелд,Майенфельд,ماينفيلد,میانفلد,マイエンフェルト,邁恩費爾德,마이엔펠트', 47.0047200, 9.5311500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11108, 'Magden', 'Magden', 'Magden,ma ge deng,Магден,馬格登', 47.5286800, 7.8112800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11109, 'Magadino', 'Magadino', 'Magadign,ماگاڈینو', 46.1489200, 8.8561000, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11110, 'Madiswil', 'Madiswil', 'Madisvil'',ma di si wei er,Мадисвиль,馬迪斯維爾', 47.1646300, 7.7985800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11111, 'Lyssach', 'Lyssach', 'Lisakh,Lissakh,li sa he,Лисах,Лиссах,利薩赫', 47.0644500, 7.5822800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11112, 'Lyss', 'Lyss', 'Lis,Lyss,ZJL,li si,liseu,lys,Лис,لیس,利斯,리스', 47.0741000, 7.3065500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11113, 'Luzern', 'Luzern', 'Canton Lucerne,Gorad Ljucehrn,Liucerna,Ljucern,Loukerne,Lucern,Lucerna,Lucerne,Lucerni,Lucerno,Luezerna,Luxerna,Luzern,Luzerna,Lüzerna,Medicago sativa,lu sai en,lucheleun,lutsarna,lutserni,lwsrn,lwzrn,rutsu~erun,Łuxerna,Λουκέρνη,Горад Люцэрн,Луцерн,Люцерн,לוצערן,לוצרן,لوسرن,लुत्सर्न,ལུ་ཛེར་ན།,ლუცერნი,ルツェルン,卢塞恩,루체른', 47.0504800, 8.3063500, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11114, 'Luzein', 'Luzein', 'Lucajn,Luzein,lu cai yin,Луцайн,盧蔡因', 46.9195700, 9.7608000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11115, 'Lützelflüh', 'Lutzelfluh', 'Ljutcel''flju,Luetzelflueh,Luetzelflueh-Goldbach,Lutzelfluh,Lützelflüh,Lützelflüh-Goldbach,lu ce er fu lu,Лютцельфлю,呂策爾弗呂', 47.0075700, 7.6916500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11116, 'Lutry', 'Lutry', 'Ljutri,lu te li,lwtry,Лютри,لوتری,吕特里', 46.5024100, 6.6864700, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11117, 'Lütisburg', 'Lutisburg', 'Luetisburg,Luetisburg-Dorf,Lütisburg,Lütisburg-Dorf', 47.3945100, 9.0831200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11118, 'Luthern', 'Luthern', 'Ljutern,Luthern,lu te en,Лютерн,盧特恩', 47.0575300, 7.9169200, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11119, 'Luterbach', 'Luterbach', 'Luterbach', 47.2142600, 7.5846300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11120, 'Lungern', 'Lungern', 'Lungern,long jiang,Лунгерн,龍疆', 46.7857800, 8.1598400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11121, 'Lumino', 'Lumino', 'Lumino', 46.2302000, 9.0642000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11122, 'Lugano', 'Lugano', 'Gorad Lugana,LUG,Lounkano,Luegan,Lugan,Luganas,Lugano,Luganu,Luganum,Lugāno,Lügan,lu jia nuo,luganea,lugano,lwganw,lwghanw,lwgnw,rugano,Ługàn,Λουγκάνο,Горад Лугана,Лугано,Луґано,Լուգանո,לוגאנא,לוגאנו,لوغانو,لوگانو,لوگنو,लुगानो,ലുഗാനോ,ལུ་ག་ནོ།,ლუგანო,ルガーノ,盧加諾,루가노', 46.0100800, 8.9600400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11123, 'Luchsingen', 'Luchsingen', 'Luchsingen,Luchsingen-Haetzingen,Luchsingen-Hätzingen,Luksingen,Луксинген', 46.9664000, 9.0371500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11124, 'Lucens', 'Lucens', 'lu sang,吕桑', 46.7085400, 6.8393100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11125, 'Lotzwil', 'Lotzwil', 'Locvil'',luo ci wei er,Лоцвиль,洛茨維爾', 47.1913500, 7.7910200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11126, 'Lostorf', 'Lostorf', 'Lostorf,luo shi tuo fu,Лосторф,洛施托夫', 47.3837200, 7.9465500, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11127, 'Losone', 'Losone', 'Loson,luo suo nei,lwzwn  swyys,لوزون، سوئیس,洛索內', 46.1686600, 8.7592800, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11128, 'Lodrino', 'Lodrino', 'Lodrino TI,Ludrin,luo de li nuo,洛德里諾', 46.3001600, 8.9798600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11129, 'Locarno', 'Locarno', 'Gorad Lakarna,Locarn,Locarno,Locarnu,Locarnum,Lokarnas,Lokarno,ZJI,lokaleuno,luo jia nuo,lwkarnw,lwqrnw,rokaruno,Λοκάρνο,Горад Лакарна,Локарно,לוקרנו,لوكارنو,لوکارنو,ლოკარნო,ロカルノ,洛迦诺,로카르노', 46.1708600, 8.7995300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11130, 'Littau', 'Littau', 'Littau,li tao,lytw  lwsrn,Литтау,لیتو، لوسرن,利陶', 47.0500000, 8.2627400, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11131, 'Linthal', 'Linthal', 'Lintal'',Linthal,Linthal GL,Linththal,lan ta,Линталь,لینتھل,兰塔', 46.9212700, 8.9979900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11132, 'Linden', 'Linden', 'Linden,Linden BE,Linden bei Oberdiessbach,Linden i Sveits,lin deng,Линден,林登', 46.8487200, 7.6749100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11133, 'Ligornetto', 'Ligornetto', 'Ligornetto,Ligurnet,li ge er nei tuo,利戈爾內托', 45.8616100, 8.9516600, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11134, 'Liestal', 'Liestal', 'Gorad Listal'',Laucostabulum,Liestal,Listal,Listal'',Listalis,li si ta er,liseutal,lstl,lystal,lystl,risutaru,Λίσταλ,Горад Лісталь,Листал,Листаль,Лісталь,ליאשטל,لستل,ليستل,لیزٹال,لیستال,リースタル,利斯塔爾,리스탈', 47.4845500, 7.7344600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11135, 'Liesberg', 'Liesberg', 'Lisberg,li si bo ge,Лисберг,利斯伯格', 47.4039800, 7.4278700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11136, 'Lichtensteig', 'Lichtensteig', 'Likhtenshtejg,li xi teng shi tai ge,lyktanstg,Лихтенштейг,لیکتانستگ,利希滕施泰格', 47.3238100, 9.0875800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11137, 'Leytron', 'Leytron', 'lai te long,萊特龍', 46.1866000, 7.2078000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11138, 'Leysin', 'Leysin', 'Lesin,Leysini vald,Lezen,Lêsin,lai sen,rezan,Лезен,לזאן,レザン,莱森', 46.3418300, 7.0115100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11139, 'Le Vaud', 'Le Vaud', 'Vaud', 46.4775300, 6.2360300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11140, 'Leuzigen', 'Leuzigen', 'Leuzigen,Ljojcigen,Lojcigen,luo yi qi gen,Лойциген,Лёйциген,羅伊齊根', 47.1745800, 7.4577500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11141, 'Leukerbad', 'Leukerbad', 'Loeche-les-Bains,Lojkerbad,Loèche-les-Bains,luo yi ke ba de,roikabato,Лойкербад,לויקרבאד,ロイカーバート,洛伊克巴德', 46.3794300, 7.6268700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11142, 'Leuk', 'Leuk', 'Leuk,Leuk Stadt,Loeche,Loueche,Louèche,Loèche,Villa de Leuca,loikeu,luo yi ke,lwk,lyk,roiku,لوک,ليك,ロイク,洛伊克,로이크', 46.3173600, 7.6341200, 'CH', '2016-07-18', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11143, 'Les Ponts-de-Martel', 'Les Ponts-de-Martel', 'Les Ponts-Martel,Les Ponts-de-Martel,lai peng de ma er tai lei,萊蓬德馬爾泰勒', 46.9973500, 6.7305900, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11144, 'Les Geneveys-sur-Coffrane', 'Les Geneveys-sur-Coffrane', 'Les Geneveys-sur-Coffrane', 47.0152800, 6.8513000, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11145, 'Les Breuleux', 'Les Breuleux', 'Les Breuleux,lei bu lei lei,勒布勒勒', 47.2109900, 7.0079200, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11146, 'Les Brenets', 'Les Brenets', 'Les Brenets,lai bu lei nei,萊布雷內', 47.0677400, 6.7047800, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11147, 'Les Bois', 'Les Bois', 'Les Bois,lei bu wa,勒布瓦', 47.1771500, 6.9049800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11148, 'Lenzerheide', 'Lenzerheide', 'Lai,Lencerkhajde,Lenzerheide,Lenzerheide/Lai,Ленцерхайде,Ленцерхајде', 46.7221500, 9.5590500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11149, 'Lenzburg', 'Lenzburg', 'Lencburg,Lencburgo,Lenzbourg,Lenzburg,ZJC,lanzbwrg,lnzbwrg,lun ci bao,Ленцбург,לנצבורג,لانزبورگ,倫茨堡', 47.3885300, 8.1750300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11150, 'Lens', 'Lens', 'Lens,Lens VS,Lens i Valais,lun si,倫斯', 46.2829800, 7.4497600, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11151, 'Le Noirmont', 'Le Noirmont', 'Le Noirmont,Noirmont,lei nu wa mang,勒努瓦芒', 47.2256700, 6.9573000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11152, 'Lenk', 'Lenk', 'Lenk im Simmental', 46.4582600, 7.4429800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11153, 'Lengnau', 'Lengnau', 'Lengnau,Lengnau BE,Lengnau bei Biel,Lengnau i Bern,Longeau,lun nao,Ленгнау,倫瑙', 47.1815500, 7.3681400, 'CH', '2016-01-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11154, 'Le Mont-sur-Lausanne', 'Le Mont-sur-Lausanne', 'Le Mont,luo sang shang lei meng,洛桑上勒蒙', 46.5581500, 6.6314500, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11155, 'Le Locle', 'Le Locle', 'Le Locle,Le Lokl,Le-Lokl'',ZJA,leulokeul,li luo ke,lw lwkl,Ле Локл,Ле-Локль,لو لوكل,لو لوکل,ル・ロックル,力洛克,르로클', 47.0561900, 6.7491300, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11156, 'Le Landeron', 'Le Landeron', 'Laneron,Laneron-Combes,Le Landeron,lei lang de long,lw landwrwn,لو لاندورون,勒朗德龍', 47.0570200, 7.0705200, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11157, 'Leibstadt', 'Leibstadt', 'Lajbshtadt,Leibstadt,lai bu shi ta te,Лайбштадт,萊布施塔特', 47.5879000, 8.1761100, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11158, 'Le Chenit', 'Le Chenit', 'Lo Chenit,lei she ni,勒舍尼', 46.6068800, 6.2306200, 'CH', '2010-04-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11159, 'Le Châtelard', 'Le Chatelard', 'Chatelard,Châtelard,Le Chatelard,Le Chatelard-Montreux,Le Châtelard,Le Châtelard-Montreux,Shatlar,Шатлар', 46.4452700, 6.8990800, 'CH', '2012-01-17', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11160, 'Lavertezzo', 'Lavertezzo', 'Lavertezzo,Vertezz,la wei er tai zuo,拉韋爾泰佐', 46.2589300, 8.8375600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11161, 'Lauterbrunnen', 'Lauterbrunnen', 'Lauterbrunnen,lauteobeulunen,lu da ben na,rautaburun''nen,Лаутербруннен,ラウターブルンネン,盧達本納,라우터브루넨', 46.5930700, 7.9093800, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11162, 'Lausen', 'Lausen', 'Lausen BL,Lauzen,lao sen,Лаузен,勞森', 47.4713900, 7.7603000, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11163, 'Lausanne', 'Lausanne', 'Lausana,Lausanne,Lausonium,Lauzano,Laŭzano,Losanna,Losena,Lozan,Lozana,Lozane,Lozanna,QLS,lo san,luo sang,rozan''nu,Λωζάνη,Лозана,Лозанна,לוזאן,โลซาน,ローザンヌ,洛桑', 46.5160000, 6.6328200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11164, 'Lauperswil', 'Lauperswil', 'Laupersvil'',Lauperswil,lao po si wei er,Лауперсвиль,勞珀斯維爾', 46.9656400, 7.7421400, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11165, 'Laupersdorf', 'Laupersdorf', 'Laupersdorf,lao po si duo fu,Лауперсдорф,勞珀斯多夫', 47.3142600, 7.6505300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11166, 'Laupen', 'Laupen', 'Laupen,Laupen BE,Laupen i Bern,lao peng,lwpan  brn,raupen,Лаупен,لوپان، برن,ラウペン,勞彭', 46.9021400, 7.2397300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11167, 'Laufenburg', 'Laufenburg', '', 47.5598500, 8.0622500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11168, 'Laufen', 'Laufen', 'Laufen,Laufen BL,Laufon,lao fen,Лауфен,勞芬', 47.4219300, 7.4994600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11169, 'Läufelfingen', 'Laufelfingen', 'Laeufelfingen,Lojfel''fingen,luo yi fu fen gen,Лойфельфинген,洛伊弗芬根', 47.3945700, 7.8557800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11170, 'La Tour-de-Trême', 'La Tour-de-Treme', 'La Tour-de-Treme,La Tour-de-Trême,Tour de Treme', 46.6106100, 7.0649600, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11171, 'La Tour-de-Peilz', 'La Tour-de-Peilz', 'la tu er de pei lei,ltwr dw plz,لتور دو پلز,拉图尔德佩勒', 46.4531200, 6.8585600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11172, 'La Sarraz', 'La Sarraz', '', 46.6586300, 6.5107700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11173, 'La Roche', 'La Roche', 'La Roche,La Roche FR,la luo shen,拉羅什', 46.6962000, 7.1372100, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11174, 'Langrickenbach', 'Langrickenbach', 'Langrickenbach,Langrikkenbakh,lang li ken ba he,Лангриккенбах,朗里肯巴赫', 47.5935300, 9.2472700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11175, 'Langnau / Langnau (Dorf)', 'Langnau / Langnau (Dorf)', 'Langnau (Dorf)', 47.2864300, 8.5362700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11176, 'Langnau', 'Langnau', 'Langnau,Langnau im Emmental', 46.9393600, 7.7873800, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11177, 'Langenthal', 'Langenthal', 'Langental,Langental'',Langenthal,Langenthal BE,ZHW,lang gen ta er,lanzhantl  swyys,Лангенталь,لانژانتل، سوئیس,朗根塔爾', 47.2152600, 7.7960700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11178, 'Langenbruck', 'Langenbruck', 'Langenbruk,lan gen bu lu ke,Лангенбрук,蘭根布魯克', 47.3491700, 7.7680200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11179, 'La Neuveville', 'La Neuveville', 'La Neuveville,La-Njovvil'',la nuo yi wei wei er,lnww wyl,Ла-Нёввиль,لنوو ویل,拉諾伊韋維爾', 47.0659200, 7.0971700, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11180, 'Landquart', 'Landquart', 'Landkvart,Landquart GR,Ландкварт', 46.9500000, 9.5666700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11181, 'Lachen', 'Lachen', 'Lachen,Lachen SZ,Lakhen,lshan  shwyyz,Лахен,لشان، شوئیز', 47.1992700, 8.8543200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11182, 'La Chaux-de-Fonds', 'La Chaux-de-Fonds', 'Chaux-de-Fonds,La Chaux de Fonda,La Chaux-de-Fonds,La Sho d''o Fon,La Sho-de-Fon,La-Sho-de-Fon,Sho de Fon,So de Fonas,ZHV,la shao de feng,la shw dw fwn,la-sho-de-poni,lasyodeupong,lshw dw fwnd,Šo de Fonas,Ла Шо дьо Фон,Ла Шо-де-Фон,Ла-Шо-де-Фон,Шо де Фон,لا شو دو فون,لشو دو فوند,ლა-შო-დე-ფონი,ラ・ショー＝ド＝フォン,拉紹德封,라쇼드퐁', 47.0999300, 6.8258600, 'CH', '2014-01-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11183, 'L''Abbaye', 'L''Abbaye', 'L''Abbaye', 46.6496600, 6.3190700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11184, 'Laax', 'Laax', 'Laax,Laax bei Ilanz,Laks,Nagens,la ke si,lagseu,Лакс,拉克斯,락스', 46.8045200, 9.2578700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11185, 'Küttigen', 'Kuttigen', 'Kjuttigen,Kuettigen,Kuttigen,Küttigen,qu di gen,Кюттиген,屈蒂根', 47.4156600, 8.0476700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11186, 'Küssnacht', 'Kussnacht', 'Chussenachus,Kjusnakht-am-Rigi,Kuessnacht,Kuessnacht SZ,Kuessnacht am Rigi,Kussnacht,Kussnacht am Rigi,Küssnacht,Küssnacht SZ,Küssnacht am Rigi,bkhsh kwsnkt,ksnakht,Кюснахт-ам-Риги,Кюснахт-ам-Рігі,بخش کوسنکت,کسناخت', 47.0855700, 8.4420600, 'CH', '2014-06-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11187, 'Küsnacht', 'Kuesnacht', 'Cussenachus,Kjusnakht,Kuesnacht,Kuesnacht ZH,Küsnacht,Küsnacht ZH,kwsnakht,qu si na he te,Кюснахт,کوسناخت,屈斯納赫特', 47.3180500, 8.5840100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11188, 'Künten', 'Kunten', 'Kjunten,Kuenten,Kunten,Künten,jin teng,Кюнтен,金滕', 47.3889000, 8.3310500, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11189, 'Krummenau', 'Krummenau', 'Krummenau', 47.2475500, 9.1706400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11190, 'Kriens', 'Kriens', 'Kriens,Krienz,Krins,Krynsas,ke lin si,krynz,kryyn,Кринс,كرينز,کریئن,克林斯', 47.0311000, 8.2854700, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11191, 'Kriegstetten', 'Kriegstetten', 'Kriegstten,Krigshtetten,ke li ge si te teng,Кригштеттен,克里格斯特滕', 47.1744900, 7.5979900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11192, 'Kreuzlingen', 'Kreuzlingen', 'Kreuzlingen,Krojclingen,ZHU,ke luo yi ci lin gen,krwzlnzhan,krwzlynghn,qrwyzlyngn,Кройцлинген,Кројцлинген,קרויצלינגן,كروزلينغن,کروزلنژان,克羅伊茨林根', 47.6505100, 9.1750400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11193, 'Krauchthal', 'Krauchthal', 'Krauchtal,Kraukhtal'',ke lao he ta er,Краухталь,克勞赫塔爾', 47.0096400, 7.5664000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11194, 'Koppigen', 'Koppigen', 'Koppigen,ke pi gen,Коппиген,科皮根', 47.1312500, 7.6052500, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11195, 'Konolfingen', 'Konolfingen', 'Konol''fingen,Konolfingen,ke nuo er fen gen,konorufingen,Конольфинген,コノルフィンゲン,科諾爾芬根', 46.8790900, 7.6201300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11196, 'Köniz', 'Koniz', 'Chunicis,K''onic,Kenic,Kjonic,Koeniz,Köniz,ke ni ci,kenittsu,kwnyz,kwynz,Кениц,Кьониц,Кёниц,كوينز,کونیز,ケーニッツ,克尼茨', 46.9243600, 7.4145700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11197, 'Kölliken', 'Kolliken', 'Kjolliken,Kolliken,Kölliken,ke li ken,kwlykn,Кёлликен,كوليكن,克利肯', 47.3388200, 8.0264400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11198, 'Kollbrunn', 'Kollbrunn', '', 47.4579300, 8.7829500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11199, 'Koblenz', 'Koblenz', 'Coblenca,Coblença,Koblenc,Koblenz AG,Koblenz i Sveits,ke bu lun ci,qwblnz,Кобленц,קובלנץ,科布倫茨', 47.6097200, 8.2375000, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11200, 'Knutwil', 'Knutwil', 'Knutvil'',Knutwil,ke nu te wei er,Кнутвиль,克努特維爾', 47.1995300, 8.0731500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11201, 'Knonau', 'Knonau', 'Chnonowa,Knonau,ke nuo nao,Кнонау,克諾瑙', 47.2235000, 8.4619700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11202, 'Kloten', 'Kloten', 'Kloten,Klotene,ke luo teng,klwtyn,kuroten,kwltan,Клотен,كلوتين,کولتان,クローテン,克洛滕', 47.4515200, 8.5849100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11203, 'Klosters Serneus', 'Klosters Serneus', 'Serneus,Serneus Dorf', 46.8891800, 9.8382600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11204, 'Klingnau', 'Klingnau', 'Klingnau,ke ling nao,klnyw,Клингнау,کلنیو,克靈瑙', 47.5836100, 8.2488000, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11205, 'Kleinlützel', 'Kleinlutzel', 'Klajnljutcel'',Kleinlutzel,Kleinlützel,xiao lu ce er,Клайнлютцель,小呂策爾', 47.4253700, 7.4229400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11206, 'Kirchlindach', 'Kirchlindach', 'Kirchlindach,Kirkhlindakh,Lindenachum,ji er he lin da he,Кирхлиндах,基爾赫林達赫', 46.9996500, 7.4173500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11207, 'Kirchberg', 'Kirchberg', 'Kirchberg,Kirchberg SG,Kirkhberg,ji er he bei ge,Кирхберг,基爾赫貝格', 47.4115900, 9.0402000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11208, 'Kirchberg', 'Kirchberg', 'Kirchberg BE,Kirchberg i Bern,Kirkhberg,ji er he bei ge,Кирхберг,基爾赫貝格', 47.0853800, 7.5828800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11209, 'Killwangen', 'Killwangen', 'Kil''vangen,Killwangen,ji er wang gen,Кильванген,基爾旺根', 47.4318200, 8.3480500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11210, 'Kilchberg', 'Kilchberg', 'Kil''khberg,Kilchberg,Kilchberg ZH,Kilchberg i Zuerich,Kilchberg i Zürich,ji xi bo ge,Кильхберг,基希伯格', 47.3243800, 8.5454800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11211, 'Kerzers', 'Kerzers', 'Chietres,Chiètres,kai er ze si,凱爾澤斯', 46.9758600, 7.1957000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11212, 'Kerns', 'Kerns', 'Kerns,Кернс', 46.9012100, 8.2751400, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11213, 'Kehrsatz', 'Kehrsatz', 'Kehrsatz,Kerzac,ke er sa ci,Керзац,克爾薩茨', 46.9103500, 7.4709600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11214, 'Kappelen', 'Kappelen', 'Capella,Kappelen,Kappelen BE,Каппелен', 47.0601500, 7.2686000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11215, 'Kandersteg', 'Kandersteg', 'Kandershteg,Kandersteg,Pons Kanderae,ZHR,kan de si tai ge,Кандерштег,坎德斯泰格', 46.4946700, 7.6732600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11216, 'Kaltbrunn', 'Kaltbrunn', 'Chaldebrunna,Kal''tbrun,Kaltbrunn,Kaltbrunn SG,ka te bu lun,Кальтбрун,卡特布倫', 47.2136700, 9.0259000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11217, 'Kallnach', 'Kallnach', 'Kal''nakh,Kallnach,ka er na he,Кальнах,卡爾納赫', 47.0203200, 7.2354500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11218, 'Kaisten', 'Kaisten', '', 47.5416000, 8.0433700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11219, 'Kaiseraugst', 'Kaiseraugst', 'Augusta Raurica,Kajzeraugst,kai ze lao si te,Кайзераугст,凱澤勞斯特', 47.5396600, 7.7260500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11220, 'Jussy', 'Jussy', 'Jussy GE,Jussy i Sveits,Zhjussi,jushi,yue xi,Жюсси,ジュシー,约西', 46.2359000, 6.2670100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11221, 'Jonschwil', 'Jonschwil', 'Iohannisvilaris,Jonshvil'',yong shi wei er,Йоншвиль,永施維爾', 47.4240200, 9.0868900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11222, 'Jonen', 'Jonen', 'Jonen,yue nen,Йонен,約嫩', 47.2974000, 8.3933700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11223, 'Jona', 'Jona', 'Iohanna,Jona,Jona SG,Йона', 47.2298300, 8.8388400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11224, 'Jenaz', 'Jenaz', 'Enac,Gianatsch,Jenaz,ye na ci,Енац,耶納茨', 46.9289200, 9.7127500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11225, 'Jegenstorf', 'Jegenstorf', 'Jegenstorf,ye gen si tuo fu,Йегенсторф,耶根斯托夫', 47.0480200, 7.5078700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11226, 'Pfäffikon / Irgenhausen', 'Pfaeffikon / Irgenhausen', 'Irgenhausen,Irgenhusen', 47.3624000, 8.7926500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11227, 'Inwil', 'Inwil', 'Invil'',Inwil,Inwil LU,yin wei er,Инвиль,因維爾', 47.1253000, 8.3488500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11228, 'Interlaken', 'Interlaken', 'Entrelagos,Interlacus,Interlaken,ZIN,antrlakn,ayntrlakn,intaraken,intarlaken,inteolaken,yin te la ken,Ίντερλακεν,Інтерлакен,Интерлакен,אינטרלאקן,إنترلاكن,اینترلاکن,இண்டர்லகேன்,インターラーケン,因特拉肯,인터라켄', 46.6838700, 7.8663800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11229, 'Ins', 'Ins', 'Anet,Ins,Ins BE,Ins i Sveits,Ins-Anet,yin si,Инс,因斯', 47.0058400, 7.1060900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11230, 'Ingenbohl', 'Ingenbohl', 'Ingenbohl,Ingenbol'',Ингенболь', 46.9988000, 8.6152900, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11231, 'Illnau', 'Illnau', '', 47.4113000, 8.7212500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11232, 'Ilanz', 'Ilanz', 'Glion,Ilanc,Ilanz,Ilanz/Glion,Iliande,aylanz,yi lan ci,Иланц,ایلانز,伊兰茨', 46.7741300, 9.2046100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11233, 'Igis', 'Igis', 'Eigias,Igis,Ovinae,yi ji si,Игис,伊吉斯', 46.9453100, 9.5721800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11234, 'Ibach', 'Ibach', '', 47.0110500, 8.6453800, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11235, 'Hüttwilen', 'Huttwilen', 'Khjutvilen,xu te wei lun,Хютвилен,許特維倫', 47.6067400, 8.8734300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11236, 'Huttwil', 'Huttwil', 'Huttwil,Khuttvil'',awt wyl,hu te wei er,Хуттвиль,اوت ویل,胡特維爾', 47.1150200, 7.8620900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11237, 'Hünenberg', 'Hunenberg', 'Huenenberg ZG,Hünenberg ZG,Khjunenberg,xiu lun bao,Хюненберг,休倫堡', 47.1753600, 8.4249700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11238, 'Horw', 'Horw', 'Horw,Khorv,ar  swyys,huo er fu,Хорв,ار، سوئیس,霍爾夫', 47.0169200, 8.3095600, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11239, 'Horn', 'Horn', 'Horn,Horn TG,Horn i Sveits,Khorn,huo en,Хорн,霍恩', 47.4942500, 9.4624600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11240, 'Horgen', 'Horgen', 'Horga,Horgen,Khorgen,awrzhan,hao er gen,hwrghn,hwrgn,Хорген,הורגן,اورژان,هورغن,豪尔根', 47.2598300, 8.5977800, 'CH', '2015-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11241, 'Zürich (Kreis 10) / Höngg', 'Zuerich (Kreis 10) / Hoengg', 'Hoengg,Höngg', 47.4031300, 8.4971000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11242, 'Homburg', 'Homburg', 'Homburg,Homburg TG,Homburg i Sveits,Homburgo,Khomburg,hong bao,Хомбург,洪堡', 47.6346900, 9.0075600, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11243, 'Hombrechtikon', 'Hombrechtikon', 'Khombrekhtikon,hong bu lei bu di kong,Хомбрехтикон,Хомбрехтікон,洪布雷布蒂孔', 47.2529800, 8.7721200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11244, 'Hölstein', 'Holstein', 'Helsteinas,Holstein,Hölstein,Hėlšteinas,Khjol''shtajn,he er si tai yin,Хёльштайн,赫爾斯泰因', 47.4251200, 7.7713600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11245, 'Hohenrain', 'Hohenrain', 'Hohenrain,Khoehnrajn,huo heng lai yin,Хоэнрайн,霍亨賴因', 47.1808300, 8.3180200, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11246, 'Hochwald', 'Hochwald', 'Hochwald', 47.4583000, 7.6418000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11247, 'Hochdorf', 'Hochdorf', 'Hochdorf', 47.1684100, 8.2917900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11248, 'Hitzkirch', 'Hitzkirch', 'Khickirkh,xi ci ji er he,Хицкирх,希茨基爾赫', 47.2240300, 8.2642500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11249, 'Hittnau / Hittnau (Dorf)', 'Hittnau / Hittnau (Dorf)', 'Hittnau,Hittnau (Dorf)', 47.3633400, 8.8241800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11250, 'Hinwil', 'Hinwil', 'Hinvilis,Khinvil,Khinvil'',xin wei er,Хинвил,Хинвиль,欣維爾', 47.2942600, 8.8439300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11251, 'Hinterrhein', 'Hinterrhein', 'Hinterrhein,Hinterrhein GR,Hinterrhein i Sveits,Khinterrajn,Rein Posteriur,Valragn,hou lai yin,Хинтеррайн,後萊茵', 46.5333300, 9.2000000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11252, 'Hindelbank', 'Hindelbank', 'Khindel''bank,xin de er ban ke,Хиндельбанк,欣德爾班克', 47.0427000, 7.5414300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11253, 'Himmelried', 'Himmelried', 'Himmelried,Khimmel''rid,xi mo li de,Химмельрид,希默里德', 47.4211100, 7.5965900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11254, 'Hilterfingen', 'Hilterfingen', 'Hilterfingen,Khil''terfingen,xi er te fen gen,Хильтерфинген,希爾特芬根', 46.7352100, 7.6618500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11255, 'Hildisrieden', 'Hildisrieden', 'Hildisrieden', 47.1506800, 8.2258200, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11256, 'Hettlingen', 'Hettlingen', '', 47.5461000, 8.7053200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11257, 'Herzogenbuchsee', 'Herzogenbuchsee', 'Khercogenbukhze,Khercogenbukse,ZHN,he zuo gen bu he sai,Херцогенбуксе,Херцогенбухзе,赫佐根布赫塞', 47.1879500, 7.7062000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11258, 'Herrliberg', 'Herrliberg', 'Kherliberg,hei li bo ge,Херлиберг,Херліберг,黑利伯格', 47.2906400, 8.6146400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11259, 'Hermiswil', 'Hermiswil', 'Hermiswil', 46.8312500, 7.4777500, 'CH', '2015-05-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11260, 'Herisau', 'Herisau', 'Gerizau,Herisan,Herisau,Herizava,Hērizava,Kherisau,Kherizau,aryzw,hei li shao,helijau,herizau,hyrasayw,Герізау,Херизау,Херисау,اریزو,هيراسايو,ہیریزاؤ,ہیریساو,ヘリザウ,黑里紹,헤리자우', 47.3861500, 9.2791600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11261, 'Hergiswil', 'Hergiswil', 'Hergensvilis,Hergiswil,Hergiswil NW,Khergisvil'',Хергисвиль', 46.9842900, 8.3094400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11262, 'Hérémence', 'Heremence', 'Heremence,Hèremence,Hérémence,ai lei mang si,埃雷芒斯', 46.1803200, 7.4047700, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11263, 'Henggart', 'Henggart', '', 47.5627200, 8.6821500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11264, 'Heitenried', 'Heitenried', 'Heitenried,hai teng li de,海滕里德', 46.8276200, 7.2994400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11265, 'Heimiswil', 'Heimiswil', 'Khajmisvil'',hai mi si wei er,Хаймисвиль,海米斯維爾', 47.0675500, 7.6666500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11266, 'Heimberg', 'Heimberg', 'Heimberg,Heimberg BE,Khajmberg,hai mu bei ge,Хаймберг,海姆貝格', 46.7948200, 7.6043300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11267, 'Heiden', 'Heiden', 'Heiden,Heiden AR', 47.4425500, 9.5329300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11268, 'Oberwinterthur (Kreis 2) / Hegi', 'Oberwinterthur (Kreis 2) / Hegi', 'Hegi', 47.5031700, 8.7739400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11269, 'Hausen am Albis / Hausen (Dorf)', 'Hausen am Albis / Hausen (Dorf)', 'Hausen,Hausen (Dorf),Hausen am Albis', 47.2449600, 8.5329900, 'CH', '2013-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11270, 'Haslen', 'Haslen', 'Haslen,Haslen AI', 47.3693100, 9.3675200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11271, 'Hasle', 'Hasle', 'Hasle,Hasle LU,Hasle i Luzern,Khasle,ha si lei,Хасле,哈斯勒', 46.9778700, 8.0532600, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11272, 'Hallau', 'Hallau', 'Khallau,Халлау', 47.6964800, 8.4582700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11273, 'Hägglingen', 'Hagglingen', 'Hagglingen,Hägglingen,Kheglingen,hei ge lin gen,Хеглинген,黑格林根', 47.3884900, 8.2532300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11274, 'Häggenschwil', 'Haggenschwil', 'Haggenschwil,Häggenschwil,Kheggenshvil'',hei gen shi wei er,Хеггеншвиль,黑根施維爾', 47.4946200, 9.3448700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11275, 'Hägendorf', 'Hagendorf', 'Hagendorf,Hägendorf,Khegendorf,hei gen duo fu,Хегендорф,黑根多夫', 47.3343600, 7.8419200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11276, 'Güttingen', 'Guttingen', 'Gjuttingen,Guettingen TG,Guttingen,Güttingen,Güttingen TG,ju ting gen,Гюттинген,居廷根', 47.6034900, 9.2874200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11277, 'Gunzwil', 'Gunzwil', 'Gunzwil', 47.2107200, 8.1793200, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11278, 'Gunzgen', 'Gunzgen', 'Guncgen,gong ci gen,Гунцген,貢茨根', 47.3137500, 7.8310200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11279, 'Guggisberg', 'Guggisberg', 'Guggisberg,Mons Guchani,gu ji si bei ge,Гуггисберг,古吉斯貝格', 46.7675600, 7.3294600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11280, 'Gstaad', 'Gstaad', 'Gshtad,Gstad,Gstadas,Gštad,Gštadas,ZHK,ghshtad,gushutado,Гштад,גשטאט,غشتاد,グシュタード', 46.4721500, 7.2868500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11281, 'Gryon', 'Gryon', 'Grion,ge li weng,grywn,גריון,格里翁', 46.2737700, 7.0597500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11282, 'Gruyères', 'Gruyeres', 'Grejerco,Greyerz,Grueria,Gruyeres,Gruyères,Nkrygier,Qruyer,ge lu ye er,geulwiyeleu,grwyr,Γκρυγιέρ,گرویر,格吕耶尔,그뤼예르', 46.5833800, 7.0820700, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11283, 'Grüsch', 'Gruesch', 'Crusch,Grjush,Gruesch,Grusch,Grüsch,ge lu shi,Грюш,格呂施', 46.9796500, 9.6463900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11284, 'Grosswangen', 'Grosswangen', 'Grosswangen', 47.1331000, 8.0504100, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11285, 'Andelfingen', 'Grossandelfingen', 'Andelfingen', 47.5944700, 8.6782600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11286, 'Grossaffoltern', 'Grossaffoltern', 'Grosaffol''tern,Grossaffol''tern,Grossaffoltern,da a fu er te en,Гросаффольтерн,Гроссаффольтерн,大阿福爾特恩', 47.0653400, 7.3568900, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11287, 'Grône', 'Grone', 'Grona,Grone,Grun,Gruona,Grôna,Grône,ge luo ne,格羅訥', 46.2528800, 7.4594700, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11288, 'Grolley', 'Grolley', 'Groslerium,ge luo lai,格羅萊', 46.8336000, 7.0711600, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11289, 'Grindelwald', 'Grindelwald', 'Grindel''val''d,Grindelvald,Grindelwald,ZHJ,ge lin de wa,gryndlwald,gryndlwwld,gurinderuvu~aruto,gurinderuwaruto,jryndlfald,Гринделвалд,Гриндельвальд,גרינדלוולד,جريندلفالد,گراینڈلوالڈ,گریندلوالد,グリンデルワルト,グリンデルヴァルト,格林德瓦', 46.6239600, 8.0360100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11290, 'Grimisuat', 'Grimisuat', 'Grimisuat', 46.2593800, 7.3840800, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11291, 'Grenchen', 'Grenchen', 'Granges,Grenchenas,Grenkhen,ZHI,ge lun xing,ghrynshyn,granshan,Гренхен,غرينشين,گرانشان,格倫興', 47.1921000, 7.3958600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11292, 'Grellingen', 'Grellingen', 'Grellingen,ge lei lin gen,Греллинген,格雷林根', 47.4423100, 7.5890600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11293, 'Greifensee', 'Greifensee', '', 47.3671700, 8.6811500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11294, 'Gravesano', 'Gravesano', 'Gravesan,ge la wei sa nuo,格拉韋薩諾', 46.0420800, 8.9183200, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11295, 'Gränichen', 'Graenichen', 'Granichen,Grenikhen,Gränichen,ge lei ni xing,Гренихен,格雷尼興', 47.3593000, 8.1024300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11296, 'Grandson', 'Grandson', 'Grancio,Granson,ge lang song,grandswn  swyys,Грансон,گراندسون، سوئیس,格朗松', 46.8094600, 6.6460000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11297, 'Grand-Savagnier', 'Grand-Savagnier', 'Grand-Savagnier', 47.0510100, 6.9548900, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11298, 'Le Grand-Saconnex', 'Le Grand-Saconnex', 'Grand-Saconnex,Le Grand-Saconnex,Saconnex,da sa kong nei,ル・グラン＝サコネ,大萨孔内', 46.2318800, 6.1209100, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11299, 'Grancy', 'Grancy', '', 46.5921400, 6.4639100, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11300, 'Grächen', 'Grachen', 'Grachen,Gracher,Grächen,Grächer,ge lei xing,格雷興', 46.1952900, 7.8374500, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11301, 'Grabs', 'Grabs', 'Grabs,Quaravedes,ge la bu si,Грабс,格拉布斯', 47.1824800, 9.4439500, 'CH', '2013-06-20', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11302, 'Gottlieben', 'Gottlieben', 'Gottlieben', 47.6638000, 9.1337100, 'CH', '2013-11-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11303, 'Gossau', 'Gossau', 'Cozesaua,Gosau,Gossau,Gossau SG,ge shao,Госау,Госсау,گوسو، سن‌گلان,戈紹', 47.4155100, 9.2548200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11304, 'Gossau', 'Gossau', 'Gosauo ZH,Gosaŭo ZH,Gossau,Gossau ZH,Gossau i Zuerich,Gossau i Zürich,ge shao,Госсау,戈紹', 47.3051000, 8.7583100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11305, 'Gorgier', 'Gorgier', 'ge ji ye,戈吉耶', 46.9014300, 6.7798500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11306, 'Gordola', 'Gordola', '', 46.1825600, 8.8665700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11307, 'Gontenschwil', 'Gontenschwil', 'Gontenschwil,Gontenshvil'',gong teng shi wei er,Гонтеншвиль,貢滕施維爾', 47.2716600, 8.1439600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11308, 'Gonten', 'Gonten', 'Gonten,Гонтен', 47.3272500, 9.3470500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11309, 'Gommiswald', 'Gommiswald', 'Gommisval''d,ge mi si wa de,Гоммисвальд,戈米斯瓦德', 47.2312800, 9.0235500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11310, 'Goldingen', 'Goldingen', 'Goldingen', 47.2647700, 8.9616700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11311, 'Goldau', 'Goldau', '', 47.0476100, 8.5461600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11312, 'Goldach', 'Goldach', 'Gol''dakh,Goldach,Goldach SG,ge da he,Гольдах,戈達赫', 47.4740100, 9.4671100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11313, 'Glovelier', 'Glovelier', 'Glovelier,ge luo wei li ye,格洛韋利耶', 47.3346600, 7.2054500, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11314, 'Glattfelden', 'Glattfelden', 'Glatfel''den,ge la te fei deng,Глатфельден,格拉特費登', 47.5587100, 8.5016700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11315, 'Glattbrugg', 'Glattbrugg', 'Glattbrugg', 47.4313000, 8.5627200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11316, 'Glarus', 'Glarus', 'Canton Glarus,Glaris,Glarona,Glaruna,Glarus,Glaruso,Gorad Glarus,ZHG,ge la lu si,geullaluseu,ghlrws,glarusi,glarws,glrw,gurarusu,Гларус,Горад Гларус,غلروس,گلاروس,گلرو,გლარუსი,グラールス,格拉魯斯,글라루스', 47.0405700, 9.0680400, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11317, 'Gland', 'Gland', 'Gland,Gland VD,ge lang,ghland,glan  swyys,Гланд,غلاند,گلان، سوئیس,格朗', 46.4208200, 6.2701000, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11318, 'Giubiasco', 'Giubiasco', 'Cibiascum,Giuebiasch,Giübiasch,zhu bi ya si ke,朱比亞斯科', 46.1724600, 9.0079300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11319, 'Giswil', 'Giswil', 'Gisvil'',Giswil,Гисвиль', 46.8333300, 8.1806500, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11320, 'Gipf-Oberfrick', 'Gipf-Oberfrick', 'Gipf-Oberfrick,Gipf-Oberfrik,ji pu fu-shang fu li ke,Гипф-Оберфрик,吉普夫-上弗里克', 47.4987500, 8.0049700, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11321, 'Gimel', 'Gimel', 'Gimel,Gimel VD,Gimel i Vaud,ri mei lei,日梅勒', 46.5094500, 6.3073600, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11322, 'Giffers', 'Giffers', 'Giffers,ji fu si,吉弗斯', 46.7623000, 7.2084500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11323, 'Geuensee', 'Geuensee', 'Geuensee,Gojenze,Gojenzee,ge yi en sai,Гойензе,Гойензее,戈伊恩塞', 47.1997000, 8.1068900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11324, 'Gersau', 'Gersau', 'Gersau', 46.9941900, 8.5250000, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11325, 'Gerlafingen', 'Gerlafingen', 'Gerlafingen,Niedergerlafingen,gai la fen gen,Герлафинген,蓋拉芬根', 47.1697800, 7.5750500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11326, 'Genolier', 'Genolier', 'Zhenolie,re nuo li ye,Женолие,热诺利耶', 46.4353700, 6.2180900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11327, 'Genève', 'Geneve', 'Cenevre,GVA,Genava,Genebe,Genebra,Geneue,Geneva,Geneve,Genevi,Genevo,Genevra,Genewa,Genf,Genève,Ginebra,Ginevra,Gorad Zhehneva,Jenewa,Jenwe,Xenebra,Zeneva,Zheneva,Znev,jeneba,jineva,jnyf,jnywa,junevu,ri nei wa,zheneva,znbh,Ĝenevo,Ženeva,Ženēva,Γενέβη,Γενευη,Γενεύη,Горад Жэнева,Женева,Ժնև,זנבה,جنيف,جنیوا,जिनेवा,ჟენევა,ジュネーヴ,日内瓦,제네바', 46.2022200, 6.1456900, 'CH', '2014-05-11', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11328, 'Gelterkinden', 'Gelterkinden', 'Gel''terkinden,Gelterkinden,gai te jin deng,Гельтеркинден,蓋特金登', 47.4649700, 7.8517400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11329, 'Gebenstorf', 'Gebenstorf', 'Gebenstorf,ge ben si tuo er fu,Гебенсторф,格本斯托爾夫', 47.4813600, 8.2394900, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11330, 'Ganterschwil', 'Ganterschwil', 'Ganterschwil,Gantershvil'',gan te shi wei er,Гантершвиль,甘特施維爾', 47.3810300, 9.0923900, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11331, 'Gams', 'Gams', 'Gams,Gams SG,Гамс', 47.2042900, 9.4417200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11332, 'Gampel', 'Gampel', '', 46.3159900, 7.7421000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11333, 'Gais', 'Gais', 'Gais,Gais AR,Gajs,gai si,Гайс,盖斯', 47.3615000, 9.4535600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11334, 'Gachnang', 'Gachnang', 'Gachnang,Gakhnang,jia he nan,Гахнанг,加赫南', 47.5393500, 8.8531100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11335, 'Fully', 'Fully', 'Fuliacum,fei li,菲利', 46.1385100, 7.1146800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11336, 'Füllinsdorf', 'Fullinsdorf', 'Fjullinsdorf,fei lin si duo fu,Фюллинсдорф,菲林斯多夫', 47.5068800, 7.7312900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11337, 'Fulenbach', 'Fulenbach', 'Fulenbach,Fulenbakh,fu lun ba he,Фуленбах,富倫巴赫', 47.2749600, 7.8334300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11338, 'Frutigen', 'Frutigen', 'Frutigen,fu lu di gen,Фрутиген,弗鲁蒂根', 46.5872300, 7.6494500, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11339, 'Froideville', 'Froideville', 'Froideville,Froideville VD,Froideville i Sveits,fu lu wa de wei er,弗鲁瓦德维尔', 46.6012300, 6.6808500, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11340, 'Frick', 'Frick', 'Frick,Frick AG,Frick i Sveits,Frik,fu li ke,Фрик,弗里克', 47.5116900, 8.0247100, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11341, 'Fribourg', 'Fribourg', 'Freiburg,Freiburg im UEechtland,Freiburg im Üechtland,Friborg,Friborgo,Fribourg,Fribur,Friburas,Friburg,Friburgo,Friburgum,Fribôrg,Fribūras,Fryburg,ZHF,furiburu,Фрибур,フリブール', 46.8023700, 7.1512800, 'CH', '2014-05-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11342, 'Frenkendorf', 'Frenkendorf', 'Frenkendorf,fu lun ken duo fu,Френкендорф,弗倫肯多夫', 47.5068600, 7.7164800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11343, 'Freienbach', 'Freienbach', 'Frajenbakh,Freienbach SZ,frayynbakh,frynbk  shwyyz,Фрайенбах,فرائینباخ,فرینبک، شوئیز', 47.2053400, 8.7584200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11344, 'Frauenkappelen', 'Frauenkappelen', 'Capela,Frauehnkappelen,Фрауэнкаппелен', 46.9542500, 7.3383500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11345, 'Frauenfeld', 'Frauenfeld', 'Frauehnfel''d,Frauenfel''d,Frauenfeld,Frauenfelda,Gorad Frauehnfel''d,ZHE,frawnfyld,frwanfld,fu lao en fei er de,furauenferuto,peulauenpelteu,Горад Фраўэнфельд,Фрауенфелд,Фрауенфельд,Фрауэнфельд,فراؤئنفیلڈ,فراونفيلد,فراونفیلد,فروآنفلد,フラウエンフェルト,弗勞恩費爾德,프라우엔펠트', 47.5577600, 8.8989300, 'CH', '2015-09-13', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11346, 'Fraubrunnen', 'Fraubrunnen', 'Fraubrunnen,fu lao bu lun nen,Фраубруннен,弗勞布倫嫩', 47.0862000, 7.5272700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11347, 'Founex', 'Founex', 'fu nei,富内', 46.3327700, 6.1924300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11348, 'Fontenais', 'Fontenais', 'Fontenais,feng tai nai,豐泰奈', 47.4047800, 7.0819100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11349, 'Fontainemelon', 'Fontainemelon', 'feng tai nei mei long,豐泰內梅隆', 47.0549500, 6.8868000, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11350, 'Flurlingen', 'Flurlingen', 'Flurlingen,fu lu lin gen,Флурлинген,弗盧林根', 47.6839000, 8.6299500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11351, 'Flums', 'Flums', 'Fluminum,Flums,fu lu mu si,Флумс,弗盧姆斯', 47.0905800, 9.3430100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11352, 'Flühli', 'Fluehli', 'Fljuli,Fluehli LU,Fluhli,Flühli,Flühli LU,fu lu li,Флюли,弗呂利', 46.8839100, 8.0155800, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11353, 'Flüelen', 'Flueelen', 'Fljuehlen,Fljuelen,Fljujlen,Flueelen,Flüelen,flwln,Флюелен,Флюйлен,Флюэлен,فلولن', 46.9047800, 8.6239600, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11354, 'Flims', 'Flims', 'Flem,Flemme,Flims,Flims Dorf,fu li mu si,Флимс,弗利姆斯', 46.8370500, 9.2845800, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11355, 'Fleurier', 'Fleurier', '', 46.9022400, 6.5825300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11356, 'Flawil', 'Flawil', 'Flavil'',Flawil,fu la wei er,Флавиль,弗拉維爾', 47.4130100, 9.1832400, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11357, 'Flamatt', 'Flamatt', '', 46.8899400, 7.3220400, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11358, 'Fischingen', 'Fischingen', 'Fischingen,Fischingen TG,Fishingen,fei xin gen,Фишинген,菲欣根', 47.4142200, 8.9686200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11359, 'Fiesch', 'Fiesch', 'Fiesch,fei shi,菲施', 46.3998100, 8.1353300, 'CH', '2015-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11360, 'Feusisberg', 'Feusisberg', 'Feusisberg', 47.1870700, 8.7472400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11361, 'Feuerthalen', 'Feuerthalen', 'Feuerthaleni vald,Fojertalen,fu yi e ta lun,Фойертален,福伊厄塔倫', 47.6905400, 8.6435700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11362, 'Ferenbalm', 'Ferenbalm', 'Ferenbal''m,Villa de Balmis,fei lun ba er mu,Ференбальм,費倫巴爾姆', 46.9488000, 7.2112400, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11363, 'Felsberg', 'Felsberg', 'Fagonium,Favugn,Fel''sberg,Felsberg,Felsberg GR,fei er si bei ge,Фельсберг,費爾斯貝格', 46.8442400, 9.4768400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11364, 'Feldmeilen', 'Feldmeilen', '', 47.2787300, 8.6216500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11365, 'Fehraltorf', 'Fehraltorf', 'Feral''torf,fei la er tuo fu,Феральторф,費拉爾托夫', 47.3877500, 8.7514900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11366, 'Fällanden', 'Fallanden', '', 47.3716900, 8.6386900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11367, 'Faido', 'Faido', 'Faedum,Faid,Faido,Faido-Borgo,Faidu,fa yi duo,法伊多', 46.4770000, 8.8012500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11368, 'Evolène', 'Evolene', 'Evolena,Evolene,Evolenna,Evolène,Evolênna,ai wo lai ne,Évolène,埃沃萊訥', 46.1142200, 7.4940700, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11369, 'Evionnaz', 'Evionnaz', 'Eviona,ai wei ao na,埃維奧納', 46.1809600, 7.0223200, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11370, 'Evilard', 'Evilard', 'Ehvilar,Evilard,Evilardo,Leubringen,Leubringen/Magglingen,ai wei la de,Эвилар,埃維拉德', 47.1504600, 7.2389500, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11371, 'Ettiswil', 'Ettiswil', 'Ehttisvil'',Ettiswil,ai di si wei er,Эттисвиль,埃蒂斯維爾', 47.1503100, 8.0175900, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11372, 'Ettingen', 'Ettingen', 'Ehttingen,Ettingen,ai ting gen,Эттинген,埃廷根', 47.4826800, 7.5498200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11373, 'Estavayer-le-Lac', 'Estavayer-le-Lac', 'Estavayer,ai si ta wa ye,埃斯塔瓦耶', 46.8487600, 6.8465000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11374, 'Escholzmatt', 'Escholzmatt', 'Ehshol''cmat,Escholzmatt,ai shuo er ci ma te,Эшольцмат,埃朔爾茨馬特', 46.9135000, 7.9342600, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11375, 'Eschlikon', 'Eschlikon', 'Ehshlikon,Eschlikon,Eschlikon TG,Eschlikon-Dorf,ai shi li kong,Эшликон,埃施利孔', 47.4636100, 8.9638100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11376, 'Eschenz', 'Eschenz', 'Ehshenc,Eschenz,Tasgetium,ai shen ci,Эшенц,埃申茨', 47.6479300, 8.8747200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11377, 'Eschenbach', 'Eschenbach', 'Ehshenbakh,Eschenbach,Eschenbach SG,ai shen ba he,Эшенбах,埃申巴赫', 47.2398100, 8.9215600, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11378, 'Erstfeld', 'Erstfeld', 'Ehrstfel''d,Erstfeld,Protocampus,Эрстфельд,ارسٹفیلڈ', 46.8188500, 8.6505200, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11379, 'Ersigen', 'Ersigen', 'Ehrzigen,e xi gen,Эрзиген,厄錫根', 47.0936800, 7.5950700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11380, 'Ermatingen', 'Ermatingen', 'Ehrmatingen,Ermatingen,e ma ting gen,Эрматинген,厄馬廷根', 47.6705700, 9.0857300, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11381, 'Erlenbach im Simmental', 'Erlenbach im Simmental', 'Ehrlenbakh,Ehrlenbakh-im-Zimmental'',Erlenbach en Simme-Valo,Erlenbach im Simmental,xi men ta er e lun ba he,Эрленбах,Эрленбах-им-Зимменталь,錫門塔爾厄倫巴赫', 46.6602100, 7.5544500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11382, 'Erlenbach', 'Erlenbach', 'Ehrlenbakh,Erlenbach,Erlenbach ZH,Erlenbakh,e lun ba he,Ерленбах,Эрленбах,厄倫巴赫', 47.3029800, 8.5974300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11383, 'Erlen', 'Erlen', 'Ehrlen,Erlen,Erlen TG,e lun,Эрлен,厄倫', 47.5481400, 9.2341500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11384, 'Erlach', 'Erlach', 'Cerlier,Ehrlakh,Erilachus,Erlach,Erlach BE,Erlach i Sveits,ai la he,arlk  swyys,ayrlash,Эрлах,إيرلاش,ارلک، سوئیس,埃拉赫', 47.0422000, 7.0972800, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11385, 'Eriswil', 'Eriswil', 'Ehrisvil'',Eriswil,Eriswil BE,ai li si wei er,Эрисвиль,埃里斯維爾', 47.0781600, 7.8514900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11386, 'Ependes', 'Ependes', 'Ependes,Ependes FR,ai pang de,Épendes,埃龐德', 46.7536800, 7.1460900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11387, 'Epalinges', 'Epalinges', 'Epalinges,ai pa lan ri,Épalinges,埃帕兰日', 46.5489600, 6.6683100, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11388, 'Entlebuch', 'Entlebuch', 'Entlebuch', 46.9955900, 8.0635400, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11389, 'Ennetbürgen', 'Ennetburgen', 'Ehnnetbjurgen,Ennetbuergen,Ennetburgen,Ennetbürgen,Эннетбюрген', 46.9842300, 8.4100300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11390, 'Ennenda', 'Ennenda', 'Ennenda', 47.0336300, 9.0788800, 'CH', '2017-06-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11391, 'Engelberg', 'Engelberg', 'Angelorum mons,Ehngel''berg,Engelberg,Engelbergi vald,en ge er bei ge,engeruberuku,Энгельберг,אנגלברג,エンゲルベルク,恩格尔贝格', 46.8210700, 8.4013300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11392, 'Emmetten', 'Emmetten', 'Ehmmetten,Emmetten,Emmeuen,Empnotis,Эмметтен', 46.9565800, 8.5146700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11393, 'Emmen', 'Emmen', 'EML,Ehmmen,Emmen,ai men,amn,emen,Эммен,آمن,エメン,埃門', 47.0861500, 8.3004600, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11394, 'Embrach', 'Embrach', 'Ehmbrakh,Embrach,Imbriagua,Unter Embrach,en bu la he,Эмбрах,恩布拉赫', 47.5056100, 8.5940600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11395, 'Elgg', 'Elgg', 'Ailaghoga,Ehl''g,ai er ge,alg,Эльг,الگ,埃爾格', 47.4971500, 8.8652300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11396, 'Einsiedeln', 'Einsiedeln', 'Ajnzidel''n,Ajnzideln,Einsiedeln,ZDZ,ai yin xi de lun,ayn‌sydn  swyys,Айнзидельн,Ајнзиделн,آین‌سیدن، سوئیس,艾因西德倫', 47.1284900, 8.7473500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11397, 'Eiken', 'Eiken', 'Eiken', 47.5339400, 7.9888300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11398, 'Eichberg', 'Eichberg', 'Eichberg', 47.3437400, 9.5314000, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11399, 'Eich', 'Eich', 'Ajkh,Eich,Eich LU,Eich i Sveits,ai xi,Айх,艾希', 47.1511600, 8.1669500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11400, 'Egnach', 'Egnach', 'Egnach,Ehgnakh,ai ge na he,Эгнах,埃格納赫', 47.5426800, 9.3804800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11401, 'Egliswil', 'Egliswil', 'Egliswil,Ehglisvil'',ai ge li si wei er,Эглисвиль,埃格利斯維爾', 47.3495400, 8.1880200, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11402, 'Eggiwil', 'Eggiwil', 'Eggiwil,Ehggivil'',ai ji wei er,Эггивиль,埃吉維爾', 46.8757500, 7.7956700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11403, 'Eggersriet', 'Eggersriet', '', 47.4420200, 9.4690100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11404, 'Egg', 'Egg', '', 47.2997600, 8.6903200, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11405, 'Egerkingen', 'Egerkingen', 'Ehgerkingen,ai ge jin gen,Эгеркинген,埃格金根', 47.3195700, 7.7842400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11406, 'Effretikon', 'Effretikon', '', 47.4257500, 8.6909400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11407, 'Ecublens', 'Ecublens', 'Ecublens,Ecublens FR,Ecublens i Fribourg,ai ju bu lang,Écublens,埃居布朗', 46.6073500, 6.8089500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11408, 'Echallens', 'Echallens', 'Echallens,ai sha lang,ashlan,Échallens,اشلان,埃沙朗', 46.6413000, 6.6331700, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11409, 'Ebnat-Kappel', 'Ebnat-Kappel', 'Ebnat,Ebnat-Kappel,Ehbnat-Kappel'',ai bu na te-ka pei er,Эбнат-Каппель,埃布納特-卡佩爾', 47.2619500, 9.1247300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11410, 'Ebikon', 'Ebikon', 'Ebikon,Ehbikon,Marcha Abinchova,abykwn,ai bi kong,Эбикон,ابیکون,埃比孔', 47.0793700, 8.3404100, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11411, 'Dürrenroth', 'Durrenroth', 'Djurrenrot,Duerrenroth,Durrenroth,Dürrenroth,Rota,di lun luo te,zurenrotto,Дюрренрот,ズレンロット,迪倫羅特', 47.0881600, 7.7913000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11412, 'Dürrenäsch', 'Durrenasch', 'Djurrenesh,Durrenasch,Dürrenäsch,di lei nei shi,Дюрренеш,迪雷內施', 47.3181200, 8.1585000, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11413, 'Dürnten', 'Durnten', 'Djurnten,di er en teng,Дюрнтен,迪爾恩滕', 47.2785600, 8.8415600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11414, 'Düdingen', 'Dudingen', 'Dudingen,Duedingen,Düdingen,Guin', 46.8491500, 7.1884800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11415, 'Dübendorf', 'Dubendorf', 'Duebendorf,Dübendorf', 47.3972400, 8.6187200, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11416, 'Dottikon', 'Dottikon', 'Dottikon,duo di kong,Доттикон,多蒂孔', 47.3843700, 8.2398100, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11417, 'Dornach', 'Dornach', 'Dornach SO,Dornakh,duo er na he,Дорнах,多爾納赫', 47.4803800, 7.6164400, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11418, 'Domdidier', 'Domdidier', 'dong di di ye,棟迪迪耶', 46.8671600, 7.0133700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11419, 'Dombresson', 'Dombresson', 'dong bu lei song,棟布雷松', 47.0719200, 6.9592000, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11420, 'Domat', 'Domat', 'Domat,Domat Ems,Domat/Ems,Ems', 46.8348300, 9.4507500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11421, 'Disentis', 'Disentis', 'Disentis,Disentis/Muster,Disentis/Mustér,Muster,Mustér', 46.7034100, 8.8509000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11422, 'Dietlikon / Dietlikon (Dorf)', 'Dietlikon / Dietlikon (Dorf)', 'Dietlikon,Dietlikon (Dorf)', 47.4182700, 8.6188000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11423, 'Dietikon', 'Dietikon', 'Dietikon,ZDX', 47.4016500, 8.4001500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11424, 'Diessenhofen', 'Diessenhofen', 'Disenkhofen,Dissenkhofen,di sen huo fen,dysnwfan,Дисенхофен,Диссенхофен,دیسنوفان,迪森霍芬', 47.6890800, 8.7495800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11425, 'Diepoldsau', 'Diepoldsau', '', 47.3860000, 9.6555800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11426, 'Diemtigen', 'Diemtigen', 'Diemtigen,Dimtigen,di mu di gen,Димтиген,迪姆蒂根', 46.6492800, 7.5647700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11427, 'Dielsdorf', 'Dielsdorf', '', 47.4814600, 8.4585000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11428, 'Diegten', 'Diegten', 'Digten,di ge teng,Дигтен,迪格滕', 47.4138000, 7.8108500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11429, 'Derendingen', 'Derendingen', 'Derendingen,Derendingen SO,Derendingen i Sveits,de lun ding gen,Дерендинген,德倫丁根', 47.1985000, 7.5884400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11430, 'Densbüren', 'Densbueren', 'Densbjuren,Densburen,Densbüren,deng si bi lun,Денсбюрен,登斯比倫', 47.4526000, 8.0533000, 'CH', '2013-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11431, 'Delémont', 'Delemont', 'D''olemon,Delemon,Delemonas,Delemons,Delemont,Delemonto,Delsberg,Delèmont,Delémont,Gorad Dehlemon,de lai meng,deullemong,dlmwn,doremon,dylymwn,dylymwnt,Горад Дэлемон,Делемон,Дьолемон,دلمون,ديليمونت,دیلیمون,دیلیمونت,ドレモン,德莱蒙,들레몽', 47.3649300, 7.3445300, 'CH', '2015-09-14', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11432, 'Deitingen', 'Deitingen', 'Dajtingen,Deitingen,dai ting gen,Дайтинген,代廷根', 47.2157900, 7.6198800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11433, 'Degersheim', 'Degersheim', 'Degersheim SG,Degerskhajm,de ge sha yi mu,Дегерсхайм,德格沙伊姆', 47.3742900, 9.2001900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11434, 'Davos', 'Davos', 'Davos,Davosa,Davosas,Davosi,Gorad Davos,Tafaas,Tavau,Tavaus,ZDV,da wo si,dabhosa,daboseu,dabosu,dafws,davosi,dww  swyys,tavocu,Горад Давос,Давос,דאבוס,دافوس,دوو، سوئیس,ڈیوس,ডাভোস,தாவோசு,დავოსი,ダボス,达沃斯,다보스', 46.8042900, 9.8372300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11435, 'Därligen', 'Darligen', 'Daerligen,Darligen,Derligen,Därligen,de li gen,Дерлиген,德利根', 46.6617500, 7.8080800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11436, 'Dardagny', 'Dardagny', 'Dardaniacum,da er da ni,darudani,ダルダニー,达尔达尼', 46.1956400, 5.9949700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11437, 'Dallenwil', 'Dallenwil', 'Dallenvil'',Dallenwil,Tellewilaris,Далленвиль', 46.9242000, 8.3878500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11438, 'Dagmersellen', 'Dagmersellen', 'Dagmersellen,Dagmerzelen,Dagmerzellen,da ge mo sai lun,Дагмерзелен,Дагмерзеллен,達格默塞倫', 47.2136600, 7.9846600, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11439, 'Dachsen', 'Dachsen', '', 47.6651500, 8.6179000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11440, 'Cully', 'Cully', 'Cully (VD),Cully VD,ju li,kwly  ww,کلی، سویٹزرلینڈ,کولی، وو,居利', 46.4889200, 6.7294500, 'CH', '2016-07-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11441, 'Cugy', 'Cugy', 'Cugy FR,Cugy i Fribourg,qu ji,屈吉', 46.8147900, 6.8888800, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11442, 'Cugnasco', 'Cugnasco', 'Cugnasco', 46.1747300, 8.9168400, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11443, 'Crissier', 'Crissier', 'Crissier,ke li xi ye,克里西耶', 46.5458600, 6.5756700, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11444, 'Couvet', 'Couvet', 'Couvet', 46.9252500, 6.6327000, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11445, 'Courtételle', 'Courtetelle', 'ku tai te lei,庫泰特勒', 47.3407400, 7.3182700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11446, 'Courtelary', 'Courtelary', 'Curtis Alerici,Kurtelari,ku te la li,Куртелари,庫特拉里', 47.1782200, 7.0723600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11447, 'Court', 'Court', 'Court BE,Kur,ku er,Кур,庫爾', 47.2395600, 7.3365500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11448, 'Courroux', 'Courroux', 'ku lu,庫魯', 47.3606900, 7.3737100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11449, 'Courrendlin', 'Courrendlin', 'Curtis Randelana,ku lang de lin,庫朗德林', 47.3385300, 7.3724300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11450, 'Courgevaux', 'Courgevaux', 'Cougevaux,Gurwolf,ku er re wo,庫爾熱沃', 46.9064800, 7.1121500, 'CH', '2015-12-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11451, 'Courgenay', 'Courgenay', 'Courgenay,Courgenay JU,ku re nai,庫熱奈', 47.4036500, 7.1241600, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11452, 'Courfaivre', 'Courfaivre', 'Courfaivre,ku fei fu er,庫費夫爾', 47.3350500, 7.2820000, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11453, 'Cossonay', 'Cossonay', 'Cossonay-Ville,ke suo nai,kwswnh,کوسونه,科索奈', 46.6144300, 6.5063100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11454, 'Cortaillod', 'Cortaillod', 'Cortuillod,ke tai luo,科泰洛', 46.9430600, 6.8444000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11455, 'Corsier', 'Corsier', 'Corsiacum,Corsier GE,ke er xi ye,korujie,コルジエ,科尔西耶', 46.2629700, 6.2246100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11456, 'Cornaux', 'Cornaux', 'Cornaux', 47.0396000, 7.0187200, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11457, 'Corminboeuf', 'Corminboeuf', 'Corminboeuf,Corminboeuf FR,ke man bo fu,科曼伯夫', 46.8102900, 7.1053500, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11458, 'Corgémont', 'Corgemont', 'ke er re meng,科爾熱蒙', 47.1945700, 7.1451700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11459, 'Coppet', 'Coppet', 'Koppe,ke pei,kwph  swyys,Коппе,کوپه، سوئیس,科佩', 46.3168200, 6.1911400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11460, 'Conthey', 'Conthey', 'Conte,Contesius,Conthey,Contê,kong tai,kwnth,کونته,孔泰', 46.2237000, 7.3028300, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11461, 'Confignon', 'Confignon', 'Cofiniacum,Konfin''on,konfinyon,kong fei ni weng,Конфиньон,コンフィニョン,孔菲尼翁', 46.1734100, 6.0843700, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11462, 'Comano', 'Comano', 'Comano,Comano TI,Comano i Sveits,Comanum,Cuman,ke ma nuo,科馬諾', 46.0363500, 8.9552600, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11463, 'Colombier', 'Colombier', '', 46.5570900, 6.4728400, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11464, 'Collombey', 'Collombey', 'Collombey', 46.2738500, 6.9478900, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11465, 'Claro', 'Claro', 'Claro TI,Cree,ke la luo,克拉羅', 46.2576300, 9.0225200, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11466, 'Churwalden', 'Churwalden', 'Curvalda,Kurval''den,Silva Augeria,ku er wa er deng,Курвальден,庫爾瓦爾登', 46.7814300, 9.5437700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11467, 'Chur', 'Chur', 'Chur,Ciura,Coira,Coire,Couere,Couère,Cuera,Cuira,Curia Raetorum,Gorad Kur,Khur,Koiro,Kour,Kur,Kura,Kuras,Kūra,Kūras,ZDT,chr,khur,ku er,kueo,kuru,kwr,shwr  swyys,Κουρ,Горад Кур,Кур,Хур,כור,شور، سوئیس,كور,چر,کؤر,คูร์,კური,クール,庫爾,쿠어', 46.8498600, 9.5328700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11468, 'Chippis', 'Chippis', 'Chippis,xi pi,希皮', 46.2802000, 7.5396200, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11469, 'Chiasso', 'Chiasso', 'Chiaso,Chiasso,Chiassu,Ciass,Civasium,K''jasso,Kiaso,Kjasas,Kjasso,ZDS,ji ya suo,kyasw,Киасо,Кьяссо,Кяссо,كياسو,基亞索', 45.8320300, 9.0311900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11470, 'Chézard-Saint-Martin', 'Chezard-Saint-Martin', 'Saint-Martin-Chezard,Saint-Martin-Chézard,xie zha er sheng ma ding,謝扎爾聖馬丁', 47.0662900, 6.9333200, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11471, 'Chexbres', 'Chexbres', 'xie bu er,谢布尔', 46.4820800, 6.7780500, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11472, 'Cheseaux', 'Cheseaux', 'Chesaux-sur-Lausanne,Cheseaux-sur-Lausanne', 46.5862400, 6.6058700, 'CH', '2013-03-11', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11473, 'Chermignon-d’en Haut', 'Chermignon-d''en Haut', 'Chermignon,Chermignon-d''en Haut,Chermignon-d’en Haut', 46.2884400, 7.4748700, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11474, 'Chêne-Bourg', 'Chene-Bourg', 'Quercus,Sen Buras,shenu=buru,xie ne bao,Šen Buras,シェヌ＝ブール,谢讷堡', 46.1953400, 6.1940600, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11475, 'Chavornay', 'Chavornay', 'Chavornay VD,Chavornay i Vaud,sha wo er nai,沙沃尔奈', 46.7024400, 6.5694000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11476, 'Chavannes', 'Chavannes', 'Chavannes-pres-Renens,Chavannes-près-Renens', 46.5300500, 6.5706800, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11477, 'Châtel-Saint-Denis', 'Chatel-Saint-Denis', 'Chatel-St-Denis,Chathel,Châtel-St-Denis,Châthél,sha tai lei sheng dan ni,沙泰勒聖但尼', 46.5269100, 6.9008300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11478, 'Château-d''Oex', 'Chateau-d''Oex', 'Chateau-d''Oex,Shato-Do,Шато-До', 46.4745500, 7.1315500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11479, 'Charrat', 'Charrat', 'Charrat,Charrat-les-Chenes,Charrat-les-Chênes', 46.1249000, 7.1313800, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11480, 'Charmey', 'Charmey', 'Charmey,sha er mei,沙爾梅', 46.6195700, 7.1648600, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11481, 'Chardonne', 'Chardonne', 'Chardena,Chardonne VD,sha er duo ne,沙尔多讷', 46.4767600, 6.8268000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11482, 'Chancy', 'Chancy', 'shang xi,shanshi,シャンシー,尚西', 46.1500300, 5.9715300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11483, 'Champéry', 'Champery', 'Champeri,Champéri,shang pei li,尚佩里', 46.1754300, 6.8690300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11484, 'Chamoson', 'Chamoson', 'Camusia,Chamoson,sha mo song,沙莫松', 46.2027500, 7.2231900, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11485, 'Cham', 'Cham', 'Cham,Cham ZG,Cham i Sveits,Chama,Hamo,Kham,ka mu,shm  swyys,Ĥamo,Хам,شم، سوئیس,卡姆', 47.1821300, 8.4635800, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11486, 'Chalais', 'Chalais', 'Chalais', 46.2675800, 7.5114500, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11487, 'Cevio', 'Cevio', 'Cevi,Cevio,qie wei ao,切維奧', 46.3147900, 8.6033200, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11488, 'Cernier', 'Cernier', 'sai er ni ye,塞爾尼耶', 47.0587800, 6.9004000, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11489, 'Celerina', 'Celerina', 'Celerina,Celerina/Schlarigna,Schlarigna', 46.5121700, 9.8579400, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11490, 'Cazis', 'Cazis', 'Cazas,Cazis,Kacis,ka qi si,Кацис,卡齊斯', 46.7194000, 9.4327100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11491, 'Caux', 'Caux', 'Caux sur Montreux,Ko,Ко', 46.4324100, 6.9385500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11492, 'Cauco', 'Cauco', 'Cauch,Cauco,Kauko,kao ke,Кауко,考科', 46.3354100, 9.1212900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11493, 'Castel San Pietro', 'Castel San Pietro', 'Castel San Pedru,Castel San Pietro,Castel San Pietro TI,Castello San Pietro,sheng bi de luo bao,聖彼得羅堡', 45.8621100, 9.0084300, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11494, 'Caslano', 'Caslano', 'Caslan,Caslano,ka si la nuo,卡斯拉諾', 45.9736400, 8.8773900, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11495, 'Carouge', 'Carouge', 'Carroge,Karuzas,Karuzh,Karužas,Quadruvium,ka lu ri,kaluju,karuju,karwj,krwzh,qrwz,Каруж,קרוז,كاروج,کروژ,カルージュ,卡鲁日,카루주', 46.1809600, 6.1392100, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11496, 'Canobbio', 'Canobbio', 'Canobbio,Canoebi,Canöbi,ka nuo bi ao,卡諾比奧', 46.0359200, 8.9660500, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11497, 'Camorino', 'Camorino', 'Camorino,Camurin,Kamorino,ka mo li nuo,Καμορίνο,卡莫里諾', 46.1648300, 9.0054700, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11498, 'Cadro', 'Cadro', 'Cadelus,ka de luo,卡德羅', 46.0459500, 8.9872500, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11499, 'Cadenazzo', 'Cadenazzo', 'Cadenazz,Cadenazzo,Kantenatso,ka de na zuo,Καντενάτσο,卡德納佐', 46.1517200, 8.9471900, 'CH', '2016-04-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11500, 'Cadempino', 'Cadempino', 'Cadempin,ka deng pi nuo,卡登皮諾', 46.0367200, 8.9340300, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11501, 'Buus', 'Buus', 'Bus,Buus,bu si,Бус,Буус,布斯', 47.5054200, 7.8647600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11502, 'Buttwil', 'Buttwil', 'Buttvil'',bu te wei er,Буттвиль,布特維爾', 47.2682800, 8.3106400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11503, 'Buttisholz', 'Buttisholz', 'Buttisholz,Buttiskhol''c,bu di si huo er ci,Буттисхольц,布蒂斯霍爾茨', 47.1144200, 8.0942500, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11504, 'Bütschwil', 'Buetschwil', 'Bjuchvil'',Bucinesvilaris,Buetschwil SG,Bütschwil SG,bi qi wei er,Бючвиль,比奇維爾', 47.3602200, 9.0721300, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11505, 'Bussigny', 'Bussigny', 'Bussigny', 46.5511000, 6.5559700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11506, 'Büsserach', 'Busserach', 'Bjusserakh,Busserach,Büsserach,bi se la he,Бюссерах,比瑟拉赫', 47.3946400, 7.5411600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11507, 'Buseno', 'Buseno', 'Busen,Buseno', 46.2738100, 9.1073500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11508, 'Büron', 'Bueron', 'Buron,Büron', 47.2120600, 8.0942100, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11509, 'Bürglen', 'Burglen', 'Bjurglen,Buerglen TG,Buerglen i Thurgau,Burglen,Bürglen,Bürglen TG,Bürglen i Thurgau,bi ge lun,Бюрглен,比格倫', 47.5492100, 9.1495000, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11510, 'Bürglen', 'Burglen', 'Bjurglen,Buerglen UR,Buerglen i Uri,Burgilla,Burglen,Bürglen,Bürglen UR,Bürglen i Uri,Бюрглен', 46.8756500, 8.6653900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11511, 'Burgistein', 'Burgistein', 'Burgishtajn,Burgistein,bu er ji si tai yin,Бургиштайн,布爾吉斯泰因', 46.7846400, 7.4998800, 'CH', '2014-05-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11512, 'Burgdorf', 'Burgdorf', 'Berthoud,Burgdorf,Burgdorf BE,Burgdorf i Bern,Burgdorfas,ZDP,brjdwrf,bu ge duo fu,bwrgdwrf  swyys,Бургдорф,برجدورف,بورگدورف، سوئیس,布格多夫', 47.0590100, 7.6278600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11513, 'Buochs', 'Buochs', 'BXO,Buochs,Buoks,Буокс', 46.9739800, 8.4227900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11514, 'Bulle', 'Bulle', 'Bjul'',Bule,Bulle,Bulle FR,Bulle i Sveits,Bulė,Butulum,bi lei,bwl  frybwrg,bywl,Буле,Бюль,بول، فریبورگ,بيول,比勒', 46.6179700, 7.0569000, 'CH', '2017-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11515, 'Bülach', 'Bulach', 'Bilakh,Bjulakh,Pulacha,bi la he,bwlk,bywlash,Билах,Бюлах,بولک,بيولاش,比拉赫', 47.5219700, 8.5404900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11516, 'Bühler', 'Buhler', 'Buehler,Buehler AR,Bühler,Bühler AR', 47.3734800, 9.4250700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11517, 'Buchs', 'Buchs', 'Buchs,Buchs AG,Buchs i Aargau,Buks,bu ke si,Букс,布克斯', 47.3935800, 8.0823300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11518, 'Buchs', 'Buchs', 'Buchs,Buchs SG,Bukhs,Buks,Pogius,bu ke si,bywshs sant ghaln,Букс,Бухс,بوک، سن‌گلان,بيوشس سانت غالن,布克斯', 47.1674300, 9.4779400, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11519, 'Buchrain', 'Buchrain', '', 47.0962500, 8.3472900, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11520, 'Buchholterberg', 'Buchholterberg', 'Buchholterberg,Bukhgol''terberg,Bukhkhol''terberg,bu he huo er te bei ge,Бухгольтерберг,Буххольтерберг,布赫霍爾特貝格', 46.8135100, 7.6746300, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11521, 'Bubikon', 'Bubikon', 'Bubikon,Puapinchova,bu bi kong,Бубикон,布比孔', 47.2669800, 8.8179000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11522, 'Bubendorf', 'Bubendorf', 'Bubendorf,Bubendorf BL,bu ben duo fu,Бубендорф,布本多夫', 47.4458600, 7.7375900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11523, 'Brüttisellen', 'Bruttisellen', '', 47.4217300, 8.6326300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11524, 'Brütten', 'Brutten', 'Brjutten,Pritta,bu lu teng,Брюттен,布呂滕', 47.4731800, 8.6756900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11525, 'Brusio', 'Brusio', 'Brues,Bruesch,Brusio,Brusium,Brüs,Brüsch,bu lu xi ao,Брусио,布魯西奧', 46.2595300, 10.1238500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11526, 'Brugg', 'Brugg', 'Brug,Bruga,Brugg,beulugeu,brwg,brwgh,bu lu ge,Бруг,Бругг,بروغ,بروگ,布魯格,브루그', 47.4809600, 8.2086900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11527, 'Brügg', 'Brugg', 'Brjug,Brjugg,Bruegg,Bruegg BE,Brugg,Brügg,Brügg BE,bu lu ge,Брюг,Брюгг,布呂格', 47.1237000, 7.2788700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11528, 'Bronschhofen', 'Bronschhofen', 'Bronshkhofen,Pramolveshova,bu long shi huo fen,Броншхофен,布龍施霍芬', 47.4783500, 9.0345400, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11529, 'Broc', 'Broc', 'Broc,Broc FR,bu luo ke,布罗克', 46.6051300, 7.0989100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11530, 'Brittnau', 'Brittnau', 'Brittnau,bu li te nao,Бриттнау,布里特瑙', 47.2595400, 7.9468900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11531, 'Brissago', 'Brissago', 'Brisa,Brissagh,Brissago,Brissago TI,Brixagum,bu li sa ge,布里薩戈', 46.1201300, 8.7118100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11532, 'Brislach', 'Brislach', '', 47.4176300, 7.5434000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11533, 'Brig', 'Brig', 'Brig,Briga-Glis,Brigue,Brigue-Glis,ZDL,buriku,Бриг,ブリーク', 46.3166700, 7.9833300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11534, 'Brienz', 'Brienz', 'Brienc,Brienz,Brienz BE,Brienzola,beuliencheu,bu li en ci,burientsu,Бриенц,ブリエンツ,布里恩茨,브리엔츠', 46.7545000, 8.0384700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11535, 'Bremgarten', 'Bremgarten', 'Bremgarten,Bremgarten AG,Bremogartum', 47.3510900, 8.3421400, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11536, 'Breitenbach', 'Breitenbach', 'Brajtenbakh,Breitenbach,Breitenbach SO,Breitenbach i Sveits,bu lai teng ba he,Брайтенбах,布賴滕巴赫', 47.4056400, 7.5438200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11537, 'Breíl', 'Breil', 'Breil,Breil/Brigels,Breíl,Brigels', 46.7698600, 9.0603600, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11538, 'Bowil', 'Bowil', 'Bovil'',Bowil,bo wei er,Бовиль,博維爾', 46.8930400, 7.6975700, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11539, 'Boudry', 'Boudry', 'Boudry NE,bu de li,bwdry,بودری,布德里', 46.9499100, 6.8375700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11540, 'Bottmingen', 'Bottmingen', 'Botmingenas,Bottmingen,bo te ming gen,bwtmynjyn,Боттминген,بوتمينجين,博特明根', 47.5234300, 7.5721100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11541, 'Bottighofen', 'Bottighofen', 'Bottighofen,Bottigkhofen,bo di ge huo fen,Боттигхофен,博蒂格霍芬', 47.6364300, 9.2088200, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11542, 'Bottens', 'Bottens', 'bo tang,博唐', 46.6159600, 6.6614900, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11543, 'Bösingen', 'Bosingen', 'Boesingen FR,Boesingen i Fribourg,Bosingen,Bösingen,Bösingen FR,Bösingen i Fribourg,Grossbosingen,Grossbösingen,bo xin gen,伯辛根', 46.8922900, 7.2277000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11544, 'Bonstetten', 'Bonstetten', '', 47.3150500, 8.4683600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11545, 'Boniswil', 'Boniswil', 'Bonisvil'',Boniswil,bo ni si wei er,Бонисвиль,博尼斯維爾', 47.3172500, 8.1896300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11546, 'Bönigen', 'Bonigen', 'Bjonigen,Boenigen b. Interlaken,Bonigen,Bönigen,Bönigen b. Interlaken,bo ni gen,Бёниген,伯尼根', 46.6873600, 7.8935000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11547, 'Boncourt', 'Boncourt', 'Boncourt,Boncourt JU,Boncourt i Sveits,bang ku er,邦庫爾', 47.4956000, 7.0142300, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11548, 'Bonaduz', 'Bonaduz', 'Beneduces,Bonaduc,Bonaduz,Panaduz,bo na du ci,Бонадуц,博納杜茨', 46.8110300, 9.3982100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11549, 'Boltigen', 'Boltigen', 'Bol''tigen,Boltigen,bo er di gen,Больтиген,博爾蒂根', 46.6289000, 7.3911100, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11550, 'Bolligen', 'Bolligen', 'Bollaigues,Bolligen,Bolligen-Dorf,bo li gen,Боллиген,博利根', 46.9751000, 7.4969700, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11551, 'Bodio', 'Bodio', 'Beid,Bodio,Bodio TI,Béid,bo di ao,Бодио,博迪奧', 46.3780800, 8.9099100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11552, 'Blumenstein', 'Blumenstein', 'Blumenshtajn,Blumenstein,Blumenstein BE,bu lu men si tai yin,Блуменштайн,布盧門斯泰因', 46.7421000, 7.5213600, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11553, 'Blonay', 'Blonay', 'Blone,bu luo nai,Блоне,布洛奈', 46.4677800, 6.8961500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11554, 'Birsfelden', 'Birsfelden', 'Birsfel''den,bi er si fei er deng,brysfldan,Бирсфельден,بریسفلدان,比爾斯費爾登', 47.5529000, 7.6232200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11555, 'Birr', 'Birr', 'Bir,Birr,Birr AG,Birr i Sveits,Birr-Lufig,bi er,Бир,Бирр,比爾', 47.4358700, 8.2080100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11556, 'Birmenstorf', 'Birmenstorf', '', 47.4615200, 8.2481600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11557, 'Birmensdorf', 'Birmensdorf', 'Birmensdorf,Birmensdorf ZH,Birmenstorf,bi men si duo fu,Бирменсдорф,比門斯多夫', 47.3551500, 8.4425600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11558, 'Bioggio', 'Bioggio', 'Bioegg,Bioggium,Biögg,bi ao jiao,比奧焦', 46.0196100, 8.9143800, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11559, 'Binningen', 'Binningen', 'Biningenas,Binningen,Binningen BL,bin ning gen,bynnzhan,Биннинген,بیننژان,賓寧根', 47.5402100, 7.5693200, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11560, 'Bilten', 'Bilten', 'Bil''ten,Bilten,Бильтен,بلٹن', 47.1499500, 9.0255100, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11561, 'Biglen', 'Biglen', 'Biglen,Pigiluna,bi ge lun,Биглен,比格倫', 46.9262900, 7.6250800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11562, 'Bière', 'Biere', 'Biere VD,Biere i Vaud,Bière VD,Bière i Vaud,bi ye er,比耶尔', 46.5376100, 6.3336200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11563, 'Biel/Bienne', 'Biel/Bienne', 'Belna,Biel,Biel-Bienne,Biel/Bienne,Bielo,Bienna,Bienne,Bienne/Biel,Bil,Bil'',Bil/Bjen,Bylis,ZDK,bi er,bil/bien,bili,biru/bien''nu,byal,byl/byn,Бил,Бил/Бјен,Биль,Біль,بيال,بیل/بین,ბილი,ビール/ビエンヌ,比爾,빌/비엔', 47.1371300, 7.2460800, 'CH', '2015-11-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11564, 'Biberist', 'Biberist', 'Biberist,bi bo li si te,Биберист,比伯里斯特', 47.1800900, 7.5624600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11565, 'Biasca', 'Biasca', 'Aviasca,Biasca,bi ya si ka,byska,بیسکا,比亞斯卡', 46.3597200, 8.9696500, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11566, 'Bex', 'Bex', 'Be,Bex,Béx,bei cheng,bh,Бе,בה,贝城', 46.2496500, 7.0098000, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11567, 'Bévilard', 'Bevilard', 'bei wei la de,貝維拉德', 47.2371100, 7.2832500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11568, 'Bevaix', 'Bevaix', 'bei wei,貝魏', 46.9295800, 6.8147000, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11569, 'Bettlach', 'Bettlach', '', 47.2006200, 7.4240500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11570, 'Bettingen', 'Bettingen', 'Bettingen,Bettingen BS,bei ting gen,Беттинген,贝廷根', 47.5703900, 7.6642500, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11571, 'Beromünster', 'Beromuenster', 'Beromjunster,Beromuenster,Beromünster,Munster,Münster,Villa Beronensis,bei luo ming si te,belomwinseuteo,beromyunsuta,brwmwnsth,Беромюнстер,برومونسته,ベロミュンスター,貝羅明斯特,베로뮌스터', 47.2061200, 8.1926500, 'CH', '2017-03-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11572, 'Bernex', 'Bernex', 'Bernex GE,Bernex i Sveits,bei er nei,berune,ベルネ,贝尔内', 46.1765000, 6.0754400, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11573, 'Bern', 'Bern', 'BRN,Bann,Beirn,Ben,Bern,Bern osh,Berna,Bernas,Berne,Berno,Bundesstadt,Bèn,Bèrna,Gorad Bern,atharvaveda,ban he na,barana,barna,beirn,beleun,berna,berni,berun,bo en,bo er ni,brn,byrn,pern,Βέρνη,Берн,Берн ош,Горад Берн,Բեռն,בערן,ברן,برن,بيرن,بێرن,بېرن,ܒܪܢ,अथर्ववेद,बर्न,বের্ন,ਬਰਨ,ବର୍ନ,பேர்ன்,ബേൺ,เบิร์น,པེར་ནེ།,ბერნი,ቤርን,ベルン,伯尔尼,伯恩,办合纳,베른', 46.9480900, 7.4474400, 'CH', '2013-11-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11574, 'Beringen', 'Beringen', 'Beringen,Beringen SH,Беринген', 47.6976300, 8.5743100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11575, 'Berikon', 'Berikon', 'Berikon,bei li kong,Берикон,貝里孔', 47.3513700, 8.3720900, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11576, 'Berg', 'Berg', 'Berg,Berg TG,Berg i Thurgau,bei ge,Берг,貝格', 47.5787900, 9.1663500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11577, 'Benken', 'Benken', 'Babinchova,Benken,Benken SG,ben ken,Бенкен,本肯', 47.1994200, 9.0073500, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11578, 'Belp', 'Belp', 'Bel''p,Belp,bei er pu,Бельп,貝爾普', 46.8912900, 7.4982500, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11579, 'Belmont-sur-Lausanne', 'Belmont-sur-Lausanne', 'luo sang shang bei lei meng,בלמון-סור-לוזאן,洛桑上贝勒蒙', 46.5189100, 6.6763600, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11580, 'Bellmund', 'Bellmund', 'Bel''mund,Bellus Mons,bei er meng de,Бельмунд,貝爾蒙德', 47.1085200, 7.2460800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11581, 'Bellinzona', 'Bellinzona', 'Belinzona,Bellincona,Bellinzona,Bellinzone,Bilitio,ZDI,berrintsu~ona,Беллинцона,ベッリンツォーナ', 46.1927800, 9.0170300, 'CH', '2013-04-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11582, 'Bellevue', 'Bellevue', 'Bellevue GE,Bellevue i Sveits,bei lei wei,beruvu~yu,ベルヴュー,贝勒维', 46.2573900, 6.1547500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11583, 'Belfaux', 'Belfaux', 'Bellofagus,bei er fu,貝爾福', 46.8217100, 7.1067400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11584, 'Begnins', 'Begnins', 'bei ni an,贝尼安', 46.4415200, 6.2476200, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11585, 'Beckenried', 'Beckenried', 'Beckenried,Bekkenrid,Беккенрид', 46.9665300, 8.4757500, 'CH', '2015-04-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11586, 'Beatenberg', 'Beatenberg', 'Beatenbeig,Beatenberg,bei a teng bei ge,bytnbrj,Беатенберг,بيتنبرج,貝阿滕貝格', 46.6989600, 7.7942800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11587, 'Bavois', 'Bavois', 'Bavois,ba wa,巴瓦', 46.6840300, 6.5671000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11588, 'Bauma', 'Bauma', 'Bauma,Bauma ZH,bao ma,Баума,鮑馬', 47.3674500, 8.8790500, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11589, 'Bauen', 'Bauen', '', 46.9355900, 8.5783600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11590, 'Bätterkinden', 'Batterkinden', 'Batterkinden,Betterkinden,Bätterkinden,bei te jin deng,Беттеркинден,貝特金登', 47.1316400, 7.5381700, 'CH', '2017-07-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11591, 'Bassersdorf', 'Bassersdorf', 'Bassersdorf,ba se si duo fu,Бассерсдорф,巴瑟斯多夫', 47.4434200, 8.6285100, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11592, 'Basse-Nendaz', 'Basse-Nendaz', 'Nendaz', 46.1899300, 7.3120900, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11593, 'Bassecourt', 'Bassecourt', 'Bassecourt,ba si ku er,巴斯庫爾', 47.3382900, 7.2449400, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11594, 'Basel', 'Basel', 'Bala,Bale,Basel,Basilea,Basileia,Basilej,Basilia,Basilèa,Basle,Baxilea,Baxiłea,Bazel,Bazel'',Bazel'' khot,Bazele,Bazeli,Bazelis,Bazelo,Bazilej,Bazylea,Bázel,Bâla,Bâle,Bāsel,Bāzele,EAP,Gorad Bazel'',Robur,Vasileia,ba sai er,ba seil,bai cai er,bajel,bajela,basala,bazeli,bazeru,bazl,bzl,pecel,Βασιλεία,Базел,Базель,Базель хот,Горад Базель,Բազել,באזעל,בזל,بازل,बासल,বাজেল,பேசெல்,บาเซิล,པ་སེལ།,ბაზელი,ባዝል,バーゼル,巴塞尔,巴塞爾,白才尔,바젤', 47.5583900, 7.5732700, 'CH', '2013-03-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11595, 'Bäriswil', 'Bariswil', '', 47.0194700, 7.5270900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11596, 'Bäretswil', 'Baretswil', 'Beretsvil'',Berofovilaris,bei lei ci wei er,Беретсвиль,貝雷茨維爾', 47.3370900, 8.8564500, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11597, 'Baltschieder', 'Baltschieder', 'Ponczirrum,ba er qi de er,巴爾奇德爾', 46.3088800, 7.8657000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11598, 'Balsthal', 'Balsthal', 'Bal''stal'',Balstal,Balsthal,ba er si ta er,Бальсталь,巴爾斯塔爾', 47.3161300, 7.6931800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11599, 'Ballwil', 'Ballwil', 'Ballwil', 47.1548700, 8.3213800, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11600, 'Ballens', 'Ballens', 'ba lang,巴朗', 46.5548500, 6.3731000, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11601, 'Balgach', 'Balgach', 'Bal''gakh,Balgach,ba er jia he,Бальгах,巴爾加赫', 47.4055600, 9.6070200, 'CH', '2016-06-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11602, 'Balerna', 'Balerna', 'Balerna,Barerna,ba lai er na,巴萊爾納', 45.8463800, 9.0072400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11603, 'Bagnes', 'Bagnes', 'Bagnes,ba nie,巴涅', 46.0833300, 7.2166700, 'CH', '2015-06-09', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11604, 'Bad Ragaz', 'Bad Ragaz', 'Bad Ragacas,Bad Ragaz,Bad-Ragac,Ragaces,Ragaz,ba de la jia zi,bad rakaz,Бад-Рагац,باد راكاز,巴德拉加茲', 47.0060100, 9.5026600, 'CH', '2013-03-25', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11605, 'Baden', 'Baden', 'Aquae Helveticae,Baden,Baden AG,Baden i Aargau,Badenas,ZDG,ba deng,baden,badn,bdan  swyys,Баден,بادن,بدان، سوئیس,バーデン,巴登,바덴', 47.4733300, 8.3059200, 'CH', '2015-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11606, 'Bachenbülach', 'Bachenbulach', '', 47.5031700, 8.5455600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11607, 'Bäch', 'Baech', 'Baech,Baech SZ,Bäch,Bäch SZ', 47.2038800, 8.7322400, 'CH', '2016-09-20', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11608, 'Baar', 'Baar', 'Baar,Bar,Бар', 47.1962500, 8.5295400, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11609, 'Ayent', 'Ayent', 'Argenta,Ayent,ai yang,艾揚', 46.2824900, 7.4102800, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11610, 'Avry-sur-Matran', 'Avry-sur-Matran', 'Avry,Avry FR,Avry-sur-Matran,a fu li,阿夫里', 46.7875300, 7.0673500, 'CH', '2017-05-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11611, 'Avenches', 'Avenches', 'Avans,Avansh,Aventicum,a wang shen,awansh,Αβάνς,Аванш,اوانش,阿旺什', 46.8800400, 7.0407100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11612, 'Auw', 'Auw', '', 47.2108200, 8.3658300, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11613, 'Auvernier', 'Auvernier', 'ao wei ni ye,奧韋尼耶', 46.9754500, 6.8790300, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11614, 'Zürich (Kreis 4) / Aussersihl', 'Zuerich (Kreis 4) / Aussersihl', 'Aussersihl,Zuerich (Kreis 4),Zürich (Kreis 4)', 47.3775200, 8.5212700, 'CH', '2016-03-23', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11615, 'Aubonne', 'Aubonne', 'Aubonne VD,Aubonne i Vaud,Obona,Obonas,awbwn  swyys,ou bo ne,Ôbôna,اوبون، سوئیس,欧伯讷', 46.4951400, 6.3915500, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11616, 'Au', 'Au', 'Au,Au SG', 47.4309300, 9.6344800, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11617, 'Au', 'Au', 'Au,Au ZH', 47.2418500, 8.6440600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11618, 'Attiswil', 'Attiswil', 'Attisvil'',a di si wei er,Аттисвиль,阿蒂斯維爾', 47.2467300, 7.6135300, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11619, 'Attinghausen', 'Attinghausen', 'Atinghauzenas,Attinghausen,Attingkhauzen,Аттингхаузен', 46.8625500, 8.6303600, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11620, 'Attalens', 'Attalens', 'Attalens,Haltningum,a ta lang,阿塔朗', 46.5055500, 6.8503900, 'CH', '2017-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11621, 'Ascona', 'Ascona', 'Askona,Scona,a si ke na,aseukona,asukona,azkwna,Аскона,ازکونا,アスコナ,阿斯科納,아스코나', 46.1545100, 8.7732700, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11622, 'Arzo', 'Arzo', '', 45.8760600, 8.9410300, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11623, 'Arzier', 'Arzier', 'Arzier-Le Muids,a er ji ye,阿尔济耶', 46.4596200, 6.2081300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11624, 'Arvigo', 'Arvigo', 'Arvigh,Arvigo,a er wei ge,Арвиго,阿爾維戈', 46.3021100, 9.1130000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11625, 'Arth', 'Arth', 'Art,Arta,Arth,Arth SZ,Арт', 47.0633700, 8.5234900, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11626, 'Arosa', 'Arosa', 'Araus,Arosa,Arosa Bahnhof,Aroza,ZDE,a luo sa,aloja,aroza,Ароза,ארוזה,アローザ,阿羅薩,아로자', 46.7779300, 9.6762100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11627, 'Arlesheim', 'Arlesheim', 'Arleskhajm,Arlezhaimas,a lei hai mu,Арлесхайм,阿勒海姆', 47.4941200, 7.6197900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11628, 'Aristau', 'Aristau', 'Aristau,a li si tao,Аристау,阿里斯陶', 47.2869200, 8.3635600, 'CH', '2013-03-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11629, 'Arisdorf', 'Arisdorf', 'Arisdorf,a li si duo fu,Арисдорф,阿里斯多夫', 47.5132300, 7.7651500, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11630, 'Ardon', 'Ardon', 'Ardon,Ardon VS,Ardon i Sveits,Ardonum,a deng,ardwn,Ардон,أردون,阿登', 46.2095100, 7.2601200, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11631, 'Arch', 'Arch', 'Arkh,a er he,Арх,阿爾赫', 47.1653300, 7.4313900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11632, 'Arbon', 'Arbon', 'Arbon,Arboni,Arbor Felix,ZDD,a er bang,arbwn,arbwn  swyys,Арбон,أربون,اربون، سوئیس,阿爾邦', 47.5166700, 9.4333300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11633, 'Apples', 'Apples', 'a pu lei,阿普勒', 46.5523700, 6.4288900, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11634, 'Appenzell', 'Appenzell', 'Apencelo,Appenzell,ZAP', 47.3310300, 9.4099600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11635, 'Anières', 'Anieres', 'a nie er,anieru,アニエール,阿涅尔', 46.2767300, 6.2220400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11636, 'Andwil', 'Andwil', 'Andwil,Andwil SG', 47.4385500, 9.2743600, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11637, 'Andermatt', 'Andermatt', 'Andermat,Andermatt,Orsera,Ursera,andeleumateu,anderumatto,andrmat,Андермат,Андерматт,أندرمات,ანდერმატი,アンデルマット,안데르마트', 46.6356500, 8.5938800, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11638, 'Amriswil', 'Amriswil', 'Amrisvil'',Amriswil,a mu li si wei er,amry wyl,Амрисвиль,آمری ویل,阿姆里斯維爾', 47.5469900, 9.2958600, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11639, 'Amden', 'Amden', 'Amden,Andimus,an deng,Амден,安登', 47.1488800, 9.1423300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11640, 'Altstätten', 'Altstatten', 'Al''tshtetten,Altshteten,Altstaetten,Altstaetten SG,Altstätten,Altstätten SG,a er te shi tai teng,Алтштетен,Альтштеттен,الستتان، سن‌گلان,阿爾特施泰滕', 47.3776600, 9.5474600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11641, 'Altnau', 'Altnau', 'Al''tnau,Altnau,a er te nao,Альтнау,阿爾特瑙', 47.6105200, 9.2616000, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11642, 'Altishofen', 'Altishofen', 'Altishofen', 47.1991600, 7.9696400, 'CH', '2014-03-29', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11643, 'Alterswil', 'Alterswil', 'Alterswil,Alterswil FR,a er te si wei er,阿爾特斯維爾', 46.7958700, 7.2587700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11644, 'Altendorf', 'Altendorf', 'Altendorf', 47.1899400, 8.8382300, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11645, 'Altdorf', 'Altdorf', 'Al''tdorf,Altdorf,Altdorf UR,Altdorf i Sveits,Altdorfas,Artofe,Gorad Al''tdorf,a er te duo fu,aldwrf  swyys,altdwrf,alteudoleupeu,arutodorufu,Алтдорф,Альтдорф,Горад Альтдорф,אלטדורף,ألتدورف,الدورف، سوئٹزر لینڈ,الدورف، سوئیس,الٹڈورف,ალტდორფი,アルトドルフ,阿爾特多夫,알트도르프', 46.8804200, 8.6444100, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11646, 'Alpnach', 'Alpnach', 'Al''pnakh,Alpenachus,Alpnach,Альпнах', 46.9422700, 8.2718000, 'CH', '2015-04-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11647, 'Allschwil', 'Allschwil', 'Al''shvil'',Allschwil,a er shi wei er,alsh wyl,Альшвиль,الش ویل,阿爾施維爾', 47.5507400, 7.5359900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11648, 'Alle', 'Alle', 'Alle,Alle JU,Alle i Sveits,a lei,阿勒', 47.4261800, 7.1291100, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11649, 'Airolo', 'Airolo', 'Airlonia,Airoe,Airola,Airolo,Airö,Ajrolo,ai luo luo,airolo,Айроло,აიროლო,艾羅洛', 46.5285500, 8.6118900, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11650, 'Aigle', 'Aigle', 'Agllo,Aigle,Aigle VD,Egul,Ehgl'',ZDC,agl  swyys,ai ge lei,ayghl,Âgllo,Егъл,Эгль,אגל,إيغل,اگل، سوئیس,埃格勒', 46.3181000, 6.9645700, 'CH', '2014-03-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11651, 'Agno', 'Agno', 'Agn,Agno TI,Agno i Sveits,Anium,a ge nuo,anyw  swyys,انیو، سوئیس,阿格諾', 45.9986300, 8.9003000, 'CH', '2013-03-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11652, 'Affoltern am Albis', 'Affoltern am Albis', 'Affol''tern-na-Al''bis,Affol''tern-na-Al''bise,Affoltern am Albis,Affoltern ce Albis,Affoltern ĉe Albis,Afoltern am Albis,a er bi si fu jin a fu er te en,afwltrn am‌alby,afwltrwn am albys,Аффольтерн-на-Альбисе,Аффольтерн-на-Альбіс,أفولترون أم ألبيس,افولترن ام‌البی,阿爾比斯附近阿福爾特恩', 47.2774300, 8.4512800, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11653, 'Affeltrangen', 'Affeltrangen', 'Affeltrangen', 47.5258100, 9.0330700, 'CH', '2015-09-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11654, 'Aeschi', 'Aeschi', 'AEschi,Aeschi bei Spiez,Äschi', 46.6584800, 7.6965000, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11655, 'Aesch', 'Aesch', 'Aesch BL,Aesch i Basel-Landschaft,Ehsh,ai shi,Эш,埃施', 47.4710400, 7.5973000, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12219, 'Yoko', 'Yoko', 'Joko,Yoko', 5.5333300, 12.3166700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12220, 'Yokadouma', 'Yokadouma', 'Yokadouma,Youkadouma', 3.5166700, 15.0500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12221, 'Yaoundé', 'Yaounde', 'Giaounte,Gorad Jaundeh,Jande,Jaunde,Jaundeo,Jaundė,Jaúnde,Jánde,YAO,Yaounde,Yaoundé,Yaunde,Yaundé,Yawunde,iaunde,ya wen de,ya''unde,yaunde,yavunte,yawndy,yaxunde,yaywndh,ye wen de,Γιαουντέ,Јаунде,Горад Яўндэ,Яунде,Յաունդե,יאונדה,יאונדע,ياوندي,یاؤندے,یائونده,یائوندێ,یاونڈی,याउंदे,ਯਾਊਂਦੇ,யாவுண்டே,ยาอุนเด,ཡོན་དྷི།,იაუნდე,ያዉንዴ,ヤウンデ,耶溫得,雅温得,야운데', 3.8666700, 11.5166700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12222, 'Yagoua', 'Yagoua', 'GXX,Jagua,Jágua,Yagoua,Yagua', 10.3410700, 15.2328800, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12223, 'Yabassi', 'Yabassi', 'Jabassi,Yabasi,Yabassi,Yabazi', 4.4569700, 9.9682200, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12224, 'Wum', 'Wum', 'Wum', 6.3833300, 10.0666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12225, 'Tonga', 'Tonga', 'Lagosdorf,Tonga,Tonga''s,Tonga’s', 4.9666700, 10.7000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12226, 'Tiko', 'Tiko', 'TKC,Tiko', 4.0750000, 9.3600500, 'CM', '2014-10-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12227, 'Tignère', 'Tignere', 'Tignere,Tignère,Tingere,Tingeré,Tinguere,Tinguéré', 7.3666700, 12.6500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12228, 'Tibati', 'Tibati', 'Tibati', 6.4650400, 12.6284300, 'CM', '2014-02-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12229, 'Tcholliré', 'Tchollire', 'Cholire,Choliré,Chollire,Djolere,Djoléré,Jolere,Tcholere,Tcholire,Tcholiré,Tchollire,Tcholliré,Tcholéré,Tscholere', 8.4022000, 14.1698000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12230, 'Sangmélima', 'Sangmelima', 'Sangmelima,Sangmelina,Sangmélima,Сангмелима', 2.9333300, 11.9833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12231, 'Saa', 'Saa', 'Saa', 4.3666700, 11.4500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12232, 'Rey Bouba', 'Rey Bouba', 'Rei Buba,Rei-Bouba,Rey Bouba,Reï-Bouba', 8.6724000, 14.1786000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12233, 'Poli', 'Poli', '', 8.4756000, 13.2409700, 'CM', '2015-02-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12234, 'Pitoa', 'Pitoa', 'Piloa,Pitoa,Pitowa', 9.3839000, 13.5023100, 'CM', '2014-01-08', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12235, 'Penja', 'Penja', 'Penja', 4.6391100, 9.6798700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12236, 'Ombésa', 'Ombesa', 'Ombesa,Ombessa,Ombésa', 4.6000000, 11.2500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12237, 'Okola', 'Okola', '', 4.0166700, 11.3833300, 'CM', '2011-03-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12238, 'Okoa', 'Okoa', 'Okoa,Scho,So,Soa', 3.9833300, 11.6000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12239, 'Obala', 'Obala', 'Obala', 4.1666700, 11.5333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12240, 'Ntui', 'Ntui', 'N''Dui,Ntui,Ntwi,N’Dui', 4.4500000, 11.6333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12241, 'Nkoteng', 'Nkoteng', 'Nkoteng', 4.5166700, 12.0333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12242, 'Nkongsamba', 'Nkongsamba', 'NKS,Nkongsamba,Nkongsomba,Нконгсамба', 4.9547000, 9.9404000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12243, 'Njinikom', 'Njinikom', 'Njinikom,Njnikom', 6.2333300, 10.2833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12244, 'Nguti', 'Nguti', '', 5.3299000, 9.4185000, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12245, 'Ngoro', 'Ngoro', 'Janjo,Janjō,Ngoro,Ngorro', 4.9500000, 11.3833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12246, 'Ngomedzap', 'Ngomedzap', 'Ngomedzap', 3.2500000, 11.2000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12247, 'Ngaoundéré', 'Ngaoundere', 'NGE,Ngaoundere,Ngaoundéré,Ngaundere,Ngaunderė,en gang dai lei,eung-gaundele,nugaundere,Нгаундере,نگاؤندیرے,ヌガウンデレ,恩冈代雷,응가운데레', 7.3276500, 13.5847200, 'CM', '2013-10-22', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12248, 'Ngambé', 'Ngambe', 'Babimbi,Ngambe,Ngambé,Nganbe,Nganbé', 4.2334300, 10.6153200, 'CM', '2015-02-28', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12083, 'Yumbel', 'Yumbel', 'Jumbel'',Yumbel,yumbel,yun bei er,ywmbl,Юмбель,یومبل,雲貝爾,윰벨', -37.0982000, -72.5608400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12084, 'Viña del Mar', 'Vina del Mar', 'KNA,Vin''ja-del''-Mar,Vina del Mar,Vinea Maris,Vinja del Mar,Vinja del Maras,Vinja-del''-Mar,Vinya del Mar,Viña del Mar,bi ni ya de er ma,binyadelmaleu,fynya dyl mar,wynya dl mar,Винья-дель-Мар,Виня дел Мар,Виња дел Мар,Віня-дель-Мар,Վինյա դել Մար,ויניה דל מאר,فينيا ديل مار,وینیا دل مار,ビニャ・デル・マール,比尼亚德尔马,비냐델마르', -33.0245700, -71.5518300, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12085, 'Villarrica', 'Villarrica', 'Gorad Vil''jaryka,Vil''jarrika,Vilarika,Viljarika,ZVC,bi ya li ka,bijarika,biyalika,wylaryka,Вильяррика,Виљарика,Горад Вільярыка,ویلاریکا,ビジャリカ,比亞里卡,비야리카', -39.2856900, -72.2279000, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12086, 'Villa Alemana', 'Villa Alemana', 'Vil''ja-Alemana,Vila Alemana,Villa Alemana,a lai ma na zhen,biyaallemana,wwylʼ ʼlʻmʼnʼ,wya almana,Вилья-Алемана,Виља Алемана,Вілья-Алемана,ווילא אלעמאנא,ویا آلمانا,ビジャ・アレマーナ,阿萊馬納鎮,비야알레마나', -33.0422200, -71.3733300, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12087, 'Vilcún', 'Vilcun', 'Vilcun,Vilcún', -38.6687500, -72.2256500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12088, 'Vicuña', 'Vicuna', 'Vicuna,Vicuña,Vikun''ja,Vikunija,Викунья', -30.0354100, -70.7127400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12089, 'Victoria', 'Victoria', 'Victoria,Viktorija,ZIC,bigtolia,wei duo li ya,Виктория,وکٹوریہ، چلی,ვიქტორია,維多利亞,빅토리아', -38.2329100, -72.3329200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12090, 'Valparaíso', 'Valparaiso', 'Balparaiso,Ciudad de Valparaiso,Ciudad de Valparaíso,Dakbayan sa Valparaiso,Dakbayan sa Valparaíso,Gorad Val''paraisa,VAP,Val''paraiso,Vallis Paradisi,Valparaesos,Valparais,Valparaisas,Valparaiso,Valparayso,Valparaíso,Valparaėsos,Waer pa lai suo,Wǎěr pà lái suǒ,bal pa ra xi so,balapara''iso,balpalaiso,balpara''i esa,balparaysw,balparejho,baruparaiso,bhalapara''iso,falbaraysw,valapara''iso,valaparaiso,valpara''iso,valparaijo,valparaysۆ,valpeyracov,wa er pa lai suo,walparayzw,walprayysw,walprayzw,Βαλπαραΐσο,Валпараисо,Вальпараисо,Вальпараїсо,Горад Вальпараіса,Վալպարաիսո,וואלפאראיסא,ולפראיסו,بآلپارایسو,فالبارايسو,والپارایزو,والپرائیسو,والپرایزو,ڤالپارایسۆ,ܒܐܠܦܐܪܐܝܣܘ,ވަލޕަރައިސޮ,बाल्परेझो,वालपाराईसो,वालपारैसो,ভালপারাইসো,ਬਾਲਪਰਾਈਸੋ,વાલ્પારાઇસો,ବଲ୍ପରଇ େସା,வல்பெய்ரசோவ்,వల్పరైజో,വൽപറാസിയോ,වල්පරයිසෝ,บัลปาราอีโซ,བལྤ་རཨིསོ,ဗလၲပရမိစော,ვალპარაისო,ቫልፓራይሶ,ᕙᓪᐸᕃᓱ,バルパライソ,瓦尔帕莱索,瓦爾帕萊索,발파라이소', -33.0393200, -71.6272500, 'CL', '2017-02-04', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12091, 'Vallenar', 'Vallenar', 'VLR,Vallenar', -28.5761700, -70.7593800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12092, 'Valdivia', 'Valdivia', 'Ciudad de Valdivia,Ciudad de Valdivía,Gorad Val''dyvija,Val''divija,Valdeveje,Valdivia,Valdivija,Valdėvėjė,ZAL,bal di beiy,baldibia,baldybya,barudibia,valdivia,wa er di wei ya,waldywya,Βαλδίβια,Валдивия,Валдивија,Вальдивия,Вальдівія,Горад Вальдывія,ואלדיביה,וואלדיוויא,بالدیبیا,والدیویا,บัลดีเบีย,ვალდივია,バルディビア,瓦尔迪维亚,발디비아', -39.8142200, -73.2458900, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12093, 'Traiguén', 'Traiguen', 'Traiguen,Traiguén,Trajgen,te lai gen,teulaigen,Трайген,特賴根,트라이겐', -38.2496000, -72.6702700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12094, 'Tomé', 'Tome', 'Tome,Tomé,Tomė,tome,tuo mei,Томе,トメ,托梅,토메', -36.6175600, -72.9559300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12095, 'Tocopilla', 'Tocopilla', 'TOQ,Tocopilla,Tokopil''ja,Tokopila,Tokopilija,tokopiya,tuo ke pi ya,twkwpyla,Токопилья,Токопиља,Токопілья,توکوپیلا,托科皮亚,토코피야', -22.0919800, -70.1979200, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12096, 'Teno', 'Teno', 'Teno', -34.8705500, -71.1621900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12097, 'Temuco', 'Temuco', 'Ciudad Temuco,Temouko,Temuco,Temukas,Temuko,Temuks,ZCO,te mu ke,temu ko,temuko,temyukea,tymwkw,Τεμούκο,Тeмуко,Темуко,Տեմուկո,טעמוקא,تیموکو,ടെമ്യൂകോ,เตมูโก,ტემუკო,テムコ,特木科,테무코', -38.7396500, -72.5984200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12098, 'Taltal', 'Taltal', 'Ciudad Taltal,TTC,Tal''tal'',Taltal,ta er ta er,tal tal,Тальталь,تال تال,塔爾塔爾', -25.4087300, -70.4835800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12099, 'Talcahuano', 'Talcahuano', 'Gorad Tal''kauana,Tal''kauano,Talcahuano,Talkahuanas,Talkauano,Talkavano,Talkawanu,ta er ka wa nuo,tal kaxaw no,talkahwanw,talkauano,tarukawano,Горад Талькауана,Талкауано,Талькауано,טאלקאוואנא,تالكاهوانو,تالکاهوانو,ตัลกาอัวโน,タルカワノ,塔爾卡瓦諾,탈카우아노', -36.7249400, -73.1168400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12100, 'Talca', 'Talca', 'Gorad Tal''ka,TLX,Tal''ka,Talca,Talka,Talkao,ta er ka,talka,taruka,Τάλκα,Горад Талька,Талка,Талька,تالكا,تالکا,ტალკა,タルカ,塔爾卡,탈카', -35.4264000, -71.6554200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12101, 'Talagante', 'Talagante', 'Talagante,ta la gan te,tallagante,Талаганте,塔拉甘特,탈라간테', -33.6638600, -70.9273400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12102, 'San Vicente de Tagua Tagua', 'San Vicente de Tagua Tagua', 'San Vicente,San Vicente de Taguatagua', -34.4385900, -71.0775100, 'CL', '2015-10-28', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12103, 'San Vicente', 'San Vicente', '', -34.4333300, -71.0833300, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12104, 'Santiago', 'Santiago', 'Ciles Santjagas,CiudadSantiago,SCL,Sanctiacobi,Sant''jago,Santiago,Santiago de Chile,Santiago de Xile,Santiago del Cile,Santiago do Chile,Santiago du Chili,Santiago du Ch·ili,Santianko,Santjago,Santjago de Chile,Santjago de Chili,Stgo.,santiago,santixako,santyaghw,santyagw,santyyagw,sheng de ya ge,Čilės Santjagas,Σαντιάγκο,Σαντιάγο,Сантьяго,Сантяго де Чиле,Сантяго де Чили,סנטיאגו דה צ''ילה,سانتىياگو,سانتياغو,سانتیاگو,ซันติอาโก,სანტიაგო დე ჩილე,ሳንቲያጎ,サンティアゴ,圣地亚哥,산티아고', -33.4569400, -70.6482700, 'CL', '2016-07-05', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12105, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa-Krus,santakeuluseu,sheng ke lu si,Санта-Крус,聖克魯斯,산타크루스', -34.6388100, -71.3657600, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12106, 'San Pedro de Atacama', 'San Pedro de Atacama', 'San Pedro de Atacama,San Pedro de Atakama,San Pedro nte Atakama,San-Pedro-de-Atakama,sanpedeulodeatakama,sheng pei de luo de a ta ka ma,Σαν Πέδρο ντε Ατακάμα,Сан-Педро-де-Атакама,サンペドロ・デ・アタカマ,聖佩德羅德阿塔卡馬,산페드로데아타카마', -22.9111000, -68.2011300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12107, 'San Javier', 'San Javier', 'San Javier,San Javier de Loncomilla,San Khavijer,San-Khav''er-de-Lonkomil''ja,sanhaibeleu,sheng ha wei er,Сан Хавијер,Сан-Хавьер-де-Лонкомилья,聖哈維爾,산하이베르', -35.5952000, -71.7292400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12108, 'San Felipe', 'San Felipe', 'San Felipe', -32.7497600, -70.7258400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12109, 'San Clemente', 'San Clemente', 'San Clemente', -35.5377700, -71.4870000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12110, 'San Carlos', 'San Carlos', 'San-Karlos,sankaleulloseu,sheng ka luo si,Сан-Карлос,聖卡洛斯,산카를로스', -36.4247700, -71.9580000, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12111, 'San Bernardo', 'San Bernardo', 'San Bernardo,San-Bernardo,sheng bei er na duo,Сан-Бернардо,聖貝爾納多', -33.5921700, -70.6996000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12112, 'San Antonio', 'San Antonio', 'QTN,San Antonio,San-Antonio,sheng an dong ni ao,Сан Антонио,Сан-Антонио,聖安東尼奧', -33.5947300, -71.6074600, 'CL', '2016-02-28', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12113, 'Salamanca', 'Salamanca', 'Salaman''ka,Salamanca,Salamanka,Salmantica,sa la man ka,sa lama ngka,salamanaka,salamanca,salamanka,sallamangka,slmnqh,syalamenka,Σαλαμάνκα,Саламанка,סלמנקה,سالامانكا,سالامانکا,ܣܐܠܐܡܐܢܩܐ,सलामांका,সালামানকা,స్యాలమెంక,സലമന്ചാ,සළමන්ක,ซาลามังกา,薩拉曼卡,살라망카', -31.7792200, -70.9638900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12114, 'Río Bueno', 'Rio Bueno', 'Ciudad de Rio Bueno,Ciudad de Río Bueno,Rio Bueno,Río Bueno', -40.3349400, -72.9556400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12115, 'Rengo', 'Rengo', 'Rengo,leng-go,lun ge,Ренго,倫戈,렝고', -34.4063900, -70.8583400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12116, 'Rauco', 'Rauco', 'Rauco', -34.9254600, -71.3172200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12117, 'Rancagua', 'Rancagua', 'QRC,Ran''kagoua,Rancagua,Rankagua,Rankagva,Rankawa,lan ka gua,langkagwa,rangka kwa,rankagua,rankagwa,Ρανκάγουα,Ранкагуа,ראנקאגווע,رانکاگوآ,รังกากวา,რანკაგუა,ランカグア,兰卡瓜,랑카과', -34.1708300, -70.7444400, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12118, 'Quilpué', 'Quilpue', 'Kil''pueh,Quilpue,Quilpué,ji er pu ai,kirupue,Кильпуэ,キルプエ,基爾普埃', -33.0475200, -71.4424900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12119, 'Quillota', 'Quillota', 'Kijota,Kil''ota,Kiljota,Kilota,Quillota,ji yue ta,ki yo ta,kiyota,Кийота,Кильота,Киљота,กีโยตา,基約塔,키요타', -32.8834100, -71.2488200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12120, 'Puyehue', 'Puyehue', 'Pujeueh,Puyehue,Puyewe,Пуйеуэ', -40.6594400, -72.6017200, 'CL', '2013-01-26', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12121, 'Putre', 'Putre', 'Putre,pu te lei,Путре,პუტრე,普特雷', -18.1982100, -69.5607100, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12122, 'Purranque', 'Purranque', 'Purranke,Purranque,pu lan ke,pulangke,Пурранке,普蘭克,푸랑케', -40.9130500, -73.1591300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12123, 'Punta Arenas', 'Punta Arenas', 'Gorad Punta Arehnas,Magallanes,PUQ,Ponta Arenasos,Pounta Arenas,Promontorium Arenosum,Punta Arenas,Punta Arenasas,Punta-Arenas,Puntaarenasa,peng ta a lei na si,pun ta xa renas,puntaalenaseu,punta・arenasu,pwnta arnas,pwnta arynas,Πούντα Αρένας,Горад Пунта Арэнас,Пунта Аренас,Пунта-Аренас,פּונטא ארענאס,פונטה ארנס,پونتا آرناس,پونتا اریناس,ปุนตาอาเรนัส,პუნტა-არენასი,プンタ・アレーナス,蓬塔阿雷纳斯,푼타아레나스', -53.1548300, -70.9112900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12124, 'Puerto Varas', 'Puerto Varas', 'PUX,Puehrto Varas,Puehrto-Varas,Puerto Varas,Puerto Varasas,ba la si gang,bwyrtw faras,pueleutobalaseu,Пуерто Варас,Пуэрто Варас,Пуэрто-Варас,פּארטא וואראס,بويرتو فاراس,巴拉斯港,푸에르토바라스', -41.3194600, -72.9853800, 'CL', '2013-01-26', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12125, 'Quellón', 'Quellon', 'Puerto Quellon,Puerto Quellón,Quellon,Quellón', -43.1181900, -73.6166100, 'CL', '2016-11-23', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12126, 'Puerto Natales', 'Puerto Natales', 'Natales,PNT,Puehrto-Natales,Puerto Natales,Puerto Natalesas,Puerto-Natales,na ta lai si gang,Пуерто-Наталес,Пуэрто-Наталес,納塔萊斯港', -51.7236300, -72.4874500, 'CL', '2009-02-24', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12127, 'Puerto Montt', 'Puerto Montt', 'Ciudad de Puerto Montt,PMC,Port Montt,Portus Monttii,Pouerto Mont,Puehrto-Mont,Puerta Muonts,Puerto Mont,Puerto Montas,Puerto Montt,Puerto-Montt,Puertomonta,Puertu Montt,meng te gang,prtw mwnt,pueleutomonteu,puerutomonto,pytrw mwnt,Πουέρτο Μοντ,Пуерто Монт,Пуерто-Монтт,Пуэрто-Монт,פּארטא מאנט,פוארטו מונט,پرتو مونت,پیترو مونت,პუერტო-მონტი,プエルトモント,蒙特港,푸에르토몬트', -41.4669100, -72.9495600, 'CL', '2016-02-06', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12128, 'Puerto Cisnes', 'Puerto Cisnes', 'Puerto Cisnes', -44.7473600, -72.6969500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12129, 'Puerto Aisén', 'Puerto Aisen', 'Aisen,Aisén,Aysen,Ciudad de Aysen,Ciudad de Aysén,Puerto Aisen,Puerto Aisén,Puerto Aysen,Puerto Aysén,WPA', -45.4030300, -72.6918400, 'CL', '2017-03-05', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12130, 'Puente Alto', 'Puente Alto', 'Puehnte-Al''to,Puente Alto,shang pu en te,Пуенте Алто,Пуэнте-Альто,პუენტე-ალტო,上普恩特', -33.6116900, -70.5757700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12131, 'Pucón', 'Pucon', 'Pukon,Pukonas,ZPC,pu kong,pukon,Пукон,プコン,普孔,푸콘', -39.2822300, -71.9542700, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12132, 'Providencia', 'Providencia', 'Providencia,Providensija,Providentia,QOV,Провиденсия', -33.4310700, -70.6045400, 'CL', '2016-04-15', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12133, 'Pitrufquén', 'Pitrufquen', 'Pitrufquen,Pitrufquén', -38.9863500, -72.6372100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12134, 'Penco', 'Penco', 'Ciudad de Penco,Penco,Penko,Penon,Peñon,peng ke,pengko,penko,pnqw,Пенко,פּענקא,פנקו,ペンコ,彭科,펭코', -36.7407500, -72.9952800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12135, 'Peñaflor', 'Penaflor', 'Pen''jaflor,Penaflor,Peñaflor,Пеньяфлор', -33.6062700, -70.8764900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12136, 'Parral', 'Parral', 'Parral,Parralja,Парраля', -36.1431100, -71.8260500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12137, 'Panguipulli', 'Panguipulli', 'Panguipulli', -39.6435500, -72.3326900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12138, 'Palena', 'Palena', 'Alto Palena,Palena,WAP', -43.6187600, -71.8043400, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12139, 'Paine', 'Paine', 'Paine,Pejn,Пейн', -33.8079600, -70.7410900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12140, 'Ovalle', 'Ovalle', 'OVL,Oval''e,Ovalje,Ovaljė,Ovalle,ao wa lie,Овалье,奧瓦列', -30.6010600, -71.1990100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12141, 'Osorno', 'Osorno', 'Osorno,ZOS,Осорно', -40.5739500, -73.1334800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12142, 'Nueva Imperial', 'Nueva Imperial', 'Nuehva-Imper''jal'',Nueva Imperial,nuebaimpelial,xin di guo zhen,Нуэва-Имперьяль,新帝國鎮,누에바임페리알', -38.7445100, -72.9502500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12143, 'Nacimiento', 'Nacimiento', 'Nacimiento', -37.5025300, -72.6730700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12144, 'Mulchén', 'Mulchen', 'Mul''chen,Mulchen,Mulchén,Мульчен', -37.7189300, -72.2409900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12145, 'Monte Patria', 'Monte Patria', 'Monte Patria,Monte Patrija,Monte-Patrija,meng te pa te li ya,montepateulia,Монте-Патрия,蒙特帕特里亞,몬테파트리아', -30.6949600, -70.9577000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12146, 'Molina', 'Molina', 'Molina,Молина', -35.1142800, -71.2823200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12147, 'Melipilla', 'Melipilla', 'Melipil''ja,Melipila,Melipilla,Mellipilla,mei li pi ya,mellipiya,Мелипилья,Мелипиља,梅利皮亞,멜리피야', -33.6890900, -71.2152800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12148, 'Machalí', 'Machali', 'Machali,Machalí,ma cha li,machalli,Мачали,馬查利,마찰리', -34.1808200, -70.6493300, 'CL', '2013-04-04', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12149, 'Lota', 'Lota', 'Lot,Lota,lota,luo ta,lwta  shyly,lwth,rota,Лот,Лота,לוטה,لوتا، شیلی,ロタ,洛塔,로타', -37.0899400, -73.1577000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12150, 'Los Ángeles', 'Los Angeles', 'Angeles,Angelopolis,Ciudad de Los Anjeles,LSQ,Los Anceles,Los Angeles,Los Anjeles,Los Ángeles,Los-Andzheles,Los-Ankheles,lo sxang heles,loseuanghelleseu,luo sang he lai si,lws ankhls,Лос-Анджелес,Лос-Анхелес,לאס אנדזשעלעס,לוס אנחלס,لوس آنخلس,โลสอังเฮเลส,ロス・アンヘレス,洛桑赫萊斯,로스앙헬레스', -37.4697300, -72.3536600, 'CL', '2016-11-21', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12151, 'Los Andes', 'Los Andes', 'Andes,Ciudad Los Andes,LOB,Los-And,Los-Andes,luo si an di si,Лос-Анд,Лос-Андес,洛斯安第斯', -32.8336900, -70.5982700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12152, 'Longaví', 'Longavi', 'Longavi,Longaví', -35.9649600, -71.6836000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12153, 'Loncoche', 'Loncoche', 'Loncoche', -39.3670800, -72.6308700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12154, 'Llaillay', 'Llaillay', 'Llaillai,Llaillay,Llay-Llay', -32.8404300, -70.9562300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12155, 'Linares', 'Linares', 'Linares,ZLR,li na lei si,linaleseu,Линарес,利納雷斯,리나레스', -35.8466700, -71.5930800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12156, 'Limache', 'Limache', 'Limache,li ma qie,limache,Лимаче,利馬切,리마체', -33.0166700, -71.2666700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12157, 'Lebu', 'Lebu', 'Ciudad de Lebu,Lebu,Puerto Lebu,lai bu,Лебу,萊布', -37.6082500, -73.6535600, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12158, 'Lautaro', 'Lautaro', 'Lautaro', -38.5306600, -72.4365200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12159, 'La Unión', 'La Union', 'Ciudad La Union,La Union,La Unión,La-Un''on,la wnywn  chly,la ywnywn,launion,Ла Унион,Ла-Уньон,لا ونیون، چلی,لا یونیون,라우니온', -40.2931300, -73.0816700, 'CL', '2016-01-27', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12160, 'La Serena', 'La Serena', 'LSC,La Serena,La-Serena,Laserena,Serena,la sai lei na,la syryna,la syryna  chly,la-serena,laselena,lasrna,lasyryna,lh srnh,Ла Серена,Ла-Серена,Серена,Լա Սերենա,לה סרנה,لا سيرينا,لا سیرینا، چلی,لاسرنا,لاسیرینا,ლა-სერენა,ラ・セレナ,拉塞雷纳,라세레나', -29.9045300, -71.2489400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12161, 'Lampa', 'Lampa', 'Lampa', -33.2863000, -70.8756100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12162, 'La Ligua', 'La Ligua', '', -32.4524200, -71.2310600, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12163, 'La Laja', 'La Laja', 'La Laja,Laja', -37.2841500, -72.7110500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12164, 'La Ensenada', 'La Ensenada', 'Ehnsenada,Ensenada,La Ensenada,Энсенада', -41.2074600, -72.5384000, 'CL', '2013-01-26', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12165, 'Iquique', 'Iquique', 'IQQ,Ikike,Ikikė,Iquique,akwyykyw,ikike,yi ji ke,Ικίκε,Ікіке,Икике,Իկիկե,איקיקה,اکوئیکیو,იკიკე,イキケ,伊基克,이키케', -20.2203600, -70.1391300, 'CL', '2012-12-05', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12166, 'Illapel', 'Illapel', 'Il''japel'',Iljapelis,Illapel,yi ya pei er,Ильяпель,伊亞佩爾', -31.6334900, -71.1696700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12167, 'Hacienda La Calera', 'Hacienda La Calera', 'Calera,Hacienda La Calera', -32.7833300, -71.2166700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12168, 'Graneros', 'Graneros', 'Graneros,ge la nei luo si,geulaneloseu,Гранерос,格拉內羅斯,그라네로스', -34.0686300, -70.7274700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12169, 'Futaleufú', 'Futaleufu', 'FFU,Futalelfu,Futalelfú,Futaleufu,Futaleufú,fu ta lai wu fu,fywtalywfw  shyly,fywtalywfyw,putalle-upu,Футалеуфу,فيوتاليوفيو,فیوتالیوفو، شیلی,富塔萊烏富,푸탈레우푸', -43.1849200, -71.8672200, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12170, 'Frutillar', 'Frutillar', 'FRT,Frutil''jar,Фрутильяр', -41.1267600, -73.0437200, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12171, 'Freire', 'Freire', 'Freire', -38.9525200, -72.6265300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12172, 'El Tabo', 'El Tabo', '', -33.4500000, -71.6666700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12173, 'El Monte', 'El Monte', 'El Monte', -33.6796900, -70.9848200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12174, 'Diego de Almagro', 'Diego de Almagro', 'Diego de Almagro', -26.3666700, -70.0500000, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12175, 'Curicó', 'Curico', 'Curico,Curicó,Kuriko,ku li ke,ku ri ko,kuliko,kuriko,kwrykw,kwrykw  shyly,Курико,Куріко,كوريكو,کوریکو، شیلی,กูรีโก,クリコ,庫里科,쿠리코', -34.9827900, -71.2394300, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12176, 'Curanilahue', 'Curanilahue', 'Curanilahue,Kuranilaueh,Kuranilave,ku la ni la wei,kulanillaue,kywranay lahyw,kywranaylahyw  shyly,Куранилаве,Куранилауэ,كيوراناي لاهيو,کیورانایلاهیو، شیلی,庫拉尼拉韋,쿠라닐라우에', -37.4779300, -73.3449500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12177, 'Corral', 'Corral', 'Ciudad de Corral,Korral'',Puerto Corral,ke la er,kolal,kwral,kwral  shyly,Корраль,كورال,کورال، شیلی,科拉爾,코랄', -39.8873000, -73.4310100, 'CL', '2014-04-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12178, 'Coronel', 'Coronel', 'Coronel,Koronel,Koronel'',ke luo nei er,koroneru,kwrwnl,Коронел,Коронель,קאראנעל,كورونل,コロネル,科羅內爾', -37.0338600, -73.1401900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12179, 'Coquimbo', 'Coquimbo', 'COW,Ciudad de Coquimbo,Coquimbo,Kokimbas,Kokimbo,Kukimpu,Mkoa wa Coquimbo,ke jin bo,koki m bo,kokimbo,kokinbo,kwkwymbw,Кокимбо,Кокімбо,كوكويمبو,โกกิมโบ,コキンボ,科金博,코킴보', -29.9533200, -71.3394700, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12180, 'Copiapó', 'Copiapo', 'CPO,Copiapo,Copiapó,Kop''japo,Kopiapo,Kopijapo,Kopjapo,Kuopejapa,Kuopėjapa,Qhupiyapu,ke pi ya bo,kopiapo,kwbyabw,kwpyapw,kwpyapw  shyly,Κοπιαπό,Копиапо,Копијапо,Копьяпо,Копіапо,كوبيابو,کوپیاپو,کوپیاپو، شیلی,კოპიაპო,コピアポ,科皮亞波,코피아포', -27.3667900, -70.3314000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12181, 'Constitución', 'Constitucion', 'Constitucion,Constitución,Konstitus''on,Konstitusjon,kanstytsywn  shyly,kong si di tu xi weng,konseutitusion,konsutito~ushion,kwnstytsywn,Конститусьон,Конститусјон,كونستيتسيون,کانستیتسیون، شیلی,コンスティトゥシオン,孔斯蒂圖西翁,콘스티투시온', -35.3332100, -72.4115600, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12182, 'Concepción', 'Concepcion', 'CCP,Ciudad de Concepcion,Ciudad ti Concepcion,Concepcion,Concepcioun,Concepción,Conceptio,Gorad Kanseps''jon,Koncepciono,Koncepsion,Konsep''sion,Konsepcion,Konseps''jon,Konseps''on,Konsepshon,Konsepsion,Konsepsjon,Konsepsjona,Konsepsjonas,Konsepsjons,Konsepsjuons,Konsepsyon,Koνσεπσιόν,kancepciyan,kang sai pu xi weng,kansepsiyan,kansepsiyana,knspsywn  shyly,konsebsion,konsepSION,konsepsi''ona,konsepushion,kwnsbsywn   tshyly,kwnsypshywn,kwnthbthywn  tshyly,kxn sep si xxn,qwnspsywn,Κονσεπσιόν,Горад Кансепсьён,Конceпсіон,Консeпcион,Консепçион,Консепсион,Консепсьйон,Консепсьон,Консепшон,Կոնսեպսիոն,קאנסעפסיאן,קונספסיון,كونثبثيون، تشيلي,كونسبسيون ، تشيلى,کنسپسیون، شیلی,کونسیپشیون,ܩܘܢܣܦܣܝܘܢ,कन्सेप्सियान,कान्सेप्सियान्,कॉन्सेप्सिओन,கன்செப்சியான்,กอนเซปซีออน,კონსეფსიონი,ኮንሴፕሲዮን,コンセプシオン,康塞普西翁,康賽普西翁,콘셉시온,', -36.8269900, -73.0497700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12183, 'Collipulli', 'Collipulli', 'Collipulli', -37.9545300, -72.4343800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12184, 'Colbún', 'Colbun', 'Colbun,Colbún,Kol''bun,ke er wen,kolbun,kwlbwn  shyly,kwlbywn,Кольбун,كولبيون,کولبون، شیلی,科爾文,콜분', -35.6949400, -71.4056800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12185, 'Coihueco', 'Coihueco', '', -36.6278500, -71.8306800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12186, 'Coyhaique', 'Coyhaique', 'Coihaique,Coyhaique,GXQ,Kojajke,Койайке', -45.5752400, -72.0661900, 'CL', '2017-04-08', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12187, 'Cochrane', 'Cochrane', 'Kokran,Kokreinas,LGR,ke ke la nei,kokeulane,kwkryn,kwkryn  shyly,Кокран,كوكرين,کوکرین، شیلی,科克拉內,코크라네', -47.2557000, -72.5695000, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12188, 'Chonchi', 'Chonchi', 'Chonch,Chonchi,Trongchue,Trongchü,chonchi,chwnchy  shyly,qiong qi,shwnshy,Чончи,شونشي,چونچی، شیلی,瓊奇,촌치', -42.6200300, -73.7767400, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12189, 'Chimbarongo', 'Chimbarongo', 'Chimbarongo', -34.7124700, -71.0434000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12190, 'Chillán', 'Chillan', 'YAI', -36.6066400, -72.1034400, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12191, 'Chile Chico', 'Chile Chico', 'CCH,Chile Chico', -46.5410000, -71.7237500, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12192, 'Chiguayante', 'Chiguayante', 'Chiguajante,Chiguayante,chiguayante,chigwayante,qi gua yang te,shyghwanty,shygwanty  shyly,Чигуаянте,Чигуајанте,טשיגואיאנטע,شيغوانتي,شیگوانتی، شیلی,チグアヤンテ,奇瓜揚特,치과얀테', -36.9256000, -73.0284100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12193, 'Chicureo Abajo', 'Chicureo Abajo', 'Chicu,Chicureo,Chicureo Abajo', -33.2837900, -70.6533300, 'CL', '2013-04-25', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12194, 'Chaitén', 'Chaiten', 'Caitenas,Chajten,WCH,chai teng,chaiten,chaytn  shyly,shaytn,Čaitenas,Чайтен,شايتن,چایتن، شیلی,柴滕,차이텐', -42.9159600, -72.7063200, 'CL', '2017-02-20', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12195, 'Cauquenes', 'Cauquenes', 'Cauquenes,De Cauquenes,Kaukenes,kao ke nei si,kaukeneseu,kaykywnys,Каукенес,كايكيونيس,考克內斯,카우케네스', -35.9671000, -72.3224800, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12196, 'Castro', 'Castro', 'Kastras,Kastro,WCA,ka si te luo shi,kasutoro,qstrw,Кастро,קאסטרא,קסטרו,カストロ,卡斯特罗市', -42.4721000, -73.7731900, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12197, 'Cartagena', 'Cartagena', 'Cartagena,Cartajena,Carthagene,Carthagène,Kartakhena,ka ta he na,kaleutahena,qrtajnt,Картахена,قرطاجنة,卡塔赫納,카르타헤나', -33.5538400, -71.6076100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12198, 'Carahue', 'Carahue', 'Carahue,Carahuo', -38.7112200, -73.1610100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12199, 'Cañete', 'Canete', 'Canete,Cañete,Kan''ete,Kanyete,ka nie te,kanyete,kanyt,Каньете,كانيت,卡涅特,카녜테', -37.8012800, -73.3961600, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12200, 'Calbuco', 'Calbuco', 'Calbuco,Kal''buko,Kallfueko,Kallfüko,ka er bu ke,kalbuko,kalbwkw,Кальбуко,كالبوكو,卡爾布科,칼부코', -41.7733800, -73.1304900, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12201, 'Calama', 'Calama', 'CJC,Calama,Kalama,ka la ma,kala ma,kalama,kallama,karama,Калама,كالاما,کالاما,กาลามา,カラマ,卡拉馬,칼라마', -22.4566700, -68.9237100, 'CL', '2016-06-04', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12202, 'Cabrero', 'Cabrero', 'Cabrero,Carrero', -37.0339400, -72.4046800, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12203, 'Bulnes', 'Bulnes', '', -36.7423200, -72.2985400, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12204, 'Buin', 'Buin', 'Buin,Буин', -33.7325700, -70.7428100, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12205, 'Arica', 'Arica', 'ARI,Areka,Arica,Arika,Arėka,a li ka,a lie ka,alika,arika,aryka,erika,Αρίκα,Арика,Аріка,Արիկա,אריקא,אריקה,آریکا,أريكا,एरिका,ਆਰੀਕਾ,არიკა,アリカ,阿列卡,阿里卡,아리카', -18.4746000, -70.2979200, 'CL', '2012-12-05', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12206, 'Arauco', 'Arauco', 'Arauko,a lao ke,alauko,arawkw,Арауко,أراوكو,阿勞科,아라우코', -37.2463000, -73.3175200, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12207, 'Antofagasta', 'Antofagasta', 'ANF,Antafagasta,Antofagast,Antofagasta,Antuofagasta,an tuo fa jia si ta,antaphagasta,antofagasuta,antopagaseuta,antophagasta,antwfagasta,antwfaghasta,antwfajasta,antwfakwsta,entofagasta,xan to faka s ta,Αντοφαγάστα,Антафагаста,Антофагаста,אנטאפאגאסטא,אנטופגסטה,آنتوفاگاستا,أنتوفاغاستا,انتوفاجاستا,انتوفاکوستا,انتوفاگاستا,ܐܢܛܘܦܐܓܐܣܛܐ,अंतोफागास्ता,एंटोफ़गास्टा,অন্তফাগস্টা,อันโตฟากัสตา,ཨན་ཏོ་ཕ་ག་སི་ཏ,ანტოფაგასტა,ኣንቶፋጋስታ,アントファガスタ,安托法加斯塔,안토파가스타', -23.6523600, -70.3954000, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12208, 'Angol', 'Angol', 'Angol,Angol'',Angolis,an ge er,angoru,Анголь,アンゴル,安戈爾', -37.7951900, -72.7163600, 'CL', '2013-03-13', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12209, 'Ancud', 'Ancud', 'An''koud,Ancud,Ankud,Ankudas,Ankun,Ankuñ,ZUD,an ku de,angkudeu,ankad,ankwd,Ανκούδ,Анкуд,أنكود,انکاد,安庫德,앙쿠드', -41.8707000, -73.8162200, 'CL', '2013-01-11', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12210, 'Puerto Chacabuco', 'Puerto Chacabuco', '', -45.4666700, -72.8166700, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12211, 'La Junta', 'La Junta', '', -43.9743400, -72.4055400, 'CL', '2014-05-01', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12212, 'Hanga Roa', 'Hanga Roa', 'Anga-Roa,Gorad Khanga-Roa,Hanaroa,Hanga Roa,Khanga Roa,Khanga-Roa,an jia luo a,hang-galoa,hanga-roa,hangaroa,hanja rwa,kanka urova,Анга-Роа,Горад Ханга-Роа,Ханга Роа,Ханга-Роа,האנגה רואה,هانجا روا,ہانگا روا,கங்கா உரோவா,ჰანგა-როა,ハンガロア,安加罗阿,항가로아', -27.1547400, -109.4324100, 'CL', '2017-01-26', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12213, 'Las Gaviotas', 'Las Gaviotas', '', -39.8665300, -73.1883400, 'CL', '2012-02-22', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12214, 'Las Animas', 'Las Animas', '', -39.8086700, -73.2182100, 'CL', '2007-04-15', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12215, 'La Pintana', 'La Pintana', 'La Pintana,La-Pintana,la ping ta na,lapintana,Ла Пинтана,Ла-Пинтана,لا پینٹانا,拉平塔納,라핀타나', -33.5833100, -70.6341900, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12216, 'Lo Prado', 'Lo Prado', 'Lo Prado,Lo-Prado,lopeulado,luo pu la duo,Ло Прадо,Ло-Прадо,洛普拉多,로프라도', -33.4443000, -70.7255200, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12217, 'Villa Presidente Frei, Ñuñoa, Santiago, Chile', 'Villa Presidente Frei, Nunoa, Santiago, Chile', '', -33.4606900, -70.5802400, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12218, 'Vallenar', 'Vallenar', '', -28.5157600, -70.2555100, 'CL', '2012-05-03', 45);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12082, 'Avarua', 'Avarua', 'Avaroua,Avarua,Avaruo,Avarúa,Gorad Avarua,RAR,a wa lu a,abalua,abarua,avarua,avaruva,avharu''a,awarwa,awarya,xa wa raw,Αβαρούα,Аваруа,Горад Аваруа,Ավարուա,אוורואה,آواروآ,آواریا,अव्हारुआ,அவாருவா,อะวารัว,ཨ་ཝ་རུ་ཨ།,ავარუა,アバルア,阿瓦鲁阿,아바루아', -21.2077800, -159.7750000, 'CK', '2012-01-18', 53);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11963, 'Zuénoula', 'Zuenoula', 'Zenoula,Zouenoula,Zouénoula,Zuenoula,Zuénoula,Zénoula', 7.4302700, -6.0505400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11964, 'Zoukougbeu', 'Zoukougbeu', 'Zoukougbe,Zoukougbeu', 6.7622900, -6.8638000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11965, 'Zouan-Hounien', 'Zouan-Hounien', 'Zouan-Hounien,Zoum Hounien,Zoun-Hounien', 6.9193700, -8.2065000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11966, 'Yamoussoukro', 'Yamoussoukro', 'ASK,Giamoussoukro,Gorad Jamusukra,Jamusukras,Jamusukro,Jamusukro khot,Yamosukro,Yamousoukro,Yamoussokro,Yamoussoukro,Yamoussoukrou,Yamussukro,Yamusukro,ya mu su ke lei,ya mu su ke luo,ya mussu kor,yamucukro,yamusasutro,yamusukaro,yamusukeulo,yamusukro,yamusukuro,yamwsswkrw,yamwswkrw,yamwwswwkrۆ,ywmwswkrw,Γιαμουσσούκρο,Јамусукро,Горад Ямусукра,Ямусукро,Ямусукро хот,Յամուսուկրո,יאמוסאקרא,יאמוסוקרו,ياموسوكرو,يامۇسسۇكرو,یاموسسوکرو,یاموسوکرو,یامووسووکرۆ,یوموسوکرو,यामूसूक्रो,ਯਾਮੂਸੂਕਰੋ,ୟାମୁସସୁତ୍ରୋ,யாமூசூக்ரோ,ยามุสซุโกร,ཡམ་སོ་ཁེ་རོ།,იამუსუკრო,ያሙሱክሮ,ヤムスクロ,亚穆苏克罗,雅穆蘇克雷,야무수크로', 6.8205500, -5.2767400, 'CI', '2012-01-17', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11967, 'Yakassé-Attobrou', 'Yakasse-Attobrou', 'Yakasse,Yakasse-Attobrou,Yakassé,Yakassé-Attobrou', 6.1817400, -3.6511100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11968, 'Ouaninou', 'Ouaninou', 'Ouaninou,Waninou', 8.2379000, -7.8663800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11969, 'Vavoua', 'Vavoua', 'Vavoua,Vavua,Вавуа', 7.3819400, -6.4777800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11970, 'Transua', 'Transua', 'Transua', 7.5500400, -3.0143100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11971, 'Toumodi', 'Toumodi', 'Toumodi,Tumodi', 6.5579900, -5.0176900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11972, 'Toulépleu Gueré', 'Toulepleu Guere', '', 6.5739500, -8.4259200, 'CI', '2014-01-10', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11973, 'Toulépleu', 'Toulepleu', 'Toulepleu,Toulobli,Toulépleu', 6.5797400, -8.4109100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11974, 'Touba', 'Touba', 'TOZ,Touba,Tuba', 8.2833300, -7.6833300, 'CI', '2016-05-22', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11975, 'Tengréla', 'Tengrela', 'Tengrela,Tengréla,Tingrela,Tingréla', 10.4811500, -6.4069400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11976, 'Tiébissou', 'Tiebissou', 'Tiebissou,Tiebissu,Tiébissou', 7.1577200, -5.2248000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11977, 'Tiassalé', 'Tiassale', 'Tiassale,Tiassalé', 5.8983900, -4.8229300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11978, 'Téhini', 'Tehini', 'Tehini,Téhini', 9.6054200, -3.6580400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11979, 'Tanda', 'Tanda', 'Tan N''Da,Tan N’Da,Tanda,Tanga', 7.8033500, -3.1683200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11980, 'Taï', 'Tai', 'Tai,Taï', 5.8736600, -7.4551900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11981, 'Tabou', 'Tabou', 'TXU,Tabou,Tabu', 4.4229500, -7.3528000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11982, 'Sipilou', 'Sipilou', 'Siguita,Sipilou,Siquita', 7.8645000, -8.1014300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11983, 'Sinfra', 'Sinfra', 'Sinfra', 6.6210300, -5.9114400, 'CI', '2013-08-05', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11984, 'Sinématiali', 'Sinematiali', 'Sinematiali,Sinématiali', 9.5841000, -5.3847600, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11985, 'Sikensi', 'Sikensi', 'Sikensi,Sikinssi,Sitensi', 5.6682900, -4.5737100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11986, 'Séguélon', 'Seguelon', 'Segelo-Koura,Seguelon,Séguélon,Ségélo-Koura', 9.3569400, -7.1208300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11987, 'Sassandra', 'Sassandra', 'Sasandra,Sassandra,ZSS,sa sang de la,sasandra,Сасандра,Сассандра,ساساندرا,薩桑德拉', 4.9538400, -6.0853100, 'CI', '2013-05-11', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11988, 'San-Pédro', 'San-Pedro', 'SPY,San Pedras,San Pedro,San Pédro,San-Pedro,San-Pédro,san bydrw,san=pedoro,sangpedeulo,sheng pei de luo,Сан-Педро,سان بيدرو,サン＝ペドロ,聖佩德羅,상페드로', 4.7485100, -6.6363000, 'CI', '2016-09-20', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11989, 'Sandégué', 'Sandegue', 'Sandegue,Sandégué', 7.9537600, -3.5801200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11990, 'Samatiguila', 'Samatiguila', 'Samatigila,Samatiguila', 9.8195200, -7.5608500, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11991, 'Sakassou', 'Sakassou', 'Sakasso,Sakassou,Sakassu', 7.4546200, -5.2926300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11992, 'Prikro', 'Prikro', 'Pirikrou,Priko,Prikro,Prikrou', 7.6470500, -3.9962600, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11993, 'Oumé', 'Oume', 'Oume,Oumé,Ume', 6.3830900, -5.4175900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11994, 'Ouangolodougou', 'Ouangolodougou', 'Ouangolodougou,Wangolodougou,Wangolodugu', 9.9683700, -5.1488200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11995, 'Odienné', 'Odienne', 'KEO,Odienne,Odienné,Odjene,Odjenė,ao die nei,Одиенне,奧迭內', 9.5051100, -7.5643300, 'CI', '2017-04-23', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11996, 'Niakaramandougou', 'Niakaramandougou', 'Niakaramandougou,Niankarama Kaha,Niankaramadougou,Niankaramadugu,Niankaramandougou', 8.6575900, -5.2910900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11997, 'Nassian', 'Nassian', 'Nasiam,Nasian,Nassian', 8.4527500, -3.4715200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11998, 'M’Bengué', 'M''Bengue', 'M''Begue,M''Begue Sokoro,M''Bengue,Mbengue,Mbenguie,Mbenguié,Mbengué,Mbingue,Mbingué,Mbngue,Mbngué,M’Bengué,M’Bégué,M’Bégué Sôkoro', 10.0024400, -5.9003700, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11999, 'M’Batto', 'M''Batto', 'M''Batto,Mbato,Mboto,M’Batto', 6.4719700, -4.3578100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12000, 'M’Bahiakro', 'M''Bahiakro', 'M''Bahiacro,M''Bahiakro,M''Bahiakrou,M''Bakiakro,Mbayakro,M’Bahiacro,M’Bahiakro,M’Bahiakrou,M’Bakiakro', 7.4572800, -4.3399300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12001, 'Mankono', 'Mankono', 'Mankono', 8.0586100, -6.1897200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12002, 'Minignan', 'Minignan', 'Maniniam,Maninian,Minignan', 9.9974400, -7.8359300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12003, 'Man', 'Man', 'MJC,Man', 7.4125100, -7.5538300, 'CI', '2012-01-17', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12004, 'Maféré', 'Mafere', 'Mafere,Maféré', 5.4151000, -3.0300600, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12005, 'Madinani', 'Madinani', 'Madinani', 9.6108300, -6.9421500, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12006, 'Lakota', 'Lakota', 'Iakota,Lakota,Лакота', 5.8475200, -5.6820000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12007, 'Kouto', 'Kouto', 'Kouto', 9.8902900, -6.4092100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12008, 'Kounahiri', 'Kounahiri', 'Koumahiri,Kounahiri,Kounairi,Kounaïri,Kunairi', 7.7908900, -5.8347700, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12009, 'Koun-Fao', 'Koun-Fao', 'Akun,Koun,Koun-Fao', 7.4876400, -3.2524900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12010, 'Kouibly', 'Kouibly', 'Kouibli,Kouibly', 7.2559700, -7.2350800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12011, 'Koro', 'Koro', 'Koro', 8.5550500, -7.4634800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12012, 'Korhogo', 'Korhogo', 'HGO,Korhogas,Korhogo,Korogo,ke huo ge,kologo,korogo,Корого,コロゴ,科霍戈,코로고', 9.4580300, -5.6296100, 'CI', '2014-08-20', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12013, 'Kong', 'Kong', 'Kong', 9.1494300, -4.6098200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12014, 'Kouassi-Kouassikro', 'Kouassi-Kouassikro', 'Koissi-Koissikro,Kouassi-Kouassikro', 7.3414100, -4.6770900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12015, 'Katiola', 'Katiola', 'KTC,Katiola,Lafouka', 8.1372800, -5.1009500, 'CI', '2016-12-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12016, 'Kaniasso', 'Kaniasso', 'Kaniasso,Kanyaso', 9.8147100, -7.5125000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12017, 'Kani', 'Kani', 'Kani', 8.4780700, -6.6050900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12018, 'Jacqueville', 'Jacqueville', 'Half Jack,Jackville,Jacqueville,Jaqueville', 5.2051500, -4.4146000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12019, 'Issia', 'Issia', 'Issia', 6.4922400, -6.5855800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12020, 'Guitry', 'Guitry', 'Gitri,Guitri,Guitry', 5.5195200, -5.2403800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12021, 'Guiglo', 'Guiglo', 'GGO,Guglo,Guiglo', 6.5436800, -7.4935000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12022, 'Guibéroua', 'Guiberoua', 'Guibehorouo,Guiberou,Guiberoua,Guibieouroua,Guibiéouroua,Guibéhorouo,Guibéroua', 6.2386900, -6.1714700, 'CI', '2016-06-04', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12023, 'Guéyo', 'Gueyo', 'Guehio,Guelhio,Gueyo,Gueyo I,Guéhio,Guéyo,Guéyo I', 5.6882000, -6.0712000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12024, 'Grand-Lahou', 'Grand-Lahou', 'Grand Lahu,Grand-Lahou', 5.2506800, -5.0033300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12025, 'Grand-Bassam', 'Grand-Bassam', 'Gran Basamas,Gran-Basam,Gran-Bassam,Grand Bassam,Grand-Bassam,da ba sa mu,gran-basami,grayanda-bas''sama,Гран-Басам,Гран-Бассам,גראן-בסאם,ग्रयाण्ड-बस्सम,გრან-ბასამი,グラン・バッサム,大巴薩姆', 5.2118000, -3.7388400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12026, 'Affery', 'Affery', 'Aferi,Affery,Aféri,Grand Aferi,Grand Aféri', 6.3203500, -3.9523500, 'CI', '2014-01-10', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12027, 'Gbéléban', 'Gbeleban', 'Gbeleba,Gbeleban,Gbéléba,Gbéléban,Geleban,Gueleba,Géléban', 9.5846100, -8.1318300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12028, 'Gagnoa', 'Gagnoa', 'GGN,Gagnoa,Gan''oa,Ganjoa,Gragnoa,gagnoa,jia ni ao a,Ганьоа,გაგნოა,加尼奧阿', 6.1319300, -5.9506000, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12029, 'Fresco', 'Fresco', 'Fresco,Fresko', 5.0822600, -5.5693800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12030, 'Ferkessédougou', 'Ferkessedougou', 'Ferkesedugu,Ferkessedougou,Ferkessédougou,Firkessedougou,Firkessedugu,Firkessédougou,Firkessédugu,Pofire,Serkessedougou,Феркеседугу', 9.5928000, -5.1944900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12031, 'Facobly', 'Facobly', 'Facobly,Fakobli,Fakobly,Fakoli', 7.3883000, -7.3764400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12032, 'Dianra', 'Dianra', 'Dianra,Dyana', 8.9433300, -6.2549000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12033, 'Duekoué', 'Duekoue', 'Duekoue,Duekoué', 6.7420200, -7.3491800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12034, 'Divo', 'Divo', 'Boudougou,DIV,Divas,Divo,di wo,Диво,迪沃', 5.8373900, -5.3572300, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12035, 'Dimbokro', 'Dimbokro', 'DIM,Dimbokro', 6.6467800, -4.7051900, 'CI', '2014-01-10', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12036, 'Dikodougou', 'Dikodougou', 'Dikodougou,Dikodugu', 9.0675700, -5.7722200, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12037, 'Djékanou', 'Djekanou', 'Diekahou,Diékahou,Djekanou,Djékanou', 6.4838900, -5.1155300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12038, 'Didiévi', 'Didievi', 'Didievi,Didiévi', 7.1286600, -4.8980400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12039, 'Daoukro', 'Daoukro', 'Daoukrou,Daukro,Даукро', 7.0591000, -3.9631000, 'CI', '2016-05-20', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12040, 'Danané', 'Danane', 'Danane,Danané,Fort Hittos,Данане', 7.2595700, -8.1549800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12041, 'Daloa', 'Daloa', 'DJO,Daloa,da luo ya,dalloa,daroa,Далоа,דאלואה,ダロア,達洛亞,달로아', 6.8773500, -6.4502200, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12042, 'Dabou', 'Dabou', 'Dab,Dabou,Dabu,Даб', 5.3255600, -4.3768500, 'CI', '2014-01-21', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12043, 'Dabakala', 'Dabakala', 'Dabakala,Dabakla', 8.3632100, -4.4286300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12044, 'Buyo', 'Buyo', 'Bouyo,Buyo,Lagoguhe,Lagoguhé', 6.2753400, -6.9970400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12045, 'Boundiali', 'Boundiali', 'BXI,Boundiali,Boundiouli,Bundiali,ben gu li,Бундиали,本賈利', 9.5216700, -6.4869400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12046, 'Bouna', 'Bouna', 'BQO,Bouna,Buna,Буна', 9.2692700, -2.9951000, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12047, 'Bouaké', 'Bouake', 'BYK,Bouake,Bouaké,Buake,Bvake,Bvakė,Bwake,baw ke,bu wa kai,buake,bwaky,Буаке,بواكي,บัวเก,ბუაკე,ブアケ,布瓦凯,부아케', 7.6938500, -5.0303100, 'CI', '2017-04-23', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12048, 'Bouaflé', 'Bouafle', 'Bouafle,Bouaflé,Buafle', 6.9904100, -5.7442000, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12049, 'Botro', 'Botro', 'Botro', 7.8524900, -5.3106300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12050, 'Bonoua', 'Bonoua', 'Bonoua,Bonua,Bunua,Grand Akapless', 5.2724700, -3.5962500, 'CI', '2013-08-05', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12051, 'Bongouanou', 'Bongouanou', 'Bongouanou,Bonguanu,Bougouanou', 6.6517500, -4.2040600, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12052, 'Bondoukou', 'Bondoukou', 'BDK,Bondoukau,Bondoukou,Bonduku,Boudoukou,Gontoukou,bang du ku,bwndwqw,Бондуку,בונדוקו,邦杜庫', 8.0402000, -2.8000300, 'CI', '2012-02-28', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12053, 'Bocanda', 'Bocanda', 'Bocanda,Bokanda', 7.0626400, -4.4994800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12054, 'Bloléquin', 'Blolequin', 'Blolekin,Blolequin,Blolékin,Bloléquin', 6.5691300, -8.0025300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12055, 'Bingerville', 'Bingerville', 'Bingerville', 5.3558100, -3.8853700, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12056, 'Biankouma', 'Biankouma', 'Biankouma', 7.7390900, -7.6137700, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12057, 'Béttié', 'Bettie', 'Betie,Bettie,Bétié,Béttié', 6.0756800, -3.4084600, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12058, 'Béoumi', 'Beoumi', 'Beoumi,Beumi,Béoumi', 7.6739500, -5.5808500, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12059, 'Bangolo', 'Bangolo', 'Bangolo,Zagna', 7.0123200, -7.4863900, 'CI', '2016-12-05', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12060, 'Azaguié', 'Azaguie', 'Azaguie,Azaguié', 5.6298400, -4.0820400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12061, 'Ayamé', 'Ayame', 'Ayame,Ayamé', 5.6052000, -3.1570900, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12062, 'Attiégouakro', 'Attiegouakro', 'Attiegouakro,Attiégouakro', 6.7740200, -5.1141100, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12063, 'Arrah', 'Arrah', 'Arra,Arrah', 6.6734200, -3.9693800, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12064, 'Anyama', 'Anyama', 'An''jame,Aniama,Anyama,Anyama Sossokoua,Аньяме', 5.4946200, -4.0518300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12065, 'Alépé', 'Alepe', 'Alepe,Alépé,Little Alepe', 5.5004000, -3.6630800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12066, 'Akoupé', 'Akoupe', 'Akoupe,Akoupé,Akupe', 6.3842300, -3.8875900, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12067, 'Agnibilékrou', 'Agnibilekrou', 'Agnibilekrou,Agnibilékrou,Anibelekru', 7.1311300, -3.2041500, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12068, 'Agboville', 'Agboville', 'Agbovil'',Agbovile,Agbovilis,Agboville,a bo wei er,agbawyl,agbwwyl,Агбовиле,Агбовиль,Агбовіль,اگباویل,اگبوویل,阿博維爾', 5.9280100, -4.2131900, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12069, 'Adzopé', 'Adzope', 'Adzope,Adzopé,Адзопе', 6.1069400, -3.8619400, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12070, 'Adiaké', 'Adiake', 'Adiake,Adiaké', 5.2863400, -3.3040300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12071, 'Aboisso', 'Aboisso', 'ABO,Abisso,Aboisas,Aboiso,Aboissa,Aboisso,Abuasso,a bo yi suo,abwaysw,Абоисо,Абуассо,ابوایسو,阿博伊索', 5.4677900, -3.2071100, 'CI', '2016-05-18', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12072, 'Abobo', 'Abobo', 'Abobo,Abobo-Gare', 5.4161300, -4.0159000, 'CI', '2016-06-04', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12073, 'Abidjan', 'Abidjan', 'ABJ,Abican,Abidjan,Abidzan,Abidzana,Abidzanas,Abidzans,Abidzhan,Abidzhan shaary,Abidżan,Abidžan,Abidžana,Abidžanas,Abidžans,Abigano,Abijan,Abiyan,Abiyán,Abizhan khot,Abiĝano,Ampitzan,Gorad Abidzhan,a bi rang,a bi ren,abdjan,abijan,abijana,abijang,abijani,abydjan,abyjan,xabi can,ʼbydgʼn,Αμπιτζάν,Абиджан,Абиджан шаары,Абижан хот,Абиџан,Абіджан,Горад Абіджан,Աբիջան,אבידגאן,אבידזשאן,آبدجان,آبیجان,أبيدجان,आबिजान,আবিজান,ਅਬੀਜਾਨ,അബിജാൻ,อาบีจาน,აბიჯანი,アビジャン,阿必仁,阿比让,아비장', 5.3096600, -4.0126600, 'CI', '2016-06-04', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12074, 'Abengourou', 'Abengourou', 'Abengourou,Abenguru,OGO,a ben gu lu,abang-gulu,abngwrw,Абенгуру,ابنگورو,阿本古鲁,아방구루', 6.7297200, -3.4963900, 'CI', '2016-05-21', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12075, 'Séguéla', 'Seguela', 'SEO,Segele,Seguela,Séguéla,Сегеле', 7.9611100, -6.6730600, 'CI', '2017-04-23', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12076, 'Soubré', 'Soubre', 'Soubre,Soubré', 5.7837700, -6.5938800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12077, 'Agou', 'Agou', 'Agou', 5.9828900, -3.9439300, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12078, 'Tiapoum', 'Tiapoum', 'Tiapoum', 5.1362200, -3.0230800, 'CI', '2016-12-03', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12079, 'Soubré', 'Soubre', 'Soubre,Soubré', 5.7855600, -6.6083300, 'CI', '2012-01-20', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12080, 'Songon', 'Songon', 'Songon', 5.3196000, -4.2541500, 'CI', '2016-12-04', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12081, 'Taabo', 'Taabo', '', 6.1998000, -5.1088400, 'CI', '2016-12-04', 55);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11656, 'Adliswil', 'Adliswil', 'Adlisvil'',a de li si wei er,adlyswyl,adlyzwyl,Адлисвиль,أدليسويل,ادلیزویل,阿德利斯維爾', 47.3099700, 8.5246200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11657, 'Adligenswil', 'Adligenswil', 'Adligensvil'',Adligenswil,a de li gen si wei er,Адлигенсвиль,阿德利根斯維爾', 47.0652100, 8.3612400, 'CH', '2014-04-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11658, 'Adelboden', 'Adelboden', 'Adel''boden,Adelboden,ZDB,a de er bo deng,adelboden,aderuboden,adlbwdn,Аделбоден,Адельбоден,ادلبودن,アーデルボーデン,阿德尔博登,아델보덴', 46.4914200, 7.5603100, 'CH', '2017-01-13', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11659, 'Acquarossa', 'Acquarossa', 'Acquarossa,Aquarossa,a kua luo sa,阿夸羅薩', 46.4547300, 8.9426100, 'CH', '2016-08-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11660, 'Aarwangen', 'Aarwangen', 'Aarvangen,Aarwangen,Arvangen,a wan gen,Аарванген,Арванген,阿萬根', 47.2384500, 7.7685400, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11661, 'Aarburg', 'Aarburg', 'Aarburg,Aarmpournk,Arburg,Arburgo,a er bao,arbwrg,arbywrgh,Άαρμπουργκ,Арбург,أربيورغ,اربورگ,阿爾堡', 47.3206700, 7.8998600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11662, 'Aarberg', 'Aarberg', 'Aarberg,Arberg,a er bei ge,arbrg,arbyrgh,Аарберг,Арберг,آربرگ,آربيرغ,阿爾貝格', 47.0443900, 7.2757800, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11663, 'Aarau', 'Aarau', 'Aaraou,Aarau,Arau,Arauo,Arava,Aravia,Araŭo,Gorad Aarau,ZDA,a lao,aarau,alau,arau,aravia,araw,arw  swyys,xa rea,Ārava,Άαραου,Аарау,Арау,Горад Аарау,آراؤ,آراو,أراو,ارو، سوئیس,อาเรา,აარაუ,アーラウ,阿劳,아라우', 47.3925400, 8.0442200, 'CH', '2014-02-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11664, 'Aadorf', 'Aadorf', 'Adorf,a duo fu,Адорф,阿多夫', 47.4920400, 8.9009900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11665, 'Riehen', 'Riehen', 'Riehn,Rien,li en,ryan,ryhyn,Риен,Риэн,ريهين,ریان,ریہین,里恩', 47.5788400, 7.6468300, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11666, 'Chêne-Bougeries', 'Chene-Bougeries', 'Chano-Bugeries,Châno-Bugeries,shenu=bujuri,xie ne bu ri li,シェヌ＝ブジュリー,谢讷布日里', 46.1984300, 6.1864200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11667, 'Meinier', 'Meinier', 'mei nie,meinie,メイニエ,梅涅', 46.2470600, 6.2342300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11668, 'Puplinge', 'Puplinge', 'pi pu lan ri,pyupuranju,ピュプランジュ,皮普兰日', 46.2104300, 6.2311400, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11669, 'Thônex', 'Thonex', 'Tone,Toneksas,Tounex,Tounèx,thwnyks,tone,tuo nei,twnks,Тоне,تونکس,ثونيكس,トネ,托内', 46.1881500, 6.1990400, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11670, 'Wettswil / Wettswil (Dorf)', 'Wettswil / Wettswil (Dorf)', 'Wettswil (Dorf),Wettswil am Albis', 47.3415200, 8.4714900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11671, 'Sellenbüren', 'Sellenbueren', '', 47.3436100, 8.4830100, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11672, 'Itingen', 'Itingen', 'Itingen,yi ting gen,Итинген,伊廷根', 47.4665100, 7.7850200, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11673, 'Ecublens', 'Ecublens', 'Ecublens,Ecublens VD,Ekublensas,ai ju bu lang,aykwblyns,Écublens,إيكوبلينس,埃居布朗', 46.5289900, 6.5626100, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11674, 'Affoltern / Hasenbüel', 'Affoltern / Hasenbueel', 'Hasenbueel,Hasenbüel', 47.2732400, 8.4521800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11675, 'Affoltern / Oberdorf', 'Affoltern / Oberdorf', 'Oberdorf', 47.2779900, 8.4504100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11676, 'Affoltern / Unterdorf', 'Affoltern / Unterdorf', 'Unterdorf', 47.2825700, 8.4508600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11677, 'Affoltern / Sonnenberg', 'Affoltern / Sonnenberg', 'Sonnenberg', 47.2805500, 8.4600800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11678, 'Schachen', 'Schachen', '', 47.3241900, 8.4725100, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11679, 'Hedingen', 'Hedingen', 'Khedingen,hei ding gen,Хединген,黑丁根', 47.2979400, 8.4483300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11680, 'Obfelden / Oberlunnern', 'Obfelden / Oberlunnern', 'Oberlunnern', 47.2619700, 8.4158800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11681, 'Obfelden / Toussen', 'Obfelden / Toussen', 'Toussen', 47.2657400, 8.4301300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11682, 'Wettswil / Ausser-Dorf', 'Wettswil / Ausser-Dorf', 'Ausser-Dorf', 47.3319700, 8.4773200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11683, 'Kleinandelfingen', 'Kleinandelfingen', '', 47.6005800, 8.6836200, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11684, 'Bülach / Niederflachs', 'Buelach / Niederflachs', 'Niederflachs', 47.5142600, 8.5326700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11685, 'Bülach / Soligänter', 'Buelach / Soligaenter', 'Soligaenter,Soligänter', 47.5263200, 8.5410600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11686, 'Bülach / Gstückt', 'Buelach / Gstueckt', 'Gstueckt,Gstückt', 47.5233700, 8.5487900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11687, 'Bülach / Seematt', 'Buelach / Seematt', 'Seematt', 47.5171600, 8.5465100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11688, 'Dietlikon / Eichwiesen', 'Dietlikon / Eichwiesen', 'Eichwiesen', 47.4191000, 8.6207800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11689, 'Embrach / Embrach (Dorfkern)', 'Embrach / Embrach (Dorfkern)', 'Embrach (Dorfkern)', 47.5040000, 8.5947700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11690, 'Embrach / Kellersacker', 'Embrach / Kellersacker', 'Kellersacker', 47.5145500, 8.5914600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11691, 'Freienstein', 'Freienstein', '', 47.5330700, 8.5845500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11692, 'Hochfelden', 'Hochfelden', '', 47.5226200, 8.5156400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11693, 'End-Höri', 'End-Hoeri', '', 47.5079900, 8.5120300, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11694, 'Kloten / Kloten (Zentrum)', 'Kloten / Kloten (Zentrum)', 'Kloten (Zentrum)', 47.4513400, 8.5868300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11695, 'Kloten / Freienberg (Chanzler-Chlini Chaseren)', 'Kloten / Freienberg (Chanzler-Chlini Chaseren)', 'Freienberg (Chanzler-Chlini Chaseren)', 47.4658400, 8.5814500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11696, 'Kloten / Horainli', 'Kloten / Horainli', 'Horainli', 47.4539900, 8.5830600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11697, 'Kloten / Geissberg', 'Kloten / Geissberg', 'Geissberg', 47.4542400, 8.5906600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11698, 'Kloten / Hostrass', 'Kloten / Hostrass', 'Hostrass', 47.4525500, 8.5946400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11699, 'Kloten / Holberg', 'Kloten / Holberg', 'Holberg', 47.4464200, 8.5766100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11700, 'Kloten / Balsberg', 'Kloten / Balsberg', 'Balsberg', 47.4423300, 8.5749600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11701, 'Kloten / Spitz', 'Kloten / Spitz', 'Spitz', 47.4445500, 8.5872400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11702, 'Kloten / Rütlen', 'Kloten / Ruetlen', 'Ruetlen,Rütlen', 47.4472600, 8.5880800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11703, 'Birchwil', 'Birchwil', '', 47.4543100, 8.6347700, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11704, 'Glattbrugg / Wydacker/Bettacker/Lättenwiesen', 'Glattbrugg / Wydacker/Bettacker/Laettenwiesen', 'Wydacker/Bettacker/Laettenwiesen,Wydacker/Bettacker/Lättenwiesen', 47.4290800, 8.5665700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11705, 'Grossacker/Opfikon', 'Grossacker/Opfikon', '', 47.4269600, 8.5788600, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11706, 'Glattbrugg / Rohr/Platten-Balsberg', 'Glattbrugg / Rohr/Platten-Balsberg', 'Rohr/Platten-Balsberg', 47.4372100, 8.5664200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11707, 'Wallisellen / Wallisellen-West', 'Wallisellen / Wallisellen-West', 'Wallisellen-West', 47.4190600, 8.5858600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11708, 'Wallisellen / Wallisellen-Ost', 'Wallisellen / Wallisellen-Ost', 'Wallisellen-Ost', 47.4144600, 8.5972700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11709, 'Wallisellen / Rieden', 'Wallisellen / Rieden', 'Rieden', 47.4173800, 8.6002800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11710, 'Dällikon / Dällikon (Dorf)', 'Daellikon / Daellikon (Dorf)', 'Daellikon (Dorf),Dällikon (Dorf)', 47.4398300, 8.4381300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11711, 'Neerach', 'Neerach', '', 47.5109600, 8.4709900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11712, 'Niederglatt / Niederglatt (Dorfkern)', 'Niederglatt / Niederglatt (Dorfkern)', 'Niederglatt (Dorfkern)', 47.4906500, 8.5004800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11713, 'Niederhasli', 'Niederhasli', 'Hasila,Niderkhasli,Niederhasli,Niederhasli (Dorf),xia ha si li,Нидерхасли,下哈斯利', 47.4801200, 8.4857600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11714, 'Oberglatt / Oberglatt (Dorfkern)', 'Oberglatt / Oberglatt (Dorfkern)', 'Oberglatt (Dorfkern)', 47.4759600, 8.5192900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11715, 'Oberglatt / Bahnhofquartier', 'Oberglatt / Bahnhofquartier', 'Bahnhofquartier', 47.4714300, 8.5128900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11716, 'Hofstetten', 'Hofstetten', '', 47.4777800, 8.5064600, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11717, 'Sonnhalde', 'Sonnhalde', '', 47.4532900, 8.4609100, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11718, 'Regensdorf / Hofacher-Geeren', 'Regensdorf / Hofacher-Geeren', 'Hofacher-Geeren', 47.4352500, 8.4624000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11719, 'Regensdorf / Feldblumen-Riedthofstrasse', 'Regensdorf / Feldblumen-Riedthofstrasse', 'Feldblumen-Riedthofstrasse', 47.4361800, 8.4665900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11720, 'Regensdorf / Obstgarten', 'Regensdorf / Obstgarten', 'Obstgarten', 47.4277200, 8.4656600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11721, 'Rümlang / Rümlang (Dorfkern)', 'Ruemlang / Ruemlang (Dorfkern)', 'Ruemlang (Dorfkern),Rümlang (Dorfkern)', 47.4494000, 8.5325500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11722, 'Tann / Tann (Dorfkern)', 'Tann / Tann (Dorfkern)', 'Tann (Dorfkern)', 47.2649400, 8.8504800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11723, 'Grüt', 'Gruet', 'Gruet,Gruet (Gossau ZH),Grüt,Grüt (Gossau ZH)', 47.3115100, 8.7833900, 'CH', '2014-04-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11724, 'Binzikon', 'Binzikon', '', 47.2794900, 8.7584200, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11725, 'Hadlikon', 'Hadlikon', '', 47.2875000, 8.8571900, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11726, 'Rüti / Westlicher Dorfteil', 'Rueti / Westlicher Dorfteil', 'Westlicher Dorfteil', 47.2554800, 8.8449000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11727, 'Rüti / Dorfzentrum, Südl. Teil', 'Rueti / Dorfzentrum, Suedl. Teil', 'Dorfzentrum  Suedl. Teil,Dorfzentrum  Südl. Teil', 47.2536800, 8.8565400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11728, 'Rüti / Oberdorf', 'Rueti / Oberdorf', 'Oberdorf', 47.2589400, 8.8651200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11729, 'Wetzikon / Robenhausen', 'Wetzikon / Robenhausen', 'Robenhausen', 47.3308900, 8.7876200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11730, 'Wetzikon / Kempten', 'Wetzikon / Kempten', 'Kempten', 47.3331900, 8.8098200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11731, 'Adliswil / Adliswil (Stadtkern)', 'Adliswil / Adliswil (Stadtkern)', 'Adliswil (Stadtkern)', 47.3112800, 8.5267500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11732, 'Adliswil / Oberleimbach', 'Adliswil / Oberleimbach', 'Oberleimbach', 47.3202000, 8.5150800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11733, 'Adliswil / Sood', 'Adliswil / Sood', 'Sood', 47.3187000, 8.5242500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11734, 'Adliswil / Hündli-Zopf', 'Adliswil / Huendli-Zopf', 'Huendli-Zopf,Hündli-Zopf', 47.3163700, 8.5188800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11735, 'Adliswil / Sonnenberg', 'Adliswil / Sonnenberg', 'Sonnenberg', 47.3095800, 8.5205500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11736, 'Adliswil / Tal', 'Adliswil / Tal', 'Tal', 47.3114200, 8.5344600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11737, 'Horgen / Horgen (Dorfkern)', 'Horgen / Horgen (Dorfkern)', 'Horgen (Dorfkern)', 47.2560400, 8.6015900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11738, 'Horgen / Allmend', 'Horgen / Allmend', 'Allmend', 47.2472900, 8.6066000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11739, 'Horgen / Scheller-Stockerstrasse', 'Horgen / Scheller-Stockerstrasse', 'Scheller-Stockerstrasse', 47.2658400, 8.5876000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11740, 'Horgen / Oberdorf', 'Horgen / Oberdorf', 'Horgen Oberdorf,Oberdorf', 47.2583700, 8.5901300, 'CH', '2015-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11741, 'Kilchberg / Bächler-Stocken', 'Kilchberg / Baechler-Stocken', 'Baechler-Stocken,Bächler-Stocken', 47.3272800, 8.5395700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11742, 'Kilchberg / Kilchberg (Dorfkern)', 'Kilchberg / Kilchberg (Dorfkern)', 'Kilchberg (Dorfkern)', 47.3201200, 8.5430600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11743, 'Langnau / Vitaquartier', 'Langnau / Vitaquartier', 'Vitaquartier', 47.2937700, 8.5375800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11744, 'Mühlehalde', 'Muehlehalde', '', 47.2830600, 8.5338600, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11745, 'Oberrieden / Mitte', 'Oberrieden / Mitte', 'Mitte', 47.2724200, 8.5802100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11746, 'Oberrieden / Berg', 'Oberrieden / Berg', 'Berg', 47.2762800, 8.5725700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11747, 'Richterswil / Dorfkern', 'Richterswil / Dorfkern', 'Dorfkern', 47.2071500, 8.7060700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11748, 'Richterswil / Richterswil (Dorfkern)', 'Richterswil / Richterswil (Dorfkern)', 'Richterswil (Dorfkern)', 47.2032300, 8.7051600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11749, 'Richterswil / Burghalde', 'Richterswil / Burghalde', 'Burghalde', 47.2097300, 8.6913300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11750, 'Thalwil / Dorfkern', 'Thalwil / Dorfkern', 'Dorfkern', 47.2904700, 8.5663300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11751, 'Thalwil / Berg', 'Thalwil / Berg', 'Berg', 47.2917800, 8.5560200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11752, 'Thalwil / Nord', 'Thalwil / Nord', 'Nord', 47.2974800, 8.5563400, 'CH', '2012-04-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11753, 'Thalwil / Süd', 'Thalwil / Sued', 'Sued,Süd', 47.2849500, 8.5695400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11754, 'Gattikon', 'Gattikon', '', 47.2843900, 8.5483000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11755, 'Wädenswil / Dorf (Wädenswil)', 'Waedenswil / Dorf (Waedenswil)', 'Dorf (Waedenswil),Dorf (Wädenswil)', 47.2292300, 8.6722000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11756, 'Au / Unter-Dorf', 'Au / Unter-Dorf', 'Unter-Dorf', 47.2473000, 8.6327000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11757, 'Au / Mittel-Dorf', 'Au / Mittel-Dorf', 'Mittel-Dorf', 47.2430300, 8.6459100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11758, 'Wädenswil / Hangenmoos', 'Waedenswil / Hangenmoos', 'Hangenmoos', 47.2336700, 8.6525100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11759, 'Wädenswil / Büelen', 'Waedenswil / Bueelen', 'Bueelen,Büelen', 47.2339500, 8.6634600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11760, 'Wädenswil / Untermosen-Fuhr', 'Waedenswil / Untermosen-Fuhr', 'Untermosen-Fuhr', 47.2277200, 8.6630300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11761, 'Wädenswil / Leihof-Mühlebach', 'Waedenswil / Leihof-Muehlebach', 'Leihof-Muehlebach,Leihof-Mühlebach', 47.2236400, 8.6714900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11762, 'Wädenswil / Eichweid', 'Waedenswil / Eichweid', 'Eichweid', 47.2184700, 8.6744000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11763, 'Wädenswil / Boller-Giessen', 'Waedenswil / Boller-Giessen', 'Boller-Giessen', 47.2211500, 8.6838500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11764, 'Erlenbach / rechts des Dorfbachs oberhalb Bahnlinie', 'Erlenbach / rechts des Dorfbachs oberhalb Bahnlinie', 'rechts des Dorfbachs oberhalb Bahnlinie', 47.3065800, 8.6027100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11765, 'Erlenbach / links des Dorfbachs oberhalb Bahnlinie', 'Erlenbach / links des Dorfbachs oberhalb Bahnlinie', 'links des Dorfbachs oberhalb Bahnlinie', 47.2995000, 8.6018800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11766, 'Küsnacht / Dorf', 'Kuesnacht / Dorf', 'Dorf', 47.3178300, 8.5830300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11767, 'Küsnacht / Goldbach', 'Kuesnacht / Goldbach', 'Goldbach', 47.3272900, 8.5807700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11768, 'Küsnacht / Itschnach', 'Kuesnacht / Itschnach', 'Itschnach', 47.3271400, 8.6006800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11769, 'Küsnacht / Schiedhalden', 'Kuesnacht / Schiedhalden', 'Schiedhalden', 47.3211200, 8.5888100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11770, 'Küsnacht / Heslibach', 'Kuesnacht / Heslibach', 'Heslibach', 47.3130700, 8.5884900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11771, 'Männedorf / Dorfkern', 'Maennedorf / Dorfkern', 'Dorfkern', 47.2561200, 8.6916100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11772, 'Männedorf / Ausserfeld', 'Maennedorf / Ausserfeld', 'Ausserfeld', 47.2463600, 8.7060800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11773, 'Dorf', 'Dorf', '', 47.2390000, 8.7356700, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11774, 'Uetikon / Grossdorf', 'Uetikon / Grossdorf', 'Grossdorf', 47.2665400, 8.6776500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11775, 'Zollikerberg', 'Zollikerberg', '', 47.3451000, 8.6008800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11776, 'Effretikon / Watt', 'Effretikon / Watt', 'Watt', 47.4279700, 8.6982200, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11777, 'Effretikon / Rappenhalde-Bannhalde', 'Effretikon / Rappenhalde-Bannhalde', 'Rappenhalde-Bannhalde', 47.4238800, 8.6965300, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11778, 'Tagelswangen', 'Tagelswangen', '', 47.4307000, 8.6728400, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11779, 'Pfäffikon / Pfäffikon (Dorfkern)', 'Pfaeffikon / Pfaeffikon (Dorfkern)', 'Pfaeffikon (Dorfkern),Pfäffikon (Dorfkern)', 47.3694300, 8.7830900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11780, 'Dübendorf / Vogelquartier', 'Duebendorf / Vogelquartier', 'Vogelquartier', 47.3950200, 8.6118400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11781, 'Dübendorf / Wasserfurren', 'Duebendorf / Wasserfurren', 'Wasserfurren', 47.3935200, 8.6085000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11782, 'Dübendorf / Sonnenberg', 'Duebendorf / Sonnenberg', 'Sonnenberg', 47.3946900, 8.6316200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11783, 'Dübendorf / Kunklerstrasse', 'Duebendorf / Kunklerstrasse', 'Kunklerstrasse', 47.4010900, 8.6272400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11784, 'Hinteregg', 'Hinteregg', '', 47.3073600, 8.6833900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11785, 'Esslingen', 'Esslingen', '', 47.2832500, 8.7103800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11786, 'Benglen', 'Benglen', '', 47.3607700, 8.6368700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11787, 'Greifensee / Müllerwis / Seilerwis', 'Greifensee / Muellerwis / Seilerwis', 'Muellerwis / Seilerwis,Müllerwis / Seilerwis', 47.3704200, 8.6815100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11788, 'Greifensee / Pfisterhölzli', 'Greifensee / Pfisterhoelzli', 'Pfisterhoelzli,Pfisterhölzli', 47.3643000, 8.6897900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11789, 'Aesch', 'Aesch', '', 47.3297000, 8.6541000, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11790, 'Binz', 'Binz', '', 47.3563500, 8.6265700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11791, 'Mönchaltorf / Dorf', 'Moenchaltorf / Dorf', 'Dorf', 47.3040100, 8.7221100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11792, 'Schwerzenbach / Chimli', 'Schwerzenbach / Chimli', 'Chimli', 47.3859200, 8.6588800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11793, 'Schwerzenbach / Blatten', 'Schwerzenbach / Blatten', 'Blatten', 47.3830800, 8.6495400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11794, 'Uster / Kirch-Uster', 'Uster / Kirch-Uster', 'Kirch-Uster', 47.3457900, 8.7183900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11795, 'Uster / Nieder-Uster', 'Uster / Nieder-Uster', 'Nieder-Uster', 47.3474300, 8.7008800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11796, 'Uster / Gschwader', 'Uster / Gschwader', 'Gschwader', 47.3601600, 8.7139000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11797, 'Uster / Ober-Uster', 'Uster / Ober-Uster', 'Ober-Uster', 47.3487400, 8.7331900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11798, 'Uster / Nossikon', 'Uster / Nossikon', 'Nossikon', 47.3408800, 8.7255500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11799, 'Nänikon / Nänikon (Dorfkern)', 'Naenikon / Naenikon (Dorfkern)', 'Naenikon (Dorfkern),Nänikon (Dorfkern)', 47.3709900, 8.6925400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11800, 'Kindhausen / Kindhausen (Dorf)', 'Kindhausen / Kindhausen (Dorf)', 'Kindhausen (Dorf)', 47.4064400, 8.6829600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11801, 'Hegnau / Sunnebüel-Eich', 'Hegnau / Sunnebueel-Eich', 'Sunnebueel-Eich,Sunnebüel-Eich', 47.3924600, 8.6791000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11802, 'Hegnau / Dammboden-Grindel', 'Hegnau / Dammboden-Grindel', 'Dammboden-Grindel', 47.3871300, 8.6665700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11803, 'Gutenswil', 'Gutenswil', '', 47.3838700, 8.7176300, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11804, 'Wangen', 'Wangen', 'Wangen b. Duebendorf,Wangen b. Dübendorf', 47.4118200, 8.6451600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11805, 'Elgg / Städtchen und Umgebung', 'Elgg / Staedtchen und Umgebung', 'Elgg / Staedtchen,Elgg / Städtchen,Staedtchen und Umgebung,Städtchen und Umgebung', 47.4926500, 8.8668000, 'CH', '2010-04-07', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11806, 'Seuzach Dorf / Breite-Weid', 'Seuzach Dorf / Breite-Weid', 'Breite-Weid', 47.5334500, 8.7341500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11807, 'Stadt Winterthur (Kreis 1) / Altstadt', 'Stadt Winterthur (Kreis 1) / Altstadt', 'Altstadt', 47.4995100, 8.7287200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11808, 'Stadt Winterthur (Kreis 1) / Lind', 'Stadt Winterthur (Kreis 1) / Lind', 'Lind', 47.5057100, 8.7337200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11809, 'Stadt Winterthur (Kreis 1) / Heiligberg', 'Stadt Winterthur (Kreis 1) / Heiligberg', 'Heiligberg', 47.4940900, 8.7233400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11810, 'Stadt Winterthur (Kreis 1) / Tössfeld', 'Stadt Winterthur (Kreis 1) / Toessfeld', 'Toessfeld,Tössfeld', 47.4934000, 8.7151200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11811, 'Stadt Winterthur (Kreis 1) / Brühlberg', 'Stadt Winterthur (Kreis 1) / Bruehlberg', 'Bruehlberg,Brühlberg', 47.4976400, 8.7127200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11812, 'Stadt Winterthur (Kreis 1) / Neuwiesen', 'Stadt Winterthur (Kreis 1) / Neuwiesen', 'Neuwiesen', 47.5020700, 8.7162500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11813, 'Oberwinterthur (Kreis 2) / Talacker', 'Oberwinterthur (Kreis 2) / Talacker', 'Talacker', 47.5059600, 8.7515000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11814, 'Oberwinterthur (Kreis 2) / Guggenbühl', 'Oberwinterthur (Kreis 2) / Guggenbuehl', 'Guggenbuehl,Guggenbühl', 47.5133900, 8.7599800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11815, 'Oberwinterthur (Kreis 2) / Zinzikon', 'Oberwinterthur (Kreis 2) / Zinzikon', 'Zinzikon', 47.5195000, 8.7564000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11816, 'Seen (Kreis 3) / Waser', 'Seen (Kreis 3) / Waser', 'Waser', 47.4891300, 8.7603400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11817, 'Seen (Kreis 3) / Büelwiesen', 'Seen (Kreis 3) / Bueelwiesen', 'Bueelwiesen,Büelwiesen', 47.4844600, 8.7651700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11818, 'Seen (Kreis 3) / Waldegg', 'Seen (Kreis 3) / Waldegg', 'Waldegg', 47.4839300, 8.7558600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11819, 'Seen (Kreis 3) / Ganzenbühl', 'Seen (Kreis 3) / Ganzenbuehl', 'Ganzenbuehl,Ganzenbühl', 47.4810000, 8.7624900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11820, 'Seen (Kreis 3) / Oberseen', 'Seen (Kreis 3) / Oberseen', 'Oberseen', 47.4820500, 8.7728900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11821, 'Töss (Kreis 4) / Vorder-Dättnau', 'Toess (Kreis 4) / Vorder-Daettnau', 'Vorder-Daettnau,Vorder-Dättnau', 47.4813500, 8.6985500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11822, 'Töss (Kreis 4) / Schlosstal', 'Toess (Kreis 4) / Schlosstal', 'Schlosstal', 47.4927900, 8.7022300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11823, 'Töss (Kreis 4) / Eichliacker', 'Toess (Kreis 4) / Eichliacker', 'Eichliacker', 47.4872700, 8.7074000, 'CH', '2016-09-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11824, 'Veltheim (Kreis 5) / Rosenberg', 'Veltheim (Kreis 5) / Rosenberg', 'Rosenberg', 47.5138600, 8.7158300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11825, 'Veltheim (Kreis 5) / Blumenau', 'Veltheim (Kreis 5) / Blumenau', 'Blumenau', 47.5061800, 8.7156300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11826, 'Wülflingen (Kreis 6) / Oberfeld', 'Wuelflingen (Kreis 6) / Oberfeld', 'Oberfeld', 47.4987300, 8.6989700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11827, 'Wülflingen (Kreis 6) / Lindenplatz', 'Wuelflingen (Kreis 6) / Lindenplatz', 'Lindenplatz', 47.5109800, 8.6929000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11828, 'Wülflingen (Kreis 6) / Niederfeld', 'Wuelflingen (Kreis 6) / Niederfeld', 'Niederfeld', 47.5090400, 8.6796800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11829, 'Wülflingen (Kreis 6) / Härti', 'Wuelflingen (Kreis 6) / Haerti', 'Haerti,Härti', 47.5126200, 8.6840000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11830, 'Mattenbach (Kreis 7) / Deutweg', 'Mattenbach (Kreis 7) / Deutweg', 'Deutweg', 47.4941900, 8.7394800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11831, 'Mattenbach (Kreis 7) / Gutschick', 'Mattenbach (Kreis 7) / Gutschick', 'Gutschick', 47.4910400, 8.7525800, 'CH', '2016-09-22', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11832, 'Mattenbach (Kreis 7) / Endliker', 'Mattenbach (Kreis 7) / Endliker', 'Endliker', 47.4882100, 8.7493800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11833, 'Kollbrunn / Kollbrunn (Dorfkern)', 'Kollbrunn / Kollbrunn (Dorfkern)', 'Kollbrunn (Dorfkern)', 47.4574800, 8.7741300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11834, 'Dietikon / Vorstadt', 'Dietikon / Vorstadt', 'Vorstadt', 47.4081900, 8.3971900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11835, 'Dietikon / Almend', 'Dietikon / Almend', 'Almend', 47.4047700, 8.3916800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11836, 'Dietikon / Oberdorf', 'Dietikon / Oberdorf', 'Oberdorf', 47.4006500, 8.3941600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11837, 'Dietikon / Kreuzacker', 'Dietikon / Kreuzacker', 'Kreuzacker', 47.3991900, 8.4014600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11838, 'Dietikon / Guggenbühl', 'Dietikon / Guggenbuehl', 'Guggenbuehl,Guggenbühl', 47.4000900, 8.4081800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11839, 'Dietikon / Hofacker', 'Dietikon / Hofacker', 'Hofacker', 47.3971800, 8.4160900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11840, 'Dietikon / Schönenwerd', 'Dietikon / Schoenenwerd', 'Schoenenwerd,Schönenwerd', 47.3970600, 8.4257600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11841, 'Oberengstringen / Zentrum', 'Oberengstringen / Zentrum', 'Zentrum', 47.4071100, 8.4627600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11842, 'Oberengstringen / Sonnenberg', 'Oberengstringen / Sonnenberg', 'Sonnenberg', 47.4121100, 8.4605500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11843, 'Oberengstringen / Rauchacher', 'Oberengstringen / Rauchacher', 'Rauchacher', 47.4091900, 8.4562700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11844, 'Schlieren / Zentrum', 'Schlieren / Zentrum', 'Zentrum', 47.3977900, 8.4477000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11845, 'Schlieren / Engstingerquartier', 'Schlieren / Engstingerquartier', 'Engstingerquartier', 47.4033800, 8.4435200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11846, 'Schlieren / Spital', 'Schlieren / Spital', 'Spital', 47.3948900, 8.4302700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11847, 'Schlieren / Freiestrasse', 'Schlieren / Freiestrasse', 'Freiestrasse', 47.3959800, 8.4420200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11848, 'Schlieren / Kamp', 'Schlieren / Kamp', 'Kamp', 47.3935800, 8.4445300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11849, 'Schlieren / Boden', 'Schlieren / Boden', 'Boden', 47.3972100, 8.4573400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11850, 'Urdorf / Bodenfeld', 'Urdorf / Bodenfeld', 'Bodenfeld', 47.3892000, 8.4226500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11851, 'Urdorf / Moos', 'Urdorf / Moos', 'Moos', 47.3897700, 8.4288600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11852, 'Urdorf / Oberurdorf', 'Urdorf / Oberurdorf', 'Oberurdorf', 47.3807200, 8.4234300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11853, 'Zürich (Kreis 12) / Auzelg', 'Zuerich (Kreis 12) / Auzelg', 'Auzelg', 47.4151100, 8.5701400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11854, 'Zürich (Kreis 11) / Schwandenholz', 'Zuerich (Kreis 11) / Schwandenholz', 'Schwandenholz', 47.4247600, 8.5212500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11855, 'Zürich (Kreis 2) / Mittel-Leimbach', 'Zuerich (Kreis 2) / Mittel-Leimbach', 'Mittel-Leimbach', 47.3253800, 8.5139100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11856, 'Zürich (Kreis 2) / Unter-Leimbach', 'Zuerich (Kreis 2) / Unter-Leimbach', 'Unter-Leimbach', 47.3336200, 8.5143300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11857, 'Zürich (Kreis 10) / Wipkingen', 'Zuerich (Kreis 10) / Wipkingen', 'Wipkingen', 47.3950300, 8.5252900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11858, 'Zürich (Kreis 10) / Rütihof', 'Zuerich (Kreis 10) / Ruetihof', 'Ruetihof,Rütihof', 47.4144400, 8.4792800, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11859, 'Zürich (Kreis 1) / Rathaus', 'Zuerich (Kreis 1) / Rathaus', 'Rathaus', 47.3716100, 8.5450100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11860, 'Zürich (Kreis 11) / Affoltern', 'Zuerich (Kreis 11) / Affoltern', 'Affoltern', 47.4181400, 8.5122000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11861, 'Zürich (Kreis 12) / Saatlen', 'Zuerich (Kreis 12) / Saatlen', 'Saatlen', 47.4112700, 8.5648000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11862, 'Zürich (Kreis 12) / Schwamendingen-Mitte', 'Zuerich (Kreis 12) / Schwamendingen-Mitte', 'Schwamendingen-Mitte', 47.4063000, 8.5724200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11863, 'Zürich (Kreis 12) / Hirzenbach', 'Zuerich (Kreis 12) / Hirzenbach', 'Hirzenbach', 47.4018700, 8.5863300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11864, 'Zürich (Kreis 1) / Lindenhof', 'Zuerich (Kreis 1) / Lindenhof', 'Lindenhof', 47.3718800, 8.5403600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11865, 'Zürich (Kreis 1) / City', 'Zuerich (Kreis 1) / City', '', 47.3726900, 8.5357600, 'CH', '2009-11-13', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11866, 'Zürich (Kreis 2) / Wollishofen', 'Zuerich (Kreis 2) / Wollishofen', 'Wollishofen', 47.3401000, 8.5313400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11867, 'Zürich (Kreis 2) / Enge', 'Zuerich (Kreis 2) / Enge', 'Enge', 47.3605000, 8.5312700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11868, 'Zürich (Kreis 3) / Friesenberg', 'Zuerich (Kreis 3) / Friesenberg', 'Friesenberg', 47.3637200, 8.5041700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11869, 'Zürich (Kreis 3) / Sihlfeld', 'Zuerich (Kreis 3) / Sihlfeld', 'Sihlfeld', 47.3738200, 8.5116400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11870, 'Zürich (Kreis 4) / Werd', 'Zuerich (Kreis 4) / Werd', 'Werd', 47.3717800, 8.5258400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11871, 'Zürich (Kreis 4) / Langstrasse', 'Zuerich (Kreis 4) / Langstrasse', 'Langstrasse', 47.3776700, 8.5285400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11872, 'Zürich (Kreis 4) / Hard', 'Zuerich (Kreis 4) / Hard', 'Hard', 47.3831100, 8.5094200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11873, 'Zürich (Kreis 5) / Gewerbeschule', 'Zuerich (Kreis 5) / Gewerbeschule', 'Gewerbeschule', 47.3848100, 8.5301100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11874, 'Zürich (Kreis 5) / Escher-Wyss', 'Zuerich (Kreis 5) / Escher-Wyss', 'Escher-Wyss', 47.3905200, 8.5129200, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11875, 'Zürich (Kreis 6) / Unterstrass', 'Zuerich (Kreis 6) / Unterstrass', 'Unterstrass', 47.3953000, 8.5372100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11876, 'Zürich (Kreis 6) / Oberstrass', 'Zuerich (Kreis 6) / Oberstrass', 'Oberstrass', 47.3891700, 8.5504000, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11877, 'Zürich (Kreis 7) / Fluntern', 'Zuerich (Kreis 7) / Fluntern', 'Fluntern', 47.3801300, 8.5613300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11878, 'Zürich (Kreis 7) / Hottingen', 'Zuerich (Kreis 7) / Hottingen', 'Hottingen', 47.3701100, 8.5630600, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11879, 'Zürich (Kreis 7) / Hirslanden', 'Zuerich (Kreis 7) / Hirslanden', 'Hirslanden', 47.3624000, 8.5675500, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11880, 'Zürich (Kreis 8) / Seefeld', 'Zuerich (Kreis 8) / Seefeld', 'Seefeld', 47.3546200, 8.5553700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11881, 'Zürich (Kreis 8) / Mühlebach', 'Zuerich (Kreis 8) / Muehlebach', 'Muehlebach,Mühlebach', 47.3572700, 8.5574400, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11882, 'Zürich (Kreis 8) / Weinegg', 'Zuerich (Kreis 8) / Weinegg', 'Weinegg', 47.3525000, 8.5701100, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11883, 'Zürich (Kreis 9) / Albisrieden', 'Zuerich (Kreis 9) / Albisrieden', 'Albisrieden', 47.3739800, 8.4900700, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11884, 'Zürich (Kreis 9) / Altstetten', 'Zuerich (Kreis 9) / Altstetten', 'Altstetten', 47.3894600, 8.4853300, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11885, 'Schwerzenbach', 'Schwerzenbach', 'Shvercenbakh,shi wei cen ba he,Шверценбах,施韋岑巴赫', 47.3821300, 8.6572700, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11886, 'Steinmaur', 'Steinmaur', '', 47.4971000, 8.4521600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11887, 'Hegnau', 'Hegnau', '', 47.3922700, 8.6698800, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11888, 'Gockhausen', 'Gockhausen', '', 47.3809800, 8.5997800, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11889, 'Stadt Winterthur (Kreis 1)', 'Stadt Winterthur (Kreis 1)', '', 47.4949400, 8.7195400, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11890, 'Zürich (Kreis 5)', 'Zuerich (Kreis 5)', '', 47.3876700, 8.5215200, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11891, 'Dänikon', 'Daenikon', 'Daenikon,Dänikon', 47.4467400, 8.4064800, 'CH', '2016-03-31', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11892, 'Zürich (Kreis 12)', 'Zuerich (Kreis 12)', '', 47.4037200, 8.5760800, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11893, 'Wülflingen (Kreis 6)', 'Wuelflingen (Kreis 6)', '', 47.5103600, 8.6833300, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11894, 'Sulz', 'Sulz', '', 47.5395400, 8.7888700, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11895, 'Seglingen', 'Seglingen', '', 47.5724400, 8.5209300, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11896, 'Niederglatt', 'Niederglatt', 'Niederglatt,Niederglatt ZH', 47.4906600, 8.4998700, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11897, 'Ebmatingen', 'Ebmatingen', '', 47.3498700, 8.6401300, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11898, 'Seen (Kreis 3)', 'Seen (Kreis 3)', '', 47.4764600, 8.7699600, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11899, 'Zürich (Kreis 3)', 'Zuerich (Kreis 3)', '', 47.3578500, 8.5029600, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11900, 'Zürich (Kreis 11)', 'Zuerich (Kreis 11)', '', 47.4232600, 8.5216600, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11901, 'Zürich (Kreis 9)', 'Zuerich (Kreis 9)', '', 47.3824500, 8.4799300, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11902, 'Oberwinterthur (Kreis 2)', 'Oberwinterthur (Kreis 2)', '', 47.5169200, 8.7686300, 'CH', '2016-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11903, 'Geroldswil', 'Geroldswil', '', 47.4221300, 8.4108500, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11904, 'Zürich (Kreis 10)', 'Zuerich (Kreis 10)', '', 47.4077300, 8.5005000, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11905, 'Zürich (Kreis 2)', 'Zuerich (Kreis 2)', '', 47.3375600, 8.5211000, 'CH', '2012-07-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11906, 'Zürich (Kreis 8)', 'Zuerich (Kreis 8)', '', 47.3548000, 8.5609700, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11907, 'Wolfhausen', 'Wolfhausen', '', 47.2561900, 8.7991000, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11908, 'Seuzach Dorf', 'Seuzach Dorf', 'Seuzach', 47.5356000, 8.7320900, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11909, 'Zürich (Kreis 1)', 'Zuerich (Kreis 1)', 'Altstadt', 47.3705500, 8.5417700, 'CH', '2012-07-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11910, 'Mattenbach (Kreis 7)', 'Mattenbach (Kreis 7)', '', 47.4870500, 8.7468100, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11911, 'Zürich (Kreis 7)', 'Zuerich (Kreis 7)', '', 47.3732800, 8.5803800, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11912, 'Obermeilen', 'Obermeilen', '', 47.2657400, 8.6556700, 'CH', '2015-08-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11913, 'Zürich (Kreis 6)', 'Zuerich (Kreis 6)', '', 47.3922300, 8.5438100, 'CH', '2012-07-30', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11914, 'Elsau-Räterschen', 'Elsau-Raeterschen', '', 47.5023800, 8.7987400, 'CH', '2006-10-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11915, 'Thalwil / See', 'Thalwil / See', 'See', 47.2940900, 8.5692900, 'CH', '2006-10-21', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11916, 'Thal', 'Thal', 'Altenrhein,Tal'',Thal SG,Thal i Sveits,ta er,Таль,塔爾', 47.4667700, 9.5664300, 'CH', '2015-11-10', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11917, 'Préverenges', 'Preverenges', '', 46.5185400, 6.5268200, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11918, 'Langnau am Albis', 'Langnau am Albis', 'Langnau ce Albis,Langnau ĉe Albis,Langnau-na-Al''bise,a er bi si fu jin lang nao,Лангнау-на-Альбисе,阿爾比斯附近朗瑙', 47.2888500, 8.5411000, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11919, 'Langendorf', 'Langendorf', 'Langendorf,Langendorf SO,Langendorf i Sveits,lan gen duo fu,Лангендорф,蘭根多夫', 47.2197400, 7.5146900, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11920, 'Troinex', 'Troinex', 'te lu wa nei,torowane,トロワネ,特鲁瓦内', 46.1631300, 6.1474500, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11921, 'Lancy', 'Lancy', 'Lanci,Lanciacus,Lansi,lang xi,lansy,ranshi,Ланси,لانسي,لانسی,ランシー,朗西', 46.1898100, 6.1144100, 'CH', '2015-05-25', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11922, 'Muralto', 'Muralto', 'Mueralt,Mural''to,Muralto,Müralt,mu la er tuo,Муралто,Муральто,穆拉爾托', 46.1732300, 8.8021900, 'CH', '2016-01-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11923, 'Stetten', 'Stetten', 'Stetten SH', 47.7402500, 8.6629800, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11924, 'Löhningen', 'Loehningen', '', 47.7012100, 8.5523600, 'CH', '2013-03-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11925, 'Lauffohr (Brugg)', 'Lauffohr (Brugg)', '', 47.5015400, 8.2312200, 'CH', '2010-04-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11926, 'Jongny', 'Jongny', '', 46.4788300, 6.8411400, 'CH', '2013-02-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11927, 'Haag (Rheintal)', 'Haag (Rheintal)', 'Haag,Haag (Rheintal)', 47.2098900, 9.4893100, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11928, 'Givisiez', 'Givisiez', 'ji wei xie,吉維謝', 46.8120100, 7.1263900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11929, 'Aire-la-Ville', 'Aire-la-Ville', 'Aeria Villa,Ehr-la-Vil'',ai er la wei er,eru=ra=vu~iru,Эр-ла-Виль,エル＝ラ＝ヴィル,艾尔拉维尔', 46.1905700, 6.0428700, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11930, 'Hausen', 'Hausen', 'Hausen AG', 47.4639600, 8.2098800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11931, 'Veyras', 'Veyras', '', 46.3021200, 7.5361900, 'CH', '2013-02-28', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11932, 'Känerkinden', 'Kaenerkinden', 'Kenerkinden,ke nei jin deng,Кенеркинден,克內金登', 47.4118800, 7.8371600, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11933, 'Oberurnen', 'Oberurnen', '', 47.1141200, 9.0586600, 'CH', '2013-04-02', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11934, 'Cuarnens', 'Cuarnens', 'ju a nan,居阿南', 46.6254500, 6.4371300, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11935, 'Cancori', 'Cancori', '', 46.4594400, 8.8994400, 'CH', '2011-03-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11936, 'Les Avanchets', 'Les Avanchets', '', 46.2216800, 6.1081400, 'CH', '2011-05-04', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11937, 'Biberstein', 'Biberstein', 'Bibershtajn,bi bei er shi tai yin,Биберштайн,比貝爾施泰因', 47.4164100, 8.0850800, 'CH', '2013-03-01', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11938, 'Braggio', 'Braggio', '', 46.3027700, 9.1238000, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11939, 'Saint-George', 'Saint-George', 'sheng qiao zhi,سینٹ-جارج,圣乔治', 46.5142800, 6.2598000, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11940, 'Saubraz', 'Saubraz', '', 46.5160600, 6.3301800, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11941, 'Berolle', 'Berolle', '', 46.5579800, 6.3355100, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11942, 'Mauraz', 'Mauraz', '', 46.6055800, 6.4207400, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11943, 'Chavannes-le-Veyron', 'Chavannes-le-Veyron', '', 46.6070000, 6.4508600, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11944, 'La Chaux', 'La Chaux', 'Chaux,La Chaux i Sveits,la shao,拉绍', 46.6171400, 6.4722300, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11945, 'Chevilly', 'Chevilly', 'Chevilly VD,Chevilly i Sveits,she wei li,舍维利', 46.6427200, 6.4766100, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11946, 'Moiry', 'Moiry', '', 46.6491400, 6.4533500, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11947, 'Ferreyres', 'Ferreyres', '', 46.6580400, 6.4852000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11948, 'Orny', 'Orny', 'Orny VD,Orny i Sveits,ao er ni,奥尔尼', 46.6675800, 6.5263900, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11949, 'Pompaples', 'Pompaples', '', 46.6669900, 6.5096600, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11950, 'Penthéréaz', 'Penthereaz', '', 46.6817100, 6.6039000, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11951, 'Vuarrens', 'Vuarrens', 'wei a lang,维阿朗', 46.6857800, 6.6479300, 'CH', '2013-02-26', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11952, 'Rueyres', 'Rueyres', 'Rueyres VD,Rueyres i Sveits', 46.6933700, 6.6921300, 'CH', '2013-02-19', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11953, 'Bas-Vully', 'Bas-Vully', 'xia wei li,下維利', 46.9619400, 7.1125100, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11954, 'Marin-Epagnier', 'Marin-Epagnier', '', 47.0101700, 6.9994100, 'CH', '2016-01-05', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11955, 'Tägertschi', 'Taegertschi', '', 46.8754800, 7.5852900, 'CH', '2017-07-27', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11956, 'Oberrohrdorf', 'Oberrohrdorf', '', 47.4183300, 8.3198300, 'CH', '2015-06-17', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11957, 'Kirchleerau', 'Kirchleerau', 'Kirkhlerau,ji er xi lai lao,Кирхлерау,基爾希萊勞', 47.2757900, 8.0658100, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11958, 'Matran', 'Matran', 'ma te lang,馬特朗', 46.7859300, 7.0976800, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11959, 'Blécherette', 'Blecherette', '', 46.5393200, 6.6222700, 'CH', '2013-05-06', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11960, 'Oberhof', 'Oberhof', 'Oberhof', 47.4487400, 8.0027300, 'CH', '2013-07-03', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11961, 'Tenniken', 'Tenniken', 'Tenniken,teng ni ken,Тенникен,滕尼肯', 47.4371200, 7.8114900, 'CH', '2015-06-08', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(11962, 'Gansingen', 'Gansingen', '', 47.5429000, 8.1351600, 'CH', '2015-05-31', 216);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12249, 'Ndikiniméki', 'Ndikinimeki', 'Ndikinemeki,Ndikinimeki,Ndikiniméki', 4.7666700, 10.8333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12250, 'Ndelele', 'Ndelele', 'Alte Fakt Delele,Delele,Delelé,Ndelele,Ndélélé,Vieux-Delele,Vieux-Délélé', 4.0406500, 14.9250100, 'CM', '2012-04-07', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12251, 'Nanga Eboko', 'Nanga Eboko', 'Nanga Eboko', 4.6833300, 12.3666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12252, 'Mvangué', 'Mvangue', '', 2.9666700, 11.5166700, 'CM', '2011-03-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12253, 'Muyuka', 'Muyuka', 'Mouyouka,Muyuka', 4.2898000, 9.4103000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12254, 'Mutengene', 'Mutengene', '', 4.0913000, 9.3144000, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12255, 'Mundemba', 'Mundemba', 'Mundemba,Mundenba,Ndian', 4.9479000, 8.8724000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12256, 'Mouanko', 'Mouanko', 'Mouangko,Mouanko,Muankoo', 3.6397200, 9.7769400, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12257, 'Mora', 'Mora', 'Mora,More,Море', 11.0461100, 14.1401100, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12258, 'Mokolo', 'Mokolo', 'Mokolo', 10.7424400, 13.8022700, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12259, 'Mme-Bafumen', 'Mme-Bafumen', 'Me,Mme,Mme-Bafumen', 6.3333300, 10.2333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12260, 'Minta', 'Minta', 'Minta', 4.5833300, 12.8000000, 'CM', '2014-04-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12261, 'Mindif', 'Mindif', 'Mendif,Mindif', 10.3975700, 14.4362600, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12262, 'Melong', 'Melong', 'Melong', 5.1218100, 9.9614300, 'CM', '2014-04-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12263, 'Meïganga', 'Meiganga', 'Meiganda,Meiganga,Mejgange,Meïganga,Мейганге', 6.5166700, 14.3000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12264, 'Mbouda', 'Mbouda', 'Mbouda', 5.6261100, 10.2542100, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12265, 'Mbengwi', 'Mbengwi', 'Mbengwi', 6.0166700, 10.0000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12266, 'Mbankomo', 'Mbankomo', 'Mbankomo', 3.7833300, 11.3833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12267, 'Mbanga', 'Mbanga', 'M''Bange,Mbanga,M’Bangé', 4.5016000, 9.5671000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12268, 'Mbang', 'Mbang', '', 4.5833300, 13.3333300, 'CM', '2011-03-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12269, 'Mbandjok', 'Mbandjok', 'Mbandjock,Mbandjok', 4.4500000, 11.9000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12270, 'Mbalmayo', 'Mbalmayo', 'Mbal''majo,Mbalmajo,Mbalmayo,Мбальмайо', 3.5166700, 11.5000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12271, 'Maroua', 'Maroua', 'MVR,Maroua,Marua,Marva,ma lu a,malua,marua,marwa,Μαρουά,Маруа,مارؤا,マルア,马鲁阿,마루아', 10.5909500, 14.3159300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12272, 'Manjo', 'Manjo', 'Manjo', 4.8428000, 9.8217000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12273, 'Mamfe', 'Mamfe', 'MMF,Mamfe', 5.7513200, 9.3137000, 'CM', '2015-01-28', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12274, 'Makary', 'Makary', 'Mafate,Mafaté,Mafete,Makari,Makary', 12.5753500, 14.4548300, 'CM', '2016-09-08', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12275, 'Loum', 'Loum', 'Loum,Lum,Лум', 4.7182000, 9.7351000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12276, 'Lolodorf', 'Lolodorf', 'Lelodorf,Lolodorf,Lolodrof', 3.2333300, 10.7333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12277, 'Limbe', 'Limbe', 'Limbe,Limbé,Limbė,VCC,Victoria,limbe,lin bei,rinbe,Лимбе,リンベ,林贝,림베', 4.0235600, 9.2060700, 'CM', '2016-10-08', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12278, 'Lagdo', 'Lagdo', 'Lagdo', 9.0582800, 13.6660500, 'CM', '2016-11-18', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12279, 'Kumbo', 'Kumbo', 'Kumbo', 6.2000000, 10.6666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12280, 'Kumba', 'Kumba', 'Kumba,Kumboj,Кумбой', 4.6363000, 9.4469000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12281, 'Kribi', 'Kribi', 'KBI,Kribi,Криби', 2.9372500, 9.9076500, 'CM', '2014-10-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12282, 'Koza', 'Koza', '', 10.8684600, 13.8820500, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12283, 'Kousséri', 'Kousseri', 'Fort Fureau,Fort-Foureau,Kousseri,Kousséri,Kusseri', 12.0768900, 15.0306300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12284, 'Kontcha', 'Kontcha', 'Koncha,Kontcha,Kontscha', 7.9666700, 12.2333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12285, 'Bankim', 'Bankim', 'Bamkim,Bamkin,Bankin,Kimi,Nga''s', 6.0830300, 11.4905000, 'CM', '2007-12-27', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12286, 'Kaélé', 'Kaele', '', 10.1091700, 14.4508300, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12287, 'Jakiri', 'Jakiri', 'Jakiri', 6.1000000, 10.6500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12288, 'Guider', 'Guider', 'Gider,Guidder,Guider', 9.9333000, 13.9467100, 'CM', '2014-01-08', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12289, 'Garoua Boulaï', 'Garoua Boulai', 'Garoua Boulai,Garoua Boulaï', 5.8833300, 14.5500000, 'CM', '2016-03-09', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12290, 'Garoua', 'Garoua', 'GOU,Garoua,Garua,Garva,galua,garua,garwa,gharwa,jia lu a,Гаруа,غاروا,گارؤا,ガルア,加鲁阿,가루아', 9.3014300, 13.3977100, 'CM', '2014-01-08', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12291, 'Fundong', 'Fundong', 'Fundong', 6.2500000, 10.2666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12292, 'Foumbot', 'Foumbot', 'Foumbat,Foumbot', 5.5080300, 10.6325000, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12293, 'Foumban', 'Foumban', 'FOM,Foumbam,Foumban,Fumban,feng ban,Фумбан,豐班', 5.7266200, 10.8986500, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12294, 'Fontem', 'Fontem', 'Fontem', 5.4685000, 9.8818000, 'CM', '2016-03-09', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12295, 'Évodoula', 'Evodoula', 'Evodoula,Évodoula', 4.0833300, 11.2000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12296, 'Essé', 'Esse', '', 4.1000000, 11.9000000, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12297, 'Eséka', 'Eseka', 'Eseka,Eséka', 3.6500000, 10.7666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12298, 'Edéa', 'Edea', 'Edea,Edeja,Edéa,Edėja,Ehdea,adya,ai dai a,edea,Édéa,Едеа,Эдеа,إديا,エデア,埃代阿', 3.8000000, 10.1333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12299, 'Ébolowa', 'Ebolowa', 'EBW,Ebolova,Ebolowa,Ébolowa', 2.9000000, 11.1500000, 'CM', '2013-04-02', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12300, 'Dschang', 'Dschang', 'Chang,DSC,Dchang,Djang,Dschang,Dzhang,Tchang,jiang zhen,Джанг,姜鎮', 5.4439700, 10.0533200, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12301, 'Doumé', 'Doume', 'Doume,Doumé,Dume,Dume-Station', 4.2333300, 13.4500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12302, 'Douala', 'Douala', 'DLA,Douala,Doula,Dual,Duala,Dualao,Dóúala,Gorad Duala,Ntouala,dau''ala,do~uara,du a la,du xa la,dualla,dwala,Ντουάλα,Горад Дуала,Дуала,דואלה,دوالا,दौआला,ਦੌਆਲਾ,ดูอาลา,ドゥアラ,杜阿拉,두알라', 4.0482700, 9.7042800, 'CM', '2011-11-01', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12303, 'Djohong', 'Djohong', 'Djohong,Doumba', 6.8333300, 14.7000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12304, 'Dizangué', 'Dizangue', 'Dizangue,Dizangué,Dizanque,Dizanqué', 3.7666700, 9.9833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12305, 'Dimako', 'Dimako', 'Dimako', 4.3833300, 13.5666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12306, 'Dibombari', 'Dibombari', 'Dibombari', 4.1787000, 9.6561000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12307, 'Diang', 'Diang', '', 4.2500000, 10.0166700, 'CM', '2011-03-06', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12308, 'Buea', 'Buea', 'Buea,Bueha,Bueja,Buéa,Buėja,bu ai ya,buea,bwyya,Буэа,بوئیا,ブエア,布埃亞,부에아', 4.1527000, 9.2410000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12309, 'Bonabéri', 'Bonaberi', 'Bonaberi,Bonabéri,Boniberi,Bouaberi', 4.0779000, 9.6759000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12310, 'Bogo', 'Bogo', '', 10.7336000, 14.6092800, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12311, 'Bétaré Oya', 'Betare Oya', 'Betare,Betare Oya,Betaye-Oya,Bétaré Oya', 5.6000000, 14.0833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12312, 'Bertoua', 'Bertoua', 'BTA,Bertoua,Bertua,Bertva,Gamane,bei er tu a,beleutua,beruto~ua,bytwa,Μπερτουά,Бертуа,بیتؤا,ベルトゥア,贝尔图阿,베르투아', 4.5772800, 13.6845900, 'CM', '2012-04-07', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12313, 'Belo', 'Belo', 'Bello,Belo', 6.1333300, 10.2500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12314, 'Bélel', 'Belel', 'Belel,Bélel', 7.0500000, 14.4333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12315, 'Bélabo', 'Belabo', 'Belabo,Bélabo,Белабо', 4.9333300, 13.3000000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12316, 'Bekondo', 'Bekondo', 'Bekondo,Boa Bekondo', 4.6819000, 9.3214000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12317, 'Bazou', 'Bazou', 'Bazou', 5.0600100, 10.4675100, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12318, 'Batouri', 'Batouri', 'Batouri,Baturi,OUR', 4.4333300, 14.3666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12319, 'Batibo', 'Batibo', '', 5.8358000, 9.8553000, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12320, 'Banyo', 'Banyo', 'Banjo,Banyo', 6.7500000, 11.8166700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12321, 'Bansoa', 'Bansoa', 'Bansoa', 5.4483600, 10.3135500, 'CM', '2013-09-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12322, 'Ngou', 'Ngou', 'Bangou,Banjou,Ngou', 5.1968500, 10.3859500, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12323, 'Bangangté', 'Bangangte', 'Bangangte,Bangangté,Bangante,Banganté', 5.1407900, 10.5253500, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12324, 'Bandjoun', 'Bandjoun', 'Bandjoun,ban zu en,班祖恩', 5.3756800, 10.4132600, 'CM', '2013-09-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12325, 'Bana', 'Bana', 'Bana', 5.1465500, 10.2754500, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12326, 'Bamusso', 'Bamusso', 'Bamuso,Bamusso', 4.4591000, 8.9027000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12327, 'Bamendjou', 'Bamendjou', 'Bamendjou', 5.3898800, 10.3301400, 'CM', '2013-09-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12328, 'Bamenda', 'Bamenda', 'BPC,Bamenda,Bamendy,ba men da,bamenda,bamynda,Баменда,Баменды,بامیندا,バメンダ,巴门达,바멘다', 5.9597000, 10.1459700, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12329, 'Bali', 'Bali', 'BLC,Bali,Бали', 5.8873700, 10.0117600, 'CM', '2014-06-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12330, 'Bafoussam', 'Bafoussam', 'BFX,Bafousam,Bafoussam,Bafusam,Bafusama,Bafusamas,Bafussama,Befoussam,ba fu sa mu,bafusamu,bafwsam,bapusam,Μπαφουσάμ,Бафусам,Бафуссама,بافؤسام,バフーサム,巴富薩姆,바푸삼', 5.4777500, 10.4175900, 'CM', '2013-09-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12331, 'Bafia', 'Bafia', 'Bafia,Bafia Ngitakuba,Bafiā Ngitakuba', 4.7500000, 11.2333300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12332, 'Bafang', 'Bafang', 'Bafang', 5.1570500, 10.1771000, 'CM', '2013-07-04', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12333, 'Babanki', 'Babanki', 'Babanki,Big Babanki', 6.1166700, 10.2500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12334, 'Ambam', 'Ambam', 'Ambam', 2.3833300, 11.2833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12335, 'Akonolinga', 'Akonolinga', 'Akomolinga,Akonolinga', 3.7666700, 12.2500000, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12336, 'Akono', 'Akono', 'Akono', 3.5000000, 11.3333300, 'CM', '2014-04-05', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12337, 'Akom II', 'Akom II', 'Akom,Akom II', 2.7833300, 10.5666700, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12338, 'Abong Mbang', 'Abong Mbang', 'Abong Mbang', 3.9833300, 13.1833300, 'CM', '2012-01-16', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12339, 'Idenao', 'Idenao', '', 4.2475000, 9.0047200, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12340, 'Ndom', 'Ndom', '', 4.4978000, 9.5628000, 'CM', '2006-01-17', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12341, 'Somié', 'Somie', 'Ndeba,Somie,Tchokmon', 6.4584300, 11.4329900, 'CM', '2007-12-27', 40);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12342, 'Zongzhai', 'Zongzhai', 'Tsung-chai,Zongzhai,Zongzhai Zhen,zong zhai,zong zhai zhen,总寨,总寨镇', 39.6166700, 98.6000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12343, 'Zongjia', 'Zongjia', 'Zongjia,Zongjia Xiang,zong jia,zong jia xiang,宗加,宗加乡', 36.2515400, 96.9490000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12344, 'Zongga', 'Zongga', 'Chi-lung,Gyirong,Jilong Xian,Jongka Dzong,Jongkha Dzong,Jung-ha,Jung-ha-tsung,Jung-ka,Jung-ka-tsung,Songka-dzong,Tsung-ka,Zongga,ji long xian,zong ga,吉隆县,宗嘎', 29.0000000, 85.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12345, 'Zito', 'Zito', 'Lo-lung,Luolong Xian,Tzu-t''o,Tzu-t’o,Zito,Zituo,Zituo Zhen,luo long xian,zi tuo,zi tuo zhen,孜托,孜托镇,洛隆县', 30.7389300, 95.8361300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12346, 'Zhugkyung', 'Zhugkyung', 'Zhouqun,Zhouqun Xiang,Zhugkyung,zhou qun,zhou qun xiang,舟群,舟群乡', 37.5977600, 99.4141800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12347, 'Zhowagoin', 'Zhowagoin', 'Jigong,Zhowagoin,Zhuwagen,Zhuwagen Zhen,ji gong,zhu wa gen,zhu wa gen zhen,吉公,竹瓦根,竹瓦根镇', 28.6591000, 97.4506500, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12348, 'Zhoinda', 'Zhoinda', 'Zengda,Zhoinda,Zhongda,Zhongda Xiang,ceng da,zhong da,zhong da xiang,仲达,仲达乡,曾达', 33.2000200, 97.0305000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12349, 'Zhiqu', 'Zhiqu', 'Zhiqu,Zhiqu Xiang,zhi qu,zhi qu xiang,治曲,治曲乡', 34.3082500, 95.5033500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12350, 'Zhedao', 'Zhedao', 'Che-tao,Che-tao-chen,Liang-ho,Lianghe,Zhedao,zhe dao,遮岛', 24.8193400, 98.2762700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12351, 'Zhangfeng', 'Zhangfeng', 'Chang-Feng-Cheh,Chang-feng,Chang-feng-chieh,Changfengkai,Hsanghawng,Lung-ch''uan,Lung-ch’uan,Zhangfeng,zhang feng,章凤', 24.2208500, 97.7868300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12352, 'Zhamog', 'Zhamog', 'Bomi,Bomi Xian,Bowo,Cha-mu,Po-mi,Zhamo,Zhamog,Zhamu,Zhamu Zhen,bo mi xian,zha mu,zha mu zhen,扎木,扎木镇,波密县', 29.8665300, 95.7590300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12353, 'Zham', 'Zham', 'Zham,Zhangmu,Zhangmu Zhen,zhang mu,zhang mu zhen,樟木,樟木镇', 27.9833300, 85.9833300, 'CN', '2016-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12354, 'Zhadong', 'Zhadong', 'Cha-tung-tsung,Chung-pa,T''e-la-to-mu,T''e-la-to-mu-tsung,Tradom,Tradum,T’e-la-to-mu,T’e-la-to-mu-tsung,Zhabdun,Zhabdün,Zhadong,Zhadun,Zhadün,Zhongba,Zhongba Xian,zha dong,zhong ba xian,仲巴县,扎东', 29.6500000, 84.1666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12355, 'Zepu', 'Zepu', 'Po-ssu-ch''ia-mu,Po-ssu-ch’ia-mu,Po-ssu-k''an,Po-ssu-k’an,Posgam,Poskam,Pozgham-bazar,Tse-p''u,Tse-p''u-hsien,Tse-p’u,Tse-p’u-hsien,Tsehpu,Zepu,pwskam,ze pu,Поскам,پوسكام,泽普', 38.1886700, 77.2707500, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12356, 'Xuji', 'Xuji', 'Tse-ling-Kou,Xuji,Xuji Xiang,Zelinggou,xu ji,xu ji xiang,ze ling gou,泽令沟,蓄集,蓄集乡', 37.3491300, 97.8329900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12357, 'Zaring', 'Zaring', 'Chaqin Gongshe,Liangdaohe,Zaren,Zaren Xiang,Zaring,cha qin gong she,zha ren,zha ren xiang,扎仁,扎仁乡,查勤公社', 31.9856800, 91.7078500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12358, 'Zaqing', 'Zaqing', 'Cha-ch''ing,Cha-ch’ing,Zaqen,Zaqing,Zaqing Xiang,Zaqên,zha qing,zha qing xiang,扎青,扎青乡', 33.0680000, 95.1690100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12359, 'Zangguy', 'Zangguy', 'Tsang-Kuei,Zangguy,Заңгуй,زاڭگۇي', 37.2833300, 78.7666700, 'CN', '2013-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12360, 'Zala', 'Zala', 'Chongda,Zala,Zala Xiang,chong da,zha la,zha la xiang,冲达,扎拉,扎拉乡', 31.7644600, 93.6096600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12361, 'Zaindainxoi', 'Zaindainxoi', 'So-hsien,So-k''o-tsung-ch''eng,So-k’o-tsung-ch’eng,So-tsung,Sog Gomba,Sogxian,Sok Gomba,Sok-gompa,Sugsundong Gompa,Sugsundong Gömpa,Suo Xian,T''u-sung-tung-kung Miao,T’u-sung-tung-kung Miao,Ya-la,Zaindainxoi,Zandanxue,suo xian,zan dan xue,索县,赞丹学,赞丹雪', 31.8500000, 93.6666700, 'CN', '2014-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12362, 'Zadoi', 'Zadoi', 'Xiahe,Zadoi,Zhaduo,Zhaduo Xiang,xia he,zha duo,zha duo xiang,下河,扎朵,扎朵乡', 33.7696200, 96.7420100, 'CN', '2017-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12363, 'Yumendong', 'Yumendong', 'Yu-men-tung-chan,Yumen Dong Zhan,Yumendong,Yumendong Zhen,Yü-men-tung-chan,yu men dong,yu men dong zhan,yu men dong zhen,玉门东,玉门东站,玉门东镇', 39.8000000, 97.9000000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12364, 'Yukuriawat', 'Yukuriawat', 'Awati,Awati Zhen,Shang-a-wa-t''ai,Shang-a-wa-t’ai,Yukuriawat,a wa ti,a wa ti zhen,阿瓦提,阿瓦提镇', 39.0833500, 77.5666200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12365, 'Yuhu', 'Yuhu', 'Erh-yuan,Eryuan,Lan-ch''iung,Lan-ch’iung,Lang-ch''iung,Lang-ch’iung,Langkiunghsien,Lankiung,Lankiunghsien,Yu-hu-chen,Yuhu,Yü-hu-chen,yu hu,玉湖', 26.1067900, 99.9829200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12366, 'Yege', 'Yege', 'Jiaqing Songduo,Yege,Yege Xiang,Yuge,Yugê,jia qing song duo,ye ge,ye ge xiang,加青松多,叶格,叶格乡', 34.5750200, 95.3422600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12367, 'Yopurga', 'Yopurga', 'Jopurga,Jupoga,Yo-p''u-hu,Yo-p’u-hu,Yopurga,Yopurgha,Yopurƣa,Yueh-p''u-hu,Yueh-p''u-hu-ch''eng,Yueh-p''u-hu-hsien,Yuepuhu,Yuepuhu Xian,Yuepuhu Zhen,Yupoga,Yupogha,Yupuga,Yüeh-p’u-hu,Yüeh-p’u-hu-ch’eng,Yüeh-p’u-hu-hsien,yue pu hu,yue pu hu xian,yue pu hu zhen,Ёпурға,يوپۇرغا,岳普湖,岳普湖县,岳普湖镇', 39.2393800, 76.7643200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12368, 'Yeyik', 'Yeyik', 'Ya-i-k''o,Ya-i-k’o,Ya-li-ka,Yarig,Yayigh,Yeh-i-k''o,Yeh-i-k’o,Yeyik,Yeyike,Yeyike Xiang,Yeyiq,Yéyiq,ye yi ke,ye yi ke xiang,Ейық,يېيىق,叶亦克,叶亦克乡', 36.6666700, 83.2333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12369, 'Yeniugou', 'Yeniugou', 'Yeh-niu-Kou,Yeniugou,Yeniugou Xiang,ye niu gou,ye niu gou xiang,野牛沟,野牛沟乡', 38.4273100, 99.5186600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12370, 'Yanduo', 'Yanduo', 'Ch''a-ya,Ch''a-ya-hsien,Chagyab Co,Chaya Xian,Ch’a-ya,Ch’a-ya-hsien,Ma-kung,Yanduo,Yanduo Zhen,Yen-tai-t''ang,Yen-tai-t’ang,Yen-to,Yendum,Yenmdo,Yêndum,Zhag''yab,Zhag’yab,cha ya xian,yan duo,yan duo zhen,察雅县,烟多,烟多镇', 30.6572200, 97.5731000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12371, 'Yantak', 'Yantak', 'Yangtake,Yangtake Xiang,Yantak,yang ta ke,yang ta ke xiang,央塔克,央塔克乡', 38.9940800, 77.6608300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12372, 'Yangkang', 'Yangkang', 'Yangkang,Yangkang Xiang,yang kang,yang kang xiang,阳康,阳康乡', 37.6833300, 98.7500000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12373, 'Ya’ngan', 'Ya''ngan', 'Pugugai,Ya''an,Ya''an Zhen,Ya''ngamdo,Ya''ngan,Ya-an-to,Ya’an,Ya’an Zhen,Ya’ngamdo,Ya’ngan,pu gu gai,ya an,ya an zhen,普古改,雅安,雅安镇', 31.8437200, 94.4374900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12374, 'Yanchiwan', 'Yanchiwan', 'Yanchiwan,Yanchiwan Xiang,Yen-ch''ih-wan,Yen-ch’ih-wan,yan chi wan,yan chi wan xiang,盐池湾,盐池湾乡', 38.9820900, 96.1137300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12375, 'Xungmai', 'Xungmai', 'Sezong,Xiongmei,Xiongmei Zhen,Xungmai,se zong,xiong mei,xiong mei zhen,色宗,雄梅,雄梅镇', 31.3408700, 89.0144500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12376, 'Xueshan', 'Xueshan', 'Duochaduo,Xueshan,Xueshan Xiang,duo cha duo,xue shan,xue shan xiang,朶茶多,雪山,雪山乡', 34.7947000, 99.7262000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12377, 'Xiwu', 'Xiwu', 'Hsi-wu,Xiewu,Xiewu Zhen,Xiwu,xie wu,xie wu zhen,歇武,歇武镇', 33.1302100, 97.3469400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12378, 'Xitieshan', 'Xitieshan', 'Hsi-t''ieh-shan,Hsi-t’ieh-shan,Xitieshan,Xitieshan Zhen,xi tie shan,xi tie shan zhen,锡铁山,锡铁山镇', 37.2972100, 95.5147900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12379, 'Xireg', 'Xireg', 'Hsi-li-kou,Kokobeli,Kukubeli,Tu-lan,Tu-lan-hsien,Ulan,Wu-lan,Wulan Xian,Xiligou,Xireg,wu lan xian,xi li gou,乌兰县,希里沟', 36.9186600, 98.4446300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12380, 'Xinyuan', 'Xinyuan', 'Hsin-yuan,Hsin-yüan,T''ien-chun,T''ien-hsun,Tianjun,Tianjun Xian,T’ien-chün,T’ien-hsün,Xinyuan,tian jun xian,xin yuan,天峻县,新源', 37.3000000, 99.0000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12381, 'Xinba', 'Xinba', 'Xinba,Xinba Xiang,xin ba,xin ba xiang,新坝,新坝乡', 39.1582100, 99.4067600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12382, 'Rikaze', 'Rikaze', 'Gigatze,Hsi-ko-tzu,Hsi-ko-tzü,Jih-k''a-tse,Jih-k''e-tze,Jih-k''o-tse,Jih-k’a-tse,Jih-k’e-tze,Jih-k’o-tse,RKZ,Rikaze,Samdruptse,Samzhubze,Samzhubze District,Samzhubzê,Samzhubzê District,Sh''i-ka-tse,Shigadze,Shigatse,Shigatsé,Shigatze,Sh’i-ka-tse,Siketze,Xigaze,Xigazê,Zhikatse,ri ka ze,samudo~uputsu~e qu,sang zhu zi qu,ssangjujjeu gu,Шигадзе,サムドゥプツェ区,日喀则,桑珠孜区,쌍주쯔 구', 29.2500000, 88.8833300, 'CN', '2014-05-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12383, 'Xidong', 'Xidong', 'Xidong,Xidong Zhen,xi dong,xi dong zhen,西洞,西洞镇', 39.6000000, 98.4000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12384, 'Xiao Surmang', 'Xiao Surmang', 'Changqingke,Hsiao-su-mang,Xiao Surmang,Xiaosumang,Xiaosumang Xiang,xiao su mang,xiao su mang xiang,zhang qing ke,小苏莽,小苏莽乡,长青可', 32.3500000, 97.2333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12385, 'Xiangride', 'Xiangride', 'Hsiang-jih,Hsiang-jih-te,Shang,Shangjih,Xiangride,Xiangride Xiang,xiang ri de,xiang ri de xiang,香日德,香日德乡', 35.9933500, 97.8864900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12386, 'Xialaxiu', 'Xialaxiu', 'Longxisi,Xialaxiu,Xialaxiu Xiang,long xi si,xia la xiu,xia la xiu xiang,下拉秀,下拉秀乡,龙西寺', 32.6672000, 96.6105100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12387, 'Xiaheqing', 'Xiaheqing', 'Xiaheqing,Xiaheqing Xiang,xia he qing,xia he qing xiang,下河清,下河清乡', 39.5666700, 98.9666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12388, 'Xia Dawo', 'Xia Dawo', 'Xia Dawo,Xiadawu,Xiadawu Xiang,Xueqianduo,xia da wu,xia da wu xiang,xue qian duo,下大武,下大武乡,雪前多', 35.0036800, 99.2604700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12389, 'Xia Boingor', 'Xia Boingor', 'Dilangduo,Xia Boingor,Xiahongke,Xiahongke Xiang,de lang duo,xia hong ke,xia hong ke xiang,下红科,下红科乡,地浪多', 32.8000000, 99.7000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12390, 'Xiexiong', 'Xiexiong', 'Jiangkaxi,Xexung,Xiexiong,Xiexiong Xiang,Xêxung,jiang ka xi,xie xiong,xie xiong xiang,协雄,协雄乡,江卡西', 31.4100000, 95.6200000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12391, 'Xinji', 'Xinji', 'Tongduo,Xenkyer,Xinji,Xinji Xiang,Xênkyêr,tong duo,xin ji,xin ji xiang,同多,新吉,新吉乡', 30.5975400, 89.8323600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12392, 'Xekar', 'Xekar', 'Xekar,Xike''erkule,Xike''erkule Zhen,Xike’erkule,Xike’erkule Zhen,xi ke er ku lei,xi ke er ku lei zhen,西克尔库勒,西克尔库勒镇', 39.8158200, 77.3664900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12393, 'Xêgar', 'Xegar', 'Dingri Xian,Hsieh-ka-erh,Hsieh-ka-erh-tsung,Hsieh-ko-erh,Shekar Dzong,Ting-jih,Tingri,Xegar,Xiega''er,Xiega’er,Xêgar,ding ri xian,xie ga er,协嘎尔,定日县', 28.6333300, 87.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12394, 'Xarsingma', 'Xarsingma', 'Chomo,Hsia-ssu-ma,Shasima,Xarsingma,Xiasima,Ya-tung,Yadong,Yadong Xian,Zhuomu Xian,xia si ma,ya dong xian,zhuo mu xian,下司马,亚东县,卓木县', 27.4940200, 88.9529600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12395, 'Xarag', 'Xarag', 'Hsia-jih-ch''ia,Hsia-jih-ch’ia,Hsia-jih-ha,Hsiajihcha,Sharha,Xarag,Xiariha,Xiariha Zhen,xia ri ha,xia ri ha zhen,夏日哈,夏日哈镇', 36.4000000, 98.1833300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12396, 'Xangda', 'Xangda', 'Hsiang-ta,Nang-ch''ien,Nang-ch’ien,Nangqen,Nangqian,Nangqian Xian,Nangqên,Xangda,Xiangda,Xiangda Zhen,nang qian,nang qian xian,xiang da,xiang da zhen,囊谦,囊谦县,香达,香达镇', 32.2055100, 96.4780900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12397, 'Waxxari', 'Waxxari', 'Chiang-kan-sha-i,Pa-shih-shih-li,Vasch-schahri,Vash Shahri,Vash-Shari,Wa-shih-hsia,Wa-shih-hsia-chuang,Wa-shih-sha-li,Wa-shih-shan-li,Wahs-shahri,Wash Shahri,Washixia,Washixia Xiang,Waxxari,wa shi xia,wa shi xia xiang,瓦石峡,瓦石峡乡', 38.7000000, 87.3166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12398, 'Wangdain', 'Wangdain', 'Wang-tan,Wangda Xiang,Wangdain,Wangdan,Wangdanxue,wang dan,wang dan xiang,wang dan xue,汪丹,汪丹乡,汪丹雪', 28.8668400, 89.1535600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12399, 'Wangda', 'Wangda', 'Tso-kung,Wang-ta,Wangda,Wangda Zhen,Zogang,Zuogong Xian,wang da,wang da zhen,zuo gong xian,左贡县,旺达,旺达镇,汪达', 29.6744500, 97.8373600, 'CN', '2015-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12400, 'Tunggar', 'Tunggar', 'Dongga,Dongga Xiang,Tunggar,dong ga,dong ga xiang,洞嘎,洞嘎乡', 29.0088000, 93.1923900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12401, 'Tungdor', 'Tungdor', 'Dongduo,Mi-lin,Mi-lin-hsien,Mi-ling,Milin Xian,Tung-to,Tung-to-ts''un,Tung-to-ts’un,Tungdor,dong duo,mi lin xian,东多,米林县', 29.2000000, 94.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12402, 'Tumantale', 'Tumantale', 'Tumantal,Tumantale,Tumantale Xiang,Tumental,Tümantal,Tümental,Tüməntal,tu man ta lei,tu man ta lei xiang,Түмәнтал,تۈمەنتال,吐曼塔勒,吐曼塔勒乡', 39.1508800, 77.7881300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12403, 'Darya Boyi', 'Darya Boyi', 'Daliya Buyi,Daliya Buyi Xiang,Darya Boye,Darya Boyi,T''ung-ku-tzu-pa-ssu-t''e,Tongguzbasti,Tongguzi Basite,T’ung-ku-tzu-pa-ssu-t’e,da li ya bu yi,da li ya bu yi xiang,tong gu zi ba si te,Тоңгузбасти,توڭگۇزباستى,达里雅布依,达里雅布依乡,通古孜巴斯特', 38.3833300, 82.0000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12404, 'Tomorlog', 'Tomorlog', 'Rodnik Timurlik,T''ieh-mu-li-k''o,Temirlik,Ti-mu-erh-li-k''o,Ti-mu-erh-li-k’o,Tiemulike,Tiemulike Xiang,Timurlik,Tomorlog,Tomurlik,Tömürlik,T’ieh-mu-li-k’o,tie mu li ke,tie mu li ke xiang,铁木里克,铁木里克乡', 38.2555500, 90.3119600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12405, 'Toding', 'Toding', 'Cha-ta,T''o-lin,T''o-lin-ma-ssu,T''o-t''e-lin-ko-ma,Ta-ting,Toding,Toling,Tolingmath,Totling,Totling-gompa,Tuling,Tuolin,Tuolin Juweihui,T’o-lin,T’o-lin-ma-ssu,T’o-t’e-lin-ko-ma,Zanda,Zhada Xian,tuo lin,tuo lin ju wei hui,zha da xian,托林,托林居委会,札达县', 31.4805600, 79.7980300, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12406, 'Tengyue', 'Tengyue', 'Momein,T''eng-ch''ung-hsien,Tengchong,Tengyue,Tengyueh,Tengyüeh,T’eng-ch’ung-hsien,teng yue,腾越', 24.9949200, 98.5127600, 'CN', '2017-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12407, 'Tatrang', 'Tatrang', 'T''a-t''a-lang,Tatirang,Tatirang Xiang,Tatran,Tatrang,T’a-t’a-lang,ta ti rang,ta ti rang xiang,tatyrang,Татираң,تاتىراڭ,塔提让,塔提让乡', 38.4666700, 85.6333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12408, 'Tanglag', 'Tanglag', 'Dangluo,Dangluo Xiang,Tang-lo,Tanglag,dang luo,dang luo xiang,当洛,当洛乡', 33.9973000, 99.4463800, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12409, 'Jiuquan', 'Jiuquan', 'Chiu-ch''uan,Chiu-ch''uan-hsien,Chiu-ch''uan-shih,Chiu-choan-chhi,Chiu-ch’üan,Chiu-ch’üan-hsien,Chiu-ch’üan-shih,Chiú-choân-chhī,Ciu-ciong,Ciū-ciòng,Czjucjuan'',Jiuquan,Jiuquan Shi,Kiuchoan,Kiuchuan,Kiuchuan-hsien,Kiuchüan,Kiuchüan-hsien,Su-chou,Suchow,Suchzhou,Suzhou,Tiou-cchuean,Tsin-tsuan-tsiun,Tuu Tuyen,Tửu Tuyền,Zhjuchuan'',jiu quan,jiu quan shi,juchwian si,jywchwan,su zhou,Ťiou-čchüan,Жючуань,Сучжоу,Цзюцюань,جیوچوآن,جیوچوان,肃州,酒泉,酒泉市,주취안 시', 39.7431800, 98.5173600, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12410, 'Songmai', 'Songmai', 'Derong,Dêrong,Songmai,Songmai Zhen,Te-jung,Te-jung-hsien,Te-yung,Tehjung,de rong,song mai,song mai zhen,得荣,松麦,松麦镇', 28.7147100, 99.2863300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12411, 'Shule', 'Shule', 'Jangi-schahr,K''o-shih-ka-erh,K''o-shih-ka-erh-hsin-ch''eng,K''o-shih-ko-erh-hsin-ch''eng,Kashgar,Kashgar Yangi Shahr,Ko-shih-ka-erh-hui-ch''eng,Ko-shih-ka-erh-hui-ch’eng,K’o-shih-ka-erh,K’o-shih-ka-erh-hsin-ch’eng,K’o-shih-ko-erh-hsin-ch’eng,New Kashgar,Sheleh,Shu-lo,Shule,Shuleh,Shulen,Su-lo,Su-lo-chen,Su-lo-hsien,Yangi-shaar,Yangi-shahr,Yangishar,Yengisheher,Yengixəh̨ər,Yéngisheher,shu lei,Еңишәһәр,يېڭىشەھەر,疏勒', 39.4023100, 76.0508000, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12412, 'Shiquanhe', 'Shiquanhe', 'Ali Diqu,NGQ,Ni-k''o-li,Ni-k’o-li,Nikri,Senge Juweihui,Shih-ch''uan,Shih-ch’üan,Shiquanhe,Zangbu Juweihui,a li de qu,cang bu ju wei hui,sen ge ju wei hui,shi quan he,森格居委会,狮泉河,藏布居委会,阿里地区', 32.5012400, 80.0975800, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12413, 'Shimen', 'Shimen', 'Shih-men-chen,Shih-men-ching,Shimen,Shimenzhen,Yun-lung,Yun-lung-hsien,Yunlong,Yün-lung,Yün-lung-hsien,shi men,石门', 25.8947900, 99.4293600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12414, 'Dianyang', 'Dianyang', 'Dianyang,Shidian,Shih-tien,Shih-tien-chen,Shih-tien-chieh,Shikuan,Shiküan,dian yang,甸阳', 24.7026100, 99.1591900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12415, 'Shibaocheng', 'Shibaocheng', 'Hsin-pao-ch''eng,Hsin-pao-ch’eng,Shibaocheng,Shibaocheng Xiang,Shih-pao-ch''eng,Shih-pao-ch’eng,Shinbaochen,shi bao cheng,shi bao cheng xiang,石包城,石包城乡', 39.8000000, 96.0666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12416, 'Shengping', 'Shengping', 'A-tun,A-tun-tzu,Atun-hsien,Atun-tse,Atung,Atuntze,Deqin,Dong,Shengping,Te-ch''in,Te-ch''in-hsien-tsang-tsu-tzu-chih-ch''u,Te-ch''in-she-chih-chu,Te-ch’in,Te-ch’in-hsien-tsang-tsu-tzu-chih-ch’ü,Te-ch’in-she-chih-chü,Tehching,Tehtsin,de qin,sheng ping,升平,德钦', 28.4856300, 98.9113900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12417, 'Shanglaxiu', 'Shanglaxiu', 'Duola Make,Shanglaxiu,Shanglaxiu Xiang,duo la ma ke,shang la xiu,shang la xiu xiang,上拉秀,上拉秀乡,多拉麻科', 32.8539900, 96.5842600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12418, 'Shanggongma', 'Shanggongma', 'Shang-kung-ma,Shanggongma,Shanggongma Xiang,Tanggegei,shang gong ma,shang gong ma xiang,tang ge gei,上贡麻,上贡麻乡,唐格给', 33.8333300, 99.6666700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12419, 'Shang Boingor', 'Shang Boingor', 'Haqingda,Shang Boingor,Shanghongke,Shanghongke Xiang,ha qing da,shang hong ke,shang hong ke xiang,上红科,上红科乡,哈青达', 32.9000000, 99.5833300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12420, 'Shangpa', 'Shangpa', 'Fu-kung,Fugong,Shang-p''a,Shang-p''a-chieh,Shang-p''a-hsing-cheng-shu,Shang-p''a-ts''un,Shang-p’a,Shang-p’a-chieh,Shang-p’a-hsing-cheng-shu,Shang-p’a-ts’un,Shangba,Shangpa,shang pa,上帕', 26.9194800, 98.9515800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12421, 'Shache', 'Shache', 'Shache,So-ch''e,So-ch''e-chen,So-ch''e-hsien,So-ch''e-shih,So-ch’e,So-ch’e-chen,So-ch’e-hsien,So-ch’e-shih,Yangi-shahr,Yarkand,Yarkand New City,Yarkand Yangi-shahr,Yarkant,Yarkend,Yarkent,Yeken,Yəkən,Якән,يەكەن', 38.4166700, 77.2405600, 'CN', '2016-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12422, 'Segong', 'Segong', 'Nieh-jung,Nieh-lung-tsung,Nierong Xian,Nyainrong,Se-kung,Segong,Serkang,Sêrkang,nie rong xian,se gong,聂荣县,色贡', 32.2166700, 92.1166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12423, 'Serikbuya', 'Serikbuya', 'Selibuya,Selibuya Zhen,Serikbuya,Serik̩buya,Seriqbuya,Sériqbuya,se li bu ya,se li bu ya zhen,Серықбуя,سېرىقبۇيا,色力布亚,色力布亚镇', 39.3017400, 77.8178600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12424, 'Serh', 'Serh', 'Sai-shih-k''o,Sai-shih-k’o,Saishike,Saishike Xiang,Serh,sai shen ke,sai shen ke xiang,赛什克,赛什克乡', 36.9489500, 98.3746300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12425, 'Shinaihai', 'Shinaihai', 'Qiecha,Senag,Shinaihai,Shinaihai Xiang,Sênag,qie cha,shi nai hai,shi nai hai xiang,切查,石乃亥,石乃亥乡', 36.9823800, 99.6289800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12426, 'Sangruma', 'Sangruma', 'Kanglongda,Sang-jih-ma,Sangrima,Sangrima Xiang,Sangruma,kang long da,sang ri ma,sang ri ma xiang,康龙达,桑日麻,桑日麻乡', 33.6500000, 99.2000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12427, 'Samada', 'Samada', 'Samada,Samada Xiang,sa ma da,sa ma da xiang,萨马达,萨马达乡', 28.4040700, 89.5554500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12428, 'Sajia', 'Sajia', 'Sa''gya,Sa''gyaxoi,Sa-chia,Sa-chia-tsung,Sajia,Sakya,Sakya Gomba,Sakya Gompa,Sakya Gömpa,Sayka Gompa,Sa’gya,Sa’gyaxoi,sa jia,萨迦', 28.9166700, 88.0500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12429, 'Shading', 'Shading', 'Sadeng,Sadêng,Sating,Sha-ting,Sha-ting-tsung,Shading,Shading Xiang,sha ding,sha ding xiang,沙丁,沙丁乡', 31.2588700, 94.4955800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12430, 'Rutog', 'Rutog', 'Jih-t''u,Jih-t''u-tsung,Jih-t’u,Jih-t’u-tsung,Lo-to-k''o,Lo-to-k''o-tsung,Lo-to-k’o,Lo-to-k’o-tsung,Ritu,Rudog,Rudok,Ruthog,Rutog,ri tu,日土', 33.4184400, 79.6391900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12431, 'Ruoqiang', 'Ruoqiang', 'Ch''o-ch''iang,Ch''o-ch''iang-hsien,Chaklik,Chakliq,Chaqiliq,Charkhik,Charkhlig,Charkhlik,Charkhliq,Charkhlok,Charkhlyk,Charkhlök,Charklig,Charklik,Charkliq,Charklyk,Charlik,Charlyk,Charrlik,Chohchiang,Chohkiang,Ch’o-ch’iang,Ch’o-ch’iang-hsien,Er-ch''iang,Er-ch’iang,Erh-ch''iang,Erh-ch''iang hsien,Erh-ch’iang,Erh-ch’iang hsien,Ertsyan,Jo-ch''iang,Jo-ch''iang-ch''eng,Jo-ch''ien,Jo-ch’iang,Jo-ch’iang-ch’eng,Jo-ch’ien,K''a-k''o-li-k''o,K’a-k’o-li-k’o,Qakilik,Qak̩ilik̩,Qarkilik,Rechiang,Ruoqiang,Ruoqiang Zhen,Tcharghalyk,Tjarchlik,Tscharklik,Zhotszyan'',Zhotszyan’,chaqylyq,ruo qiang,ruo qiang zhen,Чақылық,چاقىلىق,若羌,若羌镇', 39.0200300, 88.1646500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12432, 'Rongbo', 'Rongbo', 'Jilutong,Rongbo,Rongbu,Rongbu Zhen,ji lu tong,rong bu,rong bu zhen,纪路通,荣布,荣布镇', 31.5570700, 94.6327800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12433, 'Rendui', 'Rendui', 'Rendui,Rendui Xiang,Rindu,Rindü,ren dui,ren dui xiang,仁堆,仁堆乡', 30.0734600, 89.1047100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12434, 'Rinbung', 'Rinbung', 'Renbu,Renbu Xiang,Rinbung,ren bu,ren bu xiang,仁布,仁布乡', 29.2673300, 89.8092800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12435, 'Reshui', 'Reshui', 'Reshui,Reshui Xiang,re shui,re shui xiang,热水,热水乡', 36.2203600, 98.1687700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12436, 'Reyu', 'Reyu', 'Je-yu,Je-yü,Rayu,Rayü,Reyu,Reyu Xiang,re yu,re yu xiang,热玉,热玉乡', 31.1595600, 95.1334900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12437, 'Ramba', 'Ramba', 'Ramba,Ranba,Ranba Xiang,ran ba,ran ba xiang,然巴,然巴乡', 29.1317800, 90.1277200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12438, 'Racaka', 'Racaka', 'Lawuchi,Lei-to-ch''i,Lei-to-ch’i,Lei-wu-ch''i,Lei-wu-ch''i-tsung,Lei-wu-ch’i,Lei-wu-ch’i-tsung,Lei-wu-tsung,Leiwuqi Xian,Neiwutsi,Racaka,Rezhaka,Ribochhe,Riowoche,Rivoche,Riwoche,Riwoqe,Riwoqê,lei wu qi xian,re zha ka,热扎卡,类乌齐县', 31.4000000, 96.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12439, 'Quxar', 'Quxar', 'Ch''u-hsia,Ch’ü-hsia,La-tzu,Lazi Xian,Lhaze,Lhazê,Quxar,Quxia,T''u-chiao,T''u-lin,T’u-chiao,T’u-lin,la zi xian,qu xia,拉孜县,曲下', 29.1000000, 87.6500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12440, 'Qümong', 'Qumong', 'Ju Gompa,Jumang,Nixia,Serxu,Shih-ch''u,Shih-ch''ü,Shihchi,Sêrxü,Tsa-ch''u-k''a,Tsa-ch''ü-k''a,ni xia,འཇུ་མང,尼呷', 32.9777100, 98.0979500, 'CN', '2007-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12441, 'Qira', 'Qira', 'Cele,Chira,Chira-Bazar,Qira,Qira Zhen,Tjira,Ts''e-le,Ts''e-lo,Ts''e-lo-chen,Ts''e-lo-hsien,Ts''e-lo-shih-ch''ang,Ts''e-lo-ts''un,Tsehleh,Tsehletsun,Ts’e-le,Ts’e-lo,Ts’e-lo-chen,Ts’e-lo-hsien,Ts’e-lo-shih-ch’ang,Ts’e-lo-ts’un,ce lei,ce lei zhen,chyra,Чира,چىرا,策勒,策勒镇', 37.0284700, 80.8028700, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12442, 'Qiqing', 'Qiqing', 'Qiqing,Qiqing Zangzu Xiang,qi qing,qi qing cang zu xiang,祁青,祁青藏族乡', 39.1833300, 98.0000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12443, 'Qingshui', 'Qingshui', 'Ch''ing-shui,Ch''ing-shui-ch''uan,Ch''ing-shui-ch''uan-pao,Ch''ing-shui-p''u,Ch''ing-shui-pao,Chingshuichwan,Ch’ing-shui,Ch’ing-shui-ch’üan,Ch’ing-shui-ch’üan-pao,Ch’ing-shui-pao,Ch’ing-shui-p’u,Qingshui,Qingshui Zhen,Qingshuipu,Ts''ing-schui-p''u,Tsanshuypu,Tsinshuypu,Ts’ing-schui-p’u,qing shui,qing shui zhen,清水,清水镇', 39.3833300, 99.1333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12444, 'Qingshuihe', 'Qingshuihe', 'Ch''ing-shui-ho,Ch-ing Sui-Ho,Ch’ing-shui-ho,Domda,Qingshuihe,Qingshuihe Zhen,qing shui he,qing shui he zhen,清水河,清水河镇', 33.8038500, 97.1362700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12445, 'Qinglung', 'Qinglung', 'Qinglong,Qinglong Xiang,Qinglung,qing long,qing long xiang,青龙,青龙乡', 31.1616400, 90.6661300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12446, 'Qilanbulak', 'Qilanbulak', 'Chilanbulaq,Qilanbulak,Qilanbulak̩,Yitunbulake,Yitunbulake Zhen,yi tun bu la ke,yi tun bu la ke zhen,Чиланбулақ,چىلانبۇلاق,依吞布拉克,依吞布拉克镇', 38.3860000, 90.1569600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12447, 'Qigzhi', 'Qigzhi', 'Badi Longren,Qigzhi,Qiuzhi,Qiuzhi Xiang,ba de long ren,qiu zhi,qiu zhi xiang,巴地陇仁,秋智,秋智乡', 34.5683900, 95.6583300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12448, 'Qiemo', 'Qiemo', 'Ch''e-erh-ch''eng,Ch''ieh-mo,Ch''ieh-mo-ch''eng,Ch''ieh-mo-hsien,Ch''ien-mo,Charchan,Charchan Bazar,Cherchen,Cherchen Bazar,Ch’e-erh-ch’eng,Ch’ieh-mo,Ch’ieh-mo-ch’eng,Ch’ieh-mo-hsien,Ch’ien-mo,IQM,Qarqan,Qiemo,Qiemo Xian,Qərqən,Tchertchen,Tergen,Tjertjen,Tschertschen,qie mo,qie mo xian,Чәрчән,چەرچەن,且末,且末县', 38.1340700, 85.5297700, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12449, 'Qiangqinxue', 'Qiangqinxue', 'Jen-pang,Jen-pang-tsung,Jen-pu,Lun-p''eng-tsung,Lun-p’eng-tsung,Qamqenxoi,Qamqênxoi,Qiangqinxue,Renbu Xian,Rinphung Dzong,Rinpung Dzong,Rinpung-dsong,qiang qin xue,ren bu xian,仁布县,强钦雪', 29.2666700, 89.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12450, 'Qamdo', 'Qamdo', 'BPX,Ch''a-mu-to,Ch''ang-tu,Ch''ang-tu-hsien,Ch''ang-tu-tsung,Chamdo,Chamudo,Changdu,Chhamdo,Ch’a-mu-to,Ch’ang-tu,Ch’ang-tu-hsien,Ch’ang-tu-tsung,Qamdo,chang dou,昌都', 31.1304000, 97.1798200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12451, 'Jiajuedibu', 'Jiajuedibu', 'Hsiang-sha,Hsiang-sha-tsung,Jiajuedibu,Qajortebu,Qajortêbu,Schen-ssa-dsong,Senja-dsong,Senja-dzong,Shansa-dzong,Shen-cha,Shen-cha-hsiang,Shen-cha-tsung,Shensa Dzong,Shentsa,Shentsa Dzong,Shenzha Xian,Xainza,jia jue di bu,shen zha xian,甲觉底布,申扎县', 30.9333300, 88.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12452, 'Qiaze', 'Qiaze', 'Gaqingai,Qagze,Qagzê,Qiaze,Qiaze Xiang,ga qin gai,qia ze,qia ze xiang,嘎钦改,恰则,恰则乡', 31.7089200, 93.1742900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12453, 'Qagan Us', 'Qagan Us', 'Ch''a-han-wu-su,Chahan Wusu,Ch’a-han-wu-su,Dulan,Dulan Xian,Qagan Us,Tu-lan,cha han wu su,dou lan xian,察汗乌苏,都兰县', 36.3971900, 98.0122200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12454, 'Puqu', 'Puqu', 'Bujiu,Bujiu Zhen,Puqu,Zhuqudian,bu jiu,bu jiu zhen,zhu qu dian,布久,布久镇,朱去典', 29.4697000, 94.4172600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12455, 'Pubu', 'Pubu', 'Baingoin,Bange Xian,P''u-pao,Pan-ko,Pubao,Pubao Zhen,Pubu,P’u-pao,ban ge xian,pu bao,pu bao zhen,普保,普保镇,班戈县', 31.3962500, 90.0095800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12456, 'Guma', 'Guma', 'Guma,Guma Bazar,Guma Zhen,Ku-ma,Ku-man,P''i-shan-chen,P''i-shan-hsien,Pishan,P’i-shan-chen,P’i-shan-hsien,gu ma,gu ma zhen,Гума,گۇما,固玛,固玛镇', 37.6168000, 78.2808700, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12457, 'Pingyuan', 'Pingyuan', 'Chao-kou,Pingyuan,Tung-fang-hung-kung-she,Ying-chiang,Ying-chiang-hsien,Yingjiang,ping yuan,平原', 24.7364200, 97.9135800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12458, 'Paingar', 'Paingar', 'Baiga,Baiga Xiang,Paingar,bai ga,bai ga xiang,白嘎,白嘎乡', 31.1979300, 94.0354300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12459, 'Pagri', 'Pagri', 'P''a-li,P''a-li-tsung,P''ei-li-chuang,P''ei-li-tsung,Pagri,Pagri Zhen,Pali,Pali Zhen,Phari,Phari Dzong,Phari Jong,P’a-li,P’a-li-tsung,P’ei-li-chuang,P’ei-li-tsung,pa li,pa li zhen,帕里,帕里镇', 27.7500000, 89.1666700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12460, 'Kequ', 'Kequ', 'Gade,Gande,Gande Xian,Kan-te,Kanteh,Kequ,Kequ Zhen,Pagqen,Pagqên,gan de,gan de xian,ke qu,ke qu zhen,柯曲,柯曲镇,甘德,甘德县', 33.9686500, 99.9009700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12461, 'Pagnag', 'Pagnag', 'Amdo,An-to,An-to-mai-ma,An-to-mai-ma-chan,An-tu-mai,Anduo Xian,Pagnag,Pana,Pana Zhen,an duo xian,pa na,pa na zhen,安多县,帕那,帕那镇', 32.2698600, 91.6810100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12462, 'Oytograk', 'Oytograk', 'Ao-i-t''o-ko-la-k''o,Ao-i-t’o-ko-la-k’o,Aoyituo Gelake,Aoyituo Gelake Xiang,Oytoghraq,Oytograk,Oytoƣrak̩,ao yi tuo ge la ke,ao yi tuo ge la ke xiang,ywytwghraq,Ойтоғрақ,ئويتوغراق,奥依托格拉克,奥依托格拉克乡', 36.8333300, 81.9333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12463, 'A’yi Take', 'A''yi Take', 'A''yi Take,A''yi Take Xiang,A’yi Take,A’yi Take Xiang,Oytar,a yi ta ke,a yi ta ke xiang,阿依塔克,阿依塔克乡', 38.9530300, 75.4278300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12464, 'Wosai', 'Wosai', 'Kanbaduo,Oiser,Oisêr,Wosai,Wosai Xiang,kan ba duo,wo sai,wo sai xiang,坎巴多,窝塞乡,窝赛', 33.6166700, 99.8000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12465, 'Nyima', 'Nyima', 'Nima,Nima Xiang,Nimalong,Nyima,ni ma,ni ma long,ni ma xiang,尼玛乡,尼马,尼麻隆', 31.7592800, 92.2535500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12466, 'Nyima', 'Nyima', 'Nima,Nima Xiang,Nimalong,Nyima,ni ma,ni ma long,ni ma xiang,尼玛乡,尼玛隆,尼马', 31.5435300, 92.7324000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12467, 'Nieru', 'Nieru', 'Nailong,Nieru,Nieru Xiang,Nyeru,Nyêru,nai long,nie ru,nie ru xiang,乃隆,涅如,涅如乡', 28.5251700, 89.8504100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12468, 'Nyagla', 'Nyagla', 'Nianggong,Niangla,Niangla Xiang,Nyagla,niang gong,niang la,niang la xiang,娘拉,娘拉乡,娘贡', 32.0413600, 96.8406500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12469, 'Nur', 'Nur', 'Lu-la,Nu''er,Nu''er Xiang,Nu-jih,Nu-jih-a-lan-kan,Nu-la,Nur,Nura,Nu’er,Nu’er Xiang,nu er,nu er xiang,Нур,نۇر,奴尔,奴尔乡', 36.3247200, 81.0597200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12470, 'Luobuqiongzi', 'Luobuqiongzi', 'Bailang Xian,Bainang,Chiao-cho,Chiao-lo,Luobuqiongzi,Norbukyungze,Norbukyungzê,P''ei-na-mu-tsung,P''ing-nan,Pa-lang,Pai-lang,Pai-lang-tsung,Pal-lam,Pelam,Pen-nang Dzong,Pen-nang-dsong,Pena Dzong,Penam Dzong,Pennang,P’ei-na-mu-tsung,P’ing-nan,bai lang xian,luo bu qiong zi,洛布穷孜,白朗县', 29.1666700, 89.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12471, 'Nomhon', 'Nomhon', 'No-mo-hung,No-mo-hung-ho-t''o,No-mo-hung-ho-t’o,No-mu-hung,Nomhom,Nomhon,Nomochon-choto,Nomokhan Khoto,Nuomuhong,Nuomuhong Xiang,Po-mo-hung-ho-t''o,Po-mo-hung-ho-t’o,nuo mu hong,nuo mu hong xiang,诺木洪,诺木洪乡', 36.3705600, 96.4082100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12472, 'Ngamring', 'Ngamring', 'Ang-jen,Angren,Ngamring,Ngamringxoi,ang ren,昂仁', 29.2333300, 87.1666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12473, 'Geji', 'Geji', 'Ge''gyai,Geji,Geji Xian,Geji Zhen,Gê’gyai,Ko-chi,Na-po,Nabucun,Napo,Napug,ge ji,ge ji xian,ge ji zhen,na bu cun,na po,那坡,那布村,革吉,革吉县,革吉镇', 32.3954500, 81.1397200, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12474, 'Nanhua', 'Nanhua', 'Nanhua,Nanhua Zhen,nan hua,nan hua zhen,南华,南华镇', 39.3166700, 99.7833300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12475, 'Nangxian', 'Nangxian', 'La-to,Lang,Lang-hsien,Lang-tsung,Langxian,Nan-ko,Nan-ko-tsung,Nang,Nang Dzong,Nangxian,lang xian,朗县', 29.0470100, 93.0879500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12476, 'Wenquan', 'Wenquan', 'Namtang,Nanmutang,Wenquan,Wenquan Xiang,nan mu tang,wen quan,wen quan xiang,南木塘,温泉,温泉乡', 35.2166500, 99.6627300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12477, 'Namsai', 'Namsai', 'Angsai,Angsai Xiang,Dieniga,Namsai,ang sai,ang sai xiang,die ni ga,昂赛,昂赛乡,跌尼嘎', 32.7855200, 95.6147900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12478, 'Namling', 'Namling', 'Na-lin,Na-mu-lin-tsung,Na-mu-ling,Na-mu-ling-hsun,Na-mu-ling-hsün,Na-mu-ling-tsung,Namling,Namling Dzong,Namlingxoi,Nan-mu-lin,Nanmulin,Nanmulin Zhen,Renwu,nan mu lin,nan mu lin zhen,ren wu,仁伍,南木林,南木林镇', 29.6852700, 89.0955600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12479, 'Nailung', 'Nailung', 'Lilong,Lilong Xiang,Nailung,li long,li long xiang,里龙,里龙乡', 29.1141000, 93.8687300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12480, 'Nagqu', 'Nagqu', 'Hei-ho,Hei-ho-chen,Kheykhe,Na-ch''u,Na-ch''u-k''a,Na-ch’ü,Na-ch’ü-k’a,Na-ko-ch''u-tsung,Na-ko-ch’u-tsung,Na-ku-chia,Nag-chu-dsong,Nagchhu Dzong,Nagchhuka,Nagchhukha,Nagchu,Nagchu-dzong,Nagchuka,Nagqu,Nagqu Prefecture,Nagqu Prefektura,Nagqu Te-khu,Nagqu Tē-khu,Nagqu thi-khi,Nagqu thi-khî,Nagčhu,Nakchu,Nakchukha Dzong,Naqu,Naqu Zhen,Prefecture de Nagchu,Prefettura di Nagqu,Préfecture de Nagchu,na qu,na qu de qu,na qu zhen,nachwi jigu,naga-chu bibhaga,nagacu vibhaga,nakuchu de qu,Нагчу,नगचु विभाग,নাগ-ছু বিভাগ,ནག་ཆུ་ས་ཁུལ།,ナクチュ地区,那曲,那曲地区,那曲镇,나취 지구', 31.4767800, 92.0572900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12481, 'Muri', 'Muri', 'Mo-li,Muli,Muli Xiang,Muri,mu li,mu li xiang,木里,木里乡', 38.1333300, 99.0666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12482, 'Mozhong', 'Mozhong', 'Maozhuang,Maozhuang Xiang,Mozhong,Zaxitang,mao zhuang,mao zhuang xiang,zha xi tang,扎西唐,毛庄,毛庄乡', 32.2697400, 96.8203200, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12483, 'Karakax', 'Karakax', 'Ha-la-k''a-shih,Ha-la-k''o-shih,Ha-la-k’a-shih,Ha-la-k’o-shih,Halahashih,K''a-la-k''a-shih,K''o-la-k''o-shih,Kalakashi,Kalakashi Zhen,Kara kash,Kara-kasch,Karakax,K̩arak̩ax,K’a-la-k’a-shih,K’o-la-k’o-shih,Mo-yu-chen,Mo-yu-hsien,Mo-yü-chen,Mo-yü-hsien,Moyu,Qara Qash,Qarakash,Qaraqash,ka la ka shen,ka la ka shen zhen,qaraqash,Қарақаш,قاراقاش,喀拉喀什,喀拉喀什镇', 37.2722500, 79.7372800, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12484, 'Minghai', 'Minghai', 'Minghai,Minghai Xiang,Minghaisi,ming hai,ming hai xiang,明海,明海乡', 39.5000000, 99.4166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12485, 'Niya', 'Niya', 'Min-feng-ch''eng,Min-feng-ch’eng,Min-feng-hsien,Min-feng-she-chih-chu,Min-feng-she-chih-chü,Minfeng,Minfeng Xian,Ming-feng,Ni-ya-ch''eng,Ni-ya-ch’eng,Nia,Nija,Niya,Niya Bazar,Nya,min feng,min feng xian,ni ya,nyya,Ния,نىيا,尼雅,民丰,民丰县', 37.0655300, 82.6893300, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12486, 'Mengsuo', 'Mengsuo', 'Meng-hsaw,Mengsuo,Mong Hsaw,Möng Hsaw,meng suo,勐梭', 22.6019900, 99.5513700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12487, 'Mengmeng', 'Mengmeng', 'Meng-meng-hsiang,Mengmeng,Na-chai,Na-sai,Shuang-chiang,Shuang-chiang-hsien,Shuangjiang,Ssu-p''ai-shan,Ssu-p''ai-shan-hsien-tso,Ssu-p’ai-shan,Ssu-p’ai-shan-hsien-tso,Szepaishan,meng meng,勐勐', 23.4650200, 99.8020600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12488, 'Menglang', 'Menglang', 'Chen-pien,Chen-pien-ting,Hsia-kai-hsin,Lan-ts''ang,Lan-ts''ang-hsien,Lan-ts’ang,Lan-ts’ang-hsien,Lancang,Lancang Lahuzu Zizhixian,Meng-lang-pa,Meng-lang-pa-chen,Menglang,Menglangba,meng lang,勐朗', 22.5621400, 99.9102900, 'CN', '2016-11-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12489, 'Mengdong', 'Mengdong', 'Cangyuan,Meng-tung,Meng-tung-hsiang,Mengdong,Mengyong,Ts''ang-yuan,Ts''ang-yuan-k''a-wa-tsu-tzu-chih-hsien,Ts''ang-yuan-she-chih-chu,Ts''ang-yuan-wa-tsu-tzu-chih-hsien,Ts’ang-yüan,Ts’ang-yüan-k’a-wa-tsu-tzu-chih-hsien,Ts’ang-yüan-she-chih-chü,Ts’ang-yüan-wa-tsu-tzu-chih-hsien,meng dong,勐董', 23.1615200, 99.2022600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12490, 'Motuo', 'Motuo', 'Medog,Medog Zhen,Mo-t''o,Mo-t’o,Motuo,Mêdog,Mêdog Zhen,mo tuo,mo tuo zhen,墨脱,墨脱镇', 29.3132900, 95.3074100, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12491, 'Maindong', 'Maindong', 'Coqen,Cuoqin Xian,Maindong,Men-tung,Men-tung-Ssu,Mendong,Mendong Gomba,Mendong Gompa,Mendong Gömpa,Ts''o-ch''in,Ts’o-ch’in,cuo qin xian,men dong,措勤县,门董', 31.3333300, 85.4166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12492, 'Madoi', 'Madoi', 'Madoi,Maduo,Maduo Xiang,ma duo,ma duo xiang,麻多,麻多乡', 35.0249400, 96.3715700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12493, 'Machali', 'Machali', 'Machali,Madoi,Maduo,Maduo Xian,ma cha li,ma duo,ma duo xian,玛多,玛多县,玛查里', 34.9333300, 98.2333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12494, 'Luzhang', 'Luzhang', 'Lu-chang,Lu-chang-chieh,Lu-chang-hsiang,Lu-chang-shang-chai,Lu-shui-she-chih-chu,Lu-shui-she-chih-chü,Lushui,Luzhang,Luzhangjie,lu zhang,鲁掌', 25.9730900, 98.8234500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12495, 'Luocheng', 'Luocheng', 'Lo-ch''eng,Lo-ch’eng,Luocheng,Luocheng Xiang,luo cheng,luo cheng xiang,罗城,罗城乡', 39.6827400, 99.5544500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12496, 'Lungmar', 'Lungmar', 'Longma,Longma Xiang,Lungmar,long ma,long ma xiang,龙马,龙马乡', 28.8581600, 89.9403600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12497, 'Lunang', 'Lunang', 'Bengbacai,Lulang,Lulang Zhen,Lunang,beng ba cai,lu lang,lu lang zhen,崩巴菜,鲁朗,鲁郎镇', 29.7334900, 94.7261400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12498, 'Luring', 'Luring', 'Gaize Xian,Gerze,Gêrzê,Kai-tse,Longren,Lumaringbo,Luring,gai ze xian,long ren,改则县,隆仁', 32.2666700, 84.2000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12499, 'Lop', 'Lop', 'Lo-p''u,Lo-p''u-chen,Lo-p''u-hsien,Lo-p’u,Lo-p’u-chen,Lo-p’u-hsien,Lob,Lop,Lop-Bazar,Luopu,Luopu Zhen,luo pu,luo pu zhen,lwp,Лоп,لوپ,洛浦,洛浦镇', 37.0740300, 80.1823100, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12500, 'Longshan', 'Longshan', 'Longling,Longshan,Lung-ling,Lung-ling-hsien,long shan,龙山', 24.6008900, 98.7041800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12501, 'Linshui', 'Linshui', 'Lin-schui,Lin-shui-i,Linshui,Linshui Xiang,Ning-shui,Ninshuy,lin shui,lin shui xiang,临水,临水乡', 39.7891600, 98.7903900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12502, 'Lingti', 'Lingti', 'Lindi,Lindi Xiang,Lingti,lin di,lin di xiang,林堤,林堤乡', 30.9581800, 92.5753000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12503, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Xiang,Lianhuasi,lian hua,lian hua xiang,莲花,莲花乡', 39.6333300, 99.1000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12504, 'Lhasa', 'Lhasa', 'LXA,La-sa-shih,Lasa,Lasao,Lassa,Lhas,Lhasa,Lhasa Shi,Lhasa-chhi,Lhasa-chhī,Lhasa-su,Lhasa-sṳ,Lhassa,Lhasza,Lhásza,Lkhas,Lkhasa,Lkhasa shaary,Lkhasae,Lkhase,Lása,l''hasa,la sa,la sa shi,laca,lasa,lassa si,lhasa,lhsh,rasa,rasa shi,Λάσα,Ласа,Лхас,Лхасæ,Лхаса,Лхаса балһсн,Лхаса шаары,Лхасе,Һаса,להסה,لاسا,لاسا شەھىرى,لهاسا,لہاسا,ल्हासा,লাসা,ਲਾਸਾ,ଲାସା,லாசா,ลาซา,ལ་ས།,ལྷ་ས།,ლჰასა,ラサ,ラサ市,拉萨,拉萨市,拉薩,拉薩市,라사,라싸 시', 29.6500000, 91.1000000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12505, 'Lhari', 'Lhari', 'Jiali,Jiali Zhen,Larenguo,Lhari,jia li,jia li zhen,la ren guo,嘉黎,嘉黎镇,拉仁郭', 30.7436000, 93.3375400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12506, 'Lenghu', 'Lenghu', 'Leng-hu-chen,Leng-hu-shih,Lenghu,Lenghu Zhen,Lun-hu,leng hu,leng hu zhen,冷湖,冷湖镇', 38.7374100, 93.3319900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12507, 'Laojunmiao', 'Laojunmiao', 'Lao-chun-miao,Lao-chün-miao,Laojunmiao,Laojunmiao Zhen,Yu-men-shih,Yu-men-yu-k''uang-ch''u,Yumen,Yü-men-shih,Yü-men-yu-k’uang-ch’ü,lao jun miao,lao jun miao zhen,yu men,玉门,老君庙,老君庙镇', 39.8333300, 97.7333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12508, 'Laojie', 'Laojie', 'Ch''u-t''ung-chieh,Ch''u-tung,Chiu-ch''eng,Chiu-ch’eng,Ch’ü-tung,Ch’ü-t’ung-chieh,Kuting,Laojie,Yongping,Yung-p''ing,Yung-p''ing-hsien,Yung-p’ing,Yung-p’ing-hsien,lao jie,老街', 25.4482900, 99.5561000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12509, 'Lab', 'Lab', 'Lab,Labu,Labu Xiang,Lasitong,la bu,la bu xiang,la si tong,拉司通,拉布,拉布乡', 33.2716800, 97.1416900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12510, 'Kugri', 'Kugri', 'Gouli,Gouli Xiang,Kugri,Qurina,gou li,gou li xiang,qu ri na,曲日纳,沟里,沟里乡', 35.6592400, 98.4098600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12511, 'Kormang', 'Kormang', 'Donglangmu,Kongma,Kongma Xiang,Kormang,dong lang mu,kong ma,kong ma xiang,孔玛,孔玛乡,洞朗木', 31.6983400, 92.4257700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12512, 'Koramlik', 'Koramlik', 'K''u-la-mu-le-k''o,Koramlik,Kula Muleke,Kula Muleke Xiang,K’u-la-mu-le-k’o,ku la mu lei ke,ku la mu lei ke xiang,库拉木勒克,库拉木勒克乡', 37.4000000, 85.8666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12513, 'Kizilsu', 'Kizilsu', 'Kezilesu,Kezilesu Xiang,Kizilsu,K̩izilsu,Qizilsu,ke zi lei su,ke zi lei su xiang,Қызилсу,قىزىلسۇ,克孜勒苏,克孜勒苏乡', 39.6746700, 76.7399700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12514, 'Kezilei', 'Kezilei', 'Chia-tzu-erh,Hei-tzu-erh,Hei-tzu-erh-shih,K''a-shih-erh,K''o-shih-erh,K''o-shih-erh-shih,K''o-shih-ko-mu-pa-shih,Kezilei,Kezilei Xiang,Kizil,Kizil Bazar,Kizol-bazar,Kizyl-Bazar,Kizöl-bazar,K’a-shih-erh,K’o-shih-erh,K’o-shih-erh-shih,K’o-shih-ko-mu-pa-shih,Qizil Bazar,ke zi lei,ke zi lei xiang,克孜勒,克孜勒乡', 38.6512600, 76.4679100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12515, 'Kashgar', 'Kashgar', 'K''a-shih,K''o-shih,KHG,Kachgar,Kaixgar,Kaschgar,Kasgar,Kasgara,Kasgaras,Kash,Kashgar,Kashgar Kona Shahr,Kashgar Kone Shahr,Kashi,Kashi Shi,Kashkar,Kasjgar,Kaszgar,Kaxgar,Kaŝgar,Kaşgar,Kašgar,Kašgara,Kašgaras,Kona Shahr,K̩əxk̩ər,K’a-shih,K’o-shih,Qashqar,Qasqar,Qaşqar,Qeshqer,Shu-fu,Su-fu,ka shen,kasagara,kaseu si,kasgara,kashghr,kashqar,kashugaru,kashugaru shi,ke shen shi,Кашгар,Кашкар,Қәшқәр,Կաշգար,קאשגאר,قەشقەر,كاشغر,کاشغر,کاشقار,काश्गर,কাশগর,କାଶଗର,カシュガル,カシュガル市,喀什,喀什市,카스 시', 39.4706600, 75.9895100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12516, 'Karmar', 'Karmar', 'Karmar,Kuai''erma,Kuai''erma Xiang,Kuai’erma,Kuai’erma Xiang,kuai er ma,kuai er ma xiang,快尔玛,快尔玛乡', 37.3625000, 98.8361100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12517, 'Karmai', 'Karmai', 'Kamai,Kamai Xiang,Karmai,Tangmai,ka mai,ka mai xiang,tang mai,卡麦,卡麦乡,汤麦', 29.1351700, 89.4955000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12518, 'Kardoi', 'Kardoi', 'Gaxue,Kadui,Kadui Xiang,Kardoi,ga xue,ka dui,ka dui xiang,卡堆,卡堆乡,嘎学', 29.1233000, 89.5737500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12519, 'Kangxung', 'Kangxung', 'Kangxiong,Kangxiong Xiang,Kangxung,Qianggongba,kang xiong,kang xiong xiang,qiang gong ba,康雄,康雄乡,强贡巴', 29.2905900, 90.0823700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12520, 'Kangmar', 'Kangmar', 'K''ang-ma,Kangma,Kangma Zhen,Kangmar,Khang-ma,Khangmar,K’ang-ma,kang ma,kang ma zhen,康马,康马镇', 28.5595300, 89.6800900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12521, 'Kamru', 'Kamru', 'Baijia,Kamru,Kangru,Kangru Xiang,bai jia,kang ru,kang ru xiang,康如,康如乡,白加', 28.6223500, 89.4881500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12522, 'Kaiwen', 'Kaiwen', 'Jinjiang,Jinjiang Zhen,Kaiwen,jin jiang,jin jiang zhen,kai wen,开文,金江,金江镇', 27.1561000, 99.8348300, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12523, 'Tongpu', 'Tongpu', 'Kaiba,Tongpu,Tongpu Xiang,Zhonggaba,tong pu,tong pu xiang,zhong ga ba,中尕巴,铜普,铜普乡', 36.9833300, 98.5000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12524, 'Zongwulong', 'Zongwulong', 'Bayinhe,Jun Ul,Zongwulong,Zongwulong Xiang,ba yin he,zong wu long,zong wu long xiang,宗务隆,宗务隆乡,巴音河', 37.3845800, 97.3497300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12525, 'Jomda', 'Jomda', 'Chiang-ta,Chiang-ta-tsung,Jiangda,Jiangda Zhen,Jomda,jiang da,jiang da zhen,江达,江达镇', 31.4962000, 98.2117100, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12526, 'Jirmeng', 'Jirmeng', 'Ji''ermeng,Ji''ermeng Xiang,Jirmeng,Ji’ermeng,Ji’ermeng Xiang,ji er meng,ji er meng xiang,吉尔孟,吉尔孟乡', 37.1516700, 99.5694400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12527, 'Jiqu', 'Jiqu', 'Jiqu,Jiqu Xiang,Waihuka,ji qu,ji qu xiang,wai hu ka,吉曲,吉曲乡,外户卡', 31.9500000, 96.1166700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12528, 'Jinisai', 'Jinisai', 'Ji''nyinsib,Jinisai,Jinisai Xiang,Ji’nyinsib,Sacangtang,ji ni sai,ji ni sai xiang,sa cang tang,吉尼塞,吉尼塞乡,萨仓塘', 32.0665100, 96.0024900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12529, 'Jinta', 'Jinta', 'Ch''ing-t''a-ch''en,Chin-t''a,Chin-t''a-ch''eng,Chin-t''a-hsien,Chin-t’a,Chin-t’a-ch’êng,Chin-t’a-hsien,Chintachen'',Chintachen’,Ch’ing-t’a-ch’en,Jinta,Jinta Xian,Jinta Zhen,Kinta,Wang-tzu-chuang,jin ta,jin ta xian,jin ta zhen,金塔,金塔县,金塔镇', 39.9833300, 98.8666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12530, 'Jinhua', 'Jinhua', 'Chien-ch''uan,Chien-ch''uan-hsien,Chien-ch’uan,Chien-ch’uan-hsien,Jianchuan,Jinhua,Kienchwan-hsien,Kienchwanchow,jin hua,金华', 26.5380000, 99.9171500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12531, 'Jinfosi', 'Jinfosi', 'Ch''in-fo-chieh-p''ao-tzu,Chin-fo-ssu,Chinfodzepaodzo,Chinfodzepaodzö,Chinfoszepoatzu,Chintoszepaotzu,Ch’in-fo-chieh-p’ao-tzu,Jinfosi,Jinfosi Zhen,Kin-fo-ssi,jin fu si,jin fu si zhen,金佛寺,金佛寺镇', 39.4000000, 98.8166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12532, 'Jinding', 'Jinding', 'Jinding,jin ding,金顶', 26.4390300, 99.4406100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12533, 'Jiayuguan', 'Jiayuguan', 'Ch''ia-hsu-kuan,Chia-yu-kuan,Chia-yü-kuan,Chiayukwan,Ch’ia-hsu-kuan,Czjajujguan'',Ga-uk-guang,Gia Duc Quan,Gia Dục Quan,Gă-ṳ̆k-guăng,JGN,Jiayuguan,Jiayuguan Ceety,Jiayuguan City,Jiayuguan Lakanbalen,Ka-iok-koan-chhi,Ka-io̍k-koan-chhī,Kia-yu-kuan,Kiayukwan,Tia-jue-kuan,Tseyasyuyguan'',Tseyasyuyguan’,Yumen,jawigwan si,jia yu guan shi,jyaywgwan,Ťia-jü-kuan,Цзяюйгуань,Ցզյայույգուան,جائیوگوان شہر,جیایوگوآن,嘉峪关市,嘉峪関市,嘉峪關市,자위관 시', 39.8112100, 98.2861800, 'CN', '2014-08-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12534, 'Jiashi', 'Jiashi', 'Baren,Baren Zhen,Ch''ieh-shih-chen,Ch''ieh-shih-hsien,Chia-shih,Ch’ieh-shih-chen,Ch’ieh-shih-hsien,Fais-abad,Faizabad,Faizābād,Fayzabad,Jiashi,Jiashi Xian,P''ai-su-pa-t''e,Payzawat,Peyziwat,Pəyziwat,P’ai-su-pa-t’e,ba ren,ba ren zhen,ga shi,ga shi xian,Пәйзиват,پەيزىۋات,伽师,伽师县,巴仁,巴仁镇', 39.4955400, 76.7428200, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12535, 'Jianshe', 'Jianshe', 'Ciwada,Jianshe,Jianshe Xiang,ci wa da,jian she,jian she xiang,建设,建设乡,次哇达', 33.6833300, 99.4000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12536, 'Jangdam', 'Jangdam', 'Jangdam,Jiangdang,Jiangdang Xiang,Nongri,jiang dang,jiang dang xiang,nong ri,弄日,江当,江当乡', 29.3380100, 89.2461800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12537, 'Jamda', 'Jamda', 'Jamda,Jiangda,Jiangda Xiang,Pa''erchong,Pa’erchong,jiang da,jiang da xiang,pa er chong,帕尔冲,江达,江达乡', 31.4830000, 94.3864100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12538, 'Huashixia', 'Huashixia', 'Hua-shih-hsia,Huashixia,Huashixia Zhen,Zogainrawar,hua shi xia,hua shi xia zhen,花石峡,花石峡镇', 35.1166700, 98.8000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12539, 'Huanghe', 'Huanghe', 'Huanghe,Huanghe Xiang,Rejiang Kanduo,huang he,huang he xiang,re jiang kan duo,热江坎多,黄河,黄河乡', 34.5666700, 98.3166700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12540, 'Hotan', 'Hotan', 'Chotan,Ciudad de Jotan,Ciudad de Jotán,HTN,Hetian,Hetianshi Gujiang Bage Jiedao,Ho-t''ien,Ho-t''ien-chen,Ho-tien-hsien,Ho-t’ien,Ho-t’ien-chen,Hotan,Hotanas,Hoten,Hotən,Khotan,Xotan,Xoten,he tian,he tian shi,he tian shi gu jiang ba ge jie dao,heotyen si,hotan shi,khotana,khtn,Хотан,Хотән,ختن,خوتەن,خوتەن شەھىرى,ख़ोतान,ホータン市,和田,和田市,和田市古江巴格街道,허톈 시', 37.1075000, 79.9354800, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12541, 'Hongyazi', 'Hongyazi', 'Hongyazi,Hongyazi Xiang,hong ya zi,hong ya zi xiang,红崖子,红崖子乡', 39.1540700, 99.3018600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12542, 'Hongwansi', 'Hongwansi', 'Hongwan,Hongwansi,Hung-wan-ssu,Su-nan-yu-ku-tsu-tzu-chih-hsien,Su-nan-yü-ku-tsu-tzu-chih-hsien,Sunan,Sunan Yuguzu Zizhixian,hong wan si,su nan yu gu zu zi zhi xian,红湾寺,肃南裕固族自治县', 38.8351400, 99.5986500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12543, 'Gasi', 'Gasi', 'Gasi,Gasi Xiang,Hongliuquan,Hung-liu-ch''uan,Hung-liu-ch’üan,ga si,ga si xiang,hong liu quan,尕斯,尕斯乡,红柳泉', 38.1461000, 90.9051400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12544, 'Hoit Taria', 'Hoit Taria', 'Hoit Taria,Huai-t''ou-t''a-la,Huai-t’ou-t’a-la,Huaitoutala Zhen,huai tou ta la,huai tou ta la zhen,怀头他拉,怀头他拉镇', 37.3515500, 96.7497400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12545, 'Heka', 'Heka', 'Heka,Heka Zhen,Ho-k''a,Ho-k’a,he ka,he ka zhen,河卡,河卡镇', 35.8911600, 99.9886500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12546, 'Heiquan', 'Heiquan', 'Hei-ch''uan,Hei-ch’uan,Heiquan,Heiquan Xiang,hei quan,hei quan xiang,黑泉,黑泉乡', 39.5166700, 99.6166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12547, 'Heimahe', 'Heimahe', 'Hei-ma-ho,Heimahe,hei ma he,黑马河', 36.7289300, 99.7768400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12548, 'Gyobrag', 'Gyobrag', 'Gyobrag,Juela,Juela Xiang,Ningtanyong,jue la,jue la xiang,ning tan yong,宁滩永,觉拉,觉拉乡', 32.5671700, 96.1550800, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12549, 'Gyigang', 'Gyigang', 'Ch''a-yu,Chayu Xian,Chi-kung,Ch’a-yü,Gyigang,Jigong,Sang-ang-ch''u,Sang-ang-ch’ü,Zayu,Zayü,cha yu xian,ji gong,吉公,察隅县', 28.6666700, 97.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12550, 'Jindong', 'Jindong', 'Chi-mu-tsung,Chien-tung,Chin-tung,Dzhim,Gyemdong,Gyêmdong,Jindong,Jindong Xiang,Kyim,Kyim Dzong,Kyimdong,jin dong,jin dong xiang,金东,金东乡', 28.9705000, 93.3825900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12551, 'Jiangzi', 'Jiangzi', 'Chiang-tzu,Chiang-tzu-tsung,G''jangdze,Gyam-dze,Gyang-tse Jong,Gyangtse,Gyangze,Gyangzê,Gyantse,Jiangzi,Jiangzi Zhen,Kiangtze,jiang zi,jiang zi zhen,Гьянгдзе,江孜,江孜镇', 28.9202600, 89.5995600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12552, 'Gyangkar', 'Gyangkar', 'Chiang-ka,Dinggye,Dinggyê,Dingjie Xian,Gyangkar,Jiangga,Ting-chieh,ding jie xian,jiang ga,定结县,江嘎', 28.4000000, 87.8000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12553, 'Gyamotang', 'Gyamotang', 'Denchen,Denchin,Dengqen,Dingqing Xian,Dêngqên,Gyamotang,Jiamotang,Te-ch''ing,Te-chin,Te-ch’ing,Ting-ch''ing,Ting-ch''ing-chen,Ting-ch''ing-tsung,Ting-ch’ing,Ting-ch’ing-chen,Ting-ch’ing-tsung,ding qing xian,jia mo tang,丁青县,加莫塘', 31.5333300, 95.4333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12554, 'Gyamco', 'Gyamco', 'Gyamco,Jiacuo,Jiacuo Xiang,jia cuo,jia cuo xiang,甲错,甲错乡', 29.8466500, 89.1863500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12555, 'Gyairong', 'Gyairong', 'Ganie,Gyairong,Jielong,Jielong Xiang,Longbao,Longbao Zhen,ga nie,jie long,jie long xiang,long bao,long bao zhen,尕涅,结隆,结隆乡,隆宝,隆宝镇', 33.2701600, 96.4221400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12556, 'Golug', 'Golug', 'Golug,Gulu,Gulu Zhen,Tangwulongba,gu lu,gu lu zhen,tang wu long ba,古露,古露镇,唐屋隆巴', 30.8295600, 91.6206000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12557, 'Golmud', 'Golmud', 'A-erh-t''un-ch''u-k''o-chung-hsin-ch''u,A-erh-tun-ch''u-k''o-ha-sa-k''o-tsu-tzu-chih-ch''u,A-erh-tun-ch’ü-k’o-ha-sa-k’o-tsu-tzu-chih-ch’ü,A-erh-t’un-ch’ü-k’o-chung-hsin-ch’ü,GOQ,Ge''ermu,Ge''ermu Zhen,Ge’ermu,Ge’ermu Zhen,Golmo,Golmu,Golmud,Golmud Shi,Ka-erh-mu,Karmu,Ke Erh Mu,Ko-erh-mu,Ko-erh-mu-shih,ge er mu,ge er mu shi,ge er mu zhen,geoeolmu si,golamuda,gorumudo,gorumudo shi,Голмуд,गोलमुद,ゴルムド,ゴルムド市,格尔木,格尔木市,格尔木镇,거얼무 시', 36.4067200, 94.9006100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12558, 'Gengqing', 'Gengqing', 'Dege Gonchen,Deqe,Derge,Dêqê,Gengqing,Gengqing Zhen,Goinqen,Goinqên,Te-hua,Te-ke,Te-ko,Te-ko-hsien,Tehko,Teko Kengching,Tenko,geng qing,geng qing zhen,更庆,更庆镇', 31.8164900, 98.5957900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12559, 'Gengma', 'Gengma', 'Gengma,Keng-ma,Keng-ma-hsuan-fu-ssu,Keng-ma-she-chih-chu,Keng-ma-she-chih-chü,Keng-ma-t''ai-tsu-k''a-wa-tsu-tzu-chih-hsien,Keng-ma-t''ai-tsu-wa-tsu-tzu-chih-hsien,Keng-ma-t’ai-tsu-k’a-wa-tsu-tzu-chih-hsien,Keng-ma-t’ai-tsu-wa-tsu-tzu-chih-hsien,geng ma,耿马', 23.5232500, 99.3786000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12560, 'Jiding', 'Jiding', 'Geding,Gêding,Hsieh-t''ung-men,Hsieh-t’ung-men,Jiding,K''a-lu,K''o-la,Kara,Karu,K’a-lu,K’o-la,Setunmyn'',Setunmyn’,Thongmon,Xaitongmoin,Xietongmen Xian,ji ding,xie tong men xian,吉丁,谢通门县', 29.3666700, 88.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12561, 'Gaxung', 'Gaxung', 'Chatang,Gaxung,Gayang,Gayong,Gayong Xiang,cha tang,ga yang,ga yong,ga yong xiang,尕涌,尕涌乡,尕羊,茶塘', 32.0667200, 95.6569100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12562, 'Gar', 'Gar', 'Ga''er,Gar,Garxincun,Ga’er,K''un-sa,Ka-erh,Ka-erh-k''un-sha,Ka-erh-k’un-sha,K’un-sa,ga er,噶尔', 32.1194100, 80.0561000, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12563, 'Gartog', 'Gartog', 'Chiang-ch''ia,Chiang-ch’ia,Chiang-k''a,Chiang-k''a-tsung,Chiang-k’a,Chiang-k’a-tsung,Gartog,Gatuo,Gatuo Zhen,Ka-t''o,Ka-t’o,Mang-k''ang,Mang-k’ang,Mangkang Xian,Markam,Markham,Ning-ching,Ning-ching-hsien,Ningtsin,ga tuo,ga tuo zhen,mang kang xian,嘎托,嘎托镇,芒康县', 29.6845100, 98.5947300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12564, 'Gaotai Chengguanzhen', 'Gaotai Chengguanzhen', 'Gaotai,Gaotai Chengguanzhen,Gaotai Xian,Gaotaizhan,Gaotay,Kao-t''ai,Kao-t''ai-hsien,Kao-t’ai,Kao-t’ai-hsien,gao tai cheng guan zhen,gao tai xian,高台县,高台城关镇', 39.3445600, 99.8001500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12565, 'Kambaxoi', 'Kambaxoi', 'Gamba,Gambaxoi,Gangba Xian,Gangbaxue,K''ang-pa-tsung,Ka-mu-pa-tsung,Kambaxoi,Kampa Dzong,Kang-ma,Kang-ma-tsung,Kang-pa,Kang-pa-hsueh,Kang-pa-hsüeh,Khamba,Khamba Dzong,K’ang-pa-tsung,gang ba xian,gang ba xue,岗巴县,岗巴学', 28.3000000, 88.5333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12566, 'Gala', 'Gala', 'Gala,Gala Xiang,Galaxia,K''a-la,K''a-la-sa,K''a-la-sha,K''a-la-sha-erh,K''ai-la,Kalashar,Kalbashar,K’a-la,K’a-la-sa,K’a-la-sha,K’a-la-sha-erh,K’ai-la,ga la,ga la xia,ga la xiang,嘎拉,嘎拉乡,嘎拉夏', 28.2631100, 89.3818700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12567, 'Gahe', 'Gahe', 'Gahe,Gahe Xiang,Ka-ho,Ya-ho,ga he,ga he xiang,尕河,尕河乡', 38.8000000, 97.6333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12568, 'Gadong', 'Gadong', 'Gadong,Gadong Xiang,ga dong,ga dong xiang,嘎东,嘎东乡', 29.2127300, 89.1783500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12569, 'Nansan', 'Nansan', 'Chen-k''ang,Chen-k’ang,Feng-wei-pa,Fengwei,Fengweiba,Nansan,Zhenkang,nan san,南伞', 23.7957500, 98.8039700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12570, 'Fengshan', 'Fengshan', 'Feng-ch''ing,Feng-ch’ing,Feng-shan-chen,Fengqing,Fengshan,Shun-ning,Shun-ning-ch''eng,Shun-ning-ch’eng,Shun-ning-hsien,Shunningfu,feng shan,凤山', 24.5833300, 99.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12571, 'Dongxi', 'Dongxi', 'Dongxe,Dongxi,Dongxi Xiang,Dongxê,Qiangri,Te-ch''ing,Te-ch’ing,dong xi,dong xi xiang,qiang ri,东喜,东喜乡,强日', 28.6492100, 89.1198800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12572, 'Dongdong', 'Dongdong', 'Dongdong,Dongdong Xiang,dong dong,dong dong xiang,东洞,东洞乡', 39.5000000, 98.6666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12573, 'Domba', 'Domba', 'Domba,Dongba,Dongba Xiang,Lugouka,Tung-pa,dong ba,dong ba xiang,lu gou ka,东坝,东坝乡,芦沟卡', 32.3112100, 95.5846400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12574, 'Domartang', 'Domartang', 'Banbar,Bianba Xian,Domartang,Dongmatong,Pem Bar,Pemba-gompa,Pembar Gompa,Pembar Gömpa,Pien-pa,Pien-pa-ssu,Pien-pa-tsung,bian ba xian,dong ma tong,东马通,边坝县', 30.9390200, 94.6890800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12575, 'Duocai', 'Duocai', 'Doice,Doicê,Duocai,Duocai Xiang,Saimoyong,duo cai,duo cai xiang,sai mo yong,多采,多采乡,赛莫涌', 33.8103400, 95.4212700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12576, 'Dobjoi', 'Dobjoi', 'Dobjoi,Duojiao,Duojiao Xiang,duo jiao,duo jiao xiang,多角,多角乡', 29.5333100, 89.0605400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12577, 'Deqing', 'Deqing', 'Deqen,Deqing,Deqing Zhen,Dêqên,Guo''ermai,Guo’ermai,de qing,de qing zhen,guo er mai,德庆,德庆镇,果尔麦', 30.5280300, 90.1257200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12578, 'Dêqên', 'Deqen', 'Dechen,Deqing,de qing,Дечен,བདེ་ཆེན,德庆', 29.9617800, 90.7187500, 'CN', '2011-02-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12579, 'Delingha', 'Delingha', 'Delhi,Delingha,Délìnghā,HXD,de ling ha,德令哈', 37.3760000, 97.3745700, 'CN', '2013-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12580, 'Dedang', 'Dedang', 'Chen-k''ang,Chen-k’ang,Dedang,Te-tang,Te-tang-chen,Yongde,Yung-te,de dang,德党', 24.0118000, 99.2396400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12581, 'Dartang', 'Dartang', 'Baqen,Baqing Xian,Baqên,Da''ertang,Dartang,Da’ertang,Pa-ch''ing,Pa-ch’ing,Ta-erh-t''ang,Ta-erh-t’ang,ba qing xian,da er tang,巴青县,达尔塘', 31.9333300, 94.0000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12582, 'Daqian', 'Daqian', 'Daqen,Daqian,Daqian Zhen,Daqên,da qian,da qian zhen,大前,达前镇', 31.7469700, 92.7518300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12583, 'Da Qaidam', 'Da Qaidam', 'Da Qaidam,Da Qaidamzhen,Dachaidan,Dachaidan Xingwei,Dachaidan Zhen,I-k''o-ch''ai-ta-mu,I-ka-ch''ai-ta-mu,I-ka-ch’ai-ta-mu,I-k’o-ch’ai-ta-mu,Ihe Tsaydam,Ike Tsaidam,Ta Tsaidam,Ta-ch''ai-tan,Ta-ch''ai-tan-chen,Ta-ch''ai-tan-shih,Ta-ch’ai-tan,Ta-ch’ai-tan-chen,Ta-ch’ai-tan-shih,Tatsaitan,da chai dan,da chai dan xing wei,da chai dan zhen,大柴旦,大柴旦行委,大柴旦镇', 37.8333300, 95.3000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12584, 'Dangchengwan', 'Dangchengwan', 'Dangchengwan,Dangchengwan Zhen,Su-pei,Su-pei-meng-tsu-tzu-chih-hsien,Subei,Subei Mengguzu Zizhixian,Subey,Tang-ch''eng-wan,Tang-ch’eng-wan,dang cheng wan,dang cheng wan zhen,su bei meng gu zi zhi xian,党城湾,党城湾镇,肃北蒙古自治县', 39.5001100, 95.0408100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12585, 'Dagur', 'Dagur', 'Dagele,Dagele Xiang,Dagur,Ta-ko-le,da ge lei,da ge lei xiang,大格勒,大格勒乡', 36.4166700, 95.7333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12586, 'Chongdui', 'Chongdui', 'Ch''ung-tui,Chongdui,Ch’ung-tui,Congdu,Congdü,Kuti,Nieh-la-mu,Nielamu Xian,Nyalam,Nyalam Dzong,Nyelam,Nyenam,chong dui,nie la mu xian,充堆,聂拉木县', 28.1500000, 85.9666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12587, 'Coka', 'Coka', 'Caoka,Caoka Zhen,Coka,Coka Zhen,Guochitang,cao ka,cao ka zhen,guo chi tang,草卡,草卡镇,郭赤塘', 30.9054000, 94.6695000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12588, 'Codoi', 'Codoi', 'Calong,Codoi,Cuoduo,Cuoduo Xiang,ca long,cuo duo,cuo duo xiang,措多,擦隆,错多乡', 30.4805900, 92.4222800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12589, 'Cikai', 'Cikai', 'Cikai,Gongshan,Kung-shan,Kung-shan-tu-lung-tsu-nu-tsu-tzu-chih-hsien,Tz''u-k''ai,Tz’u-k’ai,ci kai,茨开', 27.7634400, 98.7110500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12590, 'Youdian', 'Youdian', 'Changning,Youdian,Yu-tien,Yu-tien-hsien-tso,you dian,右甸', 24.8289400, 99.5923200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12591, 'Changma', 'Changma', 'Ch''ang-ma-pao,Ch''ang-ma-pao-tzu,Ch''ang-ma-ying-tzu,Ch''ing-ma,Changma,Changma Xiang,Chinma,Ch’ang-ma-pao,Ch’ang-ma-pao-tzu,Ch’ang-ma-ying-tzu,Ch’ing-ma,Ha-min,Ha-min-kuan-li-chu,Ha-min-kuan-li-chü,chang ma,chang ma xiang,昌马,昌马乡', 39.8666700, 96.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12592, 'Burang', 'Burang', 'Burang,Durang,Jirang Juweihui,K''o-la-k''o-t''e,K’o-la-k’o-t’e,P''u-lan,P''u-lan-tsung,Pulan,Pulan Xian,Purang,P’u-lan,P’u-lan-tsung,T''a-k''o-la-k''o-t''e,Taklakhar,Taklakot,T’a-k’o-la-k’o-t’e,ji rang ju wei hui,pu lan,pu lan xian,Буранг,吉让居委会,普兰,普兰县', 30.2955900, 81.1751100, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12593, 'Baoji', 'Baoji', 'Baoji,Baoji Xiang,Boqe,Boqê,Jiaburi,bao ji,bao ji xiang,jia bu ri,保吉,保吉乡,甲布日', 30.9941100, 90.1818300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12594, 'Molo', 'Molo', 'Gonjo,Kung-chiao,Mo-lo,Molo,Molo Zhen,Moluo,mo luo,mo luo zhen,莫洛,莫落镇', 30.8600400, 98.2729700, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12595, 'Qiezha', 'Qiezha', 'Baiza,Beca,Bêca,Kama,Qiezha,Qiezha Xiang,bai zha,ka ma,qie zha,qie zha xiang,卡麻,白扎,癿扎,癿扎乡', 32.0751200, 96.5144700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12596, 'Baiba', 'Baiba', 'Baiba,Baiba Zhen,Beba,Bêba,bai ba,bai ba zhen,百巴,百巴镇', 29.7992300, 93.8524100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12597, 'Bayi', 'Bayi', 'Bayi,Bayizhen,ba yi,ba yi zhen,八一,八一镇', 29.6581200, 94.3589200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12598, 'Barun', 'Barun', 'Balong,Balong Xiang,Barun,Yike Gaoli,ba long,ba long xiang,yi ke gao li,伊克高里,巴隆,巴隆乡', 35.9290700, 97.4157500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12599, 'Baohe', 'Baohe', 'Baohe,Wei-hsi,Wei-hsi-hsien,Weisi-hsien,Weixi,bao he,保和', 27.1958200, 99.3248300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12600, 'Banbar', 'Banbar', 'Banbar,Bianba,Bianba Zhen,Xialin,bian ba,bian ba zhen,xia lin,下林,边坝,边坝镇', 30.8319800, 94.8367500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12601, 'Baitang', 'Baitang', 'Baitang,Batang,Batang Xiang,Pa-t''ang,Pa-t’ang,Tielijiao,ba tang,ba tang xiang,tie li jiao,巴塘,巴塘乡,铁力角', 32.8242700, 97.1545900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12602, 'Baima', 'Baima', 'Baima,Baima Zhen,Basu Xian,Pa-hsiu,Pa-su,Pai-ma,ba su xian,bai ma,bai ma zhen,八宿县,白玛,白玛镇', 30.0575200, 96.9185200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12603, 'Bagan', 'Bagan', 'Bagan,Bagan Xiang,Pa-kan,ba gan,ba gan xiang,巴干,巴干乡', 33.8978300, 96.5214100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12604, 'Aqqan', 'Aqqan', 'A-ch''i-ch''iang,A-ch''i-wen,A-ch''iang,A-ch’i-ch’iang,A-ch’i-wen,A-ch’iang,A-t''e-ch''iang,A-t’e-ch’iang,Achan,Achchan,Aqiang,Aqiang Xiang,Aqqan,Atchan,Atqan,a qiang,a qiang xiang,yatchan,Атчан,ئاتچان,阿羌,阿羌乡', 36.4666700, 81.9666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12605, 'Arza', 'Arza', 'Arza,Azha,Azha Zhen,a zha,a zha zhen,阿扎,阿扎镇', 30.6453600, 93.2429700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12606, 'Aqqan', 'Aqqan', 'Achchan,Aqiang,Aqiang Xiang,Aqqan,a qiang,a qiang xiang,yachchan,Аччан,ئاچچان,阿羌,阿羌乡', 37.3000000, 85.5000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12607, 'Yilkiqi', 'Yilkiqi', 'Yilkiqi,Yilkiqi Xiang,Yilk̩iqi,Yilqichi,yi li ke qi,yi li ke qi xiang,yylqychy,Йилқычи,يىلقىچى,依力克其,依力克其乡', 37.9611100, 77.2491700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12608, 'Layka', 'Layka', 'Layika,Layike Xiang,Layka,Layka Xiang,Layk̩a,Layqa,la yi ka,la yi ka xiang,layqa,Лайқа,لايقا,拉依喀,拉依喀乡', 37.0769400, 79.7316700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12609, 'Xambabazar', 'Xambabazar', 'Shenbebazar,Xambabazar,Xambabazar Zhen,Xianbai Bazha,Xianbai Bazha Zhen,Xənbəbazar,xian bai ba zha,xian bai ba zha zhen,Шәнбәбазар,شەنبەبازار,先拜巴扎,先拜巴扎镇', 36.8863900, 81.5097200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12610, 'Rokiya', 'Rokiya', 'Rokiya,Rokiya Xiang,Rok̩iyə,Roqiye,Ruokeya,Ruokeya Xiang,ruo ke ya,ruo ke ya xiang,Роқыя,روقىيە,若克雅,若克雅乡', 37.0786100, 82.8152800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12611, 'Aqqik', 'Aqqik', 'A-ch''i-k''o,A-ch’i-k’o,Achchiq,Aqike,Aqike Xiang,Aqqik,Aqqik̩,a qi ke,a qi ke xiang,yachchyq,Аччық,ئاچچىق,阿其克,阿其克乡', 39.1261900, 76.5733700, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12612, 'Damiku', 'Damiku', 'Damagou,Damagou Xiang,Damiku,Ta-mu-kou,da ma gou,da ma gou xiang,Дамику,دامىكۇ,达玛沟,达玛沟乡', 36.9786100, 81.0941700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12613, 'Zhaosu', 'Zhaosu', 'Chao-su,Chao-su-ch''eng,Chao-su-ch’eng,Chao-su-hsien,Kalmak-kure,Kalmuk Kuree,Kalmuk Küree,Mongghulkure,Mongghulküre,Monggolkure,Monggolküre,Mongƣulkürə,Zhaosu,Zhaosu Xian,zhao su,zhao su xian,Моңғулкүрә,موڭغۇلكۈرە,昭苏,昭苏县', 43.1227800, 81.0758300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12614, 'Yumen', 'Yumen', 'Yu-men,Yu-men-chen,Yu-men-hsien,Yumen,Yumen Shi,Yumen Zhen,Yü-men,Yü-men-chen,Yü-men-hsien,yu men,yu men shi,yu men zhen,玉门,玉门市,玉门镇', 40.2833300, 97.2000000, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12615, 'Yuli', 'Yuli', 'Ha-la-k''u-mu,Ha-la-k''u-mu-hsin-ch''eng,Ha-la-k’u-mu,Ha-la-k’u-mu-hsin-ch’eng,Hsin-p''ing,Hsin-p’ing,K''ung-ch''i,Kara-kum,Kara-kum Yangi-shahr,Konche,K’ung-ch’i,Lopnur,Qaraqum,Sinping,Wei-li,Wei-li-hsien,Yangi-shar,Yu-li-hsien,Yuli,Yuli Xian,Yü-li-hsien,wei li,wei li xian,wei li zhen,尉犁,尉犁县,尉犁镇', 41.3366200, 86.2567500, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12616, 'Yuanquan', 'Yuanquan', 'An-hsi,An-hsi-hsien,Ansi,Ansi Xian,Anxi,Anxi Xian,Guazhou Xian,Xincheng,Yuanquan,Yuanquan Zhen,an xi xian,gua zhou xian,yuan quan,yuan quan zhen,安西县,渊泉,渊泉镇,瓜州县', 40.5000000, 95.8000000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12617, 'Yiwu', 'Yiwu', 'A-t''u-lu-k''o,A-t’u-lu-k’o,Araturuk,Aratürük,Aturuk,Aturyuk,Atürük,I-wu,I-wu-ch''eng,I-wu-ch’eng,I-wu-hsien,T''u-hu-lu,T’u-hu-lu,Yiwu,yi wu,Аратүрүк,ئاراتۈرۈك,伊吾', 43.2491800, 94.6943000, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12618, 'Yining', 'Yining', 'Ghulja,Gulja,I-li,I-ning,I-ning-hsien,I-ning-shih,Kaldja,Khouldja,Kol''dzhat,Kol’dzhat,Kuldja,Kuldscha,Kuldzha,Kulja,Ning-yuan,Ning-yuen,Ning-yüan,Ningyuanhsien,Qulja,YIN,Yining,Yining Xian,yi ning,yi ning xian,Ƣulja,Ғулҗа,غۇلجا,伊宁,伊宁县', 43.9779900, 81.5180400, 'CN', '2013-06-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12619, 'Yengiawat', 'Yengiawat', 'Yengiawat,Ying''awati,Ying''awati Xiang,Ying’awati,Ying’awati Xiang,Yéngiawat,ying a wa ti,ying a wa ti xiang,Еңиават,يېڭىئاۋات,英阿瓦提,英阿瓦提乡', 41.3525000, 79.4686100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12620, 'Yanqi', 'Yanqi', 'Ha-la-sha-erh,K''a-la-sha-erh,K''o-la-sha-erh,Kara-schahr,Karachahr,Karashahr,Karashar,Khara Shar,Kurashar'',Kurashar’,K̩araxəh̨ər,K’a-la-sha-erh,K’o-la-sha-erh,Qara Shahr,Qarasheher,Yan''tsy,Yanqi,Yanqi Zhen,Yan’tsy,Yen-ch''i,Yen-ch''i-chen,Yen-ch''i-hsien,Yen-ch''i-hui-tsu-tzu-chih-ch''u,Yen-ch''i-hui-tsu-tzu-chih-hsien,Yen-ch’i,Yen-ch’i-chen,Yen-ch’i-hsien,Yen-ch’i-hui-tsu-tzu-chih-ch’ü,Yen-ch’i-hui-tsu-tzu-chih-hsien,Yenki,Yinki,yan qi,yan qi zhen,Қарашәһәр,قاراشەھەر,焉耆,焉耆镇', 42.0620400, 86.5663200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12621, 'Yangjiaqiao', 'Yangjiaqiao', 'Yangjiaqiao,Yangjiaqiao Xiang,yang jia qiao,yang jia qiao xiang,杨家桥,杨家桥乡', 40.1260700, 94.6638300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12622, 'Xirikxiy', 'Xirikxiy', 'Qie''erkeqi,Qie''erkeqi Xiang,Qie’erkeqi,Qie’erkeqi Xiang,Xirikxiy,qie er ke qi,qie er ke qi xiang,shyrykshy avyly,shyrykshyy yېzysy,شىرىكشىي يېزىسى,شىرىكشي اۋىلى,切尔克齐,切尔克齐乡', 47.3557400, 88.0178500, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12623, 'Xinhe', 'Xinhe', 'Do Shamba Bazar,Du-shamba-bazar,Du-shamba-bāzār,Dushamba,Hsin-ho,Hsin-ho-chen,Toksu,Tok̩su,Toqsu,Tu-san-mu-pa-shih,Tu-san-pa Shih,Xinhe,Xinhe Xian,xin he,xin he xian,Тоқсу,توقسۇ,新和,新和县', 41.5502800, 82.6166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12624, 'Xihu', 'Xihu', 'Xihu,Xihu Xiang,xi hu,xi hu xiang,西湖,西湖乡', 40.5385000, 94.9905900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12625, 'Xidi', 'Xidi', 'Hsi-ti,Hsi-ti-chuang,Sidi,Xidi,Xidi Zhen,xi de,xi de zhen,西地,西地镇', 44.0659300, 89.7385600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12626, 'Xiaxihao', 'Xiaxihao', 'Xiaxihao,Xiaxihao Xiang,xia xi hao,xia xi hao xiang,下西号,下西号乡', 40.3187800, 97.1176300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12627, 'Xiaoguai', 'Xiaoguai', 'Chugoy,Hsiao-k''uai,Hsiao-k’uai,Segoy,Xiaoguai,Xiaoguai Xiang,xiao guai,xiao guai xiang,小拐,小拐乡', 45.1285000, 85.0445700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12628, 'Xemirxek', 'Xemirxek', 'Qiemu''erqieke,Qiemu''erqieke Xiang,Qiemu’erqieke,Qiemu’erqieke Xiang,Xemirxek,qie mu er qie ke,qie mu er qie ke xiang,shەmyrshەk avyly,shەmyrshەk yېzysy,شەمىرشەك اۋىلى,شەمىرشەك يېزىسى,切木尔切克,切木尔切克乡', 47.7962300, 87.9663000, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12629, 'Xazgat', 'Xazgat', 'Xazgat,Xiazigai,Xiazigai Xiang,xia zi gai,xia zi gai xiang,夏孜盖,夏孜盖乡', 46.3434000, 86.2345600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12630, 'Xayar', 'Xayar', 'Chahyar,Schahjar,Sha Yar,Sha-ya,Sha-ya-chen,Sha-ya-hsien,Shahyar,Shajar,Shakh-yar,Shaya,Shaya Xian,Shayar,Shor-Yar,Xayar,sha ya,sha ya xian,shayar,Шаяр,شايار,沙雅,沙雅县', 41.2300000, 82.8058300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12631, 'Wushi', 'Wushi', 'Outch-tourfan,Uch Turfan,Uch-Tuifan,Uchturpan,Uqturpan,Ush-Turfan,Ushi,Utsch-Turfan,Wu-chih,Wu-shih,Wu-shih-chen,Wu-shih-hsien,Wu-shih-t''u-lu-fan,Wu-shih-t’u-lu-fan,Wushi,Wushi Xian,wu shen,wu shen xian,Учтурпан,ئۇچتۇرپان,乌什,乌什县', 41.1516700, 79.2250000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12632, 'Wujiaqu', 'Wujiaqu', 'Wujiaqu,Wujiaqu Shi,wu jia qu,wu jia qu shi,五家渠,五家渠市', 44.1696300, 87.5349700, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12633, 'Wudun', 'Wudun', 'Wudun,Wudun Xiang,wu dun,wu dun xiang,五墩,五墩乡', 40.1695100, 94.8053500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12634, 'Wensu', 'Wensu', 'A-k''o-su,A-k''o-su-chiu-ch''eng,A-k''o-su-lao-ch''eng,A-k’o-su,A-k’o-su-chiu-ch’eng,A-k’o-su-lao-ch’eng,Agsu,Ak Su Kona Shahr,Akoso,Aksou,Aksu,Aksu Old City,Aqsu,Aqsu Kona Shahr,Aqsu Old City,Kona Shahr,Old Aksu,Onsu,Wen-su-hsien,Wen-su-lao-ch''eng,Wen-su-lao-ch’eng,Wensu,Wensu Xian,Wensuh,Wensuh-lao-ch''eng,Wensuh-lao-ch’eng,wen su,wen su xian,Онсу,ئونسۇ,温宿,温宿县', 41.2719600, 80.2408500, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12635, 'Usu', 'Usu', 'Hsi-hu,K''u-erh-k''o-la-wu-su,Kweitun,K’u-erh-k’o-la-wu-su,Lao-hsi-hu,Shikho,Shikhu,Shixu,Usu,Wu-su,Wu-su-chen,Wu-su-hsien,Wusu,Wusu Shi,Xihu,wu su,wu su shi,Шиху,شىخۇ,乌苏,乌苏市', 44.4310500, 84.6762300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12636, 'Ürümqi', 'UEruemqi', 'Dikhua,OEremce,Ouroumtchi,Ouroumtsi,Ti-hua,Ti-hua-ch''eng,Ti-hua-ch’eng,Ti-hua-hsien,Ti-hua-shih,Tihwa,Tihwafu,Tikhua,Tikhva,UEruemchi-su,UEruemcsi,UEruemqi,UEruemqi-chhi,URC,Urumchi,Urumci,Urumcio,Urumcis,Urumczi,Urumptsi,Urumqi,Urumqi Shi,Urumtschi,Urumtsi,Urumutsi,Urumçi,Urumĉio,Urumči,Urumčis,Urunchi,Wu-lu-mu-ch''i,Wu-lu-mu-ch''i-shih,Wu-lu-mu-ch’i,Wu-lu-mu-ch’i-shih,Wulumuqi,Wurumch''ih,Wurumch’ih,arwmchy,awrwmchy,awrwmtshy,ulumuchi si,urumaci,urumaki,urumchi,urumucci,urumuchi,urumuchi shi,wu lu mu qi,wu lu mu qi shi,xu rum chi,Öremçe,Ürümchi,Ürümchi-sṳ,Ürümcsi,Ürümqi,Ürümqi Shi,Ürümqi-chhī,Ουρούμτσι,Урумчи,Урумчі,Урумћи,Үрімжі,Үрүмчи,Үрүмчү,Өрөмч хот,Ուրումչի,אורומצי,أورومتشي,ئۈرۈمچى,ئۈرۈمچى شەھىرى,ئۈرۈمچی,ارومچی,اورومچی,उरुमची,उरुम्छी,ਉਰੂਮਕੀ,உருமுச்சி,อุรุมชี,ཨུ་རུམ་ཆི་གྲོང་ཁྱེར།,ウルムチ,ウルムチ市,乌鲁木齐,乌鲁木齐市,烏魯木齊,烏魯木齊市,우루무치 시', 43.8009600, 87.6004600, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12637, 'Urho', 'Urho', 'Uer-ho,Urho,Wu''erhe,Wu''erhe Qu,Wu''erhe Xiang,Wu-er-ho,Wu-ho,Wu’erhe,Wu’erhe Qu,Wu’erhe Xiang,wu er he,wu er he qu,wu er he xiang,乌尔禾,乌尔禾乡,乌尔禾区', 46.1165100, 85.6776900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12638, 'Turpan', 'Turpan', 'Gorad Turfan,Lukchun,T''u-lu-fan,T''u-lu-fan-chen,T''u-lu-fan-hsien,T''urfang,TLQ,Tourfan,Tufan,Tulupan,Tulupan Xian,Turfan,Turfán,Turpan,T’u-lu-fan,T’u-lu-fan-chen,T’u-lu-fan-hsien,T’urfang,torufan shi,tu lu fan,tu lu fan shi,tu lu fan xian,tulupan si,Горад Турфан,Турпан,Турфан,تۇرپان,トルファン市,吐鲁番,吐鲁番县,吐鲁番市,투루판 시', 42.9476900, 89.1788600, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12639, 'Tumxuk', 'Tumxuk', 'T''u-mu-hsiu-k''o,Tumshuq,Tumuxiuke,Tumuxiuke Zhen,Tumxuk,Tumxuk̩,T’u-mu-hsiu-k’o,tu mu xiu ke,tu mu xiu ke zhen,Тумшуқ,تۇمشۇق,吐木秀克,吐木秀克镇', 41.3686100, 79.9627800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12640, 'Tost', 'Tost', 'Tost,Tuositie,Tuositie Xiang,tuo si tie,tuo si tie xiang,twst,Тост,توست,托斯铁,托斯铁乡', 47.2742800, 86.1279400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12641, 'Toli', 'Toli', 'Mapan,Mopan,Mopan Post,Piket Mopan,T''o-li-ch''eng,T''o-li-i,Thul,Toli,Tolu,Tuoli,Tuoli Zhen,T’o-li-ch’eng,T’o-li-i,tuo li,tuo li zhen,twly,Толи,تولى,托里,托里镇', 45.9385900, 83.6005600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12642, 'Toksun', 'Toksun', 'T''o-k''o-hsun,T''o-k''o-hsun-ch''eng,T''o-k''o-hsun-hsien,T''o-k''o-hsun-she-chih-chu,Tokosun,Toksoun,Toksun,Tok̩sun,Toqsun,Tuokexun,Tuokexun Xian,T’o-k’o-hsün,T’o-k’o-hsün-ch’eng,T’o-k’o-hsün-hsien,T’o-k’o-hsün-she-chih-chü,tuo ke xun,tuo ke xun xian,Тоқсун,توقسۇن,托克逊,托克逊县', 42.7935900, 88.6416300, 'CN', '2014-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12643, 'Todok', 'Todok', 'T''o-t''o,Todok,Tuotuo,Tuotuo Xiang,T’o-t’o,tuo tuo,tuo tuo xiang,托托,托托乡', 44.5453700, 83.5727800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12644, 'Tiechanggou', 'Tiechanggou', 'Tiechanggou,Tiechanggou Zhen,tie chang gou,tie chang gou zhen,铁厂沟,铁厂沟镇', 46.1666900, 84.4283400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12645, 'Temeke', 'Temeke', 'Temeke,Tiemaike,Tiemaike Xiang,Téméké,tie mai ke,tie mai ke xiang,Темеке,تېمېكې,铁买克,铁买克乡', 47.2224400, 89.7427600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12646, 'Tekes', 'Tekes', 'Kobo,T''e-k''o-ssu,T''e-k''o-ssu-chen,Te-k''o-ssu-hsien,Te-k’o-ssu-hsien,Tekes,Tekes Xian,Tekesi,Tekəs,Tékes,T’e-k’o-ssu,T’e-k’o-ssu-chen,te ke si,te ke si xian,Текәс,تېكەس,特克斯,特克斯县', 43.2166900, 81.8397300, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12647, 'Tashi', 'Tashi', 'T''a-shih,T''a-shih-ying,Tashi,Tashi Xiang,T’a-shih,T’a-shih-ying,ta shi,ta shi xiang,踏实,踏实乡', 40.2626100, 95.9802100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12648, 'Tacheng', 'Tacheng', 'Ch''ukuchak,Chochek,Chuguchak,Chuguchalk,Chuguchuk,Chöchek,Ch’ukuchak,Qoqek,Qɵqək,T''a-ch''eng-chen,T''a-ch''eng-hsien,T''a-erh-pa-ha,T''a-erh-pa-ha-t''ai,TCG,Tachen,Tacheng,Tacheng Xiang,Tachzn,Tahcheng,Tancheng,Tarbagatai,Tchougoutchak,Tchuruchak,T’a-ch’eng-chen,T’a-ch’eng-hsien,T’a-erh-pa-ha,T’a-erh-pa-ha-t’ai,ta cheng,ta cheng xiang,Чөчәк,چۆچەك,塔城,塔城乡', 46.7453500, 82.9584700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12649, 'Sikeshu', 'Sikeshu', 'Si-ga-shu,Sikeshu,Sikeshu Zhen,Ssu-k''o-shu,Ssu-kuo-shu,Ssu-k’o-shu,Sy-k''o-shu,Sy-k’o-shu,Sze-ko-shu,si ke shu,si ke shu zhen,四棵树,四棵树镇', 44.3731300, 84.2260000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12650, 'Shihezi', 'Shihezi', 'SHF,Shih-ho-tzu,Shih-yen-tzu,Shihezi,Shihezi Xiang,Shikhedze,Shikhedzy,Shikhehczy,Shixenze,Xihənzə,seuheojeu,shi he zi,shi he zi shi,shi he zi xiang,Шихэцзы,Шихәнзә,شىخەنزە,شىخەنزە شەھرى,شىخەنزە شەھىرى,石河子,石河子乡,石河子市,스허즈', 44.3023000, 86.0369400, 'CN', '2017-06-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12651, 'Shanshan', 'Shanshan', 'P''i-chan,Pichan,Pichang,Piqan,Pitschuang,P’i-chan,SXJ,Shan-shan-ch''eng,Shan-shan-chen,Shan-shan-ch’eng,Shan-shan-hsien,Shanshan,Shanshan Xian,Shanshar,pychan,shan shan,shan shan xian,Пичан,پىچان,鄯善,鄯善县', 42.8675000, 90.2046300, 'CN', '2014-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12652, 'Sairam', 'Sairam', 'Sailimu,Sailimu Zhen,Sairam,Sajram,Sayram,sai li mu,sai li mu zhen,sayram,Сайрам,سايرام,赛里木,赛里木镇', 41.7661100, 82.1475000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12653, 'Santai', 'Santai', 'Santai,Santai Zhen,Santay,san tai,san tai zhen,三台,三台镇', 44.0895800, 88.8888700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12654, 'Sandaohezi', 'Sandaohezi', 'San-tao-ho,San-tao-ho-tzu,San-tao-ho-tzu-chen,San-tao-ho-tzu-hsiang,San-tu-ho-tzu,Sandaohezi,Sandaohezi Zhen,Sandukhoza,san dao he zi,san dao he zi zhen,三道河子,三道河子镇', 44.3259700, 85.6200900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12655, 'Qitai', 'Qitai', 'Ch''i-t''ai,Ch''i-t''ai-chen,Ch''i-t''ai-hsien,Ch’i-t’ai,Ch’i-t’ai-chen,Ch’i-t’ai-hsien,Guchen,Guchentszy,Guchung,Guqung,Kitai,Kou-tcheng,Ku-ch''eng,Ku-ch''eng-tau,Ku-cheng-tzu,Ku-ch’eng,Ku-ch’eng-tau,Ku-shong,Ku-tschong,Ku-tschöng,Kuchengtze,Kuchong,Kuchöng,Qitai,Qitai Zhen,Tsitay,qi tai,qi tai zhen,Гучуң,گۇچۇڭ,齐台,齐台镇', 44.0278800, 89.5798000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12656, 'Qinghe', 'Qinghe', 'Ch''ing-ho,Ch''ing-ho-ch''eng,Ch''ing-ho-hsien,Ch''ing-ko-li-ho,Chinggil,Chingil'',Chingil’,Ch’ing-ho,Ch’ing-ho-ch’eng,Ch’ing-ho-hsien,Ch’ing-ko-li-ho,Qinggil,Qinghe,Qinghe Zhen,chynggyl,qing he,qing he zhen,Чиңгил,چىڭگىل,青河,青河镇', 46.6672500, 90.3786400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12657, 'Qiman', 'Qiman', 'Chimen,Qiman,Qiman Zhen,Qimən,qi man,qi man zhen,Чимән,چىمەن,齐满,齐满镇', 41.5377800, 82.9113900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12658, 'Qili', 'Qili', 'Ch''i-li-chen,Ch’i-li-chen,Qili,Qili Zhen,qi li,qi li zhen,七里,七里镇', 40.1151200, 94.6088200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12659, 'Qilan', 'Qilan', 'Chilan,Qilan,Qilang,Qilang Xiang,chylan,qi lang,qi lang xiang,Чилан,چىلان,启浪,启浪乡', 40.5666700, 79.6166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12660, 'Qarqi', 'Qarqi', 'Ch''a-erh-ch''i,Cha''erqi,Cha''erqi Zhen,Chakchi,Charkchi,Cha’erqi,Cha’erqi Zhen,Ch’a-erh-ch’i,Gakshe,Qarqi,Yakrik,cha er qi,cha er qi zhen,察尔齐,察尔齐镇', 41.5838900, 81.3663900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12661, 'Qapqal', 'Qapqal', 'Ch''a-pu-ch''a-erh,Ch''a-pu-ch''a-erh-ch''eng,Ch''a-pu-ch''a-erh-hsi-po-tsu-tzu-chih-hsien,Ch''a-pu-ch''a-erh-hsi-po-tzu-chih-hsien,Chabucha''er,Chabucha’er,Chapchal,Ch’a-pu-ch’a-erh,Ch’a-pu-ch’a-erh-ch’eng,Ch’a-pu-ch’a-erh-hsi-po-tsu-tzu-chih-hsien,Ch’a-pu-ch’a-erh-hsi-po-tzu-chih-hsien,Ho-nan,K''uo-chi-ko-erh,Kochiger,Kodjiger,Kodziger,Kojiger,Kuo-chi-lo,K’uo-chi-ko-erh,Ning-hsi,Ning-hsi-hsien,Qapqal,Qapqal Xibe Zizhixian,Qapqal Zizhixian,Turgen-sumun,cha bu cha er,cha bu cha er zi zhi xian,chapchal,Чапчал,چاپچال,察布查尔,察布查尔自治县', 43.8019400, 81.0872200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12662, 'Qahurt', 'Qahurt', 'Qahurt,Qiaku''erte,Qiaku''erte Zhen,Qiaku’erte,Qiaku’erte Zhen,qia ku er te,qia ku er te zhen,恰库尔特,恰库尔特镇', 46.3337900, 89.5923600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12663, 'Qagan Gol', 'Qagan Gol', 'Chagangol,Chaganguole,Chaganguole Xiang,Chaghanghol,Qagan Gol,Qaƣanƣol,cha gan guo lei,cha gan guo lei xiang,chaghanghwl,Чағанғол,چاغانغول,查干郭勒,查干郭勒乡', 46.4797400, 90.7456700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12664, 'Nilka', 'Nilka', 'Kung-ha,Kung-ha-hsien,Li-ni-hai,Na-li-ko,Ni-le-k''o,Ni-le-k’o,Ni-lo-ha,Ni-lo-k''o,Ni-lo-k''o-chen,Ni-lo-k’o,Ni-lo-k’o-chen,Nileha,Nileike,Nileke Xian,Nilka,Nilka Xian,Nilkha,Nilki,Nilqa,ni lei ke,ni lei ke xian,nylqa,Нилқа,نىلقا,尼勒克,尼勒克县', 43.7889400, 82.4959900, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12665, 'Muhur', 'Muhur', 'Mohu''er,Mohu''er Xiang,Mohu’er,Mohu’er Xiang,Muhur,Mukhur,mo hu er,mo hu er xiang,Мухур,مۇخۇر,莫乎尔,莫乎尔乡', 43.2000000, 82.6333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12666, 'Mori', 'Mori', 'Mo-li-ho,Mori,Mori Kazak Zizhixian,Mu-lei,Mu-lei-ch''eng,Mu-lei-ch’eng,Mu-lei-ho,Mu-lei-ho-hsien,Mu-lei-ka-sa-k''o-tsu-tzu-chih-ch''u,Mu-lei-ka-sa-k''o-tsu-tzu-chih-hsien,Mu-lei-ka-sa-k’o-tsu-tzu-chih-ch’ü,Mu-lei-ka-sa-k’o-tsu-tzu-chih-hsien,Mu-li-ho,Mulei,Mulei Hasake Zizhixian,Mulei Hoa,Muleykhe,mu lei,mu lei ha sa ke zi zhi xian,mwry,Мори,مورى,木垒,木垒哈萨克自治县', 43.8244200, 90.1947600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12667, 'Miao’ergou', 'Miao''ergou', 'K''un-tu-erh,Kuntour,K’un-tu-erh,Miao''ergou,Miao''ergou Zhen,Miao-erh-kou,Miao’ergou,Miao’ergou Zhen,Otu,Otu Karaul,Otu Post,Pik Otu,Utu,miao er gou,miao er gou zhen,庙尔沟,庙尔沟镇', 45.5163700, 83.8637400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12668, 'Mengjiaqiao', 'Mengjiaqiao', 'Mengjiaqiao,Mengjiaqiao Xiang,meng jia qiao,meng jia qiao xiang,孟家桥,孟家桥乡', 40.1807800, 94.6157400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12669, 'Manasi', 'Manasi', 'Ching-yuan-i,Ching-yuan-jih,Ching-yüan-i,Ching-yüan-jih,Ma-na-ssu,Ma-na-ssu-chen,Manas,Manasi,Manasi Zhen,Manass,Sui-lai,Sui-lai-hsien,Suylay,ma na si,ma na si zhen,manas,Манас,ماناس,玛纳斯,玛纳斯镇', 44.3063800, 86.2137100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12670, 'Luntai', 'Luntai', 'Bugar,Bugur,Bugur Bazar,Bügür,Lun-t''ai-chen,Lun-t''ai-hsien,Lun-t’ai-chen,Lun-t’ai-hsien,Luntai,Luntai Xian,Pu-ku-erh,lun tai,lun tai xian,Бүгүр,بۈگۈر,轮胎,轮胎县', 41.7738900, 84.2441700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12671, 'Liuyuan', 'Liuyuan', 'Liuyuan,Liuyuan Zhen,liu yuan,liu yuan zhen,柳园,柳园镇', 41.1024400, 95.5018900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12672, 'Laoshawan', 'Laoshawan', 'Laoshawan,Laoshawan Zhen,Sawen,Sawən,lao sha wan,lao sha wan zhen,Савән,ساۋەن,老沙湾,老沙湾镇', 44.6394600, 85.7810400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12673, 'Kuytun', 'Kuytun', 'Huyten,Hüyten,K''uei-t''un,K''uei-t''un-i,K''uei-t''un-shih,Kitim,Kue-tun,Kui-tun,Kuitun,Kuitun Shi,Kuytun,Küytun,K’uei-t’un,K’uei-t’un-i,K’uei-t’un-shih,kui tun,kui tun shi,Күйтун,كۈيتۇن,奎屯,奎屯市', 44.4270700, 84.9006900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12674, 'Kürti', 'Kurti', 'Ku''er Te,Ku''erte Xiang,Kurti,Ku’er Te,Ku’erte Xiang,Kürti,ku er te,ku er te xiang,Күрти,كۈرتى,库尔特,库尔特乡', 47.2000300, 89.3053100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12675, 'Kuqa', 'Kuqa', 'K''u-ch''e,K''u-ch''e-chen,K''u-ch''e-hsien,KCA,Kocha,Koutcha,Kucha,Kuchar,Kuche,Kuche Xian,Kuchel,Kuchi,Kuchu,Kuga,Kuqa,K’u-ch’e,K’u-ch’e-chen,K’u-ch’e-hsien,ku che,ku che xian,Куча,كۇچا,库车,库车县', 41.7277800, 82.9363900, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12676, 'Kupu', 'Kupu', 'Kup,Kupu,Kupu Xiang,Küp,Kүp,ku pu,ku pu xiang,kۈp,Күп,كۈپ,库普,库普乡', 45.8267300, 83.3098000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12677, 'Korla', 'Korla', 'K''o-erh-lo,K''u-erh-le,K''u-erh-lo,K''u-erh-lo-chen,K''u-erh-lo-hsien,K''u-erh-lo-she-chih-chu,KRL,Khorol khot,Koria,Korla,Korla Shi,Kourla,Ku''erle,Ku''erle Shi,Kuerhlei,Kuerhli,Kuerle,Kuriya,Kurla,Kurlya,Ku’erle,Ku’erle Shi,K’o-erh-lo,K’u-erh-le,K’u-erh-lo,K’u-erh-lo-chen,K’u-erh-lo-hsien,K’u-erh-lo-she-chih-chü,Sayibage,korura,korura shi,ku er lei,ku er lei shi,kueolleo si,kwrla,sa yi ba ge,Корла,Корла балһсн,Хорол хот,كورلا,كورلا شەھىرى,کورلا,コルラ,コルラ市,库尔勒,库尔勒市,萨依巴格,쿠얼러 시', 41.7605500, 86.1523100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12678, 'Koktokay', 'Koktokay', 'Fu-yun,Fu-yun-ch''eng,Fu-yun-hsien,Fu-yün,Fu-yün-ch’eng,Fu-yün-hsien,Keketuohai,Keketuohai Zhen,Kok Toqay,Kok-togoy,Koktokay,Kök Toqay,Kɵk Tok̩ay,ke ke tuo hai,ke ke tuo hai zhen,Көк Тоқай,كۆك توقاي,可可托海,可可托海镇', 47.2165400, 89.8172400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12679, 'Kizil', 'Kizil', 'Hei-tzu-erh,Ho-se-erh,Kezi''er,Kezi''er Xiang,Kezi’er,Kezi’er Xiang,Kizil,Kizil Ortang,Kizil Örtang,Kizil-urtang,Kizol,Kizöl,Kysyl,Qizil Urtang,Qizil-ortang,Qizil-örtang,ke zi er,ke zi er xiang,克孜尔,克孜尔乡', 41.8205600, 82.4347200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12680, 'Kizil', 'Kizil', 'Hei-tzu-erh,Kezile,Kezile Zhen,Kizil,ke zi lei,ke zi lei zhen,克孜勒,克孜勒镇', 41.0836400, 80.5183900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12681, 'Keyi', 'Keyi', 'Hei-ying-shan,Heiyingshan,Heiyingshan Xiang,Keyi,Keyir,Keyir Xiang,Qeyir,Qéyir,hei ying shan,hei ying shan xiang,Қейир,قېيىر,黑英山,黑英山乡', 42.1605600, 82.6347200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12682, 'Karjaw', 'Karjaw', 'Ka''erjiao,Ka''erjiao Xiang,Karjaw,Ka’erjiao,Ka’erjiao Xiang,K̩arjaw,Qarjaw,ka er jiao,ka er jiao xiang,qarjav,Қарҗав,قارجاۋ,喀尔交,喀尔交乡', 47.1909400, 86.3984800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12683, 'Kalatongke', 'Kalatongke', 'Ha-la-t''ung-kou,Ha-la-t''ung-ku,Ha-la-t’ung-kou,Ha-la-t’ung-ku,Kalatongke,Kalatongke Xiang,Karatunggu,Karatünggü,ka la tong ke,ka la tong ke xiang,喀拉通克,喀拉通克乡', 46.8559100, 89.6976100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12684, 'Halajun', 'Halajun', 'Ha-erh-chun,Ha-erh-chün,Halajun,Halajun Xiang,Karajul,Karajül,ha la jun,ha la jun xiang,哈拉峻,哈拉峻乡', 40.2500000, 76.9166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12685, 'Karabulak', 'Karabulak', 'Kalabulage,Kalabulage Xiang,Karabulak,K̩arabulak̩,Qarabulaq,ka la bu la ke,ka la bu la ke xiang,Қарабулақ,قارابۇلاق,喀拉布拉克,喀拉布拉克乡', 40.7305600, 77.5419400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12686, 'Kalpin', 'Kalpin', 'K''o-p''ing,K''o-p''ing-ch''eng,K''o-p''ing-hsien,Kalpin,Kalpin Xian,Kelpin,Kelpin-Bazar,Keping,Kəlpin,K’o-p’ing,K’o-p’ing-ch’eng,K’o-p’ing-hsien,ke ping,ke ping xian,Кәлпин,كەلپىن,柯坪,柯坪县', 40.5275500, 79.0657700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12687, 'Jimsar', 'Jimsar', 'Chi-mu-sa-erh,Chi-mu-sa-erh-chen,Chi-mu-sa-erh-hsien,Fu-yen,Fu-ynen,Fu-yuan,Fu-yuan-hsien,Fu-yüan,Fu-yüan-hsien,Fuan'',Fuan’,Jimasa,Jimsar,Jimusa''er,Jimusa''er Xian,Jimusa''er Zhen,Jimusa’er,Jimusa’er Xian,Jimusa’er Zhen,ji mu sa er,ji mu sa er xian,ji mu sa er zhen,jymsar,Җимсар,جىمسار,吉木萨尔,吉木萨尔县,吉木萨尔镇', 43.9833300, 89.0666700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12688, 'Jeminay', 'Jeminay', 'Ch''i-mu-nai,Chi-mu-nai-ch''eng,Chi-mu-nai-ch’eng,Chi-mu-nai-hsien,Ch’i-mu-nai,Jeminay,Jeminey,Jeminəy,Jimunai,Jimunai Zhen,Jéminey,Zimunay,ji mu nai,ji mu nai zhen,Җеминәй,جېمىنەي,吉木乃,吉木乃镇', 47.4996900, 85.6182800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12689, 'Jelagax', 'Jelagax', 'Jel Aghash,Jel Aƣax,Jelagax,Jiele''agashi,Jiele''agashi Xiang,Jiele’agashi,Jiele’agashi Xiang,Jél Aghash,jie lei a ga shen,jie lei a ga shen xiang,Җел Ағаш,جېل ئاغاش,杰勒阿尕什,杰勒阿尕什乡', 46.6010900, 83.9201300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12690, 'Jiamu', 'Jiamu', 'Cha-mu-t''ai,Cha-mu-t’ai,Jamtai,Jiamu,Jiamu Zhen,jia mu,jia mu zhen,佳木,佳木镇', 41.2691700, 80.5600000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12691, 'Yili', 'Yili', 'I-li Ti-ch''u,I-li Ti-ch’ü,Ili Diqu,Yili,Yili Hasake Zizhizhou,yi li,yi li ha sa ke zi zhi zhou,伊梨,伊犁哈萨克自治州', 43.9000000, 81.3500000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12692, 'Khutubi', 'Khutubi', 'Ching-hua,Ching-hua-i,Hu-t''u-pi,Hu-t''u-pi-chen,Hu-t''u-pi-hsien,Hu-t’u-pi,Hu-t’u-pi-chen,Hu-t’u-pi-hsien,Hutubi,Hutubi Zhen,Khotubi,Khutubi,Kutubi,K̩utubi,Qutubi,hu tu bi,hu tu bi zhen,Қутуби,قۇتۇبى,呼图壁,呼图壁镇', 44.1903500, 86.8852100, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12693, 'Huiyuan', 'Huiyuan', 'Hui-yuan-ch''eng,Hui-yüan-ch’eng,Huiyuan,Huiyuan Zhen,Hweiyan,Hweyuan,Hweyüan,Ili,hui yuan,hui yuan zhen,惠远,惠远镇', 43.9569400, 80.8502800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12694, 'Huangqu', 'Huangqu', 'Huangqu,Huangqu Xiang,huang qu,huang qu xiang,黄渠,黄渠乡', 40.2782100, 94.7027100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12695, 'Huahai', 'Huahai', 'Huahai,Huahai Xiang,hua hai,hua hai xiang,花海,花海乡', 40.3030300, 97.7363500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12696, 'Hoxut', 'Hoxut', 'Ch''ing-shui-ho,Ch''ing-shui-ho-i,Ch''ing-shui-ho-jih-ma,Ch''ing-shui-ho-tzu,Chimshuikhosa,Chinshuykhoza,Ch’ing-shui-ho,Ch’ing-shui-ho-i,Ch’ing-shui-ho-jih-ma,Ch’ing-shui-ho-tzu,Heshuo,Heshuo Xian,Ho-shih,Ho-shih-ch''eng,Ho-shih-ch’eng,Ho-shuo,Hoxud,Hoxut,Khoshud,Khoshut,T''a-mo-chia,T''a-wei-ka,Ta-wei-kou,Tavilgha,Tavylga,Tawilga,Tawilgha,Tewulike,T’a-mo-chia,T’a-wei-ka,Xoshut,he shuo,he shuo xian,te wu li ke,Хошут,خوشۇت,和硕,和硕县,特吾里克', 42.2586100, 86.8577800, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12697, 'Hoxtolgay', 'Hoxtolgay', 'Chia-shih-t''o-lo-kai,Chia-shih-t’o-lo-kai,Heshituoluogai,Heshituoluogai Zhen,Ho-feng,Ho-feng-hsien,Ho-shih-t''o-lo-kai,Ho-shih-t’o-lo-kai,Ho-ssu-t''o-lo-kai,Ho-ssu-t’o-lo-kai,Hosh Tologoy,Hoxtolgay,Khoshtologai hsien,Khoshutologoy,Kosh-tologoy,he shen tuo luo gai,he shen tuo luo gai zhen,和什托洛盖,和什托洛盖镇', 46.5187200, 86.0021400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12698, 'Hongdun', 'Hongdun', 'Hongdun,Hongdun Xiang,Hongdun Zhen,hong dun,hong dun xiang,hong dun zhen,hۇngdۇn qalashyʿy,khۇngdۆng bazyry,qyzyltas qalashyʿy,حۇڭدۇن قالاشىعى,خۇڭدۆڭ بازىرى,قىزىلتاس قالاشىعى,红墩,红墩乡,红墩镇', 47.7241300, 88.2184600, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12699, 'Hoboksar', 'Hoboksar', 'Hebukesai''er,Hebukesai''er Zhen,Hebukesai’er,Hebukesai’er Zhen,Ho-pu-k''o,Ho-pu-k''o-sai-erh,Ho-pu-k''o-sai-erh-ch''eng,Ho-pu-k''o-sai-erh-meng-ku-tsu-tzu-chih-hsien,Ho-pu-k’o,Ho-pu-k’o-sai-erh,Ho-pu-k’o-sai-erh-ch’eng,Ho-pu-k’o-sai-erh-meng-ku-tsu-tzu-chih-hsien,Hoboksar,Huo-pu-k''o,Huo-pu-k’o,K''o-pu-k''o,Khobuk,Kobuk,Kobuksar,K̩obuk̩sar,K’o-pu-k’o,Qobuqsar,T''e-pu-k''o,T’e-pu-k’o,he bu ke sai er,he bu ke sai er zhen,Қобуқсар,قوبۇقسار,和布克赛尔,和布克赛尔镇', 46.7950700, 85.7266000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12700, 'Hejing', 'Hejing', 'Gun Hara,Gun-khara,Gung-Khara,Guun Hara,Gün Hara,Hejing,Hejing Xian,Ho-ching,Ho-ching-cheng,Khetszin,Khotun-Symbul,Kun-ha-la,Xejing,Xéjing,he jing,he jing xian,Хеҗиң,خېجىڭ,和静,和静县', 42.3163900, 86.3827800, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12701, 'Haramgai', 'Haramgai', 'Halamagai,Halamagai Xiang,Haramgai,ha la ma gai,ha la ma gai xiang,哈拉玛盖,哈拉玛盖乡', 46.6568400, 87.7741700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12702, 'Hami', 'Hami', 'Chamil,HMI,Ha-mi-ch''eng-chen,Ha-mi-chen,Ha-mi-ch’eng-chen,Ha-mi-hsien,Ha-mi-shih,Hami,Kamil,Kha-mi,Khami,Khamil,Komul,Koumoul,Kumul,K̩umul,Qomul,Qumul,ha mi de qu,ha mi shi,hami,kumuru shi,Хами,Қумул,قۇمۇل,قۇمۇل شەھىرى,クムル市,哈密地区,哈密市,하미', 42.8339300, 93.5060100, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12703, 'Guazhou', 'Guazhou', 'Guazhou,Guazhou Xiang,gua zhou,gua zhou xiang,瓜州,瓜州乡', 40.4638400, 95.6711900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12704, 'Wuluquele', 'Wuluquele', 'Ghoruchol,Ghoruchöl,Goruqol,Wu-lu-ch''iao,Wu-lu-ch’iao,Wuluquele,Wuluquele Zhen,wu lu que lei,wu lu que lei zhen,Ƣoruqɵl,Ғоручөл,غورۇچۆل,乌鲁却勒,乌鲁却勒镇', 40.4505600, 80.4844400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12705, 'Tokkuztara', 'Tokkuztara', 'Gongliu,Gongliu Xian,Kung-liu,Kung-liu-chen,Kung-liu-hsien,T''o-ku-ssu-t''a-liu,Togustarau,Tokkuztara,Tok̩k̩uztara,Toqquztara,T’o-ku-ssu-t’a-liu,Yangishar,Yanyshar,gong liu,gong liu xian,Тоққузтара,توققۇزتارا,巩留,巩留县', 43.4666700, 82.1488900, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12706, 'Bofeng', 'Bofeng', 'Bofeng,Chengguan Zhen,Fou-k''ang,Fou-k''ang-ch''eng,Fou-k''ang-chen,Fou-k''ang-hsien,Fou-k’ang,Fou-k’ang-chen,Fou-k’ang-ch’eng,Fou-k’ang-hsien,Fu-k''an,Fu-k’an,Fukang,Fukang Shi,K''ang-lo-i,K’ang-lo-i,Pukang,bo feng,cheng guan zhen,fu kang,fu kang shi,Фукаң,فۇكاڭ,博峰,城关镇,阜康,阜康市', 44.1587400, 87.9741800, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12707, 'Fuhai', 'Fuhai', 'Baluntochoi,Bulang Tohoy,Bulun Tochoi,Bulun Tokhoi,Bulun Tokhoi-hsien,Bulun-Tokhoy,Buluntok,Burultokay,Burultok̩ay,Burultoqay,Fu-hai-ch''eng,Fu-hai-ch’eng,Fu-hai-hsien,Fuhai,Fuhai Zhen,Pu-lun-t''o,Pu-lun-t''o-hai,Pu-lun-t’o,Pu-lun-t’o-hai,Puerhtsinho,fu hai,fu hai zhen,Бурултоқай,بۇرۇلتوقاي,福海,福海镇', 47.1095000, 87.4881000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12708, 'Ewirgol', 'Ewirgol', 'Ai-wei-erh-kou,Ehvirgol,Ewirghol,Ewirgol,Ewirgol Jiedao,Ewirƣol,ai wei er gou,ai wei er gou jie dao,Éwirghol,Эвирғол,ئېۋىرغول,艾维尔沟,艾维尔沟街道', 42.9644400, 87.6611100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12709, 'Ertai', 'Ertai', 'Erh-t''ai,Erh-t’ai,Ertai,Ertay,Sa''ertuohai,Sa''ertuohai Xiang,Sa’ertuohai,Sa’ertuohai Xiang,Wang-erh-t''ai,Wang-erh-t’ai,sa er tuo hai,sa er tuo hai xiang,萨尔托海,萨尔托海乡', 46.0565400, 90.1512500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12710, 'Erdaoqiao', 'Erdaoqiao', 'Erdaoqiao,Erdaoqiao Xiang,er dao qiao,er dao qiao xiang,二道桥,二道桥乡', 46.3944000, 83.5570900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12711, 'Emin', 'Emin', 'Dorbiljin,Dörbiljin,Dɵrbiljin,Emin,Emin Zhen,O-min,O-min-ho-shih,O-min-hsien,Seteerhmutotai,Seter,Seter Outpost,e min,e min zhen,Дөрбилҗин,دۆربىلجىن,额敏,额敏镇', 46.5257400, 83.6332500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12712, 'Dushanzi', 'Dushanzi', 'Dushanzi,Dushanzi Qu,Majtag,Maytag,Maytagh,Maytaƣ,T''u-shang-tzu,Tu-shan-tzu,Tushandzo,Tushandzy,Tushandzö,Tushantze,T’u-shang-tzu,du shan zi,du shan zi qu,ma yi ta ke shan,maytagh,Майтағ,مايتاغ,独山子,独山子区,玛依塔柯山', 44.3333300, 84.8500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12713, 'Dure', 'Dure', 'Dure,Dure Xiang,Düre,Tu-je,du re,du re xiang,杜热,杜热乡', 46.3779500, 88.4684700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12714, 'Dongbatu', 'Dongbatu', 'Dongbatu,Dongbatu Xiang,Tung-pa-t''u,Tung-pa-t’u,dong ba tu,dong ba tu xiang,东巴兔,东巴兔乡', 40.0625500, 95.7059300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12715, 'Dongba', 'Dongba', 'Dongba,Dongba Xiang,Tung-pa,dong ba,dong ba xiang,东坝,东坝乡', 40.1728500, 99.0028400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12716, 'Dabancheng', 'Dabancheng', 'Dabancheng,Dabancheng Qu,Dabancheng Zhen,Davan-ch''eng,Davan-ch’eng,Davanchin,Dawan-ch''eng,Dawan-ch’eng,Dawanching,Dawanqing,Ta-fan-ch''eng,Ta-fan-ch’eng,Ta-pan-ch''eng,Ta-pan-ch’eng,Tianshan,da ban cheng,da ban cheng qu,da ban cheng zhen,davanchyng,Даванчиң,داۋانچىڭ,达坂城,达坂城区,达坂城镇', 43.3583300, 88.3200400, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12717, 'Chijin', 'Chijin', 'Ch''ih-ch''ing-p''u,Ch''ih-chin-pao,Chichinpu,Chijin,Chijin Zhen,Ch’ih-chin-pao,Ch’ih-ch’ing-p’u,chi jin,chi jin zhen,赤金,赤金镇', 40.0132000, 97.4258000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12718, 'Changji', 'Changji', 'Ch''ang-chi,Ch''ang-chi-chen,Ch''ang-chi-hsien,Chanczi,Changji,Changji Shi,Changki,Chanki,Chantszi,Ch’ang-chi,Ch’ang-chi-chen,Ch’ang-chi-hsien,Ning-pien-i,Sandzhi,Sanji,Yan''an Beilu,Yan’an Beilu,chang ji shi,sanjy,yan an bei lu,Санҗи,Чанцзи,سانجى,延安北路,昌吉市', 44.0078200, 87.3046100, 'CN', '2015-05-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12719, 'Bulongji', 'Bulongji', 'Bulingar,Bulongji,Bulongji Xiang,Bulungir,Pu-lung-ch''i Ch''eng,Pu-lung-chi,Pu-lung-ch’i Ch’eng,Pulungki,bu long ji,bu long ji xiang,布隆吉,布隆吉乡', 40.5308700, 96.5410200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12720, 'Bor Tungge', 'Bor Tungge', 'Bo''ertonggu,Bo''ertonggu Xiang,Bor Tungge,Bortunggi,Bortünggi,Bo’ertonggu,Bo’ertonggu Xiang,bo er tong gu,bo er tong gu xiang,Бортүңги,بورتۈڭگى,博尔通古,博尔通古乡', 44.0531700, 85.3774700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12721, 'Bohu', 'Bohu', 'Baghrash,Bagrash,Bagrax,Baƣrax,Bohu,Bohu Zhen,Boron Sum,Pao-la-su-mu,Po-hu,baghrash,bo hu,bo hu zhen,Бағраш,باغراش,博湖,博湖镇', 41.9843400, 86.6219800, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12722, 'Beiwucha', 'Beiwucha', 'Beiwucha,Beiwucha Zhen,bei wu cha,bei wu cha zhen,北五岔,北五岔镇', 44.5313400, 86.3197800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12723, 'Beitun', 'Beitun', 'Beitun,Beitun Zhen,Pei-t''un,Pei-t’un,bei tun,bei tun zhen,bېytۇn bazyry,bەytۇn qalashyʿy,بېيتۇن بازىرى,بەيتۇن قالاشىعى,北屯,北屯镇', 47.3524900, 87.8205300, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12724, 'Barkol', 'Barkol', 'Balikun,Barkol,Barkol Zhen,Barkoul,Barkul'',Barkul’,Barköl,Barkɵl,Chen-hsi,Chen-hsi-fu,Chen-hsi-hsien,Chensi,Chzhen''si,Chzhen’si,Pa-erh-k''u-erh,Pa-erh-k’u-erh,Pa-li-k''u-erh,Pa-li-k''un,Pa-li-k''un-chen,Pa-li-k''un-ha-sa-k''o-tzu-chih-hsien,Pa-li-k''un-ka-sa-k''o-tsu-tzu-chih-hsien,Pa-li-k’u-erh,Pa-li-k’un,Pa-li-k’un-chen,Pa-li-k’un-ha-sa-k’o-tzu-chih-hsien,Pa-li-k’un-ka-sa-k’o-tsu-tzu-chih-hsien,ba li kun,ba li kun zhen,barkwl qalashyʿy,barkۆl bazyry,Баркөл,باركول قالاشىعى,باركۆل,باركۆل بازىرى,巴里坤,巴里坤镇', 43.5988100, 93.0086200, 'CN', '2015-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12725, 'Baikouquan', 'Baikouquan', 'Baikouquan,Baikouquan Jiedao,Pai-k''ou-ch''uan,Pai-k’ou-ch’üan,bai kou quan,bai kou quan jie dao,百口泉,百口泉街道', 45.9181500, 85.4745300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12726, 'Baijiantan', 'Baijiantan', 'Baijiantan,Baijiantan Zhen,Pai-chien-t''an,Pai-chien-t’an,bai jian tan,bai jian tan zhen,白碱滩,白碱滩镇', 45.6892800, 85.1244100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12727, 'Baicheng', 'Baicheng', 'Bai,Baicheng,Baicheng Xian,Baj,Bay,Pai,Pai-ch''eng,Pai-ch''eng-chen,Pai-ch''eng-hsien,Pai-ch’eng,Pai-ch’eng-chen,Pai-ch’eng-hsien,bai cheng,bai cheng xian,bay,Бай,باي,拜城,拜城县', 41.7738900, 81.8688900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12728, 'Aykol', 'Aykol', 'A-yin-k''o,A-yin-k’o,Aykol,Ayköl,Aykɵl,Айкөл,ئايكۆل', 40.9575900, 80.1357400, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12729, 'Awiytan', 'Awiytan', 'A-wei-t''an,A-wei-t’an,Avijtan,Aweitan,Aweitan Zhen,Awiytan,a wei tan,a wei tan zhen,yavyytan,yavyytan bazyry,ʾabytan qalashyʿy,Авийтан,ءابيتان قالاشىعى,ئاۋىيتان,ئاۋىيتان بازىرى,阿苇滩,阿苇滩镇', 47.7245700, 88.0510800, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12730, 'Awat', 'Awat', 'A-wa-t''i,A-wa-t''i-chen,A-wa-t''i-hsien,A-wa-t’i,A-wa-t’i-chen,A-wa-t’i-hsien,Abad,Avat,Awat,Awat Xian,Awati,Awati Xian,a wa ti,a wa ti xian,yavat,Ават,ئاۋات,阿瓦提,阿瓦提县', 40.6383700, 80.3796500, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12731, 'Araltobe', 'Araltobe', 'Araltobe,Araltöbe,Araltɵbə,Areletuobie,Areletuobie Xiang,a re lei tuo bie,a re lei tuo bie xiang,Аралтөбә,ئارالتۆبە,阿热勒托别,阿热勒托别乡', 46.5208900, 90.2168100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12732, 'Araltobe', 'Araltobe', 'Araltobe,Araltope,Araltöpe,Araltɵpə,Аралтөпә,ئارالتۆپە', 43.4102900, 83.7647400, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12733, 'Aral', 'Aral', 'A-la-erh,Ala''er,Ala''er Shi,Ala’er,Ala’er Shi,Aral,Aral''skoe,a la er,a la er shi,yaral,Арал,Аральское,ئارال,阿拉尔,阿拉尔市', 40.5418400, 81.2656600, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12734, 'Aqal', 'Aqal', 'A-ch''ia,A-chi,A-ch’ia,Achal,Aqal,Aqiale,Aqiale Xiang,a qia lei,a qia lei xiang,yachal,Ачал,ئاچال,阿恰勒,阿恰勒乡', 40.4308300, 79.3355600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12735, 'Anjihai', 'Anjihai', 'An-chi-hai,Anchihaitai,Anchikhai,Anjihai,Anjihai Zhen,Yantszykhay,an ji hai,an ji hai zhen,安集海,安集海镇', 44.3578700, 85.3518900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12736, 'Altay', 'Altay', 'A-erh-t''ai,A-erh-t’ai,A-le-t''ai,A-le-t’ai,A-lo-t''ai,A-lo-t''ai-chen,A-lo-t''ai-hsien,A-lo-t’ai,A-lo-t’ai-chen,A-lo-t’ai-hsien,A-shan,AAT,Aletai,Aletai Zhen,Altai,Altai-Sharasume,Altaj,Altajskaja,Altay,Ch''eng-hua,Ch''eng-hua-hsien,Ch''eng-hua-ssu,Cheng-hua-sze,Chenghwa,Chenghwasze,Chenkhua,Ch’eng-hua,Ch’eng-hua-hsien,Ch’eng-hua-ssu,Shara-Sumu,Sharasume,T''u-lo-t''a,Tulta,T’u-lo-t’a,a lei tai,a lei tai shi,a lei tai zhen,aleotai,altay qalasy,yaltay,yaltay shەھyry,Ālètài,Алтай,Алтайская,ئالتاي,ئالتاي شەھىرى,التاي قالاسى,阿勒泰,阿勒泰市,阿勒泰镇,아러타이', 47.8486400, 88.1336100, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12737, 'Aksu', 'Aksu', 'A-k''o-su,A-k''o-su-chen,A-k''o-su-hsien,A-k''o-su-hsin-ch''eng,A-k’o-su,A-k’o-su-chen,A-k’o-su-hsien,A-k’o-su-hsin-ch’eng,AKU,Ak Su Yangi Shahr,Akesu,Akesu Shi,Akoso,Aksou,Aksu,Aksu New City,Ak̩su,Aqsu,Aqsu New City,Aqsu Yangi Shahr,Ciudad de Aksu,New Aksu,Yangi-shahr,a ke su,a ke su shi,akeossu si,aksw  snkyang,aksw  zynjyang,akusu,akusu shi,aqsw,Аксу,Ақсу,آکسو، سنکیانگ,أقسو,ئاقسۇ,ئاقسۇ شەھىرى,اکسو، زینجیانگ,アクス,アクス市,阿克苏,阿克苏市,아커쑤 시', 41.1841800, 80.2792100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12738, 'Akqi', 'Akqi', 'A-ho-ch''i,A-ho-ch''i-ch''eng,A-ho-ch''i-hsien,A-ho-ch’i,A-ho-ch’i-ch’eng,A-ho-ch’i-hsien,A-ko-ch''i,A-ko-ch’i,Agche,Aheqi,Aheqi Xian,Akcha,Akche,Akchiy,Akqi,Ak̩qi,Aqchi,a he qi,a he qi xian,yaqchy,Ақчи,ئاقچى,阿合奇,阿合奇县', 40.9415200, 78.4437900, 'CN', '2016-03-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12739, 'Agax Obo', 'Agax Obo', 'Agash Oba,Agashi''aobao,Agashi''aobao Xiang,Agashi’aobao,Agashi’aobao Xiang,Agax Obo,Aghash Oba,Aƣax Oba,a ga shen ao bao,a ga shen ao bao xiang,yaghash ywba,Ағаш Оба,ئاغاش ئوبا,阿尕什敖包,阿尕什敖包乡', 46.2864400, 90.4211900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12740, 'Anningqu', 'Anningqu', 'An-ning-ch''u,An-ning-ch’ü,Anningqu,Anningqu Zhen,an ning qu,an ning qu zhen,安宁渠,安宁渠镇', 43.9833300, 87.5333300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12741, 'Diwopu', 'Diwopu', 'Diwopu,Diwopu Xiang,Ta-ti-wo-p''u,Ta-ti-wo-p’u,URC,de wo bao xiang,地窝堡乡', 43.8833300, 87.4833300, 'CN', '2013-11-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12742, 'Ergong', 'Ergong', 'Ergong,Ergong Jiedao,er gong,er gong jie dao,二工,二工街道', 43.8500000, 87.5666700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12743, 'Tiechanggou', 'Tiechanggou', 'T''ieh-ch''ang-kou,Tiechanggou,Tiechanggou Zhen,T’ieh-ch’ang-kou,tie chang gou,tie chang gou zhen,铁厂沟,铁厂沟镇', 43.9166700, 87.7833300, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12744, 'Lucaogou', 'Lucaogou', 'Lu-ts''ao-kou,Lu-ts’ao-kou,Lucaogou,Lucaogou Xiang,lu cao gou,lu cao gou xiang,芦草沟,芦草沟乡', 43.8666700, 87.7833300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12745, 'Shuimogou', 'Shuimogou', 'Shui-mo-kou,Shuimogou,Shuimogou Qu,Shuimogoucun,shui mo gou,shui mo gou cun,shui mo gou qu,水磨沟,水磨沟区,水磨沟村', 43.8285600, 87.6382000, 'CN', '2014-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12746, 'Sishilichengzi', 'Sishilichengzi', 'Sishilichengzi,Ssu-shih-li-ch''eng-tzu,Ssu-shih-li-ch’eng-tzu', 41.9619400, 86.4766700, 'CN', '2013-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12747, 'Axili', 'Axili', 'Ashili,Axi''er,Axi''er Xiang,Axili,Axili Daworzu Xiang,Axi’er,Axi’er Xiang,a xi er,a xi er xiang,yashyly,Ашили,ئاشىلى,阿西尔,阿西尔乡', 46.8562800, 83.1226300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12748, 'Karakabak', 'Karakabak', 'Kalahabake,Kalahabake Xiang,Karaka Bak,Karakabak,Karakabak Xiang,K̩arak̩a Bak̩,Qaraqa Baq,ge la ha ba ke,ge la ha ba ke xiang,qaraqa baq,Қарақа Бақ,قاراقا باق,咯拉哈巴克,咯拉哈巴克乡', 46.7678600, 83.1469700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12749, 'Qaxa', 'Qaxa', 'Chasha,Qaxa,Qaxa Xiang,Qiaxia,Qiaxia Xiang,chasha,qia xia,qia xia xiang,Чаша,چاشا,恰夏,恰夏乡', 46.6886100, 83.4053000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12750, 'Emil', 'Emil', 'Ehmil,Emil,Emil Xiang,Yemenle,Yemenle Xiang,ye men lei,ye men lei xiang,Émil,Эмил,ئېمىل,也门勒,也门勒乡', 46.6471900, 83.0743000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12751, 'Shanghu', 'Shanghu', 'Shanghu,Shanghu Xiang,shang hu,shang hu xiang,上户,上户乡', 46.6372300, 83.8239100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12752, 'Altunemil', 'Altunemil', 'Aletengyemule,Aletengyemule Xiang,Altunehmil,Altunemil,Altunemil Xiang,Altunémil,a lei te ye mu lei,a lei te ye mu lei xiang,Алтунэмил,ئالتۇنئېمىل,阿勒螣也木勒,阿勒螣也木勒 乡', 46.1192300, 83.0901400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12753, 'Yushikalasu', 'Yushikalasu', 'Uq Karasu,Uq Karasu Xiang,Yushikalasu,Yushikalasu Xiang,yu shen ka la su,yu shen ka la su xiang,Üq Karasu,Üq Karasu Xiang,玉什喀拉苏,玉什喀拉苏乡', 46.7096900, 84.0450200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12754, 'Motge', 'Motge', 'Motege,Motege Xiang,Motge,Motge Xiang,mo te ge,mo te ge xiang,莫特格,莫特格乡', 46.8128200, 85.7974300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12755, 'Qagan Hol', 'Qagan Hol', 'Chagangol,Chagankule,Chagankule Xiang,Chaghanghol,Qagan Hol,Qagan Hol Xiang,Qaƣanƣol,cha gan ku lei,cha gan ku lei xiang,chaghanghwl,Чағанғол,چاغانغول,查干库勒,查干库勒乡', 46.8169600, 85.9554300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12756, 'Topterek', 'Topterek', 'Topterek,Topterek Zhen,Topterək,Toptérek,Tuoputiereke,Tuoputiereke Xiang,Tuoputiereke Zhen,tuo pu tie re ke,tuo pu tie re ke xiang,tuo pu tie re ke zhen,Топтерәк,توپتېرەك,托普铁热克,托普铁热克乡,托普铁热克镇', 47.4340300, 85.8711300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12757, 'Besterek', 'Besterek', 'Besterek,Besterek Xiang,Bestérek,Biesitiereke,Biesitiereke Xiang,Bəsterək,bie si tie re ke,bie si tie re ke xiang,Бәстерәк,بەستېرەك,别斯铁热克,别斯铁热克乡', 47.3040800, 85.8797900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12758, 'Oymak', 'Oymak', 'Oymak,Oymak Xiang,Oymak̩,Oymaq,Woyimoke,Woyimoke Xiang,wo yi mo ke,wo yi mo ke xiang,wymaqy avyly,ywymaq,ywymaq yېzysy,Оймақ,ئويماق,ئويماق يېزىسى,ويماقى اۋىلى,窝依莫克,窝依莫克乡', 47.8780900, 86.9895500, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12759, 'Xalxikay', 'Xalxikay', 'Qialeshihai,Qialeshihai Xiang,Shalshiqay,Xalxikay,Xalxikay Xiang,Xalxik̩ay,qia lei shen hai,qia lei shen hai xiang,shalshyqay,Шалшықай,شالشىقاي,恰勒什海,恰勒什海乡', 47.5225000, 86.2158300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12760, 'Egiztobe', 'Egiztobe', 'Egiztobe,Egiztobe Xiang,Egiztɵbə,Yegezituobie,Yegezituobie Xiang,ye ge zi tuo bie,ye ge zi tuo bie xiang,yېgyztۆbە yېzysy,Égiztöbe,Эгизтөбә,ئېگىزتۆبە,ئېگىزتۆبە يېزىسى,ەgyztwbە avyly,ەگىزتوبە اۋىلى,也格孜托别,也格孜托别乡', 47.8593800, 87.0046600, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12761, 'Kostik', 'Kostik', 'Kostik,Kostik Xiang,Kuositeke,Kuositeke Xiang,K̩ostik̩,Qostiq,kuo si te ke,kuo si te ke xiang,qwstyq,Қостық,قوستىق,阔斯特克,阔斯特克乡', 47.7868200, 87.3307800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12762, 'Alakak', 'Alakak', 'Alahake,Alahake Xiang,Alakak,Alakak Xiang,Alak̩ak̩,Alaqaq,a la ha ke,a la ha ke xiang,alaqaq avyly,yalaqaq,yalaqaq yېzysy,Алақақ,ئالاقاق,ئالاقاق يېزىسى,الاقاق اۋىلى,阿拉哈克,阿拉哈克乡', 47.7446200, 87.4981300, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12763, 'Balbagay', 'Balbagay', 'Balbagaj,Balbagay,Balbagay Xiang,Balbaghay,Balbaƣay,Balibagai,Balibagai Xiang,ba li ba gai,ba li ba gai xiang,balbaghay,balbaghay yېzysy,balbaʿay avyly,Балбағай,بالباعاي اۋىلى,بالباغاي,بالباغاي يېزىسى,巴里巴盖,巴里巴盖乡', 47.5179700, 87.7422800, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12764, 'Jetaral', 'Jetaral', 'Jetaral,Jetaral Xiang,Jiete''arel''e,Jiete''arel''e Xiang,Jiete’arel’e,Jiete’arel’e Xiang,jie te a re lei,jie te a re lei xiang,解特阿热勒,解特阿热勒乡', 47.0977000, 87.4453600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12765, 'Kokagax', 'Kokagax', 'Keke''agashi,Keke''agashi Xiang,Keke’agashi,Keke’agashi Xiang,Kokagax,Kokagax Xiang,ke ke a ga shen,ke ke a ga shen xiang,科克阿尕什,科克阿尕什乡', 47.0174100, 87.6875300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12766, 'Turgun', 'Turgun', 'Tu''erhong,Tu''erhong Xiang,Turgun,Turgun Xiang,Tu’erhong,Tu’erhong Xiang,Türgün,tu er hong,tu er hong xiang,Түргүн,تۈرگۈن,吐尔洪,吐尔洪乡', 46.9793300, 89.8433500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12767, 'Ayxin Siri', 'Ayxin Siri', 'Aixinseli,Aixinseli Zhen,Ajshinsiri,Ayshinsiri,Ayxin Siri,Ayxin Siri Zhen,Ayxinsiri,Kuo-chi-ka,ai xin se li,ai xin se li zhen,yayshynsyry,Айшинсири,ئايشىنسىرى,爱新色里,爱新色里镇', 43.7600000, 80.7447200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12768, 'Qong Bora', 'Qong Bora', 'Qiongbola,Qiongbola Xiang,Qong Bora,Qong Bora Xiang,qiong bo la,qiong bo la xiang,琼博拉,琼博拉乡', 43.5453400, 80.9990700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12769, 'Akdala', 'Akdala', 'Akdala,Akdala Xiang,Akedala,Akedala Xiang,Aqdala,a ke da la,a ke da la xiang,yaqdala,Ақдала,ئاقدالا,阿克达拉,阿克达拉乡', 42.9886100, 81.3800000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12770, 'Jagistay', 'Jagistay', 'Jaghistay,Jagistay,Jagistay Xiang,Jaƣistay,Jiagasitai,Jiagasitai Xiang,jaghystay,jia ga si tai,jia ga si tai xiang,Җағистай,جاغىستاي,加尕斯台,加尕斯台乡', 43.5780600, 81.2238900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12771, 'Kan', 'Kan', 'Kan,Kan Xiang,kan,kan xiang,Кан,كان,坎,坎乡', 43.6700200, 81.5431000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12772, 'Kax', 'Kax', 'Kashen,Kashen Xiang,Kax,Kax Xiang,K̩ax,Qash,ka shen,ka shen xiang,qash,Қаш,قاش,喀什,喀什乡', 43.6411100, 81.8700000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12773, 'Yengitam', 'Yengitam', 'Yengitam,Yengitam Xiang,Yingtamu,Yingtamu Xiang,ying ta mu,ying ta mu xiang,Еңитам,يېڭىتام,英塔木,英塔木乡', 43.7458300, 81.6569400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12774, 'Dongmazar', 'Dongmazar', 'Dongmazar,Dongmazar Zhen,Dunmazha,Dunmazha Zhen,Döngmazar,Dɵngmazar,Ma-cha-erh,dun ma zha,dun ma zha zhen,Дөңмазар,دۆڭمازار,墩麻扎,墩麻扎镇', 43.8313900, 81.8505600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12775, 'Dadamtu', 'Dadamtu', 'Dadamtu,Dadamtu Xiang,Dadamutu,Dadamutu Xiang,da da mu tu,da da mu tu xiang,Дадамту,دادامتۇ,达达木图,达达木图乡', 43.9802800, 81.3141700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12776, 'Yuqunweng', 'Yuqunweng', 'Uqon,Uqon Huizu Xiang,Yuqunweng,Yuqunweng Huizu Xiang,yu qun weng,yu qun weng hui zu xiang,Üqon,Üqon Huizu Xiang,愉群翁,愉群翁回族乡', 43.8744400, 81.6205600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12777, 'Suptay', 'Suptay', 'Subutai,Subutai Xiang,Suptaj,Suptay,Suptay Xiang,Ta-sa-p''u-t''ai,Ta-sa-p’u-t’ai,su bu tai,su bu tai xiang,Суптай,سۇپتاي,苏布台,苏布台乡', 43.9422200, 82.1266700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12778, 'Karasu', 'Karasu', 'Kalasu,Kalasu Xiang,Karasu,Karasu Xiang,K̩arasu,Qarasu,ka la su,ka la su xiang,Қарасу,قاراسۇ,喀拉苏,喀拉苏乡', 43.8469400, 82.1897200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12779, 'Karatobe', 'Karatobe', 'Kalatuobie,Kalatuobie Xiang,Karatobe,Karatobe Xiang,K̩aratɵbə,Qaratobe,Qaratöbe,ka la tuo bie,ka la tuo bie xiang,Қаратөбә,قاراتۆبە,喀拉托别,喀拉托别乡', 43.7492700, 82.6355600, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12780, 'Taldi', 'Taldi', 'Taldi,Taldi Xiang,Talede,Talede Xiang,ta lei de,ta lei de xiang,taldy,Талди,تالدى,塔勒德,塔勒德乡', 43.4135300, 83.0538900, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12781, 'Agarsin', 'Agarsin', 'Aga''ersen,Aga''ersen Xiang,Agarsin,Agarsin Xiang,Aga’ersen,Aga’ersen Xiang,Agharsin,Aƣarsin,a ga er sen,a ga er sen xiang,yagharsyn,Ағарсин,ئاغارسىن,阿尕尔森,阿尕尔森乡', 43.4872200, 82.4072200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12782, 'Tikerik', 'Tikerik', 'Tik Erik,Tik Erik̩,Tik Eriq,Tik Ériq,Tike Areke,Tike Areke Xiang,Tikerik,Tikerik Xiang,ti ke a re ke,ti ke a re ke xiang,Тик Эрық,تىك ئېرىق,提克阿热克,提克阿热克乡', 43.5169400, 82.0622200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12783, 'Dolati', 'Dolati', 'Dolati,Dolati Xiang,Duolate,Duolate Xiang,duo la te,duo la te xiang,dwlaty,Долати,دولاتى,多拉特,多拉特乡', 46.0106800, 83.6564500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12784, 'Sidaohezi', 'Sidaohezi', 'Sidaohezi,Sidaohezi Zhen,si dao he zi,si dao he zi zhen,四道河子,四道河子镇', 44.6890700, 85.7045600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12785, 'Huanggong', 'Huanggong', 'Huanggong,Huanggong Zhen,huang gong,huang gong zhen,皇宫,皇宫镇', 44.5830400, 84.7702400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12786, 'Ganhezi', 'Ganhezi', 'Ganhezi,Ganhezi Zhen,gan he zi,gan he zi zhen,甘河子,甘河子镇', 44.4607000, 84.5282700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12787, 'Xihu', 'Xihu', 'Shikhu,Shixu,Xihu,Xihu Zhen,xi hu,xi hu zhen,Шиху,شىخۇ,西湖,西湖镇', 44.5337700, 84.6270800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12788, 'Jiujianlou', 'Jiujianlou', 'Jiujianlou,Jiujianlou Xiang,jiu jian lou,jiu jian lou xiang,九间楼,九间楼乡', 44.5410700, 84.8325900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12789, 'Hatu Buh', 'Hatu Buh', 'Hatu Buh,Hatu Buh Zhen,Hatubuhu,Hatubuhu Zhen,ha tu bu hu,ha tu bu hu zhen,哈图布呼,哈图布呼镇', 44.4111300, 84.3071300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12790, 'Xidagou', 'Xidagou', 'Xidagou,Xidagou Zhen,xi da gou,xi da gou zhen,西大沟,西大沟镇', 44.3347800, 84.5790200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12791, 'Liumaowan', 'Liumaowan', 'Liumaowan,Liumaowan Zhen,liu mao wan,liu mao wan zhen,柳毛湾,柳毛湾镇', 44.6024300, 85.9109800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12792, 'Daquan', 'Daquan', 'Daquan,Daquan Xiang,da quan,da quan xiang,大泉,大泉乡', 44.3626400, 85.5807800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12793, 'Jingouhe', 'Jingouhe', 'Jingouhe,Jingouhe Zhen,Korgas,Qorqis,Qorqıs,jin gou he,jin gou he zhen,金沟河,金沟河镇', 44.3136600, 85.6846600, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12794, 'Ulan Us', 'Ulan Us', 'Ulan Us,Ulan Us Xiang,Wulanwusu,Wulanwusu Zhen,wu lan wu su,wu lan wu su zhen,Улан Ус,ئۇلان ئۇس,乌兰乌苏,乌兰乌苏镇', 44.2884800, 85.8573100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12795, 'Dongwan', 'Dongwan', 'Dongwan,Dongwan Zhen,dong wan,dong wan zhen,东湾,东湾镇', 44.0641200, 85.8034000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12796, 'Xigebi', 'Xigebi', 'Xigebi,Xigebi Zhen,xi ge bi,xi ge bi zhen,西戈壁,西戈壁镇', 44.0546700, 85.5171000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12797, 'Yushugou', 'Yushugou', 'Yushugou,Yushugou Zhen,yu shu gou,yu shu gou zhen,榆树沟,榆树沟镇', 44.0467000, 87.1290800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12798, 'Erliugong', 'Erliugong', 'Erliugong,Erliugong Zhen,er liu gong,er liu gong zhen,二六工,二六工镇', 44.0528600, 87.1703600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12799, 'Ershilidian', 'Ershilidian', 'Ershilidian,Ershilidian Zhen,er shi li dian,er shi li dian zhen,二十里店,二十里店镇', 44.1580500, 86.9663000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12800, 'Wugongtai', 'Wugongtai', 'Wugongtai,Wugongtai Xiang,wu gong tai,wu gong tai xiang,五工台,五工台乡', 44.1921200, 86.7962400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12801, 'Dafeng', 'Dafeng', 'Dafeng,Dafeng Zhen,da feng,da feng zhen,大丰,大丰镇', 44.1793200, 86.5909700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12802, 'Letuyi', 'Letuyi', 'Letuyi,Letuyi Zhen,le tu yi,le tu yi zhen,乐土驿,乐土驿镇', 44.1994000, 86.4580800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12803, 'Baojiadian', 'Baojiadian', 'Baojiadian,Baojiadian Zhen,bao jia dian,bao jia dian zhen,包家店,包家店镇', 44.2487200, 86.3067000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12804, 'Changshanzi', 'Changshanzi', 'Changshanzi,Changshanzi Zhen,zhang shan zi,zhang shan zi zhen,长山子,长山子镇', 44.0886400, 87.6122000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12805, 'Sandaoba', 'Sandaoba', 'Sandaoba,Sandaoba Zhen,san dao ba,san dao ba zhen,三道坝,三道坝镇', 44.1280100, 87.6208300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12806, 'Yangmaogong', 'Yangmaogong', 'Yangmaogong,Yangmaogong Zhen,yang mao gong,yang mao gong zhen,羊毛工,羊毛工镇', 44.1584000, 87.5857800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12807, 'Liugong', 'Liugong', 'Liugong,Liugong Zhen,liu gong,liu gong zhen,六工,六工镇', 44.0761300, 87.4022100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12808, 'Daxiqu', 'Daxiqu', 'Daxiqu,Daxiqu Xiang,da xi qu,da xi qu xiang,大西渠,大西渠乡', 44.1069500, 87.2765300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12809, 'Dianba', 'Dianba', 'Dianba,Dianba Xiang,dian ba,dian ba xiang,佃坝,佃坝乡', 44.1244800, 87.3296400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12810, 'Xibeiwan', 'Xibeiwan', 'Xibeiwan,Xibeiwan Xiang,xi bei wan,xi bei wan xiang,西北湾,西北湾乡', 44.0728900, 89.5619300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12811, 'Beiting', 'Beiting', 'Beiting,Beiting Zhen,bei ting,bei ting zhen,北庭,北庭镇', 44.0638500, 89.2090100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12812, 'Qingyanghu', 'Qingyanghu', 'Qingyanghu,Qingyanghu Xiang,qing yang hu,qing yang hu xiang,庆阳湖,庆阳湖乡', 44.0825300, 88.9651500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12813, 'Laotai', 'Laotai', 'Laotai,Laotai Xiang,lao tai,lao tai xiang,老台,老台乡', 44.1187300, 88.8642300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12814, 'Qoren', 'Qoren', 'Choren,Chorén,Qiren,Qiren Hasakezu,Qiren Hasakezu Xiang,Qoren,Qoren Xiang,qi ren,qi ren ha sa ke zu,qi ren ha sa ke zu xiang,Чорен,چورېن,齐仁,齐仁哈萨克族,齐仁哈萨克族乡', 44.0643700, 90.0584900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12815, 'Hujirti Mongolzuxiang', 'Hujirti Mongolzuxiang', 'Hujirti Mongolzuxiang,Huoji''erte,Huoji''erte Mengguzu,Huoji''erte Mengguzu Xiang,Huoji’erte,Huoji’erte Mengguzu,Huoji’erte Mengguzu Xiang,huo ji er te,huo ji er te meng gu zu,huo ji er te meng gu zu xiang,霍吉尔特,霍吉尔特蒙古族,霍吉尔特蒙古族乡', 46.3699400, 83.8371100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12816, 'Emalgolin Mongolzuxiang', 'Emalgolin Mongolzuxiang', 'Emaleguoleng,Emaleguoleng Mengguzu,Emaleguoleng Mengguzu Xiang,Emalgolin Mongolzuxiang,e ma lei guo leng,e ma lei guo leng meng gu zu,e ma lei guo leng meng gu zu xiang,额玛勒郭楞,额玛勒郭楞蒙古族,额玛勒郭楞蒙古族乡', 46.6707500, 84.0073900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12817, 'Saparbay', 'Saparbay', 'Saparbaj,Saparbay,Sepabayi,Sepabayi Xiang,saparbay,se pa ba yi,se pa ba yi xiang,Сапарбай,ساپارباي,色帕巴依,色帕巴依乡', 40.9188900, 78.7227800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12818, 'Yimamu', 'Yimamu', 'Imamlirim,Yimamu,Yimamu Xiang,yi ma mu,yi ma mu xiang,yymamlyrym,Имамлирим,ئىماملىرىم,依麻木,依麻木乡', 41.2041700, 79.4580600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12819, 'Yamansu', 'Yamansu', 'Jamansu,Yamansu,Yamansu Ke''erkezizu Xiang,Yamansu Ke’erkezizu Xiang,ya man su,ya man su ke er ke zi zu xiang,Ямансу,يامانسۇ,亚曼苏,亚曼苏柯尔克孜族乡', 41.1491700, 79.0850000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12820, 'Yengimahalla', 'Yengimahalla', 'Yengimahalla,Yengimehelle,Yengiməh̨əllə,Yingmaili,Yingmaili Zhen,Yéngimehelle,ying mai li,ying mai li zhen,Еңимәһәллә,يېڭىمەھەللە,英买力,英买力镇', 41.3463900, 82.6508300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12821, 'Payxambabazar', 'Payxambabazar', 'Paixianbaibazha,Paixianbaibazha Xiang,Payxambabazar,Peyshenbebazar,Pəyxənbəbazar,pai xian bai ba zha,pai xian bai ba zha xiang,Пәйшәнбәбазар,پەيشەنبەبازار,排先拜巴扎,排先拜巴扎乡', 41.4508300, 82.5766000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12822, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,hong qi,hong qi zhen,红旗,红旗镇', 41.4424400, 82.8609600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12823, 'Alakaga', 'Alakaga', 'Alahage,Alahage Zhen,Alakaga,Alak̩aƣa,Alaqagha,a la ha ge,a la ha ge zhen,yalaqagha,Алақаға,ئالاقاغا,阿拉哈格,阿拉哈格镇', 41.5466700, 82.7663900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12824, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Xiang,da qiao,da qiao xiang,大桥,大桥乡', 41.6308300, 81.5552800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12825, 'Hechen', 'Hechen', 'Hechen,Hechen Zhen,Shechen,Shechenzhuang,he chen,he chen zhen,she chen,she chen zhuang,合陈,合陈镇,舍陈,舍陈庄', 33.0057600, 120.2367800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12826, 'Xiaohai', 'Xiaohai', 'Xiaohai,Xiaohai Zhen,xiao hai,xiao hai zhen,小海,小海镇', 33.0295600, 120.4759600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12827, 'Guanyinsi', 'Guanyinsi', 'Guanyinsi,Xinduo,Xinduo Zhen,guan yin si,xin duo,xin duo zhen,新垛,新垛镇,观音寺', 33.0877400, 120.1798900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12828, 'Xindu', 'Xindu', 'Xindu,Xindu Jiedao,Yandu,Yandu Qu,xin dou,xin dou jie dao,yan dou,yan dou qu,新都,新都街道,盐都,盐都区', 33.3398700, 120.1459400, 'CN', '2014-04-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12829, 'Gaojiazhuang', 'Gaojiazhuang', 'Gaojiazhuang,Hainan,Hainan Zhen,gao jia zhuang,hai nan,hai nan zhen,海南,海南镇,高家庄', 33.0445900, 119.9830000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12830, 'Taihua', 'Taihua', 'Taihua,Taihua Zhen,tai hua,tai hua zhen,太华,太华镇', 31.1819500, 119.5832100, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12831, 'Xizhu', 'Xizhu', 'Xizhu,Xizhu Zhen,xi zhu,xi zhu zhen,西渚,西渚镇', 31.2892400, 119.5672700, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12832, 'Xinzhuang', 'Xinzhuang', 'Xinzhuang,Xinzhuang Jiedao,xin zhuang,xin zhuang jie dao,新庄,新庄街道', 31.3538600, 119.9081000, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12833, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Jiedao,xin jie,xin jie jie dao,新街,新街街道', 31.3689500, 119.7494900, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12834, 'Wanshi', 'Wanshi', 'Wanshi,Wanshi Zhen,wan shi,wan shi zhen,万石,万石镇', 31.4758700, 119.9274900, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12835, 'Xinjian', 'Xinjian', 'Xinjian,Xinjian Zhen,xin jian,xin jian zhen,新建,新建镇', 31.5617300, 119.6572800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12836, 'Zhuze', 'Zhuze', 'Zhuze,Zhuze Zhen,zhu ze,zhu ze zhen,竹箦,竹箦镇', 31.5611400, 119.3247100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12837, 'Jingqiao', 'Jingqiao', 'Jingqiao,Jingqiao Zhen,jing qiao,jing qiao zhen,晶桥,晶桥镇', 31.5338900, 119.0607200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12838, 'Jiaze', 'Jiaze', 'Jiaze,Jiaze Zhen,jia ze,jia ze zhen,嘉泽,嘉泽镇', 31.6865900, 119.7857000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12839, 'Xilin', 'Xilin', 'Xilin,Xilin Jiedao,xi lin,xi lin jie dao,西林,西林街道', 31.7689800, 119.8861600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12840, 'Beigang', 'Beigang', 'Beigang,Beigang Jiedao,Zhonglou Qu,bei gang,bei gang jie dao,zhong lou qu,北港,北港街道,钟楼区', 31.7973500, 119.8785700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12841, 'Maoshan', 'Maoshan', 'Maoshan,Maoshan Zhen,mao shan,mao shan zhen,茅山,茅山镇', 31.7915400, 119.2959200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12842, 'Jianchang', 'Jianchang', 'Jianchang,Jianchang Zhen,jian chang,jian chang zhen,建昌,建昌镇', 31.8207800, 119.4941100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12843, 'Baizhang', 'Baizhang', 'Baizhang,Baizhang Zhen,Pai-ch''uan-chen,Pai-chang,Pai-chang-chen,Pai-ch’üan-chen,bai zhang,bai zhang zhen,百丈,百丈镇', 31.9225400, 119.9705500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12844, 'Luoxi', 'Luoxi', 'Luoxi,Luoxi Zhen,luo xi,luo xi zhen,罗溪,罗溪镇', 31.9044300, 119.8034500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12845, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 32.0035500, 120.0672200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12846, 'Changdai', 'Changdai', 'Changdai,Maqiao,Maqiao Zhen,ma qiao,ma qiao zhen,zhang dai,长垈,马桥,马桥镇', 32.0361100, 120.2166700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12847, 'Shengci', 'Shengci', 'Shengci,Shengci Zhen,sheng ci,sheng ci zhen,生祠,生祠镇', 32.0361100, 120.1638900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12848, 'Hongguang', 'Hongguang', 'Hongguang,Hongguang Zhen,hong guang,hong guang zhen,红光,红光镇', 32.0630200, 120.1060900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12849, 'Jiang’an', 'Jiang''an', 'Jiang''an,Jiang''an Zhen,Jiang’an,Jiang’an Zhen,jiang an,jiang an zhen,江安,江安镇', 32.1738200, 120.4094500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12850, 'Shanhu', 'Shanhu', 'Shanhu,Shanhu Zhen,shan hu,shan hu zhen,珊瑚,珊瑚镇', 32.1792100, 120.3184000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12851, 'Nansha', 'Nansha', 'Fengjiadai,Nansha,Nansha Zhen,feng jia dai,nan sha,nan sha zhen,南沙,南沙镇,封家垈', 32.1728400, 120.2199700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12852, 'Changqing', 'Changqing', 'Changqing,Changqing Zhen,chang qing,chang qing zhen,常青,常青镇', 32.2577500, 120.4538200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12853, 'Gaoming', 'Gaoming', 'Gaoming,Gaoming Zhen,gao ming,gao ming zhen,高明,高明镇', 32.2503000, 120.3709800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12854, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃园,桃园镇', 32.2956300, 120.6070300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12855, 'Liuchen', 'Liuchen', 'Baijiazhuang,Liuchen,Liuchen Zhen,bai jia zhuang,liu chen,liu chen zhen,刘陈,刘陈镇,白家庄', 32.2666700, 120.1500000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12856, 'Hengduo', 'Hengduo', 'Hengduo,Hengduo Zhen,Hengjiaduo,heng duo,heng duo zhen,heng jia duo,横垛,横垛镇,横家垛', 32.3161400, 120.2765600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12857, 'Yuanzhu', 'Yuanzhu', 'Dayuanduo,Yuanzhu,Yuanzhu Zhen,da yuan duo,yuan zhu,yuan zhu zhen,元竹,元竹镇,大元垛', 32.3241500, 120.1748400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12858, 'Yuanzhuang', 'Yuanzhuang', 'Yuanzhuang,Yuanzhuang Zhen,yuan zhuang,yuan zhuang zhen,袁庄,袁庄镇', 32.4479800, 120.7726900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12859, 'Xue’an', 'Xue''an', 'Xue''an,Xue''an Zhen,Xue’an,Xue’an Zhen,xue an,xue an zhen,雪岸,雪岸镇', 32.4586600, 120.6901600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12860, 'Liangxu', 'Liangxu', 'Liangxu,Liangxu Zhen,liang xu,liang xu zhen,梁徐,梁徐镇', 32.4702400, 120.1140500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12861, 'Xichang', 'Xichang', 'Hsi-ch''ang,Hsi-ch''ang-chen,Hsi-ch’ang,Hsi-ch’ang-chen,Xichang,Xichang Zhen,xi chang,xi chang zhen,西场,西场镇', 32.5250000, 120.5916700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12862, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 32.5500000, 120.0694400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12863, 'Jiaoxie', 'Jiaoxie', 'Chiao-hsieh,Chiao-hsieh-chen,Jiaoxie,Jiaoxie Zhen,jiao xie,jiao xie zhen,角斜,角斜镇', 32.5723200, 120.7836300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12864, 'Shengao', 'Shengao', 'Dingjiashe,Shengao,Shengao Zhen,chen gao,chen gao zhen,ding jia she,丁家舍,沈高,沈高镇', 32.5861100, 120.1333300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12865, 'Dagong', 'Dagong', 'Dagong,Dagong Zhen,da gong,da gong zhen,大公,大公镇', 32.6151900, 120.5185500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12866, 'Yuduo', 'Yuduo', 'Yuduo,Yuduo Zhen,Yujiaduo,shu duo,shu duo zhen,shu jia duo,俞垛,俞垛镇,俞家垛', 32.6407700, 120.0128300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12867, 'Baidian', 'Baidian', 'Baidian,Baidian Zhen,bai dian,bai dian zhen,白甸,白甸镇', 32.6708700, 120.2570000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12868, 'Xingtai', 'Xingtai', 'Xiaodianzhi,Xingtai,xiao dian zhi,xing tai,兴泰,小甸址', 32.6861100, 120.0750000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12869, 'Fudong', 'Fudong', 'Fudong,Fudong Zhen,fu dong,fu dong zhen,富东,富东镇', 32.7194400, 120.5583300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12870, 'Tainan', 'Tainan', 'Heluolun,Tainan,Tainan Zhen,he luo lun,tai nan,tai nan zhen,台南,台南镇,鹤落埨', 32.7620500, 120.2694400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12871, 'Zhaowanzhuang', 'Zhaowanzhuang', 'Zhangguo,Zhangguo Zhen,Zhaowanzhuang,zhang guo,zhang guo zhen,zhao wan zhuang,张郭,张郭镇,赵万庄', 32.7448600, 120.1666700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12872, 'Taozhuang', 'Taozhuang', 'Taozhuang,Taozhuang Zhen,tao zhuang,tao zhuang zhen,陶庄,陶庄镇', 32.8666700, 120.1388900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12873, 'Daiyao', 'Daiyao', 'Daijiayao,Daiyao,Daiyao Zhen,Hsing-tung,Tai-chia-yao,Tai-chia-yao-chen,Tai-yao,Tai-yao-chen,Yao-tai,dai yao,dai yao zhen,戴窑,戴窑镇', 32.9291300, 120.2142600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12874, 'Changrong', 'Changrong', 'Changrong,Changrong Zhen,chang rong,chang rong zhen,昌荣,昌荣镇', 32.9439800, 120.0805300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12875, 'Situ', 'Situ', 'Situ,Situ Zhen,si tu,si tu zhen,司徒,司徒镇', 32.0035400, 119.5000600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12876, 'Jiepai', 'Jiepai', 'Jiepai,Jiepai Zhen,jie pai,jie pai zhen,界牌,界牌镇', 32.0730000, 119.8534300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12877, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 32.0743800, 119.8063100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12878, 'Houxiang', 'Houxiang', 'Houxiang,Houxiang Zhen,hou xiang,hou xiang zhen,后巷,后巷镇', 32.1032200, 119.7619000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12879, 'Dinggang', 'Dinggang', 'Dinggang,Dinggang Zhen,ding gang,ding gang zhen,丁岗,丁岗镇', 32.1436100, 119.6853700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12880, 'Baohua', 'Baohua', 'Baohua,Baohua Zhen,bao hua,bao hua zhen,宝华,宝华镇', 32.1456100, 119.0368600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12881, 'Xiangshan', 'Xiangshan', 'Xiangshan,Xiangshan Zhen,xiang shan,xiang shan zhen,象山,象山镇', 32.1942700, 119.5285300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12882, 'Shiye', 'Shiye', 'Shiye,Shiye Zhen,shi ye,shi ye zhen,世业,世业镇', 32.2137800, 119.3036200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12883, 'Minggou', 'Minggou', 'Minggou,Minggoucun,Yong''anzhou,Yong''anzhou Zhen,Yong’anzhou,Yong’anzhou Zhen,ming gou,ming gou cun,yong an zhou,yong an zhou zhen,明沟,明沟村,永安洲,永安洲镇', 32.2491700, 119.9075000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12884, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Zhen,qing shan,qing shan zhen,青山,青山镇', 32.2522200, 119.0733400, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12885, 'Bali', 'Bali', 'Bali,Bali Zhen,ba li,ba li zhen,八里,八里镇', 32.2907700, 119.3991800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12886, 'Shatou', 'Shatou', 'Shatou,Shatou Zhen,sha tou,sha tou zhen,沙头,沙头镇', 32.3087600, 119.5216600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12887, 'Xuzhuang', 'Xuzhuang', 'Xuzhuang,Xuzhuang Jiedao,xu zhuang,xu zhuang jie dao,许庄,许庄街道', 32.3562700, 119.9073000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12888, 'Hangji', 'Hangji', 'Hangji,Hangji Zhen,hang ji,hang ji zhen,杭集,杭集镇', 32.3681500, 119.5330000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12889, 'Chahe', 'Chahe', 'Chahe,Chahe Jiedao,cha he,cha he jie dao,汊河,汊河街道', 32.3390700, 119.3813900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12890, 'Tangwang', 'Tangwang', 'Tangwang,Tangwang Xiang,tang wang,tang wang xiang,汤王,汤王乡', 32.3700300, 119.4596300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12891, 'Yexu', 'Yexu', 'Yexu,Yexu Zhen,ye xu,ye xu zhen,野徐,野徐镇', 32.3937000, 119.9290400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12892, 'Sixiang', 'Sixiang', 'Sixiang,Sixiang Zhen,si xiang,si xiang zhen,寺巷,寺巷镇', 32.4134200, 119.8854800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12893, 'Wantou', 'Wantou', 'Wantou,Wantou Zhen,wan tou,wan tou zhen,湾头,湾头镇', 32.4252100, 119.4883800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12894, 'Xihu', 'Xihu', 'Xihu,Xihu Zhen,xi hu,xi hu zhen,西湖,西湖镇', 32.4261100, 119.3944100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12895, 'Tai’an', 'Tai''an', 'Tai''an,Tai''an Zhen,Tai’an,Tai’an Zhen,tai an,tai an zhen,泰安,泰安镇', 32.4577300, 119.5108300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12896, 'Jingtailu', 'Jingtailu', 'Jingtailu,Jingtailu Jiedao,Jiuliqiao,Taidong,Taidong Zhen,jing tai lu,jing tai lu jie dao,jiu li qiao,tai dong,tai dong zhen,九里桥,京泰路,京泰路街道,泰东,泰东镇', 32.5047100, 119.9717300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12897, 'Dinghuo', 'Dinghuo', 'Dinghuo,Dinghuo Zhen,ding huo,ding huo zhen,丁伙,丁伙镇', 32.5233200, 119.6070800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12898, 'Tianshan', 'Tianshan', 'Tianshan,Tianshan Zhen,tian shan,tian shan zhen,天山,天山镇', 32.6235500, 119.2483300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12899, 'Guoji', 'Guoji', 'Guoji,Guoji Zhen,guo ji,guo ji zhen,郭集,郭集镇', 32.6980000, 119.3272300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12900, 'Chenbao', 'Chenbao', 'Chenbao,Chenbao Zhen,chen bao,chen bao zhen,陈堡,陈堡镇', 32.7589300, 119.8851200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12901, 'Wujian', 'Wujian', 'Wujian,Wujian Zhen,wu jian,wu jian zhen,武坚,武坚镇', 32.7554800, 119.7790200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12902, 'Hanliu', 'Hanliu', 'Hanliu,Hanliu Zhen,han liu,han liu zhen,汉留,汉留镇', 32.7634700, 119.6673500, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12903, 'Xiejia', 'Xiejia', 'Xiejia,Xiejia Zhen,xie jia,xie jia zhen,卸甲,卸甲镇', 32.7615400, 119.5931400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12904, 'Lincheng', 'Lincheng', 'Lincheng,Lincheng Zhen,lin cheng,lin cheng zhen,临城,临城镇', 32.8881700, 119.8324900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12905, 'Duotian', 'Duotian', 'Duotian,Duotian Zhen,duo tian,duo tian zhen,垛田,垛田镇', 32.9275700, 119.8583200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12906, 'Zhoushan', 'Zhoushan', 'Zhoushan,Zhoushan Zhen,zhou shan,zhou shan zhen,周山,周山镇', 32.9729400, 119.5110800, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12907, 'Danyang', 'Danyang', 'Danyang,Danyang Zhen,dan yang,dan yang zhen,丹阳,丹阳镇', 31.6292200, 118.7156500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12908, 'Zhougang', 'Zhougang', 'Zhougang,Zhougang Zhen,zhou gang,zhou gang zhen,周岗,周岗镇', 31.7970300, 118.9607300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12909, 'Jiangxinzhou', 'Jiangxinzhou', 'Jiangxinzhou,Jiangxinzhou Jiedao,jiang xin zhou,jiang xin zhou jie dao,江心洲,江心洲街道', 32.0094700, 118.6948900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12910, 'Xiaoshi', 'Xiaoshi', 'Xiaoshi,Xiaoshi Jiedao,Xiaoshizhen,xiao shi,xiao shi jie dao,小市,小市街道', 32.0972500, 118.7818100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12911, 'Taishan', 'Taishan', 'Taishan,Taishan Jiedao,Taishanxinzhen,tai shan,tai shan jie dao,泰山,泰山街道', 32.1505900, 118.7047500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12912, 'Longpao', 'Longpao', 'Longpao,Longpao Zhen,long pao,long pao zhen,龙袍,龙袍镇', 32.1985200, 118.9500300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12913, 'Yudai', 'Yudai', 'Yudai,Yudai Zhen,yu dai,yu dai zhen,玉带,玉带镇', 32.2259000, 118.9031000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12914, 'Baguazhou', 'Baguazhou', 'Baguazhou,Baguazhou Jiedao,ba gua zhou,ba gua zhou jie dao,八卦洲,八卦洲街道', 32.1735200, 118.8167400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12915, 'Yanjiang', 'Yanjiang', 'Yanjiang,Yanjiang Jiedao,yan jiang,yan jiang jie dao,沿江,沿江街道', 32.1638300, 118.7115000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12916, 'Changlu', 'Changlu', 'Changlu,Changlu Jiedao,zhang lu,zhang lu jie dao,长芦,长芦街道', 32.2624100, 118.7874300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12917, 'Xinhuang', 'Xinhuang', 'Xinhuang,Xinhuang Zhen,xin huang,xin huang zhen,新篁,新篁镇', 32.3748000, 118.9397900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12918, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Zhen,Ma’an,Ma’an Zhen,ma an,ma an zhen,马鞍,马鞍镇', 32.4078300, 118.8259500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12919, 'Yeshan', 'Yeshan', 'Yeshan,Yeshan Zhen,ye shan,ye shan zhen,冶山,冶山镇', 32.5141400, 118.9135500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12920, 'Wangdian', 'Wangdian', 'Wangdian,Wangdian Xiang,wang dian,wang dian xiang,王店,王店乡', 32.7917600, 118.5839900, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12921, 'Guiwu', 'Guiwu', 'Guiwu,Guiwu Zhen,gui wu,gui wu zhen,桂五,桂五镇', 32.8689400, 118.5092000, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12922, 'Gusang', 'Gusang', 'Gusang,Gusang Xiang,gu sang,gu sang xiang,古桑,古桑乡', 32.9575700, 118.5053100, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12923, 'Huayuan', 'Huayuan', 'Huayuan,Huayuan Xiang,hua yuan,hua yuan xiang,花园,花园乡', 34.0750000, 119.4500000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12924, 'Tangjian', 'Tangjian', 'Tangjian,Tangjian Zhen,tang jian,tang jian zhen,汤涧,汤涧镇', 34.1333300, 119.0041700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12925, 'Changmao', 'Changmao', 'Changmao,Changmao Zhen,zhang mao,zhang mao zhen,长茂,长茂镇', 34.2166700, 119.5750000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12926, 'Mengxingzhuang', 'Mengxingzhuang', 'Mengxingzhuang,Mengxingzhuang Zhen,meng xing zhuang,meng xing zhuang zhen,孟兴庄,孟兴庄镇', 34.1750000, 119.2166700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12927, 'Tuhe', 'Tuhe', 'Tuhe,Tuhe Xiang,tu he,tu he xiang,图河,图河乡', 34.3333300, 119.5500000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12928, 'Baixian', 'Baixian', 'Baixian,Baixian Xiang,bai xian,bai xian xiang,白蚬,白蚬乡', 34.3250000, 119.3333300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12929, 'Muxu', 'Muxu', 'Muxu,Muxu Xiang,mu wei,mu wei xiang,穆圩,穆圩乡', 34.3916700, 119.1125000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12930, 'Gaoxu', 'Gaoxu', 'Gaoxu,Gaoxu Zhen,gao xu,gao xu zhen,高墟,高墟镇', 34.3333300, 119.0083300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12931, 'Duigougang', 'Duigougang', 'Duigougang,Duigougang Zhen,dui gou gang,dui gou gang zhen,堆沟港,堆沟港镇', 34.4166700, 119.7750000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12932, 'Xufeng', 'Xufeng', 'Xufeng,Xufeng Zhen,wei feng,wei feng zhen,圩丰,圩丰镇', 34.4500000, 119.5500000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12933, 'Gaogongdao', 'Gaogongdao', 'Gaogongdao,Gaogongdao Xiang,gao gong dao,gao gong dao xiang,高公岛,高公岛乡', 34.6958300, 119.4750000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12934, 'Zhongyun', 'Zhongyun', 'Zhongyun,Zhongyun Jiedao,zhong yun,zhong yun jie dao,中云,中云街道', 34.6500000, 119.4083300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12935, 'Yunshan', 'Yunshan', 'Yunshan,Yunshan Jiedao,yun shan,yun shan jie dao,云山,云山街道', 34.7000000, 119.3666700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12936, 'Huaguoshan', 'Huaguoshan', 'Huaguoshan,Huaguoshan Xiang,hua guo shan,hua guo shan xiang,花果山,花果山乡', 34.6416700, 119.2333300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12937, 'Luoyang', 'Luoyang', 'Luoyang,Luoyang Zhen,luo yang,luo yang zhen,罗阳,罗阳镇', 34.7108100, 119.1070200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12938, 'Songzhuang', 'Songzhuang', 'Songzhuang,Songzhuang Zhen,song zhuang,song zhuang zhen,宋庄,宋庄镇', 34.7833200, 119.1402400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12939, 'Youyupu', 'Youyupu', 'Youyupu,Yu-yu-p''u,Yu-yü-p’u,you yu pu,鱿鱼铺', 27.5517000, 109.1350000, 'CN', '2015-02-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12940, 'Zhujiachang', 'Zhujiachang', 'Chu-chia-ch''ang,Chu-chia-ch’ang,Zhujiachang', 27.3575000, 108.9383300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12941, 'Xujiaba', 'Xujiaba', 'Hsu-chia-pa,Hsü-chia-pa,Xujiaba', 27.8847200, 108.1136100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12942, 'Pingtou', 'Pingtou', 'Pingtou,Pingtou Xiang,ping tou,ping tou xiang,平头,平头乡', 28.0350700, 109.0678000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12943, 'Changping', 'Changping', 'Changping,Changping Xiang,Wuga,wu ga,zhang ping,zhang ping xiang,务旮,长坪,长坪乡', 28.0986100, 109.2755000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12944, 'Jiujiang', 'Jiujiang', 'Jiujiang,Jiujiang Zhen,jiu jiang,jiu jiang zhen,九江,九江镇', 28.1675000, 109.1277300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12945, 'Miao’ai', 'Miao''ai', 'Miao''ai,Miao''ai Xiang,Miao’ai,Miao’ai Xiang,miao ai,miao ai xiang,妙隘,妙隘乡', 28.1737600, 109.0215400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12946, 'Mushu', 'Mushu', 'Mushu,Mushu Xiang,mu shu,mu shu xiang,木树,木树乡', 28.3833300, 109.2597200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12947, 'Yajia', 'Yajia', 'Yajia,Yajia Zhen,ya jia,ya jia zhen,迓驾,迓驾镇', 28.4548200, 109.1842600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12948, 'Xinye', 'Xinye', 'Xinye,Xinye Xiang,xin ye,xin ye xiang,新业,新业乡', 28.0397200, 108.6938900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12949, 'Kuanping', 'Kuanping', 'Kuanping,Kuanping Tujiazu Miaozu Xiang,kuan ping,kuan ping tu jia zu miao zu xiang,宽坪,宽坪土家族苗族乡', 28.0245400, 108.0170200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12950, 'Lengshuixi', 'Lengshuixi', 'Lengshuixi,Lengshuixi Xiang,leng shui xi,leng shui xi xiang,冷水溪,冷水溪乡', 28.1421500, 108.8680700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12951, 'Shanshu', 'Shanshu', 'Shanshu,Shanshu Xiang,Shanshu''ao,Shanshu’ao,shan shu,shan shu xiang,杉树,杉树乡', 28.1113900, 108.4113900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12952, 'Donghua', 'Donghua', 'Donghua,Donghua Tujiazu Miaozu Xiang,Donghuaxi,dong hua,dong hua tu jia zu miao zu xiang,dong hua xi,东华,东华土家族苗族乡,东华溪', 28.0799400, 108.0882100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12953, 'Hexing', 'Hexing', 'Hexing,Hexing Tujiazu Xiang,Puziwan,he xing,he xing tu jia zu xiang,pu zi wan,合兴,合兴土家族乡,铺子湾', 28.1015400, 108.0623300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12954, 'Shiliang', 'Shiliang', 'Shiliang,Shiliang Xiang,shi liang,shi liang xiang,石梁,石梁乡', 28.1728800, 108.7517200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12955, 'Changbao', 'Changbao', 'Changbao,Changbao Tujiazu Xiang,zhang bao,zhang bao tu jia zu xiang,长堡,长堡土家族乡', 28.1897200, 108.2780600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12956, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Xiang,Yong’an,Yong’an Xiang,yong an,yong an xiang,永安,永安乡', 28.2416100, 108.6749200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12957, 'Daoba', 'Daoba', 'Daoba,Daoba Xiang,dao ba,dao ba xiang,刀坝,刀坝乡', 28.2401900, 108.5849000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12958, 'Yantang', 'Yantang', 'Meiziba,Yantang,Yantang Tujiazu Xiang,mei zi ba,yan tang,yan tang tu jia zu xiang,堰塘,堰塘土家族乡,梅子坝', 28.2239200, 108.1054800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12959, 'Qianjia', 'Qianjia', 'Qianjia,Qianjia Tujiazu Xiang,Waduanliang,qian jia,qian jia tu jia zu xiang,wa duan liang,挖断梁,钱家,钱家土家族乡', 28.2968400, 108.0758300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12960, 'Jiashi', 'Jiashi', 'Jiashi,Jiashi Zhen,jia shi,jia shi zhen,夹石,夹石镇', 28.3333200, 108.3313400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12961, 'Jingjiao', 'Jingjiao', 'Jingjiao,Jingjiao Tujiazu Xiang,jing jiao,jing jiao tu jia zu xiang,荆角,荆角土家族乡', 28.3666700, 108.1833300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12962, 'Waxi', 'Waxi', 'Dalu,Waxi,Waxi Xiang,da lu,wa xi,wa xi xiang,大路,瓦溪,瓦溪乡', 28.4429700, 108.6798300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12963, 'Zhongjie', 'Zhongjie', 'Zhongjie,Zhongjie Xiang,zhong jie,zhong jie xiang,中界,中界乡', 28.4639000, 108.5446800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12964, 'Shichao', 'Shichao', 'Shichao,Shichao Xiang,shi chao,shi chao xiang,石朝,石朝乡', 28.4097100, 108.0401500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12965, 'Qinglong', 'Qinglong', 'Dejiang Xian,Qinglong,de jiang xian,qing long,德江县,青龙', 28.2629100, 108.1123400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12966, 'Quanba', 'Quanba', 'Quanba,Quanba Xiang,quan ba,quan ba xiang,泉坝,泉坝乡', 28.5208100, 108.1910000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12967, 'Zhongzhai', 'Zhongzhai', 'Zhayouwan,Zhongzhai,Zhongzhai Xiang,zha you wan,zhong zhai,zhong zhai xiang,中寨,中寨乡,炸油湾', 28.5811600, 108.1654500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12968, 'Heita', 'Heita', 'Heita,Heita Xiang,hei ta,hei ta xiang,黑獭,黑獭乡', 28.6315500, 108.5070700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12969, 'Heishui', 'Heishui', 'Heishui,Heishui Xiang,Heishuichang,hei shui,hei shui chang,hei shui xiang,黑水,黑水乡,黑水场', 28.5943500, 108.4397500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12970, 'Hongsi', 'Hongsi', 'Hongsi,Hongsi Xiang,hong si,hong si xiang,红丝,红丝乡', 28.7221900, 108.1144800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12971, 'Xinjing', 'Xinjing', 'Xinjing,Xinjing Xiang,xin jing,xin jing xiang,新景,新景乡', 28.8869400, 108.2991700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12972, 'Maotian', 'Maotian', 'Maotian,Maotian Zhen,mao tian,mao tian zhen,茅天,茅天镇', 28.9452600, 108.0843500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12973, 'Gouping', 'Gouping', 'Gouping,Gouping Xiang,gou ping,gou ping xiang,垢坪,垢坪乡', 28.9877100, 108.1429400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12974, 'Maoya', 'Maoya', 'Maoya,Maoya Zhen,mao ya,mao ya zhen,茅垭,茅垭镇', 28.0931900, 107.1653800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12975, 'Xinjian', 'Xinjian', 'Xinjian,Xinjian Xiang,Zhujiachang,xin jian,xin jian xiang,zhu jia chang,新建,新建乡,朱家场', 28.1904800, 107.6728400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12976, 'Xihe', 'Xihe', 'Xihe,Xihe Xiang,xi he,xi he xiang,西河,西河乡', 28.1523600, 107.5314400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12977, 'Nangan', 'Nangan', 'Nangan,Nangan Tujiazu Xiang,Xinjie,nan gan,nan gan tu jia zu xiang,xin jie,新街,楠杆,楠杆土家族乡', 28.2769300, 107.8829600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12978, 'Shiping', 'Shiping', 'Shiping,Shiping Miaozu Gelaozu Xiang,Yinbao,shi ping,shi ping miao zu ge lao zu xiang,yin bao,市坪,市坪苗族仡佬族乡,银堡', 28.2787200, 107.6022500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12979, 'Pingle', 'Pingle', 'Dingjiabao,Pingle,Pingle Xiang,ding jia bao,ping le,ping le xiang,丁家堡,坪乐,坪乐乡', 28.2124500, 107.4618000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12980, 'Shaxi', 'Shaxi', 'Shaxi,Shaxi Tujiazu Xiang,Wanba,sha xi,sha xi tu jia zu xiang,wan ba,万坝,沙溪,沙溪土家族乡', 28.3175200, 107.9889400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12981, 'Hexi', 'Hexi', 'Hexi,Hexi Zhen,he xi,he xi zhen,和溪,和溪镇', 28.4566700, 107.4336100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12982, 'Banzhu', 'Banzhu', 'Banzhu,Banzhu Xiang,Banzhuyuan,ban zhu,ban zhu xiang,ban zhu yuan,斑竹,斑竹乡,斑竹园', 28.5763900, 107.6119400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12983, 'Jianping', 'Jianping', 'Jianping,Jianping Xiang,jian ping,jian ping xiang,俭平,俭平乡', 28.5172600, 107.4906200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12984, 'Huanglian', 'Huanglian', 'Huanglian,Huanglian Xiang,Huanglianba,huang lian,huang lian ba,huang lian xiang,黄连,黄连乡,黄连坝', 28.4883300, 107.0080600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12985, 'Nigao', 'Nigao', 'Nigao,Nigao Xiang,ni gao,ni gao xiang,泥高,泥高乡', 28.6917500, 107.8074500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12986, 'Zongping', 'Zongping', 'Zongping,Zongping Xiang,zong ping,zong ping xiang,棕坪,棕平乡', 28.6729500, 107.6537400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12987, 'Yangxing', 'Yangxing', 'Yangxing,Yangxing Zhen,yang xing,yang xing zhen,杨兴,杨兴镇', 28.7097200, 107.3864300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12988, 'Bifeng', 'Bifeng', 'Bifeng,Bifeng Xiang,Xiabachang,bi feng,bi feng xiang,xia ba chang,下坝场,碧峰,碧峰乡', 28.6979500, 107.3396200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12989, 'Pingmu', 'Pingmu', 'Pingmu,Pingmu Zhen,ping mo,ping mo zhen,平模,平模镇', 28.8255200, 107.4429900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12990, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Xiang,tao yuan,tao yuan xiang,桃源,桃源乡', 28.8835300, 107.7562300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12991, 'Yangxi', 'Yangxi', 'Yangxi,Yangxi Zhen,yang xi,yang xi zhen,阳溪,阳溪镇', 29.0900000, 107.5819400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12992, 'Supu', 'Supu', 'Supu,Supu Zhen,su pu,su pu zhen,素朴,素朴镇', 26.9916700, 106.3416700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12993, 'Zhuchang', 'Zhuchang', 'Zhuchang,Zhuchang Buyizhu Yizhu Xiang,zhu chang,zhu chang bu yi zu yi zu xiang,猪场,猪场布依族彝族乡', 26.8000000, 105.1166700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12994, 'Sanchahe', 'Sanchahe', 'San-ch''a,San-ch’a,Sanchahe', 28.4952800, 106.4283300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12995, 'Changqi', 'Changqi', 'Changqi,Changqi Zhen,zhang qi,zhang qi zhen,长期,长期镇', 28.6199200, 106.0681600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12996, 'Tiantai', 'Tiantai', 'Tiantai,Tiantai Zhen,tian tai,tian tai zhen,天台,天台镇', 28.5783300, 105.7466700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12997, 'Sihe', 'Sihe', 'Sihe,si he,四合', 30.7000000, 119.2583300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12998, 'Yuewan', 'Yuewan', 'Yuewan,yue wan,月湾', 30.7547000, 119.1414300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(12999, 'Sanlidian', 'Sanlidian', 'Qingxi,Sanlidian,qing xi,san li dian,三里店,清溪', 30.8833300, 119.4000000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13000, 'Fengqiao', 'Fengqiao', 'Fengqiao,feng qiao,凤桥', 30.8409400, 119.3059000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13001, 'Yishan', 'Yishan', 'Yishan,Yishan Xiang,yi shan,yi shan xiang,峄山,峄山乡', 30.8275900, 118.8169800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13002, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Xiang,gao qiao,gao qiao xiang,高桥,高桥乡', 30.7995700, 118.5734400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13003, 'Xiangyang', 'Xiangyang', 'Xiangyang,Xiangyang Zhen,xiang yang,xiang yang zhen,向阳,向阳镇', 30.8956400, 118.8667800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13004, 'Xiadu', 'Xiadu', 'Xiadu,Xiadu Xiang,xia du,xia du xiang,夏渡,夏渡乡', 30.9236400, 118.7775900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13005, 'Jinba', 'Jinba', 'Jinba,Jinba Xiang,jin ba,jin ba xiang,金坝,金坝乡', 30.8792900, 118.6698600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13006, 'Shuangxi', 'Shuangxi', 'Shuangxi,Shuangxi Zhen,shuang xi,shuang xi zhen,双溪,双溪镇', 30.9581500, 118.8045500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13007, 'Dingdian', 'Dingdian', 'Dingdian,Dingdian Xiang,ding dian,ding dian xiang,丁店,丁店乡', 30.9837600, 118.8615200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13008, 'Qinxi', 'Qinxi', 'Qinxi,Qinxi Xiang,qin xi,qin xi xiang,琴溪,琴溪乡', 30.7294300, 118.4910600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13009, 'Taiyuan', 'Taiyuan', 'Taiyuan,Taiyuan Xiang,tai yuan,tai yuan xiang,太园,太园乡', 30.7109300, 118.4004900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13010, 'Beigong', 'Beigong', 'Beigong,Beigong Xiang,bei gong,bei gong xiang,北贡,北贡乡', 30.6809200, 118.1992500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13011, 'Yandun', 'Yandun', 'Yandun,Yandun Zhen,yan dun,yan dun zhen,烟墩,烟墩镇', 30.7217400, 118.1575700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13012, 'Youhua', 'Youhua', 'Youhua,Youhua Xiang,you hua,you hua xiang,酉华,酉华乡', 30.6779600, 118.0067400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13013, 'Gufeng', 'Gufeng', 'Gufeng,Gufeng Xiang,gu feng,gu feng xiang,孤峰,孤峰乡', 30.7618300, 118.3648300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13014, 'Tongtuan', 'Tongtuan', 'Tongtuan,Tongtuan Xiang,tong tuan,tong tuan xiang,童疃,童疃乡', 30.8250000, 118.3416700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13015, 'Wenchang', 'Wenchang', 'Wenchang,Wenchang Zhen,wen chang,wen chang zhen,文昌,文昌镇', 30.9040300, 118.4886900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13016, 'Shipu', 'Shipu', 'Shipu,Shipu Zhen,shi pu,shi pu zhen,石铺,石铺镇', 30.9152000, 118.3835400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13017, 'Gelin', 'Gelin', 'Gelin,Gelin Xiang,ge lin,ge lin xiang,葛林,葛林乡', 30.8826700, 118.3819600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13018, 'Lüling', 'Luling', 'Luling,Luling Zhen,Lüling,Lüling Zhen,lu ling,lu ling zhen,绿岭,绿岭镇', 30.8489300, 118.1265200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13019, 'Wenwucao', 'Wenwucao', 'Jinlang Xiang,Wenwucao,jin lang xiang,wen wu cao,文武曹,金榔乡', 30.9209000, 118.1102900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13020, 'Donghe', 'Donghe', 'Donghe,Donghe Xiang,dong he,dong he xiang,东河,东河乡', 30.9791100, 118.4557300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13021, 'Jiulian', 'Jiulian', 'Jiulian,Jiulian Xiang,jiu lian,jiu lian xiang,九连,九连乡', 30.9556500, 118.3822700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13022, 'Gongshan', 'Gongshan', 'Gongshan,Gongshan Zhen,gong shan,gong shan zhen,工山,工山镇', 30.9356600, 118.2504800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13023, 'Jiafa', 'Jiafa', 'Jiafa,Jiafa Zhen,jia fa,jia fa zhen,家发,家发镇', 30.9930100, 118.2510100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13024, 'Chisha', 'Chisha', 'Chisha,Chisha Xiang,chi sha,chi sha xiang,赤沙,赤沙乡', 30.9902300, 118.1324300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13025, 'Zhuyang', 'Zhuyang', 'Zhuyang,Zhuyang Xiang,zhu yang,zhu yang xiang,竹阳,竹阳乡', 30.7304700, 118.0021500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13026, 'Qiucun', 'Qiucun', 'Ch''iu-ts''un,Ch’iu-ts’un,Menkoutang,Qiucun,Qiucun Zhen,men kou tang,qiu cun,qiu cun zhen,邱村,邱村镇,门口塘', 31.0092500, 119.4359200, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13027, 'Dongchong', 'Dongchong', 'Dongchong,Zhaocun,dong chong,zhao cun,东冲,赵村', 31.0202300, 119.3771100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13028, 'Nanfeng', 'Nanfeng', 'Nanfeng,Nanfeng Zhen,Quantoushan,nan feng,nan feng zhen,quan tou shan,南丰,南丰镇,拳头山', 31.0691800, 119.2150800, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13029, 'Shuiming', 'Shuiming', 'Shuiming,Shuiming Xiang,shui ming,shui ming xiang,水鸣,水鸣乡', 31.0329800, 119.1477800, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13030, 'Xinhang', 'Xinhang', 'Xinhang,Xinhang Zhen,xin hang,xin hang zhen,新杭,新杭镇', 31.0708700, 119.5602300, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13031, 'Gangnan', 'Gangnan', 'Gangnan,Gangnan Xiang,gang nan,gang nan xiang,岗南,岗南乡', 31.2402500, 119.3007400, 'CN', '2012-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13032, 'Wuxing', 'Wuxing', 'Doumenkou,Wuxing,Wuxing Xiang,dou men kou,wu xing,wu xing xiang,五星,五星乡,陡门口', 31.0093900, 118.7820100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13033, 'Guquan', 'Guquan', 'Guquan,Guquanzhen,gu quan,gu quan zhen,古泉,古泉镇', 31.0324800, 118.6471800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13034, 'Sanyuan', 'Sanyuan', 'Qifangdong,Sanyuan,Sanyuan Zhen,qi fang dong,san yuan,san yuan zhen,七房董,三元,三元镇', 31.0801800, 118.6194700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13035, 'Rencunwan', 'Rencunwan', 'Rencunwan,Yangxian,ren cun wan,yang xian,仁村湾,养贤', 31.0916700, 118.7583300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13036, 'Huaqiao', 'Huaqiao', 'Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,花桥,花桥镇', 31.1870700, 118.6922900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13037, 'Zhougao', 'Zhougao', 'Zhougao,Zhougao Zhen,zhou gao,zhou gao zhen,周皋,周皋镇', 31.1742100, 118.5464700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13038, 'Xianbao', 'Xianbao', 'Qiangwan,Xianbao,Xianbao Zhen,qiang wan,xian bao,xian bao zhen,咸保,咸保镇,强湾', 31.2750300, 118.5285600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13039, 'Taifeng', 'Taifeng', 'Gengshangchen,Taifeng,Taifeng Xiang,geng shang chen,tai feng,tai feng xiang,埂上陈,太丰,太丰乡', 31.0480700, 118.4633000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13040, 'Eshan', 'Eshan', 'Eshan,e shan,峨山', 31.0642900, 118.2157900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13041, 'Dainan', 'Dainan', 'Dainan,Dainan Xiang,Huangtutang,dai nan,dai nan xiang,huang tu tang,埭南,埭南乡,黄土塘', 31.1814500, 118.4310600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13042, 'Huolonggang', 'Huolonggang', 'Huolonggang,Huolonggang Zhen,huo long gang,huo long gang zhen,火龙岗,火龙岗镇', 31.2489100, 118.3942300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13043, 'Yitai', 'Yitai', 'Duangang,Yitai,Yitai Zhen,duan gang,yi tai,yi tai zhen,易太,易太镇,段港', 31.2760700, 118.4858900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13044, 'Jingshan', 'Jingshan', 'Jingshan,Jingshan Jiedao,Jingshanzhen,jing shan,jing shan jie dao,荆山,荆山街道', 31.3133000, 118.4492900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13045, 'Matang', 'Matang', 'Matang,Matang Zhen,ma tang,ma tang zhen,马塘,马塘镇', 31.3148400, 118.3978100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13046, 'Xiaojiangba', 'Xiaojiangba', 'Baiyin Zhen,Baiyinzhen,Xiaojiangba,bai yin zhen,xiao jiang ba,小江坝,白茚镇', 31.2849500, 118.0621300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13047, 'Dazha', 'Dazha', 'Dazha,Dazha Jiedao,da zha,da zha jie dao,大闸,大闸街道', 31.3780700, 118.5160000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13048, 'Shiqiao', 'Shiqiao', 'Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 31.4420600, 118.6001900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13049, 'Xinfeng', 'Xinfeng', 'Licunhan,Xinfeng,Xinfeng Xiang,li cun han,xin feng,xin feng xiang,新丰,新丰乡,李村涵', 31.4894400, 118.6890300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13050, 'Taibai', 'Taibai', 'Taibai,Taibai Xiang,Zhangjianian,tai bai,tai bai xiang,zhang jia nian,太白,太白乡,张家碾', 31.4979900, 118.5104900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13051, 'Liu‘an', 'Liu`an', 'Jiashan,Liu`an,Liu‘an,jia shan,liu an,佳山,六安', 31.6532700, 118.5237600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13052, 'Niandou', 'Niandou', 'Niandou,nian dou,年陡', 31.4342300, 118.4586100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13053, 'Guandou', 'Guandou', 'Guandou,Guandou Jiedao,Jiujiang Qu,guan dou,guan dou jie dao,jiu jiang qu,官陡,管陡街道,鸠江区', 31.3782900, 118.3975900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13054, 'Longshanqiao', 'Longshanqiao', 'Longshanqiao,Longshanqiao Zhen,Taibai,Taibai Zhen,long shan qiao,long shan qiao zhen,tai bai zhen,太白镇,龙山桥,龙山桥镇', 31.4959700, 118.4820100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13055, 'Dongjiang Matoukou', 'Dongjiang Matoukou', 'Dongjiang Matoukou,Jiangxin,dong jiang ma tou kou,jiang xin,东江马头口,江心', 31.5977000, 118.4532300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13056, 'Lianhe', 'Lianhe', 'Dapeng,Lianhe,da peng,lian he,大彭,联合', 31.6362400, 118.3151800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13057, 'Yushan', 'Yushan', 'Yushan,Yushan Jiedao,Yushan Qu,yu shan,yu shan jie dao,yu shan qu,雨山,雨山区,雨山街道', 31.6726500, 118.4845600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13058, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Xiang,cheng nan,cheng nan xiang,城南,城南乡', 31.6750000, 118.3430600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13059, 'Shiyang', 'Shiyang', 'Shiyang,Shiyang Zhen,shi yang,shi yang zhen,石杨,石杨镇', 31.9500000, 118.2750000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13060, 'Erlangkou', 'Erlangkou', 'Erlangkou,Erlangkouzhen,er lang kou,er lang kou zhen,二郎口,二郎口镇', 31.9696900, 118.1276800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13061, 'Changgai', 'Changgai', 'Ch''ang-kai,Changgai,Changgai Xiang,Ch’ang-kai,zhang gai,zhang gai xiang,长陔,长陔乡', 29.6586500, 118.5246900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13062, 'Shichuan', 'Shichuan', 'Ling-nan-ts''un,Ling-nan-ts’un,Lingnan,Shichuan,ling nan,shi chuan,岭南,石川', 29.4411100, 118.1663900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13063, 'Zhengwan', 'Zhengwan', 'Zhengwan,Zhengwan Xiang,zheng wan,zheng wan xiang,郑湾,郑湾乡', 29.6393000, 118.3679200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13064, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Xiang,ban qiao,ban qiao xiang,板桥,板桥乡', 29.6127800, 117.9486100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13065, 'Shanhou', 'Shanhou', 'Shanhou,Shanhou Xiang,shan hou,shan hou xiang,山后,山后乡', 29.6616900, 117.8640700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13066, 'Huangwei', 'Huangwei', 'Huangwei,Huangwei Xiang,huang wei,huang wei xiang,璜蔚,璜蔚乡', 29.6887800, 118.6399700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13067, 'Xinxikou', 'Xinxikou', 'Xinxikou,Xinxikou Xiang,xin xi kou,xin xi kou xiang,新溪口,新溪口乡', 29.7776100, 118.7015500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13068, 'Huangtian', 'Huangtian', 'Huangtian,Huangtian Xiang,huang tian,huang tian xiang,璜田,璜田乡', 29.7197100, 118.6438800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13069, 'Xiaochuan', 'Xiaochuan', 'Xiaochuan,xiao chuan,小川', 29.8101100, 118.6543800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13070, 'Zhangtan', 'Zhangtan', 'Zhangtan,Zhangtan Xiang,zhang tan,zhang tan xiang,漳潭,漳潭乡', 29.8230200, 118.5522000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13071, 'Bei’an', 'Bei''an', 'Bei''an,Bei''anzhen,Bei’an,Bei’anzhen,bei an,bei an zhen,北岸,北岸镇', 29.9098900, 118.5753200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13072, 'Jinchuan', 'Jinchuan', 'Jinchuan,Jinchuan Xiang,jin chuan,jin chuan xiang,金川,金川乡', 29.9786700, 118.8462900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13073, 'Shaolian', 'Shaolian', 'Shao-lien,Shaolian,Shaolian Xiang,shao lian,shao lian xiang,绍濂,绍濂乡', 29.7043800, 118.4627400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13074, 'Liyang', 'Liyang', 'Liyang,Liyangzhen,li yang,li yang zhen,黎阳,黎阳镇', 29.7057000, 118.2862400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13075, 'Sencun', 'Sencun', 'Sencun,Sencun Xiang,sen cun,sen cun xiang,森村,森村乡', 29.7581800, 118.4786100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13076, 'Tunguang', 'Tunguang', 'Tunguang,Tunguang Zhen,Tunguangzhen,tun guang,tun guang zhen,屯光,屯光镇', 29.7666700, 118.3583300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13077, 'Xintan', 'Xintan', 'Hsin-t''an,Hsin-t’an,Xintan,Xintan Zhen,xin tan,xin tan zhen,新潭,新潭镇', 29.7360900, 118.2808500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13078, 'Yiqi', 'Yiqi', 'Yiqi,Yiqi Zhen,yi qi,yi qi zhen,奕棋,奕棋镇', 29.7266900, 118.2569200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13079, 'Xiongcun', 'Xiongcun', 'Hsiung-ts''un,Hsiung-ts’un,Xiongcun,Xiongcun Xiang,xiong cun,xiong cun xiang,雄村,雄村乡', 29.8165900, 118.4374800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13080, 'Nanyuankou', 'Nanyuankou', 'Nanyuankou,Nanyuankou Xiang,nan yuan kou,nan yuan kou xiang,南源口,南源口乡', 29.8540300, 118.4897600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13081, 'Zhengcun', 'Zhengcun', 'Cheng-ts''un,Cheng-ts’un,Zhengcun,Zhengcun Zhen,zheng cun,zheng cun zhen,郑村,郑村镇', 29.8595000, 118.3773600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13082, 'Chengkan', 'Chengkan', 'Chengkan,Chengkan Zhen,cheng kan,cheng kan zhen,呈坎,呈坎镇', 29.9236100, 118.2836100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13083, 'Shangfeng', 'Shangfeng', 'Shangfeng,Shangfeng Xiang,shang feng,shang feng xiang,上丰,上丰乡', 29.9957100, 118.3529900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13084, 'Jiangtan', 'Jiangtan', 'Jiangtan,Jiangtan Xiang,jiang tan,jiang tan xiang,江潭,江潭乡', 29.6958300, 117.9583300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13085, 'Bingtan', 'Bingtan', 'Bingtan,Bingtan Xiang,bing tan,bing tan xiang,冰潭,冰潭乡', 29.7225800, 117.9165800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13086, 'Xuling', 'Xuling', 'Hsu-ling,Hsü-ling,Xuling,Xuling Xiang,xu ling,xu ling xiang,胥岭,胥岭乡', 29.8923500, 117.7240600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13087, 'Bishan', 'Bishan', 'Bishan,Bishan Xiang,San-tu,bi shan,bi shan xiang,碧山,碧山乡', 29.9542300, 117.9090200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13088, 'Datan', 'Datan', 'Datan,Datan Xiang,da tan,da tan xiang,大坦,大坦乡', 29.9456500, 117.7510200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13089, 'Guxi', 'Guxi', 'Guxi,Guxi Xiang,gu xi,gu xi xiang,古溪,古溪乡', 29.9477800, 117.5763400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13090, 'Yangshu', 'Yangshu', 'Penglong,Penglong Xiang,Yangshu,peng long,peng long xiang,yang shu,彭龙,彭龙乡,杨树', 29.9455300, 117.5090500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13091, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Xiang,long jiang,long jiang xiang,龙江,龙江乡', 29.9635000, 117.9523600, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13092, 'Zhupu', 'Zhupu', 'Zhupu,Zhupu Xiang,zhu pu,zhu pu xiang,竹铺,竹铺乡', 30.0375300, 118.8321700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13093, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Zhen,Chang’an,Chang’an Zhen,zhang an,zhang an zhen,长安,长安镇', 30.1524000, 118.5191300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13094, 'Jingzhou', 'Jingzhou', 'Jingzhou,Jingzhou Xiang,jing zhou,jing zhou xiang,荆州,荆州乡', 30.1928100, 118.8624100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13095, 'Banqiaotou', 'Banqiaotou', 'Banqiaotou,Banqiaotou Xiang,ban qiao tou,ban qiao tou xiang,板桥头,板桥头乡', 30.2000000, 118.6000000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13096, 'Shichuan', 'Shichuan', 'Shichuan,Shichuan Xiang,shi chuan,shi chuan xiang,仕川,仕川乡', 30.2948600, 118.6705700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13097, 'Jingqiao', 'Jingqiao', 'Jingqiao,Jingqiao Xiang,jing qiao,jing qiao xiang,旌桥,旌桥乡', 30.3146200, 118.5882100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13098, 'Huatan', 'Huatan', 'Huatan,Huatan Xiang,hua tan,hua tan xiang,华坦,华坦乡', 30.3289100, 118.5381000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13099, 'Daguyun', 'Daguyun', 'Daguyun,Daguyun Xiang,da gu yun,da gu yun xiang,大谷运,大谷运乡', 30.0609900, 118.4220800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13100, 'Huangcun', 'Huangcun', 'Huangcun,Huangcun Xiang,huang cun,huang cun xiang,黄村,黄村乡', 30.0145100, 118.4036700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13101, 'Fuxi', 'Fuxi', 'Fuxi,Fuxi Xiang,fu xi,fu xi xiang,富溪,富溪乡', 30.0023700, 118.2141100, 'CN', '2013-01-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13102, 'Shangzhuang', 'Shangzhuang', 'Shangzhuang,Shangzhuang Zhen,shang zhuang,shang zhuang zhen,上庄,上庄镇', 30.1244100, 118.4335900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13103, 'Gengcheng', 'Gengcheng', 'Gengcheng,Gengcheng Zhen,geng cheng,geng cheng zhen,耿城,耿城镇', 30.2304300, 118.1589700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13104, 'Suncun', 'Suncun', 'Suncun,Suncun Xiang,sun cun,sun cun xiang,孙村,孙村乡', 30.3160600, 118.4134900, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13105, 'Wanjia', 'Wanjia', 'Wan-chia-ch''iao,Wan-chia-ch’iao,Wanjia,wan jia,万家', 30.4041700, 119.1333300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13106, 'Zhongxi', 'Zhongxi', 'Zhongxi,Zhongxi Zhen,zhong xi,zhong xi zhen,中溪,中溪镇', 30.4865700, 119.1585000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13107, 'Xiaxi', 'Xiaxi', 'Xiaxi,Xiaxi Zhen,xia xi,xia xi zhen,霞西,霞西镇', 30.5000000, 118.9333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13108, 'Fangtang', 'Fangtang', 'Fangtang,Fangtang Xiang,fang tang,fang tang xiang,方塘,方塘乡', 30.4791700, 118.7291700, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13109, 'Yunle', 'Yunle', 'Yunle,Yunle Xiang,yun le,yun le xiang,云乐,云乐乡', 30.4500000, 118.6333300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13110, 'Tingxi', 'Tingxi', 'Tingxi,Tingxi Xiang,ting xi,ting xi xiang,汀溪,汀溪乡', 30.6065500, 118.6103200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13111, 'Suhong', 'Suhong', 'Suhong,Suhong Xiang,su hong,su hong xiang,苏红,苏红乡', 30.5791700, 118.5458300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13112, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Xiang,Qinglongqiao Xiang,qing long,qing long qiao xiang,qing long xiang,青龙,青龙乡,青龙桥乡', 30.6208300, 118.9000000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13113, 'Aimin', 'Aimin', 'Aimin,Aimin Xiang,ai min,ai min xiang,爱民,爱民乡', 30.6474800, 118.6172400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13114, 'Caijiaqiao', 'Caijiaqiao', 'Caijiaqiao,Caijiaqiao Zhen,cai jia qiao,cai jia qiao zhen,蔡家桥,蔡家桥镇', 30.3428100, 118.4701400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13115, 'Xinming', 'Xinming', 'Xinming,Xinming Xiang,xin ming,xin ming xiang,新明,新明乡', 30.3360000, 118.2442500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13116, 'Pinghu', 'Pinghu', 'Pinghu,Pinghu Zhen,ping hu,ping hu zhen,平湖,平湖镇', 30.3281500, 118.0054400, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13117, 'Xinhua', 'Xinhua', 'Xinhua,Xinhua Xiang,xin hua,xin hua xiang,新华,新华乡', 30.4482300, 118.0393000, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13118, 'Xinfeng', 'Xinfeng', 'Xinfeng,Xinfeng Xiang,xin feng,xin feng xiang,新丰,新丰乡', 30.5041900, 118.0777800, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13119, 'Anwu', 'Anwu', 'Anwu,Anwuxiang,an wu,an wu xiang,安吴,安吴乡', 30.5880800, 118.2480300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13120, 'Dingjiaqiao', 'Dingjiaqiao', 'Dingjiaqiao,Dingjiaqiao Zhen,ding jia qiao,ding jia qiao zhen,丁家桥,丁家桥镇', 30.6455000, 118.3084200, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13121, 'Zhongcun', 'Zhongcun', 'Zhongcun,Zhongcun Xiang,zhong cun,zhong cun xiang,中村,中村乡', 30.6166700, 118.1833300, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13122, 'Muta', 'Muta', 'Muta,Muta Xiang,mu ta,mu ta xiang,木塔,木塔乡', 29.7759200, 117.0499500, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13123, 'Makeng', 'Makeng', 'Makeng,Makeng Xiang,ma keng,ma keng xiang,马坑,马坑乡', 29.9246800, 117.0847100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13124, 'Huayuanli', 'Huayuanli', 'Huayuan,Huayuanli,Huayuanli Xiang,hua yuan li,hua yuan li xiang,花园里,花园里乡', 29.9649700, 117.0147100, 'CN', '2012-01-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13125, 'Yijin', 'Yijin', 'Yijin,Yijin Zhen,Yijinqiao,yi jin,yi jin zhen,义津,义津镇', 30.9200000, 117.1972200, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13126, 'Quedian', 'Quedian', 'Quedian,Quedian Xiang,que dian,que dian xiang,阙店,阙店乡', 31.3027800, 116.8388900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13127, 'Hengtanggang', 'Hengtanggang', 'Hengtanggang,Hengtanggang Xiang,heng tang gang,heng tang gang xiang,横塘岗,横塘岗乡', 31.5416700, 116.5000000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13128, 'Guoziyuan', 'Guoziyuan', 'Guoziyuan,Guoziyuan Xiang,guo zi yuan,guo zi yuan xiang,果子园,果子园乡', 31.3416700, 115.6102800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13129, 'Yeshan', 'Yeshan', 'Guantangji,Yeshan,Yeshan Zhen,guan tang ji,ye shan,ye shan zhen,关塘集,冶山,冶山镇', 32.6060400, 119.0111600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13130, 'Dushan', 'Dushan', 'Dushan,Dushan Xiang,Peiji,du shan,du shan xiang,pei ji,独山,独山乡,裴集', 32.4077400, 118.6476800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13131, 'Longshan', 'Longshan', 'Longshan,Longshan Xiang,Taiyuanying,long shan,long shan xiang,tai yuan ying,太袁郢,龙山,龙山乡', 32.5110300, 118.5580000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13132, 'Jiepai', 'Jiepai', 'Jiepai,Jiepai Zhen,Luhua,Lühua,jie pai,jie pai zhen,lu hua,界牌,界牌镇,绿化', 32.6979700, 119.1516900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13133, 'Wanshou', 'Wanshou', 'Wanshou,Wanshou Zhen,wan shou,wan shou zhen,万寿,万寿镇', 32.7264600, 119.0792500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13134, 'Yongfeng', 'Yongfeng', 'Huchengqiao,Yongfeng,Yongfeng Zhen,hu cheng qiao,yong feng,yong feng zhen,护城桥,永丰,永丰镇', 32.7314900, 118.9918000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13135, 'Gaomiaoji', 'Gaomiaoji', 'Gaomiaoji,Gaomiaoji Zhen,gao miao ji,gao miao ji zhen,高庙集,高庙集镇', 32.9290400, 118.9969800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13136, 'Anle', 'Anle', 'Anle,Anle Zhen,an le,an le zhen,安乐,安乐镇', 32.9147300, 118.8729100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13137, 'Yuele', 'Yuele', 'Yueh-le,Yuele,Yuele Zhen,Yüeh-le,yue le,yue le zhen,悦乐,悦乐镇', 36.2656600, 107.9094500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13138, 'Yingge', 'Yingge', 'Ying-ko-tsui,Yingge,Yingge Zhen,Yinggezui,ying ge,ying ge zhen,鹦鸽,鹦鸽镇', 34.0955900, 107.6485700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13139, 'Yaxing', 'Yaxing', 'Ya-hsing,Ya-hsing-shih,Yaxing,Yaxing Zhen,ya xing,ya xing zhen,雅星,雅星镇', 19.4477800, 109.2627300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13140, 'Xianshui', 'Xianshui', 'Daou,Daowu Xian,Dawu,Tao-fou,Tao-fu,Tao-fu-hsien,Tao-tu,Tao-wu,Xianshui,dao fu xian,xian shui,道孚县,鲜水', 30.9914500, 101.1270100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13141, 'Lintan Chengguanzhen', 'Lintan Chengguanzhen', 'Chiu-ch''eng,Chiu-ch''eng-chen,Chiu-ch’eng,Chiu-ch’eng-chen,Chiu-t''ao-ch''eng,Chiu-t''ao-chou,Chiu-t’ao-chou,Chiu-t’ao-ch’eng,Jiucheng,Lin-t''an Chiu-ch''eng,Lin-t’an Chiu-ch’eng,Lintan,Lintan Chengguanzhen,Lintan Xian,Taochow,Taochow Old City,lin tan,lin tan cheng guan zhen,lin tan xian,临潭,临潭县,临潭城关镇', 34.6888500, 103.3524200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13142, 'Mengjin Chengguanzhen', 'Mengjin Chengguanzhen', 'Changhua,Meng-chin,Meng-ching,Mengjin,Mengjin Chengguanzhen,meng jin cheng guan zhen,孟津城关镇', 34.8269000, 112.4312900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13143, 'Luojing', 'Luojing', 'Lo-ching,Lo-ching-hsu,Lo-ching-hsü,Lokeng,Luojing,Luojing Zhen,luo jing,luo jing zhen,罗镜,罗镜镇', 22.5414600, 111.4437600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13144, 'Kongtian', 'Kongtian', 'K''ung-t''ien,Kongtian,Kongtian Zhen,K’ung-t’ien,kong tian,kong tian zhen,孔田,孔田镇', 24.9244600, 115.3053400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13145, 'Hangkou', 'Hangkou', 'Hangkou,Hangkou Zhen,Heng-k''ou,Heng-k’ou,hang kou,hang kou zhen,杭口,杭口镇', 29.0473900, 114.4418400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13146, 'Changjing', 'Changjing', 'Ch''ang-ching,Ch''ang-ching-chen,Changjing,Changjing Zhen,Ch’ang-ching,Ch’ang-ching-chen,zhang jing,zhang jing zhen,长泾,长泾镇', 31.7550700, 120.4778200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13147, 'Zuoxi', 'Zuoxi', 'Tso-ch''i-ts''un,Tso-ch’i-ts’un,Zuoxi,Zuoxi Zhen,zuo xi,zuo xi zhen,左溪,左溪镇', 27.6300600, 119.3789100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13148, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,Tso-t''an,Tso-t’an,Zuotan,long tan,long tan zhen,龙潭,龙潭镇', 23.7133000, 114.1064700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13149, 'Liaoyang', 'Liaoyang', 'Liao,Liao-hsien,Liaoyang,Liaoyang Zhen,Lyaosyan'',Lyaosyan’,Tso-ch''uan,Tso-ch''uan-hsien,Tso-ch’üan,Tso-ch’üan-hsien,Zuoquan,Zuoquan Xian,liao yang,liao yang zhen,zuo quan xian,左权县,辽阳,辽阳镇', 37.0797700, 113.3398600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13150, 'Zunyi', 'Zunyi', 'Chun-gi-chhi,Chun-gī-chhī,Cong-ngie,Cuenji,Cun-i,Czun''i,Cŏng-ngiê,Dzuni,Gunji,Tsun-i,Tsun-i-ch''eng,Tsun-i-ch’eng,Tsun-i-hsien,Tsun-i-shih,Tsunyi,Tsunyi-hsien,Tuan Nghia,Tuân Nghĩa,ZYI,Zunyi,jjun-i si,zun yi,zun yi shi,zwnyay,zwnyy,zwnyyy,Ĝunji,Цзуньи,Цуенји,زونئی,زونیئی,زونیای,遵义市,遵義,遵義市,쭌이 시', 27.6866700, 106.9072200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13151, 'Zuitou', 'Zuitou', 'T''ai-pai,T''ai-pai-ch''u,Ta-pai,Taibai Xian,Tsui-t''ou,Tsui-t''ou-chen,Tsui-t’ou,Tsui-t’ou-chen,Tszuytouchzhen'',Tszuytouchzhen’,T’ai-pai,T’ai-pai-ch’ü,Zuitou,Zuitou Zhen,Zuitoujie,tai bai xian,zui tou,嘴头,太白县', 34.0621900, 107.3126600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13152, 'Zuitai', 'Zuitai', 'Chiu-k''ang-hsien,Chiu-k’ang-hsien,K''ang,K''ang-hsien,K''ang-hsien-ku-chih,Kangxian,K’ang,K’ang-hsien,K’ang-hsien-ku-chih,Pai-ma-kuan,Tsui-t''ai-tzu,Tsui-t’ai-tzu,Zuitai,Zuitai Zhen,Zuitaizi,ju tai,ju tai zhen,kang xian,咀台,咀台镇,康县', 33.3308300, 105.6046700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13153, 'Zuhu', 'Zuhu', 'Tsu-hu,Tsu-hu-pao,Zuhu,Zuhu Xiang,zu hu,zu hu xiang,阻虎,阻虎乡', 39.7317800, 112.0308800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13154, 'Zudun', 'Zudun', 'Shangdian,Shangduan,Zudun,Zudun Xiang,shang dian,zu dun,zu dun xiang,上店,祖墩,祖墩乡', 27.6516700, 118.6888900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13155, 'Zu’an', 'Zu''an', 'Tsu-an,Tsu-an-chen,Zu''an,Zu''an Zhen,Zu’an,Zu’an Zhen,zu an,zu an zhen,祖庵,祖庵镇', 34.0955600, 108.4844400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13156, 'Zoucheng', 'Zoucheng', 'Chou-hsien,Czouchehn,Czouchen,Trau Thanh,Trâu Thành,Tsou,Tsou-hsien,Tsowhsien,Zoucheng,Zouxian,jjeoucheong si,zou cheng shi,Цзоучен,Цзоучэн,邹城市,鄒城市,쩌우청 시', 35.4005600, 116.9655600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13157, 'Zoushi', 'Zoushi', 'Tsou-shih,Tsowshih,Zoushi,Zoushi Zhen,zou shi,zou shi zhen,陬市,陬市镇', 29.0439700, 111.5388600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13158, 'Zouqu', 'Zouqu', 'Tsou-ch''u,Tsou-ch''u-chen,Tsou-ch’ü,Tsou-ch’ü-chen,Zouqu,Zouqu Zhen,zou qu,zou qu zhen,邹区,邹区镇', 31.7960800, 119.8398700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13159, 'Zouqiao', 'Zouqiao', 'Tsou-ch''iao,Tsou-ch’iao,Zouqiao,Zouqiao Xiang,zou qiao,zou qiao xiang,邹桥,邹桥乡', 29.4238400, 115.4853900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13160, 'Zouma', 'Zouma', 'Tsou-ma-p''ing,Tsou-ma-p’ing,Zouma,Zoumaping,Zuoma Zhen,zou ma,zou ma zhen,走马,走马镇', 29.8283300, 110.4230600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13161, 'Zougang', 'Zougang', 'Chou-chia-kang,Zougang,Zougang Zhen,zou gang,zou gang zhen,邹岗,邹岗镇', 31.0850100, 114.0291100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13162, 'Zongzhai', 'Zongzhai', 'Zongzhai,Zongzhai Zhen,zong zhai,zong zhai zhen,总寨,总寨镇', 36.5289000, 101.7074600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13163, 'Zongying', 'Zongying', 'Tsung-chia-ying,Tsung-ying,Tsung-ying-chen,Zongying,Zongying Zhen,zong ying,zong ying zhen,宗营,宗营镇', 33.1579400, 106.9804200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13164, 'Zongyang', 'Zongyang', 'Ts''ung-yang,Ts''ung-yang-chen,Ts’ung-yang,Ts’ung-yang-chen,Zongyang,Zongyang Xian,cong yang,cong yang xian,枞阳,枞阳县', 30.6988900, 117.2041700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13165, 'Zongluzui', 'Zongluzui', 'Zongluzui,Zongluzui Zhen,zong lu ju,zong lu ju zhen,总路咀,总路咀镇', 30.6968300, 115.0603600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13166, 'Nyinma', 'Nyinma', 'Cho-ko-ni-ma,Ma-ch''u,Ma-ch’ü,Maqu,Maqu Xian,Matsyuy,Nima,Nima Zhen,Nyinma,Zoige''nyinma,Zoigê’nyinma,ma qu,ma qu xian,ni ma,ni ma zhen,尼玛,尼玛镇,玛曲,玛曲县', 34.0006500, 102.0712700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13167, 'Ziyang Chengguanzhen', 'Ziyang Chengguanzhen', 'Tzeyan-hsien,Tzeyang,Tziyanghsien,Tzu-yang,Tzu-yang-hsien,Ziyang,Ziyang Chengguanzhen,Ziyang Xian,zi yang cheng guan zhen,zi yang xian,紫阳县,紫阳城关镇', 32.5191700, 108.5323200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13168, 'Yanjiang', 'Yanjiang', 'Czyjan,Tszoyan,Tszöyan,Tzeyang,Tzeyang-hsien,Tzu-yang,Tzu-yang-hsien,Yanjiang,Ziyang,yan jiang,Цзыян,雁江', 30.1210800, 104.6481100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13169, 'Tangdong', 'Tangdong', 'Hing-ning-hsien,Hingning,Hsing-ning,Tangdong,Tsehhing,Tzehing,Tzehsing-hsien,Tzu-hsing,Tzu-hsing-hsien,Zixing,Zixing Shi,tang dong,zi xing,zi xing shi,唐洞,资兴,资兴市', 26.0018800, 113.2537900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13170, 'Zixi', 'Zixi', 'Tzu-ch''i-chieh,Tzu-chi,Tzu-ch’i-chieh,Tzu-hsi,Zixi,Zixi Xiang,zi xi,zi xi xiang,紫溪,紫溪乡', 28.0694900, 117.7840000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13171, 'Ziwu', 'Ziwu', 'Tzu-wu,Tzu-wu-chen,Ziwu,Ziwu Jieban,Ziwuzhen,zi wu,zi wu jie ban,子午,子午街办', 34.0580500, 108.8936200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13172, 'Wenchang', 'Wenchang', 'Tsu-t''ung,Tsu-t’ung,Tzetung-hsien,Tzu-t''ung,Tzu-t''ung-hsien,Tzu-t’ung,Tzu-t’ung-hsien,Wenchang,Zitong,wen chang,文昌', 31.6362500, 105.1550200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13173, 'Zitong', 'Zitong', 'T''ung-nan,T''ung-nan-hsien,Tongnan Xian,Tunnan,T’ung-nan,T’ung-nan-hsien,Zitong,Zitong Jiedao,tong nan xian,zi tong,zi tong jie dao,梓潼,梓潼街道,潼南县', 30.1782000, 105.8299100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13174, 'Zishui', 'Zishui', 'Zishui,Zishui Xiang,zi shui,zi shui xiang,紫水,紫水乡', 31.4128100, 108.3146500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13175, 'Zishan', 'Zishan', 'Tzeshansu,Tzu-shan,Tzu-shan-hsu,Tzu-shan-hsü,Tzu-shan-shih,Zishan,Zishan Zhen,zi shan,zi shan zhen,梓山,梓山镇', 25.9599500, 115.5412200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13176, 'Zirun', 'Zirun', 'Tzu-jun,Tzu-jun-ts''un,Tzu-jun-ts’un,Zirun,Zirun Xiang,zi run,zi run xiang,滋润,滋润乡', 39.3034600, 112.6835800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13177, 'Ziqiu', 'Ziqiu', 'Tzekiu,Tzu-ch''iu,Tzu-ch’iu,Ziqiu,Ziqiu Zhen,zi qiu,zi qiu zhen,资丘,资丘镇', 30.4373300, 110.6780100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13178, 'Zilingpu', 'Zilingpu', 'Tzu-ling-p''u,Tzu-ling-p’u,Zilingpu,Zilingpu Zhen,zi ling pu,zi ling pu zhen,子陵铺,子陵铺镇', 31.1314100, 112.2181600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13179, 'Zilang', 'Zilang', 'Tzu-liang-p''ing,Tzu-liang-p’ing,Zilang,Zilang Xiang,Ziliangping,zi liang,zi liang ping,zi liang xiang,子良,子良乡,子良坪', 30.0039300, 111.2105800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13180, 'Ziketan', 'Ziketan', 'Hsing-hai,Tzu-k''o-t''an,Tzu-k’o-t’an,Xinghai,Xinghai Xian,Zeketan Zhen,Ziketan,xing hai,xing hai xian,zi ke tan,zi ke tan zhen,兴海,兴海县,子科滩,子科滩镇', 35.5862100, 99.9879000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13181, 'Zijin', 'Zijin', 'Tzu-chin,Tzu-chin-tung,Zijin,Zijin Zhen,zi jin,zi jin zhen,紫金,紫金镇', 32.1346000, 111.3059100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13182, 'Zicheng', 'Zicheng', 'Tzekam,Tzekam-hsien,Tzu-ch''eng-chen,Tzu-chin,Tzu-ch’eng-chen,Wingon,Yung-an,Yunganhsien,Zicheng,Zicheng Zhen,Zijin,zi cheng,zi cheng zhen,紫城,紫城镇', 23.6470900, 115.1774000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13183, 'Zigong', 'Zigong', 'C-kung,Ceu-gong,Chu-kong-chhi,Chū-kòng-chhī,Cigung,Czygun,Cê̤ṳ-góng,Dzigongas,Dzugun,Tu Cong,Tzekung,Tzeliuching,Tzeliutsing,Tzu-kung,Tzu-kung-shih,Tzu-liu-ching,Tzuliutsing,Tự Cống,ZKL,Zigong,jjeugung si,zi gong,zi gong shi,zygang,zygwng,zyjwnj,Дзъгун,Цзыгун,Цигунг,زيجونج,زیگانگ,زیگونگ,自貢,自貢市,自贡,自贡市,쯔궁 시', 29.3416200, 104.7768900, 'CN', '2017-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13184, 'Zibu', 'Zibu', 'Zibu,Zibu Zhen,zi bu,zi bu zhen,梓埠,梓埠镇', 28.8533200, 116.8629300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13185, 'Zhuzuo', 'Zhuzuo', 'Zhuzuo,Zhuzuo Xiang,zhu ze,zhu ze xiang,竹笮,竹笮乡', 26.3867400, 115.9797800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13186, 'Zhuzhoujiang Miaozuxiang', 'Zhuzhoujiang Miaozuxiang', 'Chu-chou-chiang,Zhuzhoujiang,Zhuzhoujiang Miaozuxiang', 26.6752800, 110.0719400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13187, 'Zhuzhou', 'Zhuzhou', 'Chu Chau,Chu Châu,Chu-chiu-chhi,Chu-chiu-chhī,Chu-chou,Chu-chou-shih,Chu-chu-su,Chu-chû-sṳ,Chuchow,Chzhuchzhou,Cu-cou,Cyu Cou,DHU,Dzhudzhou,Dzudzou,Džudžou,Gugou,Jianning,Tu-ciu,Tṳ̆-ciŭ,Zhutsjou,Zhuzhou,Zhuzhou Shi,jujeou si,zhanzhw,zhu zhou,zhu zhou shi,zhwzhww,Çyu Cou,Ču-čou,Ĝuĝou,Џуџоу,Джуджоу,Чжучжоу,ژانژو,ژوژوو,ཞུས་ཀྲོའུ།,株洲,株洲市,주저우 시', 27.8333300, 113.1500000, 'CN', '2014-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13188, 'Zhuzhen', 'Zhuzhen', 'Chu-chen,Chu-chen-chi,Zhuzhen,Zhuzhen Zhen,Zhuzhenji,zhu zhen,zhu zhen zhen,竹镇,竹镇镇', 32.5158200, 118.6776900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13189, 'Zhuyuan', 'Zhuyuan', 'Zhuyuan,Zhuyuan Zhen,Zhuyuanping,zhu yuan,zhu yuan ping,zhu yuan zhen,竹园,竹园坪,竹园镇', 31.3021600, 109.2580600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13190, 'Zhuyuan', 'Zhuyuan', 'Chu-yuan,Chu-yuan-chen,Chu-yuan-chieh,Chu-yüan,Chu-yüan-chieh,Chü-yüan-chen,Zhuyuan,Zhuyuan Zhen,zhu yuan,zhu yuan zhen,竹园,竹园镇', 24.1077800, 103.4186100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13191, 'Zhuyeping', 'Zhuyeping', 'Zhuyeping,Zhuyeping Xiang,zhu ye ping,zhu ye ping xiang,竹叶坪,竹叶坪乡', 29.4723600, 110.5419300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13192, 'Zhuyang', 'Zhuyang', 'Chu-yang-hsi,Zhuyang,Zhuyang Zhen,zhu yang,zhu yang zhen,朱杨,朱杨镇', 29.0642300, 105.9448700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13193, 'Zhuyang', 'Zhuyang', 'Dazhu,Ta-chu,Ta-chu-ch''eng,Ta-chu-ch’eng,Ta-chu-hsien,Zhuyang,zhu yang,竹阳', 30.7367400, 107.2011500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13194, 'Zhuxi Chengguanzhen', 'Zhuxi Chengguanzhen', 'Chu-ch''i,Chu-ch''i-hsien,Chu-ch’i,Chu-ch’i-hsien,Chu-hsi,Chuki,Chuki-hsien,Zhuxi,Zhuxi Chengguanzhen,zhu xi cheng guan zhen,竹溪城关镇', 32.3256900, 109.7233700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13195, 'Zhuxi', 'Zhuxi', 'Chu-hsi,Zhaojia Yuanzi,Zhuxi,Zhuxi Zhen,zhao jia yuan zi,zhu xi,zhu xi zhen,朱溪,朱溪镇,赵家院子', 29.5361400, 105.6668500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13196, 'Zhuwa', 'Zhuwa', 'Zhuwa,Zhuwa Zhen,zhu wa,zhu wa zhen,竹瓦,竹瓦镇', 30.5950800, 115.1165600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13197, 'Zhutuo', 'Zhutuo', 'Chu-t''o,Chu-t’o,Zhutuo,Zhutuo Zhen,zhu tuo,zhu tuo zhen,朱沱,朱沱镇', 29.0184000, 105.8487700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13198, 'Zhuting', 'Zhuting', 'Chu-t''ing,Chu-t’ing,Zhuting,Zhuting Xiang,zhu ting,zhu ting xiang,竹亭,竹亭乡', 27.7760100, 114.0785100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13199, 'Zhutian', 'Zhutian', 'Chu-t''ien,Chu-t’ien,Zhutian,Zhutian Xiang,zhu tian,zhu tian xiang,珠田,珠田乡', 28.7584800, 117.0811500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13200, 'Zhutang', 'Zhutang', 'Chu-t''ang,Chu-t''ang-ch''iao,Chu-t''ang-chen,Chu-t’ang,Chu-t’ang-chen,Chu-t’ang-ch’iao,Zhutang,Zhutang Zhen,zhu tang,zhu tang zhen,祝塘,祝塘镇', 31.7696500, 120.4083600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13201, 'Zhutan', 'Zhutan', 'Chu-t''an,Chu-t''an-chen,Chu-t’an,Chu-t’an-chen,Zhutan,Zhutan Zhen,zhu tan,zhu tan zhen,株潭,株潭镇', 28.0526100, 114.1605500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13202, 'Zhushi', 'Zhushi', 'Chu-shih,Zhushi,Zhushi Xiang,zhu shi,zhu shi xiang,诸市,诸市乡', 33.0615900, 113.8888100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13203, 'Zhushan Chengguanzhen', 'Zhushan Chengguanzhen', 'Chu-shan,Chu-shan-hsien,Zhushan,Zhushan Chengguanzhen,zhu shan cheng guan zhen,竹山城关镇', 32.2217900, 110.2361400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13204, 'Zhusha', 'Zhusha', 'Chu-sha,Zhusha,Zhusha Zhen,zhu sha,zhu sha zhen,朱砂,朱砂镇', 22.5655200, 110.9660900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13205, 'Jiahe Chengguanzhen', 'Jiahe Chengguanzhen', 'Chia-ho,Chia-ho-hsien,Chu-ch''uan,Chu-ch’üan,Jiahe,Jiahe Chengguanzhen,Kiaho,Kiaho-hsien,Zhuquan,jia he cheng guan zhen,嘉禾城关镇', 25.5593600, 112.3635200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13206, 'Zhuqiao', 'Zhuqiao', 'Chu-ch''iao,Chu-ch''iao-chen,Chu-ch’iao,Chu-ch’iao-chen,Chukiao,Zhuqiao,Zhuqiao Zhen,zhu qiao,zhu qiao zhen,朱桥,朱桥镇', 37.3637000, 120.0967600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13207, 'Zhuqi', 'Zhuqi', 'Chu-ch''i,Chu-ch’i,Chuki,Zhuqi,Zhuqi Xiang,zhu qi,zhu qi xiang,竹岐,竹岐乡', 26.1486000, 119.1021600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13208, 'Zhuoyang', 'Zhuoyang', 'Zhuoyang,Zhuoyang Xiang,zhuo yang,zhuo yang xiang,卓洋,卓洋乡', 26.6300300, 119.0215000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13209, 'Zhuotian', 'Zhuotian', 'Cho-t''ien,Cho-t’ien,Zhuotian,Zhuotian Zhen,zhuo tian,zhuo tian zhen,濯田,濯田镇', 25.5582300, 116.2756800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13210, 'Zhuoshui', 'Zhuoshui', 'Cho-shui,Zhuoshui,Zhuoshui Zhen,zhuo shui,zhuo shui zhen,濯水,濯水镇', 29.3030900, 108.7702000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13211, 'Zhuoshui', 'Zhuoshui', 'Cho-shui,Zhuoshui,Zhuoshui Zhen,zhuo shui,zhuo shui zhen,浞水,浞水镇', 28.9179000, 107.8971100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13212, 'Zhuogang', 'Zhuogang', 'Cho-kang,Zhuogang,Zhuogang Zhen,zhuo gang,zhuo gang zhen,濯港,濯港镇', 30.0124100, 115.8758600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13213, 'Zhumushan', 'Zhumushan', 'Zhumushan,Zhumushan Xiang,zhu mu shan,zhu mu shan xiang,株木山,株木山乡', 28.8266700, 111.9672200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13214, 'Zhumadian', 'Zhumadian', 'Chu-ma-tien,Chu-ma-tien-chen,Chu-ma-tien-shih,Chzhumadjan'',Hsin-chuang,Zhumadian,zhu ma dian shi,Чжумадянь,驻马店市', 32.9794400, 114.0294400, 'CN', '2014-08-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13215, 'Zhulin', 'Zhulin', 'Chu-lin,Chu-lin-chen,Zhulin,Zhulin Zhen,zhu lin,zhu lin zhen,朱林,朱林镇', 31.7395400, 119.4545400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13216, 'Zhulin', 'Zhulin', 'Zhulin,Zhulin Zhen,zhu lin,zhu lin zhen,株林,株林镇', 30.3693700, 115.4916500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13217, 'Zhuliang', 'Zhuliang', 'Chu-liang,Zhuliang,Zhuliang Zhen,zhu liang,zhu liang zhen,株良,株良镇', 27.4683800, 116.6008900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13218, 'Zhulan', 'Zhulan', 'Chu-lan-pu,Zhulan,Zhulan Xiang,Zhulanbu,zhu lan,zhu lan xiang,珠兰,珠兰乡', 25.6268100, 115.7111200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13219, 'Zhukou', 'Zhukou', 'Chu-k''ou,Chu-k''ou-chen,Chu-k''ou-p''u,Chu-k’ou,Chu-k’ou-chen,Chu-k’ou-p’u,Zhukou,Zhukou Zhen,zhu kou,zhu kou zhen,朱口,朱口镇', 26.9789900, 117.2604700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13220, 'Zhujing', 'Zhujing', 'Chin-shan,Chin-shan-hsien,Chu-ching,Chu-ching-chen,Chuking,Jinshan,Kinshan,Zhujing,Zhujing Zhen,zhu jing,zhu jing zhen,朱泾,朱泾镇', 30.9010000, 121.1596600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13221, 'Zhujiazhuang', 'Zhujiazhuang', 'Chu-chia-chuang,Zhujiazhuang,Zhujiazhuang Zhen,zhu jia zhuang,zhu jia zhuang zhen,祝家庄,祝家庄镇', 34.4723600, 107.7806000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13222, 'Zhujiapu', 'Zhujiapu', 'Chu-chia-p''u,Chu-chia-p’u,Zhujiapu,Zhujiapu Zhen,zhu jia pu,zhu jia pu zhen,朱家铺,朱家铺镇', 28.7594400, 111.7913900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13223, 'Zhujiang', 'Zhujiang', 'Chu-chiang-ch''ing,Chu-chiang-ch’ing,Zhujiang,Zhujiang Xiang,Zhujiangqing,zhu jiang,zhu jiang xiang,竹江,竹江乡', 27.2768500, 114.7044300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13224, 'Jiangpu', 'Jiangpu', 'Chiang-p''u,Chiang-p''u Hsien,Chiang-p’u,Chiang-p’u Hsien,Chu-chiang,Jiangpu,Jiangpu Jiedao,Kiangpu,Zhujiang,jiang pu,jiang pu jie dao,zhu jiang,江浦,江浦街道,珠江', 32.0614900, 118.6239900, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13225, 'Zhujiajiao', 'Zhujiajiao', 'Ching-t''ing-chiang,Ching-t’ing-chiang,Chu-chia-chiao,Chu-chieh-ko,Chzhuczjaczjao,Zhujiajiao,Zhujiajiao Zhen,zhu jia jiao,zhu jia jiao zhen,Чжуцзяцзяо,朱家角,朱家角镇', 31.1075700, 121.0569600, 'CN', '2016-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13226, 'Zhuangxing', 'Zhuangxing', 'Chu-chia-hang,Chu-chia-hang-chen,Chu-chia-hsing-chen,Zhuangxing,Zhuhang,Zhuhang Xiang,Zhujiahang,zhuang xing,庄行', 30.8515700, 121.3335200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13227, 'Shangqiu', 'Shangqiu', 'Chu-chi,Chu-kia-tsi,Chu-sun-chi,Sang-cchiou,Shancju,Shang-ch''iu,Shang-ch''iu-shih,Shang-ch’iu,Shang-ch’iu-shih,Shangqiu,Siong-khiu-chhi,Siong-khiu-chhī,Siong-kiu,Siŏng-kiŭ,Sjangqiu,Thuong Khau,Thương Khâu,Zhuji,sangchu si,shang qiu,shang qiu shi,shangchyw,shanghkyw,Šang-čchiou,Шанцю,شانغكيو,شانگچیو,ሻንግጭዩ,商丘,商丘市,상추 시', 34.4500000, 115.6500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13228, 'Zhuji', 'Zhuji', 'Chu-chi,Chu-chi-hsien,Chu-chi-hsien-ch''eng,Chu-chi-hsien-ch’eng,Chuki,Chukihsien,Zhuji,Zhuji Shi,zhu ji,zhu ji shi,诸暨,诸暨市', 29.7187700, 120.2423300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13229, 'Zhuhong', 'Zhuhong', 'Chu-heng-chiang,Chu-hung,Chu-hung-chiang,Zhuhong,Zhuhong Zhen,zhu hong,zhu hong zhen,竹泓,竹泓镇', 32.8819700, 119.9858400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13230, 'Zhuhe', 'Zhuhe', 'Chu-chia-ho,Chu-ho,Chuhoshih,Zhuhe,Zhuhe Zhen,zhu he,zhu he zhen,朱河,朱河镇', 29.7338100, 113.1246200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13231, 'Zhuhang', 'Zhuhang', 'Chu-hang,Chu-hang-chen,Chu-hsing-chen,Zhuhang,Zhuhang Zhen,zhu xing,zhu xing zhen,竹行,竹行镇', 31.9000500, 120.9819300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13232, 'Zhouqu Chengguanzhen', 'Zhouqu Chengguanzhen', 'Chou-ch''u,Chou-ch''u-hsien,Chou-ch’ü,Chou-ch’ü-hsien,Hsi-ku,Hsi-ku-hsien,Hsi-ku-hsien-ch''eng,Hsi-ku-hsien-ch’eng,Lung-tieh,Si-ku,Zhouqu,Zhouqu Chengguanzhen,Zhouqu Xian,Zhugqu,zhou qu,zhou qu cheng guan zhen,zhou qu xian,舟曲,舟曲县,舟曲城关镇', 33.7841700, 104.3627800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13233, 'Zhuge', 'Zhuge', 'Chu-ko,Chu-ko-chen,Zhuge,Zhuge Zhen,zhu ge,zhu ge zhen,诸葛,诸葛镇', 29.2518600, 119.2907600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13234, 'Zhushi', 'Zhushi', 'Chu-kao-t''ang,Chu-kao-t’ang,Zhugaotang,Zhushi', 27.0877800, 110.6769400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13235, 'Zhufeng', 'Zhufeng', 'Chu-feng,Chu-feng-chen,Zhufeng,Zhufeng Xiang,Zhufengzhen,zhu feng,竹峰', 30.5681300, 118.9364200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13236, 'Zhudian', 'Zhudian', 'Zhudian,Zhudian Xiang,zhu dian,zhu dian xiang,朱店,朱店乡', 35.1156700, 105.9466000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13237, 'Zhucun', 'Zhucun', 'Chu-ts''un,Chu-ts’un,Zhucun,Zhucun Jiedao,zhu cun,zhu cun jie dao,朱村,朱村街道', 23.2797200, 113.6886100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13238, 'Mizhou', 'Mizhou', 'Chu-ch''eng,Chu-ch’eng,Chu-hsien,Mizhou,mi zhou,密州', 35.9947200, 119.3975000, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13239, 'Zhuantang', 'Zhuantang', 'Chuan-t''ang,Chuan-t’ang,Zhuantang,Zhuantang Jiedao,Zhuantang Zhen,zhuan tang,zhuan tang jie dao,zhuan tang zhen,转塘,转塘街道,转塘镇', 30.1635000, 120.0761300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13240, 'Zhuanshui', 'Zhuanshui', 'Zhuanshui,Zhuanshui Zhen,zhuan shui,zhuan shui zhen,转水,转水镇', 23.9991700, 115.6968900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13241, 'Zhuanqiang', 'Zhuanqiang', 'Chuan-ch''iang,Chuan-ch’iang,Zhuanqiang,Zhuanqiang Zhen,zhuan qiang,zhuan qiang zhen,砖墙,砖墙镇', 31.2631700, 118.8176300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13242, 'Zhuanlu', 'Zhuanlu', 'Chuan-lu,Chuan-lu-chen,Zhuanlu,Zhuanlu Zhen,zhuan lu,zhuan lu zhen,砖路,砖路镇', 38.6557000, 114.9451700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13243, 'Zhuangtou', 'Zhuangtou', '', 39.6577800, 117.2916700, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13244, 'Zhuangtou', 'Zhuangtou', 'Chuang-t''ou,Chuang-tzu-t''ou,Chuang-tzu-t’ou,Chuang-t’ou,Zhuangtou,Zhuangtou Zhen,zhuang tou,zhuang tou zhen,庄头,庄头镇', 34.2575000, 108.4516700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13245, 'Zhuangta', 'Zhuangta', 'Chuang-t''a,Chuang-t’a,Zhuangta,Zhuangta Xiang,zhuang ta,zhuang ta xiang,庄塌,庄塌乡', 29.6281500, 110.9011000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13246, 'Zhuangshi', 'Zhuangshi', 'Chuang-shih,Chuang-shih-chen,Zhuangshi,Zhuangshi Jiedao,zhuang shi,zhuang shi jie dao,庄市,庄市街道', 29.9330600, 121.6096200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13247, 'Zhuangqiao', 'Zhuangqiao', 'Chang-ch''iao,Chang-ch''iao-chen,Chang-ch’iao,Chang-ch’iao-chen,Changkiao,Chuang-ch''iao,Chuang-ch''iao-chen,Chuang-ch’iao,Chuang-ch’iao-chen,Zhuangqiao,Zhuangqiao Zhen,zhuang qiao,zhuang qiao zhen,庄桥,庄桥镇', 29.9300000, 121.5483300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13248, 'Zhuangli', 'Zhuangli', 'Chuang-li,Chuang-li-chen,Zhuangli,Zhuangli Zhen,zhuang li,庄里', 34.8195800, 109.0598400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13249, 'Zhuanghe', 'Zhuanghe', 'Chuang-ho,Chuang-ho-chen,Chuang-ho-chieh,Chuang-ho-hsien,Chwangho,Zhuanghe', 39.7008300, 122.9911100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13250, 'Zhuangbian', 'Zhuangbian', 'Zhuangbian,Zhuangbian Zhen,zhuang bian,zhuang bian zhen,庄边,庄边镇', 25.6348000, 118.9764500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13251, 'Zhouzhuang', 'Zhouzhuang', 'Chou-chuang,Chou-chuang-chen,Zhouzhuang,Zhouzhuang Zhen,zhou zhuang,zhou zhuang zhen,周庄,周庄镇', 31.8672900, 120.4034300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13252, 'Zhouzhuang', 'Zhouzhuang', 'Chou-chuang,Chou-chuang-chen,Chzhouchzhuan,Zhouzhuang,Zhouzhuang Zhen,zhou zhuang,zhou zhuang zhen,Чжоучжуан,周庄,周庄镇', 31.1178800, 120.8442700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13253, 'Zhouxin', 'Zhouxin', 'Chou-hsin,Chou-hsin-hsu,Chou-hsin-hsü,Chowsin,Zhouxin,Zhouxin Jiedao,zhou xin,zhou xin jie dao,洲心,洲心街道', 23.6841000, 113.0853700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13254, 'Zhouxi', 'Zhouxi', 'Zhouxi,Zhouxi Zhen,Zhouxijie,zhou xi,zhou xi zhen,周溪,周溪镇', 29.1859000, 116.3894400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13255, 'Zhouxiang', 'Zhouxiang', 'Zhouxiang,Zhouxiang Zhen,zhou xiang,zhou xiang zhen,周巷,周巷镇', 33.0066600, 119.5706100, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13256, 'Zhouxiang', 'Zhouxiang', 'Chou-chia-hsiang,Zhouxiang,Zhouxiang Zhen,zhou xiang,zhou xiang zhen,周巷,周巷镇', 31.1689800, 114.1128100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13257, 'Zhouxiang', 'Zhouxiang', 'Chou-hsiang,Chou-hsiang-chen,Zhouxiang,Zhouxiang Zhen,zhou xiang,zhou xiang zhen,周巷,周巷镇', 30.1744300, 121.1276900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13258, 'Zhouwang', 'Zhouwang', 'Chou-wang-p''u,Chou-wang-p’u,Zhouwang,Zhouwang Zhen,Zhouwangpu,zhou wang,zhou wang pu,zhou wang zhen,周旺,周旺铺,周旺镇', 27.1944400, 111.1944400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13259, 'Zhouwangmiao', 'Zhouwangmiao', 'Chou-wang-miao,Chou-wang-miao-chen,Zhouwangmiao,Zhouwangmiao Zhen,zhou wang miao,zhou wang miao zhen,周王庙,周王庙镇', 30.4636700, 120.5044800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13260, 'Zhouwang', 'Zhouwang', 'Chou-wang,Chou-wang-ts''un,Chou-wang-ts’un,Zhouwang,Zhouwangcun,zhou wang,zhou wang cun,周王,周王村', 30.7603700, 118.6824900, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13261, 'Donggou', 'Donggou', 'Chou-t''un,Chou-t’un,Donggou,Donggou Xiang,Zhoutun,dong gou,dong gou xiang,zhou tun,东沟,东沟乡,周屯', 35.9041300, 101.5092500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13262, 'Zhoutou', 'Zhoutou', 'Lao-chou-t''ou,Lao-chou-t’ou,Laozhoutou,Zhoutou,Zhoutou Xiang,zhou tou,zhou tou xiang,洲头,洲头乡', 29.8640900, 116.3181600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13263, 'Zhoutie', 'Zhoutie', 'Chou-t''ieh-ch''iao,Chou-t’ieh-ch’iao,Zhoutie,Zhoutie Zhen,Zhoutieqiao,zhou tie,zhou tie zhen,周铁,周铁镇', 31.4388900, 119.9954200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13264, 'Zhoutian', 'Zhoutian', 'Chou-t''ien,Chou-t''ien-hsu,Chou-t’ien,Chou-t’ien-hsü,Zhoutian,Zhoutian Zhen,zhou tian,zhou tian zhen,周田,周田镇', 25.3288200, 115.7278300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13265, 'Zhoutian', 'Zhoutian', 'Zhoutian,Zhoutian Zhen,zhou tian,zhou tian zhen,周田,周田镇', 24.9657700, 113.8091000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13266, 'Zhoushi', 'Zhoushi', 'Chou-shu,Chou-shu-chen,Zhoushi,Zhoushi Zhen,Zhoushu,zhou shi,zhou shi zhen,周市,周市镇', 31.4650300, 120.9900700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13267, 'Zhouquan', 'Zhouquan', 'Chou-ch''uan,Chou-ch''uan-chen,Chou-ch’üan,Chou-ch’üan-chen,Zhouquan,Zhouquan Zhen,zhou quan,zhou quan zhen,洲泉,洲泉镇', 30.5792600, 120.3474800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13268, 'Zhouling', 'Zhouling', 'Chou-kung-mu,Chou-ling,Zhouling,Zhouling Zhen,zhou ling,zhou ling zhen,周陵,周陵镇', 34.4052800, 108.7272200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13269, 'Zhoukoudian', 'Zhoukoudian', 'Chou-k''ou-tien,Chou-k’ou-tien,Zhoukoudian,Zhoukoudian Zhen,zhou kou dian,zhou kou dian zhen,周口店,周口店镇', 39.6840400, 115.9346500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13270, 'Zhoukou', 'Zhoukou', 'Chiu-khau-chhi,Chiu-kháu-chhī,Chou-chia-k''ou,Chou-chia-k’ou,Chou-k''ou,Chou-k''ou-chen,Chou-k’ou,Chou-k’ou-chen,Chow-kia-kow,Chu Khau,Chu Khẩu,Chzhouko,Chzhoukou,Ciu-kau,Ciŭ-kāu,Cou-kchou,Dzoukou,Juko shehiri,Shang-shui-hsien,Tsjoukou,Zhoukou,Zhoukouzhen,jeoukeou si,zhou kou,zhou kou shi,zhwkw,zhwwkww,Čou-kchou,Џоукоу,Чжоуко,Чжоукоу,زهوكو,ژووکوو,周口,周口市,저우커우 시', 33.6333300, 114.6333300, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13271, 'Zhoukou', 'Zhoukou', 'Chou-k''ou,Chou-k''ou-chen,Chou-k’ou,Chou-k’ou-chen,Chowkow,Chzhoukou,Peng''an,Peng’an,Zhoukou,zhou kou,周口', 31.0347300, 106.4011300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13272, 'Zhoukou', 'Zhoukou', 'Zhoukou,Zhoukou Zhen,zhou kou,zhou kou zhen,洲口,洲口镇', 29.0152800, 112.0450000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13273, 'Zhoujiang', 'Zhoujiang', 'Zhoujiang,Zhoujiang Zhen,zhou jiang,zhou jiang zhen,周江,周江镇', 23.7589300, 115.5728000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13274, 'Zhoujiadian', 'Zhoujiadian', 'Chou-chia-tien,Zhoujiadian,Zhoujiadian Zhen,zhou jia dian,zhou jia dian zhen,周家店,周家店镇', 29.2479800, 111.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13275, 'Zhoujia', 'Zhoujia', 'Chou-chia,Zhoujia,Zhoujia Zhen,zhou jia,zhou jia zhen,周嘉,周嘉镇', 30.4190800, 107.5384800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13276, 'Zhouhu', 'Zhouhu', 'Chou-hu,Chou-hu-shih,Zhouhu,Zhouhu Zhen,zhou hu,zhou hu zhen,洲湖,洲湖镇', 27.1592000, 114.5202600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13277, 'Zhoufang', 'Zhoufang', 'Zhoufang,zhou fang zhen,周坊镇', 28.5293400, 117.1666100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13278, 'Zhoucun', 'Zhoucun', 'Chou-lin-chen,Chou-ts''un,Chou-ts''un-chen,Chou-ts’un,Chou-ts’un-chen,Chowtsun,Zhoucun', 36.8166700, 117.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13279, 'Zhoucheng', 'Zhoucheng', 'Chou-ch''eng,Chou-ch''eng-fu,Chou-ch’eng,Chou-ch’eng-fu,Zhoucheng,zhou cheng,周城', 34.4363900, 108.1211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13280, 'Yuxi', 'Yuxi', 'Giok-khe-chhi,Gio̍k-khe-chhī,Hongta,Hongta Qu,Hsin-hsing,Jue-si,Jujsi,Jü-si,Ngoc Khe,Nguk-ka,Ngṳ̆k-kă̤,Ngọc Khê,Sinhing,Sinhingchow,Yu-ch''i,Yu-ch''i-hsien,Yu-hsi,Yuki,Yuki-hsien,Yuxi,Yü-ch’i,Yü-ch’i-hsien,Yü-hsi,Yüki,Yüki-hsien,Zhoucheng,hong ta,hong ta qu,wisi si,ygzy,yu si,yu xi,yu xi shi,Юйси,یگزی,ยู่ซี,玉渓市,玉溪,玉溪市,红塔,红塔区,위시 시', 24.3550000, 102.5422200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13281, 'Zhongzhou', 'Zhongzhou', 'Chung,Chung-hsien,Chungchou,Chungchow,Chzhunsyan'',Chzhunsyan’,Zhong Xian,Zhongzhou,Zhongzhou Zhen,zhong xian,zhong zhou,zhong zhou zhen,忠县,忠州,忠州镇', 30.2940200, 108.0329600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13282, 'Zhongzhou', 'Zhongzhou', 'Chung-chou,Zhongzhou,Zhongzhou Zhen,zhong zhou,zhong zhou zhen,中洲,中洲镇', 24.1051600, 112.1610800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13283, 'Zhongzhai', 'Zhongzhai', 'Zhongzhai,zhong zhai,中寨', 34.6485100, 103.9648500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13284, 'Zhongzhai', 'Zhongzhai', 'Chung-chai,Zhongzhai,zhong zhai,中寨', 33.1913300, 104.4200900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13285, 'Zhongzhai', 'Zhongzhai', 'Chung-chai-ch''ang,Chung-chai-ch’ang,Zhongzhai', 27.1952800, 109.2686100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13286, 'Zhongzhai', 'Zhongzhai', 'Zhongzhai,Zhongzhai Xiang,zhong zhai,zhong zhai xiang,中寨,中寨乡', 24.7418200, 114.3964800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13287, 'Zhongyun', 'Zhongyun', 'Chung-yun,Chung-yün,Zhongyun,Zhongyun Zhen,zhong yun,zhong yun zhen,中云,中云镇', 29.2212600, 117.6859400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13288, 'Zhongyuan', 'Zhongyuan', 'Chung-yuan,Chung-yuan-chen,Chung-yuan-shih,Chung-yüan,Chung-yüan-chen,Chung-yüan-shih,Lo-hui,Zhongyuan,Zhongyuan Zhen,zhong yuan,zhong yuan zhen,中原,中原镇', 19.1478700, 110.4675900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13289, 'Zhongying', 'Zhongying', 'Zhongying,Zhongying Xiang,zhong ying,zhong ying xiang,中营,中营乡', 29.9830300, 109.9712600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13290, 'Zhongguanyi', 'Zhongguanyi', 'Chung-i,Chung-kuan-i,Zhongguanyi,Zhongguanyi Zhen,Zhongyi,zhong guan yi,zhong guan yi zhen,中馆驿,中馆驿镇', 31.1192600, 114.8888000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13291, 'Ningxiang', 'Ningxiang', 'Chung-yang,Chung-yang-hsien,Ning-hsiang,Ningsianhsien,Ningxiang,Ningxiang Zhen,Zhongyang,Zhongyang Xian,ning xiang,ning xiang zhen,zhong yang xian,中阳县,宁乡,宁乡镇', 37.3400000, 111.2052300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13292, 'Zhongxinqiao', 'Zhongxinqiao', 'Zhongxinqiao,zhong xin qiao,中心桥', 39.0379400, 117.5606200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13293, 'Zhongxing', 'Zhongxing', 'Chung-hsing,Chung-hsing-chen,Chunghing,Chunking,Siyang,Ssu-yang,Ssu-yang-hsien,Szeyang,Zhongxing', 33.7038900, 118.6791700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13294, 'Zhongxing', 'Zhongxing', 'Zhongxing,Zhongxing Zhen,zhong xing,zhong xing zhen,中兴,中兴镇', 19.5685500, 109.8524800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13295, 'Zhongxin', 'Zhongxin', 'Chung-hsin,Zhongxin,Zhongxin Zhen,zhong xin,zhong xin zhen,忠信,忠信镇', 28.9336100, 107.7114400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13296, 'Zhongxin', 'Zhongxin', 'Chiu-hua-p''ing,Chiu-hua-p’ing,Chung-hsin-chen,Hua-p''ing-chiu-chih,Hua-p''ing-hsien,Hua-p''ing-ku-chih,Hua-p’ing-chiu-chih,Hua-p’ing-hsien,Hua-p’ing-ku-chih,Huaping,Kiuyaping,Zhongxin,zhong xin,中心', 26.6166700, 101.2715400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13297, 'Zhongxin', 'Zhongxin', 'Chung-hsin,Chung-hsin-chen,Chung-hsin-hsu,Chung-hsin-hsü,Chungsun,Lien-p''ing,Lien-p’ing,Zhongxin,Zhongxin Zhen,zhong xin,zhong xin zhen,忠信,忠信镇', 24.2166700, 114.7333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13298, 'Zhongxin', 'Zhongxin', 'Chung-hsin,Zhongxin,Zhongxin Zhen,zhong xin,zhong xin zhen,中新,中新镇', 23.2877800, 113.6127800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13299, 'Zhongxian', 'Zhongxian', 'Chung-hsien,Zhongxian,Zhongxian Xiang,zhong xian,zhong xian xiang,中仙,中仙乡', 25.9509100, 118.3698900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13300, 'Zhongwei', 'Zhongwei', 'Chung-wei,Chung-wei-hsien,Chzhunvehj,Chzhunvey,Cung-wej,Dung-oi,Dṳ̆ng-ôi,Tiong-oe-chhi,Tiong-oē-chhī,Trung Ve,Trung Vệ,ZHY,Zhongwei,Zhongwei Shi,jung-wei si,zhong wei,zhong wei shi,zhwngwyy,Čung-wej,Чжунвэй,ژونگوئی,中卫,中卫市,中衛,中衛市,중웨이 시', 37.5112900, 105.1906700, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13301, 'Zhongtou', 'Zhongtou', 'Chung-t''ou,Chung-t''ou-chen,Chung-t’ou,Chung-t’ou-chen,Zhongtou,Zhongtou Zhen,zhong tou,zhong tou zhen,冢头,冢头镇', 33.9883600, 113.3395500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13302, 'Zhongtong', 'Zhongtong', 'Zhongtong,Zhongtong Zhen,zhong tong,zhong tong zhen,中童,中童镇', 28.3012700, 116.9681100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13303, 'Zhongtang', 'Zhongtang', 'Chung-t''ang,Chung-t’ang,Zhongtang,Zhongtang Zhen,zhong tang,zhong tang zhen,中堂,中堂镇', 23.0939100, 113.6498400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13304, 'Zhonghe', 'Zhonghe', 'Zhonghe,Zhonghe Xiang,Zhongshuihe,zhong he,zhong he xiang,中河,中河乡', 36.0329200, 106.1738400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13305, 'Zhongshu', 'Zhongshu', 'Huancheng,Lu-liang-hsien,Luliang,Zhongshu,zhong shu,中枢', 25.0273000, 103.6629800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13306, 'Zhongshu', 'Zhongshu', 'Chung-shu-chen,Chzhunshu,Kuang-hsi,Kwangsi-hsien,Kwangsichow,Lu-hsi,Lu-hsi-hsien,Lusi-hsien,Luxi,Zhongshu,zhong shu,Чжуншу,中枢', 24.5166700, 103.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13307, 'Zhongshan', 'Zhongshan', 'Zhongshan,Zhongshan Buyizhu Yizhu Xiang,zhong shan,zhong shan bu yi zu yi zu xiang,钟山,钟山布依族彝族乡', 26.9833300, 106.2166700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13308, 'Zhongshan', 'Zhongshan', 'Zhongshan,Zhongshan Zhen,zhong shan,zhong shan zhen,钟山,钟山镇', 25.5321500, 118.7903400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13309, 'Laocheng', 'Laocheng', 'Laocheng,Zhongshan,Zhongshan Zhen,lao cheng,zhong shan,zhong shan zhen,中山,中山镇,老城', 25.0273700, 116.0357800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13310, 'Zhongshan', 'Zhongshan', 'Chung-saan,Chung-shan,Chung-shan-chen,Chung-shan-hsien,Fu-chung,Shan-chung-chen,Zhongshan,zhong shan,钟山', 24.5333300, 111.3000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13311, 'Zhongqiao', 'Zhongqiao', 'Chung-ch''iao,Chung-ch''iao-chen,Chung-ch’iao,Chung-ch’iao-chen,Zhongqiao,Zhongqiao Xiang,zhong qiao,zhong qiao xiang,钟桥,钟桥乡', 31.1760500, 119.1910500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13312, 'Jinzhong', 'Jinzhong', 'Hui-tse,Hui-tse-hsien,Huize,Hweitseh,Hweitseh-hsien,Jinzhong,Tung-ch''uan,Tung-ch’uan,Tungchwan,Tungchwan-fu,Zhongping,jin zhong,金钟', 26.3759500, 103.3063900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13313, 'Ning’an', 'Ning''an', 'Chung-ning,Chung-ning-hsien,Chzhunnin,Hsin-ning-an-pao,Nin''an''pu,Nin-Anspu,Ning''an,Ning''an Zhen,Ning-an,Ning-an-p''u,Ning-an-pao,Ning-an-pto,Ning-an-p’u,Ning’an,Ning’an Zhen,Nin’an’pu,Zhongning,Zhongning Xian,ning an,ning an zhen,zhong ning xian,中宁县,宁安,宁安镇', 37.4975300, 105.6765000, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13314, 'Maikun', 'Maikun', 'Maikun,Maikun Xiang,Zhong Ngawa,mai kun,mai kun xiang,麦昆,麦昆乡', 32.9101800, 101.7547900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13315, 'Zhongnan', 'Zhongnan', 'Chung-nan,Chung-nan-chen,Zhongnan,Zhongnan Zhen,zhong nan,zhong nan zhen,终南,终南镇', 34.1467700, 108.3601700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13316, 'Zhongmu Chengguanzhen', 'Zhongmu Chengguanzhen', 'Chung-mou,Chung-mou-hsien,Chungmow,Zhongmou,Zhongmu Chengguanzhen,zhong mou cheng guan zhen,中牟城关镇', 34.7114500, 113.9655900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13317, 'Zhongming', 'Zhongming', 'Chung-ming,Chung-ming-chieh,Zhongming,Zhongming Zhen,zhong ming,zhong ming zhen,钟鸣,钟鸣镇', 30.9848200, 118.0507500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13318, 'Zhongmen', 'Zhongmen', 'Zhongmen,Zhongmen Zhen,zhong men,zhong men zhen,忠门,忠门镇', 25.1934100, 119.0813200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13319, 'Zhongluotan', 'Zhongluotan', 'Chung-lo-t''an,Chung-lo-t’an,Chunglao-tan,Chungloktam,Zhongluotan,Zhongluotan Zhen,zhong luo tan,zhong luo tan zhen,钟落潭,钟落潭镇', 23.3845400, 113.3937000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13320, 'Zhonglu', 'Zhonglu', 'Chung-lu,Chung-lu-chieh,Zhonglu,Zhonglu Zhen,zhong lu,zhong lu zhen,忠路,忠路镇', 30.0223100, 108.7198000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13321, 'Zhongling', 'Zhongling', 'Chung-ling,Chung-ling-ch''iao,Chung-ling-ch’iao,Zhongling,Zhongling Xiang,zhong ling,zhong ling xiang,钟陵,钟陵乡', 28.4382200, 116.4778300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13322, 'Zhongjiapu', 'Zhongjiapu', 'Zhongjiapu,Zhongjiapu Xiang,zhong jia pu,zhong jia pu xiang,钟家铺,钟家铺乡', 29.0890100, 111.0501100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13323, 'Kaijiang', 'Kaijiang', 'Chung-chiang,Chung-chiang-hsien,Chungkiang,Chungkiang-hsien,Chzhuntszyan,Kaijiang,Zhongjiang,kai jiang,凯江', 31.0395900, 104.6744800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13324, 'Zhonghuopu', 'Zhonghuopu', 'Chung-ho-p''u,Chung-ho-p’u,Chung-huo-p''u,Chung-huo-p’u,Chunghwopu,Zhonghuopu,Zhonghuopu Zhen,zhong huo pu,zhong huo pu zhen,中伙铺,中伙铺镇', 29.7603400, 114.0010500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13325, 'Zhonghe', 'Zhonghe', 'Zhonghe,Zhonghe Zhen,zhong he,zhong he zhen,中和,中和镇', 31.1766400, 108.1315500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13326, 'Zhonghe', 'Zhonghe', 'Hsiu-shan,Hsiu-shan-hsien,Siushan,Siushan-hsien,Xiushan Tujiazu Miaozu Zizhixian,Zhonghe,Zhonghe Zhen,xiu shan tu jia zu miao zu zi zhi xian,zhong he,zhong he zhen,中和,中和镇,秀山土家族苗族自治县', 28.4504900, 108.9890100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13327, 'Zhongguan', 'Zhongguan', 'Chung-kuan,Chung-kuan-chen,Zhongguan,Zhongguan Zhen,zhong guan,zhong guan zhen,钟管,钟管镇', 30.6495800, 120.1845100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13328, 'Zhongguan', 'Zhongguan', 'Zhongguan,Zhongguan Zhen,zhong guan,zhong guan zhen,中观,中观镇', 28.4313900, 107.6010300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13329, 'Zhongfeng', 'Zhongfeng', 'Chung-feng,Zhongfeng,Zhongfeng Zhen,zhong feng,zhong feng zhen,中峰,中峰镇', 32.3235800, 109.6402700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13330, 'Zhongfang', 'Zhongfang', 'Chung-fang,Zhongfang,zhong fang,中方', 27.4113900, 109.9319400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13331, 'Zhongfang', 'Zhongfang', 'Chung-fang,Zhongfang', 26.6008300, 119.4258300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13332, 'Zhongduo', 'Zhongduo', 'Youyang Tujiazu Miaozu Zizhixian,Yu-yang,Yu-yang-hsien,Yuyangchow,Zhongduo,Zhongduo Zhen,you yang tu jia zu miao zu zi zhi xian,zhong duo,zhong duo zhen,酉阳土家族苗族自治县,钟多,钟多镇', 28.8466000, 108.7641600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13333, 'Zhongdu', 'Zhongdu', 'Chung-tu,Raofang,Zhongdu,Zhongdu Zhen,rao fang,zhong dou,zhong dou zhen,中都,中都镇,饶坊', 24.8782800, 116.4397800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13334, 'Zhongdong', 'Zhongdong', 'Zhongdong,Zhongtong Zhen,zhong dong,zhong dong zhen,中垌,中垌镇', 21.8371300, 110.4685600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13335, 'Zhongdeng', 'Zhongdeng', 'Chung-teng,Chung-teng-ts''un,Chung-teng-ts’un,Zhongdeng,Zhongdengcun', 39.5905600, 117.3530600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13336, 'Lianhuashan', 'Lianhuashan', 'Lianhuashan,Lianhuashan Xiang,Zhongdang,lian hua shan,lian hua shan xiang,zhong dang,中垱,莲花山,莲花山乡', 29.6185200, 116.9924900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13337, 'Zhongcun', 'Zhongcun', 'Luoji,Luoji Xiang,Zhongcun,luo ji,luo ji xiang,zhong cun,中村,洛吉,洛吉乡', 27.7980500, 100.2053700, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13338, 'Zhongcun', 'Zhongcun', 'Zhongcun,Zhongcun Xiang,zhong cun,zhong cun xiang,中村,中村乡', 26.9604400, 115.8277100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13339, 'Zhongcun', 'Zhongcun', 'Chung-ts''un,Chung-ts’un,Zhongcun,Zhongcun Xiang,zhong cun,zhong cun xiang,中村,中村乡', 25.3578000, 115.8350600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13340, 'Zhongchi', 'Zhongchi', 'Zhongchi,Zhongchi Xiang,zhong chi,zhong chi xiang,中赤,中赤乡', 24.9252400, 116.1308800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13341, 'Gusong', 'Gusong', 'Gusong,Gusong Zhen,Ku-sung,Ku-sung-hsien,Zhongcheng,gu song,gu song zhen,古宋,古宋镇', 28.3133000, 105.2377000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13342, 'Zhongchao', 'Zhongchao', 'Chung-ch''ao,Chung-ch''ao-so,Chung-ch’ao,Chung-ch’ao-so,Zhongchao', 26.1375000, 109.2200000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13343, 'Zhongbu', 'Zhongbu', 'Chung-fou,Chung-fou-chieh,Chung-pu,Chung-pu-chieh,Zhongbu,Zhongbu Zhen,Zhongbujie,zhong bu,zhong bu zhen,众埠,众埠镇', 28.8461900, 117.2963300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13344, 'Mingxing', 'Mingxing', 'Chung-pao,Mingxing,Zhongbao,Zhongbao Zhen,ming xing,zhong bao zhen,忠堡镇,明星', 29.6803300, 109.2706200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13345, 'Zhongbao', 'Zhongbao', 'Zhongbao,Zhongbao Zhen,zhong bao,zhong bao zhen,中堡,中堡镇', 25.1954300, 116.2652400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13346, 'Zhongfan', 'Zhongfan', 'Chung-pan,Zhongban,Zhongfan,zhong fan,中畈', 28.5403800, 117.3782000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13347, 'Zhongba', 'Zhongba', 'Chiang-chang,Chiang-yu,Chiang-yu-hsien,Chung-pa,Chzhunba,Jiangyou,Zhongba,zhong ba,中坝', 31.7781900, 104.7393200, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13348, 'Zhongba', 'Zhongba', 'Chung-pa,Zhongba,Zhongba Zhen,zhong ba,zhong ba zhen,中坝,中坝镇', 23.7093400, 115.3464700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13349, 'Zhong’ao', 'Zhong''ao', 'Chung-ao-chen,Zhong''ao,Zhong''ao Zhen,Zhong’ao,Zhong’ao Zhen,zhong ao,zhong ao zhen,中敖,中敖镇', 29.7650000, 105.6664500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13350, 'Zhong’an', 'Zhong''an', 'Chung-an-chen,Fuyuan,P''ing-i,P''ing-i-hsien,Pingyi-hsien,P’ing-i,P’ing-i-hsien,Zhong''an,Zhong’an,zhong an,中安', 25.6666700, 104.2333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13351, 'Zhizhong', 'Zhizhong', 'Zhizhong,Zhizhong Zhen,zhi zhong,zhi zhong zhen,志仲,志仲镇', 18.6193400, 109.2665500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13352, 'Zhiying', 'Zhiying', 'Chih-ying,Chih-ying-shih,Zhiying,Zhiying Jiedao,zhi ying,zhi ying jie dao,芝英,芝英街道', 28.9469700, 120.1248800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13353, 'Zhixi', 'Zhixi', 'Chen-ch''i-ch''iao-chen,Chen-ch’i-ch’iao-chen,Chih-ch''i,Chih-ch''i-ch''iao,Chih-ch’i,Chih-ch’i-ch’iao,Chih-hsi-ch''iao,Chih-hsi-ch’iao,Zhixi,Zhixi Zhen,Zhixiqiao,zhi xi,zhi xi zhen,直溪,直溪镇', 31.8065200, 119.4531900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13354, 'Zhixia', 'Zhixia', 'Chih-hsia,Zhixia,Zhixia Zhen,zhi xia,zhi xia zhen,值夏,值夏镇', 26.9819900, 115.1108100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13355, 'Zhitang', 'Zhitang', 'Chih-t''ang,Chih-tang-chen,Chih-t’ang,Zhitang,Zhitang Zhen,zhi tang,zhi tang zhen,支塘,支塘镇', 31.6106600, 120.9545900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13356, 'Zhitan', 'Zhitan', 'Chih-t''an,Chih-t’an,To-t''an,To-t’an,Zhitan,Zhitan Xiang,shi tan,shi tan xiang,峙滩,峙滩乡', 29.6205200, 117.3090900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13357, 'Zhishan', 'Zhishan', 'Zhishan,Zhishan Zhen,zhi shan,zhi shan zhen,址山,址山镇', 22.5176100, 112.7841400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13358, 'Zhiqian', 'Zhiqian', 'Chih-ch''ien-ch''iao,Chih-ch''ien-piao,Chih-ch’ien-ch’iao,Chih-ch’ien-piao,Zhiqian,Zhiqian Zhen,Zhiqianbiao,zhi qian,zhi qian zhen,指前,指前镇', 31.6192300, 119.4894600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13359, 'Zhili', 'Zhili', 'Chih-li,Chih-li-shih,Zhili,Zhili Zhen,zhi li,zhi li zhen,织里,织里镇', 30.8735800, 120.2566700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13360, 'Zhijin', 'Zhijin', 'Chih-chin,Chih-chin-ch''eng,Chih-chin-ch’eng,Chih-chin-hsien,Chihkin,Chihkin-hsien,Chihkiohsien,P''ing-yuan,Pingyuanchow,P’ing-yüan,Zhijin,Zhijin Chengguanzhen,zhi jin,zhi jin cheng guan zhen,织锦,织锦城关镇', 26.6668000, 105.7680000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13361, 'Zhijiang', 'Zhijiang', 'Chih-chian,Chih-chiang,Chih-chiang-hsien,Chihkiang,Chihkiang-hsien,HJJ,Yuan-chou,Yuanchow,Yuen-chow-fu,Yüan-chou,Yüanchow,Zhijiang,zhi jiang,芷江', 27.4581400, 109.6592000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13362, 'Zhigong', 'Zhigong', 'Chih-kan,Chih-kung,Chih-kung-hsu,Chih-kung-hsü,Zhigong,Zhigong Zhen,zhi long,zhi long zhen,织篢,织篢镇', 21.7428500, 111.6136100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13363, 'Zhifudao', 'Zhifudao', 'Zhifucun,Zhifudao,Zhifudao Jiedao,Zhifuzhen,zhi fu dao,zhi fu dao jie dao,芝罘岛,芝罘岛街道', 37.6032500, 121.3757400, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13364, 'Zhifang', 'Zhifang', 'Chih-fang,Chih-fang-shih,Jiangxia Qu,Wuchang,Wuchang Xian,Zhifang,Zhifang Jiedao,Zhifang Zhen,jiang xia qu,wu chang,wu chang xian,zhi fang,zhi fang jie dao,zhi fang zhen,武昌,武昌县,江夏区,纸坊,纸坊街道,纸坊镇', 30.3500000, 114.3166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13365, 'Zhicheng', 'Zhicheng', 'Ch''ang-hsing,Ch''ang-hsing-hsien,Ch''ang-hsing-hsien-ch''eng,Changhing,Changhing-hsien,Changxing Xian,Ch’ang-hsing,Ch’ang-hsing-hsien,Ch’ang-hsing-hsien-ch’eng,Zhicheng,Zhicheng Zhen,zhang xing xian,zhi cheng,zhi cheng zhen,长兴县,雉城,雉城镇', 31.0054000, 119.9048800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13366, 'Zhicheng', 'Zhicheng', 'Chi-Kiang,Chih-ch''eng,Chih-chiang,Chih-chiang-chen,Chih-chiang-hsien,Chih-ch’eng,Chihkiang,Chihkianghsien,Zhicheng,Zhicheng Zhen,zhi cheng,zhi cheng zhen,枝城,枝城镇', 30.2955600, 111.5047200, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13367, 'Zhibu', 'Zhibu', 'Chih-pu,Zhibu,Zhibu Zhen,zhi bu,zhi bu zhen,直埠,直埠镇', 29.8206500, 120.2484800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13368, 'Zhetian', 'Zhetian', 'Zhetian,Zhetian Xiang,zhe tian,zhe tian xiang,柘田,柘田乡', 27.2342500, 114.4078000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13369, 'Zhetang', 'Zhetang', 'Che-t''ang,Che-t''ang-chen,Che-t’ang,Che-t’ang-chen,Zhetang,Zhetang Zhen,zhe tang,zhe tang zhen,柘塘,柘塘镇', 31.7561400, 118.9155200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13370, 'Zhenzhushan', 'Zhenzhushan', 'Chen-chu-shan,Zhenzhushan,Zhenzhushan Xiang,zhen zhu shan,zhen zhu shan xiang,珍珠山,珍珠山乡', 29.1890700, 117.4612400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13371, 'Zhenzhou', 'Zhenzhou', 'I-chang,I-cheng,I-cheng-hsien,I-tcheng,Icheng Ku,Yangtzehsien,Yicheng,Yizheng Shi,Zhenzhou,Zhenzhou Zhen,yi zheng shi,zhen zhou,zhen zhou zhen,仪征市,真州,真州镇', 32.2803400, 119.1699900, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13372, 'Zhenze', 'Zhenze', 'Chen-tse,Chen-tse-chen,Zhenze,Zhenze Zhen,zhen ze,zhen ze zhen,震泽,震泽镇', 30.9157100, 120.5000500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13373, 'Zhenyuan Chengguanzhen', 'Zhenyuan Chengguanzhen', 'Chen-yuan,Chen-yuan-hsien,Chen-yüan,Chen-yüan-hsien,Tschon-yuan-hien,Tschön-yüan-hién,Zhencheng,Zhenyuan,Zhenyuan Chengguanzhen,Zhenyuan Xian,zhen yuan cheng guan zhen,zhen yuan xian,镇原县,镇原城关镇', 35.6775000, 107.1963900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13374, 'Zhenyuan', 'Zhenyuan', 'Chen-yuan,Chen-yüan,Zhenyuan,Zhenyuan Zhen,zhen yuan,zhen yuan zhen,贞元,贞元镇', 34.3250200, 108.1999600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13375, 'Wufeng', 'Wufeng', 'Chen-hsiung,Chen-hsiung-hsien,Chen-hsuing,Chensiung,Chensiung-hsien,Chensiungchow,Wufeng,Zhenxiong,wu feng,乌峰', 27.4500000, 104.8333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13376, 'Zhenxi', 'Zhenxi', 'Chen-hsi-chen,Zhenxi,Zhenxi Zhen,zhen xi,zhen xi zhen,珍溪,珍溪镇', 29.8992900, 107.4645200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13377, 'Zhenwu', 'Zhenwu', 'Chen-wu-miao,Zhenwu,Zhenwu Zhen,Zhenwumiao,zhen wu,zhen wu zhen,真武,真武镇', 32.6169100, 119.5761500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13378, 'Zhentian', 'Zhentian', 'Zhentian,Zhentian Xiang,zhen tian,zhen tian xiang,镇田,镇田乡', 24.7782000, 115.3190500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13379, 'Zhenshang', 'Zhenshang', 'Chen-shang,Zhenshang,Zhenshang Zhen,zhen shang,zhen shang zhen,圳上,圳上镇', 28.1000000, 111.3833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13380, 'Zhenqian', 'Zhenqian', 'Chen-ch''ien,Chen-ch’ien,Zhenqian,Zhenqian Zhen,zhen qian,zhen qian zhen,镇前,镇前镇', 27.2430600, 119.0938900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13381, 'Zhenping Chengguanzhen', 'Zhenping Chengguanzhen', 'Chen-p''ing,Chen-p''ing-hsien,Chen-p’ing,Chen-p’ing-hsien,Chengguan Zhen,Zhenping,Zhenping Chengguanzhen,zhen ping,zhen ping cheng guan zhen,镇平,镇平城关镇', 33.0331400, 112.2332100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13382, 'Zhennan', 'Zhennan', 'Chen-nan,Zhengnan,Zhennan,Zhennan Zhen,zhen nan,zhen nan zhen,镇南,镇南镇', 28.7015400, 107.8714600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13383, 'Zhenlong', 'Zhenlong', 'Chen-lung,Zhenlong,Zhenlong Zhen,zhen long,镇隆', 22.9402800, 114.3079400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13384, 'Zhenjiang', 'Zhenjiang', 'Chen-chiang,Chen-chiang-ch''eng,Chen-chiang-ch’eng,Chen-chiang-hsien,Chen-chiang-shih,Chenkiang,Chinkiang,Chinkiang Fu,Chinking,Tan-t''a,Tan-t''u,Tan-t’a,Tan-t’u,Tantuhsien,ZUJ,Zhenjiang,Zhenjiang Shi,zhen jiang,zhen jiang shi,جېنجياڭ شەھىرى,鎮江,镇江,镇江市', 32.2108600, 119.4550800, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13385, 'Zhaobaoshan', 'Zhaobaoshan', 'Chen-hai,Chen-hai-hsien,Chen-hai-hsien-ch''eng,Chen-hai-hsien-ch’eng,Chinhai,Zhaobaoshan,Zhaobaoshan Jiedao,Zhenhai,Zhenhai Qu,zhao bao shan,zhao bao shan jie dao,zhen hai,zhen hai qu,招宝山,招宝山街道,镇海,镇海区', 29.9695000, 121.6875300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13386, 'Zhenhai', 'Zhenhai', 'Chen-hai,Chen-hai-ch''eng,Chen-hai-ch’eng,Zhenhai,zhen hai,镇海', 24.2582300, 118.0904900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13387, 'Zhengzhou', 'Zhengzhou', 'CGO,Cencou,Ceng-cou,Cengcou,Cheng,Cheng-chou,Cheng-chou-shih,Cheng-hsien,Chengchow,Chhiang-chu-su,Chhiáng-chû-sṳ,Chzhehnchzhou,Chzhenchzhou,Cjencjou,Csengcsou,Cwngcouh,Czengczou,Dang-ciu,Dzendzou,Dzengdzou,Dzhundzhou,Dâng-ciŭ,Džendžou,Džengdžou,Genggouo,Trinh Chau,Trịnh Châu,Tsentsoou,Tēⁿ-chiu-chhī,Zengzou,Zhengtsjou,Zhengzhou,Zhengzhou Shi,canaco,cancau,ceing cow,cencavu,jeongjeou si,jhengajho''u,tshnghtshw,zheng zhou,zheng zhou shi,zhngzhw,zhyngzhw,Çengçou,Çjençjou,Čeng-čou,Ĝengĝoŭo,Žengžou,Τσεντσόου,Џенгџоу,Джънджоу,Жөнжоу,Чженчжоу,Чжэнчжоу,Чжэнчжоў,تشنغتشو,جېڭجۇ شەھىرى,ژنگژو,ژینگژو,चंचौ,झेंगझोऊ,ਚੰਙਚੋ,செங்சவு,เจิ้งโจว,ကျင့်ကျိုးမြို့,郑州,郑州市,鄭州,鄭州市,정저우 시', 34.7577800, 113.6486100, 'CN', '2015-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13388, 'Zhenyang', 'Zhenyang', 'Cheng-yang,Cheng-yang-hsien,Zhengyang,Zhenyang,zhen yang,真阳', 32.6036100, 114.3830600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13389, 'Zhengxing', 'Zhengxing', 'Cheng-hsing,Zhengxing,Zhengxing Zhen,Zhengxingchang,zheng xing,zheng xing zhen,正兴,正兴镇', 29.4574100, 106.1292600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13390, 'Zhenglu', 'Zhenglu', 'Cheng-lu-ch''iao,Cheng-lu-ch’iao,Zhenglu,Zhenglu Zhen,Zhengluqiao,zheng lu,zheng lu zhen,郑陆,郑陆镇', 31.8284500, 120.0782800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13391, 'Zhengji', 'Zhengji', 'Zhengji,Zhengji Zhen,Zhengjiaji,zheng ji,zheng ji zhen,zheng jia ji,郑家集,郑集,郑集镇', 32.5958200, 118.9461100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13392, 'Zhengguo', 'Zhengguo', 'Cheng-kou-hsu,Cheng-kou-hsü,Cheng-kuo,Cheng-kuo-hsu,Cheng-kuo-hsü,Ching Kwo,Zhengguo,Zhengguo Zhen,zheng guo,zheng guo zhen,正果,正果镇', 23.4133300, 113.8950000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13393, 'Zhengfang', 'Zhengfang', 'Cheng-fang,Zhengfang,Zhengfang Zhen,zheng fang,zheng fang zhen,郑坊,郑坊镇', 28.7009800, 117.8891500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13394, 'Zhengfang', 'Zhengfang', 'Zhengfang,Zhengfang Xiang,zheng fang,zheng fang xiang,郑坊,郑坊乡', 26.7134300, 117.7074000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13395, 'Zhengdun', 'Zhengdun', 'Cheng-tun,Zhengdun,Zhengdun Zhen,zheng dun,zheng dun zhen,郑墩,郑墩镇', 27.4956200, 118.6978300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13396, 'Zhengdian', 'Zhengdian', 'Zhengdian,Zhengdian Jiedao,zheng dian,zheng dian jie dao,郑店,郑店街道', 30.3333300, 114.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13397, 'Zhengcun', 'Zhengcun', 'Cheng-ts''un,Cheng-ts’un,Zhengcun,Zhengcun Xiang,zheng cun,zheng cun xiang,征村,征村乡', 28.9545400, 114.5293400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13398, 'Zhengang', 'Zhengang', 'Chen-kang,Zhengang,Zhengang Xiang,zhen gang,zhen gang xiang,镇岗,镇岗乡', 25.0004400, 115.3152100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13399, 'Zhendong', 'Zhendong', 'Zhendong,Zhengdong Xiang,zhen dong,zhen dong xiang,振东,振东乡', 34.1333300, 120.2166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13400, 'Zhendeqiao', 'Zhendeqiao', 'Zhendeqiao,Zhendeqiao Zhen,zhen de qiao,zhen de qiao zhen,镇德桥,镇德桥镇', 29.1379400, 111.8280700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13401, 'Zhen’an', 'Zhen''an', 'Chen-an,Zhen''an,Zhen''an Zhen,Zhen’an,Zhen’an Zhen,zhen an,zhen an zhen,镇安,镇安镇', 29.7186000, 107.1508100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13402, 'Zhemu', 'Zhemu', 'Zhemu,Zhemu Xiang,zhe mu,zhe mu xiang,柘木,柘木乡', 29.5892400, 113.1385900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13403, 'Zhelin', 'Zhelin', 'Che-lin,Che-lin-ch''eng,Che-lin-ch’eng,Cholin,Zhelin,zhe lin,柘林', 30.8325000, 121.4691700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13404, 'Zhelin', 'Zhelin', 'Che-lin,Sanxiqiao,Zhelin,Zhelin Zhen,zhe lin,zhe lin zhen,柘林,柘林镇', 29.2333300, 115.4666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13405, 'Zhelin', 'Zhelin', 'Che-lin,Chelim,Zhelin,Zhelin Zhen,zhe lin,zhe lin zhen,柘林,柘林镇', 23.5809100, 117.1030200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13406, 'Zhelang', 'Zhelang', 'Chelang,Zhelang,Zhelang Jiedao,zhe lang,zhe lang jie dao,遮浪,遮浪街道', 22.6730700, 115.5673800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13407, 'Zhecheng Chengguanzhen', 'Zhecheng Chengguanzhen', 'Che-ch''eng,Che-ch''eng-hsien,Che-ch’eng,Che-ch’eng-hsien,Zhecheng,Zhecheng Chengguanzhen,zhe cheng cheng guan zhen,柘城城关镇', 34.1046000, 115.3176000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13408, 'Zhaxi', 'Zhaxi', 'Cha-hsi,Cha-hsi-chen,Wei-hsin,Wei-hsin-hsien,Weisin-hsien,Weixin,Zhaxi,zha xi,扎西', 27.8508100, 104.9687400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13409, 'Qianyou', 'Qianyou', 'Hsiao-i,Qianyou,Siaoyi,Siaoyiting,Syaoi,Tso-shui,Tso-shui-hsien,Tso-shui-hsien-ch''eng,Tso-shui-hsien-ch’eng,Zhashui,Zhashui Xian,gan you,zha shui xian,乾佑,柞水县', 33.6775000, 109.1233300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13410, 'Zhapu', 'Zhapu', 'Cha-p''u,Cha-p''u-chen,Cha-p’u,Cha-p’u-chen,Zhapu,Zhapu Zhen,zha pu,zha pu zhen,乍浦,乍浦镇', 30.6015300, 121.0868600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13411, 'Zhaozhen', 'Zhaozhen', 'Chao-chen,Chao-chia-tu,Chaokiatu,Chin-t''ang,Chin-t’ang,Chzhaotszyadu,Jintang,Zhaozhen,zhao zhen,赵镇', 30.8563000, 104.4360600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13412, 'Xinghua', 'Xinghua', 'Hsin-hsing,Hsing-hua,Hsing-hua-ch''eng,Hsing-hua-ch’eng,Hsing-hua-hsien,Sinkhua,Xinghua,Xinxing,Zhaoyang,Синхуа', 32.9391700, 119.8341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13413, 'Zhaoxie', 'Zhaoxie', 'Chao-hsieh,Zhaoxie,Zhaoxie Zhen,zhao xie,zhao xie zhen,招携,招携镇', 27.1677800, 115.8705800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13414, 'Zhaoxiang', 'Zhaoxiang', 'Chao-hsiang,Zhaoxiang,zhao xiang,赵巷', 31.1519400, 121.1920300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13415, 'Zhaoxian', 'Zhaoxian', 'Chao-hsien,Chao-hsien-chen,Chzhaosyan''chzhen'',Chzhaosyan’chzhen’,Zhaoxian,Zhaoxian Zhen,zhao xian,zhao xian zhen,招贤,招贤镇', 34.7498300, 107.6233500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13416, 'Zhaotong', 'Zhaotong', 'Cao-tchung,Chao-t''ung,Chao-t''ung-hsien,Chao-t’ung,Chao-t’ung-hsien,Chiau-thong-chhi,Chiau-thong-chhī,Chieu Thong,Chiêu Thông,Chzhaotun,Cieu-tung,Ciĕu-tŭng,En-an,En-an-hsien,ZAT,Zhaotong,cea thng,jaotung si,zhao tong,zhao tong shi,zhawtwng,Čao-tchung,Чжаотун,ژاوتونگ,เจาทง,昭通,昭通市,자오퉁 시', 27.3166700, 103.7166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13417, 'Zhaoshi', 'Zhaoshi', 'Chao-Shih,Zhaoshi,Zhaoshi Zhen,zhao shi,zhao shi zhen,召市,召市镇', 29.2357400, 109.4255200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13418, 'Zhaoren', 'Zhaoren', 'Ch''ang-wil,Ch''ang-wu-hsien,Ch''ang-wu-hsien-ch''eng,Chan''u,Changwu,Changwu Xian,Chan’u,Ch’ang-wil,Ch’ang-wu-hsien,Ch’ang-wu-hsien-ch’eng,Zhaoren,zhang wu xian,zhao ren,昭仁,长武县', 35.2066700, 107.7913900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13419, 'Zhaoqing', 'Zhaoqing', 'Cao-cching,Chao-ch''ing,Chao-ch''ing-chen,Chao-chou,Chao-ch’ing,Chao-ch’ing-chen,Chao-king,Chzhaocin,Dieu-keng,Diêu-kéng,Dzaocing,Kao-yao,Kao-yao-hsien,Koyiu,Koyiu-hsien,Koynihsien,Sau-khin-su,Sau-khin-sṳ,Shiuhing,Shiuhingfu,Tiau-kheng-chhi,Tiāu-khèng-chhī,Trieu Khanh,Triệu Khánh,Zhaoqing,gʼwzyng,jaoching si,zhao qing,zhao qing shi,zhawchng,zhawchyng,zhawkyng,Čao-čching,Џаоћинг,Чжаоцин,גאוצינג,ژاؤچینگ,ژاوچنگ,ژاوکینگ,肇庆,肇庆市,肇慶,肇慶市,자오칭 시', 23.0511600, 112.4597200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13420, 'Zhaoqiao', 'Zhaoqiao', 'Chao-ch''iao,Chao-ch’iao,Yang-lao-ts''un,Yang-lao-ts’un,Yanglao,Zhaoqiao,Zhaoqiao Xiang,yang lao,zhao qiao,zhao qiao xiang,杨老,赵桥,赵桥乡', 31.2087100, 118.5840300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13421, 'Zhaoping', 'Zhaoping', 'Chao-p''ing,Chao-p''ing-chen,Chao-p''ing-hsien,Chao-p’ing,Chao-p’ing-chen,Chao-p’ing-hsien,Zhaoping,zhao ping,昭平', 24.1724400, 110.7870300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13422, 'Zhaoliqiao', 'Zhaoliqiao', 'Chao-li-ch''iao,Chao-li-ch’iao,Chaolikiao,Zhaoliqiao,Zhaoliqiao Zhen,zhao li qiao,zhao li qiao zhen,赵李桥,赵李桥镇', 29.5683800, 113.7117000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13423, 'Zhaolingpu', 'Zhaolingpu', 'Zhaolingpu,Zhaolingpu Zhen,zhao ling pu,zhao ling pu zhen,赵陵铺,赵陵铺镇', 38.0988900, 114.4650000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13424, 'Zhaokang', 'Zhaokang', 'Chao-k''ang,Chao-k''ang-chen,Chao-k’ang,Chao-k’ang-chen,Zhaokang,Zhaokeng Zhen,zhao kang,zhao kang zhen,赵康,赵康镇', 35.7205300, 111.2472500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13425, 'Zhaopeng', 'Zhaopeng', 'Chao-chia-p''eng,Chao-chia-p’eng,Zhaojiapeng,Zhaopeng,Zhaopeng Zhen,zhao peng,zhao peng zhen,赵棚,赵棚镇', 31.4132000, 113.8485900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13426, 'Zhaohe', 'Zhaohe', 'Chao-ho,Chao-ho-chen,Zhaohe,zhao he,赵河', 33.1877400, 112.8452700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13427, 'Zhaoguli', 'Zhaoguli', 'Zhaoguli,zhao gu li,赵沽里', 39.1667300, 117.2419100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13428, 'Zhaogezhuang', 'Zhaogezhuang', 'Chao-ko-chuang,Zhaogezhuang', 39.7844400, 117.1958300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13429, 'Zhaogezhuang', 'Zhaogezhuang', 'Chao-chia-chuang,Chao-ko-chuang,Chaokochwang,Zhaogezhuang,zhao ge zhuang,赵各庄', 39.7653800, 118.4119100, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13430, 'Chaoge', 'Chaoge', 'Ch''ao-ko,Ch''ao-ko-chen,Ch''i,Ch''i-hsien,Chaoge,Ch’ao-ko,Ch’ao-ko-chen,Ch’i,Ch’i-hsien,Qixian,Zhaoge,chao ge,朝歌', 35.6050000, 114.1886100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13431, 'Zhaozhen', 'Zhaozhen', 'Chao-chen,Chao-ts''un,Chao-ts''un-chen,Chao-ts’un,Chao-ts’un-chen,Zhaocun,Zhaozhen,zhao zhen,赵镇', 34.5572200, 108.4969400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13432, 'Zhaocun', 'Zhaocun', 'Zhaocun,zhao cun,赵村', 33.7548200, 112.4796100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13433, 'Luofeng', 'Luofeng', 'Chao-yuan,Chao-yuan-hsien,Chao-yüan,Chao-yüan-hsien,Luofeng,Zhaocheng,Zhaoyuan,Zhaoyuan Shi,luo feng,zhao yuan shi,招远市,罗峰', 37.3649700, 120.4099700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13434, 'Zhaobei', 'Zhaobei', 'Chao-pei,Chao-pi-ts''un,Chao-pi-ts’un,Zhaobei,Zhaobei Zhen,zhao bei,zhao bei zhen,赵北,赵北镇', 39.4844400, 114.0327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13435, 'Xiping', 'Xiping', 'Ch''u-ching,Chan-i,Chan-i-chen,Chan-i-hsien,Chanyi,Chanyi-hsien,Chanyichow,Ch’ü-ching,Xiping,Zhanyi,xi ping,西平', 25.5978400, 103.7961300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13436, 'Zhanxi', 'Zhanxi', 'Chan-chi,Chan-hsi,Zhanxi,Zhanxi Xiang,zhan xi,zhan xi xiang,湛溪,湛溪乡', 28.0480100, 115.2285000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13437, 'Zhantian', 'Zhantian', 'Zhantian,Zhantian Xiang,zhan tian,zhan tian xiang,湛田,湛田乡', 26.5920800, 116.1610700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13438, 'Zhantang', 'Zhantang', 'Zhangtang Xiang,Zhantang,zhan tang,zhan tang xiang,站塘,站塘乡', 25.4161500, 115.7921700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13439, 'Zhanping', 'Zhanping', 'Zhanping,Zhanping Xiang,zhan ping,zhan ping xiang,展坪,展坪乡', 28.0297400, 116.2405800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13440, 'Zhanjiang', 'Zhanjiang', 'Chan-chiang,Chan-chiang-shih,Chankiang,Chzhan''czjan,Fort Bayard,Hsi-ying,Kwangchow,Kwangchowan,Kwangchowwan,Tram Giang,Trạm Giang,Tsamkong,ZHA,Zhanjiang,Zhanjiang Shi,zhan jiang,zhan jiang shi,Чжаньцзян,جاڭجياڭ شەھىرى,湛江,湛江市', 21.2814500, 110.3427100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13441, 'Zhanjiaji', 'Zhanjiaji', 'Zhanjiaji,Zhanjiaji Jiedao,zhan jia ji,zhan jia ji jie dao,湛家矶,湛家矶街道', 30.6690000, 114.3518000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13442, 'Danzhu', 'Danzhu', 'Chang-tzu,Chang-tzu-chen,Chang-tzu-hsien,Chang-tzu-hsien-ch''eng,Chang-tzu-hsien-ch’eng,Chantszo,Chantszö,Danzhu,Danzhu Zhen,Zhangzi,Zhangzi Xian,dan zhu,dan zhu zhen,zhang zi xian,丹朱,丹朱镇,长子县', 36.1245000, 112.8610100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13443, 'Zhangjiazhuang', 'Zhangjiazhuang', 'Chang-chia-chuang,Chang-chuang,Zhangjiazhuang,Zhangjiazhuang Xiang,Zhangzhuang,zhang jia zhuang,zhang jia zhuang xiang,张家庄,张家庄乡', 39.2633300, 112.7938900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13444, 'Zhangzhuang', 'Zhangzhuang', 'Chang-chuang,Zhangzhuang,Zhangzhuang Xiang,zhang zhuang,zhang zhuang xiang,章庄,章庄乡', 27.5264600, 114.3589200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13445, 'Zhangzhu', 'Zhangzhu', 'Chang-chu,Chang-chu-chen,Zhangzhu,Zhangzhu Zhen,zhang zhu,zhang zhu zhen,张渚,张渚镇', 31.2682000, 119.6286800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13446, 'Zhangzhou', 'Zhangzhou', 'Cang-cou,Chang-chou,Chang-chou-shih,Changchow,Changchowfu,Chiang-chiu-chhi,Chiang-chiu-chhī,Chong-chu-su,Chuong Chau,Chzhanchzhou,Chông-chû-sṳ,Chương Châu,Ciong-ciu,Ciŏng-ciŭ,Dzangdzou,Dzhandzhou,Gangou,Jyangju shehiri,Lung-ch''i,Lung-ch''i-hsien-ch''eng,Lung-ch’i,Lung-ch’i-hsien-ch’eng,Lungki,Lunki,Zhangtsjou,Zhangzhou,jangjaw,jangjeou si,shou zhou shi,zhang zhou,zhang zhou shi,zhangzhw,Čang-čou,Ĝanĝou,Џангџоу,Джанджоу,Чжанчжоу,جانگجاو,ژانگژو,ショウ州市,漳州,漳州市,장저우 시', 24.5133300, 117.6555600, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13447, 'Zhangzhishan', 'Zhangzhishan', 'Chang-chih-chen,Chang-chih-shan,Chang-chih-shan-chen,Zhangzhishan,Zhangzhishan Zhen,zhang zhi shan,zhang zhi shan zhen,张芝山,张芝山镇', 31.9272200, 121.0059700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13448, 'Zhangzhen', 'Zhangzhen', 'Chang-chen,Chang-chia-fou,Zhangzhen,Zhangzhen Zhen,zhang zhen,zhang zhen zhen,章镇,章镇镇', 29.8093100, 120.8683700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13449, 'Zhangye', 'Zhangye', 'Cang-jie,Chang-i,Chang-yeh,Chang-yeh-hsien,Chang-yeh-shih,Changyen,Chzhanue,Diong-ik,Diŏng-ĭk,Dzhanie,Ganzhou,Kan-chou,Kanchow,Tiuⁿ-e̍k-chhī,Truong Dich,Trương Dịch,Zhangye,Zhangye Shi,Zhanue,jang-ye si,zhang ye,zhang ye shi,Čang-jie,Джание,Жанъе,Чжанъе,Չժանիե,ژانگیے,ژانگیۓ,张掖,张掖市,張掖,張掖市,장예 시', 38.9341700, 100.4516700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13450, 'Zhangyan', 'Zhangyan', 'Chang-yen,Chang-yen-chen,Chang-yin,Zhangyan,Zhangyan Zhen,zhang yan,zhang yan zhen,张堰,张堰镇', 30.8066300, 121.2800800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13451, 'Zhangxing', 'Zhangxing', 'Chang-hsing,Chang-wu,Zhangxing,Zhangxing Zhen,zhang xing,zhang xing zhen,张星,张星镇', 37.4602300, 120.3400100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13452, 'Zhangxi', 'Zhangxi', 'Chang-ch''i,Chang-ch’i,Chang-hsi,Zhangxi,Zhangxi Xiang,zhang xi,zhang xi xiang,张溪,张溪乡', 28.4827500, 120.7762000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13453, 'Zhangwu', 'Zhangwu', 'Chang-wu,Chang-wu-ts''un,Chang-wu-ts’un,Zhangwu,zhang wu,鄣吴', 30.7797200, 119.5438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13454, 'Zhangwan', 'Zhangwan', 'Chang-wan,Zhangwan', 26.7113900, 119.5919400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13455, 'Zhangting', 'Zhangting', 'Chang-t''ing,Chang-t''ing-chen,Chang-t’ing,Chang-t’ing-chen,Zhangting,Zhangting Zhen,zhang ting,zhang ting zhen,丈亭,丈亭镇', 30.0152800, 121.2842400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13456, 'Zhangshu', 'Zhangshu', 'Chang-shu-kang,Zhangshu,Zhangshu Zhen,Zhangshugang,zhang shu,zhang shu zhen,樟树,樟树镇', 28.5630600, 112.8116700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13457, 'Zhangpu', 'Zhangpu', 'Chang-p''u,Chang-p''u-chen,Chang-p’u,Chang-p’u-chen,Zhangpu,Zhangpu Zhen,zhang pu,zhang pu zhen,张浦,张浦镇', 31.2871400, 120.9478000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13458, 'Zhangmutou', 'Zhangmutou', 'Chang-ma-tao,Chang-mu-t''ou,Chang-mu-t’ou,Zhangmutou,Zhangmutou Zhen,zhang mu tou,zhang mu tou zhen,樟木头,樟木头镇', 22.8909600, 114.0716000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13459, 'Zhangliang', 'Zhangliang', 'Chang-liang-tien,Zhangliang,Zhangliang Zhen,Zhangliangdian,zhang liang,zhang liang zhen,张良,张良镇', 33.6694900, 113.0404700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13460, 'Zhangjin', 'Zhangjin', 'Ch''ang-chin-ho-shih,Chang-chin-ho,Ch’ang-chin-ho-shih,Zhangjin,Zhangjin Zhen,Zhangjinhe,zhang jin,zhang jin zhen,张金,张金镇', 30.1972600, 112.5976900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13461, 'Zhangjiazhuang', 'Zhangjiazhuang', 'Chang-chia-chuang,Zhangjiazhuang,Zhangjiazhuang Zhen,zhang jia zhuang,zhang jia zhuang zhen,张家庄,张家庄镇', 38.1749400, 114.7370300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13462, 'Zhangjiayuan', 'Zhangjiayuan', 'Zhangjiayuan,Zhangjiayuan Xiang,zhang jia yuan,zhang jia yuan xiang,张家垣,张家垣乡', 36.7218500, 106.3330000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13463, 'Zhangjiawo', 'Zhangjiawo', 'Zhangjiawo,Zhangjiawo Zhen,zhang jia wo,zhang jia wo zhen,张家窝,张家窝镇', 39.0561400, 117.0415200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13464, 'Zhangjiawan', 'Zhangjiawan', 'Chang-chia-wan,Zhangjiawan,Zhangjiawan Zhen,zhang jia wan,zhang jia wan zhen,张家湾,张家湾镇', 39.8606600, 116.6996400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13465, 'Zhangjiashan', 'Zhangjiashan', 'Chang-chia-Shan,Zhangjiashan,Zhangjiashan Zhen,zhang jia shan,zhang jia shan zhen,张家山,张家山镇', 28.0852300, 115.4792600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13466, 'Zhangqiao', 'Zhangqiao', 'Chang-chia-ch''iao,Chang-chia-ch’iao,Zhangjiaqiao,Zhangqiao,Zhangqiao Zhen,zhang jia qiao,zhang qiao,zhang qiao zhen,张家桥,张桥,张桥镇', 32.1159300, 120.0596900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13467, 'Zhangjiapan', 'Zhangjiapan', 'Chang-chia-fan,Chang-chia-p''an,Chang-chia-p’an,Ching-pien,Jingbian,Jingbian Xian,Zhangjiapan,jing bian xian,zhang jia pan,张家畔,靖边县', 37.6015700, 108.7970200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13468, 'Zhangji', 'Zhangji', 'Chang-chia-chi,Zhangji,Zhangji Zhen,Zhangjiaji,zhang ji,zhang ji zhen,张集,张集镇', 31.5116000, 112.7784100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13469, 'Zhangjiahe', 'Zhangjiahe', 'Chang-chia-ho,Zhangjiahe,zhang jia he,张家河', 33.4413900, 106.5644700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13470, 'Zhangfang', 'Zhangfang', 'Chang-chia-fang,Chang-chia-hsu,Chang-chia-hsü,Zhangfang,Zhangfang Zhen,Zhangjiafang,zhang fang,zhang fang zhen,张坊,张坊镇', 28.3272100, 114.1030200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13471, 'Kuocang', 'Kuocang', 'Chang-chia-tu,Chang-chia-tu-shih,Kuocang,Kuocang Zhen,Zhangjiadu,kuo cang,kuo cang zhen,zhang jia du,张家渡,括苍,括苍镇', 28.8586900, 120.9825100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13472, 'Zhangjiachuan', 'Zhangjiachuan', 'Chang-ch''uan,Chang-ch''uan-chen,Chang-chia-ch''uan,Chang-chia-ch''uan-chen,Chang-chia-ch''uan-hui-tsu-tzu-chih-ch''u,Chang-chia-ch''uan-hui-tsu-tzu-chih-hsien,Chang-chia-ch’uan,Chang-chia-ch’uan-chen,Chang-chia-ch’uan-hui-tsu-tzu-chih-ch’ü,Chang-chia-ch’uan-hui-tsu-tzu-chih-hsien,Chang-ch’uan,Chang-ch’uan-chen,Chzhantszyachuan'',Chzhantszyachuan’,Zhangchuan,Zhangjiachuan,Zhangjiachuan Huizu Zizhixian,zhang jia chuan,zhang jia chuan hui zu zi zhi xian,张家川,张家川回族自治县', 34.9875600, 106.2090200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13473, 'Zhangji', 'Zhangji', 'Chang-chi,Zhangji,Zhangji Xiang,zhang ji,zhang ji xiang,张集,张集乡', 34.0500000, 119.6500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13474, 'Zhangji', 'Zhangji', 'Shang-pai-ts''un,Shang-pai-ts’un,Zhangji,Zhangji Zhen,zhang ji,zhang ji zhen,张集,张集镇', 32.3560000, 111.8676300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13475, 'Zhangjiaji', 'Zhangjiaji', 'Chang-chi,Chang-chia-chi,Zhangji,Zhangjiaji,Zhangjiaji Xiang,zhang jia ji,zhang jia ji xiang,张家集,张家集乡', 31.8637500, 118.3764000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13476, 'Zhanghuban', 'Zhanghuban', 'Chang-hu,Chang-hu-fan,Chang-hu-pan,Zhanghu Zhen,Zhanghuban,zhang hu ban,zhang hu zhen,樟湖坂,樟湖镇', 26.3865400, 118.4840800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13477, 'Zhangguizhuang', 'Zhangguizhuang', 'Chang-kuei-chuang,Dongli,Dongli Qu,Zhangguizhuang,Zhangguizhuang Jiedao,dong li,dong li qu,zhang gui zhuang,zhang gui zhuang jie dao,东丽,东丽区,张贵庄,张贵庄街道', 39.0902000, 117.3071900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13478, 'Zhanggu', 'Zhanggu', 'Chang-ku,Chzhangu,Danba,Danba Xian,Rimochegotyu,Romichangku,Rongzhag,Rumichangu,Tan-pa,Tan-pa-hsien,Ts''an-pa,Tsan''ba,Tsan’ba,Ts’an-pa,Zhanggu,dan ba xian,zhang gu,丹巴县,章谷', 30.8687500, 101.8884800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13479, 'Zhangpu', 'Zhangpu', 'Chang-kung-p''u,Chang-kung-p’u,Zhanggongpu,Zhangpu,Zhangpu Zhen,zhang pu,zhang pu zhen,张铺,张铺镇', 32.7603100, 118.7854000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13480, 'Zhanggang', 'Zhanggang', 'Chang-kang,Changchiehkiang,Zhanggang,Zhanggang Zhen,zhang gang,zhang gang zhen,张港,张港镇', 30.5720400, 112.8766500, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13481, 'Zhanggang', 'Zhanggang', 'Chang-chiang,Chang-kang,Zhanggang,Zhanggang Zhen,zhang gang,zhang gang zhen,漳港,漳港镇', 25.9247900, 119.6272400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13482, 'Zhangfang', 'Zhangfang', 'Chang-fang,Chang-fang-chen,Zhangfang,Zhangfang Zhen,zhang fang,zhang fang zhen,张坊,张坊镇', 39.5707300, 115.7075000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13483, 'Zhangduangu', 'Zhangduangu', 'Chang-tuan-ku,Chang-tuan-ku-chuang,Zhangduangu,Zhangduangu Zhen,zhang duan gu,zhang duan gu zhen,张段固,张段固镇', 38.1328700, 114.9421200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13484, 'Zhangdu', 'Zhangdu', 'Chang-chia-tu,Chang-chia-tu-chen,Chang-tu,Changkiatu,Zhangdu,Zhangdu Zhen,zhang du,zhang du zhen,章渡,章渡镇', 30.5963700, 118.2279600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13485, 'Zibo', 'Zibo', 'C-po,Chang-chou-shih,Chang-tien,Chang-tien-shih,Chu-phok-chhi,Chu-phok-chhī,Cu-bauk,Czybo,Cṳ̆-báuk,Dzubo,Truy Bac,Truy Bác,Tzu-po,Zhangdian,Zibo,jjeubo si,shi bo shi,zaybw,zi bo,zi bo shi,zibo,zybw,Дзъбо,Цзыбо,زایبو,زىبو شەھىرى,زيبو,زیبو,ਜ਼ੀਬੋ,シ博市,淄博,淄博市,쯔보 시', 36.7905600, 118.0633300, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13486, 'Zhangdian', 'Zhangdian', 'Chang-tien,Chang-tien-chen,Zhangdian,Zhangdian Zhen,zhang dian,zhang dian zhen,张店,张店镇', 34.2000000, 119.3000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13487, 'Zhangdian', 'Zhangdian', 'Chang-tien,Chang-tien chen,Zhangdian,Zhangdian Zhen,zhang dian,zhang dian zhen,张甸,张甸镇', 32.4041800, 120.0514700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13488, 'Anyang', 'Anyang', 'AYN,Ahn Yang,An Duong,An Dương,An''jan,An''jang,An-jang,An-yang-hsien,Anjan,Anjang,Anjangas,Anyang,Chang-te,Changte-fu,Changteh,Changten,Dengtalu,Zhangde,an yang shi,an-yang si,anyangh,deng ta lu,Аньян,Аньянг,Анян,Анјанг,انيانغ,അൻയാങ്,安阳市,安陽市,灯塔路,안양 시', 36.0960000, 114.3827800, 'CN', '2015-07-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13489, 'Zhangcunping', 'Zhangcunping', 'Shih-chia-p''ing,Shih-chia-p’ing,Zhangcunping,Zhangcunping Zhen,zhang cun ping,zhang cun ping zhen,樟村坪,樟村坪镇', 31.2977300, 111.2049200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13490, 'Zhangcun', 'Zhangcun', 'Chang-ts''un,Chang-ts’un,Zhangcun,Zhangcun Jieban,zhang cun,zhang cun jie ban,张村,张村街办', 35.6501100, 111.3494400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13491, 'Panfeng', 'Panfeng', 'Panfeng,Panfeng Xiang,Zhangcun,pan feng,pan feng xiang,zhang cun,樟村,盘峰,盘峰乡', 28.9390500, 120.5400600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13492, 'Zhangcheng', 'Zhangcheng', 'Inghok,Inghokhsien,Ingtao,Intaihsien,Yongtai,Yung-fu,Yung-fu-chen,Yung-fu-hsien,Yung-t''ai,Yung-t''ai-ch''eng,Yung-t''ai-hsien,Yung-t’ai,Yung-t’ai-ch’eng,Yung-t’ai-hsien,Zhangcheng,zhang cheng,樟城', 25.8467600, 118.9369200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13493, 'Zhangba', 'Zhangba', 'Chang-pa-ssu,Chang-ta-ssu,Zhangba,zhang ba,丈八', 34.8965400, 107.6479000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13494, 'Zhan’erxiang', 'Zhan''erxiang', 'Chan-erh-hsiang,Zhan''erxiang,Zhan’erxiang,zhan r xiang,站儿巷', 33.7798600, 106.3003400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13495, 'Zhakou', 'Zhakou', 'Cha-k''ou,Cha-k’ou,Zhakou,Zhakou Zhen,zha kou,zha kou zhen,闸口,闸口镇', 29.9219600, 112.2017600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13496, 'Zhakou', 'Zhakou', 'Zhakou,Zhakou Xiang,zha kou,zha kou xiang,闸口,闸口乡', 29.8519600, 111.5007400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13497, 'Zhajin', 'Zhajin', 'Cha-ching,Cha-ching-chieh,Chachin,Chatsin,Zhajin,Zhajin Zhen,zha jin,zha jin zhen,渣津,渣津镇', 29.0096100, 114.2359700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13498, 'Zhaixi', 'Zhaixi', 'Chai-hsi,Zhaixi,Zhaixi Zhen,zhai xi,zhai xi zhen,窄溪,窄溪镇', 29.8698600, 119.7622600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13499, 'Zhaiwu', 'Zhaiwu', 'Chai-wu,Zhaiwu,Zhaiwu Zhen,zhai wu,zhai wu zhen,宅梧,宅梧镇', 22.6185300, 112.6286300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13500, 'Zhaitang', 'Zhaitang', 'Chai-t''ang,Chai-t’ang,Chi-t''ang,Chi-t’ang,Dongzhaitang,Tung-chai-t''ang,Tung-chai-t''ang-ts''un,Tung-chai-t’ang,Tung-chai-t’ang-ts’un,Zhaitang,Zhaitang Zhen,zhai tang,zhai tang zhen,斋堂,斋堂镇', 39.9711900, 115.6906100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13501, 'Zhaishi Miaozu Dongzuxiang', 'Zhaishi Miaozu Dongzuxiang', 'Chai-shih-chen,Chiu-sui-ning,Chzhaysichzhen,Jiusuining,Sui-ning,Zaishi,Zhaishi,Zhaishi Miaozu Dongzuxiang,Zhaishizhen', 26.5008300, 110.0444400, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13502, 'Zhaike', 'Zhaike', 'Zhaike,Zhaike Xiang,zhai ke,zhai ke xiang,寨科,寨科乡', 36.2915600, 106.4233700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13503, 'Zhaigang', 'Zhaigang', 'Chai-kang,Chai-kang-hsu,Chai-kang-hsü,Lien-nan,Lien-nan-hsien,Zhaigang,Zhaigang Zhen,zhai gang,zhai gang zhen,寨岗,寨岗镇', 24.5132600, 112.3451300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13504, 'Zhaiba', 'Zhaiba', 'Chai-pa,Zhaiba,Zhaiba Zhen,Zhaibachang,zhai ba,zhai ba zhen,寨坝,寨坝镇', 28.6027800, 106.5558300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13505, 'Zezhang', 'Zezhang', 'Tse-chang,Tse-chang-ts''un,Tse-chang-ts’un,Zezhang,Zezhang Zhen,ze zhang,ze zhang zhen,泽掌,泽掌镇', 35.7157300, 111.1555300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13506, 'Zetou', 'Zetou', 'Tse-t''ou-chi,Tse-t’ou-chi,Zetou,Zetou Zhen,Zetouji,ze tou,ze tou zhen,泽头,泽头镇', 37.0491500, 121.8878800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13507, 'Zengtian', 'Zengtian', 'Tseng-t''ien,Tseng-t''ien-chieh,Tseng-t’ien,Tseng-t’ien-chieh,Zengtian,Zengtian Zhen,zeng tian,zeng tian zhen,增田,增田镇', 27.3563000, 115.8389700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13508, 'Zengtian', 'Zengtian', 'Tseng-t''ien,Tseng-t’ien,Zengtian,Zengtian Zhen,ceng tian,ceng tian zhen,曾田,曾田镇', 24.0172100, 114.9831900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13509, 'Zengji', 'Zengji', 'Tseng-chia-chi,Zengji,Zengji Zhen,Zengjiaji,ceng ji,ceng ji zhen,曾集,曾集镇', 30.7202800, 112.3698300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13510, 'Zengjia', 'Zengjia', 'Tseng-chia-ho,Zengjia,Zengjia Zhen,Zengjiahe,ceng jia,ceng jia zhen,曾家,曾家镇', 32.6195700, 106.1011800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13511, 'Zengdian', 'Zengdian', 'Tseng-chia-tien,Zengdian,Zengdian Zhen,ceng dian,ceng dian zhen,曾店,曾店镇', 31.1258200, 113.7702700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13512, 'Zeku', 'Zeku', 'Zeku,Zeku Zhen,ze ku,ze ku zhen,泽库,泽库镇', 36.9402300, 122.0543100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13513, 'Zekou', 'Zekou', 'Tsawkow,Zekou,Zekou Jiedao,ze kou,ze kou jie dao,泽口,泽口街道', 30.4870600, 112.8715200, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13514, 'Zejia', 'Zejia', 'Tse-chia-hu,Zejia,Zejia Zhen,Zejiahu,ze jia,ze jia zhen,泽家,泽家镇', 28.8528000, 109.7779400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13515, 'Zeguo', 'Zeguo', 'Tse-kuo,Zeguo,Zeguo Zhen,ze guo,ze guo zhen,泽国,泽国镇', 28.5115300, 121.3608600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13516, 'Zaozhuang', 'Zaozhuang', 'Cao-cuang,Cao-čuang,Cho-chng-chhi,Chó-chng-chhī,Co-cong,Czaochzhuan,Cō̤-cŏng,I-hsien,Tao Trang,Tsao-chuang,Tsao-chuang-shih,Tsaochwang,Tssaochwang,Tảo Trang,Zaozhuang,jjaojwang si,zao zhuang,zao zhuang shi,zawzhwang,Цзаочжуан,زاوژوانگ,枣庄市,棗荘市,棗莊,짜오좡 시', 34.8647200, 117.5541700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13517, 'Zaoyang', 'Zaoyang', 'Tsao-yang,Tsao-yang-hsien,Zaoyang', 32.1272200, 112.7541700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13518, 'Zaoxi', 'Zaoxi', 'Tsao-hsi,Zaoxi,zao xi,藻溪', 30.2006000, 119.4901000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13519, 'Zaoshi', 'Zaoshi', 'Tsao-shih,Zaoshi,Zaoshi Zhen,zao shi,zao shi zhen,皂市,皂市镇', 30.8557000, 113.3349600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13520, 'Zaoshi', 'Zaoshi', 'Tsao-chiao-shih,Tsao-shih,Zaoshi,Zaoshi Zhen,zao shi,zao shi zhen,皂市,皂市镇', 29.6543800, 111.2356500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13521, 'Zaoshi', 'Zaoshi', 'Guantang Pu,Tsao-shih,Zaoshi,Zaoshi Zhen,guan tang pu,zao shi,zao shi zhen,枣市,枣市镇,管塘铺', 26.6708300, 113.4447200, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13522, 'Xicun', 'Xicun', 'Tsao-lin,Tsao-lin-ts''un,Tsao-lin-ts’un,Xicun,Zaolin Zhen,xi cun,zao lin zhen,枣林镇,西村', 39.1513900, 113.1154500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13523, 'Zaolin', 'Zaolin', 'Tsao-lin,Tsao-lin-ying,Zaolin,Zaolin Zhen,zao lin,zao lin zhen,枣林,枣林镇', 34.3635200, 107.6961800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13524, 'Zaojiacheng', 'Zaojiacheng', 'Zaojiacheng,Zaojiacheng Zhen,zao jia cheng,zao jia cheng zhen,造甲城,造甲城镇', 39.2770600, 117.4357400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13525, 'Zangzhai', 'Zangzhai', 'Tsang-chai,Zangzhai,Zangzhai Xiang,zang zhai,zang zhai xiang,臧寨,臧寨乡', 39.6295300, 113.1136700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13526, 'Zangjiazhuang', 'Zangjiazhuang', 'Tsang-chia-chuang,Tsang-ko-chuang,Zanggezhuang,Zangjiazhuang,Zangjiazhuang Zhen,zang jia zhuang,zang jia zhuang zhen,臧家庄,臧家庄镇', 37.4661100, 120.9852800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13527, 'Zamashi', 'Zamashi', 'Gezidong,Ko-tzu-tung,Zamashi,Zamashi Xiang,ge zi dong,zha ma shen,zha ma shen xiang,扎麻什,扎麻什乡,鸽子洞', 38.2038900, 100.0150000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13528, 'Zagunao', 'Zagunao', 'Hsing-lung-ch''ang,Hsing-lung-ch’ang,Li,Li Xian,Li-hsien,Lixian,Shih-ku-nao,Tsa-ku-nao,Tsakulao,Tszagunao,Zagunao,li xian,za gu nao,杂谷脑,理县', 31.4461800, 103.1766200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13529, 'Yuzui', 'Yuzui', 'Yu-tsui-chen,Yu-tsui-t''o,Yuzhui Zhen,Yuzui,Yuzuizhen,Yü-tsui-chen,Yü-tsui-t’o,yu zui,yu zui zhen,鱼嘴,鱼嘴镇', 29.6204600, 106.7619900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13530, 'Shangyuzhuang', 'Shangyuzhuang', 'Hsia-yu-chuang-tzu,Hsia-yü-chuang-tzu,Shangyuzhuang,Yu-chuang,Yuzhuang Xiang,Yü-chuang,shang yu zhuang,yu zhuang xiang,上榆庄,余庄乡', 38.9075600, 112.2057900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13531, 'Yuzhu', 'Yuzhu', 'Yuzhu,Yuzhu Jiedao,yu zhu,yu zhu jie dao,鱼珠,鱼珠街道', 23.1025300, 113.4273400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13532, 'Yuzhong Chengguanzhen', 'Yuzhong Chengguanzhen', 'Chin,Chin-ch''eng,Chin-ch’eng,Yu-chung,Yu-chung-hsien,Yuzhong,Yuzhong Chengguanzhen,Yuzhong Xian,Yü-chung,Yü-chung-hsien,yu zhong cheng guan zhen,yu zhong xian,榆中县,榆中城关镇', 35.8427800, 104.1125000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13533, 'Yuyue', 'Yuyue', 'Chia-yu,Chia-yu-hsien,Chia-yü,Chia-yü-hsien,Jiayu,Kiayu,Kiayuhsien,Yuyue,yu yue,鱼岳', 30.0182000, 113.9632500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13534, 'Yuyao', 'Yuyao', 'Ju-kao,Jujao,YYP,Yuyao,yu yao,Юяо,余姚', 30.0500000, 121.1494400, 'CN', '2014-05-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13535, 'Yuyangguan', 'Yuyangguan', 'Ch''iao-ho,Ch’iao-ho,Yu-yang-kuan,Yuyangguan,Yuyangguan Zhen,Yuyangkwan,Yü-yang-kuan,yu yang guan,yu yang guan zhen,渔洋关,渔洋关镇', 30.1763600, 111.0700200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13536, 'Yuyang', 'Yuyang', 'Yuyang,Yuyang Zhen,yu yang,yu yang zhen,渔洋,渔洋镇', 30.1737500, 112.9028300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13537, 'Yuxin', 'Yuxin', 'Yu-hsien-tai,Yu-hsin,Yuxin,Yuxin Zhen,Yü-hsien-tai,Yü-hsin,yu xin,yu xin zhen,余新,余新镇', 30.6687900, 120.7884800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13538, 'Yuxin', 'Yuxin', 'Yu-hsin,Yuxin,Yuxin Zhen,Yü-hsin,yu xin,yu xin zhen,渔薪,渔薪镇', 30.6729300, 112.9909500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13539, 'Xiushui', 'Xiushui', 'Xiushui,Xiushui Zhen,Yu,Yu Xian,Yu-hsien,Yuhsie,Yuxian,Yuysyan'',Yuysyan’,Yü,Yü-hsien,Yühsie,xiu shui,xiu shui zhen,yu xian,盂县,秀水,秀水镇', 38.1037900, 113.3886500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13540, 'Yingchuan', 'Yingchuan', 'Yingchuan,Yu,Yu-hsien,Yuchow,Yuxian,Yuzhou,Yü,Yü-hsien,ying chuan,颍川', 34.1627800, 113.4638900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13541, 'Yuxiakou', 'Yuxiakou', 'Yu-hsia-k''ou,Yuxiakou,Yuxiakou Zhen,Yü-hsia-k’ou,yu xia kou,yu xia kou zhen,渔峡口,渔峡口镇', 30.4200900, 110.5012500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13542, 'Yuxia', 'Yuxia', 'Yu-hsia,Yu-hsia-li,Yuxia,Yuxia Zhen,Yü-hsia,Yü-hsia-li,yu xia,yu xia zhen,余下,余下镇', 34.0615300, 108.6290500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13543, 'Yuxi', 'Yuxi', 'Yu-ch''i,Yu-hsi,Yuxi,Yuxi Zhen,Yü-ch’i,Yü-hsi,yu xi,yu xi zhen,淤溪,淤溪镇', 32.5823100, 119.9992600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13544, 'Yuxi', 'Yuxi', 'Yu-hsi,Yuxi,Yuxi Zhen,Yü-hsi,yu xi,yu xi zhen,玉溪,玉溪镇', 30.3239200, 105.7774300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13545, 'Yuxi', 'Yuxi', 'Daozhen,Daozhen Gelaozu Miaozu Zizhixian,T''u-ch''i-ch''ang,Tao-chen,Tao-chen-hsien,Tukichang,T’u-ch’i-ch’ang,Yu-ch''i,Yu-ch''i-chen,Yu-hsi,Yuxi,Yuxi Zhen,Yü-ch’i,Yü-ch’i-chen,Yü-hsi,dao zhen ge lao zu miao zu zi zhi xian,yu xi,yu xi zhen,玉溪,玉溪镇,道真仡佬族苗族自治县', 28.8890000, 107.5940000, 'CN', '2014-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13546, 'Yuxi', 'Yuxi', 'Yu-ch''i,Yu-hsi,Yuxi,Yuxi Zhen,Yü-ch’i,Yü-hsi,yu xi,yu xi zhen,渔溪,渔溪镇', 25.6034000, 119.2919000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13547, 'Yuwang', 'Yuwang', 'Yuwang,Yuwang Zhen,yu wang,yu wang zhen,予旺,予旺镇', 36.8192900, 106.3776700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13548, 'Yuwan', 'Yuwan', 'Yuwan,Yuwan Zhen,yu wan,yu wan zhen,鱼湾,鱼湾镇', 24.1640700, 113.6650200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13549, 'Yutou', 'Yutou', 'Yo-tou-shi,Yu-t''ou-shih,Yutou,Yutou Zhen,Yü-t’ou-shih,yu tou,yu tou zhen,淤头,淤头镇', 28.6214900, 118.5056600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13550, 'Yuting', 'Yuting', 'Yuting,Yuting Zhen,yu ting,yu ting zhen,渔亭,渔亭镇', 29.8403800, 117.9696800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13551, 'Yutian', 'Yutian', 'Yu-t''ien,Yu-t''ien-ch''eng-kuan,Yu-t''ien-hsien,Yutian,Yü-t’ien,Yü-t’ien-ch’eng-kuan,Yü-t’ien-hsien,yu tian,玉田', 39.8786100, 117.7391700, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13552, 'Yutian', 'Yutian', 'Yutian,Yutian Zhen,yu tian,yu tian zhen,玉田,玉田镇', 25.8748200, 119.4517500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13553, 'Jicheng', 'Jicheng', 'Jicheng,Jicheng Zhen,Yu-she-hsien,Yushe,Yushe Xian,Yuyshe,Yü-she-hsien,ji cheng,ji cheng zhen,yu she xian,榆社县,箕城,箕城镇', 37.0635900, 112.9576900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13554, 'Yushan', 'Yushan', 'Yu-shan-chen,Yushan,Yushan Zhen,Yü-shan-chen,yu shan,yu shan zhen,郁山,郁山镇', 29.5328400, 108.4250400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13555, 'Yushan', 'Yushan', 'Yushan,Yushan Zhen,yu shan,玉山', 34.2056300, 109.5015800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13556, 'Yushan', 'Yushan', 'Yushan,Yushan Zhen,yu shan,yu shan zhen,玉山,玉山镇', 33.1994800, 113.8155000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13557, 'Yushan', 'Yushan', 'Yushan,Yushan Zhen,yu shan,yu shan zhen,峪山,峪山镇', 31.9894600, 112.3678500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13558, 'Kunshan', 'Kunshan', 'Con Son,Côn Sơn,K''un-shan-ch''eng,K''un-shan-hsien,KVN,Kan-shan,Kun''shan'',Kunsanas,Kunshan,Kunshan Shi,Kunšanas,K’un-shan-ch’eng,K’un-shan-hsien,Yushan,Yushan Zhen,kun shan,kun shan shi,kunsan si,kwnshan,yu shan,yu shan zhen,Куншан,Куньшань,کونشان,崑山,崑山市,昆山,昆山市,玉山,玉山镇,쿤산 시', 31.3776200, 120.9543100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13559, 'Yushan', 'Yushan', 'Yu-shan-chieh,Yushan,Yü-shan-chieh,yu shan,玉山', 26.9086300, 118.5671300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13560, 'Yuqi', 'Yuqi', 'Yu-ch''i,Yu-ch''i-chen,Yuqi,Yuqi Zhen,Yü-ch’i,Yü-ch’i-chen,yu qi,yu qi zhen,玉祁,玉祁镇', 31.7177100, 120.1828600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13561, 'Yuping', 'Yuping', 'Ching-pien,P''ing-pien,P''ing-pien-hsien,P''ing-pien-miao-tsu-tzu-chih-hsien,P’ing-pien,P’ing-pien-hsien,P’ing-pien-miao-tsu-tzu-chih-hsien,Tahotzu,Tsingpien,Yu-p''ing-chieh,Yuping,Yü-p’ing-chieh,yu ping,玉屏', 22.9769300, 103.7108500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13562, 'Yungaisi', 'Yungaisi', 'Yun-chen,Yun-kai-ssu,Yungaisi,Yungaisi Zhen,Yunzhen,Yün-chen,Yün-kai-ssu,yun gai si,yun gai si zhen,云盖寺,云盖寺镇', 33.4891700, 109.1052800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13563, 'Yunyang', 'Yunyang', 'Yun-yang-chen,Yunyang,Yunyang Zhen,Yün-yang-chen,yun yang,yun yang zhen,云阳,云阳镇', 34.6372200, 108.8086100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13564, 'Yunyang', 'Yunyang', 'Chiu-nan-chao,Jiunanzhao,Nan-chao,Nan-chao Old City,Nan-chao-chiu-chiu,Nan-chao-hsien,Nan-chao-ku-chih,Yunyang,yun yang,云阳', 33.4474300, 112.7142200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13565, 'Yunyang', 'Yunyang', 'Yun-yang-hsien,Yunyang,Yunyang Zhen,Yün-yang-hsien,yun yang,yun yang zhen,云阳,云阳镇', 30.9979500, 108.8813700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13566, 'Junyang', 'Junyang', 'Gao''an Shi,Gao’an Shi,Jui-chou,Juichow,Juichowfu,Junyang,Junyang Jiedao,Kao-an,Kao-an-hsien,Yunyang,gao an shi,jun yang,jun yang jie dao,筠阳,筠阳街道,高安市', 28.4166700, 115.3666700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13567, 'Yunxian Chengguanzhen', 'Yunxian Chengguanzhen', 'Yun,Yun-hsien,Yun-yang,Yun-yang-fu,Yunxian,Yunxian Chengguanzhen,Yün,Yün-hsien,Yün-yang,Yün-yang-fu,yun xian cheng guan zhen,郧县城关镇', 32.8312900, 110.8087500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13568, 'Aihua', 'Aihua', 'Aihua,Yun,Yun-ch''eng-chen,Yun-hsien,Yunchow,Yunxian,Yün,Yün-ch’eng-chen,Yün-hsien,Yünchow,ai hua,爱华', 24.4166700, 100.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13569, 'Yunxixian Chengguanzhen', 'Yunxixian Chengguanzhen', 'Yun-hsi,Yun-hsi-hsien,Yunsi,Yunsi-hsien,Yunxi,Yunxi Chengguanzhen,Yunxixian Chengguanzhen,Yün-hsi,Yün-hsi-hsien,Yünsi-hsien,yun xi cheng guan zhen,yun xi xian cheng guan zhen,郧西县城关镇,郧西城关镇', 32.9827600, 110.4230600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13570, 'Yunxi', 'Yunxi', 'Yan''tin,Yanting,Yan’tin,Yen-t''ing,Yen-t''ing-hsien,Yen-t’ing,Yen-t’ing-hsien,Yunxi,yun xi,云溪', 31.2264000, 105.3861400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13571, 'Yunxi', 'Yunxi', 'Yun-hsi,Yunxi,Yunxi Qu,Yün-hsi,yun xi,yun xi qu,云溪,云溪区', 29.4732800, 113.2458000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13572, 'Yunxi', 'Yunxi', 'Yunxi,yun xi,云溪', 29.0465400, 118.9396300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13573, 'Yunting', 'Yunting', 'Yun-t''ing-chen,Yunting,Yunting Zhen,Yün-t’ing-chen,yun ting,yun ting zhen,云亭,云亭镇', 31.8644100, 120.3372700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13574, 'Yunti', 'Yunti', 'Yunti,Yunti Shezuxiang,yun ti,yun ti she zu xiang,云梯,云梯畲族乡', 30.3744400, 119.2822200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13575, 'Yuntai', 'Yuntai', 'Yuntai,Yuntai Zhen,yun tai,yun tai zhen,云台,云台镇', 33.4463400, 105.6656100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13576, 'Yuntai', 'Yuntai', 'Yuntai,Yuntai Zhen,yun tai,yun tai zhen,云台,云台镇', 30.1389400, 107.2048700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13577, 'Yunshan', 'Yunshan', 'Yun-shan-shih,Yunshan,Yunshan Zhen,Yün-shan-shih,yun shan,yun shan zhen,云山,云山镇', 28.1759300, 116.2994900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13578, 'Yunmenling', 'Yunmenling', 'Chun-men-ling,Chün-men-ling,Yun-men-ling,Yunmenling,Yunmenling Zhen,Yün-men-ling,jun men ling,jun men ling zhen,筠门岭,筠门岭镇', 25.2407000, 115.7444000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13579, 'Yunmeng Chengguanzhen', 'Yunmeng Chengguanzhen', 'Yun-meng-hsien,Yunmeng,Yunmeng Chengguanzhen,Yün-meng-hsien,yun meng cheng guan zhen,云梦城关镇', 31.0625100, 113.7654500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13580, 'Yunmen', 'Yunmen', 'Yun''mon''chzhen'',Yun''myn''chzhen'',Yun-men-chen,Yunmen,Yunmen Zhen,Yun’myn’chzhen’,Yun’mön’chzhen’,Yün-men-chen,yun men,yun men zhen,云门,云门镇', 30.0827400, 106.3237600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13581, 'Yunluo', 'Yunluo', 'Yunluo,Yunluo Zhen,yun luo,yun luo zhen,云落,云落镇', 23.2437600, 116.0751800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13582, 'Yunlong', 'Yunlong', 'Yunlong,Yunlong Zhen,yun long,yun long zhen,云龙,云龙镇', 19.8765500, 110.4670600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13583, 'Yunling', 'Yunling', 'Yunling,Yunling Zhen,yun ling,yun ling zhen,云岭,云岭镇', 30.6533100, 118.2240900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13584, 'Yunling', 'Yunling', 'Yin-siao-ting,Yun-hsiao,Yunling,Yunsiao,Yunxiao,Yün-hsiao,yun ling,云陵', 23.9538400, 117.3360300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13585, 'Jinghong', 'Jinghong', 'Ch''e-li,Ch''e-li-hsien,Chianghung,Ching-hung,Ching-te,Chiu-lung-chiang,Ch’e-li,Ch’e-li-hsien,JHG,Jinghong,Kenghung,Kianghung,Kinlungkiang,Kiulungkiang,Kiulunkiang,Kuilung-kiang,Pan-na-ching-hung,Pan-na-yun-ching-hung,Pan-na-yün-ching-hung,Yun-ching-hung,Yun-ching-hung-chen,Yunjinghong,Yün-ching-hung,Yün-ching-hung-chen,cheiyng rung,jing hong,jing hong shi,เชียงรุ้ง,景洪,景洪市', 21.9910200, 100.7340900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13586, 'Pizhou', 'Pizhou', 'P''ei-hsien,Peixian,Pizhou,P’ei-hsien,Yun-ho,Yun-ho-ch''e-chan,Yun-ho-chen,Yunhe,Yün-ho,Yün-ho-chen,Yün-ho-ch’e-chan', 34.3113900, 117.9502800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13587, 'Yunhe', 'Yunhe', 'Kung-chi,Kung-chi-chieh,Yun-ho-chi,Yunhe,Yunhe Zhen,Yün-ho-chi,yun he,yun he zhen,运河,运河镇', 34.0833300, 119.7166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13588, 'Yunhe', 'Yunhe', 'Hao-ch''ing,Hao-ch''ing-hsien,Hao-ch’ing,Hao-ch’ing-hsien,Heqing,Ho-ch''ing,Ho-ch’ing,Hoking,Hoking-hsien,Yunhe,yun he,云鹤', 26.5249700, 100.1978000, 'CN', '2014-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13589, 'Yunfu', 'Yunfu', 'Hun-phu-chhi,Hung-pu,Hùng-pù,Hûn-phû-chhī,Juen-fu,Jun''fu,Jün-fu,Tung-an,Van Phu,Vân Phù,Wanfow,Yun-ch''eng,Yun-ch''eng-chen,Yun-fou,Yun-fou-hsien,Yunfu,Yün-ch’eng,Yün-ch’eng-chen,Yün-fou,Yün-fou-hsien,winpu si,yanfw,ynfw,yun fu,yun fu shi,ywnfw,Юньфу,یانفو,ینفو,یونفو,云浮,云浮市,雲浮,雲浮市,윈푸 시', 22.9283300, 112.0395400, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13590, 'Yuncheng', 'Yuncheng', 'Yun-ch''eng-hsien,Yuncheng,Yungchenghsien,Yün-ch’eng-hsien,yun cheng,郓城', 35.5983300, 115.9347200, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13591, 'Yuncheng', 'Yuncheng', 'An-i-hsien,Anyi,Anyihsien,Juen-ccheng,Jun''chehn,Juncheng,Jün-čcheng,Ong-siang,Van Thanh,Vận Thành,YCU,Yun''chen,Yun-ch''eng-chen,Yuncheng,Yuncheng Shi,Yun’chen,Yün-ch’eng-chen,an yi,wincheong si,yangchng,yun cheng,yun cheng shi,ywnchyng,Ông-siàng,Ūn-siâⁿ-chhī,Јунченг,Юньчэн,یانگچنگ,یونچینگ,安邑,运城,运城市,運城,運城市,윈청 시', 35.0230600, 110.9927800, 'CN', '2013-03-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13592, 'Yuncao', 'Yuncao', 'Ts''ao-yun,Ts’ao-yün,Yun-ts''ao,Yun-ts''ao-chen,Yun-ts''ao-ho,Yuncao,Yuncao Zhen,Yün-ts’ao,Yün-ts’ao-chen,Yün-ts’ao-ho,yun cao,yun cao zhen,运漕,运漕镇', 31.4226600, 118.0741000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13593, 'Yun’an', 'Yun''an', 'Yun''an,Yun''an Zhen,Yun-an-chen,Yun’an,Yun’an Zhen,Yün-an-chen,yun an,yun an zhen,云安,云安镇', 31.0456800, 108.8529000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13594, 'Yuling', 'Yuling', 'Yu-lin-ts''un,Yuling,Yuling Xiang,Yü-lin-ts’un,yu ling,yu ling xiang,榆岭,榆岭乡', 39.5558300, 112.4294400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13595, 'Yulindian', 'Yulindian', 'Yulindian,Yulindian Zhen,yu lin dian,yu lin dian zhen,玉林店,玉林店镇', 37.2772700, 121.6199600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13596, 'Yulinshi', 'Yulinshi', 'Du Lam,Du Lâm,Jiu-lim-chhi,Jiû-lîm-chhī,Jue-lin,Jujlin'',Jü-lin,U-ling,UYN,Yu-lin-hsien,Yulin,Yulinfu,Yulinshi,Yü-lin-hsien,wilin si,yu lin,yu lin shi,ywln  shangzy,Юйлинь,یولن، شانگزی,Ṳ̀-lìng,楡林,楡林市,榆林,榆林市,위린 시', 38.2918100, 109.7375300, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13597, 'Yulin', 'Yulin', 'Giok-lim-chhi,Gio̍k-lîm-chhī,Jue-lin,Jujlin'',Jü-lin,Ngiuk-lim-su,Ngiu̍k-lìm-sṳ,Ngoc Lam,Nguk-ling,Ngṳ̆k-lìng,Ngọc Lâm,Watlam,Watlam-hsien,Yo-ling,Yoglinz,Yu-lin-chen,Yu-lin-hsien,Yulin,Yü-lin-chen,Yü-lin-hsien,wilin si,yu lin,yu lin shi,ywlayn,ywln,ywln  gwangshy,Юйлинь,یولاین,یولن,یولن، گوانگشی,玉林,玉林市,위린 시', 22.6333300, 110.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13598, 'Yulao', 'Yulao', 'Yu-lao-hsu,Yulao,Yulao Zhen,Yü-lao-hsü,yu lao,yu lao zhen,渔涝,渔涝镇', 23.4971000, 111.7372900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13599, 'Yujing', 'Yujing', 'Wu-ching,Yu-ching,Yujing,Yujing Zhen,Yü-ching,yu jing,yu jing zhen,玉井,玉井镇', 39.6755200, 112.6029000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13600, 'Yujin', 'Yujin', 'Yu-chin,Yu-chin-chen,Yu-chin-t''un,Yujin,Yujin Zhen,Yü-chin,Yü-chin-chen,Yü-chin-t’un,yu jin,雨金', 34.5150800, 109.2446500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13601, 'Yujin', 'Yujin', 'Chien-wei,Chien-wei-hsien,Kienwei,Kienwei-hsien,Qianwei,Yujin,yu jin,玉津', 29.2090900, 103.9455600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13602, 'Wulingyuan', 'Wulingyuan', 'Wulingyuan,Wulingyuan Qu,Yujiazui,wu ling yuan,wu ling yuan qu,武陵源,武陵源区', 29.3493600, 110.5440700, 'CN', '2017-05-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13603, 'Yujiawu', 'Yujiawu', 'Yujiawu,Yujiawu Huizuxiang,yu jia wu,yu jia wu hui zu xiang,于家务,于家务回族乡', 39.7209600, 116.7029200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13604, 'Yujia', 'Yujia', 'Yujia,Yujia Zhen,Yujiachang,yu jia,yu jia zhen,余家,余家镇', 30.8115000, 107.9537700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13605, 'Yujia', 'Yujia', 'Yu-chia,Yujia,Yujia Xiang,Yü-chia,yu jia,yu jia xiang,余家,余家乡', 28.1744000, 117.0229700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13606, 'Yuhuangmiao', 'Yuhuangmiao', 'Yuhuangmiao,yu huang miao,玉皇庙', 33.7271500, 106.9489100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13607, 'Yuhua', 'Yuhua', 'Yuhua,Yuhua Zhen,yu hua,yu hua zhen,裕华,裕华镇', 33.2040600, 120.5421500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13608, 'Yuhu', 'Yuhu', 'Yuhu,Yuhu Zhen,yu hu,yu hu zhen,玉湖,玉湖镇', 23.6817300, 116.2336100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13609, 'Yuguzhuang', 'Yuguzhuang', '', 39.6400000, 117.3588900, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13610, 'Yugan', 'Yugan', 'Yu-kan,Yu-kan-chen,Yu-kan-hsien,Yu-kan-hsien-ch''eng,Yugan,Yugan Xian,Yü-kan,Yü-kan-chen,Yü-kan-hsien,Yü-kan-hsien-ch’eng,yu gan,yu gan xian,余干,余干县', 28.6956300, 116.6843900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13611, 'Yufang', 'Yufang', 'Yufang,Yufang Xiang,yu fang,yu fang xiang,余坊,余坊乡', 26.9021900, 117.2548100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13612, 'Yufa', 'Yufa', 'Yu-fa-chen,Yufa,Yufa Zhen,Yü-fa-chen,yu fa,yu fa zhen,榆垡,榆垡镇', 39.5196900, 116.3154200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13613, 'Yueyang', 'Yueyang', 'An-tse,An-tse-ch''eng,An-tse-ch’eng,An-tse-hsien,Chiu-an-tse,Gu Xian,Guxian,Ku-hsien,Yueh-yang,Yueh-yang-chen,Yueyang,Yueyang Zhen,Yüeh-yang,Yüeh-yang-chen,gu xian,yue yang,yue yang zhen,古县,岳阳,岳阳镇', 36.2896000, 111.9145400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13614, 'Yuexi', 'Yuexi', 'Qiuxi,Yuexi,Yuexi Zhen,yue xi,yue xi zhen,岳溪,岳溪镇', 30.9112700, 108.1592600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13615, 'Yuexi', 'Yuexi', 'Yuexi,Yuexi Jiedao,yue xi,yue xi jie dao,越溪,越溪街道', 31.2158700, 120.5841300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13616, 'Yuecheng', 'Yuecheng', 'Yuecheng,Yueh-ch''un,Yueh-chien,Yueh-hsi,Yueh-sui,Yueh-sui-hsien,Yuehsi,Yuexi,Yüeh-chien,Yüeh-ch’ün,Yüeh-hsi,Yüeh-sui,Yüeh-sui-hsien,Yüehsi,yue cheng,越城', 28.6415700, 102.5087000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13617, 'Yuetang', 'Yuetang', 'Yueh-t''ang,Yueh-t''ang-chi,Yuetang,Yuetang Xiang,Yüeh-t’ang,Yüeh-t’ang-chi,yue tang,yue tang xiang,月塘,月塘乡', 32.4047800, 119.0801900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13618, 'Yuelai', 'Yuelai', 'Yueh-lai,Yueh-lai-chen,Yuelai,Yuelai Zhen,Yüeh-lai,Yüeh-lai-chen,yue lai,yue lai zhen,悦来,悦来镇', 31.9357000, 121.4324500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13619, 'Yuelai', 'Yuelai', 'Yueh-lai,Yueh-lai-ch''ang,Yuelai,Yuelai Zhen,Yuelaichang,Yüeh-lai,Yüeh-lai-ch’ang,yue lai,yue lai zhen,悦崃,悦崃镇', 30.2053100, 108.2669900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13620, 'Jiulong', 'Jiulong', 'Iochi,Jiulong,Yo-ch''ih,Yo-ch’ih,Yochih-hsien,Yuechi,Yueh-ch''ih,Yueh-ch''ih-hsien,Yüeh-ch’ih,Yüeh-ch’ih-hsien,jiu long,九龙', 30.5362200, 106.4371300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13621, 'Yuecheng', 'Yuecheng', 'Yuecheng,Yuecheng Zhen,yue cheng,yue cheng zhen,悦城,悦城镇', 23.0979600, 112.1234300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13622, 'Yudongzi', 'Yudongzi', 'Yu-tung-tzu,Yudongzi,Yü-tung-tzu,yu dong zi,鱼洞子', 33.3250900, 106.3225300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13623, 'Yudong', 'Yudong', 'Yu-tung,Yu-tung-chen,Yudong,Yudong Zhen,Yutungchang,Yü-tung,Yü-tung-chen,yu dong,yu dong zhen,余东,余东镇', 32.0272300, 121.3550000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13624, 'Yudong', 'Yudong', 'Baxian,Chi-chia-t''o,Chi-chia-t’o,Jujdun,Pa,Pa-hsien,Yu-tung-ch''i,Yu-tung-chen,Yu-tung-hsi,Yudong,Yudongxi,Yü-tung-chen,Yü-tung-ch’i,Yü-tung-hsi,Юйдун', 29.3850000, 106.5194400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13625, 'Yucun', 'Yucun', 'Yu-ts''un,Yucun,Yucun Xiang,Yü-ts’un,shu cun,shu cun xiang,俞村,俞村乡', 30.3488900, 118.6313900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13626, 'Yuci', 'Yuci', 'Yu-tz''u,Yu-tz''u-hsien,Yu-tz''u-shih,Yuci,Yuci Qu,Yutzehsien,Yü-tz’u,Yü-tz’u-hsien,Yü-tz’u-shih,Yützehsien,yu ci,yu ci qu,榆次,榆次区', 37.6802800, 112.7319400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13627, 'Yucheng', 'Yucheng', 'Chiu-yu-t''ai,Chiu-yü-t’ai,Hitaihsien,Jujchehn,Yu-t''ai,Yu-t''ai-hsien,Yucheng,Yü-t’ai,Yü-t’ai-hsien,Юйчэн', 34.9288900, 116.4652800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13628, 'Yucheng', 'Yucheng', 'Yu-ch''eng-chen,Yucheng,Yucheng Zhen,Yü-ch’eng-chen,yu cheng,yu cheng zhen,于城,于城镇', 30.5350700, 120.8522900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13629, 'Yuanzhou', 'Yuanzhou', 'Yuanzhou,Yuanzhou Zhen,yuan zhou,yuan zhou zhen,园洲,园洲镇', 23.1228500, 113.9508000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13630, 'Yuanyi', 'Yuanyi', 'Yuan-i,Yuanbayi,Yuanyi,Yuanyi Zhen,Yüan-i,yuan ba yi,yuan yi,yuan yi zhen,袁坝驿,袁驿,袁驿镇', 30.7414000, 107.5132200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13631, 'Yuanyang', 'Yuanyang', 'Yuan-yang-ch''iao,Yuanyang,Yuanyang Jiedao,Yüan-yang-ch’iao,yuan yang,yuan yang jie dao,鸳鸯,鸳鸯街道', 29.6657200, 106.5574900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13632, 'Yuanwu', 'Yuanwu', 'Chiu-yuan-wu,Chiu-yüan-wu,Yuan-wu-hsien,Yuanwu,Yuanwu Zhen,Yüan-wu-hsien,yuan wu,yuan wu zhen,原武,原武镇', 34.9952800, 113.7747200, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13633, 'Yuantan', 'Yuantan', 'Yuan-t''an-hsu,Yuan-t’an-hsü,Yuantan,Yuantan Zhen,yuan tan,yuan tan zhen,源潭,源潭镇', 23.6675000, 113.1983300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13634, 'Yuanshan', 'Yuanshan', 'Lianping Xian,Lien-p''ing,Lien-p''ing-hsien,Lien-p’ing,Lien-p’ing-hsien,Lin-ping,Linping-hsien,Linpingchow,Yuanshan,Yuanshan Zhen,lian ping xian,yuan shan,yuan shan zhen,元善,元善镇,连平县', 24.3695900, 114.4896200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13635, 'Yuanren', 'Yuanren', 'Yuan-jen,Yuan-jen-chia,Yuanren,Yüan-jen,Yüan-jen-chia,yuan ren,原任', 34.7968100, 109.4548700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13636, 'Yuanqiao', 'Yuanqiao', 'Yuan-ch''iao,Yuan-ch''iao-chen,Yuanqiao,Yuanqiao Zhen,Yüan-ch’iao,Yüan-ch’iao-chen,yuan qiao,yuan qiao zhen,院桥,院桥镇', 28.5526500, 121.2487000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13637, 'Yuanping', 'Yuanping', 'Yuanping,Yuanping Shi,yuan ping,yuan ping shi,原平,原平市', 38.7152800, 112.7575000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13638, 'Yuanmou', 'Yuanmou', 'Ma-chieh,Makai,YUA,Yanma,Yuanma,Yuanmou,Yuanmow,Yuanmow-hsien,Yüanmow,Yüanmow-hsien,yuan ma,元马', 25.7058900, 101.8687500, 'CN', '2013-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13639, 'Yuanling', 'Yuanling', 'Ch''en-chou,Ch’en-chou,Shenchow,Shenchowfu,Yuan-ling-hsien,Yuanling,Yuanling Xian,Yüan-ling-hsien,yuan ling,yuan ling xian,沅陵,沅陵县', 28.4486100, 110.4022200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13640, 'Qianjiang', 'Qianjiang', 'Ch''ien-chiang,Ch''ien-chiang-hsien,Chien-kou,Ch’ien-chiang,Ch’ien-chiang-hsien,JQJ,Juan''lin'',Qianjiang,Qiánjiāng,Tsienkiang,Yuanlin,Yuanlin Jiedao,yuan lin,yuan lin jie dao,Юаньлинь,园林,园林街道', 30.4210000, 112.8919000, 'CN', '2013-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13641, 'Yuankeng', 'Yuankeng', 'Yuankeng,Yuankeng Zhen,yuan keng,yuan keng zhen,元坑,元坑镇', 26.7613400, 117.7106800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13642, 'Yuanjiazhuang', 'Yuanjiazhuang', 'Fo-p''ing-hsien,Fo-p’ing-hsien,Foping,Foping Xian,Yuan-chia-chuang,Yuanjiazhuang,Yuanjiazhuang Zhen,Yüan-chia-chuang,fu ping xian,yuan jia zhuang,yuan jia zhuang zhen,佛坪县,袁家庄,袁家庄镇', 33.5231900, 107.9830000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13643, 'Yuanhua', 'Yuanhua', 'Yuan-hua-chen,Yuan-hua-t''ang,Yuanhua,Yuanhua Zhen,Yüan-hua-chen,Yüan-hua-t’ang,yuan hua,yuan hua zhen,袁花,袁花镇', 30.4145400, 120.7715500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13644, 'Yuanhou', 'Yuanhou', 'Yuanhou,Yuanhou Zhen,Yuanhouchang,yuan hou,yuan hou zhen,元厚,元厚镇', 28.3408300, 105.9761100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13645, 'Yuanguping', 'Yuanguping', 'Yuanguping,Yuanguping Zhen,yuan gu ping,yuan gu ping zhen,沅古坪,沅古坪镇', 29.0158300, 110.7245400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13646, 'Yuandun', 'Yuandun', 'Chiu-tun-tzu,Yuan-tun,Yuan-tun-tzu,Yuandun,Yuandun Zhen,Yuandunzi,Yüan-tun,Yüan-tun-tzu,yuan dun,yuan dun zhen,元墩,元墩镇', 33.0278400, 106.6392000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13647, 'Yuancheng', 'Yuancheng', 'Yuancheng,Yuancheng Xiang,yuan cheng,yuan cheng xiang,元城,元城乡', 36.6520200, 107.7895700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13648, 'Heyuan', 'Heyuan', 'Che-juean,Che-jüan,Ha Nguyen,Heyuan,Ho-goan-chhi,Ho-ngien-su,Ho-yuan,Ho-yuan-hsien,Ho-yüan,Ho-yüan-hsien,Hoyun,Hoyunhsien,Hoyün,Hà Nguyên,Hò-ngièn-sṳ,Hô-goân-chhī,Khehjuan'',O-nguong,Yuancheng,he yuan,he yuan shi,heowian si,hywan,Ò̤-nguòng,Хэюань,هیوان,ہی یوآن,ہیئوان,河源,河源市,허위안 시', 23.7333300, 114.6833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13649, 'Yuanbuzi', 'Yuanbuzi', 'Yuan-pao-tzu,Yuanbuzi,Yuanbuzi Zhen,Yüan-pao-tzu,yuan bao zi,yuan bao zi zhen,元堡子,元堡子镇', 39.8222000, 112.5343400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13650, 'Yuanba', 'Yuanba', 'Yuanba,yuan ba,元坝', 32.3256300, 105.9617800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13651, 'Youzha', 'Youzha', 'Xiyi,Xiyi Zhen,Youzha,xi yi zhen,you zha,油榨,西一镇', 24.4661100, 103.2747200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13652, 'Youzai', 'Youzai', 'Youzai,Youzhai Zhen,Yu-tsai,Yu-tsai-pao,you zai,you zai zhen,友宰,友宰镇', 39.9509100, 113.8885100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13653, 'Youyang', 'Youyang', 'Youyang,Youyang Zhen,you yang,you yang zhen,游洋,游洋镇', 25.6250200, 118.8074100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13654, 'Youxikou', 'Youxikou', 'Youxikou,Youxikou Zhen,Yu-hsi-k''ou,Yu-hsi-k’ou,you xi kou,you xi kou zhen,尤溪口,尤溪口镇', 26.3981200, 118.4438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13655, 'Youxian Chengguanzhen', 'Youxian Chengguanzhen', 'You Xian,Youxian,Youxian Chengguanzhen,Yu,Yu-hsien,Yu-hsien-ch''eng,Yu-hsien-ch’eng,you xian,you xian cheng guan zhen,攸县,攸县城关镇', 26.9916800, 113.3606200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13656, 'Youxi', 'Youxi', 'Youxi,Youxi Zhen,Yu-hsi,you xi,you xi zhen,油溪,油溪镇', 29.2093600, 106.1442800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13657, 'Youxi', 'Youxi', 'Huayuan,Youxi,Youxi Zhen,Yu-hsi,hua yuan,you xi,you xi zhen,尤溪,尤溪镇,花园', 28.7402800, 121.0988100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13658, 'Youxi Chengguanzhen', 'Youxi Chengguanzhen', 'Youxi,Youxi Chengguanzhen,Yu-ch''i,Yu-ch''i-hsien,Yu-ch''i-hsien-ch''eng,Yu-ch’i,Yu-ch’i-hsien,Yu-ch’i-hsien-ch’eng,Yu-hsi,Yuki,Yukihsien,you xi cheng guan zhen,尤溪城关镇', 26.1736100, 118.1788900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13659, 'Youting', 'Youting', 'Youting,Youting Zhen,Yu-t''ing-p''u,Yu-t’ing-p’u,you ting,you ting zhen,邮亭,邮亭镇', 29.4312800, 105.7375700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13660, 'Youtian', 'Youtian', 'Youtian,Youtian Xiang,Yu-t''ien,Yu-t’ien,you tian,you tian xiang,油田,油田乡', 27.5120800, 114.7927600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13661, 'Youshui', 'Youshui', 'Youshui,Youshui Xiang,Yu-shui,you shui,you shui xiang,右水,右水乡', 25.4434700, 115.6697400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13662, 'Youlan', 'Youlan', 'Youlan,Youlan Zhen,Yu-lan,Yu-lan-shih,you lan,you lan zhen,幽兰,幽兰镇', 28.5800200, 116.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13663, 'Youguzhuang', 'Youguzhuang', 'Hsi-lung-ko-chuang,Youguzhuang', 39.9058300, 117.2461100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13664, 'Youfang', 'Youfang', 'Youfang,Youfang Zhen,Yu-fang,Yu-fang-chen,Yufanchzhen'',Yufanchzhen’,you fang,you fang zhen,油坊,油坊镇', 37.0114400, 115.7696700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13665, 'Youfang', 'Youfang', 'Youfang,Youfang Zhen,Yu-fang,Yu-fang-ch''iao,Yu-fang-ch’iao,you fang,you fang zhen,油坊,油坊镇', 32.1289200, 119.8443300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13666, 'Youdunjie', 'Youdunjie', 'Youdunjie,Youdunjie Zhen,Yu-tun-chieh,you dun jie,you dun jie zhen,油墩街,油墩街镇', 29.3770000, 116.6374200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13667, 'Youchou', 'Youchou', 'Youchou,Youchou Zhen,you chou,you chou zhen,酉酬,酉酬镇', 28.9634600, 109.1414700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13668, 'Youcheng', 'Youcheng', 'Youcheng,Youcheng Xiang,Yu-ch''eng,Yu-ch’eng,you cheng,you cheng xiang,游城,游城乡', 29.2365000, 116.8307700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13669, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Jiedao,Yung-hsing-chen,yong xing,yong xing jie dao,永兴,永兴街道', 31.9229800, 120.9201400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13670, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Zhen,Yung-hsing,yong xing,yong xing zhen,永兴,永兴镇', 30.9645300, 113.2306700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13671, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Zhen,Yongxingchang,Yung-hsing,yong xing,yong xing zhen,永兴,永兴镇', 28.9896800, 106.1761200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13672, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Zhen,Yung-hsing,yong xing,yong xing zhen,永兴,永兴镇', 27.9292700, 118.3689100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13673, 'Yongxing Chengguanzhen', 'Yongxing Chengguanzhen', 'Yongxing,Yongxing Chengguanzhen,Yongxing Xian,Yung-hsin,Yung-hsing,Yung-hsing-hsien,Yung-hsing-hsien-ch''eng,Yung-hsing-hsien-ch’eng,Yunghing,Yunghing-hsien,yong xing cheng guan zhen,yong xing xian,永兴县,永兴城关镇', 26.1240800, 113.1285200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13674, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Zhen,yong xing,yong xing zhen,永兴,永兴镇', 19.8938400, 110.2629400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13675, 'Yongxin', 'Yongxin', 'Yongxin,Yongxin Zhen,Yongxinchang,Yung-hsin,yong xin,yong xin zhen,永新,永新镇', 28.9666700, 106.5333300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13676, 'Yongtai', 'Yongtai', 'Yongtai,Yung-t''ai,Yung-t’ai,yong tai,永太', 34.8894400, 108.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13677, 'Yongtai', 'Yongtai', 'Yongtai,Yongtai Zhen,Yung-t''ai,Yung-t''ai-chieh,Yung-t’ai,Yung-t’ai-chieh,yong tai,yong tai zhen,永泰,永泰镇', 27.9429600, 115.4421000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13678, 'Yongshan', 'Yongshan', 'Yongshan,Yongshan Zhen,Yung-shan,Yung-shan-shih,yong shan,yong shan zhen,涌山,涌山镇', 29.1497000, 117.3148400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13679, 'Yongquan', 'Yongquan', 'Yongquan,Yongquan Zhen,Yung-ch''uan,Yung-ch''uan-chen,Yung-ch’üan,Yung-ch’üan-chen,yong quan,yong quan zhen,涌泉,涌泉镇', 28.7625600, 121.3175800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13680, 'Yongqing', 'Yongqing', 'Ch''ing-shui,Ch''ing-shui-hsien,Ch''ing-shui-hui-tsu-tzu-chih-chen,Ch’ing-shui,Ch’ing-shui-hsien,Ch’ing-shui-hui-tsu-tzu-chih-chen,Qingshui,Qingshui Xian,Tsinshuy,Yongqing,qing shui xian,yong qing,永清,清水县', 34.7480600, 106.1269400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13681, 'Yongping', 'Yongping', 'Ch''ien-shan,Ch''ien-shan-hsien,Ch''ien-shan-hsien-ch''eng,Ch’ien-shan,Ch’ien-shan-hsien,Ch’ien-shan-hsien-ch’eng,Yongping,Yongping Zhen,Yuan-hsien,Yuanshan,Yuanshanhsien,Yung-p''ing,Yung-p''ing-chen,Yung-p’ing,Yung-p’ing-chen,Yüanshan,yong ping,yong ping zhen,永平,永平镇', 28.2155400, 117.7777000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13682, 'Yongping', 'Yongping', 'Yongping,Yongping Xiang,Yung-p''ing,Yung-p’ing,yong ping,yong ping xiang,永平,永平乡', 25.2821200, 116.1141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13683, 'Yongning', 'Yongning', 'Yongning,yong ning,永宁', 33.8395600, 106.1886500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13684, 'Yongning', 'Yongning', 'Yongning,Yongning Zhen,Yung-ning,yong ning,yong ning zhen,永宁,永宁镇', 32.1361200, 118.5667700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13685, 'Yongning', 'Yongning', 'T''ung-ku,T''ung-ku-hsien,Tonggu Xian,Tung-k''ou,Tung-k’ou,Tungkuting,T’ung-ku,T’ung-ku-hsien,Yongning,Yongning Zhen,tong gu xian,yong ning,yong ning zhen,永宁,永宁镇,铜鼓县', 28.5244900, 114.3657600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13686, 'Yongning', 'Yongning', 'Yongning,Yung-ning', 24.6800000, 118.6900000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13687, 'Yongning', 'Yongning', 'Yongning,Yongning Zhen,yong ning,yong ning zhen,永宁,永宁镇', 22.2634800, 111.6023700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13688, 'Yonglong', 'Yonglong', 'Yonglong,Yonglong Xiang,yong long,yong long xiang,永隆,永隆乡', 25.4174000, 115.9311700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13689, 'Yongledian', 'Yongledian', 'Yongledian,Yongledian Zhen,Yung-le-tien,Yung-lo-tien,Yung-lo-tien-chen,yong le dian,yong le dian zhen,永乐店,永乐店镇', 39.7088800, 116.7766100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13690, 'Yongle', 'Yongle', 'Yongle,Yongle Zhen,Yongledian,Yung-le-chen,Yung-le-tien,Yung-lo-chen,yong le,yong le zhen,永乐,永乐镇', 34.5327800, 108.9380600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13691, 'Yongjia', 'Yongjia', 'Yongjia,Yongjia Zhen,Yung-chia,yong jia,yong jia zhen,永嘉,永嘉镇', 29.5719000, 106.0013400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13692, 'Yonghe', 'Yonghe', 'Yonghe,Yonghecun', 39.0752800, 117.4755600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13693, 'Zhihe', 'Zhihe', 'Yonghe,Yonghe Xian,Yung-ho,Yung-ho-hsien,Yung-ho-hsien-ch''eng,Yung-ho-hsien-ch’eng,Yunghwohsien,Yunkhe,Zhihe,Zhihe Zhen,yong he xian,zhi he,zhi he zhen,永和县,芝河,芝河镇', 36.7799600, 110.6395600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13694, 'Yongjiahe', 'Yongjiahe', 'Yin-chia-ho,Yonghe,Yongjiahe,Yongjiahe Zhen,yong jia he,yong jia he zhen,永佳河,永佳河镇', 31.1546300, 114.7076100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13695, 'Yonghe', 'Yonghe', 'Lien-shan,Lien-shan-chuang-tsu-yao-tsu-tzu-chih-hsien,Lien-shan-hsien,Yonghe,Yonghe Zhen,Yung-ho,Yung-ho-chen,Yung-ho-hsu,Yung-ho-hsü,yong he,yong he zhen,永和,永和镇', 24.6166700, 112.0333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13696, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Zhen,yong he,yong he zhen,永和,永和镇', 24.1453700, 115.8001200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13697, 'Yonghan', 'Yonghan', 'Yonghan,Yonghan Zhen,Yung-han,Yung-han-hsu,Yung-han-hsü,yong han,yong han zhen,永汉,永汉镇', 23.5708300, 113.9711100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13698, 'Yonggu', 'Yonggu', 'Yonggu,Yonggu Xiang,yong gu,yong gu xiang,永固,永固乡', 38.3810900, 100.9506500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13699, 'Yonggu', 'Yonggu', 'Yonggu,Yonggu Xiang,Yung-ku,Yung-ku-ts''un,Yung-ku-ts’un,yong gu,yong gu xiang,永固,永固乡', 35.7213000, 111.3631000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13700, 'Yonggu', 'Yonggu', 'Yonggu,Yonggu Zhen,yong gu,yong gu zhen,永固,永固镇', 23.7161800, 112.0693600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13701, 'Yongfu', 'Yongfu', 'Yongfu,Yongfu Zhen,Yung-fu,Yung-fu-hsun,Yung-fu-hsün,Yung-fu-li,Yung-fu-li-hsu,Yung-fu-li-hsü,yong fu,yong fu zhen,永福,永福镇', 25.0653400, 117.3029500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13702, 'Yongfu', 'Yongfu', 'Yongfu,Yung-fu,Yung-fu-chen,Yung-fu-hsien,yong fu,永福', 25.0040200, 109.9818500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13703, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Zhen,Yongfengchang,Yung-feng-ch''ang,Yung-feng-ch’ang,yong feng,yong feng zhen,永丰,永丰镇', 30.3185100, 107.8194000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13704, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Zhen,Yung-feng,Yung-feng-chen,yong feng,永丰', 34.9991700, 109.8592600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13705, 'Yongfeng', 'Yongfeng', 'Guangfeng,Kuang-feng,Kuang-feng-hsien,Kuang-feng-hsien-ch''eng,Kuang-feng-hsien-ch’eng,Kwangfeng,Kwangfeng-hsien,Yongfeng,Yongfeng Xiang,yong feng,yong feng xiang,永丰,永丰乡', 28.4189300, 118.2136600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13706, 'Yongfeng', 'Yongfeng', 'Shuangfeng,Yongfeng,Yung-feng,Yung-feng-chen,Yung-feng-shih,Yungfengsze,yong feng,永丰', 27.4282900, 112.1833800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13707, 'Yongding', 'Yongding', 'Chu-chueh,Chuchih,Chucho,Chü-chüeh,Yongding,Yongren,Yung-jen,Yung-jen-hsien,Yung-ting-chen,yong ding,永定', 26.0412200, 101.6864200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13708, 'Yongding', 'Yongding', 'Fu-min-hsien,Yongding,yong ding,永定', 25.1986000, 102.4618900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13709, 'Yongdeng Chengguanzhen', 'Yongdeng Chengguanzhen', 'P''ing-fan,Pinfan'',Pinfan’,Pingfanhsien,P’ing-fan,Yongdeng,Yongdeng Chengguanzhen,Yongdeng Xian,Yunden,Yung-teng,Yung-teng-hsien,yong deng cheng guan zhen,yong deng xian,永登县,永登城关镇', 36.7336100, 103.2593100, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13710, 'Taocheng', 'Taocheng', 'Taocheng,Yongchun,Yung-ch''un,Yung-ch''un-hsien,Yung-ch’un,Yung-ch’un-hsien,tao cheng,桃城', 25.3123000, 118.3005600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13711, 'Yongchang Chengguanzhen', 'Yongchang Chengguanzhen', 'Yongchang,Yongchang Chengguanzhen,Yongchang Xian,Yunchan,Yung-ch''ang,Yung-ch''ang-hsien,Yung-ch’ang,Yung-ch’ang-hsien,yong chang cheng guan zhen,yong chang xian,永昌县,永昌城关镇', 38.2705300, 102.0201700, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13712, 'Yongchuan', 'Yongchuan', 'Jungchunghsien,Yongchang,Yongchuan,Yung-ch''uan,Yung-ch''uan-hsien,Yung-ch’uan,Yung-ch’uan-hsien,Yungchwan,Yungchwan-hsien,yong chuan,永川', 29.3537600, 105.8939200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13713, 'Yongchang', 'Yongchang', 'Yongchang,Yung-ch''ang,Yung-ch''ang-ch''en,Yung-ch’ang,Yung-ch’ang-ch’en,yong chang,永昌', 29.2280100, 119.3528400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13714, 'Yongbei', 'Yongbei', 'Yongbei,Yongsheng,Yung-pei,Yung-shen,Yung-sheng,Yung-sheng-chen,Yung-sheng-hsien,Yungpeh,Yungpeh-hsien,yong bei,永北', 26.6462300, 100.7807300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13715, 'Yong’an', 'Yong''an', 'Feng-chieh,Feng-chieh-hsien,Feng-chien,Fengjie Xian,Fengkieh,Fengkieh-hsien,K''uei-chou,Kwei-chow-fu,Kweichow,K’uei-chou,Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,feng jie xian,yong an,yong an zhen,奉节县,永安,永安镇', 31.0205600, 109.4587100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13716, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 30.4618100, 113.9286300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13717, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 28.2032500, 106.4248900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13718, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,Yung-an,yong an,yong an zhen,永安,永安镇', 28.1148500, 107.5821100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13719, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Shi,Yong’an,Yong’an Shi,Yuang An,Yung-an,Yung-an-hsien,yong an,yong an shi,永安,永安市', 25.9800000, 117.3641700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13720, 'Yizhang Chengguanzhen', 'Yizhang Chengguanzhen', 'I-chang,I-chang-hsien,Ichung,Yizhang,Yizhang Chengguanzhen,yi zhang cheng guan zhen,宜章城关镇', 25.3832300, 112.9789700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13721, 'Yiyang Chengguanzhen', 'Yiyang Chengguanzhen', 'I-yang,I-yang-hsien,Yiang,Yiyang,Yiyang Chengguanzhen,yi yang cheng guan zhen,宜阳城关镇', 34.5108300, 112.1622200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13722, 'Yixingfu', 'Yixingfu', 'I-hsing-fou,Yixingbu,Yixingfu,Yixingfu Zhen,yi xing bu,yi xing bu zhen,宜兴埠,宜兴埠镇', 39.1991700, 117.2113900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13723, 'Yixi', 'Yixi', 'I-hsi,Yixi,Yixi Zhen,yi xi,yi xi zhen,意溪,意溪镇', 23.6994700, 116.6405300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13724, 'Yiting', 'Yiting', 'I-t''ing,I-ting-shih,I-t’ing,Yiting,Yiting Zhen,yi ting,yi ting zhen,义亭,义亭镇', 29.2359700, 119.9608900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13725, 'Yitiaoshan', 'Yitiaoshan', 'Ching-t''ai,Ching-t’ai,Hung-shui,I-t''iao-shan,I-t’iao-shan,Ityaoshan'',Ityaoshan’,Jingtai,Jingtai Xian,Khunshuy,Lu-yang,Ta-lu-t''ang,Ta-lu-t’ang,Tsintay,Yitiaoshan,jing tai xian,yi tiao shan,一条山,景泰县', 37.1533000, 104.0620000, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13726, 'Yitao', 'Yitao', 'Yitao,Yitao Zhen,yi tao,yi tao zhen,沂涛,沂涛镇', 34.0833300, 119.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13727, 'Yitang', 'Yitang', 'I-t''ang,I-t''ang-chen,I-t’ang,I-t’ang-chen,Yitang,Yitang Zhen,yi tang,yi tang zhen,义堂,义堂镇', 31.0956800, 113.7044200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13728, 'Yisuhe', 'Yisuhe', 'I-su-ho,Yisuhe,yi su he,易俗河', 27.7654400, 112.9268300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13729, 'Yishui', 'Yishui', 'I-shui,I-shui-hsien,Yishui', 35.7847200, 118.6280600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13730, 'Yishui', 'Yishui', 'Yishui,Yishui Zhen,yi shui,yi shui zhen,溢水,溢水镇', 32.2677200, 110.0904800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13731, 'Yishi', 'Yishi', 'I-shih-chieh,Yishi,Yishi Zhen,Yishijie,yi shi,yi shi zhen,一市,一市镇', 29.1994400, 121.4747200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13732, 'Yishi', 'Yishi', 'I-shih,I-shih-ch''eng,I-shih-chen,I-shih-ch’eng,I-shih-hsien,Ishi,Lin-i,Lin-i-hsien,Linyi,Linyi Xian,Yishi,Yishi Zhen,lin yi xian,yi shi,yi shi zhen,临猗县,猗氏,猗氏镇', 35.1649700, 110.7459800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13733, 'Yishan', 'Yishan', 'Dayishan,Guanyun Xian,Kuan-yun,Kuan-yun-hsien,Kuan-yün,Kuan-yün-hsien,Ta-i-shan,Ta-i-shan-chen,Ta-shan-chen,Tayishan,Yishan,Yishan Zhen,guan yun xian,yi shan,yi shan zhen,伊山,伊山镇,灌云县', 34.2994400, 119.2541700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13734, 'Yisa', 'Yisa', 'Honghe,Hung-ho,I-sa,I-sa-chen,Yisa,Yisa Zhen,Yisha,yi sa,迤萨', 23.3323100, 102.4471100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13735, 'Yirong', 'Yirong', 'Yirong,Yirong Zhen,yi rong,yi rong zhen,义容,义容镇', 23.5229000, 114.8310300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13736, 'Yiqiao', 'Yiqiao', 'I-ch''iao,I-ch''iao-chen,I-ch’iao,I-ch’iao-chen,Yiqiao,Yiqiao Zhen,yi qiao,yi qiao zhen,义桥,义桥镇', 30.0695600, 120.1978400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13737, 'Yinzu', 'Yinzu', 'Yin-tsu,Yin-tsu-chieh,Yinzu,Yinzu Zhen,yan zu,yan zu zhen,殷祖,殷祖镇', 29.9602900, 114.8866000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13738, 'Yinzi', 'Yinzi', 'Yin-tzu-K''uang,Yin-tzu-K’uang,Yinzi,Yinzi Zhen,Yinzikuang,yin zi,yin zi zhen,荫子,荫子镇', 37.2149600, 122.3128100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13739, 'Yinzhu', 'Yinzhu', 'Yin-chu-pu,Yinzhu,Yinzhubu,yin zhu,印渚', 29.9823000, 119.4168600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13740, 'Yinzhen', 'Yinzhen', 'Yin-chen,Yin-chia-hui,Yin-chia-hui-chen,Yinjiahui,Yinzhen,yin zhen,引镇', 34.0826800, 109.0976600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13741, 'Yinying', 'Yinying', 'Jiao Qu,Lao-hu-kou,Shang-yin-ying,Yangquan Jiaoqu,Yinying,Yinying Zhen,jiao qu,yang quan jiao qu,yin ying,yin ying zhen,荫营,荫营镇,郊区,阳泉郊区', 37.9369400, 113.5575000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13742, 'Yinyang', 'Yinyang', 'Yin-yang-chen,Yinyang,Yinyang Zhen,yin yang,yin yang zhen,寅阳,寅阳镇', 31.7148300, 121.8618700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13743, 'Yintang', 'Yintang', 'Yintang,Yintang Zhen,yin tang,yin tang zhen,银塘,银塘镇', 31.6015700, 118.5293000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13744, 'Yinliu', 'Yinliu', '', 39.9825000, 117.3963900, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13745, 'Yinkeng', 'Yinkeng', 'Yinkang,Yinkeng,Yinkeng Zhen,yin keng,yin keng zhen,银坑,银坑镇', 26.2151200, 115.6147300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13746, 'Yinjiang', 'Yinjiang', 'Yin-chiang,Yin-chiang-chiao,Yinjiang,Yinjiang Zhen,yin jiang,yin jiang zhen,鄞江,鄞江镇', 29.7742000, 121.3551900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13747, 'Eling', 'Eling', 'Eling,Yin-chiang,Yin-chiang-hsien,Yinjiang,Yinjiang Tujiazu Miaozu Zizhixian,Yinkiang-hsien,e ling,yin jiang tu jia zu miao zu zi zhi xian,印江土家族苗族自治县,峨岭', 28.0004500, 108.4009300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13748, 'Yinji', 'Yinji', 'Yin-chia-chi,Yinji,Yinji Xiang,Yinjiaji,yin ji,yin ji xiang,尹集,尹集乡', 31.9407400, 112.0738600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13749, 'Yinjiacheng', 'Yinjiacheng', 'Yinjiacheng,Yinjiacheng Xiang,yan jia cheng,yan jia cheng xiang,殷家城,殷家城乡', 36.1886600, 106.9412700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13750, 'Yinji', 'Yinji', 'Yinji,Yinji Zhen,yin ji,尹集', 33.2508200, 113.5750000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13751, 'Yining', 'Yining', 'Hsiu-shui,Hsiu-shui-hsien,I-ning,I-ning-chen,Iningchow,Siushui,Siushui-hsien,Suishiuhsien,Xiushui,Xiushui Xian,Yining,Yining Zhen,xiu shui xian,yi ning,yi ning zhen,义宁,义宁镇,修水县', 29.0361400, 114.5636200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13752, 'Yingzhou', 'Yingzhou', 'Yingzhou,Yingzhou Zhen,ying zhou,ying zhou zhen,英州,英州镇', 18.4214900, 109.8494100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13753, 'Zhongxiang', 'Zhongxiang', 'An-lu,Anlu,Anlufu,Chung-hsiang,Chung-hsiang-hsien,Chungsiang,Yingzhong,Zhongxiang', 31.1661100, 112.5830600, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13754, 'Yingzai', 'Yingzai', 'Yingzai,Yingzai Zhen,ying zi,ying zi zhen,营仔,营仔镇', 21.4905200, 109.9252000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13755, 'Yingxian', 'Yingxian', 'Insyan'',Insyan’,Jincheng,Jincheng Zhen,Ying,Ying Xian,Ying-hsien,Yingchow,jin cheng,jin cheng zhen,ying xian,应县,金城,金城镇', 39.5591200, 113.1855400, 'CN', '2015-11-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13756, 'Yingtou', 'Yingtou', 'Hsia-ying-t''ou,Hsia-ying-t’ou,Yingtou,Yingtou Zhen,ying tou,ying tou zhen,营头,营头镇', 34.1601400, 107.7538600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13757, 'Yingshang Chengguanzhen', 'Yingshang Chengguanzhen', 'Yin-shang,Ying-shang-hsien,Yingshang,Yingshang Chengguanzhen,ying shang cheng guan zhen,颖上城关镇', 32.6294500, 116.2701300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13758, 'Yingqiao', 'Yingqiao', 'Yingqiao,Yingqiao Huizuzhen,ying qiao,ying qiao hui zu zhen,颍桥,颍桥回族镇', 33.9634200, 113.5853000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13759, 'Yingqian', 'Yingqian', 'Ying-ch''ien,Ying-ch’ien,Yingqian,Yingqian Zhen,ying qian,ying qian zhen,营前,营前镇', 25.9670700, 119.4632200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13760, 'Yingli', 'Yingli', 'Ying-li-hsu,Ying-li-hsü,Ying-ts''un,Ying-ts’un,Yingli,Yingli Zhen,ying li,ying li zhen,英利,英利镇', 20.5642100, 110.0962600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13761, 'Yinggen', 'Yinggen', 'Ch''iung-chung,Ch’iung-chung,Qiongzhong,Qiongzhong Lizu Miaozu Zizhixian,Ying-ken,Ying-ken-chen,Ying-ken-p''u,Ying-ken-p’u,Yinggen,Yinggen Zhen,qiong zhong li zu miao zu zi zhi xian,ying gen,ying gen zhen,琼中黎族苗族自治县,营根,营根镇', 19.0383300, 109.8400000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13762, 'Yinggehai', 'Yinggehai', 'Inkohai,Yeko Hoi,Ying Khoa,Ying-ko-hai,Ying-ko-hai-shih,Ying-ko-tsui,Yinggehai,Yinggehai Zhen,ying ge hai,ying ge hai zhen,莺歌海,莺歌海镇', 18.5114200, 108.6894400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13763, 'Yingfengqiao', 'Yingfengqiao', 'Ying-feng-ch''iao,Ying-feng-ch’iao,Yingfengqiao,Yingfengqiao Zhen,ying feng qiao,ying feng qiao zhen,迎风桥,迎风桥镇', 28.6608300, 112.2633300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13764, 'Yingdu', 'Yingdu', 'Ying-nei,Ying-tu,Yingdu', 24.9716700, 118.2441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13765, 'Yingdianjie', 'Yingdianjie', 'Yingdianjie,Yingdianjie Zhen,ying dian jie,ying dian jie zhen,应店街,应店街镇', 29.8172200, 120.1138900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13766, 'Yingcheng', 'Yingcheng', 'Ying-te,Ying-te-hsien,Yingcheng,Yingde,Yingtak,Yingtak-hsien,ying cheng,英城', 24.1658800, 113.4126700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13767, 'Yingcui', 'Yingcui', 'Ying-tsui-yen,Yingcui,Yingcui Zhen,Yingzuiyan,ying cui,ying cui zhen,英萃,英萃镇', 32.4824000, 106.4510800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13768, 'Yingchuan', 'Yingchuan', 'Ying-ts''un,Ying-ts’un,Yingchuan,Yingchuan Zhen,ying chuan,ying chuan zhen,英川,英川镇', 27.8530600, 119.3152800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13769, 'Chengzhong', 'Chengzhong', 'Chengzhong,Chengzhong Jiedao,Ying-ch''eng-hsien,Ying-ch’eng-hsien,Yingcheng,cheng zhong,cheng zhong jie dao,ying cheng,城中,城中街道,应城', 30.9445400, 113.5528400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13770, 'Yindian', 'Yindian', 'Yin-tien,Yindian,Yindian Zhen,yan dian,yan dian zhen,殷店,殷店镇', 32.0721300, 113.5056100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13771, 'Yinchuan', 'Yinchuan', 'Gin-chhoan-chhi,Gîn-chhoan-chhī,Ho-lan,INC,In''chuan'',Inchuan,Incuanas,Inčuanas,Jin-cchuan,Jin-čchuan,Jinchuan,Ngan Xuyen,Ngung-chiong,Ngân Xuyên,Ngṳ̀ng-chiŏng,Ning-hsia,Ningsia,Ningsia-hsien,Ningsiafu,Thanh pho Ngan Xuyen,Thành phố Ngân Xuyên,Yin-ch''uan-shih,Yin-ch’uan-shih,Yinchuan,Yinchuan Shi,Yinzconh,inchwan si,mdynt ynshwan,yin chuan,yin chuan shi,ynchwan,yynchwan,Їньчуань,Јинчуан,Инчуан,Иньчуань,مدينة ينشوان,يىنچۈئەن شەھىرى,ینچوآن,ینچوان,یینچوان,യിഞ്ചുവാൻ,ཡིན་ཁྲོའོན་གྲོང་ཁྱེར།,銀川,銀川市,银川,银川市,인촨 시', 38.4680600, 106.2730600, 'CN', '2015-11-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13772, 'Yima', 'Yima', 'I-ma,Jimy,Yima,Йимы', 34.7380600, 111.8838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13773, 'Yiling', 'Yiling', 'I-ling,I-ling-chen,T-ling,Yiling,Yiling Zhen,yi ling,yi ling zhen,宜陵,宜陵镇', 32.4820000, 119.6738400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13774, 'Yijing', 'Yijing', 'I-ching,I-ching-ts''un,I-ching-ts’un,Yijing,Yijing Xiang,yi jing,yi jing xiang,义井,义井乡', 39.6393100, 113.2140300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13775, 'Yijing', 'Yijing', 'I-ching,I-ching-chen,Itsing,Yijing,Yijing Zhen,yi jing,yi jing zhen,义井,义井镇', 39.0644900, 111.9998400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13776, 'Yijing', 'Yijing', 'Cheng Qu,I-ching,I-ching-chen,Yijing,Yijing Jiedao,cheng qu,yi jing,yi jing jie dao,义井,义井街道,城区', 37.8355600, 113.6019400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13777, 'Yijing', 'Yijing', 'Chin-t''ou-chen,Chin-t’ou-chen,I-ching,I-ching-chen,Yijing,Yijing Zhen,yi jing,yi jing zhen,义井,义井镇', 34.5722200, 108.1050000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13778, 'Yijiang', 'Yijiang', 'Ch''ing-i-chiang,Ch’ing-i-chiang,I-chiang-chen,Tsingkiang,Yijiang,Yijiang Zhen,yi jiang,yi jiang zhen,弋江,弋江镇', 30.9074500, 118.4860600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13779, 'Yigou', 'Yigou', 'I-kou,I-kou-chen,I-kou-i,Igoui,Yigou', 35.8113900, 114.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13780, 'Yigou', 'Yigou', 'I-kou,I-kou-chen,Yigou,Yigouzhen,yi gou,yi gou zhen,一沟,一沟镇', 32.8017900, 119.5247400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13781, 'Qingzhou', 'Qingzhou', 'Ch''ing-chou,Ch’ing-chou,Cinchzhou,I-tu,I-tu-hsien,Qingzhou,Tsingchow,Tsingchowfu,Yidu,Yitu,Цинчжоу', 36.6966700, 118.4797200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13782, 'Yidu', 'Yidu', 'Yidu,Yidu Zhen,yi dou,yi dou zhen,一都,一都镇', 25.7778400, 119.1872300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13783, 'Yidu', 'Yidu', 'Yidu,Yidu Zhen,Zhongban,yi dou,yi dou zhen,一都,一都镇', 25.4589400, 117.8087300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13784, 'Yidian', 'Yidian', 'I-tien,I-tien-chen,P''en-tien-chen,P’en-tien-chen,Yidian,Yidian Zhen,yi dian,yi dian zhen,益店,益店镇', 34.4037600, 107.7530900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13785, 'Yidao', 'Yidao', 'I-tao,Yidao,Yidao Zhen,yi dao,yi dao zhen,驿道,驿道镇', 37.2313600, 120.1613300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13786, 'Yichun', 'Yichun', 'Gi-chhun-chhi,Gî-chhun-chhī,I-cchun,I-ch''un,I-ch''un-chen,I-ch''un-hsien,I-ch’un,I-ch’un-chen,I-ch’un-hsien,I-čchun,Ichun'',Nghi Xuan,Nghi Xuân,Ngi-chung,Ngì-chŭng,Ni-chhun-su,Nî-chhûn-sṳ,YIC,Yichun,Yichun Shi,Yichun i Jiangxi,Yuan-chou,Yuanchow,Yuen-chow-fu,Yüan-chou,Yüanchow,ichun si,ychan,yi chun,yi chun shi,yyshwn  jyangshy,Ичунь,یچان,ییشون، جیانگشی,宜春,宜春市,이춘 시', 27.8333300, 114.4000000, 'CN', '2013-02-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13787, 'Yichuan Chengguanzhen', 'Yichuan Chengguanzhen', 'Fu-tien,I-ch''uan,I-ch''uan-hsien,I-ch’uan,I-ch’uan-hsien,Nan''fudyan,Nan-fu-tien,Nan’fudyan,Yichuan,Yichuan Chengguanzhen,yi chuan cheng guan zhen,伊川城关镇', 34.4197200, 112.4191700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13788, 'Yichongqiao', 'Yichongqiao', 'Yichongqiao,Yichongqiao Xiang,yi chong qiao,yi chong qiao xiang,宜冲桥,宜冲桥乡', 29.3313600, 110.8611300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13789, 'Tangxing', 'Tangxing', 'I-ch''eng,I-ch''eng-hsien,I-ch’eng,I-ch’eng-hsien,Tangxing,Tangxing Zhen,Yicheng,Yicheng Xian,Yichenghsien,tang xing,tang xing zhen,yi cheng xian,唐兴,唐兴镇,翼城县', 35.7452100, 111.6987200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13790, 'Yicheng', 'Yicheng', 'Hsuan-ch''eng,Hsüan-ch’eng,I-ch''eng,I-ch''eng-hsien,I-ch’eng,I-ch’eng-hsien,Tzu-chung,Tzu-chung-hsien,Yicheng,Yicheng Jiedao,yan cheng,yan cheng jie dao,鄢城,鄢城街道', 31.7047200, 112.2561100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13791, 'Yicheng', 'Yicheng', 'I-ch''eng-chen,I-ch’eng-chen,I-hsing,I-hsing-ch''eng,I-hsing-ch’eng,I-hsing-hsien,Ihing,Yicheng,Yicheng Jiedao,Yixing,Yixing Shi,yi cheng,yi cheng jie dao,yi xing shi,宜兴市,宜城,宜城街道', 31.3605900, 119.8201600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13792, 'Yichang', 'Yichang', 'Che-Keou-chan,Che-Kéou-chan,Gi-chhiong-chhi,Gî-chhiong-chhī,I-cchang,I-ch''ang-hsien,I-ch''ang-shih,I-chang,I-ch’ang-hsien,I-ch’ang-shih,I-čchang,Ican,Ichan,Ichang,Ičan,Jicang,Jichang,Jiĉang,Nghi Xuong,Nghi Xương,Ngi-chiong,Ngì-chiŏng,Tung-hu,YIH,Yichang,aychang,ichang si,ychng,yi chang,yi chang shi,Ічан,Јичанг,Ичан,ایچانگ,يىچاڭ شەھىرى,یچنگ,宜昌,宜昌市,이창 시', 30.7144400, 111.2847200, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13793, 'Yibin', 'Yibin', 'Gi-pin-chhi,Gî-pin-chhī,Hsu-chou,Hsü-chou,I-pin,I-pin-hsien,I-pin-shih,Ibin,Ibin'',Jibin,Nghi Tan,Nghi Tân,Ngi-bing,Ngì-bĭng,Suchow,Suifu,Süchow,Xufu,Xuzhou Cheng,YBP,Yibin,Yibin Shi,ayblyn,ibin si,xu fu,xu zhou cheng,ybyn,yi bin,yi bin shi,Јибин,Ибин,Ибинь,ایبلین,یبین,叙州城,叙府,宜宾,宜宾市,宜賓,宜賓市,이빈 시', 28.7666700, 104.6238300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13794, 'Yezhou', 'Yezhou', 'Chien-shih,Chien-shih-hsien,Jianshi,Jianshi Xian,Kien-shih,Kienshih-hsien,Yezhou,jian shi,jian shi xian,ye zhou,业州,建始,建始县', 30.6036900, 109.7233300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13795, 'Yexie', 'Yexie', 'Yeh-hsieh,Yeh-hsieh-chen,Yexie,Yexie Zhen,ye xie,ye xie zhen,叶榭,叶榭镇', 30.9454300, 121.3164300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13796, 'Kunyang', 'Kunyang', 'Kunyang,Kunyang Zhen,Shesyan,Yeh,Yeh-hsien,Yexian,kun yang,昆阳', 33.6200000, 113.3450000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13797, 'Yetan', 'Yetan', 'Yetan,Yetan Zhen,ye tan,ye tan zhen,叶潭,叶潭镇', 23.9078200, 115.1791800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13798, 'Yesanguan', 'Yesanguan', 'Ch''uan-nung-t''ing,Ch’üan-nung-t’ing,Yeh-san-kuan,Yesanguan,Yesanguan Zhen,Yeshankwan,ye san guan,ye san guan zhen,野三关,野三关镇', 30.6185600, 110.3231600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13799, 'Yeping', 'Yeping', 'Yeh-p''ing,Yeh-p’ing,Yeping,Yeping Xiang,ye ping,ye ping xiang,叶坪,叶坪乡', 25.9056700, 116.0697000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13800, 'Yeliguan', 'Yeliguan', 'Yeh-li-kuan,Yeliguan,ye li guan,冶力关', 34.9644000, 103.6604900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13801, 'Yelang', 'Yelang', 'Yeh-lang-pa,Yelang,Yelang Zhen,Yelangba,ye lang,ye lang zhen,夜郎,夜郎镇', 28.4022200, 106.7794400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13802, 'Yazhou', 'Yazhou', 'Ya-chou,Yazhou,Yazhou Zhen,Yeh-chou-chuang,ya zhou,ya zhou zhen,雅周,雅周镇', 32.3973100, 120.3277000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13803, 'Yaxi', 'Yaxi', 'Ya-ch''i,Ya-ch''i-chiang,Ya-ch’i,Ya-ch’i-chiang,Ya-hsi,Ya-hsi-kang,Yaxi,Yaxi Zhen,Yaxigang,ya xi,ya xi zhen,桠溪,桠溪镇', 31.3698200, 119.1600500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13804, 'Yatunpu', 'Yatunpu', 'Ya-t''un-pao,Ya-t’un-pao,Yatunbu,Yatunpu,Yatunpu Xiang', 26.1550000, 109.6266700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13805, 'Yatou', 'Yatou', 'Jung-ch''eng,Jung-ch''eng-hsien,Jung-ch’eng,Jung-ch’eng-hsien,Rongcheng,Rongcheng Shi,Yai-t''ou,Yai-t''ou-chi,Yai-t’ou,Yai-t’ou-chi,Yatou,Yatou Jiedao,Zhunchehn,rong cheng,rong cheng shi,ya tou,ya tou jie dao,Жунчэн,崖头,崖头街道,荣成,荣成市', 37.1566000, 122.4376200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13806, 'Yatang', 'Yatang', 'Yatang,Yatang Zhen,ya tang,ya tang zhen,雅塘,雅塘镇', 21.6128700, 110.0414700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13807, 'Yashan', 'Yashan', 'Liao-shan-chen,Shan-chieh,Ya-shan-chen,Ya-shan-chieh,Yashan,Yashan Zhen,ya shan,ya shan zhen,丫山,丫山镇', 30.8166700, 118.0166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13808, 'Yashan', 'Yashan', '', 22.1975000, 109.9419400, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13809, 'Yartang', 'Yartang', 'Remuka,Yaritang,Yaritang Xiang,Yartang,re mu ka,ya ri tang,ya ri tang xiang,亚日堂,亚日堂乡,热木卡', 32.7628400, 100.7834700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13810, 'Yaqueling', 'Yaqueling', 'Ya-ch''iao-ling,Ya-ch''ueh-ling,Ya-ch’iao-ling,Ya-ch’üeh-ling,Yaqueling,Yaqueling Zhen,ya que ling,ya que ling zhen,鸦鹊岭,鸦鹊岭镇', 30.6454300, 111.5861500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13811, 'Yaqiao', 'Yaqiao', 'Yaqiao,Yaqiao Xiang,ya qiao,ya qiao xiang,雅桥,雅桥乡', 28.4168400, 109.4197400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13812, 'Yaqian', 'Yaqian', 'Ya-ch''ien,Ya-ch’ien,Yaqian,Yaqian Xiang,ya qian,ya qian xiang,衙前,衙前乡', 28.2898300, 116.4528800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13813, 'Yaoxu', 'Yaoxu', 'Yao-hsi-chieh,Yao-hsu,Yao-hsü,Yaoxu,Yaoxu Zhen,yao wei,yao wei zhen,姚圩,姚圩镇', 27.8542900, 115.2081200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13814, 'Yaozhou', 'Yaozhou', 'Yao,Yao-hsien,Yao-hsien-ch''eng,Yao-hsien-ch’eng,Yaochow,Yaochzhou,Yaosyan,Yaoxian,Yaozhou,Yaozhou Qu,yao zhou,yao zhou qu,耀州,耀州区', 34.9052800, 108.9700000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13815, 'Yaotang', 'Yaotang', 'Yao-t''ang,Yao-t''ang-chen,Yao-t’ang,Yao-t’ang-chen,Yaotang,Yaotang Zhen,yao tang,yao tang zhen,尧塘,尧塘镇', 31.7178500, 119.6758700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13816, 'Yaoshi', 'Yaoshi', 'Yao-shih,Yao-ssu,Yaoshi,Yaoshi Zhen,yao shi,腰市', 34.0579600, 109.9365900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13817, 'Yaoshi', 'Yaoshi', 'Yao-shang,Yao-shih,Yaoshi', 27.6394400, 109.5302800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13818, 'Yaoshi', 'Yaoshi', '', 26.2930600, 110.7891700, 'CN', '2004-05-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13819, 'Yaopi', 'Yaopi', 'Yaopi,Yaopi Zhen,yao bei,yao bei zhen,腰陂,腰陂镇', 26.8949600, 113.6486400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13820, 'Yaoli', 'Yaoli', 'Yaoli,Yaoli Zhen,yao li,yao li zhen,瑶里,瑶里镇', 29.5462100, 117.5750200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13821, 'Yaokou', 'Yaokou', 'Yao-kou-chi,Yaokou,Yaokou Xiang,Yaokouji,yao kou,yao kou xiang,窑口,窑口乡', 32.4500000, 116.7800000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13822, 'Yaowang', 'Yaowang', 'Yao-chia-chuang,Yao-chuang,Yaojiazhuang,Yaowang,Yaowang Zhen,yao jia zhuang,yao wang,yao wang zhen,姚家庄,姚王,姚王镇', 32.2166700, 120.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13823, 'Yaoqiao', 'Yaoqiao', 'Yao-chia-ch''iao,Yao-chia-ch’iao,Yaojiaqiao,Yaokiakiao,Yaoqiao,Yaoqiao Zhen,yao qiao,yao qiao zhen,姚桥,姚桥镇', 32.1635200, 119.7722300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13824, 'Yaojiaji', 'Yaojiaji', 'Yao-chia-chi,Yaojiaji,Yaojiaji Zhen,yao jia ji,yao jia ji zhen,姚家集,姚家集镇', 31.2131100, 114.3662900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13825, 'Yaojiagou', 'Yaojiagou', 'Yao-chia-kou,Yaojiagou,Yaojiagou Zhen,yao jia gou,yao jia gou zhen,姚家沟,姚家沟镇', 34.5664100, 107.5214700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13826, 'Yaohua', 'Yaohua', 'Qixia Qu,Yaohua,Yaohua Jiedao,Yaohuamen,qi xia qu,yao hua,yao hua jie dao,尧化,尧化街道,栖霞区', 32.1215200, 118.8717000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13827, 'Yaoguan', 'Yaoguan', 'Yao-kuan-hsiang,Yaoguan,Yaoguan Zhen,yao guan,yao guan zhen,遥观,遥观镇', 31.6984400, 120.0315900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13828, 'Yaogu', 'Yaogu', 'Yao-ku,Yao-ku-hsu,Yao-ku-hsü,Yaogu,Yaogu Zhen,Yiuku,yao gu,yao gu zhen,腰古,腰古镇', 22.8925800, 112.2819100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13829, 'Yaodu', 'Yaodu', 'Chih-te,Dongzhi,Tung-chih,Yao-tu,Yao-tu-chen,Yao-tu-chieh,Yao-tu-hsu,Yao-tu-hsü,Yao-tu-wei,Yaodu,yao du,尧渡', 30.1000000, 117.0166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13830, 'Yaodian', 'Yaodian', 'Yao-tien,Yao-tien-chen,Yaodian,Yaodian Zhen,yao dian,yao dian zhen,窑店,窑店镇', 34.4075000, 108.8519400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13831, 'Yaojiadian', 'Yaojiadian', 'Yao-chia-tien,Yaojiadian,Yaojiadian Xiang,yao jia dian,yao jia dian xiang,姚家店,姚家店乡', 30.3668100, 111.4376300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13832, 'Yaocun', 'Yaocun', 'Yao-ts''un,Yao-ts’un,Yaocun,yao cun,姚村', 30.8918100, 119.1005800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13833, 'Yanziji', 'Yanziji', 'Yanziji,Yanziji Jiedao,Yen-tzu-chi,yan zi ji,yan zi ji jie dao,燕子矶,燕子矶街道', 32.1440100, 118.8193900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13834, 'Yanzibian', 'Yanzibian', 'Yanzibian,Yanzibian Zhen,Yen-tzu-pien,yan zi bian,yan zi bian zhen,燕子砭,燕子砭镇', 32.9011900, 105.9254000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13835, 'Yanzi', 'Yanzi', 'Yanzi,Yanzi Xiang,yan zi,yan zi xiang,燕子,燕子乡', 29.9680600, 110.2202800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13836, 'Yanzhou', 'Yanzhou', 'Ch''ie-fou,Ch’ie-fou,Tzeyang,Tzu-yang,Tzu-yang-ch''eng,Tzu-yang-ch’eng,Tzu-yang-hsien,Yanzhou,Yen-chou,Yenchow,Yenchow-fu,Yenzhou', 35.5527800, 116.8286100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13837, 'Yanzhao', 'Yanzhao', 'Yanzhao,Yanzhao Zhen,Yen-chao,Yen-chao-chen,yan zhao,yan zhao zhen,燕赵,燕赵镇', 38.5503600, 114.8064600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13838, 'Yanyang', 'Yanyang', 'Yanyang,Yanyang Zhen,yan yang,yan yang zhen,雁洋,雁洋镇', 24.4163000, 116.3216600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13839, 'Yanxia', 'Yanxia', 'Yanxia,Yanxia Xiang,Yen-hsia,yan sha,yan sha xiang,燕厦,燕厦乡', 29.5697500, 114.8627900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13840, 'Yanxi', 'Yanxi', 'Yanxi,Yanxi Zhen,Yen-hsi,yan xi,yan xi zhen,砚溪,砚溪镇', 27.6425500, 115.0390500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13841, 'Yanwu', 'Yanwu', 'Yanwu,Yanwu Xiang,yan wu,yan wu xiang,演武,演武乡', 36.1577000, 107.0736800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13842, 'Yanweigang', 'Yanweigang', 'Yanweigang,Yanweigang Zhen,Yen-wei-chiang,Yen-wei-kang,Yenhweikiang,yan wei gang,yan wei gang zhen,燕尾港,燕尾港镇', 34.4666700, 119.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13843, 'Yanwan', 'Yanwan', 'Yanwan,Yawan,Yen-wan,yan wan,岩湾', 34.0337000, 106.9783000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13844, 'Yantou', 'Yantou', 'Yantou,Yantou Xiang,Yen-t''ou,Yen-t’ou,yan tou,yan tou xiang,岩头,岩头乡', 39.0605900, 113.3290200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13845, 'Yantou', 'Yantou', 'Yantou,Yantou Zhen,Yen-t''ou,Yen-t’ou,yan tou,yan tou zhen,岩头,岩头镇', 28.3415800, 120.7293700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13846, 'Yantian', 'Yantian', 'Yantian,Yantian Zhen,Yen-t''ien,Yen-t’ien,yan tian,yan tian zhen,严田,严田镇', 27.3659400, 114.3742900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13847, 'Yantian', 'Yantian', 'Yantian,Yen-t''ien,Yen-t’ien', 26.8533300, 119.8575000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13848, 'Yantian', 'Yantian', 'Imtin,Yantian,Yantian Jiedao,Yen-t''ien,Yen-t''ien-tung,Yen-t’ien,Yen-t’ien-tung,Yim Tin,yan tian,yan tian jie dao,盐田,盐田街道', 22.5600400, 114.2347700, 'CN', '2014-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13849, 'Yantang', 'Yantang', 'Yantang,Yantang Zhen,Yen-t''ang,Yen-t’ang,Zhangshi,yan tang,yan tang zhen,zhang shi,严塘,严塘镇,樟市', 26.7883300, 113.6958300, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13850, 'Yantan', 'Yantan', 'Yantan,Yen-t''an,Yen-t’an,yan tan,沿滩', 29.2739600, 104.8738000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13851, 'Yantan', 'Yantan', 'Yantan,Yantan Zhen,Yen-t''an,Yen-t’an,yan tan,yan tan zhen,岩坦,岩坦镇', 28.4479200, 120.7249800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13852, 'Yantai', 'Yantai', 'Cheefoo,Chefoo,Chifu,Ian-tai-chhi,Ian-tâi-chhī,Ieng-dai,Iĕng-dài,Jan''taj,Jantai,Jantaj,Jen-tchaj,YNT,Yantai,Yantái,Yen GJai,Yen-t''ai,Yen-t''ai-shih,Yen-t’ai,Yen-t’ai-shih,Yên Đài,yan tai,yan tai shi,yantay,yantayy,yentai si,yeondae,yeontae,Јантај,Янтай,Яньтай,يەنتەي شەھىرى,یانتائی,یانتای,烟台市,煙台市,煙臺,연대,연태,옌타이 시', 37.4764900, 121.4408100, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13853, 'Yansi', 'Yansi', 'An-ssu,Huizhou,Huizhou Qu,Yansi,Yansi Zhen,Yen-ssu,Yen-ssu-chieh,Yensze,hui zhou qu,yan si,yan si zhen,岩寺,岩寺镇,徽州区', 29.8236500, 118.3379200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13854, 'Yanshan', 'Yanshan', 'Yanshan,Yanshan Zhen,yan shan,yan shan zhen,砚山,砚山镇', 28.8022700, 107.8951400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13855, 'Yanqian', 'Yanqian', 'Yanqian,Yanqian Zhen,Yen-ch''ien,Yen-ch’ien,yan qian,yan qian zhen,岩前,岩前镇', 26.2625900, 117.4516300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13856, 'Yanqian', 'Yanqian', 'Yanqian,Yanqian Zhen,Yen-ch''ien,Yen-ch''ien-ch''eng,Yen-ch’ien,Yen-ch’ien-ch’eng,yan qian,yan qian zhen,岩前,岩前镇', 24.8694500, 116.2227900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13857, 'Yanmenguan', 'Yanmenguan', 'Yanmenguan,Yanmenguan Xiang,Yen-men Kuan,yan men guan,yan men guan xiang,雁门关,雁门关乡', 39.1901800, 112.8594600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13858, 'Yanmen', 'Yanmen', 'Yanmen,Yen-men', 27.8550000, 109.7402800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13859, 'Anling', 'Anling', 'Anling,Yanling,Yen-ling,Yen-ling-hsien,an ling,安陵', 34.1089000, 114.1698300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13860, 'Yanling', 'Yanling', 'Yanling,Yanling Zhen,Yen-ling,Yen-ling-chen,yan ling,yan ling zhen,延陵,延陵镇', 31.8807100, 119.4767800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13861, 'Yanling', 'Yanling', 'Wei-yuan-hsien,Wei-yüan-hsien,Weiyuan,Yanling,yan ling,严陵', 29.5306500, 104.6610800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13862, 'Yanliang', 'Yanliang', 'Yanliang,Yen-liang,Yen-liang-chen,yan liang,阎良', 34.6591800, 109.2292100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13863, 'Yankou', 'Yankou', 'Wusheng,Yankou,Yen-k''ou,Yen-k''ou-ch''ang,Yen-k''ou-chen,Yen-k’ou,Yen-k’ou-chen,Yen-k’ou-ch’ang,yan kou,沿口', 30.3511500, 106.2866900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13864, 'Yankou', 'Yankou', 'Yankou,Yankouxiang,yan kou,yan kou xiang,岩口,岩口乡', 27.3483300, 111.0880600, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13865, 'Yanjing', 'Yanjing', 'Yanjing,Yanjing Zhen,Yen-ching,yan jing,yan jing zhen,盐井,盐井镇', 29.9449400, 106.3502500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13866, 'Yanjing', 'Yanjing', 'Yanjing,Yanjing Zhen,yan jing,yan jing zhen,盐井,盐井镇', 29.8427700, 111.7594400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13867, 'Yanjing', 'Yanjing', 'Pai-yen-ching,Yanjing,Yanyuan,Yen-ching,Yen-ching-hsiang,Yen-yuan,Yen-yüan,yan jing,盐井', 27.4269900, 101.5096800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13868, 'Yanjin Chengguanzhen', 'Yanjin Chengguanzhen', 'Yanjin,Yanjin Chengguanzhen,Yen-chin,Yen-ching,Yen-ching-hsien,yan jin cheng guan zhen,延津城关镇', 35.1408300, 114.1877800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13869, 'Yanjing', 'Yanjing', 'Lao-ya-kuan,Lao-ya-t''an,Lao-ya-t’an,Yanjin,Yanjin Xian,Yanjing,Yen-chin,Yen-ching,Yen-ching-hsien,Yentsing,Yentsing-hsien,yan jin xian,yan jing,盐井,盐津县', 28.0822800, 104.1949700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13870, 'Yanjiatai', 'Yanjiatai', 'Yanjiatai,Yanjiatai Zhen,yan jia tai,yan jia tai zhen,燕家台,燕家台镇', 40.0011600, 115.5624900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13871, 'Yanjiao', 'Yanjiao', 'Qiyunshan,Qiyunshan Zhen,Yanjiao,qi yun shan,qi yun shan zhen,yan jiao,岩脚,齐云山,齐云山镇', 29.8200000, 118.0411100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13872, 'Heyou', 'Heyou', 'Heyou,Heyou Zhen,Yanjia,Yanjiachang,he you,he you zhen,yan jia chang,严家场,鹤游,鹤游镇', 30.0825600, 107.3517400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13873, 'Yanji', 'Yanji', 'Yangki,Yanji,Yanji Zhen,yan ji,yan ji zhen,燕矶,燕矶镇', 30.3998700, 115.0088600, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13874, 'Yanjiahe', 'Yanjiahe', 'Yanhe,Yanjiahe,Yanjiahe Zhen,Yen-ho,yan jia he,yan jia he zhen,阎家河,阎家河镇', 31.2097700, 115.1163600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13875, 'Yangzongnan Hengjie', 'Yangzongnan Hengjie', 'Yang-t''sung-ch''eng,Yang-t’sung-ch’eng,Yangzong,Yangzong Zhen,Yangzongnan Hengjie,yang zong,yang zong nan heng jie,yang zong zhen,阳宗,阳宗南横街,阳宗镇', 24.8222200, 102.9694500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13876, 'Yangzi', 'Yangzi', 'Yang-tzu-ch''iao,Yang-tzu-ch’iao,Yangzi,Yangzi Zhen,Yangziqiao,yang zi,yang zi zhen,杨梓,杨梓镇', 29.6413000, 116.6041200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13877, 'Yangshi', 'Yangshi', 'Yangshi,Yangshi Zhen,Yangziqian,yang shi,yang shi zhen,yang zi qian,羊子嵌,羊市,羊市镇', 30.8143100, 109.0456800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13878, 'Yangzi', 'Yangzi', 'Yang-tzu,Yang-tzu-chen,Yangzi,Yangzi Zhen,yang zi,yang zi zhen,洋梓,洋梓镇', 31.2920900, 112.6324300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13879, 'Yangzhou', 'Yangzhou', 'Chiang-tu,Chiang-tu-hsien,Duong Chau,Dương Châu,Han-chiang,Iong-chiu-chhi,Iong-ciu,Iòng-ciŭ,Iông-chiu-chhī,Janchzhou,Jancjou,Jandzhou,Jang-cou,Jang-čou,Jangdzou,Janĉĵou,Kiangtu,YTY,Yang-chou,Yang-chou-shih,Yang-chow-fu,Yangchow,Yangjo shehiri,Yangtsjou,Yangzhou,yang zhou,yang zhou shi,yanghtshw,yangjeou si,yangzhw,Јангџоу,Янджоу,Янчжоу,יאנגצו,يانغتشو,یانگژو,ཡྰང་ཀྲོའུ།,扬州市,揚州,揚州市,양저우 시', 32.3972200, 119.4358300, 'CN', '2013-04-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13880, 'Yangzhou', 'Yangzhou', 'Yangzhou,Yangzhou Xiang,yang zhou,yang zhou xiang,杨洲,杨洲乡', 29.1627900, 115.3802800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13881, 'Yangzhong', 'Yangzhong', 'Yang-chung,Yangzhong', 26.7055600, 119.3744400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13882, 'Hutou', 'Hutou', 'Hutou,Hutou Zhen,hu tou,hu tou zhen,湖头,湖头镇', 25.2297900, 118.0484800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13883, 'Yangyuan', 'Yangyuan', 'Yangyuan,Yangyuan Xiang,yang yuan,yang yuan xiang,杨源,杨源乡', 27.1511100, 119.0158300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13884, 'Yangyu', 'Yangyu', 'Yang-yu-ts''un,Yang-yü-ts’un,Yangyu,Yangyu Xiang,yang yu,yang yu xiang,阳隅,阳隅乡', 35.4201200, 111.0909700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13885, 'Yangyu', 'Yangyu', 'Yang-yu-chen,Yang-yü-chen,Yangyu,Yangyu Zhen,yang yu,yang yu zhen,阳峪,阳峪镇', 34.6412100, 108.2094200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13886, 'Yangxu', 'Yangxu', 'Yangxu,Yangxu Zhen,yang wei,yang wei zhen,杨圩,杨圩镇', 28.3692200, 115.1584900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13887, 'Yangxin', 'Yangxin', 'Yang-hsin,Yang-hsin-hsien,Yang-hsin-hsien-ch''eng,Yang-hsin-hsien-ch’eng,Yangsin,Yangsinhsien,Yangxin,Yangxin Zhen,yang xin,yang xin zhen,阳信,阳信镇', 37.6447200, 117.5766700, 'CN', '2016-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13888, 'Yangxiang', 'Yangxiang', 'Yang-hsiang,Yang-hsiang-chen,Yangxiang,Yangxiang Zhen,yang xiang,yang xiang zhen,杨巷,杨巷镇', 31.4779900, 119.5875600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13889, 'Yangxi', 'Yangxi', 'Yang-ch''i,Yang-ch''i-chen,Yang-ch’i,Yang-ch’i-chen,Yang-hsi,Yangxi,Yangxi Zhen,yang xi,yang xi zhen,杨溪,杨溪镇', 30.1566700, 118.6421000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13890, 'Yangxi', 'Yangxi', 'Yang-hsi,Yangxi,Yangxi Xiang,yang xi,yang xi xiang,杨溪,杨溪乡', 28.2297700, 116.7319200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13891, 'Yangxi', 'Yangxi', 'Yang-hsi,Yangxi,Yangxi Zhen,yang xi,yang xi zhen,洋溪,洋溪镇', 27.2979900, 114.2132500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13892, 'Yangxi', 'Yangxi', 'Yang-hsi,Yangxi,Yangxi Xiang,yang xi,yang xi xiang,洋溪,洋溪乡', 26.3114100, 117.7267300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13893, 'Yuanyang Chengguanzhen', 'Yuanyang Chengguanzhen', 'Po-lang,Yang-wu-hsien,Yangwu,Yuanyang,Yuanyang Chengguanzhen,yuan yang cheng guan zhen,原阳城关镇', 35.0522200, 113.9638900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13894, 'Yangwei', 'Yangwei', 'Yang-wei-shih,Yangwei,Yangwei Zhen,yang wei,yang wei zhen,羊尾,羊尾镇', 32.8144000, 110.1949100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13895, 'Yangwang', 'Yangwang', 'Yang-wang-chen,Yangwang,Yangwang Zhen,yang wang,yang wang zhen,阳王,阳王镇', 35.5071600, 111.1152100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13896, 'Yangtou', 'Yangtou', 'Yang-t''ou-ssu,Yang-t’ou-ssu,Yangtou', 27.6894400, 109.4138900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13897, 'Yangting', 'Yangting', 'Yangting,Yangting Zhen,yang ting,yang ting zhen,羊亭,羊亭镇', 37.4241300, 122.0342700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13898, 'Yangtan', 'Yangtan', 'Kou-hsi-ts''un,Kou-hsi-ts’un,Yangtan,Yangtan Xiang,yang tan,yang tan xiang,杨谈,杨谈乡', 35.7751600, 111.5384700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13899, 'Yangtan', 'Yangtan', 'Yangtan,yang tan,杨滩', 30.7058300, 119.1680600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13900, 'Yangshuo', 'Yangshuo', 'Jansho,Yang-shuo-chen,Yang-shuo-hsien,Yangso,Yangso-hsien,yang shuo,Яншо,阳朔', 24.7808100, 110.4896700, 'CN', '2010-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13901, 'Zhangjiagang', 'Zhangjiagang', 'Sha-chou,Shazhou,Yang-she-chen,Yang-she-ying,Yangshe,Zhangjiagang Shi', 31.8650000, 120.5388900, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13902, 'Yangsha', 'Yangsha', 'Yangsha,yang sha,羊沙', 34.8315500, 103.6681600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13903, 'Yangri', 'Yangri', 'Yangri,Yangri Zhen,yang ri,yang ri zhen,阳日,阳日镇', 31.7398600, 110.8149300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13904, 'Yangquan', 'Yangquan', 'Duong Tuyen,Dương Tuyền,Iong-choan-chhi,Iong-ciong,Iòng-ciòng,Iông-choân-chhī,Jancjuan,Jancjuan'',Jang-cchuean,Jang-čchüan,Jangcuen,Yang-ch''uan,Yang-ch''uan-chan,Yang-ch''uan-shih,Yang-ch’üan,Yang-ch’üan-chan,Yang-ch’üan-shih,Yangquan,Yangquan Shi,yang quan,yang quan shi,yangchwan,yangchwian si,yangkwan,Јангћуен,Янцюань,یانگچوان,یانگکوان,阳泉,阳泉市,陽泉,陽泉市,양취안 시', 37.8575000, 113.5633300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13905, 'Yangqing', 'Yangqing', 'Yangqing,Yangqing Zhen,yang qing,yang qing zhen,洋青,洋青镇', 21.3541500, 110.1081900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13906, 'Yangqiao', 'Yangqiao', 'Yang-ch''iao,Yang-ch’iao,Yangqiao,Yangqiao Zhen,yang qiao,yang qiao zhen,杨桥,杨桥镇', 27.9574600, 114.5899700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13907, 'Yangpu', 'Yangpu', 'Yangpu,yang pu,杨浦', 31.2619300, 121.5190400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13908, 'Yangpingguan', 'Yangpingguan', 'Ku''yang-p''ing-kuan,Ku’yang-p’ing-kuan,Yang-p''ing-kuan,Yang-p’ing-kuan,Yangpingguan,Yangpingguan Zhen,Yangpingkwan,Yanpingan'',Yanpingan’,yang ping guan,yang ping guan zhen,阳平关,阳平关镇', 32.9623200, 106.0539800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13909, 'Yangping', 'Yangping', 'Yang-p''ing-chen,Yang-p’ing-chen,Yangping,Yangping Zhen,yang ping,yang ping zhen,阳平,阳平镇', 34.3379000, 107.4898600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13910, 'Yangping', 'Yangping', 'Yangping,Yangping Zhen,yang ping,yang ping zhen,洋坪,洋坪镇', 31.2242400, 111.5536000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13911, 'Yangmingbu', 'Yangmingbu', 'Yang-ming-pao,Yangmingbu,Yangmingbu Zhen,Yanminbao,yang ming bao,yang ming bao zhen,阳明堡,阳明堡镇', 39.0125000, 112.8722200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13912, 'Yangming', 'Yangming', 'Heping Xian,Ho-p''ing,Ho-p''ing-hsien,Ho-p’ing,Ho-p’ing-hsien,Yang-ming-chen,Yangming,Yangming Zhen,he ping xian,yang ming,yang ming zhen,和平县,阳明,阳明镇', 24.4532800, 114.9345700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13913, 'Yangmei', 'Yangmei', 'Yangmei,Yangmei Zhen,yang mei,yang mei zhen,杨梅,杨梅镇', 24.1000000, 112.5582400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13914, 'Yanglu', 'Yanglu', 'Yanglu,Yanglu Xiang,Yangluwa,yang lu,yang lu xiang,羊路,羊路乡', 36.6365500, 106.1416400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13915, 'Guanshang', 'Guanshang', 'Guanshang,Guanshang Zhen,Yang-hsien,Yang-lo,Yanglo,Yanglochen,Yangluo,Yangluo Jiedao,guan shang,guan shang zhen,关上,关上镇', 30.6570400, 114.5533300, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13916, 'Yangluozhou', 'Yangluozhou', 'Yangluo,Yangluozhou,Yangluozhou Zhen,yang luo zhou,yang luo zhou zhen,阳罗洲,阳罗洲镇', 29.0497200, 112.5761100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13917, 'Yanglu', 'Yanglu', 'Yanglu,Yanglu Xiang,yang lu,yang lu xiang,养鹿,养鹿乡', 31.0897000, 108.5523700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13918, 'Yangloudong', 'Yangloudong', 'Yang-lou-tung,Yangloudong,Yangloudong Zhen,Yanglowtung,yang lou dong,yang lou dong zhen,羊楼洞,羊楼洞镇', 29.5414500, 113.7438600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13919, 'Yangliuqing', 'Yangliuqing', 'Yang-liu-ch''ing,Yang-liu-ch''ing-chen,Yang-liu-ch’ing,Yang-liu-ch’ing-chen,Yangliuqing,yang liu qing,杨柳青', 39.1375000, 116.9997200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13920, 'Yangliu', 'Yangliu', 'Yang-tiu-p''u,Yang-tiu-p’u,Yangliu,Yangliu Zhen,Yangliupu,yang liu,yang liu zhen,杨柳,杨柳镇', 30.8379500, 118.6117300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13921, 'Yangliuwan', 'Yangliuwan', 'Yangliu,Yangliuwan,Yangliuwan Zhen,yang liu wan,yang liu wan zhen,杨柳湾,杨柳湾镇', 30.8216100, 115.7714000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13922, 'Yanglinzhai', 'Yanglinzhai', 'Yang-lin-chai,Yanglinzhai,Yanglinzhai Xiang,yang lin zhai,yang lin zhai xiang,杨林寨,杨林寨乡', 28.7666700, 112.7166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13923, 'Yanglinwei', 'Yanglinwei', 'Yanglinwei,Yanglinwei Zhen,yang lin wei,yang lin wei zhen,杨林尾,杨林尾镇', 30.1349900, 113.5103400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13924, 'Yanglinshi', 'Yanglinshi', 'Yang-lin,Yang-lin-shih,Yanglinshi,Yanglinshi Zhen,yang lin shi,yang lin shi zhen,杨林市,杨林市镇', 29.9787500, 111.7755500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13925, 'Yangling', 'Yangling', 'Yang-ling-chen,Yangling,Yangling Qu,yang ling,yang ling qu,杨陵,杨陵区', 34.2717300, 108.0789100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13926, 'Yanglingou', 'Yanglingou', 'Yan lin kau,Yanglin,Yanglingou,Yanglingou Zhen,yang lin gou,yang lin gou zhen,杨林沟,杨林沟镇', 30.5341900, 113.6412200, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13927, 'Yangli', 'Yangli', 'Yangli,Yangli Xiang,yang li,yang li xiang,洋里,洋里乡', 26.3645800, 118.9555600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13928, 'Yanglang', 'Yanglang', 'Yang-lang-chen,Yanglang,Yanglang Xiang,Yanglangzhen,yang lang,yang lang xiang,杨郎,杨郎乡', 36.2256800, 106.1697000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13929, 'Yangkou', 'Yangkou', 'Yangkou,Yangkou Zhen,yang kou,yang kou zhen,洋口,洋口镇', 26.8006000, 117.8996000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13930, 'Yangjinzhuang', 'Yangjinzhuang', '', 39.8850000, 117.3980600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13931, 'Yangzhai', 'Yangzhai', 'Yang-chia-chai,Yang-chia-chia,Yangjiazhai,Yangkiachai,Yangzhai,Yangzhai Zhen,yang zhai,yang zhai zhen,杨寨,杨寨镇', 31.4931900, 114.0156900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13932, 'Yangjiapo', 'Yangjiapo', '', 39.2941700, 117.8875000, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13933, 'Yangjiao', 'Yangjiao', 'Yang-chiao-chen,Yangjiao,Yangjiao Zhen,yang jiao,yang jiao zhen,羊角,羊角镇', 29.3979000, 107.6064900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13934, 'Yangjiaotang', 'Yangjiaotang', 'Yangjiao,Yangjiaotang,Yangjiaotang Zhen,yang jiao tang,yang jiao tang zhen,羊角塘,羊角塘镇', 28.5349500, 111.6215600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13935, 'Yangjiang', 'Yangjiang', 'Yang-chiang,Yangjiang,Yangjiang Xiang,yang jiang,yang jiang xiang,洋江,洋江乡', 27.8565800, 114.5340500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13936, 'Yangmiao', 'Yangmiao', 'Yang-chia-miao,Yangjiamiao,Yangmiao,Yangmiao Zhen,yang miao,yang miao zhen,杨庙,杨庙镇', 32.4160300, 119.3298100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13937, 'Yangji', 'Yangji', 'Yang-chia-chi,Yangji,Yangji Zhen,Yangjiaji,yang ji,yang ji zhen,杨集,杨集镇', 31.2189500, 112.9949200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13938, 'Yangdian', 'Yangdian', 'Yangdian,yang dian,杨店', 33.9333200, 106.4265600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13939, 'Yangjiachang', 'Yangjiachang', 'Yang-chia-ch''ang,Yang-chia-ch’ang,Yangjiachang,Yangjiachang Zhen,yang jia chang,yang jia chang zhen,杨家厂,杨家厂镇', 30.0663200, 112.2847700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13940, 'Yanghu', 'Yanghu', 'Yanghu,Yanghu Zhen,yang hu,yang hu zhen,阳湖,阳湖镇', 29.7037800, 118.3039600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13941, 'Yanghou', 'Yanghou', '', 26.6408300, 118.5080600, 'CN', '2001-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13942, 'Yanghong', 'Yanghong', 'Yang-hung,Yang-hung-tien,Yanghong,Yanghong Zhen,yang hong,yang hong zhen,阳洪,阳洪镇', 34.5195800, 108.3151600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13943, 'Yanghe', 'Yanghe', 'Yang-ho,Yang-ho-pao,Yanghe,Yongning,Yongning Xian,Yung-ning,Yung-ning-hsien,yang he,yong ning xian,杨和,永宁县', 38.2785200, 106.2477600, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13944, 'Yanghe', 'Yanghe', 'Yang-chia-ho,Yanghe,Yanghe Zhen,yang he,yang he zhen,杨河,杨河镇', 31.0962500, 113.5808900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13945, 'Yangguo', 'Yangguo', 'Yang-kuo,Yang-kuo-chen,Yangguo,Yangguo Zhen,yang guo,阳郭', 34.3558800, 109.5196300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13946, 'Yangguang', 'Yangguang', 'Yangguang,Yangguang Zhen,Yanguang Zhen,yang guang,yang guang zhen,杨广,杨广镇', 24.1372200, 102.7938900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13947, 'Yanggu', 'Yanggu', 'Jang,Yang-ku,Yang-ku-hsien,Янг', 36.1105600, 115.7752800, 'CN', '2010-01-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13948, 'Yanggang', 'Yanggang', 'Yanggang,Yanggang Zhen,yang gang,yang gang zhen,洋港,洋港镇', 29.5781800, 115.1374100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13949, 'Yangfanglin', 'Yangfanglin', 'Yangfanglin,Yangfanglin Xiang,yang fang lin,yang fang lin xiang,杨芳林,杨芳林乡', 29.4841300, 114.3630200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13950, 'Yangfangkou', 'Yangfangkou', 'Yangfangkou,Yangfangkou Zhen,yang fang kou,yang fang kou zhen,阳方口,阳方口镇', 39.1007100, 112.3305900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13951, 'Yangezhuang', 'Yangezhuang', 'Yangezhuang,Yen-ko-chuang', 39.9963900, 117.6902800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13952, 'Yangdun', 'Yangdun', 'Yangdun,Yangdun Xiang,yang dun,yang dun xiang,洋墩,洋墩乡', 27.0252200, 117.8744000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13953, 'Yangdian', 'Yangdian', 'Yang-tien,Yang-tien-i,Yangdian,Yangdian Zhen,yang dian,yang dian zhen,杨店,杨店镇', 31.0267200, 114.1068500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13954, 'Yangdi', 'Yangdi', 'Yangdi,Yangdi Xiang,yang de,yang de xiang,洋地,洋地乡', 26.0486400, 116.3281500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13955, 'Yangdeng', 'Yangdeng', 'Yang-teng,Yangdeng,Yangdeng Zhen,yang deng,yang deng zhen,羊磴,羊磴镇', 28.7172200, 106.9597200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13956, 'Yangdang', 'Yangdang', 'Yang-chia-tang,Yang-tang,Yangdang,Yangdang Zhen,yang dang,yang dang zhen,杨垱,杨垱镇', 32.3122200, 112.6365300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13957, 'Yangcun', 'Yangcun', 'Wu-ch''ing,Wu-ch''ing-hsien,Wu-ch’ing,Wu-ch’ing-hsien,Wuqing,Yang-ts''un,Yang-ts’un,Yangcun', 39.3638900, 117.0602800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13958, 'Yangcun', 'Yangcun', 'Yang-ts''un,Yang-ts''un-chen,Yang-ts’un,Yang-ts’un-chen,Yangcun,Yangzun Zhen,yang cun,yang cun zhen,杨村,杨村镇', 32.7906200, 118.9777000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13959, 'Yangcun', 'Yangcun', 'Yang-ts''un,Yang-ts’un,Yangcun,Yangcun Zhen,yang cun,yang cun zhen,杨村,杨村镇', 24.6373400, 114.6279900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13960, 'Yangcun', 'Yangcun', 'Yang-t''sun,Yang-ts''un-hsu,Yang-ts’un-hsü,Yang-t’sun,Yangcun,Yangcun Zhen,yang cun,yang cun zhen,杨村,杨村镇', 23.4352300, 114.4762900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13961, 'Yangchu', 'Yangchu', 'Yang-cho,Yangchu,Yangchu Zhen,yang chu,yang chu zhen,杨础,杨础镇', 37.1907600, 120.7807400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13962, 'Yangcheng', 'Yangcheng', 'Fengcheng,Fengcheng Zhen,Yang-ch''eng-hsien,Yang-ch’eng-hsien,Yangcheng,Yangcheng Xian,feng cheng,feng cheng zhen,yang cheng xian,凤城,凤城镇,阳城县', 35.4922000, 112.4042800, 'CN', '2015-11-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13963, 'Yangcheng', 'Yangcheng', 'Yang-shan-hsien,Yangcheng,Yangcheng Zhen,Yangshan,Yeungshanhsien,yang cheng,yang cheng zhen,阳城,阳城镇', 24.4793000, 112.6421200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13964, 'Yangchao', 'Yangchao', 'Yangchao,Yangchao Xiang,yang chao,yang chao xiang,阳朝,阳朝乡', 28.6644300, 109.6985500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13965, 'Yangce', 'Yangce', 'Yang-cha,Yang-ts''e,Yang-ts’e,Yangce,Yangce Zhen,yang ce,羊册', 32.9928500, 113.2470600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13966, 'Yangba', 'Yangba', 'Yang-chia-pa,Yangba,Yangba Zhen,yang ba,yang ba zhen,杨坝,杨坝镇', 32.4746300, 106.7819100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13967, 'Yanduhe', 'Yanduhe', 'Yanduhe,Yanduhe Zhen,Yen-tu-ho,yan du he,yan du he zhen,沿渡河,沿渡河镇', 31.2260200, 110.2906300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13968, 'Yanchihe', 'Yanchihe', 'Yanchihe,Yanchihe Zhen,yan chi he,yan chi he zhen,盐池河,盐池河镇', 32.3290100, 111.0507200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13969, 'Huamachi', 'Huamachi', 'Chiu-yen-ch''ih,Chiu-yen-ch’ih,Hua-ma-ch''ih,Hua-ma-ch’ih,Huamachi,Yanchi,Yanchi Xian,Yen-ch''ih,Yen-ch’ih,hua ma chi,yan chi xian,盐池县,花马池', 37.7852000, 107.4032200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13970, 'Yancheng', 'Yancheng', 'Ch''i-ho,Ch’i-ho,Qihe,Yancheng,Yancheng Jiedao,Yen-ch''eng,Yen-ch''eng-chen,Yen-ch’eng,Yen-ch’eng-chen,yan cheng,yan cheng jie dao,晏城,晏城街道', 36.7994400, 116.7438900, 'CN', '2016-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13971, 'Yancheng Chengguanzhen', 'Yancheng Chengguanzhen', 'Yancheng,Yancheng Chengguanzhen,Yen-ch''eng,Yen-ch''eng-hsien,Yen-ch’eng,Yen-ch’eng-hsien,Yen-hsien,yan cheng cheng guan zhen,郾城城关镇', 33.5847200, 113.9866700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13972, 'Yancheng', 'Yancheng', 'Diem Thanh,Diêm Thành,Iâm-siâⁿ-chhī,Jan''chehn,Jancengo,Jancheng,Janĉengo,Jen-ccheng,Jen-čcheng,Jenchun,Sieng-siang,Sièng-siàng,YNZ,Yancheng,Yen-ch''eng,Yen-ch''eng-chen,Yen-ch''eng-hsien,Yen-ch’eng,Yen-ch’eng-chen,Yen-ch’eng-hsien,yan cheng,yan cheng shi,yanchng,yencheong si,ynchyng,Јанченг,Йенчън,Яньчэн,يەنچېن شەھىرى,یانچنگ,ینچینگ,塩城市,盐城,盐城市,鹽城,옌청 시', 33.3575000, 120.1573000, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13973, 'Yanbodu', 'Yanbodu', 'Yanbodu,Yanbodu Zhen,Yen-pai-tu,Yen-po-tu,yan po du,yan po du zhen,岩泊渡,岩泊渡镇', 29.3746700, 110.9681400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13974, 'Dongxia', 'Dongxia', 'Dongxia,Dongxia Zhen,Ya-men-chuang,Yamenzhuang,dong xia,dong xia zhen,东峡,东峡镇', 37.0382600, 101.7889900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13975, 'Yakou', 'Yakou', 'Yakou,Yakow,ya kou,衙口', 24.6719400, 118.6372200, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13976, 'Yajiang', 'Yajiang', 'Ya-chiang,Yajiang,Yajiang Zhen,ya jiang,ya jiang zhen,鸭江,鸭江镇', 29.4547700, 107.3736900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13977, 'Yafan', 'Yafan', 'Yafan,Yafan Zhen,ya fan,ya fan zhen,雅畈,雅畈镇', 29.0365700, 119.6753500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13978, 'Ya’erya', 'Ya''erya', 'Ya''erya,Ya''erya Xiang,Ya-chi-yai,Ya-erh-ya,Yan''erya,Yan’erya,Ya’erya,Ya’erya Xiang,Yen-erh-ya,Yen-ya,Yen-yai,ya r ya,ya r ya xiang,鸦儿崖,鸦儿崖乡', 39.9687600, 112.9930900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13979, 'Yacheng', 'Yacheng', 'Yacheng,Yacheng Zhen,ya cheng,ya cheng zhen,牙城,牙城镇', 26.9882900, 120.1883500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13980, 'Yacheng', 'Yacheng', 'Chiu-yai-hsien,Ngaaiuen,Ngai chiu,Ngai-hsien,Yacheng,Yacheng Zhen,Yai,Yai-ch''eng,Yai-ch''eng-chen,Yai-chou,Yai-ch’eng,Yai-ch’eng-chen,Yai-hsien,Yaichiu,Yaichu,ya cheng,ya cheng zhen,崖城,崖城镇', 18.3759500, 109.1647300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13981, 'Yacha', 'Yacha', 'Bach Sia,Baisha,Baisha Lizu Zizhixian,Pai-sha,Pai-sha-hsien,Pai-sha-shih,Paksha,Paktua,Ta-ch''i,Ta-ch’i,Ya-ch''i-chen,Ya-ch’i-chen,Yacha,Yacha Zhen,bai sha li zu zi zhi xian,ya cha,ya cha zhen,牙叉,牙叉镇,白沙黎族自治县', 19.2305600, 109.4475000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13982, 'Yabai', 'Yabai', 'Wa-pai,Ya-pai,Ya-pai-chen,Ya-pei-chen,Yabai,Yabai Zhen,ya bai,ya bai zhen,哑柏,哑柏镇', 34.1793900, 108.0866200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13983, 'Yucheng', 'Yucheng', 'Ya''an,Ya-an-hsien,Ya-an-shih,Ya-chou,Yachow,Ya’an,Yucheng,Yucheng Qu,ya an,yu cheng,yu cheng qu,雅安,雨城,雨城区', 29.9852100, 102.9990000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13984, 'Xuzhuang', 'Xuzhuang', 'Hsu-chuang,Hsü-chuang,Xuzhuang,Xuzhuang Zhen,xu zhuang,许庄', 34.8645500, 109.9404700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13985, 'Tongshan', 'Tongshan', 'Hsu-chou,Hsu-chou-shih,Hsü-chou,Hsü-chou-shih,Sjujchzhou,Suchow,Suchow-fu,Süchow-fu,T''ung-shan,Tongshan,T’ung-shan,Xuzhou,swijeou si,xu zhou,xu zhou shi,Сюйчжоу,شۈجو شەھىرى,徐州,徐州市,쉬저우 시', 34.1804500, 117.1570700, 'CN', '2016-03-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13986, 'Xuyong', 'Xuyong', 'Hsu-yung,Hsu-yung-hsien,Hsü-yung,Hsü-yung-hsien,Suyung,Suyung-hsien,Suyüng,Süyung-hsien,Xuyong,Yongning,Yung-ning,Yungninghsien,xu yong,叙永', 28.1699200, 105.4345200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13987, 'Xuyang', 'Xuyang', 'Xuyang,xu yang,徐杨', 34.6183000, 109.1435300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13988, 'Xuyang', 'Xuyang', 'Jung,Jung-hsien,Rongxian,Xuyang,Yung-hsien,xu yang,旭阳', 29.4594100, 104.4194700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13989, 'Xucheng', 'Xucheng', 'Hsu-wen,Hsu-wen-hsien,Hsü-wen,Hsü-wen-hsien,Suwen,Suwenyun,Tsuimen,Xucheng,Xucheng Jiedao,Xucheng Zhen,Xuwen,xu cheng,xu cheng jie dao,xu cheng zhen,徐城,徐城街道,徐城镇', 20.3291700, 110.1671200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13990, 'Xuwei', 'Xuwei', 'Hsu-wei,Hsü-wei,Xuwei,Xuwei Zhen,xu wei,xu wei zhen,徐圩,徐圩镇', 34.5259800, 119.5380300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13991, 'Xushuguan', 'Xushuguan', 'Hsu-kuan-chen,Hsu-shu-kuan,Hsü-kuan-chen,Hsü-shu-kuan,Hu-shu-kuan,Hushukwan,Xushuguan,Xushuguan Zhen,hu shu guan,hu shu guan zhen,浒墅关,浒墅关镇', 31.3802800, 120.4981700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13992, 'Xushi', 'Xushi', 'Hsu-shih,Hsü-shih,Xushi,Xushi Zhen,xu shi,xu shi zhen,徐市,徐市镇', 27.2278100, 118.0892000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13993, 'Xushe', 'Xushe', 'Hsu-she,Hsu-she-chen,Hsü-she,Hsü-she-chen,Sushechen,Süshechen,Xushe,Xushe Zhen,xu she,xu she zhen,徐舍,徐舍镇', 31.3960600, 119.6507300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13994, 'Shangrao', 'Shangrao', 'Kuanghsin,Kwangsin,SQD,Sang-zao,Shang-jao,Shang-jao-hsien,Shang-jao-shih,Shangrao,Shangrao Shi,Shangzhao,Shanzhao,Siong-jiau-chhi,Siong-ngieu,Siông-ngièu,Siōng-jiâu-chhī,Sjangrao,Song-ngieu-su,Song-ngièu-sṳ,Thuong Nhieu,Thượng Nhiêu,Xuri,sanglao si,shang rao,shang rao shi,shangraw,Šang-žao,Шангжао,Шанжао,شانگراو,上饒,上饒市,上饶,上饶市,상라오 시', 28.4517900, 117.9428700, 'CN', '2016-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13995, 'Xunzhai', 'Xunzhai', 'Sun-chai-shih,Xunzhai,Xunzhai Zhen,xun zhai,xun zhai zhen,巽宅,巽宅镇', 28.3478100, 120.4812600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13996, 'Xunyi Chengguanzhen', 'Xunyi Chengguanzhen', 'Hsun-i,Hsun-i-hsien,Hsun-i-hsien-ch''eng,Hsün-i,Hsün-i-hsien,Hsün-i-hsien-ch’eng,Kou-i,San''shuy,San-shui,Sanshuihsien,San’shuy,Singyi,Syun''i,Syun’i,Xunyi,Xunyi Chengguanzhen,Xunyi Xian,xun yi cheng guan zhen,xun yi xian,旬邑县,旬邑城关镇', 35.1173200, 108.3127500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13997, 'Xun Xian Chengguanzhen', 'Xun Xian Chengguanzhen', 'Chun,Chun-hsien,Chün,Chün-hsien,Hsun-hsien,Hsün-hsien,Syun''syan,Syun’syan,Xun Xian Chengguanzhen,Xunxian,jun xian cheng guan zhen,浚县城关镇', 35.6647300, 114.5345800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13998, 'Xunqiao', 'Xunqiao', 'Hsun-ch''iao,Hsun-ch''iao-shih,Hsün-ch’iao,Hsün-ch’iao-shih,Xunqiao,Xunqiao Zhen,xun qiao,xun qiao zhen,汛桥,汛桥镇', 28.7967700, 121.1722700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(13999, 'Xunjian', 'Xunjian', 'Hsun-chien-ssu,Hsunkiensze,Hsün-chien-ssu,Hsünkiensze,Sunkiensze,Xunjian,Xunjian Zhen,Xunjiansi,xun jian,xun jian zhen,巡检,巡检镇', 31.3859100, 111.6116500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14000, 'Xundian', 'Xundian', 'Hsun-tien,Hsün-tien,Xundian,Xundian Zhen,xun dian,xun dian zhen,巡店,巡店镇', 31.1618900, 113.6338000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14001, 'Xunchang', 'Xunchang', 'Xunchang,xun chang,巡场', 28.4543300, 104.7149800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14002, 'Xukou', 'Xukou', 'Hsu-k''ou,Hsu-k''ou-chen,Hsü-k’ou,Hsü-k’ou-chen,Xukou,Xukou Zhen,xu kou,xu kou zhen,胥口,胥口镇', 31.2342800, 120.4769700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14003, 'Xujing', 'Xujing', 'Hsu-ching-chen,Xujing,Xujing Zhen,xu jing,xu jing zhen,徐泾,徐泾镇', 31.1761200, 121.2712200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14004, 'Yuyue', 'Yuyue', 'Hsu-chia-chuang,Xujiazhuang,Xujiazhuang Zhen,Yuyue,Yuyue Zhen,xu jia zhuang zhen,yu yue,yu yue zhen,徐家庄镇,禹越,禹越镇', 30.5189500, 120.2613100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14005, 'Xujiaping', 'Xujiaping', 'Hsu-chia-p''ing,Hsü-chia-p’ing,Xujiaping,Xujiaping Zhen,xu jia ping,xu jia ping zhen,徐家坪,徐家坪镇', 33.4054500, 106.0576300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14006, 'Xujiang', 'Xujiang', 'Guangchang Xian,Kuang-ch''ang,Kuang-ch''ang-hsien,Kuang-ch’ang,Kuang-ch’ang-hsien,Kwangchang,Kwangchang-hsien,Xujiang,Xujiang Zhen,guang chang xian,xu jiang,xu jiang zhen,广昌县,旴江,旴江镇', 26.8394500, 116.3201100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14007, 'Xujiadu', 'Xujiadu', 'Hsu-chia-tu,Hsü-chia-tu,Xujiadu,Xujiadu Zhen,xu jia du,xu jia du zhen,徐家渡,徐家渡镇', 28.2466500, 114.7026300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14008, 'Xujiadian', 'Xujiadian', 'Hsu-chia-tien,Hsu-tien,Hsü-chia-tien,Hsü-tien,Liu-lien-p''u,Liu-lien-p’u,Xujiadian,Xujiadian Zhen,xu jia dian,xu jia dian zhen,徐家店,徐家店镇', 37.0806100, 120.9852600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14009, 'Xubu', 'Xubu', 'Hsu-chia-fou,Hsu-chia-pu,Hsü-chia-fou,Hsü-chia-pu,Xubu,Xubu Zhen,Xujiabu,xu bu,xu bu zhen,徐埠,徐埠镇', 29.4645700, 116.3152400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14010, 'Xujia', 'Xujia', 'Xujia,Xujia Xiang,xu jia,xu jia xiang,徐家,徐家乡', 27.6500500, 116.6904600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14011, 'Xuhui', 'Xuhui', 'Hsu-chia-hui,Hsu-chia-hui-chen,Hsu-chia-t''ang,Hsu-hui,Hsü-chia-hui,Hsü-chia-hui-chen,Hsü-chia-t’ang,Hsü-hui,Siccawei,Xuhui,xu hui,徐汇', 31.1959400, 121.4470900, 'CN', '2012-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14012, 'Xuhe', 'Xuhe', 'Hsu-chia-ho,Hsü-chia-ho,Xuhe,Xuhe Zhen,xu he,xu he zhen,许河,许河镇', 32.7274100, 120.6404700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14013, 'Xuhang', 'Xuhang', 'Hsu-chia-hang,Hsu-hang,Hsü-chia-hang,Hsü-hang,Xuhang,Xuhang Zhen,xu xing,xu xing zhen,徐行,徐行镇', 31.4129300, 121.2706500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14014, 'Xugu', 'Xugu', 'Hsu-ku,Hsü-ku,Xugu,Xugu Zhen,xu gu,xu gu zhen,徐古,徐古镇', 30.9512800, 114.9678000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14015, 'Xuezhen', 'Xuezhen', 'Hsieh-chia-chen,Hsueh-chen,Hsueh-chia-chen,Hsüeh-chen,Hsüeh-chia-chen,Xuezhen,xue zhen,薛镇', 34.9547500, 109.2965200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14016, 'Xuejin', 'Xuejin', 'Hsieh-chen,Hsueh-chen,Hsüeh-chen,Xuejin,Xuejin Zhen,xue jin,xue jin zhen,薛津,薛津镇', 31.5765000, 118.6425400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14017, 'Xueyan', 'Xueyan', 'Hsueh-yen,Hsueh-yen-ch''iao,Hsüeh-yen,Hsüeh-yen-ch’iao,Shueh-yen-chiao,Xueyan,Xueyan Zhen,Xueyanqiao,xue yan,xue yan zhen,雪堰,雪堰镇', 31.5100600, 120.0947100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14018, 'Xueping', 'Xueping', 'Hsueh-p''ing,Hsüeh-p’ing,Xueping,Xueping Zhen,xue ping,xue ping zhen,薛坪,薛坪镇', 31.6364900, 111.6671600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14019, 'Xuelu', 'Xuelu', 'Hsieh-lu-chen,Hsueh-lu,Hsueh-lu-chen,Hsüeh-lu,Hsüeh-lu-chen,Xuelu,Xuelu Zhen,xue lu,xue lu zhen,薛录,薛录镇', 34.4096100, 108.3405200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14020, 'Xuekulue', 'Xuekulue', 'Hsieh-chia-k''ou-luan,Hsieh-chia-k''uo-luan,Hsieh-chia-k’ou-lüan,Hsieh-chia-k’uo-lüan,Hsueh-hu-lun,Hsuëh-hu-lun,Xuekulue,Xuekulun,Xukulue Xiang,xue ku lue,xue ku lue xiang,薛圐圙,薛圐圙乡', 39.4079800, 112.7966900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14021, 'Xuejiawa', 'Xuejiawa', 'Hsieh-chia-wa,Hsueh-chia-wa,Hsüeh-chia-wa,Xuejiawa,Xuejiawa Xiang,xue jia wa,xue jia wa xiang,薛家洼,薛家洼乡', 39.0497500, 112.4424500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14022, 'Xuejia', 'Xuejia', 'Hsieh-chia-ch''iao,Hsieh-chia-ch''iao-chen,Hsieh-chia-ch’iao,Hsieh-chia-ch’iao-chen,Hsueh-chia-ch''iao,Hsüeh-chia-ch’iao,Xuejia,Xuejia Zhen,Xuejiaqiao,xue jia,xue jia zhen,薛家,薛家镇', 31.8609400, 119.9143700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14023, 'Funan Chengguanzhen', 'Funan Chengguanzhen', 'Fou-nan,Funan,Funan Chengguanzhen,Hsieh-chi,Hsieh-chi-chen,Xueji,fu nan cheng guan zhen,阜南城关镇', 32.6367800, 115.6149400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14024, 'Xuefeng', 'Xuefeng', 'Chiu-ming-ch''i,Chiu-ming-ch’i,Guihua,Hsueh-feng,Hsueh-feng-chen,Hsüeh-feng,Hsüeh-feng-chen,Kuei-hua,Kweihwa,Kweihwahsien,Ming-ch''i,Ming-ch''i-hsien,Ming-ch’i,Ming-ch’i-hsien,Ming-hsi,Mingxi,San-ming,Xuefeng,xue feng,雪峰', 26.3572200, 117.1977800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14025, 'Xuedian', 'Xuedian', 'Hsueh-tien,Hsüeh-tien,Xuedian,Xuedian Zhen,xue dian,xue dian zhen,薛店,薛店镇', 35.4699700, 111.1993300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14026, 'Xuedian', 'Xuedian', 'Hsieh-tien,Hsueh-tien,Hsüeh-tien,Xuedian,Xuedian Zhen,xue dian,薛店', 34.0119500, 113.0870500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14027, 'Xuebu', 'Xuebu', 'Hsieh-fou,Hsieh-fou-chen,Hsueh-pu,Hsüeh-pu,Xuebu,Xuebu Zhen,xue bu,xue bu zhen,薛埠,薛埠镇', 31.7186100, 119.3698800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14028, 'Xucun', 'Xucun', 'Hsu-ts''un,Hsu-ts''un-chen,Hsü-ts’un,Hsü-ts’un-chen,Xucun,Xucun Zhen,xu cun,xu cun zhen,许村,许村镇', 30.4352300, 120.3647300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14029, 'Xucun', 'Xucun', 'Hsu-ts''un,Hsü-ts’un,Xucun,Xucun Zhen,xu cun,xu cun zhen,许村,许村镇', 29.9978300, 118.3164500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14030, 'Xucun', 'Xucun', 'Hsu-ts''un,Hsü-ts’un,Xucun,Xucun Zhen,xu cun,xu cun zhen,许村,许村镇', 29.1836100, 117.5552800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14031, 'Jiangguanchi', 'Jiangguanchi', 'Hsu-ch''ang,Hsu-ch''ang-hsien,Hsu-ch''ang-shih,Hsu-chou,Hsuchow,Hsü-chou,Hsü-ch’ang,Hsü-ch’ang-hsien,Hsü-ch’ang-shih,Hsüchow,Jiangguanchi,Syuychan,Xuchang,jiang guan chi,将官池', 34.1282100, 113.8068100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14032, 'Xuanbao', 'Xuanbao', 'Hsuan-chia-p''u,Hsuan-chia-pao,Hsuan-p''u,Hsuan-pao,Hsüan-chia-pao,Hsüan-chia-p’u,Hsüan-pao,Hsüan-p’u,Xuanbao,Xuanbao Zhen,Xuanjiabao,Xuanjiapu,xuan bao,xuan bao zhen,xuan jia bao,宣堡,宣堡镇,宣家堡', 32.2910000, 119.9923400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14033, 'Xuanhuadian', 'Xuanhuadian', 'Hsuan-hua-tien,Hsüan-hua-tien,Suanhwatien,Süanhwatien,Xuanhuadian,Xuanhuadian Zhen,xuan hua dian,xuan hua dian zhen,宣化店,宣化店镇', 31.6958500, 114.4914900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14034, 'Xuanfeng', 'Xuanfeng', 'Hsuan-feng,Hsuan-feng-chen,Hsüan-feng-chen,Suanfengchen,Xuanfeng,Xuanfeng Zhen,xuan feng,xuan feng zhen,宣风,宣风镇', 27.6962400, 114.1198800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14035, 'Zhushan', 'Zhushan', 'Hsuan-en,Hsuan-en-hsien,Hsüan-en,Hsüan-en-hsien,I-en,Suan-en-hsien,Suanen,Süan-en-hsien,Xuan''en,Xuan''en Xian,Xuan’en,Xuan’en Xian,Zhushan,xuan en,xuan en xian,zhu shan,宣恩,宣恩县,珠山', 29.9945200, 109.4790700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14036, 'Xuanzhou', 'Xuanzhou', 'Hsuan-ch''eng,Hsuan-ch''eng-hsien,Hsüan-ch’eng,Hsüan-ch’eng-hsien,Ning-kuo,Ningkwo,Ningkwofu,Suancheng,Suancheng-hsien,Süancheng,Süancheng-hsien,Xuancheng,Xuanzhou', 30.9525000, 118.7552800, 'CN', '2015-07-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14037, 'Xuancheng', 'Xuancheng', 'Hsuan-ch''eng,Hsüan-ch’eng,Xuancheng,Xuancheng Xiang,xuan cheng,xuan cheng xiang,宣城,宣城乡', 25.4094900, 116.3841000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14038, 'Xizhou', 'Xizhou', 'Hsi-chou,Hsi-chou-chen,Sichow,Xizhou,Xizhou Zhen,xi zhou,xi zhou zhen,西周,西周镇', 29.4788900, 121.6727800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14039, 'Xizhaotong', 'Xizhaotong', 'Xizhaotong,Xizhaotong Zhen,xi zhao tong,xi zhao tong zhen,西兆通,西兆通镇', 38.0716100, 114.5967500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14040, 'Xizhaizhuang', 'Xizhaizhuang', 'Xizhaizhuang,Xizhaizhuang Zhen,xi di zhuang,xi di zhuang zhen,西翟庄,西翟庄镇', 38.7702800, 117.0016700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14041, 'Xizhai', 'Xizhai', 'Hsi-chai,Hsi-wang-chai,Xizhai,xi zhai,西寨', 34.6847600, 110.0500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14042, 'Xiyan', 'Xiyan', 'Hsi-yen-shih,Muguatsyao,Xiyan,Xiyan Zhen,Xiyanshi', 26.6163900, 110.4736100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14043, 'Leping', 'Leping', 'Hsi-yang,Hsi-yang-hsien,Leping,Leping Zhen,Lo-p''ing,Lo-p’ing,Siyang,Xiyang,Xiyang Xian,le ping,le ping zhen,xi yang xian,乐平,乐平镇,昔阳县', 37.6146900, 113.6649900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14044, 'Xiyang', 'Xiyang', 'Hsi-yang,Hsi-yang-chen,Xiyang,Xiyang Zhen,xi yang,西阳', 34.6603300, 109.0085300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14045, 'Xiyang', 'Xiyang', 'Hsi-yang,Xiyang,Xiyang Xiang,xi yang,xi yang xiang,西阳,西阳乡', 30.5328100, 118.5143800, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14046, 'Xiyang', 'Xiyang', 'Hsi-yang,Hsi-yang-hsun,Hsi-yang-hsün,Xiyang,Xiyang Zhen,xi yang,xi yang zhen,西洋,西洋镇', 25.8140500, 117.4339900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14047, 'Xixing', 'Xixing', 'Hsi-hsing,Hsi-hsing-chen,Xixing,Xixing Jiedao,xi xing,xi xing jie dao,西兴,西兴街道', 30.1891100, 120.2266900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14048, 'Xixiashu', 'Xixiashu', 'Hsi-hsia-shu,Hsia-shu,Hsia-shu-chen,Xixiashu,Xixiashu Zhen,xi xia shu,xi xia shu zhen,西夏墅,西夏墅镇', 31.9507200, 119.8200400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14049, 'Xixiang', 'Xixiang', 'Hsi-hsiang,Xixiang', 35.1627800, 112.8650000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14050, 'Xixiang', 'Xixiang', 'Hsi-hsiang,Hsi-hsiang-hsien,Sisiang-hsien,Xixiang,Xixiang Xian,xi xiang,xi xiang xian,西乡,西乡县', 32.9870300, 107.7640000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14051, 'Longquan', 'Longquan', 'Hsi,Hsi-hsien,Hsi-hsien-ch''eng,Hsi-hsien-ch’eng,Longquan,Longquan Zhen,Lu-liang,Lü-liang,Sichow,Xi Xian,Xixian,long quan,long quan zhen,xi xian,隰县,龙泉,龙泉镇', 36.6952500, 110.9556400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14052, 'Xi Xian Chengguanzhen', 'Xi Xian Chengguanzhen', 'Chiu-hsi-hsien,Hsi,Hsi-hsien,Hsi-hsien Old City,Hsi-hsien-chiu-chih,Hsi-hsien-ku-chih,Hsi-ku-hsien,Sihsien Old City,Xi Xian Chengguanzhen,Xixian,xi xian cheng guan zhen,息县城关镇', 32.3436100, 114.7294400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14053, 'Zijin', 'Zijin', 'Hsi-hsia,Hsi-hsia-k''ou,Hsi-hsia-kou-chi,Hsi-hsia-k’ou,Sisiakow,Xixia,Zijin,zi jin,紫金', 33.2891700, 111.4744400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14054, 'Xixi', 'Xixi', 'Hsi-hsi,Xixi,xi xi,锡溪', 27.6937500, 110.9533300, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14055, 'Xiwu', 'Xiwu', 'Hsi-wu,Hsi-wu-ts''un,Hsi-wu-ts’un,Xiwu,Xiwu Zhen,xi wu,xi wu zhen,西吴,西吴镇', 34.2972200, 108.5663900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14056, 'Xiwu', 'Xiwu', 'Hsi-wu,K''u-chu,K’u-chu,Xiwu,Xiwu Xiang,xi wu,xi wu xiang,西武,西武乡', 29.9062600, 117.8845700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14057, 'Xiwu', 'Xiwu', 'Hsi-wu,Hsi-wu-chen,Xiwu,Xiwu Zhen,xi wu,xi wu zhen,西坞,西坞镇', 29.6832200, 121.4835100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14058, 'Xiwei', 'Xiwei', 'Xiwei,Xiwei Xiang,xi wei,xi wei xiang,溪尾,溪尾乡', 26.1898100, 118.3742600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14059, 'Xiuzhuan', 'Xiuzhuan', 'Xiuzhuan,Xiuzhuan Zhen,xiu zhuan,xiu zhuan zhen,秀篆,秀篆镇', 24.1043200, 116.9642400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14060, 'Xiuying', 'Xiuying', 'Hsiu-ying,Xiuying,xiu ying,秀英', 20.0007300, 110.2935900, 'CN', '2012-05-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14061, 'Xiuwu Chengguanzhen', 'Xiuwu Chengguanzhen', 'Hsiu-wu,Hsiu-wu-hsien,Siu-wu,Syuu,Xiuwu,Xiuwu Chengguanzhen,xiu wu cheng guan zhen,修武城关镇', 35.2311100, 113.4380600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14062, 'Xiushi', 'Xiushi', 'Xiushi,Xiushi Zhen,xiu shi,xiu shi zhen,秀市,秀市镇', 28.0007800, 115.9265400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14063, 'Xiushan', 'Xiushan', 'Xiushan,Xiushan Zhen,xiu shan,xiu shan zhen,修山,修山镇', 28.5941700, 112.0347200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14064, 'Xiushan', 'Xiushan', 'Ch''i-lu,Ch’i-lu,T''ung-hai,T''ung-hai-hsien,Tonghai,Tonghai Xian,T’ung-hai,T’ung-hai-hsien,Xiushan,Xiushan Zhen,tong hai xian,xiu shan,xiu shan zhen,秀山,秀山镇,通海县', 24.1099900, 102.7615300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14065, 'Xiuqi', 'Xiuqi', 'Xiuqi,Xiuqi Zhen,Xiuqiba,xiu qi,xiu qi zhen,修齐,修齐镇', 31.8773700, 108.7815900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14066, 'Xiulin', 'Xiulin', 'Shi-shau,Shih-shou,Shih-shou-hsien,Shih-show-hsien,Shishou,Shishow,Xiulin', 29.7166700, 112.4000000, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14067, 'Xiugu', 'Xiugu', 'Chin-ch''i,Chin-ch''i-hsien,Chin-ch''i-hsien-ch''eng,Chin-ch’i,Chin-ch’i-hsien,Chin-ch’i-hsien-ch’eng,Chin-hsi,Jinxi,Jinxi Xian,Kinki,Kinkihsien,Xiugu,Xiugu Zhen,jin xi xian,xiu gu,xiu gu zhen,秀谷,秀谷镇,金溪县', 27.9113200, 116.7763700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14068, 'Xituo', 'Xituo', 'Hsi-t''o-chen,Hsi-t’o-chen,Xituo,Xituo Zhen,xi tuo,xi tuo zhen,西沱,西沱镇', 30.4079300, 108.2173200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14069, 'Xituan', 'Xituan', 'Hsi-t''uan,Hsi-t''uan-chen,Hsi-t’uan,Hsi-t’uan-chen,Xituan,Xituan Zhen,xi tuan,xi tuan zhen,西团,西团镇', 33.1095400, 120.4182900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14070, 'Xitou', 'Xitou', 'Ch''i-t''ou-chen,Ch’i-t’ou-chen,Hsi-t''ou,Hsi-t''ou-chen,Hsi-t’ou,Hsi-t’ou-chen,Xitou,Xitou Zhen,xi tou,xi tou zhen,溪头,溪头镇', 30.0105300, 118.4673100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14071, 'Xitou', 'Xitou', 'Xitou,Xitou Xiang,xi tou,xi tou xiang,溪头,溪头乡', 29.4540400, 118.0794200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14072, 'Xitou', 'Xitou', 'Hsi-t''ou,Hsi-t’ou,Xitou,Xitou Zhen,xi tou,xi tou zhen,溪头,溪头镇', 21.6550600, 111.7517200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14073, 'Xiting', 'Xiting', 'Hsi-t''ing,Hsi-t''ing-chen,Hsi-t’ing,Hsi-t’ing-chen,Xiting,Xiting Zhen,xi ting,xi ting zhen,西亭,西亭镇', 32.1185700, 121.0046200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14074, 'Xitianwei', 'Xitianwei', 'Xitianwei,Xitianwei Zhen,xi tian wei,xi tian wei zhen,西天尾,西天尾镇', 25.4897300, 119.0408600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14075, 'Xitangtuo', 'Xitangtuo', 'Xitangtuo,xi tang tuo,西塘坨', 39.3224000, 117.4882100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14076, 'Xitang', 'Xitang', 'Hsi-t''ang,Hsi-t''ang-chen,Hsi-t’ang,Hsi-t’ang-chen,Xitang,Xitang Zhen,xi tang,xi tang zhen,西塘,西塘镇', 30.9472900, 120.8878500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14077, 'Xitangqiao', 'Xitangqiao', 'Hsi-t''ang-ch''iao,Hsi-t’ang-ch’iao,Xitang,Xitangqiao,Xitangqiao Zhen,xi tang qiao,xi tang qiao zhen,西塘桥,西塘桥镇', 30.6086800, 120.9828600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14078, 'Xitan', 'Xitan', 'Xitan,Xitan Zhen,Xitian,xi tan,xi tan zhen,xi tian,溪填,溪潭,溪潭镇', 27.0101800, 119.6172500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14079, 'Houxixi', 'Houxixi', 'Houxixi,Hsi-t''an,Hsi-t’an,Xitan,hou xi xi,后溪西', 23.7677400, 117.1226600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14080, 'Xishuijie', 'Xishuijie', 'Hsi-shui-chieh,Xishuijie,Xishuijie Xiang,xi shui jie,xi shui jie xiang,西水界,西水界乡', 39.6636600, 112.2334100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14081, 'Xishiqiao', 'Xishiqiao', 'Hsi-shih-ch''iao,Hsi-shih-ch’iao,Xishiqiao,Xishiqiao Zhen,xi shi qiao,xi shi qiao zhen,西石桥,西石桥镇', 31.8688900, 120.0883300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14082, 'Xishenba', 'Xishenba', 'Hsi-shen-chu,Hsi-shen-chü,Hsi-shen-pa,Sishen''tzyuy,Sishen’tzyuy,Xishenba,Xishenba Xiang,xi shen ba,xi shen ba xiang,喜神坝,喜神坝乡', 32.8051200, 106.9199100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14083, 'Xishan', 'Xishan', 'Hsi-shan,Hsi-shan-wan-shou-kung,Wan-shou-kung,Xishan,Xishan Zhen,xi shan,xi shan zhen,西山,西山镇', 28.5516600, 115.6247900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14084, 'Xishan', 'Xishan', 'Hsi-shan-chieh,Xishan', 25.6852800, 108.9638900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14085, 'Xisa', 'Xisa', 'Hsi-ch''ou,Hsi-ch''ou-hsien,Hsi-ch’ou,Hsi-ch’ou-hsien,Hsi-hsi,Hsi-sa,Hsi-sa-chen,Hsi-sa-chieh,Sichow-hsien,Sisha,Sishakai,Xichou,Xisa,xi sa,西洒', 23.4500000, 104.7077500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14086, 'Xiqin', 'Xiqin', 'Hsi-ch''in,Hsi-ch’in,Sikin,Xiqin,Xiqin Zhen,xi qin,xi qin zhen,西芹,西芹镇', 26.5720700, 118.1099300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14087, 'Xiqiao', 'Xiqiao', 'Xiqiao,Xiqiao Zhen,xi qiao,xi qiao zhen,西樵,西樵镇', 22.9461400, 112.9673800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14088, 'Xipu', 'Xipu', 'Hsi-p''u-chen,Hsi-p’u-chen,Xipu,Xipuzhen,xi pu,xi pu zhen,犀浦,犀浦镇', 30.7571300, 103.9699000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14089, 'Baicheng', 'Baicheng', 'Baicheng,Hsi-p''ing-hsien,Hsi-ping,Hsi-p’ing-hsien,Sinin,Xiping,bai cheng,柏城', 33.3863900, 114.0158300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14090, 'Xiping', 'Xiping', 'Hsi-p''ing,Hsi-p’ing,Xiping,Xiping Zhen,Xiyuan,xi ping,xi ping zhen,xi yuan,西原,西坪,西坪镇', 25.0251400, 117.9399500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14091, 'Xiongzhou', 'Xiongzhou', 'Namyung,Nan-hsiung,Nan-hsiung-hsien,Nanxiong,Nanyung-hsien,Xiongzhou,xiong zhou,雄州', 25.1166700, 114.3000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14092, 'Guixi', 'Guixi', 'Guixi,Guixi Shi,Kuei-ch''i,Kuei-ch''i-hsien,Kuei-ch''i-hsien-ch''eng,Kuei-ch’i,Kuei-ch’i-hsien,Kuei-ch’i-hsien-ch’eng,Kuei-hsi,Kweiki,Kweikihsien,Xiongshi,gui xi,gui xi shi,贵溪,贵溪市', 28.2885700, 117.2132900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14093, 'Xiongshan', 'Xiongshan', 'Cheng-ho,Cheng-ho-hsien,Chiu-cheng-ho,Xiongshan,Xiongshan Zhen,Zhenghe,Zhenhe Xian,xiong shan,xiong shan zhen,zheng he,zheng he xian,政和,政和县,熊山,熊山镇', 27.3643900, 118.8571100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14094, 'Xiongkou', 'Xiongkou', 'Hsiung-k''ou,Hsiung-k''ou-shih,Hsiung-k’ou,Hsiung-k’ou-shih,Xiongkou,Xiongkou Zhen,xiong kou,xiong kou zhen,熊口,熊口镇', 30.3064600, 112.7752700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14095, 'Xiongjiang', 'Xiongjiang', 'Xiongjiang,Xiongjiang Zhen,xiong jiang,xiong jiang zhen,雄江,雄江镇', 26.3350100, 118.7423900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14096, 'Xionghe', 'Xionghe', 'Hsiung-chia-ho,Xionghe,Xionghe Zhen,Xiongjiahe,xiong he,xiong he zhen,熊河,熊河镇', 30.0842400, 112.4430700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14097, 'Xiongji', 'Xiongji', 'Hsing-chia-chi,Hsiung-chia-chi,Xiongji,Xiongji Zhen,xiong ji,xiong ji zhen,熊集,熊集镇', 31.9563900, 112.6547200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14098, 'Xinzhu', 'Xinzhu', 'Hsin-chu,Hsin-chu-chen,Xinzhu,xin zhu,新筑', 34.3848800, 109.0554300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14099, 'Xinzhuang', 'Xinzhuang', 'Hsin-chuang,Xinzhuang,Xinzhuang Zhen,xin zhuang,xin zhuang zhen,辛庄,辛庄镇', 37.5013600, 120.2246700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14100, 'Xinzhuang', 'Xinzhuang', 'Xinzhuang,Xinzhuang Zhen,xin zhuang,xin zhuang zhen,新庄,新庄镇', 37.0615900, 101.5610100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14101, 'Xinzhou', 'Xinzhou', 'Gorad Sin''dzhou,Han Chau,Hian-chiu-chhi,Hian-chiu-chhī,Hsin,Hsin-hsien,Hsin-hsien-ch''eng,Hsin-hsien-ch’eng,Hsin-ting,Hung-ciu,Hãn Châu,Hṳ̆ng-ciŭ,Sin''chzhou,Sin-cou,Sin-čou,Sinchow,Sinhsien,WUT,Xinfu Qu,Xinxian,Xinzhou,Xinzhou Shi,shnzhww,shynjw,sinjeou si,xin fu qu,xin zhou,xin zhou shi,Горад Сіньджоў,Синьчжоу,شنژوو,شینجو,忻州,忻州市,忻府区,신저우 시', 38.4091700, 112.7333300, 'CN', '2016-03-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14102, 'Xinzhou', 'Xinzhou', 'Xinzhou,Xinzhou Xiang,xin zhou,xin zhou xiang,新洲,新洲乡', 32.1790500, 109.9664800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14103, 'Xinzhou', 'Xinzhou', 'Hsin-chou,Hsin-chou-chen,Sinchow,Xinzhou', 30.8666700, 114.8000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14104, 'Xinzhou', 'Xinzhou', 'Hsin-chou,Xinzhou,Xinzhou Zhen,xin zhou,xin zhou zhen,新洲,新洲镇', 29.5552200, 111.8813500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14105, 'Xinzhou', 'Xinzhou', 'Hsin-chou,Sinchow,Xinzhou,Xinzhou Zhen,xin zhou,xin zhou zhen,新州,新州镇', 28.8102400, 107.3525900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14106, 'Xinzhou', 'Xinzhou', 'Hsi-lung,Hsi-lung-hsien,Hsin-chou,Hsin-chou-chen,Longlin Gezu Zizhixian,Lung-lin,Lung-lin-hsiang,Lung-lin-ko-tsu-tzu-chih-hsien,Silung,Silung-hsien,Xinzhou,xin zhou,新州', 24.8723400, 105.3511700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14107, 'Xinzhou', 'Xinzhou', 'Hsin-chou,Xinzhou,Xinzhou Zhen,xin zhou,xin zhou zhen,新洲,新洲镇', 21.8577200, 112.2804200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14108, 'Xinzhou', 'Xinzhou', 'Hsin-chou,Taan,Tam-chau,Tamchiu,Tamchow,Tan,Tan-hsien,Tanchow,Xinzhou,Xinzhou Zhen,xin zhou,xin zhou zhen,新州,新州镇', 19.7144600, 109.3114600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14109, 'Xinzhi', 'Xinzhi', 'Hsin-chih,Hsin-chih-ts''un,Hsin-chih-ts’un,Pei-ts''un,Pei-ts’un,Xinzhi', 36.4988900, 111.7047200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14110, 'Xinzhi', 'Xinzhi', 'Hsin-chih,Xinzhi,Xinzhi Xiang,xin zhi,xin zhi xiang,新祉,新祉乡', 27.6945600, 114.6823900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14111, 'Xinhualu', 'Xinhualu', 'Hsin-cheng,Hsin-cheng-hsien,Sincheng,Xinhualu,Xinzheng,xin hua lu,新华路', 34.3963300, 113.7246600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14112, 'Xinzheng', 'Xinzheng', 'Xinzheng,xin zheng,新政', 31.2749100, 106.2871400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14113, 'Xinzheng', 'Xinzheng', 'Xinzheng,Xinzheng Zhen,xin zheng,xin zheng zhen,新政,新政镇', 18.5429700, 109.6235500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14114, 'Zhelin', 'Zhelin', 'Hsin-che-lin,Xinzhelin,Zhelin,Zhelin Zhen,zhe lin,zhe lin zhen,柘林,柘林镇', 29.2096800, 115.5064100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14115, 'Xinzha', 'Xinzha', 'Hsin-cha,Hsin-cha-chen,Xinzha,Xinzha Jiedao,Xinzhazhen,xin zha,xin zha jie dao,新闸,新闸街道', 31.8184900, 119.8902700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14116, 'Xinzhan', 'Xinzhan', 'Hsin-chan,Xinzhan', 28.3883300, 106.8566700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14117, 'Xinzhai', 'Xinzhai', 'Hsin-chai,Xinzhai,Xinzhai Xiang,xin zhai,xin zhai xiang,新寨,新寨乡', 36.9427700, 107.9476500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14118, 'Xinzhai', 'Xinzhai', 'Xinzhai,xin zhai,新寨', 33.6438700, 104.6838600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14119, 'Xinzao', 'Xinzao', 'Hsin-tsao,P''an-yu,P’an-yü,Suntso,Xinzao,Xinzao Zhen,xin zao,xin zao zhen,新造,新造镇', 23.0431600, 113.4158800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14120, 'Xinyu', 'Xinyu', 'Xinyu,Xinyu Shi,xin yu,xin yu shi,xinyu shi,新余,新余市', 27.8390600, 114.8459100, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14121, 'Xinyu', 'Xinyu', 'Hsin-yu,Hsin-yu-chen,Hsin-yu-hsien,Hsin-yu-hsien-ch''eng,Hsin-yu-shih,Hsin-yü,Hsin-yü-chen,Hsin-yü-hsien,Hsin-yü-hsien-ch’eng,Hsin-yü-shih,Sin''juj,Sin-jue,Sin-jü,Sin-u-chhi,Sin-yi-su,Sin-û-chhī,Sing-u,Sinyu-hsien,Sinyü-hsien,Sîn-yì-sṳ,Sĭng-ṳ̀,Tan Du,Tân Dư,Xinyu,Xinyu Shi,shynyw,sin-wi si,xin yu,xin yu shi,Синьюй,شینیو,新余,新余市,新喻,신위 시', 27.8042900, 114.9333500, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14122, 'Xinying', 'Xinying', 'Hsin-hsing,Hsin-hsing-shih,Sinhin,Sunhing,Sunhingshi,Xinxing,Xinying,Xinying Zhen,xin ying,xin ying zhen,新盈,新盈镇', 19.8929500, 109.5253400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14123, 'Xinyi', 'Xinyi', 'Hsin-i,Hsin-i-chen,Xinyi,xin yi,信义', 34.5695400, 109.5996600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14124, 'Hancheng', 'Hancheng', 'Hancheng,Hsin-yeh,Hsin-yeh-hsien,Sin-ye-hsien,Sinyeh-hsien,Xinye,han cheng,汉城', 32.5186100, 112.3522200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14125, 'Xinyang', 'Xinyang', 'Czinan'',Hsin-yang,Hsin-yang-hsien,Hsin-yang-shih,Sinyang,Sinyang-hsien,XYW,Xinyang,Цзинань', 32.1227800, 114.0655600, 'CN', '2013-10-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14126, 'Xinxu', 'Xinxu', 'Hsin-hsu,Hsin-hsü,Xinxu,Xinxu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 26.9063600, 115.1343700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14127, 'Xinxu', 'Xinxu', 'Hsin-hsu,Hsin-hsü,Xinxu,Xinxu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 24.7379800, 118.2530700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14128, 'Xinxu', 'Xinxu', 'Xinxu,Xinxu Zhen,Xinyu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 24.0559500, 115.8648700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14129, 'Xinxu', 'Xinxu', 'Hsin-hsu,Hsin-hsü,Xinxu,Xinxu Zhen,Xinyu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 22.8547600, 114.3228200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14130, 'Xinxing', 'Xinxing', 'Hsin-hsing,Xinxing,Xinxing Zhen,xin xing,xin xing zhen,新兴,新兴镇', 34.7755600, 108.8850000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14131, 'Xincheng', 'Xincheng', 'Hsin-hsing,Hsin-hsing-hsien,Sinhing,Sunhing,Sunhing-hsien,Xincheng,Xincheng Zhen,Xinxing,xin cheng,xin cheng zhen,新城,新城镇', 22.7015500, 112.2246400, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14132, 'Xinxing', 'Xinxing', 'Hsin-hsing,Hsin-hsing-shih,Hsing-hsing-shih,Xinxing,Xinxing Zhen,Xinying,xin xing,xin xing zhen,新兴,新兴镇', 19.5109900, 110.1759700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14133, 'Nangandao', 'Nangandao', 'Hsin-hsiang,Hsin-hsiang-hsien,Hsin-hsiang-shih,Hsinghsiang,Nangandao,Sin''sjan,Singsieng,Sinsiang-hsien,Xinxiang,nan gan dao,Синьсян,南干道', 35.1903300, 113.8015100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14134, 'Xinji', 'Xinji', 'Ching-fu,Ching-fu-hsien,Hsin-chi,Hsin-hsien,Kingfu,Xin Xian,Xinji,Xinji Zhen,Xinxian,xin ji,xin ji zhen,xin xian,新县,新集,新集镇', 31.6232000, 114.8740000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14135, 'Xinxian', 'Xinxian', 'Hsin-hsien,Xinxian,Xinxian Zhen,xin xian,xin xian zhen,新县,新县镇', 25.6564500, 119.0531800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14136, 'Xinwo', 'Xinwo', 'Hsin-wo,Xinwo,Xinwo Zhen,xin wo,xin wo zhen,新渥,新渥镇', 28.9484000, 120.3741200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14137, 'Xintian', 'Xintian', 'Xintian,Xintian Zhen,xin tian,xin tian zhen,新田,新田镇', 30.6986600, 108.4019300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14138, 'Xintian', 'Xintian', 'Hsin-t''ien-shan,Hsin-t’ien-shan,Xintian,Xintian Zhen,Xintianshan,xin tian,xin tian zhen,新田,新田镇', 30.7553100, 118.7694700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14139, 'Xintian', 'Xintian', 'Hsin-t''ien,Hsin-t''ien-ch''iao,Hsin-t’ien,Hsin-t’ien-ch’iao,Xintian,Xintian Xiang,xin tian,xin tian xiang,新田,新田乡', 27.8249500, 114.2580000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14140, 'Longquan', 'Longquan', 'Hsin-t''ien,Hsin-t''ien-hsien,Hsin-t’ien,Hsin-t’ien-hsien,Longquan,Longquanzhen,Sintien-hsien,Xintian,long quan,龙泉', 25.9013900, 112.2116700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14141, 'Xintian', 'Xintian', 'Hsin-t''ien,Hsin-t’ien,Xintian,Xintian Zhen,xin tian,xin tian zhen,新田,新田镇', 25.3617700, 115.2455100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14142, 'Xintang', 'Xintang', 'Hsin-t''ang-pu,Hsin-t’ang-pu,Xintang,Xintang Xiang,Xintangpu,xin tang,xin tang xiang,新塘,新塘乡', 29.6187900, 115.7135800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14143, 'Xintang', 'Xintang', 'Hsin-t''ang,Hsin-t''ang-ch''ang,Hsin-t’ang,Hsin-t’ang-ch’ang,Xintang,Xintang Xiang,xin tang,xin tang xiang,新塘,新塘乡', 30.2733800, 109.7518000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14144, 'Xintang', 'Xintang', 'Hsin-t''ang,Hsin-t’ang,Santong,Suntong,Xintang,Xintang Zhen,xin tang,xin tang zhen,新塘,新塘镇', 23.1150000, 113.6083300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14145, 'Xintai', 'Xintai', 'Hsin-t''ai,Hsin-t''ai-hsien,Hsin-t’ai,Hsin-t’ai-hsien,Hsing-t''ai,Hsing-t’ai,Sintai,Sintaihsien,Sintoihsien,Xintai', 35.9005600, 117.7519400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14146, 'Xinshidu', 'Xinshidu', 'Hsin-shih-tu,Xinshidu,Xinshidu Zhen,xin shi du,xin shi du zhen,新市渡,新市渡镇', 28.4897200, 112.2802800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14147, 'Xinshiba', 'Xinshiba', 'Chieh-lo,Ganluo,Hsi-hsi-chiao-pa,Hsin-shih-pa,Kan-lo,Xinshiba,xin shi ba,新市坝', 28.9709100, 102.7712600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14148, 'Xinshi', 'Xinshi', 'Hsin-shih,Hsin-shih-chen,Xinshi,Xinshi Zhen,xing shi,幸市', 34.5725800, 109.5247000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14149, 'Xinshi', 'Xinshi', 'Xinshi,Xinshi Zhen,xin shi,xin shi zhen,新市,新市镇', 32.3343500, 112.9648200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14150, 'Xinshi', 'Xinshi', 'Hsin-shih,Hsin-shih-chen,Xinshi,Xinshi Zhen,xin shi,xin shi zhen,新市,新市镇', 31.5778100, 118.7325000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14151, 'Xinshi', 'Xinshi', 'Ching-shan,Ching-shan-hsien,Jingshan,Kingshan,Kingshanhsien,Xinshi,xin shi,新市', 31.0470400, 113.1409800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14152, 'Xinshi', 'Xinshi', 'Hsin-shih,Hsin-shih-chen,Sinshih,Xinshi,Xinshi Zhen,xin shi,xin shi zhen,新市,新市镇', 30.6173800, 120.2840700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14153, 'Xinsheng', 'Xinsheng', 'Xinsheng,Xinsheng Zhen,Xinshengchang,xin sheng,xin sheng zhen,新生,新生镇', 30.2101500, 107.9458900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14154, 'Daxinshao', 'Daxinshao', 'Daxinshao,Xinshao,Xinshao Zhen,da xin shao,xin shao,xin shao zhen,大新哨,新哨,新哨镇', 24.2405200, 103.4515300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14155, 'Xinshan', 'Xinshan', 'An-yuan-hsien,An-yüan-hsien,Anyuan,Anyuan Xian,Xinshan,Xinshan Zhen,an yuan xian,xin shan,xin shan zhen,安远县,欣山,欣山镇', 25.1373200, 115.3872000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14156, 'Xinquansi', 'Xinquansi', 'Xinquansi,Xinquansi Zhen,xin quan si,xin quan si zhen,新泉寺,新泉寺镇', 28.6283300, 112.6975000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14157, 'Xinquan', 'Xinquan', 'Hsin-ch''uan,Hsin-ch’üan,Xinquan,Xinquan Zhen,xin quan,xin quan zhen,新泉,新泉镇', 25.3548300, 116.6120900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14158, 'Xinqiaohe', 'Xinqiaohe', 'Hsin-ch''iao-ho,Hsin-ch’iao-ho,Xinqiaohe,Xinqiaohe Zhen,xin qiao he,xin qiao he zhen,新桥河,新桥河镇', 28.6089200, 112.1862300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14159, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch''iao-chen,Hsin-chao-ch''iao,Hsin-chao-ch’iao,Hsin-ch’iao,Hsin-ch’iao-chen,Xinqiao,Xinqiao Xiang,xin qiao,xin qiao xiang,新桥,新桥乡', 31.5118600, 118.4517300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14160, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch''iao-chen,Hsin-ch’iao,Hsin-ch’iao-chen,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 31.0650000, 121.3075000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14161, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch’iao,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 29.1894700, 110.5062200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14162, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao-kuan,Hsin-ch’iao-kuan,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 28.5208700, 121.4120500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14163, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch’iao,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 25.8809600, 116.4516400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14164, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch’iao,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 25.5919400, 117.5058300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14165, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao,Hsin-ch''iao-hsu,Hsin-ch’iao,Hsin-ch’iao-hsü,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 22.9544700, 112.4102600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14166, 'Xinpu', 'Xinpu', 'Hsin-p''u,Hsin-p''u-yen,Hsin-p’u,Hsin-p’u-yen,Xinpu,Xinpu Zhen,Xinpuyan,xin pu,xin pu zhen,新浦,新浦镇', 30.2436700, 121.3641900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14167, 'Xinpu', 'Xinpu', 'Hsien-p''u,Hsien-p’u,Hsin-hai-lien,Hsin-hai-lien-shih,Hsin-p''u,Hsin-p''u-chen,Hsin-p’u,Hsin-p’u-chen,Lianyungang,Lien-yun-chiang,Lien-yun-chiang-shih,Lien-yun-kang,Lien-yün-chiang,Lien-yün-chiang-shih,Lien-yün-kang,Sinpuchen,Tsin-pu,Xinpu,lian yun gang,lian yun gang shi,lyen-wingang,xin pu,ليەنيۈنگاڭ شەھىرى,新浦,连云港,连云港市,連雲港,連雲港市,롄윈강', 34.5997200, 119.1594400, 'CN', '2015-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14168, 'Xinpu', 'Xinpu', 'Hsin-p''u,Hsin-p''u-wan,Hsin-p’u,Hsin-p’u-wan,Xinpu,Xinpu Zhen,xin pu,xin pu zhen,新铺,新铺镇', 33.1000000, 106.4500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14169, 'Xinpu', 'Xinpu', 'Xinpu,Xinpu Xiang,xin pu,xin pu xiang,新铺,新铺乡', 29.6813500, 111.3781500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14170, 'Xinpeicun', 'Xinpeicun', 'Hsin-p''ei-ts''un,Hsin-p’ei-ts’un,Peicun Xiang,Shiyihao Xiang,Xinpeicun,pei cun xiang,shen yi hao xiang,xin pei cun,什义号乡,新裴村,裴村乡', 39.6175500, 113.5293500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14171, 'Xinnong', 'Xinnong', 'Xinnong,Xinnong Zhen,xin nong,xin nong zhen,新农,新农镇', 32.7500200, 120.7581200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14172, 'Xinning', 'Xinning', 'Wu-ning-hsien,Wu-ning-hsien-ch''eng,Wu-ning-hsien-ch’eng,Wuning,Xinning,Xinning Zhen,xin ning,xin ning zhen,新宁,新宁镇', 29.2392200, 115.0973700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14173, 'Xinning', 'Xinning', 'Fu-nan-hsiang,Fu-nan-hsien,Fu-sui,Funan,Hsin-ning,Xinning,xin ning,新宁', 22.6708000, 107.8891200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14174, 'Xinmin', 'Xinmin', 'Xinmin,Xinmin Zhen,xin min,xin min zhen,新民,新民镇', 30.9034300, 109.4668200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14175, 'Xinmiao', 'Xinmiao', 'Hsin-miao-chen,Xinmiao,Xinmiao Zhen,xin miao,xin miao zhen,新妙,新妙镇', 29.6552800, 107.0498800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14176, 'Xinmian', 'Xinmian', 'Nongchang,Shih-mien,Shimian,Xinmian,xin mian,新棉', 29.2399200, 102.3720800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14177, 'Xinlong', 'Xinlong', 'Xinlong,Xinlongxu,xin long,xin long zhen,新龙,新龙镇', 25.1979300, 114.6225400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14178, 'Xinli', 'Xinli', 'Hsin-li-p''u,Hsin-li-p’u,Xinli,Xinli Zhen,Xinlipu,xin li,xin li zhen,新立,新立镇', 30.2808000, 107.6447100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14179, 'Xinling', 'Xinling', 'Badong,Pa-tung,Pa-tung-hsien,Xinling,xin ling,信陵', 31.0253000, 110.3181600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14180, 'Xinli', 'Xinli', 'Xinli,Xinli Jiedao,Xinlicun,xin li,xin li jie dao,新立,新立街道', 39.0847200, 117.3355600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14181, 'Xinkaikou', 'Xinkaikou', 'Hsin-k''ai-t''un,Hsin-k’ai-t’un,Xinkaikou', 39.6788900, 117.1902800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14182, 'Xinkai', 'Xinkai', 'Hsin-k''ai-kang,Hsin-k’ai-kang,Hsu-chia,Hsü-chia,Xinkai,Xinkai Zhen,Xinkaigang,xin kai,xin kai zhen,新开,新开镇', 31.9139000, 120.9354800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14183, 'Xinjing', 'Xinjing', 'Ching-hsi,Ching-hsi-hsien,Ching-hsi-hsien-ch''eng,Ching-hsi-hsien-ch’eng,Jingxi,Kuei-shun,Kweishun,Tsingsi,Tsingsihsien,Xinjing,xin jing,新靖', 23.2025200, 106.3820700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14184, 'Xinjie', 'Xinjie', 'Hsin-chieh,Xinjie,Xinjie Huizu Xiang,xin jie,xin jie hui zu xiang,新街,新街回族乡', 35.7167400, 101.3733600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14185, 'Xinjie', 'Xinjie', 'Hsin-chieh,Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 32.6318200, 118.8454800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14186, 'Xinjie', 'Xinjie', 'Hsin-chieh,Hsin-hsu,Hsin-hsü,Sinchia,Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 28.2326900, 115.4084100, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14187, 'Xinjiayuan', 'Xinjiayuan', 'Hsin-chia-yuan,Hsin-chia-yüan,Xinjiayuan,Xinjiayuan Xiang,xin jia yuan,xin jia yuan xiang,新家园,新家园乡', 39.7532400, 112.9858300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14188, 'Longxing', 'Longxing', 'Hsin-chiang,Hsin-chiang-hsien,Kiangchow,Longxing,Longxing Zhen,Sinkiang,Sinkianghsien,Xinjiang Xian,long xing,long xing zhen,xin jiang xian,新绛县,龙兴,龙兴镇', 35.6129700, 111.2192500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14189, 'Xinjiang', 'Xinjiang', 'Hsin-chiang,Hsin-chiang-hsu,Hsin-chiang-hsü,Sin''dzjan,Xinjiang,Xinjiang Zhen,xin jiang,xin jiang zhen,Синьдзян,新江,新江镇', 24.4689900, 113.8302900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14190, 'Xinjian', 'Xinjian', 'Hsin-chien,Shih-tu,Xinjian,Xinjian Xiang,xin jian,xin jian xiang,新建,新建乡', 29.1249800, 117.9348500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14191, 'Xinjian', 'Xinjian', 'Hsin-chien-chen,Xinjian,Xinjian Zhen,xin jian,xin jian zhen,新建,新建镇', 28.7243500, 120.0192200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14192, 'Xinji', 'Xinji', 'Hsin-chi,Hsin-chi-chen,Shu-lu-hsien,Shulu,Sin''tszi,Sin’tszi,Xinji', 37.9027800, 115.2036100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14193, 'Xinji', 'Xinji', 'Hsin-chi,Xinji,Xinji Xiang,xin ji,xin ji xiang,辛集,辛集乡', 33.7893000, 113.0002500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14194, 'Xinji', 'Xinji', 'Hsin-chi,Sin''tszi,Sin’tszi,Xinji,Xinji Zhen,xin ji,xin ji zhen,新集,新集镇', 33.0080600, 106.8211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14195, 'Xinji', 'Xinji', 'Hsin-chi,Ta-hsu-chuang,Ta-hsü-chuang,Xinji,Xinji Zhen,xin ji,xin ji zhen,薪集,薪集镇', 32.3283600, 119.2930800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14196, 'Xinji', 'Xinji', 'Hsin-chi,Hsin-chi-chen,Xinji,Xinji Zhen,xin ji,xin ji zhen,薪集,薪集镇', 32.3082500, 118.7147800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14197, 'Xiniu', 'Xiniu', 'Hsi-niu,Hsi-niu-hsu,Hsi-niu-hsü,Hsi-niu-t''an,Hsi-niu-t’an,Xiniu,Xiniu Zhen,xi niu,xi niu zhen,西牛,西牛镇', 24.1634900, 113.1118000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14198, 'Xining', 'Xining', 'Gorad Sinin,Hsi-ning,Hsi-ning-shih,Hszining,Sa-ning,Se-leng-chhi,Se-lêng-chhī,Shinin,Shining shehiri,Si-nen-su,Si-ning,Sihningz,Siniin,Sinin,Sining,Sining-hsien,Siningas,Siningfu,Sinino,Sî-nèn-sṳ,Să̤-nìng,Tay Ninh,Tây Ninh,XNN,Xining,Xining Shi,shynyng,shynyngh,sinin,sining si,sininga,sinini,synyng,xi ning,xi ning shi,Горад Сінін,Синиин,Синин,Сининг,Сінін,Шинин,שינינג,شينينغ,شینینگ,शिनिंग,ཟི་ལིང་།,სინინი,西宁,西宁市,西寧,西寧市,시닝 시', 36.6255400, 101.7573900, 'CN', '2013-07-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14199, 'Xinhuang', 'Xinhuang', 'Hsin-huang,Hsin-huang-chen,Xinhuang,Xinhuang Shequ,Xinhuang Zhen,xin huang,xin huang she qu,xin huang zhen,新篁,新篁社区,新篁镇', 30.6212100, 120.9148600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14200, 'Xinhuang', 'Xinhuang', 'Hsin-huang,Hsin-huang-t''ung-tsu-tzu-chih-hsien,Hsin-huang-t’ung-tsu-tzu-chih-hsien,Huang,Huang-hsien,Xinhuang,xin huang,新晃', 27.3735900, 109.1337600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14201, 'Xinhua', 'Xinhua', 'Xinhua,Xinhua Zhen,xin hua,xin hua zhen,新华,新华镇', 39.2000000, 100.0000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14202, 'Shangmei', 'Shangmei', 'Hsin-hua,Hsin-hua-hsien,Shangmei,Sinhwa,Sinhwa-hsien,Xinhua,shang mei,上梅', 27.7427800, 111.2955600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14203, 'Xinhua', 'Xinhua', 'Ch''ao-chia,Ch''iao-chia,Ch''iao-chia-hsien,Ch’ao-chia,Ch’iao-chia,Ch’iao-chia-hsien,Kiaokia,Kiaokia-hsien,Qiaojia,Qiaojia Xian,Xinhua,qiao jia xian,xin hua,巧家县,新华', 26.8883800, 102.9332400, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14204, 'Xinhua', 'Xinhua', 'Fu-chou,Fu-chou-hsien,Fu-chow,Fu-ning-hsien,Funing,Xinhua,xin hua,新华', 23.6431000, 105.6531700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14205, 'Xinhua', 'Xinhua', 'Hsin-chieh,Hsin-chieh-hsu,Hsin-chieh-hsü,Hua-hsien,Huadu,Huaxian,Sunkai,Sunmanfow,Xinhua,Xinhua Jiedao,xin hua,xin hua jie dao,新华,新华街道', 23.3812100, 113.2074400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14206, 'Xinhe', 'Xinhe', 'Hsin-ho-chen,Shuxun,Xinhe,Xinhe Zhen,Xinhezhen,shu xun,xin he,xin he zhen,新河,新河镇,树勋', 31.9835800, 121.3468700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14207, 'Xinheng', 'Xinheng', 'Hsin-heng,Hsin-heng-hsu,Hsin-heng-hsü,Xinheng,Xinheng Zhen,xin heng,xin heng zhen,新亨,新亨镇', 23.6396000, 116.2873900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14208, 'Xinhe', 'Xinhe', 'Hsin-ho,Sinho,Xinhe,Xinhe Jiedao,xin he,xin he jie dao,新河,新河街道', 39.0397200, 117.6213900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14209, 'Xinhe', 'Xinhe', 'Xinhe,Xinhe Xiang,xin he,xin he xiang,新合,新合乡', 29.6967100, 119.9066700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14210, 'Xinhe', 'Xinhe', 'Hsin-ho,Hsin-ho-so-ch''eng,Hsin-ho-so-ch’eng,Xinhe,Xinhe Zhen,xin he,xin he zhen,新河,新河镇', 28.4812300, 121.4510300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14211, 'Xingzi', 'Xingzi', 'Hsing-tzu,Hsing-tzu-fou,Hsing-tzu-hsu,Hsing-tzu-hsü,Xingzi,Xingzi Zhen,xing zi,xing zi zhen,星子,星子镇', 25.0000000, 112.5500000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14212, 'Suohe', 'Suohe', 'Hsing-yang,Jung-yang,Jung-yang-hsien,Suohe,Xingyang,Ying-yang,suo he,索河', 34.7872200, 113.3580600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14213, 'Weifen', 'Weifen', 'Hinghsien,Hsing,Hsing-hsien,Sinsyan'',Sinsyan’,Weifen,Weifen Zhen,Xing Xian,Xingxian,wei fen,wei fen zhen,xing xian,兴县,蔚汾,蔚汾镇', 38.4806400, 111.1666400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14214, 'Zhongcheng', 'Zhongcheng', 'Hingwen,Hingwenhsien,Hsing-wen,Hsing-wen-hsien,Xingwen,Zhongcheng,Zhongcheng Zhen,zhong cheng,zhong cheng zhen,中城,中城镇', 28.3095400, 105.2307500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14215, 'Xingtian', 'Xingtian', 'Hingtien,Hsing-t''ien,Hsing-t''ien-i,Hsing-t’ien,Hsing-t’ien-i,Singtien,Xingtian,Xingtian Zhen,xing tian,xing tian zhen,兴田,兴田镇', 27.5000000, 118.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14216, 'Xingtan', 'Xingtan', 'Hsing-t''an,Hsing-t’an,Xingtan,Xingtan Zhen,xing tan,xing tan zhen,杏坛,杏坛镇', 22.7836600, 113.1445100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14217, 'Xingtai', 'Xingtai', 'Chin-t''ai,Chin-t’ai,Heng-tai-chhi,Hing-dai,Hinh GJai,Hsing-t''ai,Hsing-t''ai-hsien,Hsing-tai-shih,Hsing-t’ai,Hsing-t’ai-hsien,Hêng-tâi-chhī,Hìng-dài,Hình Đài,Setay,Shun''de,Shun-te,Shunteh,Shuntehfu,Shun’de,Sing-tchaj,Singtai,Singtaj,Sintaj,XNT,Xingtai,Yingtaihsien,kei tai shi,shngtayy,shyngtay,singtai si,xing tai,xing tai shi,Сингтај,Синтай,Сінтай,شنگتائی,شینگتای,ケイ台市,邢台,邢台市,싱타이 시', 37.0630600, 114.4941700, 'CN', '2014-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14218, 'Xingzhen', 'Xingzhen', 'Hsing-chen,Hsing-shih,Hsing-shih-chen,Xingshizhen,Xingzhen,xing zhen,兴镇', 34.9321700, 109.4487500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14219, 'Xingsheng', 'Xingsheng', 'Xingsheng,Xingsheng Xiang,Xingshengzhuang,xing sheng,xing sheng xiang,兴盛,兴盛乡', 35.4500000, 106.3333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14220, 'Xingren', 'Xingren', 'Hsing-jen,Hsing-jen-chen,Xingren,Xingren Zhen,xing ren,xing ren zhen,兴仁,兴仁镇', 32.0649700, 120.9399500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14221, 'Xingping', 'Xingping', 'Hsing-p''ing,Hsing-p’ing,Xingping,xing ping,兴坪', 35.8412500, 105.6603100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14222, 'Xingou', 'Xingou', 'Hsin-kou,Hsin-kou-tsui,Xingou,Xingou Zhen,xin gou,xin gou zhen,新沟,新沟镇', 30.1317900, 112.9529200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14223, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Jiedao,Hinghinghsien,Hingning,Hingning-hsien,Hsieng-ning,Hsin-ning,Hsing-ch''eng-chen,Hsing-ch’eng-chen,Hsing-ning,Hsing-ning-hsien,Xingning,fu xing,fu xing jie dao,xing ning,兴宁,福兴,福兴街道', 24.1271100, 115.7202100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14224, 'Tongmin', 'Tongmin', 'Tongmin,Tongmin Zhen,Xingmin,tong min,tong min zhen,同民,同民镇', 28.1852800, 105.9958300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14225, 'Xinglong', 'Xinglong', 'Hsing-lung,Hsing-lung-chen,Xinglong,Xinglongzhen,xing long,兴隆', 35.7037900, 105.8098900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14226, 'Xinglong', 'Xinglong', 'Ch''ing-lung-chen,Ch’ing-lung-chen,Hsing-lung-chen,Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 32.1778800, 119.8475000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14227, 'Xinglong', 'Xinglong', 'Hsing-lung,Hsing-lung-chi,Xinglong,Xinglongji,xing long,兴隆', 32.0493000, 112.9030500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14228, 'Xinglong', 'Xinglong', 'Hsing-lung,Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 29.8893100, 106.7062200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14229, 'Xinglongchang', 'Xinglongchang', 'Hsing-lung-ch''ang,Hsing-lung-ch’ang,Xinglongchang,Xinglongchang Zhen,xing long chang,xing long chang zhen,兴隆场,兴隆场镇', 28.0508300, 109.8500000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14230, 'Xinglong', 'Xinglong', 'Hsing-lung-tien,Xinglong,Xinglong Xiang,xing long,xing long xiang,兴隆,兴隆乡', 31.7136500, 113.6106400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14231, 'Xinglong', 'Xinglong', 'Sanjiaoba,Xinglong,Xinglong Zhen,san jiao ba,xing long,xing long zhen,三角坝,兴隆,兴隆镇', 30.6572300, 109.4459900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14232, 'Xinglong', 'Xinglong', 'Hsing-lung,Ta-li-ts''un,Ta-li-ts’un,Xinglong,Xinglong Xiang,xing long,xing long xiang,兴隆,兴隆乡', 30.3569100, 118.3412300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14233, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 29.2584100, 109.0371400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14234, 'Xinglin', 'Xinglin', 'Hsing-lin,Hsing-lin-chen,Xinglin,Xinglin Zhen,xing lin,xing lin zhen,杏林,杏林镇', 34.3441800, 107.9904200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14235, 'Xinglin', 'Xinglin', 'Hsing-lin,Xinglin,Xinglin Jiedao,xing lin,xing lin jie dao,杏林,杏林街道', 24.5660900, 118.0375900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14236, 'Xingkou', 'Xingkou', 'Hsing-k''ou-shih,Hsing-k’ou-shih,Xingkou,Xingkou Xiang,xing kou,xing kou xiang,星口,星口乡', 29.0816800, 118.3012000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14237, 'Xinghua', 'Xinghua', 'Xinghua,Xinghua Zhen,xing hua,xing hua zhen,杏花,杏花镇', 23.4000000, 111.7166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14238, 'Xingguo', 'Xingguo', 'Ch''in-an,Ch''in-an-hsien,Ch''ing-ang,Ch’in-an,Ch’in-an-hsien,Ch’ing-ang,Qin''an,Qin''an Xian,Qin’an,Qin’an Xian,Tsin''an'',Tsinanhsien,Tsin’an’,Xingguo,qin an xian,xing guo,兴国,秦安县', 34.8586100, 105.6686100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14239, 'Xingguo', 'Xingguo', 'Hingkwo-fu,Hingkwochow,Hsin-yang,Hsing-kou,Xingguo,Yang-hsin,Yang-hsin-hsien,Yangsio,Yangxin,xing guo,兴国', 29.9225300, 115.3020800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14240, 'Xingdian', 'Xingdian', 'Hsin-tien-miao,Hsing-tien-miao,Xingdian,Xingdian Zhen,xing dian,xing dian zhen,星甸,星甸镇', 32.0395100, 118.4351000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14241, 'Xingao', 'Xingao', 'Hsin-kao,Hsin-kao-ts''un,Hsin-kao-ts’un,Xingao,Xingao Xiang,xin gao,xin gao xiang,新高,新高乡', 39.0260700, 112.9616100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14242, 'Xingang', 'Xingang', 'Hsin-chiang,Xingang,Xingang Zhen,xin gang,xin gang zhen,新港,新港镇', 29.7541900, 116.0972100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14243, 'Xing’an', 'Xing''an', 'Hsing-an,Hsing-an-chen,Hsing-an-ts''un,Hsing-an-ts’un,Xing''an,Xing''an Zhen,Xing’an,Xing’an Zhen,xing an,xing an zhen,兴安,兴安镇', 38.0157300, 114.9147700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14244, 'Ankang', 'Ankang', 'AKA,An-k''ang-hsien,An-k’ang-hsien,Ankan,Ankang,Hingan,Hinganfu,Hsing-an,Xing''an,Xing’an,an kang,an kang shi,Анкан,安康,安康市', 32.6800000, 109.0172200, 'CN', '2014-05-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14245, 'Xing’an', 'Xing''an', 'Hingan,Hinganhsien,Hsing-an,Hsing-an-hsien,Hsing-an-hsien-ch''eng,Hsing-an-hsien-ch’eng,Xing''an,Xing’an,xing an,兴安', 25.6196400, 110.6424800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14246, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-chen,Xinfeng,Xinfeng Jieban,Xinfengzhen,xin feng,新丰', 34.4266400, 109.2636400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14247, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-chen,Hsin-feng-chi,Xinfeng,Xinfeng Zhen,xin feng,xin feng zhen,新丰,新丰镇', 33.2683100, 120.4535600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14248, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-chen,Sinfeng,Xinfeng,Xinfeng Zhen,xin feng,xin feng zhen,辛丰,辛丰镇', 32.1139800, 119.5662300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14249, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-chen,Liuchong,Xinfeng,Xinfeng Zhen,liu chong,xin feng,xin feng zhen,刘冲,新丰,新丰镇', 31.1353700, 118.6794300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14250, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-chen,Xinfeng,Xinfeng Zhen,xin feng,xin feng zhen,新丰,新丰镇', 30.7090000, 120.9183500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14251, 'Xinfengjie', 'Xinfengjie', 'Hsin-feng,Hsin-feng-chen,Hsin-feng-chieh,Sinfengchen,Xinfeng,Xinfengjie,Xinfengjie Zhen,xin feng jie,xin feng jie zhen,新丰街,新丰街镇', 27.4268000, 116.5893300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14252, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-shih,Xinfeng,Xinfeng Xiang,xin feng,xin feng xiang,新丰,新丰乡', 27.1089000, 116.2131700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14253, 'Xinfeng', 'Xinfeng', 'Hsin-feng,Hsin-feng-hsu,Hsin-feng-hsü,Xinfeng,Xinfeng Zhen,xin feng,xin feng zhen,新丰,新丰镇', 24.0509800, 116.8558700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14254, 'Xinfang', 'Xinfang', 'Hsin-fang,Xinfang,Xinfang Xiang,xin fang,xin fang xiang,新坊,新坊乡', 27.7004700, 114.4699200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14255, 'Xindu', 'Xindu', 'Hsin-tu,Hsin-tu-hsien,Sin''du,Sintu,Sintu-hsien,Sin’du,Xindu,xin dou,新都', 30.8223600, 104.1574200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14256, 'Xindou', 'Xindou', 'Chang,Changku,Chango,Chiu-lu-ho,Dango Gomba,Drango,Laojie,Lu-ho,Luhuo,Lukho,Xindou,Xindou Zhen,Zhaggo,xin dou,xin dou zhen,新都,新都镇', 31.3964800, 100.6784700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14257, 'Wenfeng', 'Wenfeng', 'Hsin-tien-tzu,Wenfeng,Wenfeng Zhen,Xindianzi,wen feng,wen feng zhen,xin dian zi,文峰,文峰镇,新店子', 31.4049500, 109.2345900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14258, 'Xindian', 'Xindian', 'Hsin-tien,Hsingtien,Sintien,Xindian', 36.7975000, 118.2944400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14259, 'Xindian', 'Xindian', 'Xindian,xin dian,辛店', 33.4135900, 113.3720900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14260, 'Xindian', 'Xindian', 'Hsin-tien,Xindian,Xindian Zhen,xin dian,xin dian zhen,新店,新店镇', 32.2719300, 120.9236400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14261, 'Xindian', 'Xindian', 'Hsin-tien,Hsin-tien-chen,Sintienchen,Xindian,Xindian Zhen,xin dian,xin dian zhen,新店,新店镇', 29.6461200, 113.6771700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14262, 'Xindian', 'Xindian', 'Hsin-tien,Xindian,Xindian Zhen,xin dian,xin dian zhen,新店,新店镇', 26.1223800, 119.3015300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14263, 'Xindian', 'Xindian', 'Hsin-tien,Xindian,Xindian Zhen,xin dian,xin dian zhen,新店,新店镇', 24.6100600, 118.2406800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14264, 'Xindi', 'Xindi', 'Honghu,Hsin-ti,Hsin-ti-chen,Hung-hu,Jingsee,Shin-ti,Sing Ti,Singti,Sinti,Xindi', 29.8166700, 113.4666700, 'CN', '2015-11-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14265, 'Xindeng', 'Xindeng', 'Ch''eng-yang-chen,Chengyang,Ch’eng-yang-chen,Hsin-ch''eng,Hsin-ch’eng,Hsin-teng,Hsin-teng-hsien,Hsin-teng-hsien-ch''eng,Hsin-teng-hsien-ch’eng,Sin-cheng-hsien,Sincheng Che,Sinteng,Sintenghsien,Xindeng,Xindeng Zhen,xin deng,xin deng zhen,新登,新登镇', 29.9713200, 119.7289200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14266, 'Xindai', 'Xindai', 'Hsin-tai,Hsin-tai-chen,Xindai,Xindai Zhen,xin dai,xin dai zhen,新埭,新埭镇', 30.8230300, 121.0824300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14267, 'Xincun', 'Xincun', 'Hsin-ts''un,Hsin-ts''un-shih,Hsin-ts’un,Hsin-ts’un-shih,Tsunten,Xincun,Xincun Zhen,xin cun,xin cun zhen,新村,新村镇', 18.4161200, 109.9639600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14268, 'Xinchong', 'Xinchong', 'Xinchong,Xinchong Zhen,xin chong,xin chong zhen,新冲镇,辛冲', 30.7747400, 114.8154400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14269, 'Xinchengpu', 'Xinchengpu', 'Fu-ch''eng-i,Fu-ch’eng-i,Hsin-ch''eng-p''u,Hsin-ch’eng-p’u,Sin''chenpu,Sin’chenpu,Xinchengpu,Xinchengpu Zhen,xin cheng pu,xin cheng pu zhen,新城铺,新城铺镇', 38.2678600, 114.6831800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14270, 'Xincheng', 'Xincheng', 'Hsin-ch''ang,Hsin-ch''eng,Hsin-ch’ang,Hsin-ch’eng,Sin-cheng,Xincheng,Xincheng Zhen,xin cheng,xin cheng zhen,新城,新城镇', 38.9830600, 117.5558300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14271, 'Xinchengzi', 'Xinchengzi', 'Hsin-ch''eng,Hsin-ch’eng,Xincheng,Xinchengzi,Xinchengzi Zhen,xin cheng zi,xin cheng zi zhen,新城子,新城子镇', 38.1833300, 101.6000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14272, 'Feicheng', 'Feicheng', 'Fei-ch''eng-hsien,Fei-ch’eng-hsien,Feicheng,Feychen,Xincheng', 36.2486100, 116.7658300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14273, 'Xincheng', 'Xincheng', 'Liu-chang,Liu-chang-chen,Liu-chang-ts''un,Liu-chang-tsun-chen,Liu-chang-ts’un,Liuzhang,Liuzhangzhen,Xincheng,Xincheng Zhen,Yuan-ch''u,Yuan-ch’ü,Yuangqu,Yuangqu Xian,xin cheng,xin cheng zhen,yuan qu xian,垣曲县,新城,新城镇', 35.3000000, 111.6641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14274, 'Xincheng', 'Xincheng', 'Hsin-ch''eng,Hsin-ch’eng,Lin-t''an,Lin-t’an,Lintanhsien,T''ao-chou,Taochow,Taochzhou,T’ao-chou,Xincheng,xin cheng,新城', 34.6743100, 103.5868000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14275, 'Xincheng', 'Xincheng', 'Hsin-ch''eng,Hsin-ch’eng,Xincheng,Xincheng Zhen,xin cheng,xin cheng zhen,新城,新城镇', 32.3495000, 113.1957600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14276, 'Xincheng', 'Xincheng', 'Hsin-ch''eng,Hsin-ch''eng-chen,Hsin-ch’eng,Hsin-ch’eng-chen,Xincheng,Xincheng Zhen,xin cheng,xin cheng zhen,新城,新城镇', 32.2876900, 119.2331300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14277, 'Xincheng', 'Xincheng', 'Hsin-ch''eng,Hsin-ch’eng,Xincheng,Xincheng Zhen,xin cheng,xin cheng zhen,新城,新城镇', 31.4872100, 114.2657700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14278, 'Xincheng', 'Xincheng', 'Chao-chiao-hsien,Chao-chio,Chao-chueh,Chao-chüeh,Chaokioh,Xincheng,Zhaojue,xin cheng,新城', 28.0151200, 102.8423300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14279, 'Chengdong', 'Chengdong', 'Chengdong,Gutian,Ku-t''ien,Ku-t''ien-hsien,Ku-t''ien-hsien-ch''eng,Ku-t’ien,Ku-t’ien-hsien,Ku-t’ien-hsien-ch’eng,Lo-hua,Xincheng,cheng dong,xin cheng,城东,新城', 26.5786100, 118.7386100, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14280, 'Xincheng Chengguanzhen', 'Xincheng Chengguanzhen', 'Hsin-ch''eng,Hsin-ch''eng-hsien,Hsin-ch’eng,Hsin-ch’eng-hsien,Sincheng,Sincheng-hsien,Xincheng,Xincheng Chengguanzhen,xin cheng cheng guan zhen,忻城城关镇', 24.0861300, 108.6526100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14281, 'Xinshi', 'Xinshi', 'Hsin-ch''ang,Hsin-ch’ang,Xinshi,Xinshi Zhen,xin shi,xin shi zhen,新市,新市镇', 29.9599600, 107.1040800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14282, 'Xinchang', 'Xinchang', 'Hsin-ch''ang,Hsin-ch’ang,Sinchang,Xinchang,Xinchang Zhen,xin chang,xin chang zhen,新厂,新厂镇', 29.8924200, 112.4282800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14283, 'Xinchang Chengguanzhen', 'Xinchang Chengguanzhen', 'Chengguan Zhen,Hsin-ch''ang,Hsin-ch''ang-hsien,Hsin-ch''ang-hsien-ch''eng,Hsin-ch’ang,Hsin-ch’ang-hsien,Hsin-ch’ang-hsien-ch’eng,Sinchang,Sinchanghsien,Xinchang Chengguanzhen,cheng guan zhen,xin chang cheng guan zhen,城关镇,新昌城关镇', 29.5052800, 120.9001700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14284, 'Sanbu', 'Sanbu', 'Hsichang,Hsin-ch''ang,Hsin-ch''ang-fou,Hsin-chiang,Hsin-ch’ang,Hsin-ch’ang-fou,K''ai-p''ing,K’ai-p’ing,San-fou-chen,Sanbu,Sanbu Jiedao,Sunchang,Sunchong,Xinchang,san bu,san bu jie dao,三埠,三埠街道', 22.3613600, 112.6876900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14285, 'Xincang', 'Xincang', 'Hsin-ts''ang,Hsin-ts''ang-chen,Hsin-ts’ang,Hsin-ts’ang-chen,Xincang,Xincang Zhen,xin cang,xin cang zhen,新仓,新仓镇', 30.7315100, 121.1757700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14286, 'Xincai', 'Xincai', 'Ching-fu,Gulu,Gulü,Hsin-ts''ai,Hsin-ts''ai-hsien,Hsin-ts’ai,Hsin-ts’ai-hsien,Sintsai-hsien,Xincai,gu lu,古吕', 32.7438900, 114.9761100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14287, 'Xinbuzi', 'Xinbuzi', 'Hsin-p''u-tzu,Hsin-pao-tzu,Hsin-p’u-tzu,Xinbuzi,xin bao zi,新堡子', 34.9859900, 108.0864600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14288, 'Xinbu', 'Xinbu', 'Hsin-p''u,Hsin-pao,Hsin-p’u,Hsin-t''un-p''u,Hsin-t''un-pao,Hsin-t’un-pao,Hsin-t’un-p’u,Xinbu,Xinbu Xiang,xin bao,xin bao xiang,新堡,新堡乡', 38.6050000, 111.9390900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14289, 'Xinbu', 'Xinbu', 'Hsin-p''u,Hsin-p''u-hsu,Hsin-p’u,Hsin-p’u-hsü,Sunpu,Xinbu,Xinpu Zhen,xin pu,xin pu zhen,新铺,新铺镇', 24.5117000, 116.1248100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14290, 'Xinbao', 'Xinbao', 'Xinbao,xin bao,新堡', 34.5741800, 103.6153000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14291, 'Xinbang', 'Xinbang', 'Hsin-chung-pang,Hsin-pang,Xinbang,Xinbang Zhen,xin bang,xin bang zhen,新浜,新浜镇', 30.9346700, 121.0614700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14292, 'Xinba', 'Xinba', 'Hsin-pa,Xinba,Xinba Zhen,xin ba,xin ba zhen,新坝,新坝镇', 34.4402800, 119.1311100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14293, 'Xinba', 'Xinba', 'Hsin-pa,Hsin-pa-chen,Xinba,Xinba Zhen,xin ba,xin ba zhen,新坝,新坝镇', 32.2636400, 119.7536900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14294, 'Xin’an', 'Xin''an', 'Xin''an,Xin''an Xiang,Xin''anzhou,Xin’an,Xin’an Xiang,Xin’anzhou,xin an,xin an xiang,新安,新安乡', 29.8875500, 117.2803800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14295, 'Xin’an', 'Xin''an', 'Hsin-an-chen,Xin''an,Xin''an Zhen,Xin''anzhen,Xin’an,Xin’an Zhen,Xin’anzhen,xin an,xin an zhen,新安,新安镇', 31.7978600, 121.7808500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14296, 'Xin’anjiang', 'Xin''anjiang', 'Hsin-an-chiang,Jiande Shi,Xin''anjiang,Xin''anjiang Jiedao,Xin’anjiang,Xin’anjiang Jiedao,jian de shi,xin an jiang,xin an jiang jie dao,建德市,新安江,新安江街道', 29.4747800, 119.2714800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14297, 'Xin’an', 'Xin''an', 'Hsin-an,Xin''an,Xin''an Zhen,Xin’an,Xin’an Zhen,xin an,xin an zhen,新安,新安镇', 38.2248700, 114.6068500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14298, 'Xin’an Chengguanzhen', 'Xin''an Chengguanzhen', 'Hsin-an,Hsin-an-hsien,Si-nan,Xin''an,Xin''an Chengguanzhen,Xin’an,Xin’an Chengguanzhen,xin an cheng guan zhen,新安城关镇', 34.7175000, 112.1355600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14299, 'Xin’an', 'Xin''an', 'Lai''an,Lai-an-hsien,Lai’an,Lia-an,Xin''an,Xin’an,xin an,新安', 32.4379900, 118.4088800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14300, 'Xin’an', 'Xin''an', 'Gaoxing,Hsin-an,Xin''an,Xin''an Zhen,Xin’an,Xin’an Zhen,gao xing,xin an,xin an zhen,新安,新安镇,高兴', 29.6500000, 111.5000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14301, 'Xinan', 'Xinan', 'Hsi-nan,Nan-an,Xinan', 26.7200000, 119.8555600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14302, 'Xinan', 'Xinan', 'Hsi-nan,Xinan,Xinan Zhen,xi nan,xi nan zhen,溪南,溪南镇', 25.4000600, 117.5737600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14303, 'Sanshui', 'Sanshui', 'Hsi-man,Hsi-nan-chen,Hsin-nan,Sainam,Sainan,Sanshui,Xinan,san shui,三水', 23.1548600, 112.8916100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14304, 'Xin’an', 'Xin''an', 'Hsin-an,Xin''an,Xin’an,xin an,新庵', 23.1208600, 115.1909000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14305, 'Xin’an', 'Xin''an', 'Hsi-hsiang,Saiheung,Xin''an,Xin''an Jiedao,Xin’an,Xin’an Jiedao,Xixiang,xin an,xin an jie dao,新安,新安街道', 22.5727400, 113.9161500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14306, 'Xin’an', 'Xin''an', 'Xin''an,Xin''an Zhen,Xin’an,Xin’an Zhen,xin an,xin an zhen,新安,新安镇', 21.6493500, 110.4309700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14307, 'Xinli', 'Xinli', 'Hang-chin-ch''i,Hang-chin-ch’i,Hanggin Qi,Hsi-ni-chen,O-erh-to-ssu-yu-i-hou-ch''i,O-erh-to-ssu-yu-i-hou-ch''i-pei-lo-miao,O-erh-to-ssu-yu-i-hou-ch’i,O-erh-to-ssu-yu-i-hou-ch’i-pei-lo-miao,Xini Zhen,Xinli,hang jin qi,xi ni,xi ni zhen,杭锦旗,锡尼,锡尼镇', 39.8441700, 108.7347200, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14308, 'Ximei', 'Ximei', 'Ch''i-mei-chen,Ch''i-wei,Ch’i-mei-chen,Ch’i-wei,Naman,Nan''an,Nan-an-hsien,Nan’an,Ximei,Xizhai,xi mei,西美', 24.9877300, 118.3858000, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14309, 'Ximafang', 'Ximafang', 'Hsi-ma-fang,Ximafang,Ximafang Xiang,xi ma fang,xi ma fang xiang,西马坊,西马坊乡', 38.6638000, 112.0171000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14310, 'Xima', 'Xima', 'Hsi-ma-fan,Xima,Xima Zhen,Ximafan,xi ma,xi ma zhen,洗马,洗马镇', 30.4705200, 115.4742100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14311, 'Xiliuhe', 'Xiliuhe', 'Hsi-liu-ho,Xiliuhe,Xiliuhe Zhen,xi liu he,xi liu he zhen,西流河,西流河镇', 30.3092800, 113.6898700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14312, 'Xiliu', 'Xiliu', 'Hsi-liu,Hsi-liu-ts''un,Hsi-liu-ts’un,Xiliu,Xiliu Xiang,Xiliucun,xi liu,xi liu xiang,西留,西留乡', 39.6831700, 113.5408300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14313, 'Xiling', 'Xiling', 'Hsi-ling,Xiling', 26.8144400, 119.0472200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14314, 'Xilian', 'Xilian', 'Hsi-lien,Xilian,Xilian Zhen,xi lian,xi lian zhen,西连,西连镇', 20.3800300, 109.9454500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14315, 'Xilai', 'Xilai', 'Hsi-lai,Hsi-lai-chen,Xilai,Xilai Zhen,xi lai,xi lai zhen,西来,西来镇', 32.1184900, 120.4275700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14316, 'Xilaiqiao', 'Xilaiqiao', 'Hsi-ch''iao,Hsi-ch''iao-chen,Hsi-ch’iao,Hsi-ch’iao-chen,Hsi-lai-ch''iao,Hsi-lai-ch''iao-chen,Hsi-lai-ch’iao,Hsi-lai-ch’iao-chen,Xilaiqiao,Xilaiqiao Zhen,xi lai qiao,xi lai qiao zhen,西来桥,西来桥镇', 32.0368900, 119.9131200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14317, 'Guxi', 'Guxi', 'Ch''i-k''ou,Ch’i-k’ou,Guxi,Guxi Zhen,Hsi-k''ou,Hsi-k’ou,Xikou,gu xi,gu xi zhen,古溪,古溪镇', 30.6784800, 118.7080800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14318, 'Xikou', 'Xikou', 'Hsi-k''ou,Hsi-k''ou-chen,Hsi-k’ou,Hsi-k’ou-chen,Xikou,Xikou Zhen,xi kou,xi kou zhen,溪口,溪口镇', 29.6852400, 121.2744100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14319, 'Xikou', 'Xikou', 'Ch''i-k''ou,Ch’i-k’ou,Hsi-k''ou,Hsi-k’ou,Shang-ch''i-k''ou,Shang-ch’i-k’ou,Shang-hsi-k''ou,Shang-hsi-k’ou,Shangkikow,Xikou,Xikou Zhen,xi kou,xi kou zhen,溪口,溪口镇', 29.6862500, 118.0095200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14320, 'Xikou', 'Xikou', 'Hsi-k''ou,Hsi-k’ou,Xikou,Xikou Zhen,xi kou,xi kou zhen,溪口,溪口镇', 29.2256400, 110.7582000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14321, 'Xikou', 'Xikou', 'Hsi-k''ou,Hsi-k’ou,Xikou,Xikou Zhen,xi kou,xi kou zhen,溪口,溪口镇', 29.1631200, 114.3757600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14322, 'Xikou', 'Xikou', 'Hsi-k''ou,Hsi-k’ou,Xikou,Xikou Zhen,xi kou,xi kou zhen,溪口,溪口镇', 26.8455600, 116.8323300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14323, 'Xikeng', 'Xikeng', 'Hsi-k''eng,Hsi-k’eng,Xikeng,Xikeng Shezu Zhen,xi keng,xi keng she zu zhen,西坑,西坑畲族镇', 27.8467700, 119.9209500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14324, 'Xitan', 'Xitan', 'Xijitan,Xitan,Xitanxiang,xi ji tan,xi tan,xi tan xiang,西吉滩,西滩,西滩乡', 35.8837900, 105.7416100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14325, 'Xijiao', 'Xijiao', 'Xijiao,Xijiao Xiang,xi jiao,xi jiao xiang,西郊,西郊乡', 36.0095800, 106.2761400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14326, 'Xijiang', 'Xijiang', 'Hsi-chiang,Hsi-chiang-hsu,Hsi-chiang-hsü,Hsi-chiang-shih,Sikiangshih,Xijiang,Xijiang Zhen,xi jiang,xi jiang zhen,西江,西江镇', 25.8373100, 115.7805600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14327, 'Xijiang', 'Xijiang', 'Hsi-chiang,Hsi-chiang-hsu,Hsi-chiang-hsü,Xijiang,Xijiang Zhen,xi jiang,xi jiang zhen,西江,西江镇', 24.7547000, 112.5840100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14328, 'Xijiadian', 'Xijiadian', 'Hsi-chia-tien,Xijiadian,Xijiadian Zhen,xi jia dian,xi jia dian zhen,习家店,习家店镇', 32.7523500, 111.1786300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14329, 'Xijia', 'Xijia', 'Hsi-chia,Xijia,Xijia Xiang,xi gu,xi gu xiang,西贾,西贾乡', 35.8086000, 111.3252200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14330, 'Xiji', 'Xiji', 'Hsi-chi,Hsi-chi-chen,Xiji,Xiji Zhen,xi ji,xi ji zhen,西集,西集镇', 39.8138500, 116.8774500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14331, 'Xihuaiba', 'Xihuaiba', 'Hsi-huai-pa,Hsi-t''an-pa,Hsi-t’an-pa,Xihuaiba,xi huai ba,西淮坝', 33.5257500, 105.9185400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14332, 'Xihuachi', 'Xihuachi', 'Heshui,Heshui Xian,Ho-shui,Hsi-hua,Hsi-hua-ch''ih,Hsi-hua-ch’ih,Hsi-hua-i,Xihuachi,he shui xian,xi hua chi,合水县,西华池', 35.8163900, 108.0125000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14333, 'Wacheng', 'Wacheng', 'Hsi-hua,Hsi-hua-hsien,Sihwahsien,Sikhua,Wacheng,Xihua,wa cheng,娲城', 33.7833300, 114.5166700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14334, 'Xihu', 'Xihu', 'Hsi-hu,Xihu,Xihu Xiang,xi hu,xi hu xiang,西湖,西湖乡', 29.8494900, 117.1791800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14335, 'Xihongmen', 'Xihongmen', 'Hsi-hung-men,Hsi-ta-hung-men,Xihongmen,Xihongmen Zhen,xi hong men,xi hong men zhen,西红门,西红门镇', 39.7906000, 116.3445800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14336, 'Xihe', 'Xihe', 'Hsi-ho,Hsi-ho-chen,Sihochen,Xihe,Xihe Zhen,xi he,xi he zhen,淅河,淅河镇', 31.6863500, 113.4658500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14337, 'Xihe', 'Xihe', 'Hsi-ho,Hsi-ho-chen,Xihe,Xihe Zhen,xi he,xi he zhen,西河,西河镇', 30.9917500, 118.4746600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14338, 'Xigang', 'Xigang', 'Helan,Helan Xian,Ho-lan,Ho-lan-hsien,Hsi-kang,Hsieh-kang-pao,Xigang,he lan xian,xi gang,习岗,贺兰县', 38.5525800, 106.3480500, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14339, 'Xigang', 'Xigang', 'Xigang,Xigang Zhen,xi gang,xi gang zhen,西港,西港镇', 29.0921000, 114.4017900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14340, 'Nanjie', 'Nanjie', 'Hsi-feng-chen,Nanjie,Si-fong-tschon,Si-föng-tschön,Sifengchen,Sifonchzhen'',Sifynchzhen'',Sifynchzhen’,Sifönchzhen’,Xifeng,Xifeng Qu,Xifengzhen,nan jie,xi feng qu,南街,西峰区', 35.7355600, 107.6352800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14341, 'Xifangcheng', 'Xifangcheng', 'Hsi-fang-ch''eng,Hsi-fang-ch’eng,Xifangcheng,Xifangcheng Zhen,xi fang cheng,xi fang cheng zhen,西坊城,西坊城镇', 39.6121700, 113.4813900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14342, 'Xietang', 'Xietang', 'Hsieh-chia-t''ang,Hsieh-chia-t’ang,Hsieh-t''ang,Hsieh-t’ang,Xietang,Xietang Zhen,xie tang,xie tang zhen,谢塘,谢塘镇', 30.1219000, 120.9011000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14343, 'Xietan', 'Xietan', 'Hsieh-t''an,Hsieh-t’an,Xietan,Xietan Zhen,xie tan,xie tan zhen,斜滩,斜滩镇', 27.3236500, 119.5312900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14344, 'Xieqiao', 'Xieqiao', 'Hsieh-ch''iao,Hsieh-ch''iao-chen,Hsieh-ch’iao,Hsieh-ch’iao-chen,Xieqiao,Xieqiao Zhen,xie qiao,xie qiao zhen,斜桥,斜桥镇', 32.0616900, 120.3836300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14345, 'Xieqiao', 'Xieqiao', 'Hsieh-ch''iao,Hsieh-ch''iao-chen,Hsieh-ch’iao,Hsieh-ch’iao-chen,Xieqiao,Xieqiao Zhen,xie qiao,xie qiao zhen,斜桥,斜桥镇', 30.4887300, 120.5680500, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14346, 'Xiepu', 'Xiepu', 'Hsieh-fu,Hsieh-p''u,Hsieh-p''u-chen,Hsieh-p’u,Hsieh-p’u-chen,Xiepu,Xiepu Zhen,xie pu,xie pu zhen,澥浦,澥浦镇', 30.0245700, 121.5938200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14347, 'Xiema', 'Xiema', 'Hsieh-ma-ho,Siehimaho,Siehmaho,Xiema,Xiema Zhen,Xiemahe,xie ma,xie ma zhen,歇马,歇马镇', 31.6181400, 111.1718200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14348, 'Xiema', 'Xiema', 'Hsieh-ma-ch''ang,Hsieh-ma-ch’ang,Xiema,Xiema Zhen,Xiemachang,xie ma,xie ma zhen,歇马,歇马镇', 29.7741500, 106.3688000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14349, 'Xiekou', 'Xiekou', 'Hsieh-k''ou,Hsieh-k''ou-chen,Hsieh-k’ou,Hsieh-k’ou-chen,Xiekou,xie kou,斜口', 34.3608900, 109.1530800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14350, 'Xiejiaya', 'Xiejiaya', 'Xiejiaya,Xiejiaya Xiang,xie jia ya,xie jia ya xiang,谢家垭,谢家垭乡', 28.9833300, 110.6666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14351, 'Xiejiatan', 'Xiejiatan', 'Hsieh-chia-t''an,Hsieh-chia-t’an,Xiejiatan,Xiejiatan Zhen,xie jia tan,xie jia tan zhen,谢家滩,谢家滩镇', 29.4876500, 116.7119500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14352, 'Xiejiapu', 'Xiejiapu', 'Hsieh-chia-p''u,Hsieh-chia-p’u,Xiejiapu,Xiejiapu Zhen,xie jia pu,xie jia pu zhen,谢家铺,谢家铺镇', 28.8333300, 111.8000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14353, 'Xieji', 'Xieji', 'Hsieh-chi,Hsieh-chia-chi,Xieji,Xieji Xiang,Xiejiaji,xie ji,xie ji xiang,谢集,谢集乡', 32.4261300, 119.1314700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14354, 'Xieji', 'Xieji', 'Hsieh-chi,Hsieh-chi-hsu,Hsieh-chi-hsü,Xieji,Xieji Zhen,xie ji,xie ji zhen,谢鸡,谢鸡镇', 21.9166700, 110.9833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14355, 'Xiehu', 'Xiehu', 'Hsieh-hu,Hsieh-hu-chen,Xiehu,Xiehu Zhen,xie hu,洩湖', 34.2041700, 109.2456100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14356, 'Xiefang', 'Xiefang', 'Hsieh-fang,Hsieh-fang-hsu,Hsieh-fang-hsü,Hsieh-fang-ts''un,Hsieh-fang-ts’un,Siehfang,Xiefang,Xiefang Zhen,xie fang,xie fang zhen,谢坊,谢坊镇', 25.7065400, 115.8656200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14357, 'Xiedian', 'Xiedian', 'Chieh-tien,Chieh-tien-chen,Hsieh-tien,Hsieh-tien-chen,Wan-ch''uan,Wan-ch’üan,Wan-jung,Wanrong,Wanrong Xian,Xiedian,Xiedian Zhen,jie dian,jie dian zhen,wan rong xian,万荣县,解店,解店镇', 35.4281600, 110.8118100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14358, 'Xieba', 'Xieba', 'Hsieh-pa,Xieba,Xieba Gelaozu Miaozu Xiang,xie ba,xie ba ge lao zu miao zu xiang,谢坝,谢坝仡佬族苗族乡', 28.2111100, 107.5669400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14359, 'Xidu', 'Xidu', 'Heng-yang,Hsi-tu,Xidu,xi du,西渡', 26.9562900, 112.3682900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14360, 'Xiditou', 'Xiditou', 'Hai-ti-t''ou,Hai-ti-t’ou,Hsi-ti-t''ou,Hsi-ti-t’ou,Xiditou,Xiditou Zhen,xi di tou,xi di tou zhen,西堤头,西堤头镇', 39.2537500, 117.3481400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14361, 'Xidian', 'Xidian', 'Hsi-tien,Hsi-tien-chen,Xidian,Xidian Zhen,xi dian,xi dian zhen,西店,西店镇', 29.4905100, 121.4330300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14362, 'Xidi', 'Xidi', 'Hsi-ti,Xidi,Xidi Zhen,xi di,xi di zhen,西递,西递镇', 29.9072200, 117.9924100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14363, 'Xicun', 'Xicun', 'Hsi-ts''un,Hsi-ts’un,Xicun,Xicun Zhen,xi cun,xi cun zhen,西村,西村镇', 27.7551200, 114.2178800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14364, 'Hexi', 'Hexi', 'Hexi,Hexi Zhen,Ho-hsi,Ho-hsi-hsien,Hosi,Hosihsien,Hsi-ch''eng,Hsi-ch’eng,Xicheng,he xi,he xi zhen,河西,河西镇', 24.1436100, 102.6486100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14365, 'Xichehe', 'Xichehe', 'Hsi-ch''e,Hsi-ch''e-ho,Hsi-ch’e,Hsi-ch’e-ho,Hsi-tung,Sicheshih,Xiche,Xichehe,Xichehe Zhen,xi che he,xi che he zhen,洗车河,洗车河镇', 29.0711200, 109.5332100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14366, 'Xichang', 'Xichang', 'Hsi-ch''ang,Hsi-ch''ang-hsien,Hsi-ch’ang,Hsi-ch’ang-hsien,Ning-yuan,Ning-yüan,Ningyuanfu,Sichan,Sichang,Sichanghsien,XIC,Xichang,sichang,xi chang,xi chang shi,Сичан,西昌,西昌市,ꀒꎂ,시창', 27.8964200, 102.2634100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14367, 'Xibu', 'Xibu', 'Hsi-fou,Hsi-pu,Xibu,Xibu Zhen,xi bu,xi bu zhen,西埠,西埠镇', 31.7783700, 118.2849200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14368, 'Xibu', 'Xibu', 'Dongshan,Hsi-pu,Hsi-pu-chen,Hsi-pu-hsu,Hsi-pu-hsü,Tung-shan,Xibu,Xipu,xi bu,西埔', 23.6990600, 117.4251100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14369, 'Xibing', 'Xibing', 'Ch''i-ping,Ch’i-ping,Hsi-ping,Xibing', 26.9813900, 119.7247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14370, 'Yukou', 'Yukou', 'Hsia-chuang,Xiazhuang,Yu-k''ou-ts''un,Yukou,Yukou Xiang,Yü-k’ou-ts’un,yu kou,yu kou xiang,峪口,峪口乡', 39.0548200, 113.0456000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14371, 'Xiazhuang', 'Xiazhuang', 'Hsia-chuang,Hsia-chuang-chen,Linshu,Xiazhuang', 34.9161100, 118.6388900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14372, 'Xiazhu', 'Xiazhu', 'Xiazhu,Xiazhu Xiang,xia zhu,xia zhu xiang,下祝,下祝乡', 26.4934000, 118.9898200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14373, 'Xiazhen', 'Xiazhen', 'Hsia-chen,Weishan,Xiazhen,Xiazhencun', 34.8022200, 117.1116700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14374, 'Xiazhen', 'Xiazhen', 'Hsia-chen,Xiazhen,Xiazhen Zhen,xia zhen,xia zhen zhen,下镇,下镇镇', 28.6461000, 118.4024400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14375, 'Xiazhai', 'Xiazhai', 'Hsia-chai,Hsia-chai-tzu,Xiazhai,Xiazhai Zhen,xia zhai,下寨', 34.7145300, 109.7650500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14376, 'Xia Zanggor', 'Xia Zanggor', 'Jiangqian,Xia Zanggor,Xiacangke,Xiacangke Xiang,jiang qian,xia cang ke,xia cang ke xiang,下藏科,下藏科乡,江千', 34.0675200, 100.6987800, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14377, 'Xiayunling', 'Xiayunling', 'Hsia-yun-ling,Xiayunling,Xiayunling Xiang,xia yun ling,xia yun ling xiang,霞云岭,霞云岭乡', 39.7242400, 115.7362800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14378, 'Xiayong', 'Xiayong', 'Hsia-yung,Xiayong,Xiayong Jiedao,Xiayong Zhen,xia yong,xia yong jie dao,霞涌,霞涌街道', 22.7879300, 114.6485000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14379, 'Chezhan', 'Chezhan', 'Chezhan,Chezhan Zhen,Hsia-i-chan,Xiayizhan,Xiayizhen,che zhan,che zhan zhen,车站,车站镇', 34.4025000, 116.0244400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14380, 'Xiayi Chengguanzhen', 'Xiayi Chengguanzhen', 'Hsia-i,Hsia-i-hsien,Siayihsien,Xiayi,Xiayi Chengguanzhen,xia yi cheng guan zhen,夏邑城关镇', 34.2368000, 116.1160800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14381, 'Xiayang', 'Xiayang', 'Hsia-yang,Siayang,Xiayang,Xiayang Zhen,xia yang,xia yang zhen,峡阳,峡阳镇', 26.7736300, 117.9933100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14382, 'Xiayang', 'Xiayang', 'Hsia-yang,Xiayang,Xiayang Xiang,xia yang,xia yang xiang,夏阳,夏阳乡', 26.4287600, 117.4541700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14383, 'Xiayang', 'Xiayang', 'Hsia-yang,Xiayang,Xiayang Zhen,xia yang,xia yang zhen,下洋,下洋镇', 25.4955600, 117.9983300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14384, 'Xiayang', 'Xiayang', 'Hsia-yang,Xiayang,Xiayang Zhen,xia yang,xia yang zhen,下洋,下洋镇', 24.6016800, 116.8333500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14385, 'Yaofeng', 'Yaofeng', 'Hsia-chen,Hsia-hsien,Hsia-hsien-ch''eng,Hsia-hsien-ch’eng,Siahsien,Xia Xian,Xiaxian,Yaofeng,Yaofeng Zhen,xia xian,yao feng,yao feng zhen,夏县,瑶峰,瑶峰镇', 35.1386100, 111.2122200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14386, 'Xiawuqi', 'Xiawuqi', '', 39.6136100, 117.0533300, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14387, 'Xiatuanpu', 'Xiatuanpu', 'Hsia-t''uan-pao,Hsia-t’uan-pao,Xiatuanpu,Xiatuanpu Xiang,xia tuan bao,xia tuan bao xiang,下团堡,下团堡乡', 39.3602800, 112.3766700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14388, 'Xiatang', 'Xiatang', 'Hsia-t''ang,Hsia-t''ang-chen,Hsia-t’ang,Hsia-t’ang-chen,Hsia-yang,Hsia-yang-chen,Xiatang,Xiatang Zhen,xia tang,xia tang zhen,下汤,下汤镇', 33.7198700, 112.6798000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14389, 'Xiashuitou', 'Xiashuitou', 'Hsia-shui-t''ou,Hsia-shui-t’ou,Xiashuitou,Xiashuitou Xiang,xia shui tou,xia shui tou xiang,下水头,下水头乡', 39.5277300, 112.0818600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14390, 'Xiashu', 'Xiashu', 'Hsia-shu,Hsia-shu-chieh,Siashu,Xiashu,Xiashu Zhen,xia shu,xia shu zhen,下蜀,下蜀镇', 32.1732900, 119.1859800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14391, 'Xiashi', 'Xiashi', 'Hai-ning-hsien,Haining,Hsia-shih,Hsia-shih-chen,Siashih,Xiashi,Xiashi Jiedao,xia shi,xia shi jie dao,硖石,硖石街道', 30.5362900, 120.6863800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14392, 'Xiashe', 'Xiashe', 'Hsia-she,Hsia-she-ts''un,Hsia-she-ts’un,Xiahe,Xiashe,Xiashe Zhen,xia she,xia she zhen,下社,下社镇', 39.5141700, 113.2930600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14393, 'Xiashan', 'Xiashan', 'Ho-shan-chen,Qiangjiao,Qiangjiao Zhen,Xiashan,Xiashanzhen,qiang jiao zhen,xia shan,峡山,强蛟镇', 29.4647700, 121.5305100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14394, 'Xiashan', 'Xiashan', 'Hapshan,Hsia-shan,Hsia-shan-hsu,Hsia-shan-hsü,Xiashan,Xiashan Jiedao,Xiashanzhen,xia shan,xia shan jie dao,峡山,峡山街道', 23.2498100, 116.4271200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14395, 'Xiaruyue', 'Xiaruyue', 'Hsia-ju-yueh,Hsia-ju-yüeh,Xiaruyue,Xiaruyue Xiang,xia ru yue,xia ru yue xiang,下茹越,下茹越乡', 39.2120000, 113.3574100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14396, 'Xiaqu', 'Xiaqu', 'Xiaqu,Xiaqu Xiang,xia qu,xia qu xiang,下渠,下渠乡', 26.8237000, 117.1565400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14397, 'Xiaqiu', 'Xiaqiu', 'Hsia-ch''iu,Hsia-ch''iu-p''u,Hsia-ch''iu-pao,Hsia-ch’iu,Hsia-ch’iu-pao,Hsia-ch’iu-p’u,Xiaqiu,Xiaqiu Zhen,Xiaqiubao,Xiaqiupu,xia qiu,xia qiu zhen,夏邱,夏邱镇', 37.0076200, 119.9023000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14398, 'Xiaqiaotou', 'Xiaqiaotou', 'Ch''iao-t''ou,Ch’iao-t’ou,Hutiaoxia,Hutiaoxia Zhen,Qiaotou,Xiaqiaotou,hu tiao xia,hu tiao xia zhen,xia qiao tou,下桥头,虎跳峡,虎跳峡镇', 27.1853400, 100.0433700, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14399, 'Xiaqiao', 'Xiaqiao', 'Hakiu,Hsia-ch''iao,Hsia-ch''iao-hsu,Hsia-ch''iao-shih,Hsia-ch’iao,Hsia-ch’iao-hsü,Hsia-ch’iao-shih,Xiaqiao,Xiaqiao Zhen,xia qiao,xia qiao zhen,下桥,下桥镇', 20.4484900, 110.1326400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14400, 'Xiapu', 'Xiapu', 'Hsia-p''u,Hsia-p’u,Xiapu,Xiapu Zhen,sha pu,sha pu zhen,厦铺,厦铺镇', 29.5144100, 114.4642300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14401, 'Xiapu', 'Xiapu', 'Hsia-p''u,Hsia-p’u,Xiapu,Xiapu Xiang,xia pu,xia pu xiang,下浦,下浦乡', 27.7964200, 114.4431600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14402, 'Xiaozhou', 'Xiaozhou', 'Hsiao-chou,Xiaozhou,Xiaozhou Xiang,xiao zhou,xiao zhou xiang,小洲,小洲乡', 29.7721700, 118.5786100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14403, 'Xiaozhan', 'Xiaozhan', 'Hsiao-chan,Hsin-ch''ing-chen,Hsin-ch’ing-chen,Hsin-nung,Hsin-nung-chen,Siaochan,Xiaozhan,Xiaozhan Zhen,xiao zhan,xiao zhan zhen,小站,小站镇', 38.9102100, 117.4270400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14404, 'Xiaozhai', 'Xiaozhai', 'Hsiao-chai,Xiaozhai,xiao zhai,小寨', 34.0456600, 109.2871400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14405, 'Xiaoyue', 'Xiaoyue', 'Hsiao-yueh,Hsiao-yueh-chen,Hsiao-yüeh,Hsiao-yüeh-chen,Xiaoyue,Xiaoyue Zhen,xiao yue,xiao yue zhen,小越,小越镇', 30.0712200, 120.9279600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14406, 'Zijinglu', 'Zijinglu', 'Gongyi,Hsiao-i,Hsiao-i-chen,Kung-hsien,Xiaoyi,Zijinglu,zi jing lu,紫荆路', 34.7600000, 112.9713900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14407, 'Xiaoyi', 'Xiaoyi', 'Hsiao-i,Hsiao-i-chen,Xiaoyi,Xiaoyi Zhen,xiao yi,孝义', 34.6177800, 109.7030100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14408, 'Xiaoyan', 'Xiaoyan', 'Hsiao-yen,Xiaoyan,Xiaoyan Zhen,xiao yan,xiao yan zhen,肖堰,肖堰镇', 31.4884800, 111.7656800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14409, 'Xiaoya', 'Xiaoya', 'Luotongzhai,Xiaoya,Xiaoya Zhen,luo tong zhai,xiao ya,xiao ya zhen,小雅,小雅镇,骆通宅', 28.4894700, 107.2175400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14410, 'Xiaoxita', 'Xiaoxita', 'Hsiao-hsi-t''a,Hsiao-hsi-t''a-shih,Hsiao-hsi-t’a,Hsiao-hsi-t’a-shih,I-ch''ang,I-ch’ang,Xiaoxita,Xiaoxita Jiedao,Yichang,Yichang Xian,xiao xi ta,xiao xi ta jie dao,yi chang,yi chang xian,宜昌,宜昌县,小溪塔,小溪塔街道', 30.7713500, 111.3214600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14411, 'Xiaoxi', 'Xiaoxi', 'Hsiao-hsi,Xiaoxi,Xiaoxi Xiang,xiao xi,xiao xi xiang,小溪,小溪乡', 25.7704000, 115.3299000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14412, 'Xiaoxi', 'Xiaoxi', 'Hsiao-ch''i,Hsiao-ch''i-chen,Hsiao-ch’i,Hsiao-ch’i-chen,P''ing-ho,Pinghe,P’ing-ho,Xiaoxi,xiao xi,小溪', 24.3524900, 117.2907100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14413, 'Xiaoweizhai', 'Xiaoweizhai', '', 26.1902800, 107.5125000, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14414, 'Xiaowangzhuang', 'Xiaowangzhuang', 'Xiaowangzhuang,Xiaowangzhuang Zhen,xiao wang zhuang,xiao wang zhuang zhen,小王庄,小王庄镇', 38.7512700, 117.1543400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14415, 'Xiaowangmiao', 'Xiaowangmiao', 'Hsiao-wang-miao,Hsiao-wang-miao-shih,Xiaowangmiao,Xiaowangmiao Zhen,xiao wang miao,xiao wang miao zhen,萧王庙,萧王庙镇', 29.7013900, 121.3558300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14416, 'Xiaotian', 'Xiaotian', 'Hsiao-t''ien,Hsiao-t’ien,Xiaotian,Xiaotian Xiang,Xiaotian Zhen,xiao tian,xiao tian xiang,xiao tian zhen,肖田,肖田乡,肖田鎮', 27.0420400, 116.0925100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14417, 'Xiaotao', 'Xiaotao', 'Hsiao-t''ao,Hsiao-t''ao-hsu,Hsiao-t’ao,Hsiao-t’ao-hsü,Ning-yang,Ning-yang-hsien,Xiaotao,Xiaotao Zhen,xiao tao,xiao tao zhen,小陶,小陶镇', 25.7307500, 117.1229700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14418, 'Xiaosong', 'Xiaosong', 'Hsiao-sung,Xiaosong,Xiaosong Zhen,xiao song,xiao song zhen,小松,小松镇', 27.1703200, 118.3863200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14419, 'Xiaosong', 'Xiaosong', 'Hsiao-sung,Hsiao-sung-shih,Xiaosong,Xiaosong Zhen,xiao song,xiao song zhen,小松,小松镇', 26.4424200, 116.3055000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14420, 'Xiaoshun', 'Xiaoshun', 'Hsiao-shun,Hsiao-shun-chen,Xiaoshun,Xiaoshun Zhen,xiao shun,xiao shun zhen,孝順鎮,孝顺,孝顺镇', 29.1799700, 119.8698400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14421, 'Xiaoshidian', 'Xiaoshidian', 'Hsiao-shih-tien,Xiaoshidian,Xiaoshidian Zhen,xiao shi dian,xiao shi dian zhen,小史店,小史店镇', 33.1551200, 113.3200900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14422, 'Shangqiao', 'Shangqiao', 'Hsiao-shang-ch''iao,Hsiao-shang-ch''iao-pei-chai,Hsiao-shang-ch’iao,Hsiao-shang-ch’iao-pei-chai,Shangqiao,Shangqiao Zhen,Xiaoshangqiao,shang qiao,shang qiao zhen,商桥,商桥镇', 33.7059800, 113.9566700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14423, 'Xiaoshan', 'Xiaoshan', 'Hsiao-chan,Hsiao-chi-shan,Hsiao-shan,Hsiao-shan-hsien,Hsiao-shan-hsien-ch''eng,Hsiao-shan-hsien-ch’eng,Siaoshan,Siaoshanhsien,Sjaoshan'',Xiaoshan,Xiaoshan Xian,xiao shan,xiao shan xian,Сяошань,萧山,萧山县', 30.1674600, 120.2588300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14424, 'Shakou', 'Shakou', 'Hsiao-sha-k''ou,Hsiao-sha-k’ou,Shakou,Shakou Zhen,Xiaoshakou,sha kou,sha kou zhen,沙口,沙口镇', 29.9829700, 113.2855400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14425, 'Xiaoshajiang', 'Xiaoshajiang', 'Hsiao-sha-chiang,Xiaoshajiang,Xiaoshajiang Zhen,xiao sha jiang,xiao sha jiang zhen,小沙江,小沙江镇', 27.5213900, 110.7480600, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14426, 'Xiaosanjiang', 'Xiaosanjiang', 'Hsiao-chiang,Xiaojiang,Xiaosanjiang,Xiaosanjiang Zhen,xiao san jiang,xiao san jiang zhen,小三江,小三江镇', 24.2715300, 112.1287700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14427, 'Xiaoqiu', 'Xiaoqiu', 'Hsiao-ch''iu,Hsiao-ch''iu-chen,Hsiao-ch’iu,Hsiao-ch’iu-chen,Shui-ch''iu-chen,Shui-ch’iu-chen,Xiaoqiu,Xiaoqiu Zhen,Xiaoqu,xiao qiu,xiao qiu zhen,校丘,校丘镇', 34.9094400, 108.7713900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14428, 'Xiaoqiao', 'Xiaoqiao', 'Hsiao-ch''iao,Hsiao-ch’iao,Xiaoqiao,Xiaoqiao Zhen,xiao qiao,xiao qiao zhen,小桥,小桥镇', 26.9538500, 118.4660700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14429, 'Xiaopu', 'Xiaopu', 'Xiaopu,Xiaopu Zhen,xiao pu,xiao pu zhen,小浦,小浦镇', 31.0302500, 119.8310600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14430, 'Xiaopingyi', 'Xiaopingyi', 'Hsiao-p''ing-i,Hsiao-p''ing-i-ts''un,Hsiao-p’ing-i,Hsiao-p’ing-i-ts’un,Xiaopingyi,Xiaopingyi Xiang,xiao ping yi,xiao ping yi xiang,小平易,小平易乡', 39.3847400, 112.4813500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14431, 'Xiaonangou', 'Xiaonangou', 'Xiaonangou,Xiaonangou Xiang,xiao nan gou,xiao nan gou xiang,小南沟,小南沟乡', 36.6243500, 106.8180900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14432, 'Xiaomian', 'Xiaomian', 'Hsiao-mien-ch''i,Hsiao-mien-ch’i,Xiaomian,Xiaomian Zhen,xiao mian,xiao mian zhen,小沔,小沔镇', 30.1226800, 106.5343500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14433, 'Xiaomei', 'Xiaomei', 'Hsiao-mei,Hsiao-mei-chen,Xiaomei,Xiaomei Zhen,xiao mei,xiao mei zhen,小梅,小梅镇', 27.8258300, 118.9722200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14434, 'Xiaolukou', 'Xiaolukou', 'Hsia-lu-k''ou,Hsia-lu-k’ou,Hsiao-lu-k''ou,Hsiao-lu-k’ou,Xiaolukou,Xiaolukou Zhen,xiao lu kou,xiao lu kou zhen,小路口,小路口镇', 29.8615000, 117.6077000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14435, 'Xiaolou', 'Xiaolou', 'Hsiao-lou,Xiaolou,Xiaolou Zhen,xiao lou,xiao lou zhen,小楼,小楼镇', 23.3869400, 113.8263900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14436, 'Xiaolongmen', 'Xiaolongmen', 'Hsiao-lung,Hsiao-lung-men,Hsiao-lung-p''u,Hsiao-lung-p’u,Xiaolongmen', 27.8019400, 110.1605600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14437, 'Xiaolong', 'Xiaolong', 'Hsiao-lung,Xiaolong,Xiaolong Zhen,xiao long,xiao long zhen,小龙,小龙镇', 26.6818200, 115.2547500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14438, 'Xiaolong', 'Xiaolong', 'Xiaolong,Xiaolong Xiang,xiao long,xiao long xiang,晓龙,晓龙乡', 25.5413800, 115.5448400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14439, 'Xiaolingwei', 'Xiaolingwei', 'Hsiao-ling-wei,Xiaolingwei,Xiaolingwei Jiedao,xiao ling wei,xiao ling wei jie dao,孝陵卫,孝陵卫街道', 32.0324400, 118.8540000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14440, 'Xiaolin', 'Xiaolin', 'Hsiao-lin,Hsiao-lin-ts''un,Hsiao-lin-ts’un,Xiaolin,Xiaolin Xiang,xiao lin,xiao lin xiang,晓林,晓林乡', 38.5725900, 114.6321400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14441, 'Xiaolin', 'Xiaolin', 'Hsiao-lin,Hsiao-lin-chen,Xiaolin,Xiaolin Zhen,xiao lin,xiao lin zhen,逍林,逍林镇', 30.1727400, 121.3058900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14442, 'Xiaolan', 'Xiaolan', 'Hsiao-lan,Hsiao-lan-chen,Hsiao-lung,Siulam,Siulan,Suilan,Xiaolan,Xiaolan Zhen,xiao lan,xiao lan zhen,小榄,小榄镇', 22.6782500, 113.2313400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14443, 'Xiaokeng', 'Xiaokeng', 'Xiaokeng,Xiaokeng Zhen,xiao keng,xiao keng zhen,小坑,小坑镇', 24.7171800, 113.8144600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14444, 'Xiaojingzhuang', 'Xiaojingzhuang', 'Hsiao-chin-chuang,Hsiao-ching-chuang,Xiaojingzhuang,Xiaojingzhuang Xiang,xiao jing zhuang,xiao jing zhuang xiang,小京庄,小京庄乡', 39.8864000, 112.6516500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14445, 'Xiaojing', 'Xiaojing', 'Xiaojing,Xiaojing Xiang,xiao jing,xiao jing xiang,晓景,晓景乡', 28.4308900, 108.5758000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14446, 'Xiaojian', 'Xiaojian', 'Hsiao-chien-tzu,Xiaojian,Xiaojian Zhen,Xiaojianji,Yu-shun-chi,Yü-shun-chi,xiao jian,xiao jian zhen,小尖,小尖镇', 34.1333300, 119.6500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14447, 'Xiaojiang', 'Xiaojiang', 'Hsiao-chiang,Hsiao-chiang-shih,Xiaojiang,Xiaojiang Zhen,xiao jiang,xiao jiang zhen,小将,小将镇', 29.3832700, 121.1154300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14448, 'Xiaojiang', 'Xiaojiang', 'Hsiao-chiang,Hsiao-chiang-chen,Hsiao-chiang-hsu,Hsiao-chiang-hsü,Hsiao-ching-hsu,Hsiao-ching-hsü,P''u-pei,Pubei,P’u-pei,Siukonghu,Siukonghü,Xiaojiang,Xiaojiang Zhen,xiao jiang,xiao jiang zhen,小江,小江镇', 22.2729600, 109.5518400, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14449, 'Xiaogang', 'Xiaogang', 'Hsiao-chia-kang,Xiaogang,Xiaogang Zhen,Xiaojiagang,xiao gang,xiao gang zhen,肖港,肖港镇', 31.0774300, 113.9336300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14450, 'Xiaoji', 'Xiaoji', 'Hsiao-chi,Hsiao-chi-chen,Xiaoji,Xiaoji Zhen,xiao ji,xiao ji zhen,小纪,小纪镇', 32.6264900, 119.7640600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14451, 'Xiaohu', 'Xiaohu', 'Hsiao-hu,Xiaohu,Xiaohu Zhen,xiao hu,xiao hu zhen,小湖,小湖镇', 27.3333300, 118.2666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14452, 'Bange', 'Bange', 'Bange,Bangebao,Hsiao-ho-ch''eng,Hsiao-ho-chen,Hsiao-ho-ch’eng,Shao-k''o-ch''eng,Shao-k’o-ch’eng,Siaohocheng,Xiaohe Xiang,ban ge,ban ge bao,xiao he xiang,半个,半个堡,硝河乡', 35.8870400, 105.8498200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14453, 'Xiaohenglong', 'Xiaohenglong', 'Hsiao-heng-lung,Xiaohenglong', 27.6050000, 110.5169400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14454, 'Xiaohemiao', 'Xiaohemiao', 'Hsiao-ho-miao,Xiaohemiao,xiao he miao,小河庙', 32.9589700, 106.6653900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14455, 'Xiaohe', 'Xiaohe', 'Hsiao-ho,Hsiao-ho-chen,Hsiao-ho-wan,Hsiasho,Xiaohe,Xiaohe Zhen,xiao he,xiao he zhen,小河,小河镇', 31.8038900, 112.1522200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14456, 'Heshikou', 'Heshikou', 'Heshikou,Hsiao-ho,Hsiao-ho-chen,Xiaohe,Xiaohe Xiang,he shi kou,xiao he,xiao he xiang,合石口,小河,小河乡', 28.2223000, 114.0582700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14457, 'Xiaohai', 'Xiaohai', 'Hsiao-hai,Hsiao-hai-chen,Xiaohai,Xiaohai Zhen,Xiaohaizhen,xiao hai,xiao hai zhen,小海,小海镇', 31.9544300, 120.9667700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14458, 'Xiaoguan', 'Xiaoguan', 'Xiaoguan,Xiaoguan Zhen,xiao guan,xiao guan zhen,小观,小观镇', 36.9764600, 121.8709500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14459, 'Xiaoguan', 'Xiaoguan', 'Hsiao-kuan,Xiaoguan,Xiaoguan Dongzuxiang,xiao guan,xiao guan dong zu xiang,晓关,晓关侗族乡', 29.8758800, 109.3193100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14460, 'Xiaogang', 'Xiaogang', 'Hsiao-kang-k''ou,Hsiao-kang-k’ou,Xiaogang,Xiaogang Zhen,Xiaogangkou,xiao gang,xiao gang zhen,小港,小港镇', 28.2467600, 115.8627700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14461, 'Xiaogang', 'Xiaogang', 'Hsiao-kang-chen,Xiaogang,Xiaogang Zhen,xiao gang,xiao gang zhen,小港,小港镇', 29.9503300, 121.7429300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14462, 'Xiaogan', 'Xiaogan', 'Hau-gang,Hau-kam-chhi,Hieu Cam,Hiếu Cảm,Hsiao-kan,Hsiao-kan-hsien,Hàu-kám-chhī,Háu-gāng,Siao-kan,Siaokan,Siaokanhsien,Sjaogan'',XJW,Xiaogan,shyawgan,syaogan si,xiao gan,xiao gan shi,Сяогань,شياۋگەن شەھىرى,شیاوگان,孝感,孝感市,샤오간 시', 30.9268900, 113.9222100, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14463, 'Xiaodongzhuang', 'Xiaodongzhuang', 'Xiaodongzhuang,xiao dong zhuang,小东庄', 39.0602900, 117.4154400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14464, 'Xiaodong', 'Xiaodong', 'Xiaodong,Xiaodong Zhen,xiao dong,xiao dong zhen,肖东,肖东镇', 30.0333300, 121.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14465, 'Xiaodian', 'Xiaodian', 'Hsiao-tien-chuang,Xiaodian,Xiaodian Zhen,Xiaodianzhuang,xiao dian,xiao dian zhen,小淀,小淀镇', 39.2541200, 117.2274700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14466, 'Xiaodian', 'Xiaodian', 'Hsiao-t''ien,Hsiao-tien-chen,Hsiao-t’ien,Xiaodian,Xiaodian Jiedao,Xiaodian Qu,xiao dian,xiao dian jie dao,xiao dian qu,小店,小店区,小店街道', 37.7363900, 112.5563900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14467, 'Xiaocun', 'Xiaocun', 'Hsiao-ts''un,Hsiao-ts’un,Xiaocun,Xiaocun Zhen,xiao cun,xiao cun zhen,小村,小村镇', 34.2638800, 108.2614400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14468, 'Xiaocun', 'Xiaocun', 'Hsiao-ts''un,Hsiao-ts’un,Xiaocun,Xiaocun Xiang,xiao cun,xiao cun xiang,小村,小村乡', 29.9119100, 108.9568000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14469, 'Xiaocun', 'Xiaocun', 'Hsiao-ts''un,Hsiao-ts’un,Xiaocun,Xiaocun Zhen,Zhuyuan,xiao cun,xiao cun zhen,zhu yuan,竹园,筱村,筱村镇', 27.5666700, 119.9086100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14470, 'Xiaochuan', 'Xiaochuan', 'Hsiao-ch''uan,Hsiao-ch''uan-chen,Hsiao-ch’uan,Hsiao-ch’uan-chen,Xiaochuan,Xiaochuan Zhen,xiao chuan,xiao chuan zhen,小川,小川镇', 33.6806000, 105.5615600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14471, 'Xiaochi', 'Xiaochi', 'Hsiao-ch''ih-k''ou,Hsiao-ch’ih-k’ou,Xiaochi,Xiaochi Zhen,Xiaochikou,xiao chi,xiao chi zhen,小池,小池镇', 29.7535900, 115.9895100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14472, 'Xiaochi', 'Xiaochi', 'Hsiao-ch''ih,Hsiao-ch''ih-hsu,Hsiao-ch’ih,Hsiao-ch’ih-hsü,Siaochih,Xiaochi,Xiaochi Zhen,xiao chi,xiao chi zhen,小池,小池镇', 25.1443400, 116.8854400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14473, 'Xiaocheng', 'Xiaocheng', 'Hsiao-ch''eng,Hsiao-ch’eng,Ting-hai,Tinhai,Xiaocheng,Xiaocheng Zhen,xiao cheng,xiao cheng zhen,筱埕,筱埕镇', 26.2943300, 119.7854100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14474, 'Xiaocha', 'Xiaocha', 'Xiaocha,Xiaocha Xiang,xiao cha,xiao cha xiang,小岔,小岔乡', 36.1518100, 106.7597100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14475, 'Xiaobu', 'Xiaobu', 'Hsiao-p''u,Hsiao-p’u,Xiaobu,Xiaobu Zhen,Xiaopu,xiao bu,xiao bu zhen,小布,小布镇', 26.7863200, 115.8312100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14476, 'Xiaoban', 'Xiaoban', 'Xiaoban,Xiaoban Zhen,xiao ban,xiao ban zhen,小板,小板镇', 30.6112800, 113.2175500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14477, 'Xiao’ao', 'Xiao''ao', 'Hsiao-ao,Xiao''ao,Xiao''ao Zhen,Xiao’ao,Xiao’ao Zhen,xiao ao,xiao ao zhen,晓澳,晓澳镇', 26.2206200, 119.6488500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14478, 'Xi’ao', 'Xi''ao', 'Xi''ao,Xi''ao Zhen,Xi’ao,Xi’ao Zhen,xi ao,xi ao zhen,细坳,细坳镇', 24.6909200, 115.2619300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14479, 'Xianzong', 'Xianzong', 'Hsien-tsung,Xianzong,Xianzong Zhen,xian zong,xian zong zhen,仙踪,仙踪镇', 31.8013000, 118.0078100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14480, 'Xianyuan', 'Xianyuan', 'Ch''eng-hsiang-chen,Chiu-t''ai-p''ing,Chiu-t’ai-p’ing,Ch’eng-hsiang-chen,Hsien-yuan,Hsien-yuan-chen,Hsien-yüan,Hsien-yüan-chen,T''ai-p''ing,T''ai-p''ing-chen,T''ai-p''ing-hsien,T’ai-p’ing,T’ai-p’ing-chen,T’ai-p’ing-hsien,Xianyuan,Xianyuan Zhen,xian yuan,xian yuan zhen,仙源,仙源镇', 30.3054200, 118.2002000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14481, 'Xianyuan', 'Xianyuan', 'Xianyuan,Xianyuan Zhen,xian yuan,xian yuan zhen,仙源,仙源镇', 28.3833300, 106.6000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14482, 'Xianyuan', 'Xianyuan', 'Hsien-yuan,Hsien-yüan,Xianyuan,Xianyuan Xiang,xian yuan,xian yuan xiang,仙源,仙源乡', 28.2987000, 114.2583300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14483, 'Xianyang', 'Xianyang', 'Ham Duong,Ham-iong-chhi,Hang-iong,Hsien-yang,Hsien-yang-hsien,Hsien-yang-shih,Hszienjang,Hàm Dương,Hàng-iòng,Hâm-iông-chhī,San''jan,Sianjangas,Sien-jang,Sienjan,Sienyanghsien,Sjan''jan,Sjanjang,Sjanjango,Syanyan,Xianyang,Xianyang Shi,seiy n hyang,shyanyang,syen-yang si,xian yang,xian yang shi,Ŝjanjango,Саньян,Сиенян,Сяньян,Сјанјанг,شیانیانگ,شیان‌یانگ,เสียนหยาง,咸阳,咸阳市,咸陽,咸陽市,셴양 시', 34.3377800, 108.7026100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14484, 'Xianyang', 'Xianyang', 'Hsien-yang,Xianyang,Xianyang Zhen,xian yang,xian yang zhen,仙阳,仙阳镇', 28.0455800, 118.5183300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14485, 'Xianyan', 'Xianyan', 'Hsien-yen,Hsien-yen-chen,Xianyan,Xianyan Zhen,xian yan,xian yan zhen,仙岩,仙岩镇', 29.6754300, 120.8132100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14486, 'Xianxi', 'Xianxi', 'Hsien-hsi-chen,Tung-tao,Xianxi,Xianxi Zhen', 26.3347200, 109.6430600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14487, 'Xianxiang', 'Xianxiang', 'Hsien-hsiang-chen,Xianxiang,Xianxiang Zhen,xian xiang,xian xiang zhen,咸祥,咸祥镇', 29.6903400, 121.7788400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14488, 'Yejia', 'Yejia', 'Hsien-hsia,Shan-chia-ts''un,Shan-chia-ts’un,Xianxia,Xianxia Zhen,Yejia,xian xia,xian xia zhen,ye jia,仙霞,仙霞镇,叶家', 30.4076400, 119.2876600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14489, 'Xianxia', 'Xianxia', 'Hsien-hsia,Hsien-hsia-kuan,Shan-hsia-kuan,Xianxia,Xianxia Xiang,xian xia,xian xia xiang,仙下,仙下乡', 26.1131200, 115.5631300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14490, 'Xianxi', 'Xianxi', 'Xianxi,Xianxi Zhen,xian xi,xian xi zhen,仙溪,仙溪镇', 28.4175400, 121.0663000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14491, 'Xianxi', 'Xianxi', 'Hsien-hsi,Xianxi,Xianxi Zhen,xian xi,xian xi zhen,仙溪,仙溪镇', 28.2441700, 111.7052800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14492, 'Xiantao', 'Xiantao', 'Hsien-t''ao-chen,Hsien-t’ao-chen,Mianyang,Mien-yang,Mien-yang Hsien,Sientaochen,XTQ,Xiantao,Xiantaozhen', 30.3708000, 113.4429400, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14493, 'Xiantang', 'Xiantang', 'Hsien-t''ang,Hsien-t’ang,Xiantang,Xiantang Zhen,xian tang,xian tang zhen,仙塘,仙塘镇', 23.8252100, 114.7678300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14494, 'Xiantan', 'Xiantan', 'Hsien-t''an-ch''ang,Hsien-t’an-ch’ang,Xiantan,Xiantanchang,xian tan,先滩', 28.8185900, 106.1927000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14495, 'Xiantaiba', 'Xiantaiba', 'Hsien-t''ai-pa,Hsien-t’ai-pa,Xiantaiba,xian tai ba,仙台坝', 33.3934000, 106.3685000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14496, 'Xianshuigu', 'Xianshuigu', 'Hsien-shui-ku,Jinnan,Jinnan Qu,T''ien-ching,T''ien-ching-hsien,T’ien-ching,T’ien-ching-hsien,Xianshuigu,Xianshuigu Zhen,jin nan,jin nan qu,xian shui gu,xian shui gu zhen,咸水沽,咸水沽镇,津南,津南区', 38.9850000, 117.3827800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14497, 'Xianrenwan', 'Xianrenwan', 'Hsien-jen-wan,Xianrenwan', 27.7544400, 110.3297200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14498, 'Xianrendu', 'Xianrendu', 'Hsien-jen-tu,Xianrendu,Xianrendu Zhen,xian ren du,xian ren du zhen,仙人渡,仙人渡镇', 32.2566100, 111.7138800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14499, 'Xianren', 'Xianren', 'Xianren,Xianren Xiang,xian ren,xian ren xiang,仙仁,仙仁乡', 28.6186500, 109.7453900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14500, 'Xiannü', 'Xiannu', 'Chiang-tu,Hsien-nu-chen,Hsien-nu-miao,Hsien-nu-miao-chen,Hsien-nü-chen,Hsien-nü-miao,Hsien-nü-miao-chen,Jiangdu Shi,Siennumiao,Siennümiao,Xiannu,Xiannumiao,Xiannü,Xiannümiao,jiang dou shi,xian nu,仙女,江都市', 32.4280600, 119.5604800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14501, 'Xianning', 'Xianning', 'Hsien-ning,IUO,Sjan''nin,Xianning,Сяньнин', 29.8434700, 114.3220100, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14502, 'Xianlin', 'Xianlin', 'Hsien-lin,Hsien-lin-fou,Hsien-lin-pu,Xianlin,Xianlinbu,xian lin,闲林', 30.2258300, 119.9813900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14503, 'Xianliang', 'Xianliang', 'Hsien-liang,Hsien-liang-ts''un,Hsien-liang-ts’un,Shihu,Xianliang,Xianliang Zhen,xian liang,xian liang zhen,贤良,贤良镇', 27.6516700, 119.2238900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14504, 'Xianju', 'Xianju', 'Hsien-chu,Hsien-chü,Xianju,Xianju Xiang,xian ju,xian ju xiang,仙居,仙居乡', 31.4001500, 112.0337900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14505, 'Xianju', 'Xianju', 'Hsien-chu,Hsien-chu-hsien,Hsien-chu-hsien-ch''eng,Hsien-chü,Hsien-chü-hsien,Hsien-chü-hsien-ch’eng,Sienku,Sienkuhsien,Sienkü,Xianju,xian ju,仙居', 28.8547000, 120.7316800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14506, 'Xianren', 'Xianren', 'Hsien-chu-ts''un,Hsien-chü-ts’un,Xianju,Xianren,Xianren Xiang,xian ju,xian ren,xian ren xiang,仙居,仙稔,仙稔乡', 27.5894400, 119.7533300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14507, 'Xiangzikou', 'Xiangzikou', 'Hsiang-tzu-k''ou,Hsiang-tzu-k’ou,Xiangzikou,Xiangzikou Zhen,xiang zi kou,xiang zi kou zhen,巷子口,巷子口镇', 28.1030400, 111.9540900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14508, 'Xiangzhu', 'Xiangzhu', 'Hsiang-chu,Hsiang-chu-shih,Qingweijie,Xiangzhu,Xiangzhu Zhen,qing wei jie,xiang zhu,xiang zhu zhen,清渭街,象珠,象珠镇', 28.9897200, 120.0815000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14509, 'Xiangzhou', 'Xiangzhou', 'Hsiang,Hsiang-chou,Hsiang-chou-chen,Hsiang-hsien,Tseung-hsien,Xiangzhou,xiang zhou,象州', 23.9728200, 109.6667800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14510, 'Zhuhai', 'Zhuhai', 'Chau Hai,Chu Hai,Chu Hải,Chu-hai,Chu-hai-chhi,Chu-hoi-su,Chu-hái-chhī,Chzhukhaj,Châu Hải,Chû-hói-sṳ,Cio-hai,Ciŏ-hāi,Cu-chaj,Dzhukhaj,Dzukhaj,Guhaj,Heung chau,Hsiang-chou,Hsiang-chou-chen,Hsiang-chou-fou,Huengchow,Juxey shehiri,Xiangzhou,ZUH,Zhuhai,juhai si,jwhay,zhu hai,zhu hai shi,zwhay,Ču-chaj,Ĝuhaj,Џухај,Джухай,Чжухай,جوهای,زوهاي,ژوہوئی,珠海,珠海市,주하이 시', 22.2769400, 113.5677800, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14511, 'Xiangcheng', 'Xiangcheng', 'Hsiang-ch''eng-chen,Hsiang-ch’eng-chen,Hsiang-yun,Hsiang-yun-hsien,Hsiang-yün,Hsiang-yün-hsien,Siangyun,Siangyün,Xiangcheng,Xiangyun,Yun-nan,Yunnanhsien,Yunnansen,Yün-nan,xiang cheng,祥城', 25.4668700, 100.5624800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14512, 'Guhan', 'Guhan', 'Guhan,Hsiang-yuan,Hsiang-yuan-hsien,Hsiang-yüan,Hsiang-yüan-hsien,Siangyuanhsien,Siangyüanhsien,Syan''yuan'',Syan’yuan’,Xiangyuan,gu han,古韩', 36.5354700, 113.0252800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14513, 'Wenxing', 'Wenxing', 'Hsiang-yin,Hsiang-yin-hsien,Siang-Yin,Siangyin,Siangyinhsien,Wenxing,Xiangyin,Xiangyin Xian,wen xing,xiang yin xian,文星,湘阴县', 28.6820800, 112.8786400, 'CN', '2015-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14514, 'Xiangyang', 'Xiangyang', 'Hsiang-yang,Hsiang-yang-ts''un,Hsiang-yang-ts’un,Xiangyang,Xiangyang Zhen,Xiangyangcun,xiang yang,xiang yang zhen,向阳,向阳镇', 31.8722200, 121.7877800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14515, 'Xiangyangpu', 'Xiangyangpu', 'Hsiang-yang,Hsiang-yang-pao,Xiangyangpu,Xiangyangpu Xiang,xiang yang bao,xiang yang bao xiang,向阳堡,向阳堡乡', 39.6072500, 112.3513400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14516, 'Xiangxiang', 'Xiangxiang', 'Hsan-shan,Hsiang-hsiang,Hsiang-hsiang-hsien,Siangsiang,Siangsianghsien,Siong-hiong-su,Siong-hiông-sṳ,Tuong Huong,Tương Hương,Xiangxiang,syangsyang si,xiang xiang,xiang xiang shi,湘乡,湘乡市,湘郷市,샹샹 시', 27.7333300, 112.5333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14517, 'Xiangxi', 'Xiangxi', 'Xiangxi,Xiangxi Zhen,xiang xi,xiang xi zhen,香溪,香溪镇', 29.2874400, 119.5319400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14518, 'Xiangxi', 'Xiangxi', 'Xiangxi,Xiangxi Xiang,xiang xi,xiang xi xiang,象溪,象溪乡', 25.5595400, 118.6968000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14519, 'Xiangtang', 'Xiangtang', 'Hsiang-t''ang,Hsiang-t’ang,Xiangtang,Xiangtang Zhen,xiang tang,xiang tang zhen,向塘,向塘镇', 28.4264400, 115.9632300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14520, 'Xiangtan', 'Xiangtan', 'Hsiang-t''an-ch''eng,Hsiang-t''an-hsien,Hsiang-t''an-shih,Hsiang-tan,Hsiang-t’an-ch’eng,Hsiang-t’an-hsien,Hsiang-t’an-shih,Siang-tchan,Siangtan,Siangtanhsien,Siong-tang,Siong-tham-chhi,Siong-tham-su,Siong-thâm-chhī,Siong-thâm-sṳ,Siŏng-tàng,Sjangtan,Sjantan,Sjantan'',Tuong GJam,Tương Đàm,Xiangtan,Xiangtan Shi,shyangtan,syangtan si,xiang tan,xiang tan shi,Сянтан,Сянтань,Сјангтан,شیانگتان,სიანტანი,湘潭,湘潭市,샹탄 시', 27.8500000, 112.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14521, 'Xiangshuitang', 'Xiangshuitang', 'Hsiang-shui-t''an,Hsiang-shui-t’an,Xiangshuitang,Xiangshuitang Xiang,xiang shui tan,xiang shui tan xiang,响水滩,响水滩乡', 29.4747900, 116.5501000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14522, 'Xiangshui', 'Xiangshui', 'Xiangshui,Xiangshui Zhen,xiang shui,xiang shui zhen,响水,响水镇', 30.6550000, 108.1930000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14523, 'Xiangshui', 'Xiangshui', 'Hsiang-shui-ssu,Xiangshui,Xiangshui Zhen,Xiangshuisi,xiang shui,xiang shui zhen,湘水,湘水镇', 32.9422200, 107.0797200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14524, 'Xiangshui', 'Xiangshui', 'Hsiang-shui,Hsiang-shui-hsu,Hsiang-shui-hsü,Xiangshui,Xiangshui Zhen,xiang shui,响水', 23.2687100, 114.2187100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14525, 'Xiangshui', 'Xiangshui', 'Xiangshui,Xiangshui Zhen,xiang shui,xiang shui zhen,响水,响水镇', 18.5931900, 109.6120600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14526, 'Xiangshi', 'Xiangshi', 'Xiangshi,Xiangshi Zhen,xiang shi,xiang shi zhen,象市,象市镇', 29.5172000, 110.8374600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14527, 'Xiangshan', 'Xiangshan', 'Hsiang-shan,Xiangshan,Xiangshan Jiedao,xiang shan,xiang shan jie dao,香山,香山街道', 39.9932000, 116.2011700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14528, 'Xiangshan', 'Xiangshan', 'Hsiang-shan,Xiangshan,Xiangshan Zhen,xiang shan,xiang shan zhen,向山,向山镇', 31.6605500, 118.5868200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14529, 'Menghai', 'Menghai', 'Fo-hai,Fo-hai-hsien,Fuhai-hsien,Menghai,Pan-na-meng-hai,Xiangshan,meng hai,勐海', 21.9532200, 100.3840900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14530, 'Xiangquan', 'Xiangquan', 'Hsiang-ch''uan,Hsiang-ch''uan-chen,Hsiang-ch’üan,Hsiang-ch’üan-chen,Xiangquan,Xianquan Zhen,xiang quan,xiang quan zhen,香泉,香泉镇', 31.8707800, 118.3178600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14531, 'Xiangqiao', 'Xiangqiao', 'Hsiang-ch''iao,Hsiang-ch''iao-chen,Hsiang-ch’iao,Hsiang-ch’iao-chen,Xiangqiao,Xiangqiao Zhen,xiang qiao,相桥', 34.6151400, 109.3661700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14532, 'Xiangqian', 'Xiangqian', 'Xiangqian,Xiangqian Zhen,xiang qian,xiang qian zhen,祥谦,祥谦镇', 25.9420900, 119.3857100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14533, 'Xiangong', 'Xiangong', 'Hsien-kung,Hsien-kung-chen,Xiangong,Xiangong Zhen,xian gong,xian gong zhen,县功,县功镇', 34.5268300, 107.0680600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14534, 'Changning', 'Changning', 'Changning,Changning Zhen,Hsiang-ning,Hsiang-ning-hsien,Siangninghsien,Syannin,Xiangning,Xiangning Xian,chang ning,chang ning zhen,xiang ning xian,乡宁县,昌宁,昌宁镇', 35.9798300, 110.8221100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14535, 'Xiangmiao', 'Xiangmiao', 'Hsiang-miao,Xiangmiao,xiang miao,香庙', 34.9925300, 108.2260000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14536, 'Xiangling', 'Xiangling', 'Chiu-hsiang-ling,Hsiang-ling,Hsiang-ling-ch''eng,Hsiang-ling-ch’eng,Hsiang-ling-hsien,Sianglinghsien,Syanlin,Xiangling,Xiangling Zhen,xiang ling,xiang ling zhen,襄陵,襄陵镇', 36.0272200, 111.4000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14537, 'Xiangkou', 'Xiangkou', 'Hsiang-k''ou,Hsiang-k''ou-chang,Hsiang-k''ou-chen,Hsiang-k’ou,Hsiang-k’ou-chang,Hsiang-k’ou-chen,Wu-lung,Wu-lung-hsien,Wulong Xian,Xiangkou,Xiangkou Zhen,wu long xian,xiang kou,xiang kou zhen,巷口,巷口镇,武隆县', 29.3305000, 107.7370000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14538, 'Xianghuaqiao', 'Xianghuaqiao', 'Hsiang-hua-ch''iao,Hsiang-hua-ch’iao,Xianghuaqiao,Xianghuaqiao Jiedao,xiang hua qiao,xiang hua qiao jie dao,香花桥,香花桥街道', 31.1745100, 121.1169200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14539, 'Xianghua', 'Xianghua', 'Xianghua,Xianghua Xiang,xiang hua,xiang hua xiang,祥华,祥华乡', 25.1881500, 117.7345300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14540, 'Xianghu', 'Xianghu', 'Hsiang-hu,Xianghu,Xianghu Zhen,xiang hu,xiang hu zhen,湘湖,湘湖镇', 29.3253700, 117.3158800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14541, 'Xianghu', 'Xianghu', 'Jui-chin,Jui-chin-hsien,Juikin,Juikin-hsien,Ruijin Shi,Shuikin,Shuikin-hsien,Xianghu,Xianghu Zhen,rui jin shi,xiang hu,xiang hu zhen,瑞金市,象湖,象湖镇', 25.8000000, 116.0000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14542, 'Xianghu', 'Xianghu', 'Hsiang-hu,Xianghu,Xianghu Zhen,xiang hu,xiang hu zhen,象湖,象湖镇', 25.4206500, 117.6287700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14543, 'Xianghe', 'Xianghe', 'Hsiang-ho-kuan,Hsiang-ho-tien,Xianghe,Xiangheguan,xiang he,象河', 33.1089100, 113.4249200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14544, 'Xiangfu', 'Xiangfu', 'Hsiang-fu-kuan,Hsiang-fu-kuan-chieh,Xiangfu,Xiangfu Zhen,Xiangfuguan,xiang fu,xiang fu zhen,祥符,祥符镇', 28.4747000, 115.4303700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14545, 'Zhangwan', 'Zhangwan', 'Xiangfanbei,Xiangyang Qu,Xiangzhou Qu,Zhangwan,Zhangwan Zhen,xiang fan bei,xiang yang qu,xiang zhou qu,zhang wan,zhang wan zhen,张湾,张湾镇,襄州区,襄樊北,襄阳区', 32.0832600, 112.1666700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14546, 'Xiangyang', 'Xiangyang', 'Fancheng,Fancheng Zhen,Hsiang-fan,Hsiang-yang,Hsiang-yang-hsien,Siangfan,Siangyang,Siangyang-hsien,Sjanfan'',XFN,Xiangfan,Xiangfan Shi,Xiangyang,Xiangyang Shi,Xiangyangfu,fan cheng,fan cheng zhen,xiang fan,xiang fan shi,xiang yang,xiang yang fu,xiang yang shi,Сянфань,شياڭفان شەھىرى,樊城,樊城镇,襄樊,襄樊市,襄阳,襄阳市,襄阳府', 32.0422000, 112.1447900, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14547, 'Xiangdong', 'Xiangdong', 'Hsiang-tung,Siangtung,Xiangdong,Xiangdong Qu,xiang dong,xiang dong qu,湘东,湘东区', 27.6520700, 113.7240600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14548, 'Xiangcheng Chengguanzhen', 'Xiangcheng Chengguanzhen', 'Hsiang-ch''eng,Hsiang-ch''eng-hsien,Hsiang-ch’eng,Hsiang-ch’eng-hsien,Xiangcheng,Xiangcheng Chengguanzhen,xiang cheng,xiang cheng cheng guan zhen,襄城,襄城城关镇', 33.8470300, 113.4778000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14549, 'Xiangcheng', 'Xiangcheng', 'Hsiang-ch''eng,Hsiang-ch’eng,Xiangcheng,Xiangcheng Zhen,xiang cheng,xiang cheng zhen,相城,相城镇', 28.1990400, 115.1615200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14550, 'Xiangang', 'Xiangang', 'Hsien-kang,Xiangang,Xiangang Zhen,xian gang,xian gang zhen,蚬岗,蚬岗镇', 23.0445000, 112.6675800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14551, 'Xianfeng', 'Xianfeng', 'Hsien-feng,Xianfeng,Xianfeng Zhen,Xianfengchang,xian feng,xian feng zhen,先锋,先锋镇', 29.2100400, 106.3001200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14552, 'Xiandu', 'Xiandu', 'Hsien-tu,Shangxiang,Xiandu,Xiandu Zhen,shang xiang,xian dou,xian dou zhen,上巷,仙都,仙都镇', 25.0233300, 117.6480600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14553, 'Xiancun', 'Xiancun', 'Hsien-ts''un,Hsien-ts’un,Xiancun', 26.9386100, 119.3602800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14554, 'Xi’an', 'Xi''an', 'Ch''ang-an,Ch''ang-an-hsien,Ch’ang-an,Ch’ang-an-hsien,Hsi Gnan Fu,Hsi-an,Hsi-an-shih,Hsi-ching,Hsi-ching-shih,Hsingan,SIA,Si-Gan-Fu,Sian,Sian'',Siana,Sianas,Sianfu,Siano,Siaņa,Siking,Singan,Tay An,Tây An,Xi''an,Xi''an - xi an,Xi''an - 西安,Xi''an Shi,Xian,Xi’an,Xi’an Shi,Xī''ān,si xan,sian si,xi an,xi an shi,Ŝiano,Сиань,شىئەن شەھىرى,ซีอาน,西安,西安市,시안 시', 34.2583300, 108.9286100, 'CN', '2015-11-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14555, 'Xi’an', 'Xi''an', 'Xi''an,Xi''an Zhen,Xi’an,Xi’an Zhen,xi an,xi an zhen,西安,西安镇', 28.4666700, 111.0500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14556, 'Xi’an', 'Xi''an', 'Xi''an,Xi''an Zhen,Xi’an,Xi’an Zhen,xi an,xi an zhen,西岸,西岸镇', 24.9205600, 112.2884400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14557, 'Xiamujiao', 'Xiamujiao', 'Hsia-mu-chiao,Hsia-shui-chiao,Xiamujiao,Xiamujiao Xiang,xia mu jiao,xia mu jiao xiang,下木角,下木角乡', 39.4641900, 112.0804400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14558, 'Xiamiao', 'Xiamiao', 'Hsia-miao,Hsia-miao-chen,Xiamiao,Xiamiao Zhen,xia miao,下庙', 34.5764900, 109.7705700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14559, 'Xiamiangao', 'Xiamiangao', 'Hsia-mien-kao,Mien-kao-kou,Xiamiangao,Xiamiangao Xiang,xia mian gao,xia mian gao xiang,下面高,下面高乡', 39.4975300, 112.5123900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14560, 'Xiamen', 'Xiamen', 'A-muong,Amoy,E-mng-chhi,Ha Mon,Ha-mun-su,Ha-mùn-sṳ,Hiyamin,Hsia-men,Hsia-men-shih,Hsziamen,Hạ Môn,Shamen,Sia-men,Siamen,Siamenas,Sjamehn'',Sjamen,Sjamen'',Sjamun,Sjamyn'',Ssu-ming,Ssu-ming-hsien,Szeming-hsien,XMN,Xiamen,Xiamen - sha men,Xiamen - 厦门,Xiamen Shi,seiy he min,sha men,sha men shi,shyamn,shyamyn,siamini,syameon si,Â-muòng,Ē-mn̂g-chhī,Σιαμέν,Сямень,Сямън,Сямынь,Сямэнь,Сјамен,שיאמן,شيامن,شيامېن شەھىرى,شیامن,شیامین,เซี่ยเหมิน,სიამინი,厦门,厦门市,廈門,廈門市,샤먼 시', 24.4797900, 118.0818700, 'CN', '2016-11-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14561, 'Xiamayu', 'Xiamayu', 'Hsia-ma-yu,Hsia-ma-yü,Xiamayu,Xiamayu Xiang,xia ma yu,xia ma yu xiang,下马峪,下马峪乡', 39.3960600, 113.1084100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14562, 'Xiamao', 'Xiamao', 'Hsia-mao,Xiamao,Xiamao Zhen,xia mao,xia mao zhen,夏茂,夏茂镇', 26.5764900, 117.6658100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14563, 'Xialiang', 'Xialiang', 'Hsia-liang-ho-k''ou,Hsia-liang-ho-k’ou,Xialiang,Xialiang Xiang,Xialiang Zhen,Xialianghekou,xia liang,xia liang xiang,xia liang zhen,下两,下两乡,下两镇', 32.0767300, 106.7715100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14564, 'Xiali', 'Xiali', 'Xiali,xia li,夏李', 33.5308800, 113.2124600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14565, 'Xialaba', 'Xialaba', 'Hsia-la-pa,Xialaba,Xialaba Xiang,xia la ba,xia la ba xiang,下喇叭,下喇叭乡', 39.5922200, 112.6575000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14566, 'Xiakouyi', 'Xiakouyi', 'Hsia-k''ou-i,Hsia-k’ou-i,Xiakouyi,Xiakouyi Zhen,xia kou yi,xia kou yi zhen,硖口驿,硖口驿镇', 33.2111700, 106.4075100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14567, 'Xiakou', 'Xiakou', 'Chia-k''ou-shih,Chia-k’ou-shih,Hsia-k''ou,Hsia-k''ou-shih,Hsia-k’ou,Hsia-k’ou-shih,Xiachuan,Xiachuan Zhen,Xiakou,xia chuan,xia chuan zhen,xia kou,峡口,峡川,峡川镇', 29.1443200, 118.9872300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14568, 'Xiakeng', 'Xiakeng', 'Hsia-k''eng,Hsia-k’eng,Xiakeng,Xiakeng Zhen,xia keng,xia keng zhen,霞坑,霞坑镇', 29.9591000, 118.6627000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14569, 'Kajiaman', 'Kajiaman', 'Kajiaman,Kajiaman Xiang,Xiakajia,ka jia man,ka jia man xiang,卡家曼,卡家曼乡', 35.0885100, 102.9139300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14570, 'Nancheng', 'Nancheng', 'Hsia-chin,Hsia-ching,Hsia-ching-hsien,Nancheng,Siatsing,Siatsinghsien,Xiajin,nan cheng,xia jin,南城,夏津', 36.9486100, 115.9977800, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14571, 'Xiayuan', 'Xiayuan', 'Hsia-chia-yuan,Hsia-chia-yüan,Xiajiayuan,Xiayuan,Xiayuan Zhen,xia yuan,xia yuan zhen,下原,下原镇', 32.2306500, 120.6330400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14572, 'Xiajiang', 'Xiajiang', 'Chiu-hsia-chiang,Hiakiang,Hiakiang-hsien,Hsia-chiang,Hsia-chiang-hsien,Xiajiang', 25.7555600, 108.6919400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14573, 'Xiahu', 'Xiahu', 'Hsia-hu,Xiahu', 26.6105600, 119.9483300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14574, 'Xiahong', 'Xiahong', 'Hsia-hung,Hsia-hung-ts''un,Hsia-hung-ts’un,Xiahong,Xiahong Xiang,xia hong,xia hong xiang,下洪,下洪乡', 27.5150000, 119.8691700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14575, 'Xiahe', 'Xiahe', 'Hsia-ho,Hsia-ho-chen,Xiahe,Xiahe Xiang,xia he,xia he xiang,下河,下河乡', 38.6988800, 114.7462600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14576, 'Xiahe', 'Xiahe', 'Hsia-ho,Xiahe,Xiahe Xiang,xia he,xia he xiang,下河,下河乡', 24.0155600, 117.2733300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14577, 'Xiahan', 'Xiahan', 'Hsia-han,Hsia-han-ts''un,Hsia-han-ts’un,Xiahan,Xiahan Xiang,xia han,xia han xiang,下韩,下韩乡', 39.7246500, 113.6143300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14578, 'Xiaji', 'Xiaji', 'Hsia-kua-chen,Hsia-kuei,Hsia-kuei-chen,Xiagui,Xiaji,Xiaji Zhen,xia ji,下吉', 34.7258700, 109.5072400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14579, 'Xiaguan', 'Xiaguan', 'Hsia-kuan,Hsia-kuan-chen,Kuan-ch''i,Kuan-ch’i,Xiaguan,Xiaguan Zhen,xia guan,xia guan zhen,下管,下管镇', 29.8439300, 121.0305900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14580, 'Xiagongma', 'Xiagongma', 'Xiagongma,Xiagongma Xiang,Zhehe Xietang,xia gong ma,xia gong ma xiang,zhe he xue tang,下贡麻,下贡麻乡,折合血塘', 33.7957500, 100.1678000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14581, 'Xiage', 'Xiage', 'Hsia-ko,Hsia-ko-chen,Xiage,Xiage Zhen,xia ge,xia ge zhen,下各,下各镇', 28.8600100, 120.8455600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14582, 'Xiagang', 'Xiagang', 'Hsia-chiang,Hsia-chiang-chen,Hsia-kang,Xiagang,Xiagang Zhen,xia gang,xia gang zhen,夏港,夏港镇', 31.8966700, 120.2100000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14583, 'Qixian', 'Qixian', 'Hsia-fang-ch''iao,Hsia-fang-ch’iao,Qixian,Qixian Zhen,Xiafangqiao,qi xian,qi xian zhen,齐贤,齐贤镇', 30.1224800, 120.5370600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14584, 'Xiadong', 'Xiadong', 'Hsia-tung,Hsia-tung-hsu,Hsia-tung-hsü,Xiadong,Xiadong Zhen,xia dong,xia dong zhen,霞洞,霞洞镇', 21.7333300, 111.1100300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14585, 'Xiadingjia', 'Xiadingjia', 'Dalujia,Dalüjia,Ta-lu-chia,Ta-lü-chia,Xiadingjia,Xiadingjia Zhen,xia ding jia,xia ding jia zhen,下丁家,下丁家镇', 37.5380900, 120.4946500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14586, 'Xiadian', 'Xiadian', 'Hsia-tien,Xiadian,Xiadian Zhen,xia dian,xia dian zhen,夏店,夏店镇', 31.4166000, 114.2941300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14587, 'Xiadao', 'Xiadao', 'Hsia-tao,Siaotao,Siatao,Xiadao,Xiadao Zhen,xia dao,xia dao zhen,夏道,夏道镇', 26.5750800, 118.2694300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14588, 'Xiacun', 'Xiacun', 'Hsia-ts''un,Hsia-ts’un,Xiacun,Xiacun Zhen,xia cun,xia cun zhen,下村,下村镇', 27.9234600, 114.9491400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14589, 'Xiacheng', 'Xiacheng', 'Xiacheng,xia cheng,峡城', 34.9960400, 103.8026700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14590, 'Xiache', 'Xiache', 'Xiache,Xiache Xiang,Xiachejie,xia che,xia che xiang,下车,下车乡', 34.3500000, 119.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14591, 'Xiacang', 'Xiacang', 'Hsia-ts''ang,Hsia-ts''ang-chen,Hsia-ts’ang,Hsia-ts’ang-chen,Xiacang', 39.7863900, 117.4166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14592, 'Xiabuji', 'Xiabuji', 'Hsia-pu-chi,Xiabuji,Xiabuji Xiang,xia bu ji,xia bu ji xiang,下埠集,下埠集乡', 28.3085800, 116.3820500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14593, 'Xiabaoping', 'Xiabaoping', 'Hsia-p''u-p''ing,Hsia-pao-p''ing,Hsia-pao-p’ing,Hsia-p’u-p’ing,Xiabaoping,Xiabaoping Xiang,xia bao ping,xia bao ping xiang,下堡坪,下堡坪乡', 31.0328300, 111.1599400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14594, 'Xiabao', 'Xiabao', 'Xiabao,Xiabao Xiang,xia bao,xia bao xiang,下包,下包乡', 29.6885200, 119.4894400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14595, 'Xiabaishi', 'Xiabaishi', 'Hsia-pai-shih,Pai-shih,Xiabaishi', 26.8152800, 119.6791700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14596, 'Xiaba', 'Xiaba', 'Hsia-pa,Xiaba,Xiaba Xiang,xia ba,xia ba xiang,霞拔,霞拔乡', 25.9278500, 118.6888900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14597, 'Xiaba', 'Xiaba', 'Hsia-pa,Hsia-pa-hsu,Hsia-pa-hsü,Xiaba,Xiaba Xiang,xia ba,xia ba xiang,下坝,下坝乡', 24.8799800, 116.0373900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14598, 'Wuzhou', 'Wuzhou', 'Ng-chu-su,Ngo Chau,Ngo-chiu-chhi,Ngouzcouh,Ngu-ciu,Ngô Châu,Ngô͘-chiu-chhī,Ngù-ciŭ,Ts''ang-wu,Ts''ang-wu-hsien,Ts’ang-wu,Ts’ang-wu-hsien,Uchzhou,Vudzou,WUZ,Wu-chou,Wu-chou-shih,Wu-cou,Wu-čou,Wuchow,Wuzhou,ujeou si,wazhw,wu zhou,wu zhou shi,wwzhww,Ǹg-chû-sṳ,Вуџоу,Учжоу,واژو,ووژوؤ,ووژوو,梧州,梧州市,우저우 시', 23.4833300, 111.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14599, 'Wuzhong', 'Wuzhong', 'Uchzhunpu,Wu-chung,Wu-chung-p''u,Wu-chung-pao,Wu-chung-p’u,Wu-chung-shih,Wuzhong,Wuzhong Xian,Wuzhong Zhen,wu zhong,wu zhong zhen,吴忠,吴忠镇', 37.9867000, 106.2010000, 'CN', '2015-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14600, 'Wuzhen', 'Wuzhen', 'T''ung-hsiang,T’ung-hsiang,Wu-chen,Wuzhen,Wuzhen Zhen,wu zhen,wu zhen zhen,乌镇,乌镇镇', 30.7453600, 120.4851000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14601, 'Yancheng', 'Yancheng', 'Uchzhay,Wu-chai,Wu-chai-hsien,Wu-chia,Wuzhai,Wuzhai Xian,Yancheng,Yancheng Zhen,wu zhai xian,yan cheng,yan cheng zhen,五寨县,砚城,砚城镇', 38.9153800, 111.8692800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14602, 'Wuyun', 'Wuyun', 'Chin-yun,Chin-yun-hsien,Chin-yun-hsien-chih,Chin-yün,Chin-yün-hsien,Chin-yün-hsien-chih,Jinyun Xian,Tsinyun,Tsinyün,Wuyun,Wuyun Zhen,jin yun xian,wu yun,wu yun zhen,五云,五云镇,缙云县', 28.6538800, 120.0669300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14603, 'Wuyuan', 'Wuyuan', 'Hai-yen,Hai-yen-hsien,Hai-yen-hsien-ch''eng,Hai-yen-hsien-ch’eng,Haiyan,Haiyan Xian,Wu-yuan-chen,Wu-yüan-chen,Wuyuan,Wuyuan Zhen,hai yan,hai yan xian,wu yuan,wu yuan zhen,武原,武原镇,海盐,海盐县', 30.5153900, 120.9485600, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14604, 'Ziyang', 'Ziyang', 'Wu-yuan-hsien,Wu-yüan-hsien,Wuyuan,Wuyuan Xian,Ziyang,Ziyang Zhen,wu yuan xian,zi yang,zi yang zhen,婺源县,紫阳,紫阳镇', 29.2497200, 117.8547200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14605, 'Wuyu', 'Wuyu', 'Wuyu,wu yu,浯屿', 24.3355100, 118.1448900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14606, 'Wuquan', 'Wuquan', 'Uyan,Wu-yang-hsien,Wuquan,Wuquan Zhen,Wuyang,wu quan,舞泉', 33.4440800, 113.5709000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14607, 'Wuyang', 'Wuyang', 'Wu-yang-chi,Wuyang', 31.9925000, 116.2472200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14608, 'Wujin', 'Wujin', 'Hsin-chin,Hsin-ching,Hsin-ching-hsien,Sinsing,Sintsing,Sintsinghsien,Wujin,Wuyang,Xinjin,wu jin,五津', 30.4113100, 103.8130200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14609, 'Wuyang', 'Wuyang', 'Wu-yuang,Wuyang,Wuyang Xiang,wu yang,wu yang xiang,武阳,武阳乡', 29.8471300, 118.6518700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14610, 'Wuyang', 'Wuyang', 'Wu-yang-shih,Wuyang,Wuyang Zhen', 26.7427800, 110.3283300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14611, 'Wuyang', 'Wuyang', 'Wu-yang-hsu,Wu-yang-hsü,Wuyang,Wuyang Zhen,wu yang,wu yang zhen,武阳,武阳镇', 25.7685700, 115.9180300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14612, 'Wuyang', 'Wuyang', 'Chiu-wu-ch''uan,Chiu-wu-ch’uan,Ngchun,Ngchunyun,Ngchün,Ngchünyün,Wu-ch''uan,Wu-ch''uan-chiu-chih,Wu-ch''uan-ku-chih,Wu-ch’uan,Wu-ch’uan-chiu-chih,Wu-ch’uan-ku-chih,Wuchwan,Wuyang,Wuyang Zhen,wu yang,wu yang zhen,吴阳,吴阳镇', 21.3476600, 110.6882900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14613, 'Wuxue', 'Wuxue', 'Guangji,Kuang-chi,Kuang-chi-hsien,Wu-hsueh,Wu-hsueh-chen,Wu-hsüeh,Wu-hsüeh-chen,Wuhiutsun,Wusueh,Wuxue,Wuxue Jiedao,wu xue,wu xue jie dao,武穴,武穴街道', 29.8505800, 115.5525000, 'CN', '2014-12-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14614, 'Wuxuan', 'Wuxuan', 'Mosun,Mosun-hsien,Mosün,Mosün-hsien,Wu-hsuan,Wu-hsuan-chen,Wu-hsuan-hsien,Wu-hsuen-hsien,Wu-hsüan,Wu-hsüan-chen,Wu-hsüan-hsien,Wu-hsüen-hsien,Wuxuan,wu xuan,武宣', 23.6246600, 109.6520100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14615, 'Wuxing', 'Wuxing', 'Wu-hsing,Wuxing,wu xing,五星', 34.0661100, 108.7911100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14616, 'Shixiang', 'Shixiang', 'Shixiang,Wuxie,Wuxie Zhen,shi xiang,wu xie zhen,五泄镇,狮象', 29.6879100, 120.0850000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14617, 'Fengzhou', 'Fengzhou', 'Duancun,Fengzhou,Fengzhou Zhen,Tuan-ts''un,Tuan-ts''un-chen,Tuan-ts’un,Tuan-ts’un-chen,Wu-hsiang,Wuxiang,Wuxiang Xian,feng zhou,feng zhou zhen,wu xiang xian,丰州,丰州镇,武乡县', 36.8427800, 112.8541700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14618, 'Wuxiang', 'Wuxiang', 'Mi-le-yuan,Mi-le-yüan,Wu-hsiang,Wu-hsiang-chen,Wuxiang,Wuxiang Zhen,wu xiang,wu xiang zhen,武乡,武乡镇', 33.1863900, 107.0488900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14619, 'Wuxia', 'Wuxia', 'Wu-shan-hsien,Wushan Xian,Wuxia,Wuxia Zhen,wu shan xian,wu xia,wu xia zhen,巫山县,巫峡,巫峡镇', 31.0797100, 109.8758800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14620, 'Wuxi', 'Wuxi', 'Bu-sek-chhi,Bû-sek-chhī,Gorad Usi,U-sek,Usi,Usis,Vo Tich,Vuhszi,Vusi,Vusio,Vuzsiz,Vuŝio,Vô Tích,WUX,Wu-hsi,Wu-hsi-hsien,Wu-hsi-shih,Wu-si,Wusih,Wusih-hsien,Wusihsien,Wuxi,Wuxi Shi,usi si,vukasi,wu xi,wu xi shi,wwshy,wwsy,xu si,Ù-sék,Вуси,Горад Усі,Уси,Усі,Үshi,Үши,וושי,ووشي,ووشی,ۋۇشى شەھىرى,ਵੁਕਸੀ,อู๋ซี,ཝུའུ་ཞི།,无锡,无锡市,無錫,無錫市,우시 시', 31.5688700, 120.2885700, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14621, 'Wuxi', 'Wuxi', 'Usi,Wu-ch''i,Wu-ch''i-chen,Wu-ch’i,Wu-ch’i-chen,Wu-hsi,Wuxi,Wuxi Zhen,wu xi,wu xi zhen,Уси,乌溪,乌溪镇', 31.3089700, 118.6562900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14622, 'Wuwangkou', 'Wuwangkou', 'Wuwangkou,Wuwangkou Xiang,wu wang kou,wu wang kou xiang,吴王口,吴王口乡', 39.0451200, 114.0185800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14623, 'Tongxiang', 'Tongxiang', 'T''ung-hsiang,TVX,Tongxiang,Tongxiang Shi,Tunghiang,Tóngxiāng Shì,T’ung-hsiang,Wu-t''ung,Wu-t''ung-chen,Wu-t’ung,Wu-t’ung-chen,Wutong,Wutong Jiedao,tong xiang,tong xiang shi,wu tong,wu tong jie dao,桐乡,桐乡市,梧桐,梧桐街道', 30.6328700, 120.5608100, 'CN', '2012-11-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14624, 'Wutong', 'Wutong', 'Wu-t''ung,Wu-t''ung-wei,Wu-t’ung,Wu-t’ung-wei,Wutong,Wutong Zhen,wu tong,wu tong zhen,梧桐,梧桐镇', 25.7290200, 118.7430300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14625, 'Wutang', 'Wutang', 'Wutang,Wutang Zhen,wu tang,wu tang zhen,梧塘,梧塘镇', 25.4943300, 119.0783200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14626, 'Wutan', 'Wutan', 'Wutan,Wutan Zhen,wu tan,wu tan zhen,武潭,武潭镇', 28.5188900, 111.7558300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14627, 'Taicheng', 'Taicheng', 'Taicheng,Taicheng Zhen,Wu-t''ai-hsien,Wu-t’ai-hsien,Wucheng,Wutai,Wutai Xian,tai cheng,tai cheng zhen,wu tai xian,五台县,台城,台城镇', 38.7310200, 113.2280000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14628, 'Wushi', 'Wushi', 'Wu-shih,Wu-shih-hsu,Wu-shih-hsü,Wushek,Wushi,Wushi Zhen,Wushihhui,wu shi,wu shi zhen,乌石,乌石镇', 24.5745500, 113.5956400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14629, 'Wushi', 'Wushi', 'Wu-shih,Wu-shih-chiang,Wushi,Wushi Zhen,wu shi,wu shi zhen,乌石,乌石镇', 20.5529700, 109.8659400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14630, 'Wushan', 'Wushan', 'Wu-shan-chen,Wushan,Wushan Zhen,wu shan,wu shan zhen,吴山,吴山镇', 32.1372500, 113.0713800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14631, 'Wuqu', 'Wuqu', 'Wu-ch''u,Wu-ch’ü,Wuqu,Wuqu Zhen,wu qu,wu qu zhen,五曲镇,武曲', 27.2336100, 119.5655600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14632, 'Wuqiao', 'Wuqiao', 'Wuqiao,Wuqiao Zhen,wu qiao,wu qiao zhen,吴桥,吴桥镇', 32.4354500, 119.7553400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14633, 'Wuqiao', 'Wuqiao', 'Wuqiao,Wuqiao Jiedao,wu qiao,wu qiao jie dao,五桥,五桥街道', 30.7796700, 108.4550600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14634, 'Wuqiao', 'Wuqiao', 'Wu-ch''iao,Wu-ch''iao-ho,Wu-ch’iao,Wu-ch’iao-ho,Wuqiao,Wuqiao Zhen,wu qiao,wu qiao zhen,伍桥,伍桥镇', 28.5849900, 115.2423000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14635, 'Wuqi', 'Wuqi', 'Wu-ch''i,Wu-ch''i-chen,Wu-ch’i,Wu-ch’i-chen,Wuqi,Wuqi Xian,wu qi,wu qi xian,吴起,吴起县', 36.9263100, 108.1717100, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14636, 'Wuniu', 'Wuniu', 'Wu-niu-ma-tao,Wuniu,Wuniu Zhen,Wuniumadao,wu niu,wu niu zhen,乌牛,乌牛镇', 28.0387100, 120.7913900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14637, 'Wuning', 'Wuning', 'Wuning,Wuning Zhen,wu ning,wu ning zhen,武宁,武宁镇', 37.3682500, 121.5563700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14638, 'Dongyang', 'Dongyang', 'Dongyang,Dongyang Shi,Tung-yang,Tung-yang-hsien,Tung-yang-hsien-ch''eng,Tung-yang-hsien-ch’eng,Wuning,dong yang,dong yang shi,东阳,东阳市', 29.2677800, 120.2252800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14639, 'Chengxiang', 'Chengxiang', 'Chengxiang,Chengxiang Zhen,Wu-ming-hsien,Wu-yuan,Wu-yüan,Wuming,cheng xiang,cheng xiang zhen,城厢,城厢镇', 23.1609600, 108.2775900, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14640, 'Wumaying', 'Wumaying', 'Wu-chia-ma-ying,Wumaying,Wumaying Xiang,wu ma ying,wu ma ying xiang,吴马营,吴马营乡', 39.6450000, 112.4855600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14641, 'Wuma', 'Wuma', 'Wuma,wu ma,五马', 33.0635000, 105.4425300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14642, 'Wuluo', 'Wuluo', 'Wuluo,Wuluo Zhen,wu luo,wu luo zhen,伍洛,伍洛镇', 30.9829000, 113.8066000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14643, 'Wuluo', 'Wuluo', 'Wu-lo,Wuluo,Wuluo Zhen,wu luo,wu luo zhen,乌罗,乌罗镇', 28.0933200, 108.7928100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14644, 'Huaibin Chengguanzhen', 'Huaibin Chengguanzhen', 'Huai-pin,Huai-pin-chen,Huaibin,Huaibin Chengguanzhen,Uluntszi,Wu-lung-chi,Wulongji,huai bin cheng guan zhen,淮滨城关镇', 32.4639700, 115.4081200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14645, 'Wulipu', 'Wulipu', 'Wulipu,Wulipu Zhen,wu li pu,wu li pu zhen,五里铺,五里铺镇', 30.7369500, 112.2007500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14646, 'Wuli', 'Wuli', 'Wuli,Wuli Xiang,Wuliping,wu li,wu li xiang,五里,五里乡', 29.8964600, 110.3449800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14647, 'Wuling', 'Wuling', 'Wu-ling-chen,Wuling,Wuling Zhen,Wulingchang,wu ling,wu ling zhen,武陵,武陵镇', 30.5059500, 108.2588400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14648, 'Changde', 'Changde', 'CGD,Cangde,Cchang-te,Ch''ang-te,Ch''ang-te-ch''eng,Ch''ang-te-hsien,Ch''ang-te-shih,Chandeh,Changde,Changde Shi,Changteh,Changteh-hsien,Ch’ang-te,Ch’ang-te-ch’eng,Ch’ang-te-hsien,Ch’ang-te-shih,Siong-daik,Siong-tek-chhi,Siòng-dáik,Siông-tek-chhī,Song-tet-su,Sòng-tet-sṳ,Thuong GJuc,Thường Đức,Wuling,chang de,chang de shi,changda,changdeo si,changdy,Čangdė,Čchang-te,Чангде,Чандэ,چانگدا,چانگدی,常徳,常徳市,常德,常德市,창더 시', 29.0463800, 111.6783000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14649, 'Wuling', 'Wuling', 'Wu-ling-an,Wuling,wu ling,武陵', 25.6313900, 117.7157400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14650, 'Wulijie', 'Wulijie', 'Wu-li-chieh,Wulijie,Wulijie Zhen,wu li jie,wu li jie zhen,五里界,五里界镇', 30.3394900, 114.3921100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14651, 'Wukang', 'Wukang', 'Deqing,Wu-k''ang-hsien,Wu-k''ang-hsien-ch''eng,Wu-k’ang-hsien,Wu-k’ang-hsien-ch’eng,Wukang,Wukang Zhen,de qing,wu kang,wu kang zhen,德清,武康,武康镇', 30.5415500, 119.9593500, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14652, 'Wujingfu', 'Wujingfu', 'Wu-ching,Wu-ching-fu,Wujingfu,Wujingfu Zhen,wu jing fu,wu jing fu zhen,五经富,五经富镇', 23.5666000, 116.0696800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14653, 'Wujing', 'Wujing', 'Wu-ching,Wu-ching-chen,Wujing,Wujing Zhen,wu jing,wu jing zhen,午井,午井镇', 34.3157300, 107.8254900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14654, 'Wujing', 'Wujing', 'Wu-ching,Wu-ching-hsu,Wu-ching-hsü,Wujing,Wujing Zhen,wu jing,wu jing zhen,乌迳,乌迳镇', 25.2533000, 114.6113800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14655, 'Wujiayao', 'Wujiayao', 'Wu-chia-yao,Wujiayao,Wujiayao Zhen,wu jia yao,wu jia yao zhen,吴家窑,吴家窑镇', 39.7845300, 112.8565600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14656, 'Wujiashan', 'Wujiashan', 'Dongxihu,Dongxihu Qu,Wujiashan,Wujiashan Jiedao,dong xi hu,wu jia shan,东西湖,吴家山', 30.6170200, 114.1316600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14657, 'Wujia', 'Wujia', 'Wu-chia-p''u,Wu-chia-p’u,Wujia,Wujia Zhen,Wujiapu,Wukiapu,wu jia,wu jia zhen,吴家,吴家镇', 29.6348200, 105.3911000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14658, 'Wujiao', 'Wujiao', 'Wujiao,Wujiao Xiang,wu jiao,wu jiao xiang,五蛟,五蛟乡', 36.4497900, 107.8054200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14659, 'Wujiang', 'Wujiang', 'Wu-chiang-p''u,Wu-chiang-p’u,Wujiang,Wujiang Zhen,Wujiangpu,wu jiang,wu jiang zhen,乌江,乌江镇', 39.0166700, 100.4666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14660, 'Wujiang', 'Wujiang', 'Wu-chiang,Wu-chiang-chen,Wujiang,Wujiang Zhen,Wukiang,wu jiang,wu jiang zhen,乌江,乌江镇', 31.8660300, 118.4614200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14661, 'Wujiang', 'Wujiang', 'Wu-chiang,Wujiang,Wujiang Zhen,wu jiang,wu jiang zhen,乌江,乌江镇', 27.2141000, 115.2645100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14662, 'Wudian', 'Wudian', 'Wu-chia-ta-tien,Wu-chia-tien,Wudian,Wudian Zhen,Wujiadian,Wukiatien,wu dian,wu dian zhen,吴店,吴店镇', 31.9280800, 113.6423000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14663, 'Wujia', 'Wujia', 'Wujia,Wujia Xiang,Wujiagang,wu jia,wu jia xiang,伍家,伍家乡', 30.6463500, 111.3471300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14664, 'Wuji', 'Wuji', 'Wu-chi,Wuji,Wuji Zhen,wu ji,wu ji zhen,吴集,吴集镇', 34.2011100, 119.0433300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14665, 'Wuhu', 'Wuhu', 'Bu-ho-chhi,Bû-hô͘-chhī,Ouhu,U-hu,Ukhu,Vu Ho,Vu Hồ,Vuhu,Vukhu,Vuĥu,WHU,Wu-chu,Wu-hu-hsien,Wu-hu-shih,Wuhu,Wuhu Shi,uhu si,waha,wu hu,wu hu shi,Ù-hù,Вуху,Уху,Վուհու,واها,ووہو,芜湖,芜湖市,蕪湖,蕪湖市,우후 시', 31.3372800, 118.3735100, 'CN', '2014-11-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14666, 'Wuhe Chengguanzhen', 'Wuhe Chengguanzhen', 'Wu-ho,Wu-ho-hsien,Wuhe,Wuhe Chengguanzhen,wu he cheng guan zhen,五河城关镇', 33.1386000, 117.8658200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14667, 'Wuhan', 'Wuhan', 'Bu-han-chhi,Bú-hàn-chhī,Gorad Ukhan'',Gouchan,Owhan,U-hang,Uhan,Uhana,Uhanas,Uhaņa,Ukhan,Ukhan'',Uxan,Vu Han,Vu-hon-su,Vuhan,Vuhani,Vuhano,Vujhan,Vukhan,Vú-hon-sṳ,Vũ Hán,WUH,Wu-chan,Wu-han-shih,Wuhan,Wuhan Shi,uhan si,ukhani,uuxan,vuhana,vukan,vukhana,wu han,wu han shi,wwhan,xu han,Ū-háng,Γουχάν,Вухан,Вухан балһсн,Горад Ухань,Ухан,Ухань,Үkhan'',Үхань,Үһән,Ուհան,ווהאן,ووهان,ووھان,ووہان,ۋۇخەن شەھىرى,ܘܘܗܐܢ,वूहान,ਵੂਖ਼ਨ,வுகான்,വൂഹാൻ,อู่ฮั่น,ཝུའུ་ཧན་གྲོང་ཁྱེར།,ဝူဟန့်မြို့,უხანი,ዉሃን,武汉,武汉市,武漢,武漢市,우한 시,', 30.5833300, 114.2666700, 'CN', '2015-04-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14668, 'Wuhai', 'Wuhai', 'Hai-p''o-wan-shih,Hai-po-wan,Hai-p’o-wan-shih,Haibowan,O Hai,O-hai-chhi,O͘-hái-chhī,U-hai,Uhajus,Ukhaj,Vu-hoi-su,Vuhajo,Vû-hói-sṳ,WUA,Wu-chaj,Wu-hai-shih,Wuhai,hai bo wan,uhai si,wu hai,wu hai shi,wwhay,Ô Hải,Ŭ-hāi,Ухай,Үхай хот,ووهای,ووہائی,乌海,乌海市,海勃湾,烏海,烏海市,우하이 시', 39.6844200, 106.8158300, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14669, 'Wugui', 'Wugui', 'Wu-kuei-ch''ang,Wu-kuei-ch’ang,Wugui,Wugui Zhen,wu gui,wu gui zhen,五桂,五桂镇', 29.8188200, 105.7556300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14670, 'Wugong', 'Wugong', 'P''u-chi,P''u-chi-chen,Puji,Puji Zhen,P’u-chi,P’u-chi-chen,Wu-kung,Wu-kung-chan,Wugong,pu ji zhen,wu gong,普集镇,武功', 34.2582900, 108.2067500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14671, 'Wugong', 'Wugong', 'Wu-kung,Wu-kung-chen,Wugong,wu gong,武功', 33.3341200, 113.5695600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14672, 'Yakou', 'Yakou', 'Wugang,Yakou,Yakou Jiedao,ya kou,ya kou jie dao,垭口,垭口街道', 33.2964900, 113.5235100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14673, 'Wufu', 'Wufu', 'Wufu,Wufu Zhen,wu fu,wu fu zhen,五夫,五夫镇', 27.6123900, 118.2050100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14674, 'Wufeng', 'Wufeng', 'Ch''ang-lo,Changlo-fu,Ch’ang-lo,Wu-feng-hsien,Wufeng,wu feng,五峰', 30.2000000, 110.6908100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14675, 'Wudui', 'Wudui', 'Wudui,Wudui Xiang,wu dui,wu dui xiang,五队,五队乡', 34.3166700, 119.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14676, 'Wuduhe', 'Wuduhe', 'Wu-tu-ho,Wuduhe,Wuduhe Zhen,wu du he,wu du he zhen,雾渡河,雾渡河镇', 31.1086400, 111.2057400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14677, 'Wudong', 'Wudong', 'Wu-tung,Wudong,Wudong Zhen,wu dong,wu dong zhen,五洞,五洞镇', 30.2099000, 107.3412700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14678, 'Wudian', 'Wudian', 'Wu-tien,Wudian,Wudian Zhen,wu dian,wu dian zhen,吴店,吴店镇', 31.9832500, 112.7710200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14679, 'Wangjiaping', 'Wangjiaping', 'Wangjiaping,Wu-tao-shui,Wudaoshui,Wudaoshui Zhen,wang jia ping,wu dao shui zhen,五道水镇,汪家坪', 29.7037000, 109.9131600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14680, 'Wudabao', 'Wudabao', 'Wu-ta-pao,Wudabao,Wudabao Xiang,wu da bao,wu da bao xiang,五大堡,五大堡乡', 27.6078200, 119.1693000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14681, 'Wuda', 'Wuda', 'Bayinsai,Ud,Wu-ta,Wu-ta-shih,Wuda,Wuda Qu,ba yin sai,wu da,wu da qu,乌达,乌达区,巴音赛', 39.4994400, 106.7116700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14682, 'Wuci', 'Wuci', 'Hougeyang,Wu-tzu,Wuci,hou ge yang,wu ci,后隔洋,吾祠', 25.5969000, 117.6440100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14683, 'Wucheng', 'Wucheng', 'Wu-ch''eng-ts''un,Wu-ch’eng-ts’un,Wucheng,Wucheng Xiang,wu cheng,wu cheng xiang,吴城,吴城乡', 39.8347200, 113.6235500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14684, 'Laocheng', 'Laocheng', 'Laocheng,Laowucheng,Wu-ch''eng-hsien,Wu-ch’eng-hsien,Wucheng', 37.1427800, 115.8883300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14685, 'Wucheng', 'Wucheng', 'Wucheng,Wucheng Zhen,wu cheng,吴城', 33.4500400, 113.7541300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14686, 'Wucheng', 'Wucheng', 'Wu-wei-hsien,Wucheng,Wuwei,Wuwei Xian,Wuweichow,wu cheng,wu wei xian,无为县,无城', 31.2837000, 117.9019300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14687, 'Wucheng', 'Wucheng', 'Wucheng,Wucheng Zhen,wu cheng,wu cheng zhen,五城,五城镇', 29.6007700, 118.1749500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14688, 'Wucheng', 'Wucheng', 'Wocheng Zhen,Wu-ch''eng-chen,Wu-ch’eng-chen,Wucheng,Wucheng Zhen,wu cheng,wu cheng zhen,吴城,吴城镇', 29.1840400, 116.0048900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14689, 'Wolong', 'Wolong', 'Wolong,Wolong Xiang,wo long,wo long xiang,卧龙,卧龙乡', 30.9057400, 113.8954000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14690, 'Wenzhou', 'Wenzhou', 'On Chau,Un-chiu-chhi,Un-chiu-chhī,Ung-ciu,Uundzhou,Vehn''chzhou,Ven''chzhou,Vencsou,Vendzou,Vendžou,Vengou,Venĝou,Vun-chu-su,Vûn-chû-sṳ,WNZ,Wen-chou,Wen-chou-shih,Wen-cou,Wen-čou,Wenchow,Wenchow-fu,Wenju shehiri,Wentsjou,Wenzhou,Wenzhou Shi,Wénju shehiri,Yung-chia,Yung-chia-hsien,Yungkai,Yungkia,Yungkia-hsien,wen zhou,wen zhou shi,wntshw,wnzhw,wonjeou si,Ôn Châu,Ŭng-ciŭ,Веньчжоу,Венџоу,Вэньчжоу,Уънджоу,ونتشو,ونژو,温州,温州市,溫州市,원저우 시', 27.9994200, 120.6668200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14691, 'Wenyan', 'Wenyan', 'Wen-chia-yen,Wenyan,Wenyan Zhen,wen yan,wen yan zhen,闻堰,闻堰镇', 30.1273500, 120.1705100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14692, 'Wenquan', 'Wenquan', 'Ven''syan,Ven’syan,Wen,Wen-hsien,Wenquan,Wenxian,wen quan,温泉', 34.9352800, 113.0733300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14693, 'Wenxian Chengguanzhen', 'Wenxian Chengguanzhen', 'Chengguan Zhen,Wen,Wen-hsien,Wenxian,Wenxian Chengguanzhen,cheng guan zhen,wen xian,wen xian cheng guan zhen,城关镇,文县,文县城关镇', 32.9471200, 104.6813900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14694, 'Tongcheng', 'Tongcheng', 'Tongcheng,Tongcheng Zhen,Ven''si,Ven’si,Wen-hsi,Wen-hsi-hsien,Wensi,Wensihsien,Wenxi Xian,tong cheng,tong cheng zhen,wen xi xian,桐城,桐城镇,闻喜县', 35.3546800, 111.2160800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14695, 'Wenxi', 'Wenxi', 'Wen-ch''i,Wen-ch''i-chieh,Wen-ch’i,Wen-ch’i-chieh,Wen-hsi,Wenxi,Wenxi Zhen,wen xi,wen xi zhen,温溪,温溪镇', 28.1593100, 120.3856200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14696, 'Wentang', 'Wentang', 'Wentang,Wentang Zhen,wen tang,wen tang zhen,温塘,温塘镇', 29.1701500, 110.2039800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14697, 'Wentang', 'Wentang', 'Wentang,Wentang Zhen,wen tang,wen tang zhen,温汤,温汤镇', 27.6925300, 114.2856900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14698, 'Fengcheng', 'Fengcheng', 'Fengcheng,Fengcheng Zhen,Ven''shuy,Ven’shuy,Wen-shui-hsien,Wenshui,Wenshui Xian,feng cheng,feng cheng zhen,wen shui xian,凤城,凤城镇,文水县', 37.4327800, 112.0233300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14699, 'Wenshui', 'Wenshui', 'Wenshui,Wenshui Zhen,wen shui,wen shui zhen,温水,温水镇', 28.4505600, 106.5266700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14700, 'Wenshang', 'Wenshang', 'Wen-shang-hsien,Wenshang', 35.7275000, 116.4961100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14701, 'Wenquan', 'Wenquan', 'Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 33.1333300, 106.7439600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14702, 'Wenquan', 'Wenquan', 'Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 31.3591100, 108.5222400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14703, 'Wenquan', 'Wenquan', 'Wenquan,Ying-hsien,Ying-shan-hsien,Yingshan,wen quan,温泉', 30.8492800, 115.6991000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14704, 'Wenquan', 'Wenquan', 'Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 29.4159200, 115.8897700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14705, 'Wenquan', 'Wenquan', 'Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 28.2019400, 107.3452800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14706, 'Wenquan', 'Wenquan', 'Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 23.6491700, 113.6500000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14707, 'Wenqiao', 'Wenqiao', 'Wen-ch''iao,Wen-ch’iao,Wenqiao,Wenqiao Xiang,wen qiao,wen qiao xiang,文桥,文桥乡', 29.6614300, 116.2986500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14708, 'Wenping', 'Wenping', 'Wanping,Wenping,Wenping Zhen,wan ping,wen ping,wen ping zhen,宛坪,稳坪,稳坪镇', 28.3137300, 108.2174900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14709, 'Wenping', 'Wenping', 'Lu-tien,Lu-tien-hsien,Ludian,Lutienting,Wen-p''ing-chen,Wen-p’ing-chen,Wenping,wen ping,文屏', 27.1930600, 103.5273000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14710, 'Wenlou', 'Wenlou', 'Wenlou,Wenlou Zhen,wen lou,wen lou zhen,文楼,文楼镇', 22.0939300, 110.4215700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14711, 'Wenlong', 'Wenlong', 'Wen-lung-hsu,Wen-lung-hsü,Wenlong,Wenlong Zhen,Wenlung,wen long,wen long zhen,汶龙,汶龙镇', 24.7670400, 114.8987700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14712, 'Wenling', 'Wenling', 'T''ai-p''ing,Taipinghsien,T’ai-p’ing,Wen-ling-hsien,Wen-ling-hsien-ch''eng,Wen-ling-hsien-ch’eng,Wenlin,Wenling,wen ling,温岭', 28.3752400, 121.3841600, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14713, 'Wenlin', 'Wenlin', 'Jen-shou,Jen-shou-hsien,Jenshow,Jenshow-hsien,Renshou,Wenlin,wen lin,文林', 29.9981400, 104.1399200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14714, 'Wenjiapo', 'Wenjiapo', 'Wen-chia-p''o,Wen-chia-p’o,Wenjiapo,wen jia po,文家坡', 34.6929300, 107.1346000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14715, 'Wenjiao', 'Wenjiao', 'Mankiao,Wen-chiao-shih,Wenjiao,Wenjiao Zhen,Wunkao,wen jiao,wen jiao zhen,文教,文教镇', 19.6699200, 110.9067400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14716, 'Wenjiangsi', 'Wenjiangsi', 'Wen-chiang-ssu,Wenjiangsi,wen jiang si,温江寺', 33.8123100, 106.5386800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14717, 'Wenjiang', 'Wenjiang', 'Wenjiang,Wenjiang Xiang,wen jiang,wen jiang xiang,文江,文江乡', 25.9899700, 117.8672200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14718, 'Wenheng', 'Wenheng', 'Wenheng,Wenheng Xiang,wen heng,wen heng xiang,文亨,文亨乡', 25.6674200, 116.7542900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14719, 'Wengyang', 'Wengyang', 'Jiufang,Weng-ch''iang-chieh,Weng-ch’iang-chieh,Weng-yang-chieh,Wengyang,Wengyang Zhen,jiu fang,weng yang,weng yang zhen,九房,翁垟,翁垟镇', 28.0287100, 120.9661300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14720, 'Wengtian', 'Wengtian', 'Weng-t''ien,Weng-t''ien-shih,Weng-t’ien,Weng-t’ien-shih,Wengtian,Wengtian Zhen,weng tian,weng tian zhen,翁田,翁田镇', 19.9329500, 110.8731300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14721, 'Wengcheng', 'Wengcheng', 'Chiu-weng-yuan,Chiu-weng-yüan,Weng-ch''eng-chen,Weng-ch’eng-chen,Weng-yuan,Weng-yuan Old City,Weng-yuan-chiu-chih,Weng-yüan,Weng-yüan Old City,Weng-yüan-chiu-chih,Wengcheng,Wengcheng Zhen,Yungyun,Yungyunhsien,Yungyün,weng cheng,weng cheng zhen,翁城,翁城镇', 24.3760700, 113.8265900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14722, 'Wengang', 'Wengang', 'Wengang,Wengang Zhen,wen gang,wen gang zhen,文港,文港镇', 28.2865900, 116.1087500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14723, 'Wenfeng', 'Wenfeng', 'Chi-shai-hsien,Chi-shui,Chi-shui-hsien-ch''eng,Chi-shui-hsien-ch’eng,Jishui,Jishui Xian,Kishui,Kishuihsien,Wenfeng,Wenfeng Zhen,ji shui xian,wen feng,wen feng zhen,吉水县,文峰,文峰镇', 27.1989900, 115.1196300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14724, 'Wenfang', 'Wenfang', 'Wen-fang-chen,Wenfang,Wenfang Zhen,wen fang,wen fang zhen,文坊,文坊镇', 28.0388000, 117.3390800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14725, 'Laxiong', 'Laxiong', 'Laxiong,Wendu,Wendu Cangzuxiang,la xiong,wen dou,wen dou cang zu xiang,拉雄,文都,文都藏族乡', 35.7814800, 102.3972600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14726, 'Wendou', 'Wendou', 'Wen-tou,Wen-tou-ch''ang,Wen-tou-ch’ang,Wendou,Wendou Xiang,wen dou,wen dou xiang,文斗,文斗乡', 29.8906300, 108.5913200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14727, 'Wencun', 'Wencun', 'Wen-ts''un,Wen-ts’un,Wencun,Wencun Zhen,wen cun,wen cun zhen,汶村,汶村镇', 21.8626900, 112.4951100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14728, 'Tianfu', 'Tianfu', 'Chiu-wen-teng,K''un-yu,K’un-yü,Tianfu,Tianfu Jiedao,Wen-teng,Wen-teng-ch''eng,Wen-teng-ch’eng,Wen-teng-hsien,Wencheng,Wendeng,Wendeng Shi,tian fu,tian fu jie dao,wen deng,wen deng shi,天福,天福街道,文登,文登市', 37.1972300, 122.0522800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14729, 'Wencheng', 'Wencheng', 'Wencheng,Wencheng Xiang,wen cheng,wen cheng xiang,文城,文城乡', 33.0558500, 113.7978000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14730, 'Wenchang', 'Wenchang', 'Wenchang,Wenchang Zhen,wen chang,wen chang zhen,文昌,文昌镇', 29.7817500, 119.2013600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14731, 'Wenchang', 'Wenchang', 'Bun-chhiong-chhi,Bûn-chhiong-chhī,Mencheong,Mencheonghsien,Van Xuong,Vehn''chan,Vun Sio,Văn Xương,WEC,Wen-ch''ang-hsien,Wen-ch''eng-chen,Wen-chiang,Wen-ch’ang-hsien,Wen-ch’eng-chen,Wenchang,Wenchang Shi,Wencheng,Wencheng Zhen,wen chang,wen chang shi,wen cheng,wen cheng zhen,wonchang si,wynchang,Вэньчан,وینچانگ,文城,文城镇,文昌,文昌市,원창 시', 19.6157000, 110.7489400, 'CN', '2013-10-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14732, 'Wen’an', 'Wen''an', 'Wen''an,Wen''an Zhen,Wen-an-ssu,Wen’an,Wen’an Zhen,wen an,wen an zhen,问安,问安镇', 30.5243400, 111.8227300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14733, 'Weizhuang', 'Weizhuang', 'Wei-chuang,Wei-chuang-chen,Weizhuang,Weizhuang Zhen,wei zhuang,韦庄', 34.9735600, 109.9273000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14734, 'Weizhou', 'Weizhou', 'Veychzhou,Wei-chou,Wei-chou-chen,Weizhou,Weizhou Zhen,Xianzhou,wei zhou,wei zhou zhen,威州,威州镇', 38.1060500, 114.1499800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14735, 'Weizhou', 'Weizhou', 'Mao-wen,Mao-wen-ch''iang-tsu-tzu-chih-hsien,Mao-wen-ch’iang-tsu-tzu-chih-hsien,Veychzhou,Wei-chiu,Wei-chou,Wei-chou-chen,Weikiu,Weizhou,Wenchuan,Wenchuan Xian,wei zhou,wen chuan xian,威州,汶川县', 31.4926700, 103.5849100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14736, 'Weizheng', 'Weizheng', 'Wei-cheng,Weizheng,Weizheng Zhen,wei zheng,wei zheng zhen,威整,威整镇', 23.6507500, 112.7313600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14737, 'Weiyuankou', 'Weiyuankou', 'Weiyuankou,Weiyuankou Zhen,wei yuan kou,wei yuan kou zhen,韦源口,韦源口镇', 30.1333300, 115.2333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14738, 'Weiyuan', 'Weiyuan', 'Wei-yuan-pao,Wei-yüan-pao,Weiyuan,Weiyuan Zhen,Weiyuanbu,wei yuan,wei yuan zhen,威远,威远镇', 39.9485600, 112.3414800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14739, 'Weiyuan', 'Weiyuan', 'Hu-chu,Hu-chu-hsien-t''u-tsu-tzu-chih-ch''u,Hu-chu-hsien-t’u-tsu-tzu-chih-ch’ü,Hu-chu-t''u-tsu-tzu-chih-hsien,Hu-chu-t’u-tsu-tzu-chih-hsien,Huzhu,Huzhu Tuzhu Zizhixian,Khuchzhu,Ugampu,Ujam-bu,Wei-yuan-chen,Wei-yuan-pao,Wei-yüan-chen,Wei-yüan-pao,Weiyuan,Weiyuanbu,Weyyuan'',Weyyuan’,hu zhu tu zu zi zhi xian,wei yuan,互助土族自治县,威远', 36.8531600, 101.9916900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14740, 'Qingyuan', 'Qingyuan', 'Qingyuan,Veyyuan'',Veyyuan’,Wei-yuan-hien,Wei-yuan-hsien,Wei-yüan-hién,Wei-yüan-hsien,Weiyuan,Weiyuan Xian,qing yuan,wei yuan xian,清源,渭源县', 35.1367400, 104.2221000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14741, 'Weiyuan', 'Weiyuan', 'Ching-ku,Ching-ku-chieh,Ching-ku-hsien,Dajie,Jinggu,Kingku,Kingkuhsien,Mongwaw,Weiyuan,wei yuan,威远', 23.4683100, 100.6835400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14742, 'Weixin', 'Weixin', 'Wei-hsin-ch''ang,Wei-hsin-ch’ang,Weixin,Weixin Zhen,Weixinchang,wei xin,wei xin chang,wei xin zhen,维新,维新场,维新镇', 29.7596600, 111.1079200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14743, 'Mingzhou', 'Mingzhou', 'Mingzhou,Veysyan,Wai,Wei,Wei-chen,Wei-hsien,Wei-hsien-ch''eng-kuan,Wei-hsien-ch’eng-kuan,Weixian,ming zhou,洺州', 36.9761000, 115.2566300, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14744, 'Weixi', 'Weixi', 'Weixi,Weixi Xiang,wei xi,wei xi xiang,渭溪,渭溪乡', 28.2477800, 110.5636100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14745, 'Weituo', 'Weituo', 'Veyte,Wei-t''e,Wei-t''o,Wei-t’e,Wei-t’o,Weituo,Weituo Zhen,wei tuo,wei tuo zhen,渭沱,渭沱镇', 30.0398300, 106.1470100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14746, 'Weitian', 'Weitian', 'Wei-t''ien,Wei-t’ien,Weitian,Weitian Zhen,wei tian,wei tian zhen,渭田,渭田镇', 27.7130600, 118.7866700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14747, 'Weitang', 'Weitang', 'Chia-shan,Chia-shan-hsien,Chiu-shan,Jiashan,Kashan,Weitang,Weitang Zhen,jia shan,wei tang,wei tang zhen,嘉善,魏塘,魏塘镇', 30.8502100, 120.9113800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14748, 'Weishi Chengguanzhen', 'Weishi Chengguanzhen', 'Wei-shih,Wei-shih-hsien,Weishi,Weishi Chengguanzhen,Yu-shih,Yü-shih,wei shi cheng guan zhen,尉氏城关镇', 34.4136100, 114.1872200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14749, 'Weishanzhuang', 'Weishanzhuang', 'Wei-shan-chuang,Weishanzhuang,Weishanzhuang Zhen,wei shan zhuang,wei shan zhuang zhen,魏善庄,魏善庄镇', 39.6296100, 116.4164500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14750, 'Weishan', 'Weishan', 'Wei-shan-chen,Weishan,Weishan Zhen,wei shan,wei shan zhen,巍山,巍山镇', 29.3299900, 120.4348200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14751, 'Weirong', 'Weirong', 'Veybenchzhen'',Veybenchzhen’,Wei-ch''eng-chen,Wei-ch’eng-chen,Wei-jung,Wei-jung-chen,Wei-jung-tschon,Wei-jung-tschön,Wei-peng-chen,Wei-shu-chen,Wei-wu-chen,Weirong,wei rong,威戎', 35.3675200, 105.7610000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14752, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Qu,Chang-an-hsien,Chang’an,Chang’an Qu,Wei-ch''u,Wei-ch''u-chen,Wei-ch’ü,Wei-ch’ü-chen,Weiqu,zhang an,zhang an qu,长安,长安区', 34.1511100, 108.9450000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14753, 'Weiqi', 'Weiqi', 'Weiqi,Weiqi Zhen,wei qi,wei qi zhen,位奇,位奇镇', 38.6333300, 101.1000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14754, 'Weinan', 'Weinan', 'Oi-nang,Ui-lam-chhi,Vehjnan'',Veinan,Vejnan,Veynan,Vi Nam,Vị Nam,Wei-nan-hsien,Weinan,Weinan Shi,Wej-nan,waynan,wei nan,wei nan shi,weinan si,wyynan,Ôi-nàng,Ūi-lâm-chhī,Вејнан,Вэйнань,وئینان,واینان,渭南,渭南市,웨이난 시', 34.5035500, 109.5089100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14755, 'Weihai', 'Weihai', 'Ui-hai,Ui-hai-chhi,Ui-hái-chhī,Uy Hai,Uy Hải,Vehjkhaj,Veihai,WEH,Wei-hai-shih,Wei-hai-wei,Wei-hai-wei-shih,Weihai,Weihai Shi,Wej-chaj,wei hai,wei hai shi,weihai si,wey hi,wyhay,Ŭi-hāi,Вэйхай,ویهای,وییہائی,ۋېيخەي شەھىرى,เวยไห่,威海,威海市,웨이하이 시', 37.5091400, 122.1135600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14756, 'Weifang', 'Weifang', 'Duy Phuong,Duy Phường,I-hng-chhi,Vehjfan,Vejfang,WEF,Wei,Wei-fang-shih,Wei-hsien,Weifang,Wej-fang,i fang shi,wei fang,wei fang shi,weipang si,wyfang,Î-hng-chhī,Вејфанг,Вэйфан,ویفانگ,イ坊市,潍坊市,濰坊,웨이팡 시', 36.7100000, 119.1019400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14757, 'Weidi', 'Weidi', 'Wei-ti,Wei-ti-hsu,Wei-ti-hsü,Weidi,Weidi Zhen,wei di,wei di zhen,围底,围底镇', 22.7132800, 111.6666700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14758, 'Weicun', 'Weicun', 'Wei-ts''un,Wei-ts''un-chen,Wei-ts’un,Wei-ts’un-chen,Weicun,Weicun Zhen,wei cun,wei cun zhen,魏村,魏村镇', 31.9693600, 119.9269500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14759, 'Waxi', 'Waxi', 'Waxi,Waxi Zhen,wa xi,wa xi zhen,瓦溪,瓦溪镇', 23.5374800, 115.1097100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14760, 'Wawu', 'Wawu', 'Wawu,Wawumiao,wa wu,瓦屋', 33.8896400, 112.6608600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14761, 'Wanzhi', 'Wanzhi', 'Wan-chih,Wan-chih-chen,Wanzhi,Wanzhi Zhen,Wu-hu-hsien,Wuhu,Wuhu Xian,wan zhi,wan zhi zhen,wu hu xian,湾沚,湾沚镇,芜湖县', 31.1468700, 118.5670800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14762, 'Wanzhai', 'Wanzhai', 'Wanzhai,Wanzhai Xiang,wan zhai,wan zhai xiang,万寨,万寨乡', 30.1367500, 109.5761700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14763, 'Wanzai', 'Wanzai', 'Wan-tsai,Wanzai,Wanzai Jiedao,wan zi,wan zi jie dao,湾仔,湾仔街道', 22.2016600, 113.5278200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14764, 'Wanxiang', 'Wanxiang', 'Wan-hsiang,Wan-hsiang-chen,Wanxiang,Wanxiang Zhen,wan xiang,wan xiang zhen,万祥,万祥镇', 30.9695500, 121.8150300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14765, 'Wanxian', 'Wanxian', 'Wan,Wan-hsien,Wan-hsien-shih,Wanxian', 30.8154400, 108.3708900, 'CN', '2013-06-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14766, 'Wantouqiao', 'Wantouqiao', 'Wan-t''ou-ch''iao,Wan-t’ou-ch’iao,Wantouqiao', 26.8411100, 110.6194400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14767, 'Wantian', 'Wantian', 'Wan-t''ien,Wan-t’ien,Wantian,Wantian Xiang,wan tian,wan tian xiang,万田,万田乡', 25.9414800, 115.7208800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14768, 'Wantan', 'Wantan', 'Wan-yun,Wan-yün,Wantan,Wantan Zhen,wan tan,wan tan zhen,湾潭,湾潭镇', 30.0482900, 110.4235900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14769, 'Wanshun', 'Wanshun', 'Wanshun,Wanshun Zhen,wan shun,wan shun zhen,万顺,万顺镇', 30.0400600, 106.9715900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14770, 'Wanshi', 'Wanshi', 'Wanshi,wan shi,万市', 30.0977400, 119.5689300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14771, 'Wansheng', 'Wansheng', 'Wan-sheng-chen,Wan-shou-ch''ang,Wan-shou-ch’ang,Wansheng,Wansheng Qu,Wanshengchang,Wanshengcheng,Wanshengqu,wan sheng,wan sheng qu,万盛,万盛区', 28.9629000, 106.9284400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14772, 'Wanshan', 'Wanshan', 'Chang-chia-p''ing,Chang-chia-p’ing,Chiu-sheng-ch''i,Chiu-sheng-ch’i,Chiuhsingchi,Sheng-ch''i,Sheng-ch''i-hsien,Sheng-ch’i,Sheng-ch’i-hsien,Sheng-hsi-ku-ch''ih,Sheng-hsi-ku-ch’ih,Wan-shan-ch''ang,Wan-shan-ch’ang,Wan-shan-t''e-ch''u,Wan-shan-t’e-ch’ü,Wanshan,Wanshan Tequ,Wanshan Zhen,Wanshanssu,Wanshansze,wan shan,wan shan zhen,万山,万山镇', 27.5232000, 109.2060000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14773, 'Wanquan', 'Wanquan', 'Wanquan,Wanquan Xiang,wan quan,wan quan xiang,万全,万全乡', 26.6712400, 117.1851100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14774, 'Wanqingsha', 'Wanqingsha', 'Wan-ch''ing-sha,Wan-ch’ing-sha,Wanqingsha,Wanqingsha Zhen,wan qing sha,wan qing sha zhen,万顷沙,万顷沙镇', 22.7067400, 113.5446000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14775, 'Wanning', 'Wanning', 'Maning,Manning,Manyun,Van Leng,WXJ,Wan,Wan-ch''eng-chen,Wan-ch’eng-chen,Wan-hsien,Wan-ning-hsien,Wancheng,Wanning,Wanning Shi,wan cheng,wan ning,wan ning shi,wanning si,wannyng,واننینگ,万城,万宁市,万寧,万寧市,萬寧,완닝 시', 18.7993100, 110.3841000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14776, 'Xiasanhe', 'Xiasanhe', 'Wan-sheng-sha,Wannian,Wannian Zhen,Xiasanhe,wan nian,wan nian zhen,xia san he,万年,万年镇,下三和', 31.9822800, 121.4192900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14777, 'Wanmingang', 'Wanmingang', 'Wanmin Xiang,Wanmingang,wan min gang,wan min xiang,万民乡,万民岗', 29.4076900, 109.9193100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14778, 'Wanmao', 'Wanmao', 'Wanmao,wan mao,完冒', 34.8000000, 103.2000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14779, 'Wanling', 'Wanling', 'Wanling,Wanling Zhen,wan ling,wan ling zhen,湾岭,湾岭镇', 19.1748500, 109.9356500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14780, 'Wanli', 'Wanli', 'Wanli,Wanli Jiedao,wan li,wan li jie dao,湾里,湾里街道', 31.3971600, 118.3890900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14781, 'Wanbu', 'Wanbu', 'Wan-chia-fou,Wan-chia-pu,Wan-chia-tou,Wanbu,Wanbu Zhen,Wanjiabu,wan bu,wan bu zhen,万埠,万埠镇', 28.8580000, 115.6519300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14782, 'Wanhu', 'Wanhu', 'Wanhu,Wanhu Zhen,wan hu,wan hu zhen,万户,万户镇', 29.2446500, 116.5132000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14783, 'Wanhe', 'Wanhe', 'Wan-ho-tien,Wanhe,Wanhe Zhen,Wanhedian,wan he,wan he zhen,万和,万和镇', 32.2311000, 113.2777000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14784, 'Wangzuo', 'Wangzuo', 'Wangzuo,Wangzuo Zhen,wang zuo,wang zuo zhen,王佐,王佐镇', 39.8075600, 116.1560900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14785, 'Wangguan', 'Wangguan', 'Vantszoguan'',Vantszöguan’,Wang-tzi-k''uan,Wang-tzu-kuan,Wang-tzï-k’üan,Wangguan,Wangziguan,wang guan,望关', 33.4591700, 105.3616700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14786, 'Wangzhuangbu', 'Wangzhuangbu', 'Vaychzhuanbao,Wang-chuang-pao,Wangchwangpao,Wangjuangbu,Wangzhuangbu,Wangzhuangbu Zhen,wang zhuang bao,wang zhuang bao zhen,王庄堡,王庄堡镇', 39.4353800, 113.9090200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14787, 'Wangxian', 'Wangxian', 'Wang-hsien,Wang-hsien-chieh,Wangxian,Wangxian Xiang,wang xian,wang xian xiang,望仙,望仙乡', 27.2570200, 115.8716800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14788, 'Wangxi', 'Wangxi', 'Dawangcun,Ta-wang-ts''un,Ta-wang-ts’un,Wangxi,Wangxi Zhen,wang xi,wang xi zhen,汪溪,汪溪镇', 30.6867300, 118.9728200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14789, 'Wangwu', 'Wangwu', 'Wang-wu-shih,Wangwu,Wangwu Zhen,wang wu,wang wu zhen,王五,王五镇', 19.6562300, 109.2907100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14790, 'Wangwenzhuang', 'Wangwenzhuang', 'Wang-wan,Wang-wen-chuang,Wang-yin-chuang,Wangwenzhuang,Wangwenzhuang Zhen,wang wen zhuang,wang wen zhuang zhen,王稳庄,王稳庄镇', 38.8827400, 117.2677200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14791, 'Xiawangwa', 'Xiawangwa', 'Wangwa Xiang,Xiawangwa,wang wa xiang,xia wang wa,下王洼,王洼乡', 36.1060200, 106.6360900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14792, 'Wangu', 'Wangu', 'Wan-ku-ch''ang,Wan-ku-chen,Wan-ku-ch’ang,Wangu,Wangu Zhen,Wanguchang,wan gu,wan gu zhen,万古,万古镇', 29.6824200, 105.9355100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14793, 'Wangtuan', 'Wangtuan', 'Wang-t''uan-chi,Wang-t’uan-chi,Wangtuan,Wangtuan Zhen,wang tuan,wang tuan zhen,王疃,王疃镇', 37.3080800, 121.9753600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14794, 'Wangting', 'Wangting', 'Wangting,Wangting Zhen,wang ting,wang ting zhen,望亭,望亭镇', 31.4401000, 120.4409200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14795, 'Wangtan', 'Wangtan', 'Wang-t''an-shih,Wang-t’an-shih,Wangtan,Wangtan Zhen,wang tan,wang tan zhen,王坛,王坛镇', 29.7868300, 120.6718100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14796, 'Wangtai', 'Wangtai', 'Wang-t''ai-p''u,Wang-t’ai-p’u,Wangtai,Wangtai Zhen,wang tai,wang tai zhen,王台,王台镇', 26.6398600, 117.9691400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14797, 'Wangren', 'Wangren', 'Wang-jen,Wang-jen-p''u,Wang-jen-p’u,Wangren,Wangren Zhen,wang ren,wang ren zhen,汪仁,汪仁镇', 30.1537200, 115.1235000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14798, 'Wangqu', 'Wangqu', 'Wang-ch''u,Wang-ch''u-chen,Wang-ch’ü,Wang-ch’ü-chen,Wangqu,Wangqu Zhen,wang qu,wang qu zhen,王曲,王曲镇', 34.0767800, 108.9640600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14799, 'Wangqinzhuang', 'Wangqinzhuang', 'Wangqinzhuang,wang qin zhuang,王秦庄', 39.2294200, 117.0896800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14800, 'Wangqingtuo', 'Wangqingtuo', 'Wang-ch''ing-ch''a,Wang-ch''ing-t''o,Wang-ch’ing-ch’a,Wang-ch’ing-t’o,Wangkingto,Wangqingtuo,Wangqingtuo Zhen,wang qing tuo,wang qing tuo zhen,王庆坨,王庆坨镇', 39.1853900, 116.8964400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14801, 'Wangqiao', 'Wangqiao', 'Wang-ch''iao,Wang-ch’iao,Wangqiao,Wangqiao Zhen,wang qiao,wang qiao zhen,王桥,王桥镇', 34.6161100, 108.6422200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14802, 'Wangqiao', 'Wangqiao', 'Wang-ch''iao,Wang-ch’iao,Wangqiao,Wangqiao Zhen,wang qiao,wang qiao zhen,汪桥,汪桥镇', 29.9773800, 112.7048100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14803, 'Wangqiao', 'Wangqiao', 'Wangqiao,Wangqiao Zhen,wang qiao,wang qiao zhen,王桥,王桥镇', 28.1766200, 116.7134000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14804, 'Wangpu', 'Wangpu', 'Wangpu,wang pu,王铺', 35.0571200, 105.4358500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14805, 'Wangping', 'Wangping', 'Wangping,Wangping Zhen,wang ping,wang ping zhen,王平,王平镇', 39.9672300, 115.9812500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14806, 'Wangping', 'Wangping', 'Wangping,wang ping,王坪', 33.9276600, 112.4590300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14807, 'Wangmudu', 'Wangmudu', 'T''u-mu-tu,T’u-mu-tu,Wang-mu-tu,Wangmudu,Wangmudu Zhen,wang mu du,wang mu du zhen,王母渡,王母渡镇', 25.6109500, 114.9965300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14808, 'Wangmin', 'Wangmin', 'Wangmin,Wangminbu,Wangminxiang,wang min,王民', 35.8009800, 105.7360600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14809, 'Wangmeng', 'Wangmeng', 'Wangmeng,Wangmeng Xiang,wang meng,wang meng xiang,王孟,王孟乡', 33.9287300, 113.9551000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14810, 'Wangluo', 'Wangluo', 'Wang-lo,Wangluo,wang luo,王洛', 33.9676900, 113.4797000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14811, 'Wanglinkou', 'Wanglinkou', 'Dongwangliukou,Tung-wang-lin-k''ou,Tung-wang-lin-k’ou,Tung-wang-liu-k''ou,Tung-wang-liu-k’ou,Wanglinkou,Wanglinkou Xiang,wang lin kou,wang lin kou xiang,王林口,王林口乡', 38.8221900, 114.3421900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14812, 'Wangliao', 'Wangliao', 'Wang-liao-chen,Wangliao,Wangliao Zhen,wang liao,王寮', 34.8077100, 109.2317000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14813, 'Wangjing', 'Wangjing', 'Wangjing,Wangjing Jiedao,wang jing,wang jing jie dao,望京,望京街道', 39.9933000, 116.4728400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14814, 'Wangjiaxu', 'Wangjiaxu', 'Wang-chia-hsu,Wang-chia-hsü,Wangjiaxu,Wangjiaxu Xiang,wang jia wei,wang jia wei xiang,汪家圩,汪家圩乡', 28.5388000, 115.3090900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14815, 'Wangjiaqiao', 'Wangjiaqiao', 'Wang-chia-ch''iao,Wang-chia-ch’iao,Wangjiaqiao,Wangjiaqiao Zhen,wang jia qiao,wang jia qiao zhen,王家桥,王家桥镇', 30.1351000, 111.6711200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14816, 'Wangjiangjing', 'Wangjiangjing', 'Wang-chiang-ching,Wang-chiang-ching-chen,Wangjiangjing,Wangjiangjing Zhen,wang jiang jing,wang jiang jing zhen,王江泾,王江泾镇', 30.8834500, 120.7053000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14817, 'Leiyang', 'Leiyang', 'Leiyang,Wang-chiang,Wang-chiang-hsien,Wangjiang,Wangjiang Xian,Wangkiang,Wangkiang-hsien,lei yang,wang jiang,wang jiang xian,望江,望江县,雷阳', 30.1204300, 116.6829200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14818, 'Wangjiafan', 'Wangjiafan', 'Wang-chia-fan,Wangjiafan,Wangjiafan Xiang,wang jia fan,wang jia fan xiang,王家畈,王家畈乡', 30.1825200, 111.3594600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14819, 'Wangdian', 'Wangdian', 'Wang-chia-tien,Wangdian,Wangdian Zhen,Wangjiadian,Wangkiatien,wang dian,wang dian zhen,王店,王店镇', 31.3924000, 113.9664600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14820, 'Wangdian', 'Wangdian', 'Wang-chia-tien,Wangdian,Wangdian Zhen,Wangjiadian,wang dian,wang dian zhen,王店,王店镇', 30.7083900, 111.6686700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14821, 'Wangjiachang', 'Wangjiachang', 'Wang-chia-ch''ang,Wang-chia-ch’ang,Wangjiachang,Wangjiachang Zhen,wang jia chang,wang jia chang zhen,王家厂,王家厂镇', 29.7613900, 111.5344400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14822, 'Wangji', 'Wangji', 'Wangji,wang ji,汪集', 30.7782000, 114.7031800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14823, 'Wanghu', 'Wanghu', 'Wang-hu-ts''un,Wang-hu-ts’un,Wang-ku,Wanghu,Wanghu Xiang,wang hu,wang hu xiang,望狐,望狐乡', 39.7955900, 113.9579000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14824, 'Yinzhu', 'Yinzhu', 'Chiao-nan,Wang-ko-chuang,Wanggezhuang,Yinzhu,yin zhu,隐珠', 35.8786100, 119.9752800, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14825, 'Wanggang', 'Wanggang', 'Wang-chia-kang,Wang-kang,Wanggang,Wanggang Zhen,wang gang,wang gang zhen,汪岗,汪岗镇', 30.6227800, 115.1729400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14826, 'Wangfu', 'Wangfu', 'Wang-fu-hsu,Wang-fu-hsü,Wangfu,Wangfu Zhen,wang fu,wang fu zhen,望夫,望夫镇', 21.7323900, 111.3700600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14827, 'Wang’er', 'Wang''er', 'Wang''er,Wang''er Zhen,Wang-erh,Wang’er,Wang’er Zhen,wang er,wang er zhen,汪二,汪二镇', 28.2892600, 117.5163900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14828, 'Wangdun', 'Wangdun', 'Wangdun,Wangdun Xiang,wang dun,wang dun xiang,汪墩,汪墩乡', 29.3375200, 116.2629300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14829, 'Wangdingdi', 'Wangdingdi', 'Wangdingdi,Wangdingdi Jiedao,wang ding di,wang ding di jie dao,王顶堤,王顶堤街道', 39.1026000, 117.1363300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14830, 'Wangdian', 'Wangdian', 'Wang-tien,Wangdian,wang dian,王店', 32.8035000, 113.4734000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14831, 'Wangdian', 'Wangdian', 'Wang-tien,Wang-tien-chen,Wangdian,Wangdian Zhen,wang dian,wang dian zhen,王店,王店镇', 30.6242100, 120.7156100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14832, 'Wangcun', 'Wangcun', 'Wang-ts''un-p''u,Wang-ts’un-p’u,Wangcun,Wangcunpu,wang cun,王村', 33.0168600, 112.4120200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14833, 'Wangcun', 'Wangcun', 'Wang-ts''un,Wang-ts’un,Wangcun,Wangcun Zhen,wang cun,wang cun zhen,王村,王村镇', 29.7575400, 118.3996100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14834, 'Wangcun', 'Wangcun', 'Wang-ts''un,Wang-ts’un,Wangcun,Wangcun Zhen,wang cun,wang cun zhen,汪村,汪村镇', 29.6292400, 117.8051700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14835, 'Wangcun', 'Wangcun', 'Wang-ts''un,Wang-ts’un,Wangchen,Wangcun,Wangcun Zhen,wang cun,wang cun zhen,王村,王村镇', 28.7411100, 109.9433300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14836, 'Wangcheng', 'Wangcheng', 'Wang-tzu-ch''eng,Wang-tzu-ch’eng,Wangcheng,Wangcheng Zhen,wang cheng,wang cheng zhen,王城,王城镇', 31.9579800, 112.9363300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14837, 'Wangcao', 'Wangcao', 'Wang-ts''ao-ch''ang,Wang-ts''ao-pa,Wang-ts’ao-ch’ang,Wang-ts’ao-pa,Wangcao,Wangcao Zhen,Wangcaoba,wang cao,wang cao zhen,旺草,旺草镇', 28.1171100, 107.2667200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14838, 'Wangbuzhuang', 'Wangbuzhuang', 'Wang-pu-chuang,Wang-pu-chuang-chen,Wangbuzhuang,Wangpu', 39.6775000, 117.4286100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14839, 'Wangbu', 'Wangbu', 'Wangbu,Wangbu Zhen,wang bu,wang bu zhen,望埠,望埠镇', 24.2661400, 113.4891300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14840, 'Anping', 'Anping', 'Anping,Wang''anping,Wang’anping', 27.8663900, 110.1161100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14841, 'Wanfu', 'Wanfu', 'Wanfu,Wanfu Zhen,wan fu,wan fu zhen,万福,万福镇', 27.4115400, 114.8829300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14842, 'Wandian', 'Wandian', 'Wan-chia-tien,Wandian,Wandian Zhen,wan dian,wan dian zhen,万店,万店镇', 31.8328200, 113.4914300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14843, 'Wancun', 'Wancun', 'Wancun,Wancun Xiang,wan cun,wan cun xiang,万村,万村乡', 28.7128700, 117.4720000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14844, 'Wan’an', 'Wan''an', 'Wan''an,Wan''an Zhen,Wan-an-ts''un,Wan-an-ts’un,Wan’an,Wan’an Zhen,wan an,wan an zhen,万安,万安镇', 35.5419200, 111.1279600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14845, 'Wan’an', 'Wan''an', 'Wan''an,Wan''an Zhen,Wan-an-chieh,Wan’an,Wan’an Zhen,Wao-an-chieh,wan an,wan an zhen,万安,万安镇', 29.7916700, 118.2152800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14846, 'Wan’an', 'Wan''an', 'Wan''an,Wan''an Zhen,Wan-an-chen,Wan’an,Wan’an Zhen,wan an,wan an zhen,万安,万安镇', 26.8964900, 117.4253100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14847, 'Wan’an', 'Wan''an', 'Wan''an,Wan''an Xiang,Wan’an,Wan’an Xiang,wan an,wan an xiang,万安,万安乡', 25.1349300, 116.0919600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14848, 'Waitun', 'Waitun', 'Waitun,Waitun Xiang,wai tun,wai tun xiang,外屯,外屯乡', 27.3347200, 118.9880600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14849, 'Waina', 'Waina', 'Waina,Wainapu,wai na,外纳', 33.2063900, 105.0497200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14850, 'Waihai', 'Waihai', 'Waihai,Waihai Jiedao,wai hai,wai hai jie dao,外海,外海街道', 22.5968300, 113.1465000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14851, 'Waigang', 'Waigang', 'Wai-kang,Wai-kang-chen,Waigang,Waigang Zhen,wai gang,wai gang zhen,外冈,外冈镇', 31.3630600, 121.1705600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14852, 'Wafangdian', 'Wafangdian', 'Fu,Fu-hsien,Fuxian,Wa-fan-tien,Wa-fang-tien,Wa-fang-tien-chen,Wafangdian', 39.6183300, 122.0080600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14853, 'Zhongwadi', 'Zhongwadi', 'Chung-wa-ti,Hsi-wa-ti,Tung-wa-ti,Tung-yen-ts''un,Tung-yen-ts’un,Wa-ti,Wadi Zhen,Zhongwadi,wa di zhen,zhong wa di,中畖底,畖底镇', 35.4433300, 111.1522200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14854, 'Ulan', 'Ulan', 'Etuoke Qi,Khotok,O-cha-k''o-ch''i,O-cha-k’o-ch’i,O-erh-to-ssu-yu-i-chung-ch''i,O-erh-to-ssu-yu-i-chung-ch''i-wang-fu,O-erh-to-ssu-yu-i-chung-ch’i,O-erh-to-ssu-yu-i-chung-ch’i-wang-fu,O-t''o-k''o-ch''i,O-t''o-k''o-miao,O-t’o-k’o-ch’i,O-t’o-k’o-miao,Ordos Barun Gar Domda,Otog,Otog Qi,Residency Knyaz'' Otok,Residency Knyaz’ Otok,Ulan,Ulan Balgas,Wu-lan-chen,Wu-lan-ha-la-ka-su,Wu-lan-ha-la-ka-su-chen,Wulan,Wulan Zhen,Wulanhalagasu,e tuo ke qi,wu lan,wu lan zhen,乌兰,乌兰镇,鄂托克旗', 39.0937400, 107.9802200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14855, 'Tuzhai', 'Tuzhai', 'T''u-chai,Tuzhai,T’u-chai,tu zhai,涂寨', 24.9830100, 118.8319400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14856, 'Tuxiang', 'Tuxiang', 'T''u-hsiang,T''u-hsiang-pa,Tuxiang,Tuxiang Zhen,T’u-hsiang,T’u-hsiang-pa,Xiongjiabang,tu xiang,tu xiang zhen,xiong jia bang,吐祥,吐祥镇,熊家塝', 30.7129300, 109.1555600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14857, 'Tuxi', 'Tuxi', 'T''u-hsi,Tuxi,Tuxi Zhen,T’u-hsi,tu xi,tu xi zhen,土溪,土溪镇', 28.2977800, 107.7500000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14858, 'Tutang', 'Tutang', 'Tutang,Tutang Zhen,tu tang,tu tang zhen,土塘,土塘镇', 29.3623900, 116.4181500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14859, 'Tutai', 'Tutai', 'Tutai,Tutai Xiang,tu tai,tu tai xiang,土台,土台乡', 32.5875800, 111.2601100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14860, 'Tushan', 'Tushan', 'Tushan,Tushan Zhen,tu shan,tu shan zhen,土山,土山镇', 37.0554100, 119.6745100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14861, 'Tuqiao', 'Tuqiao', 'T''u-ch''iao,T''u-ch''iao-chen,Tuqiao,Tuqiao Zhen,T’u-ch’iao,T’u-ch’iao-chen,tu qiao,tu qiao zhen,土桥,土桥镇', 31.9395800, 119.0588500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14862, 'Tuping', 'Tuping', 'T''u-p''ing-ch''ang,Tuping,Tuping Zhen,T’u-p’ing-ch’ang,tu ping,tu ping zhen,土坪,土坪镇', 28.2650200, 107.3610300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14863, 'Tuoxi', 'Tuoxi', 'Tuoxi,Tuoxi Xiang,tuo xi,tuo xi xiang,托溪,托溪乡', 27.4441700, 119.3647200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14864, 'Tuokou', 'Tuokou', 'T''o-k''ou,T''o-k''ou-p''u,Tokow,Tuokou,T’o-k’ou,T’o-k’ou-p’u', 27.1247200, 109.6247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14865, 'Tuojiang', 'Tuojiang', 'Feng-huang-hsien,Fenghuang,Fenghwang,Fenghwang-hsien,Fenghwangtin,Fengwang,T''o-chiang-chen,Tuojiang,T’o-chiang-chen,tuo jiang,沱江', 27.9547200, 109.5679800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14866, 'Tuojiang', 'Tuojiang', 'Chiang-hua-hsien,Chiang-hua-yao-tsu-tzu-chih-hsien,Chiu-chiang-hua,Kianghwa,Kianghwa-hsien,T''o-chiang,T''o-chiang-chen,Tuojiang,Tuojiangzhen,T’o-chiang,T’o-chiang-chen,tuo jiang,沱江', 25.1866700, 111.5716700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14867, 'Tuofeng', 'Tuofeng', 'T''o-feng,Tuofeng,Tuofeng Xiang,T’o-feng,tuo feng,tuo feng xiang,驼峰,驼峰乡', 39.6178000, 113.4483500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14868, 'Tuodian', 'Tuodian', 'Shuang-pai,Shuangbai,T''o-tien,T''o-tien-chen,T''o-tien-chieh,Tuodian,T’o-tien,T’o-tien-chen,T’o-tien-chieh,tuo dian,妥甸', 24.6666700, 101.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14869, 'Tuochuan', 'Tuochuan', 'T''o-ch''uan-pu,Tuochuan,Tuochuan Zhen,Tuochuanbu,T’o-ch’uan-pu,tuo chuan,tuo chuan zhen,拖船,拖船镇', 28.1531300, 115.6606200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14870, 'Tuocheng', 'Tuocheng', 'Chiu-lung-ch''uan,Chiu-lung-ch’uan,Lung-ch''uan,Lung-ch''uan-hsien,Lung-chun,Lung-chün,Lung-ch’uan,Lung-ch’uan-hsien,T''o-ch''eng,T''o-ch''eng-chen,Tuocheng,Tuocheng Zhen,T’o-ch’eng,T’o-ch’eng-chen,tuo cheng,tuo cheng zhen,佗城,佗城镇', 24.0618700, 115.1885500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14871, 'Huangshan', 'Huangshan', 'Chuang-san,Chuang-šan,Hoang Son,Hoàng Sơn,Huangshan,Huangshan City,Huangshan Shi,Khuanshan'',N̂g-soaⁿ-chhī,T''un-ch''i,T''un-ch''i-chen,T''un-ch''i-shih,T''un-hsi,TXN,Tun''si,Tunki,Tunqi,Tunxi,Tunxi Qu,T’un-ch’i,T’un-ch’i-chen,T’un-ch’i-shih,T’un-hsi,Uong-sang,Uòng-săng,huang shan,huang shan shi,hwangsan si,hwangshan,tun xi,tun xi qu,Туньси,Хуаншань,هوانگشان,ہوآنگشان,ہوانگشان شہر,屯溪,屯溪区,黃山市,黄山,黄山市,황산 시', 29.7113900, 118.3125000, 'CN', '2013-04-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14872, 'Linjiang', 'Linjiang', 'Linjiang,Linjiang Zhen,T''un-ch''ang,T''un-liu-chen,T''un-liu-hsien,T''un-liu-hsien-ch''eng,Tunliu,Tunliu Xian,T’un-ch’ang,T’un-liu-chen,T’un-liu-hsien,T’un-liu-hsien-ch’eng,lin jiang,lin jiang zhen,tun liu xian,屯留县,麟绛,麟绛镇', 36.3275000, 112.8819400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14873, 'Tuncheng', 'Tuncheng', 'T''un-ch''ang-chen,T''un-ch''ang-shih,Ting-ch''ang,Ting-ch’ang,Tunchang,Tuncheng,Tuncheng Zhen,T’un-ch’ang-chen,T’un-ch’ang-shih,tun cheng,tun cheng zhen,屯城,屯城镇', 19.3633300, 110.0977800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14874, 'Tunbao', 'Tunbao', 'T''un-pao,Tunbao,Tunbao Xiang,T’un-pao,tun bao,tun bao xiang,屯堡,屯堡乡', 30.3772100, 109.3752400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14875, 'Tumba', 'Tumba', 'Dongba,Dongba Xiang,Tumba,Tung-pa,dong ba,dong ba xiang,东巴,东巴乡', 36.3795500, 100.7703000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14876, 'Tubu', 'Tubu', 'Hsu-chia-fou,Hsü-chia-fou,T''u-chia,T''u-chia-fou,T''u-chia-fou-chen,T''u-chia-pu,Tubu,Tubu Xiang,Tujiabu,Tukiafow,T’u-chia,T’u-chia-fou,T’u-chia-fou-chen,T’u-chia-pu,Yongxiu,Yung-hsiu,tu bu,tu bu xiang,涂埠,涂埠乡', 29.0453200, 115.8126700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14877, 'Renhe', 'Renhe', 'Renhe,Renhe Zhen,T''ui-kuang,Tuiguang,T’ui-kuang,ren he,ren he zhen,人和,人和镇', 23.3328400, 113.2919800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14878, 'Tuguan', 'Tuguan', 'T''u-kuan-ts''un,Tuguan,Tuguan Zhen,Tuguancun,T’u-kuan-ts’un,Xinjie,tu guan,tu guan zhen,土官,土官镇', 24.9453600, 102.2002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14879, 'Tufang', 'Tufang', 'Tufang,Tufang Zhen,tu fang,tu fang zhen,涂坊,涂坊镇', 25.4712300, 116.4581200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14880, 'Tudi’ao', 'Tudi''ao', 'T''u-ti-ao,Tudi''ao,Tudi''ao Zhen,Tudi’ao,Tudi’ao Zhen,T’u-ti-ao,tu de ao,tu de ao zhen,土地坳,土地坳镇', 28.4605100, 108.2130800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14881, 'Tudian', 'Tudian', 'T''u-tien,T''u-tien-shih,Tudian,Tudian Zhen,T’u-tien,T’u-tien-shih,tu dian,tu dian zhen,屠甸,屠甸镇', 30.5804000, 120.6139200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14882, 'Tucheng', 'Tucheng', 'Tucheng,Tucheng Zhen,tu cheng,tu cheng zhen,土城,土城镇', 32.2637200, 110.6888400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14883, 'Tucheng', 'Tucheng', 'Tucheng,Tucheng Xiang,tu cheng,tu cheng xiang,土城,土城乡', 30.6560600, 111.1064900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14884, 'Tucheng', 'Tucheng', 'T''u-ch''eng-ch''ang,Tucheng,Tucheng Zhen,T’u-ch’eng-ch’ang,tu cheng,tu cheng zhen,土城,土城镇', 28.2925000, 105.9938900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14885, 'Tuanshansi', 'Tuanshansi', 'T''uan-shan-ssu,Tuanshansi,Tuanshansi Zhen,T’uan-shan-ssu,tuan shan si,tuan shan si zhen,团山寺,团山寺镇', 29.6050900, 112.3171100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14886, 'Tuanpo', 'Tuanpo', 'T''uan-po-wa,Tuanpo,Tuanpo Zhen,T’uan-po-wa,tuan po,tuan po zhen,团泊,团泊镇', 38.8996700, 117.1477400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14887, 'Tuanlinpu', 'Tuanlinpu', 'T''uanlin,Tuanlinpu,Tuanlinpu Zhen,T’uanlin,tuan lin pu,tuan lin pu zhen,团林铺,团林铺镇', 30.8769000, 112.1760600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14888, 'Tuankou', 'Tuankou', 'Tuankou,tuan kou,湍口', 30.0419300, 119.1527900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14889, 'Tuanfeng', 'Tuanfeng', 'Tuanfeng,Twanfeng,tuan feng,团风', 30.7136100, 114.9161300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14890, 'Touzao', 'Touzao', 'Touzao,Touzao Zhen,tou zao,tou zao zhen,头灶,头灶镇', 32.8892300, 120.5492400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14891, 'Touying', 'Touying', '', 39.9638900, 117.2183300, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14892, 'Touying', 'Touying', 'Touying,Touying Xiang,tou ying,tou ying xiang,头营,头营乡', 36.1648500, 106.2184500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14893, 'Toutuo', 'Toutuo', 'Toutuo,Toutuo Zhen,tou tuo,tou tuo zhen,头陀,头陀镇', 28.6307400, 121.1420800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14894, 'Toufang', 'Toufang', 'Toufang,tou fang,透防', 33.2500000, 105.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14895, 'Tongzi', 'Tongzi', 'T''ung-tzu-shan,Tongzi,Tongzi Zhen,Tongzichang,T’ung-tzu-shan,tong zi,tong zi zhen,桐梓,桐梓镇', 29.5589900, 107.9507300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14896, 'Loushanguan', 'Loushanguan', 'Loushanguan,Loushanguan Zhen,T''ung-tzu,T''ung-tzu-ch''eng,T''ung-tzu-hsien,Tongzi,Tongzi Xian,Tungtze,Tungtze-hsien,T’ung-tzu,T’ung-tzu-ch’eng,T’ung-tzu-hsien,lou shan guan,lou shan guan zhen,tong zi,tong zi xian,娄山关,娄山关镇,桐梓,桐梓县', 28.1368000, 106.8220000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14897, 'Tongzhou', 'Tongzhou', 'T''ung,T''ung-chen,T''ung-chou,T''ung-chou-ch''u,T''ung-chou-shih,T''ung-hsien,T''ung-hsien-chen,Tingchow,Tongxian,Tongzhou,Tunchzhou,Tunsyan'',Tunsyan’,T’ung,T’ung-chen,T’ung-chou,T’ung-chou-ch’ü,T’ung-chou-shih,T’ung-hsien,T’ung-hsien-chen,tong zhou,Тунчжоу,通州', 39.9039500, 116.6618300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14898, 'Tongyuan', 'Tongyuan', 'T''ung-yuan-fang,Tongyuan,Tongyuan Zhen,Tongyuanfang,Tungyunfang,T’ung-yüan-fang,tong yuan,通远', 34.5535300, 109.0403900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14899, 'Tongyuan', 'Tongyuan', 'T''ung-yuan,T''ung-yuan-chen,Tongyuan,Tongyuan Zhen,T’ung-yüan,T’ung-yüan-chen,tong yuan,tong yuan zhen,通元,通元镇', 30.4558500, 120.8390400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14900, 'Tongyuan', 'Tongyuan', 'T''ung-yuan,Tongyuan,Tongyuan Xiang,T’ung-yüan,tong yuan,tong yuan xiang,桐源,桐源乡', 28.0784500, 116.2219400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14901, 'Tongyang', 'Tongyang', 'T''ung-shan,T''ung-shan-hsien,Tongshan,Tongyang,T’ung-shan,T’ung-shan-hsien,tong yang,通羊', 29.6705400, 114.5969400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14902, 'Tongxu Chengguanzhen', 'Tongxu Chengguanzhen', 'T''ung-hsu,T''ung-hsu-hsien,Tongxu,Tongxu Chengguanzhen,Tungsu,Tungsuihsien,T’ung-hsü,T’ung-hsü-hsien,tong xu cheng guan zhen,通许城关镇', 34.4772200, 114.4583300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14903, 'Tongxing', 'Tongxing', 'T''ung-hsing-chen,Tongxing,Tongxing Xiang,Tongxingzhen,T’ung-hsing-chen,tong xing,通兴', 32.0154600, 121.5613400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14904, 'Tongxing', 'Tongxing', 'T''ung-hsing,T''ung-hsing-chi,T''ung-hsing-chieh,Tongxing,Tongxing Zhen,Tongxingjie,T’ung-hsing,T’ung-hsing-chi,T’ung-hsing-chieh,tong xing,tong xing zhen,同兴,同兴镇', 34.4166700, 119.4000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14905, 'Yuhai', 'Yuhai', 'T''ung-hsin,T''ung-hsin-ch''eng,T''ung-hsin-hsien,Tongxin,Tongxin Xian,Tungsin,Tunsin'' Chen,Tunsin’ Chen,T’ung-hsin,T’ung-hsin-ch’eng,T’ung-hsin-hsien,Yuhai,tong xin,tong xin xian,yu hai,同心,同心县,豫海', 36.9812900, 105.9060600, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14906, 'Tongxian', 'Tongxian', 'Tongxian,Tongxian Xiang,tong xian,tong xian xiang,通贤,通贤乡', 25.3016900, 116.4564100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14907, 'Tongxi', 'Tongxi', 'T''ung-hsi,Tongxi,Tongxi Zhen,T’ung-hsi,tong xi,tong xi zhen,铜溪,铜溪镇', 30.0004700, 106.1304300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14908, 'Pingxiang', 'Pingxiang', 'Pingxiang,Pingxiang Zhen,T''ung-wei,T''ung-wei-hien,T''ung-wei-hsien,Tongwei,Tunwey,T’ung-wei,T’ung-wei-hien,T’ung-wei-hsien,ping xiang,ping xiang zhen,平襄,平襄镇', 35.2079000, 105.2505800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14909, 'Tongwan', 'Tongwan', 'T''ung-wan,Tongwan,T’ung-wan', 27.5811100, 110.2772200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14910, 'Tongping', 'Tongping', 'T''ung-shu-p''ing,Tongping,Tongping Zhen,Tongshuping,T’ung-shu-p’ing,tong ping,tong ping zhen,桐坪,桐坪镇', 27.2500600, 114.9246900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14911, 'Tongshan', 'Tongshan', 'T''ung-shan,T''ung-shan-hsu,T''ung-shan-ts''un,Tongshan,Tongshan Xiang,T’ung-shan,T’ung-shan-hsü,T’ung-shan-ts’un,tong shan,tong shan xiang,铜山,铜山乡', 30.4243500, 118.2485200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14912, 'Fuding', 'Fuding', 'Fu-ting,Fu-ting-hsien,Fuding,Tongshan,fu ding,福鼎', 27.3273400, 120.2139900, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14913, 'Tongren', 'Tongren', 'Kiangkowhsien,T''ung-jen,T''ung-jen-hsien,T''ung-yen,TEN,Tongren,Tongren Shi,T’ung-jen,T’ung-jen-hsien,T’ung-yen', 27.7172200, 109.1852800, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14914, 'Tongquan', 'Tongquan', 'Ma-lung,Ma-lung-hsien,Malong,T''ung-ch''uan-chen,Tongquan,T’ung-ch’üan-chen,tong quan,通泉', 25.4000000, 103.5666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14915, 'Tongqing', 'Tongqing', 'T''ung-ch''ing-hsu,Tongqing,Tongqing Zhen,T’ung-ch’ing-hsü,tong qing,tong qing zhen,同庆,同庆镇', 21.5924100, 110.6924100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14916, 'Tongqian', 'Tongqian', 'Tongqian,Tongqianba,tong qian,铜钱', 33.0691700, 105.7638900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14917, 'Wusong', 'Wusong', 'T''ung-ling,T''ung-ling-hsien,Tongling,T’ung-ling,T’ung-ling-hsien,Wusong,Yuan-hsien-ch''eng,Yüan-hsien-ch’eng,tong ling,tong ling shi,wu song,五松,铜陵,铜陵市', 30.9500000, 117.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14918, 'Tongle', 'Tongle', 'Chiu-lo-yeh,Le-yeh,Leye,Lo-yeh,Lo-yeh-hsien,Lo-yeh-hsien-ch''eng,Lo-yeh-hsien-ch’eng,Lo-yeh-hsu,Lo-yeh-hsü,T''ung-lo,T''ung-lo-hsiang,Tongle,T’ung-lo,T’ung-lo-hsiang,tong le,同乐', 24.8475700, 106.5764000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14919, 'Tongjinpu', 'Tongjinpu', 'Tongjinpu,Tongjinpu Zhen,tong jin pu,tong jin pu zhen,通津铺,通津铺镇', 29.5384500, 110.9668500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14920, 'Tongjing', 'Tongjing', 'T''ung-ching-chen,Tongjing,Tongjing Zhen,T’ung-ching-chen,tong jing,tong jing zhen,统景,统景镇', 29.8565300, 106.8448000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14921, 'Tongjing', 'Tongjing', 'T''ung-chin,T''ung-ching,T''ung-ching-chen,Tongjing,Tongjing Zhen,Tungtsing,T’ung-chin,T’ung-ching,T’ung-ching-chen,tong jing,tong jing zhen,铜井,铜井镇', 31.7912600, 118.5466800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14922, 'Tongjing', 'Tongjing', 'Tongjing,Tongjing Tujiazu Xiang,tong jing,tong jing tu jia zu xiang,桶井,桶井土家族乡', 28.3352800, 108.2655600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14923, 'Tonghu', 'Tonghu', 'Tonghu,Tonghu Zhen,tong hu,tong hu zhen,潼湖,潼湖镇', 23.0842800, 114.1827900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14924, 'Tonghaikou', 'Tonghaikou', 'T''ung-hai-k''ou,Tonghaikou,Tonghaikou Zhen,T’ung-hai-k’ou,tong hai kou,tong hai kou zhen,通海口,通海口镇', 30.1971000, 113.1504600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14925, 'Tongguan', 'Tongguan', 'T''ung-kuan,Tongguan,Tongguan Zhen,T’ung-kuan,tong guan,tong guan zhen,铜官,铜官镇', 28.4558300, 112.8077800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14926, 'Tonggu', 'Tonggu', 'Lao-chin-p''ing,Lao-chin-p’ing,Tonggu', 26.5722200, 109.3094400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14927, 'Tongfang', 'Tongfang', 'T''ung-fang,Tongfang,Tongfang Zhen,T’ung-fang,tong fang,tong fang zhen,童坊,童坊镇', 25.8036700, 116.5506200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14928, 'Tongchuan', 'Tongchuan', 'San''tay,San-t''ai-hsien,San-t’ai-hsien,Santai,San’tay,T''ung-ch''uan,Tongchuan,Tunchuan,Tungchwan,Tungchwan-fu,T’ung-ch’uan,tong chuan,潼川', 31.0940700, 105.0873100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14929, 'Tongzha', 'Tongzha', 'T''ung-ch''eng-cha,T''ung-ch''eng-cha-chen,Tongchengzha,Tongzha,Tongzha Zhen,T’ung-ch’eng-cha,T’ung-ch’eng-cha-chen,tong zha,tong zha zhen,铜闸,铜闸镇', 31.4845000, 118.1327000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14930, 'Tongcheng', 'Tongcheng', 'T''ung-ch''eng,T''ung-ch''eng-chen,Tongcheng,Tongcheng Zhen,T’ung-ch’eng,T’ung-ch’eng-chen,tong cheng,tong cheng zhen,铜城,铜城镇', 32.8984800, 118.9320300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14931, 'Tongcheng', 'Tongcheng', 'T''ung-ch''eng,TGX,Tongcheng,T’ung-ch’eng,tong cheng shi,tungcheong si,twngchng,تونگچنگ,桐城市,퉁청 시', 31.0391100, 116.9736700, 'CN', '2015-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14932, 'Tongchang', 'Tongchang', 'T''ung-ch''ang,Tongchang,Tongchang Yizuxiang,T’ung-ch’ang,tong chang,tong chang yi zu xiang,铜厂,铜厂彝族乡', 24.7133300, 102.0347200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14933, 'Tongbai Chengguanzhen', 'Tongbai Chengguanzhen', 'T''ung-pai,T''ung-pai-hsien,Tongbai,Tongbai Chengguanzhen,Tungpeh,Tungpeh-hsien,T’ung-pai,T’ung-pai-hsien,tong bai cheng guan zhen,桐柏城关镇', 32.3641700, 113.3963900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14934, 'Tong’an', 'Tong''an', 'T''ung-an-ch''iao-chen,Tong''an,Tong''an Zhen,Tong’an,Tong’an Zhen,T’ung-an-ch’iao-chen,tong an,tong an zhen,通安,通安镇', 31.3752200, 120.4513100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14935, 'Tong’an', 'Tong''an', 'T''ung-an,T''ung-an-shih,Tong''an,Tong''an Xiang,Tong’an,Tong’an Xiang,T’ung-an,T’ung-an-shih,tong an,tong an xiang,同安,同安乡', 28.5605100, 114.8930100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14936, 'Tingzhou', 'Tingzhou', 'Ch''ang-t''ing-hsien,Changting,Ch’ang-t’ing-hsien,T''ing-chou,Tingchow,Tingchowfu,Tingzhou,Tingzhou Zhen,T’ing-chou,ting zhou,ting zhou zhen,汀州,汀州镇', 25.8285600, 116.3296400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14937, 'Tingxiandu', 'Tingxiandu', 'T''ing-hsien-tu,Tingxiandu,Tingxiandu Zhen,T’ing-hsien-tu,ting xian du,ting xian du zhen,停弦渡,停弦渡镇', 29.5878000, 111.6251400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14938, 'Tingsiqiao', 'Tingsiqiao', 'T''ing-ssu-ch''iao,Ting-sze-chiao,Tingsiqiao,Tingsiqiao Zhen,Tingszekiao,T’ing-ssu-ch’iao,ting si qiao,ting si qiao zhen,汀泗桥,汀泗桥镇', 29.8166800, 114.1669100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14939, 'Tingqian', 'Tingqian', 'T''ing-ch''ien,T''ing-ch''ien-i,Tingqian,Tingqian Zhen,T’ing-ch’ien,T’ing-ch’ien-i,ting qian,ting qian zhen,停前,停前镇', 30.2127700, 115.9770700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14940, 'Tingping', 'Tingping', 'Tingping,Tingping Xiang,ting ping,ting ping xiang,廷坪,廷坪乡', 26.5204200, 119.0533300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14941, 'Tingpang', 'Tingpang', 'T''ing-p''ang-chen,Tingbangzhen,Tingpang,Tingpang Zhen,T’ing-p’ang-chen,ting pang,ting pang zhen,亭旁,亭旁镇', 29.0407500, 121.3386400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14942, 'Tingjiang', 'Tingjiang', 'T''ing-t''ou,Tingjiang,Tingjiang Zhen,T’ing-t’ou,ting jiang,ting jiang zhen,亭江,亭江镇', 26.0740100, 119.5057400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14943, 'Tingdong', 'Tingdong', 'T''ing-tung,Tingdong,T’ing-tung', 25.8244400, 108.6125000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14944, 'Tiewang', 'Tiewang', 'T''ieh-wang,T''ieh-wang-ts''un,Tiewang,T’ieh-wang,T’ieh-wang-ts’un,tie wang,铁王', 34.9166700, 108.5725000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14945, 'Tieqiao', 'Tieqiao', 'T''ieh-so-ch''iao,Tieqiao,Tieqiao Zhen,T’ieh-so-ch’iao,tie qiao,tie qiao zhen,铁桥,铁桥镇', 31.0400100, 108.1336200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14946, 'Tieshan', 'Tieshan', 'T''ieh-shan-miao,Tieshan,Tieshanmiao,T’ieh-shan-miao,tie shan,铁山', 33.3332400, 113.5297100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14947, 'Tieshanlong', 'Tieshanlong', 'T''ieh-shan-lung,Tieshanlong,Tieshanlong Zhen,T’ieh-shan-lung,tie shan long,tie shan long zhen,铁山垄,铁山垄镇', 25.7335000, 115.5113700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14948, 'Tieshan', 'Tieshan', 'T''ieh-shan,Tieshan,Tieshan Zhen,T’ieh-shan,tie shan,tie shan zhen,铁山,铁山镇', 27.3991700, 118.9261100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14949, 'Tiemengang', 'Tiemengang', 'Tiemen,Tiemengang,Tiemengang Xiang,tie men gang,tie men gang xiang,铁门岗,铁门岗乡', 31.0403200, 114.8467600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14950, 'Tielu', 'Tielu', 'T''ieh-lu,T''ieh-lu-chen,Tielu,T’ieh-lu,T’ieh-lu-chen,tie lu,铁炉', 34.3939900, 109.4431700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14951, 'Tiechang', 'Tiechang', 'T''ieh-ch''ang,T''ieh-ch''ang-hsu,Tiechang,Tiechang Zhen,T’ieh-ch’ang,T’ieh-ch’ang-hsü,tie chang,tie chang zhen,铁场,铁场镇', 24.1644700, 115.4911000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14952, 'Tiebiancheng', 'Tiebiancheng', 'T''ieh-pien-ch''eng,Tiebiancheng,Tiebiancheng Zhen,T’ieh-pien-ch’eng,tie bian cheng,tie bian cheng zhen,铁边城,铁边城镇', 36.9899100, 107.8479500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14953, 'Tiaofeng', 'Tiaofeng', 'T''iao-feng-shih,Tiaofeng,Tiaofeng Zhen,Tiu-fung,T’iao-feng-shih,diao feng,diao feng zhen,调风,调风镇', 20.6863900, 110.2518800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14954, 'Tianzhou', 'Tianzhou', 'Chiu-feng-i,Feng-i,T''ien-chou,T''ien-chou-chen,T''ien-chou-hsu,T''ien-yang,Tianyang,Tianzhou,Tienchow,T’ien-chou,T’ien-chou-chen,T’ien-chou-hsü,T’ien-yang,tian zhou,田州', 23.7786100, 106.8971800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14955, 'Tianxin', 'Tianxin', 'T''ien-hsin,T''ien-hsin-hsu,Tianxin,Tianxin Zhen,T’ien-hsin,T’ien-hsin-hsü,tian xin,tian xin zhen,田心,田心镇', 28.1356400, 114.6039600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14956, 'Tianxin', 'Tianxin', 'T''ien-hsin,T''ien-hsin-hsu,Tianxin,Tianxin Zhen,T’ien-hsin,T’ien-hsin-hsü,tian xin,tian xin zhen,天心,天心镇', 25.3980500, 115.5043200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14957, 'Tianwang', 'Tianwang', 'T''ien-wang-ssu,Tianwang,Tianwang Zhen,Tianwangsi,T’ien-wang-ssu,tian wang,tian wang zhen,天王,天王镇', 31.7462600, 119.2027000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14958, 'Tianwang', 'Tianwang', 'T''ien-wang,T''ien-wang-ts''un,Tianwang,Tianwang Zhen,T’ien-wang,T’ien-wang-ts’un,tian wang,tian wang zhen,天王,天王镇', 34.3013600, 107.4695700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14959, 'Tianwan', 'Tianwan', 'T''ien-wan,Tianwan,Tianwan Zhen,T’ien-wan,tian wan,tian wan zhen,田湾,田湾镇', 28.0933300, 110.2344400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14960, 'Tiantang', 'Tiantang', 'T''ien-t''ang,T''ien-t''ang-chen,T''ing-t''ang-ssu,Tiantang,Tiantang Zhen,Tyan''tanchzhen,Tyan’tanchzhen,T’ien-t’ang,T’ien-t’ang-chen,T’ing-t’ang-ssu,tian tang,tian tang zhen,天堂,天堂镇', 34.9195200, 107.5507900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14961, 'Tiantang', 'Tiantang', 'Tiantang,Ya-ch''ien,Ya-ch''ien-chen,Ya-ch’ien,Ya-ch’ien-chen,Yaqian,Yueh-hsi,Yuexi,Yuexi Xian,Yüeh-hsi,tian tang,yue xi xian,天堂,岳西县', 30.8500000, 116.3500000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14962, 'Tiantang', 'Tiantang', 'Lien-t''ang,Lien-t’ang,T''ien-t''ang,T''ien-tang-hsu,Tiantang,Tiantang Zhen,T’ien-tang-hsü,T’ien-t’ang,tian tang,tian tang zhen,天堂,天堂镇', 22.5616600, 111.9994200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14963, 'Tiantai Chengguanzhen', 'Tiantai Chengguanzhen', 'Chengguan Zhen,T''ien-t''ai,T''ien-t''ai-hsien,Tiantai,Tiantai Chengguanzhen,T’ien-t’ai,T’ien-t’ai-hsien,cheng guan zhen,tian tai,tian tai cheng guan zhen,城关镇,天台,天台城关镇', 29.1363300, 121.0295800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14964, 'Qincheng', 'Qincheng', 'Ch''in-chou,Ch’in-chou,Qincheng,Qincheng Qu,Qinzhou Qu,T''ien-shui,T''ien-shui-chen,Tianshui,Tianshui Shi,Tianshuizhen,Tsin''chzhou,Tsinchow,Tsin’chzhou,Tyan''shuy,Tyan’shuy,T’ien-shui,T’ien-shui-chen,qin cheng,qin cheng qu,qin zhou qu,tian shui,tian shui shi,天水,天水市,秦城,秦城区,秦州区', 34.5802800, 105.7272200, 'CN', '2016-03-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14965, 'Tianshui', 'Tianshui', 'THQ,Tianshui,Tiānshuǐ,tian shui,天水', 34.5795200, 105.7423800, 'CN', '2013-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14966, 'Tianshi', 'Tianshi', 'T''ien-shih,T''ien-shih-chen,Tianshi,Tianshi Zhen,T’ien-shih,T’ien-shih-chen,tian shi,田市', 34.6221200, 109.4281500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14967, 'Tianshi', 'Tianshi', 'Tianshi,Tianshi Zhen,tian shi,tian shi zhen,田市,田市镇', 28.7814300, 120.6312900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14968, 'Tianqian', 'Tianqian', 'Tianqian,tian qian,田墘', 22.7279000, 115.5025800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14969, 'Tianpeng', 'Tianpeng', 'P''eng,P''eng-hsien,Pengxian,Pensyan'',Pensyan’,P’eng,P’eng-hsien,Tianpeng,tian peng,天彭', 30.9866400, 103.9393300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14970, 'Tianning', 'Tianning', 'T''ien-ning,T''ien-ning-chuang,Tianning,Tianning Zhen,Tianningzhuang,T’ien-ning,T’ien-ning-chuang,tian ning,tian ning zhen,天凝,天凝镇', 30.8960400, 120.8005700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14971, 'Tianlou', 'Tianlou', 'T''ien-lou,Tianlou,Tianlou Xiang,T’ien-lou,tian lou,tian lou xiang,田楼,田楼乡', 34.2500000, 119.6000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14972, 'Tianjin', 'Tianjin', 'T''ien-chin,T''ien-ching,T''ien-ching-shih,TSN,Tchien-tin,Tchien-ťin,Tehnd''iin,Thien Tan,Thien-tsin,Thiên Tân,Thiên-tsîn,Tiandzinas,Tianjin,Tianjin Shi,Tianjing,Tianjín,Tiantzin,Tiencin,Tiencsin,Tiendzin,Tientsin,Tiençin,Tjan''czin'',Tjandzina,Tjangino,Tjanĝino,Tjaņdziņa,Tjencin,Tyantszin,T’ien-chin,T’ien-ching,T’ien-ching-shih,cheonjin,theiyn cin,ti''anjina,tian jin,tian jin shi,tiyanjin,tyanjina,tyanjn,tyanjyn,tyenjin si,tyyng''yn,Τιαντζίν,Тиендзин,Тэндьиин,Тяньцзинь,Тяньцзінь,Тјенцин,טיינג''ין,تيانجين,تيەنجىن شەھىرى,تیانجن,تیانجین,तिआंजिन,त्यांजिन,ਤਿਆਂਜਿਨ,தியான்ஜின்,ടിയാൻജിൻ,เทียนจิน,ཐན་ཅིན ་གྲོང་ཁྱེར།,ထျန်းကျင်းမြို့,ტიანძინი,天津,天津市,천진,톈진 시', 39.1422200, 117.1766700, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14973, 'Tianjiazhuang', 'Tianjiazhuang', 'Ch''ien-chia-chuang,Ch’ien-chia-chuang,T''ien-chia-chuang,T''ien-chia-p''u,Tianjiazhuang,Tianjiazhuang Zhen,T’ien-chia-chuang,T’ien-chia-p’u,tian jia zhuang,tian jia zhuang zhen,田家庄,田家庄镇', 34.5151600, 107.4759500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14974, 'Wuxue Shi', 'Wuxue Shi', 'T''ien-chia-chen,T''ien-chia-p''u,Tienkeachin,Tienkiachen,T’ien-chia-chen,T’ien-chia-p’u,Wuxue Jiedao,Wuxue Shi,wu xue jie dao,wu xue shi,武穴市,武穴街道', 29.9152500, 115.4143200, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14975, 'Tianjiazhai', 'Tianjiazhai', 'Tianjiazhai,Tianjiazhai Zhen,tian jia zhai,tian jia zhai zhen,田家寨,田家寨镇', 36.4536100, 101.7933300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14976, 'Tianjiaba', 'Tianjiaba', 'T''ien-chia-pa,Tianjiaba,Tianjiaba Zhen,T’ien-chia-pa,tian jia ba,tian jia ba zhen,田家坝,田家坝镇', 32.1719500, 110.1448700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14977, 'Tianhekou', 'Tianhekou', 'T''ien-ho-k''ou,Tianhekou,Tianhekou Xiang,Tienhoku,T’ien-ho-k’ou,tian he kou,tian he kou xiang,天河口,天河口乡', 32.1281900, 113.4468000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14978, 'Tian’erhe', 'Tian''erhe', 'T''ien-erh-ho,Tian''erhe,Tian''erhe Zhen,Tian’erhe,Tian’erhe Zhen,T’ien-erh-ho,tian er he,tian er he zhen,田二河,田二河镇', 30.5366400, 113.4404400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14979, 'Tian’e', 'Tian''e', 'Tian''e,Tian''e Zhen,Tian’e,Tian’e Zhen,tian e,tian e zhen,天鹅,天鹅镇', 30.7741600, 113.5792800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14980, 'Tiandu', 'Tiandu', 'T''ien-tu,T''ien-tu-chen,Tiandu,Tiandu Zhen,T’ien-tu,T’ien-tu-chen,tian du,tian du zhen,天度,天度镇', 34.4922900, 107.9620700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14981, 'Tiandu', 'Tiandu', 'T''ien-tu,T''ien-tu-ts''un,Tiandu,Tiandu Zhen,T’ien-tu,T’ien-tu-ts’un,tian du,tian du zhen,田独,田独镇', 18.2846000, 109.5823200, 'CN', '2012-05-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14982, 'Tiandiba', 'Tiandiba', 'Chin-yang,Jinyang,T''ien-ti-pa,Tiandiba,Tiantai,T’ien-ti-pa,tian de ba,天地坝', 27.7017800, 103.2480600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14983, 'Tiandeng', 'Tiandeng', 'Chen-tu,T''ien-teng,T''ien-teng-chen,T''ien-teng-hsiang,Tiandeng,T’ien-teng,T’ien-teng-chen,T’ien-teng-hsiang,tian deng,天等', 23.1265800, 107.0936900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14984, 'Tianhe', 'Tianhe', 'Tiancun,Tianhe,Tianhe Jiedao,tian he,tian he jie dao,田和,田和街道', 37.5001300, 122.0540200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14985, 'Tianchi', 'Tianchi', 'Tianchi,Tianchi Xiang,tian chi,tian chi xiang,天池,天池乡', 36.2363900, 107.3115500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14986, 'Tianchi', 'Tianchi', 'Le-chih,Lechzhi,Lezhi,Lo-chih,Lo-chih-hsien,Tianchi,tian chi,天池', 30.2811200, 105.0234600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14987, 'Tiancheng', 'Tiancheng', 'Ch''ung-yang,Ch''ung-yang-hsien,Chongyang,Chongyang Xian,Ch’ung-yang,Ch’ung-yang-hsien,T''sun-yang,Tiancheng,Tiancheng Zhen,Tsungyang,Tsungyang-hsien,T’sun-yang,chong yang xian,tian cheng,tian cheng zhen,天城,天城镇,崇阳县', 29.5402200, 114.0415500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14988, 'Tianchang', 'Tianchang', 'Ping-hui,T''ien-ch''ang,T''ien-ch''ang-ch''eng,T''ien-ch''ang-chen,T''ien-ch''ang-hsien,Tianchang,Tianchang Jiedao,Tianchang Shi,T’ien-ch’ang,T’ien-ch’ang-chen,T’ien-ch’ang-ch’eng,T’ien-ch’ang-hsien,tian zhang,tian zhang jie dao,tian zhang shi,天长,天长市,天长街道', 32.6849700, 119.0093200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14989, 'Tianbu', 'Tianbu', 'T''ien-pu,T''ien-pu-chen,Tianbu,Tianbu Zhen,T’ien-pu,T’ien-pu-chen,tian bu,tian bu zhen,天补,天补镇', 31.9275800, 121.1137000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14990, 'Tianbu', 'Tianbu', 'Tianbu,Tianbu Xiang,tian bu,tian bu xiang,田埠,田埠乡', 26.3954100, 116.1907700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14991, 'Chengtangcun', 'Chengtangcun', 'Chengtangcun,T''eng,T''eng-hsien,Tehnchzhou,Teng Xian,Tengzhou,Tengzhou Shi,T’eng,T’eng-hsien,cheng tang cun,teng xian,teng zhou,teng zhou shi,Тэнчжоу,滕县,滕州,滕州市,程堂村', 35.0835700, 117.1907100, 'CN', '2016-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14992, 'Tengtian', 'Tengtian', 'T''eng-t''ien,T''eng-t''ien-chen,Tengtian,Tengtian Zhen,T’eng-t’ien,T’eng-t’ien-chen,teng tian,teng tian zhen,藤田,藤田镇', 27.0787200, 115.6586700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14993, 'Tengqiao', 'Tengqiao', 'T''eng-ch''iao,Tengqiao,Tengqiao Zhen,T’eng-ch’iao,teng qiao,teng qiao zhen,藤桥,藤桥镇', 28.0695100, 120.4998100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14994, 'Tengqiao', 'Tengqiao', 'T''eng-ch''iao,Tengqiao,Tengqiao Zhen,T’eng-ch’iao,teng qiao,teng qiao zhen,腾桥,腾桥镇', 27.7614900, 116.5095700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14995, 'Tengjia', 'Tengjia', 'T''eng-chia-chi,Tengjia,Tengjia Zhen,Tengjiaji,T’eng-chia-chi,teng jia,teng jia zhen,滕家,滕家镇', 37.0603400, 122.3483200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14996, 'Tengzhou', 'Tengzhou', 'T''eng,T''eng-ch''eng-chen,T''eng-hsien,Tengcheng,Tengxian,Tengyun,Tengyün,Tengzhou,T’eng,T’eng-ch’eng-chen,T’eng-hsien,teng zhou,藤州', 23.3880600, 110.8911600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14997, 'Temuli', 'Temuli', 'Butuo,Pu-t''o,Pu-t’o,Temuli,te mu li,特木里', 27.7079500, 102.8076800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14998, 'Tazhuang', 'Tazhuang', 'T''a-chuang,Tazhuang,Tazhuang Zhen,T’a-chuang,ta zhuang,ta zhuang zhen,塔庄,塔庄镇', 26.0537000, 118.7700400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(14999, 'Tawo', 'Tawo', 'Tawo,Tawo Zhen,ta wo,ta wo zhen,塔卧,塔卧镇', 29.1947600, 109.9584600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15000, 'Tashi', 'Tashi', 'T''a-shih,Tashi,Tashi Zhen,T’a-shih,ta shi,ta shi zhen,塔石,塔石镇', 29.1401200, 119.1556300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15001, 'Taqian', 'Taqian', 'T''a-ch''ien,Taqian,Taqian Zhen,T’a-ch’ien,ta qian,ta qian zhen,塔前,塔前镇', 29.0625000, 117.0827800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15002, 'Taozhuang', 'Taozhuang', 'T''ao-chuang,Taozhuang,T’ao-chuang', 34.8500000, 117.3333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15003, 'Taozhuang', 'Taozhuang', 'T''ao-chuang,T''ao-chuang-chen,Taozhuang,Taozhuang Zhen,T’ao-chuang,T’ao-chuang-chen,tao zhuang,tao zhuang zhen,陶庄,陶庄镇', 30.9691700, 120.8065100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15004, 'Taozhou', 'Taozhou', 'Guangde,Kuang-te,Kuang-te-hsien,Kwangteh,Kwangteh-hsien,Kwangtenchow,Lang-kuang,Taozhou,Taozhou Zhen,guang de,tao zhou,tao zhou zhen,广德,桃州,桃州镇', 30.9064100, 119.4086500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15005, 'Zhangjiang', 'Zhangjiang', 'T''ao-yuan-hsien,Taoyuan,Taoyuan Xian,T’ao-yüan-hsien,Zhangjiang,Zhangjiang Zhen,tao yuan,tao yuan xian,zhang jiang,zhang jiang zhen,桃源,桃源县,漳江,漳江镇', 28.9110300, 111.4799000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15006, 'Taoyuan', 'Taoyuan', 'T''ao-yuan-hsu,Taoyuan,Taoyuan Zhen,T’ao-yüan-hsü,tao yuan,tao yuan zhen,桃源,桃源镇', 25.7877600, 117.5757000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15007, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃源,桃源镇', 22.7220900, 112.9120700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15008, 'Taoyang', 'Taoyang', 'Didao,Lin-t''ao,Lin-t’ao,Lintao Xian,Taoyang,Ti-tao,lin tao xian,tao yang,临洮县,洮阳', 35.4013500, 103.8532500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15009, 'Taoyan', 'Taoyan', 'T''ao-yen,T''ao-yen-shih,Taoyan,Taoyan Zhen,T’ao-yen,T’ao-yen-shih,tao yan,tao yan zhen,陶堰,陶堰镇', 30.0213900, 120.7281200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15010, 'Taoxin', 'Taoxin', 'Chang-she,Chang-she-ts''un,Chang-she-ts’un,Shuangqiaotou,T''ao-hsin,Taoxin,Taoxin Zhen,T’ao-hsin,shuang qiao tou,tao xin,tao xin zhen,双桥头,陶辛,陶辛镇', 31.1606700, 118.4851500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15011, 'Taoxia', 'Taoxia', 'T''ao-hsia-chan,T''ao-ts''un,Taoxia,Taoxia Zhen,Taoxiazhan,T’ao-hsia-chan,T’ao-ts’un,tao xia,桃下', 34.5433700, 109.9783900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15012, 'Taoxi', 'Taoxi', 'T''ao-hsi,Taoxi,Taoxi Zhen,T’ao-hsi,tao xi,tao xi zhen,桃溪,桃溪镇', 25.3634200, 116.1863000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15013, 'Taowu', 'Taowu', 'T''ao-wu-chen,Taowu,Taowu Zhen,T’ao-wu-chen,tao wu,tao wu zhen,陶吴,陶吴镇', 31.7772500, 118.7712500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15014, 'Taosi', 'Taosi', 'T''ao-ssu,T''ao-ssu-ts''un,Taosi,Taosi Xiang,T’ao-ssu,T’ao-ssu-ts’un,tao si,tao si xiang,陶寺,陶寺乡', 35.8969600, 111.4987500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15015, 'Taosha', 'Taosha', 'T''ao-sha-hsu,Taosha,Taosha Zhen,T’ao-sha-hsü,tao sha,tao sha zhen,陶沙,陶沙镇', 28.0511800, 116.0669300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15016, 'Taokeng', 'Taokeng', 'Kengkouxu,Taokeng,Taokeng Xiang,keng kou wei,tao keng,tao keng xiang,坑口圩,桃坑,桃坑乡', 26.6677600, 113.7497100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15017, 'Taohuajiang', 'Taohuajiang', 'T''ao-chiang,T''ao-chiang-chen,T''ao-hua-chiang,Taohuajiang,Taojiang,Taojiang Xian,T’ao-chiang,T’ao-chiang-chen,T’ao-hua-chiang,tao hua jiang,tao jiang xian,桃江县,桃花江', 28.5236100, 112.1252800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15018, 'Taojiahe', 'Taojiahe', 'T''ao-chia-ho,Taojiahe,Taojiahe Xiang,T’ao-chia-ho,tao jia he,tao jia he xiang,陶家河,陶家河乡', 30.9129100, 115.9351500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15019, 'Taocun', 'Taocun', 'T''ao-chia-ts''un,Taocun,Taocun Xiang,Taojiacun,T’ao-chia-ts’un,tao cun,tao cun xiang,陶村,陶村乡', 39.4478400, 112.4523900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15020, 'Taochang', 'Taochang', 'T''ao-chia-ch''ang,Taochang,Taochang Zhen,Taojiachang,T’ao-chia-ch’ang,tao chang,tao chang zhen,陶厂,陶厂镇', 31.5976000, 118.1223300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15021, 'Taohuayuan', 'Taohuayuan', 'Taohuayuan,Taohuayuan Zhen,tao hua yuan,tao hua yuan zhen,桃花源,桃花源镇', 28.7750000, 111.4441700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15022, 'Taohong', 'Taohong', 'Longhui,Lung-hui,T''ao-hung-chen,Taohong,Taohuaping,Taohwaping,T’ao-hung-chen,tao hong,桃洪', 27.1010700, 110.9948600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15023, 'Taodian', 'Taodian', 'T''ao-tien,Taodian,Taodian Xiang,T’ao-tien,tao dian,tao dian xiang,陶店,陶店乡', 30.5396400, 114.9653700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15024, 'Taochuan', 'Taochuan', 'Taochuan,Taochuan Zhen,tao chuan,tao chuan zhen,桃川,桃川镇', 34.0569200, 107.5469400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15025, 'Taocheng', 'Taocheng', 'Shou-ch''eng-chen,Shou-ch’eng-chen,T''ao-ch''eng-p''u,Taocheng,Taocheng Zhen,T’ao-ch’eng-p’u,tao cheng,tao cheng zhen,涛城,涛城镇', 31.0984800, 119.2497500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15026, 'Taocheng', 'Taocheng', 'Daxin,Ta-hsin,Taocheng,Yang-li,Yang-li-hsien,tao cheng,桃城', 22.8793600, 107.1564800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15027, 'Tanzhesi', 'Tanzhesi', 'T''an-che-ssu,Tanzhesi,Tanzhesi Zhen,T’an-che-ssu,tan zhe si,tan zhe si zhen,潭柘寺,潭柘寺镇', 39.8721400, 116.0282700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15028, 'Tanxi', 'Tanxi', 'T''an-ch''i,T''an-hsi,Tanxi,Tanxi Zhen,T’an-ch’i,T’an-hsi,tan xi,tan xi zhen,滩溪,滩溪镇', 28.9839600, 115.6347700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15029, 'Tanxi', 'Tanxi', 'T''an-hsi,Tanxi,Tanxi Zhen,T’an-hsi,tan xi,tan xi zhen,潭溪,潭溪镇', 28.2666700, 109.9500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15030, 'Tanxi', 'Tanxi', 'Tanxi,Tanxi Zhen,tan xi,tan xi zhen,潭西,潭西镇', 22.9357700, 115.5621900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15031, 'Tanwan', 'Tanwan', '', 27.9663900, 110.1502800, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15032, 'Tantou', 'Tantou', 'T''an-t''ou-shih,Tantou,Tantou Zhen,T’an-t’ou-shih,tan tou,tan tou zhen,坦头,坦头镇', 29.1116800, 121.1187300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15033, 'Tantou', 'Tantou', 'Tantou,Tantou Xiang,Tantouchang,tan tou,tan tou chang,tan tou xiang,滩头,滩头乡,滩头场', 28.2833300, 104.2666700, 'CN', '2015-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15034, 'Tantou', 'Tantou', 'Tantou,Tantou Zhen,tan tou,tan tou zhen,滩头,滩头镇', 27.2638900, 111.1441700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15035, 'Tantou', 'Tantou', 'T''an-t''ou-shih,Tantou,Tantou Xiang,T’an-t’ou-shih,tan tou,tan tou xiang,潭头,潭头乡', 26.8372000, 115.4899500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15036, 'Tantou', 'Tantou', 'Tantou,Tantou Zhen,tan tou,tan tou zhen,潭头,潭头镇', 26.0303300, 119.5973900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15037, 'Tanshui', 'Tanshui', 'Tamshui,Tan-shui-hsu,Tan-shui-hsü,Tanshui,Tanshui Zhen,Tanshuichu,tan shui,tan shui zhen,潭水,潭水镇', 22.0472400, 111.6012600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15038, 'Tanshi', 'Tanshi', 'T''an-shih,T''an-shih-shih,Tanshi,Tanshi Zhen,T’an-shih,T’an-shih-shih,tan shi,tan shi zhen,坛石,坛石镇', 28.7151200, 118.4933100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15039, 'Tanshang', 'Tanshang', 'T''an-shang-ts''un,Tanshang,Tanshang Zhen,T’an-shang-ts’un,tan shang,tan shang zhen,滩上,滩上镇', 38.9581800, 113.1708300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15040, 'Tanshan', 'Tanshan', 'Tanshan,Tanshan Xiang,tan shan,tan shan xiang,炭山,炭山乡', 36.3774500, 106.3045200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15041, 'Tanshan', 'Tanshan', 'Tanshan,Tanshan Zhen,tan shan,tan shan zhen,潭山,潭山镇', 28.5438900, 114.7516900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15042, 'Tanqiu', 'Tanqiu', 'T''an-ch''iu,Tanqiu,Tanqiu Xiang,T’an-ch’iu,tan qiu,tan qiu xiang,潭丘,潭丘乡', 27.6315000, 115.5970700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15043, 'Tanqiao', 'Tanqiao', 'T''an-ch''iao,Tanqiao,Tanqiao Zhen,T’an-ch’iao,tan qiao,tan qiao zhen,滩桥,滩桥镇', 30.1646300, 112.2960800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15044, 'Tanniu', 'Tanniu', 'Tanniu,Tanniu Zhen,tan niu,tan niu zhen,潭牛,潭牛镇', 19.7117000, 110.7310900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15045, 'Tanjiaqiao', 'Tanjiaqiao', 'T''an-chia-ch''iao,Tanjiaqiao,Tanjiaqiao Zhen,T’an-chia-ch’iao,tan jia qiao,tan jia qiao zhen,谭家桥,谭家桥镇', 30.1744400, 118.2683300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15046, 'Tanjiang', 'Tanjiang', 'T''an-chiang-hsu,Tanjiang,Tanjiang Zhen,T’an-chiang-hsü,tan jiang,tan jiang zhen,潭江,潭江镇', 24.0981800, 116.5215900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15047, 'Tanjiahe', 'Tanjiahe', 'T''an-chia-ho,T''an-chia-ho-shih,Tanjiahe,Tanjiahe Xiang,T’an-chia-ho,T’an-chia-ho-shih,tan jia he,tan jia he xiang,谭家河,谭家河乡', 31.9021300, 113.9641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15048, 'Tanjia', 'Tanjia', 'T''an-chia-pa,Tanjia,Tanjia Xiang,T’an-chia-pa,tan jia,tan jia xiang,谭家,谭家乡', 31.4557400, 108.4986100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15049, 'Tangzhai', 'Tangzhai', 'Chu-tzu-chieh,Chü-tzu-chieh,Tang-chai,Tangzhai', 34.4327800, 116.5911100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15050, 'Tangzha', 'Tangzha', 'T''ang-cha,T''ang-chia-cha,Tangkiacha,Tangzha,Tangzha Zhen,Tangzhazhen Jiedao,T’ang-cha,T’ang-chia-cha,tang zha,tang zha zhen,tang zha zhen jie dao,唐闸,唐闸镇,唐闸镇街道', 32.0640900, 120.8042000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15051, 'Tangzang', 'Tangzang', 'T''ang-tsang,Tangzang,Tangzang Zhen,T’ang-tsang,tang cang,tang cang zhen,唐藏,唐藏镇', 34.0905600, 106.5836100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15052, 'Tangyang Chengguanzhen', 'Tangyang Chengguanzhen', 'T''ang-yin-hsien,Tangyang Chengguanzhen,Tangyin,T’ang-yin-hsien,tang yang cheng guan zhen,汤阳城关镇', 35.9144600, 114.3551400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15053, 'Tangyin', 'Tangyin', 'Tangyin,Tangyin Zhen,tang yin,tang yin zhen,棠阴,棠阴镇', 27.4939100, 116.3039300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15054, 'Tangyang', 'Tangyang', 'T''ang-chia-yang,Tangyang,Tangyang Zhen,T’ang-chia-yang,tang yang,tang yang zhen,唐洋,唐洋镇', 32.6373800, 120.6911500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15055, 'Tangxian', 'Tangxian', 'Piyaanhsien,T''ang-hsien-chen,T''ang-hsien-chien,Tangxian,Tangxian Zhen,T’ang-hsien-chen,T’ang-hsien-chien,tang xian,tang xian zhen,唐县,唐县镇', 31.9793100, 113.1144000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15056, 'Tangxia', 'Tangxia', 'T''ang-hsia,Tangxia,Tangxia Zhen,T’ang-hsia,tang xia,tang xia zhen,棠下,棠下镇', 22.6820300, 113.0320100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15057, 'Tangxi', 'Tangxi', 'T''ang-ch''i,T''ang-ch''i-hsien,T''ang-hsi,Tangki,Tangxi,Tangxi Zhen,T’ang-ch’i,T’ang-ch’i-hsien,T’ang-hsi,tang xi,tang xi zhen,汤溪,汤溪镇', 29.0525000, 119.3978000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15058, 'Fenghuanglu', 'Fenghuanglu', 'Fenghuanglu,Fenghuanglu Jiedao,T''ang-wan-chen,Tangwan,Tangwan Zhen,T’ang-wan-chen,feng huang lu,feng huang lu jie dao,tang wan,tang wan zhen,凤凰路,凤凰路街道,塘湾,塘湾镇', 32.4422500, 119.9597900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15059, 'Tangwan', 'Tangwan', 'T''ang-pei-wan,Tangwan,Tangwan Zhen,T’ang-pei-wan,tang wan,tang wan zhen,塘湾,塘湾镇', 28.0763200, 117.2223900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15060, 'Tangxia', 'Tangxia', 'T''ang-t''ou-hsia,T''ang-t''ou-hsia-hsu,Tangtouxia,Tangtowhwa,Tangxia,Tangxia Zhen,Thon-theu-ha,T’ang-t’ou-hsia,T’ang-t’ou-hsia-hsü,tang sha,tang sha zhen,塘厦,塘厦镇', 22.8081000, 114.0963800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15061, 'Tangtang', 'Tangtang', 'T''ang-ho-hsu,T''ang-tang-hsu,Tangtang,Tangtang Zhen,T’ang-ho-hsü,T’ang-tang-hsü,tang tang,tang tang zhen,汤塘,汤塘镇', 23.7430900, 113.4673400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15062, 'Tangshan', 'Tangshan', 'GJuong Son,T''ang-shan-chen,T''ang-shan-shih,TVS,Tangsanas,Tangsano,Tangshan,Tangŝano,Tangšanas,Tanshan,Tanshan'',Tchang-san,Tchang-šan,Tongshan,T’ang-shan-chen,T’ang-shan-shih,tang shan,tang shan shi,tangasana,tangsan si,tangsana,tangshan,Đường Sơn,Таншан,Таншань,تانگشان,تاڭشەن شەھىرى,तांग्शान,ਤਾਂਗਸ਼ਾਨ,ടാങ്ഷാൻ,唐山,唐山市,탕산 시', 39.6333300, 118.1833300, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15063, 'Tangquan', 'Tangquan', 'T''ang-ch''uan,T''ang-ch''uan-chen,Tangquan,Tangquan Zhen,T’ang-ch’üan,T’ang-ch’üan-chen,tang quan,tang quan zhen,汤泉,汤泉镇', 32.0924900, 118.5067100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15064, 'Tangqian', 'Tangqian', 'T''ang-ch''ien,Tangqian,Tangqian Xiang,T’ang-ch’ien,tang qian,tang qian xiang,塘前,塘前乡', 25.8660300, 119.1492700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15065, 'Tangqi', 'Tangqi', 'T''ang-ch''i,T''ang-ch''i-chen,T''ang-hsi,Tangqi,Tangqi Zhen,Tangxi,Tangxi Zhen,T’ang-ch’i,T’ang-ch’i-chen,T’ang-hsi,tang qi,tang qi zhen,塘栖,塘栖镇', 30.4783200, 120.1810500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15066, 'Tangpu', 'Tangpu', 'T''ang-p''u-chen,Tangpu,Tangpu Zhen,T’ang-p’u-chen,tang pu,tang pu zhen,汤浦,汤浦镇', 29.8608700, 120.7837300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15067, 'Tangpu', 'Tangpu', 'Tangpu,Tangpu Zhen,tang pu,tang pu zhen,棠浦,棠浦镇', 28.4441000, 114.9849600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15068, 'Tangping', 'Tangping', 'Ho-t''ang,Ho-t’ang,T''ang-p''ing-hsu,Tangping,Tangping Zhen,T’ang-p’ing-hsü,tang ping,tang ping zhen,塘坪镇,塘平', 22.0317700, 111.9353700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15069, 'Tangpeng', 'Tangpeng', 'T''ang-p''eng-hsu,Tangpeng,Tangpeng Zhen,T’ang-p’eng-hsü,tang peng,tang peng zhen,塘蓬,塘蓬镇', 21.7943100, 110.1123300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15070, 'Tangkou', 'Tangkou', '', 26.9541700, 119.0127800, 'CN', '2001-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15071, 'Tangkou', 'Tangkou', 'T''ang-k''ou-hsu,Tangkou,Tangkou Zhen,T’ang-k’ou-hsü,tang kou,tang kou zhen,塘口,塘口镇', 21.8320700, 111.5732200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15072, 'Tangkeng', 'Tangkeng', 'Feng-shun,T''ang-k''eng-chen,T''ang-k''eng-hsu,Tangkeng,Tangkeng Zhen,Tonghang,T’ang-k’eng-chen,T’ang-k’eng-hsü,tang keng,tang keng zhen,汤坑,汤坑镇', 23.7591200, 116.1709100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15073, 'Tangjie', 'Tangjie', 'Tangjie,Tangjie Zhen,tang jie,tang jie zhen,堂街,堂街镇', 33.8975500, 113.3152500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15074, 'Tangjiazhuang', 'Tangjiazhuang', 'T''ang-chia-chuang,T''ang-chia-chuang-tzu,Tangjiazhuang,Tangkiachwang,T’ang-chia-chuang,T’ang-chia-chuang-tzu,tang jia zhuang,唐家庄', 39.7432600, 118.4509900, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15075, 'Tangjiapo', 'Tangjiapo', 'T''ang-chia-po,Tangjiapo,Tangjiapo Zhen,T’ang-chia-po,tang jia po,tang jia po zhen,唐家泊,唐家泊镇', 37.2237600, 120.9864900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15076, 'Tangjiafang', 'Tangjiafang', 'T''ang-chia-fang,Tangjiafang,Tantszyafan,T’ang-chia-fang', 26.8400000, 110.3647200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15077, 'Tangjia', 'Tangjia', 'T''ang-chia,Tangjia,Tangjia Zhen,T’ang-chia,tang jia,tang jia zhen,唐家,唐家镇', 20.8425000, 109.8469400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15078, 'Tanghui', 'Tanghui', 'Tanghui,Tanghui Jiedao,tang hui,tang hui jie dao,塘汇,塘汇街道', 30.7946600, 120.7719800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15079, 'Tanghua', 'Tanghua', 'Tanghua,Tanghua Xiang,Tanghuapu,tang hua,tang hua pu,tang hua xiang,堂华铺,棠华,棠华乡', 29.3701700, 111.8653500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15080, 'Binhe', 'Binhe', 'Binhe,Pi-yuan,Pi-yüan,T''ang-ho,T''ang-ho-hsien,Tanghe,T’ang-ho,T’ang-ho-hsien,bin he,滨河', 32.6883300, 112.8275000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15081, 'Tanggu', 'Tanggu', 'T''ang-ku,Taku,Tanggu,Tango,Tung-ku,T’ang-ku,tang gu,Танго,塘沽', 39.0211100, 117.6469400, 'CN', '2015-10-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15082, 'Tangdukou', 'Tangdukou', 'Shao-yang-hsien,Shaoyang,T''ang-tu,T''ang-tu-k''ou,T''ang-tu-k''ou-chen,Tangdukou,T’ang-tu,T’ang-tu-k’ou,T’ang-tu-k’ou-chen,tang du kou,塘渡口', 26.9658900, 111.2413800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15083, 'Tangdi', 'Tangdi', 'T''ang-li-shu,Tangdi,Tangdi Zhen,Tangdishu,T’ang-li-shu,tang di,tang di zhen,棠棣,棠棣镇', 31.2390400, 113.5866300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15084, 'Tangcun', 'Tangcun', 'T''ang-ts''un,Tangcun,Tangcun Zhen,T’ang-ts’un,Xiangjia,tang cun,tang cun zhen,xiang jia,唐村,唐村镇,项家', 29.8059700, 118.8487600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15085, 'Tangcun', 'Tangcun', 'T''an-ts''un,T''ang-ts''un,Tangcun,Tangcun Zhen,T’an-ts’un,T’ang-ts’un,tang cun,tang cun zhen,塘村,塘村镇', 29.2866700, 119.2994400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15086, 'Tangcun', 'Tangcun', 'T''ang-ts''un,Tangcun,Tangcun Xiang,T’ang-ts’un,tang cun,tang cun xiang,塘村,塘村乡', 25.5406100, 115.3422900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15087, 'Tangchuan', 'Tangchuan', 'Tangchuan,Tangchuan Xiang,tang chuan,tang chuan xiang,汤川,汤川乡', 26.1145700, 118.4261600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15088, 'Tangchijie', 'Tangchijie', 'Tangchi,Tangchi Zhen,Tangchijie,tang chi,tang chi jie,tang chi zhen,汤池,汤池街,汤池镇', 24.9616700, 103.0336100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15089, 'Tangba', 'Tangba', 'T''ang-pa,Tangba,Tangba Zhen,T’ang-pa,tang ba,tang ba zhen,塘坝,塘坝镇', 30.0165100, 105.7973000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15090, 'Tangba', 'Tangba', 'Tangba,Tangba Xiang,tang ba,tang ba xiang,塘坝,塘坝乡', 29.0053800, 108.2329900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15091, 'Tancheng', 'Tancheng', 'T''an-ch''eng-hsien,Tancheng,Tancheng Zhen,T’an-ch’eng-hsien,tan cheng,tan cheng zhen,郯城,郯城镇', 34.6152000, 118.3380000, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15092, 'Tancheng', 'Tancheng', 'Tancheng,Tancheng Xiang,tan cheng,tan cheng xiang,潭城,潭城乡', 27.4375300, 115.4976200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15093, 'Tancheng', 'Tancheng', 'Haitanchin,P''ing-t''an-hsien,P''ing-t''an-hsien-ch''eng,Pingtan,Pingtankieh,P’ing-t’an-hsien,P’ing-t’an-hsien-ch’eng,Tancheng,tan cheng,潭城', 25.5080800, 119.8072200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15094, 'Tanbu', 'Tanbu', 'T''an-pu,Tanbu,Tanbu Zhen,T’an-pu,tan bu,tan bu zhen,潭埠,潭埠镇', 28.1164400, 114.2156800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15095, 'Tanbu', 'Tanbu', 'T''an-pu,T''an-pu-hsu,Tan-pien,Tanbu,Tanbu Zhen,Tanpo,T’an-pu,T’an-pu-hsü,tan bu,tan bu zhen,炭步,炭步镇', 23.3372300, 113.1008600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15096, 'Tanbin', 'Tanbin', 'Tanbin,bin Zhen,tan bin,tan bin zhen,榃滨,榃滨镇', 22.8180200, 111.3960700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15097, 'Taji', 'Taji', 'Taji,Taji Zhen,ta ji,ta ji zhen,塔集,塔集镇', 32.9491200, 119.1576400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15098, 'Guanghe Chengguanzhen', 'Guanghe Chengguanzhen', 'Guanghe,Guanghe Chengguanzhen,Guanghe Xian,Kuang-ho,Kuang-t''ung,Kuang-t''ung-hui-tsu-tzu-chi-hsien,Kuang-t’ung,Kuang-t’ung-hui-tsu-tzu-chi-hsien,Nindin,Ning-ting,Ning-ting-hsien,T''ai-tzi-ssi,T''ai-tzu-ssu,Taizisi,Taytszoso,Taytszysy,Taytszösö,T’ai-tzi-ssi,T’ai-tzu-ssu,guang he cheng guan zhen,guang he xian,广河县,广河城关镇', 35.4815300, 103.5760400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15099, 'Taizi', 'Taizi', 'T''ai-tzu-miao,Taizi,Taizi Zhen,Taizimiao,T’ai-tzu-miao,tai zi,tai zi zhen,太子,太子镇', 30.0333300, 115.1833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15100, 'Taizhou', 'Taizhou', 'T''ai,T''ai-chou,T''ai-chou-shih,T''ai-hsien,T''ai-hsien-ch''eng,Tai-ciu,Taichow,Taitsjou,Taizhou,Taizhou Shi,Taizhou i Jiangsu,Tajchzhou,Tajdzhou,Tajdzou,Tajgou,Tajĝou,Tchaj-cou,Tchaj-čou,Teyju shehiri,Thai Chau,Thai-chiu-chhi,Thài-chiu-chhī,Thái Châu,Tái-ciŭ,T’ai,T’ai-chou,T’ai-chou-shih,T’ai-hsien,T’ai-hsien-ch’eng,YTY,tai zhou,tai zhou shi,taijeou si,tayyzhw  jyangsw,tayzhw,Тайджоу,Тайчжоу,Тајџоу,تائیژو، جیانگسو,تایژو,泰州,泰州市,타이저우 시', 32.4906900, 119.9081200, 'CN', '2013-04-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15101, 'Taiyuan', 'Taiyuan', 'Daiyienz,T''ai-yuan-shih,TYN,Tai-nguong,Taigiouan,Taijuan,Taijuana,Taijuaņa,Taiyuan,Taiyuan Shi,Taiyuan-fu,Taiyuenum,Taiyüan-fu,Tajjuan'',Tajjuean,Tajjuen,Tajjüan,Tajuanas,Tajuano,Tayyuan,Tchaj-juean,Tchaj-jüan,Thai Nguyen,Thai-goan-chhi,Thài-goân-chhī,Thái Nguyên,Tái-nguòng,T’ai-yüan-shih,Yang-ch''u,Yang-ch’ü,Yangku,Yangkü,Yanka,ta''iyu''ana,tai yuan,tai yuan shi,taiwian si,tay ywan,tayy ywan,tayywan,thayyu''ana,thi hywn,Ταϊγιουάν,Таијуан,Тайюань,Тайюен,טאי-יואן,تائی یوآن,تائی‌یوان,تاي يوان,تاییوان,تەييۈەن شەھىرى,ताइयुआन,थाय्युआन,ਤਾਈਯੂਆਨ,ไท่หยวน,太原,太原市,타이위안 시', 37.8694400, 112.5602800, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15102, 'Taiyu', 'Taiyu', 'T''ai-yu-chen,Taiyu,T’ai-yü-chen,tai yu,太峪', 34.9327200, 108.0598100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15103, 'Taiyigong', 'Taiyigong', 'T''ai-i-kung,Taiyigong,T’ai-i-kung,tai yi gong,太乙宫', 34.0261700, 109.0016000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15104, 'Taiyanghe', 'Taiyanghe', 'T''ai-yang-ho,Ta-yang-ho,Taiyanghe,Taiyanghe Xiang,T’ai-yang-ho,tai yang he,tai yang he xiang,太阳河,太阳河乡', 30.5981400, 109.5135700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15105, 'Taiyang', 'Taiyang', 'T''ai-yang-chen,Taiyang,T’ai-yang-chen,tai yang,太阳', 30.1852600, 119.2961100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15106, 'Taiyang', 'Taiyang', 'T''ai-yang-hsu,Taiyang,Taiyang Zhen,T’ai-yang-hsü,tai yang,tai yang zhen,太阳,太阳镇', 28.1972100, 115.2680600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15107, 'Taiyang', 'Taiyang', 'T''ai-yang-hsu,Taiyang,Taiyang Zhen,T’ai-yang-hsü,tai yang,tai yang zhen,太阳,太阳镇', 28.0621000, 116.4778000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15108, 'Taixing', 'Taixing', 'T''ai-hsing,T''ai-hsing-ch''eng,T''ai-hsing-chen,T''ai-hsing-hsien,Taihing,Taishing,Taixing,Taixing Shi,Taixing Zhen,T’ai-hsing,T’ai-hsing-chen,T’ai-hsing-ch’eng,T’ai-hsing-hsien,tai xing,tai xing shi,tai xing zhen,泰兴,泰兴市,泰兴镇', 32.1666700, 120.0136100, 'CN', '2014-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15109, 'Taixi', 'Taixi', 'T''ai-hsi,Taixi,Taixi Xiang,T’ai-hsi,tai xi,tai xi xiang,台溪,台溪乡', 26.1019200, 118.2473000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15110, 'Taipingzhuang', 'Taipingzhuang', 'T''ai-p''ing-chuang,Taipingzhuang,Taipingzhuang Xiang,T’ai-p’ing-chuang,tai ping zhuang,tai ping zhuang xiang,太平庄,太平庄乡', 39.0479400, 112.1360100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15111, 'Taiping', 'Taiping', 'T''ai-p''ing-chen,Taiping,Taiping Xiang,Taipingzhen,T’ai-p’ing-chen,tai ping,tai ping xiang,太平,太平乡', 29.8319400, 109.9227800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15112, 'Taipingxi', 'Taipingxi', 'T''ai-p''ing-ch''i,T''ai-p''ing-ch''i-shih,Taipingki,Taipingxi,Taipingxi Zhen,T’ai-p’ing-ch’i,T’ai-p’ing-ch’i-shih,tai ping xi,tai ping xi zhen,太平溪,太平溪镇', 30.8762400, 110.9640200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15113, 'Taipingqiao', 'Taipingqiao', 'T''ai-p''ing-ch''iao,Taipingqiao,Taipingqiao Xiang,T’ai-p’ing-ch’iao,tai ping qiao,tai ping qiao xiang,太平桥,太平桥乡', 29.0618800, 111.3371800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15114, 'Taipingguan', 'Taipingguan', 'T''ai-p''ing-kuan,Taipingguan,Taipingguan Xiang,T’ai-p’ing-kuan,tai ping guan,tai ping guan xiang,太平关,太平关乡', 29.7524200, 116.4296700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15115, 'Taiping', 'Taiping', 'T''ai-p''ing-tu,Taiping,Taipingdu,T’ai-p’ing-tu,tai ping,太平', 28.1408300, 106.0377100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15116, 'Taipingdian', 'Taipingdian', 'T''ai-p''ing-tien,Taipingchieh,Taipingdian,Taipingdian Zhen,T’ai-p’ing-tien,tai ping dian,tai ping dian zhen,太平店,太平店镇', 32.1355700, 111.8028700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15117, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,Taipingchang,tai ping,tai ping zhen,太平,太平镇', 23.4468100, 113.4726200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15118, 'Taiping', 'Taiping', 'T''ai-p''ing-chen,Taiping,Taiping Zhen,T’ai-p’ing-chen,tai ping,tai ping zhen,太平,太平镇', 32.2866500, 112.7568400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15119, 'Taiping', 'Taiping', 'T''ai-p''ing-chen,Taiping,Taiping Zhen,T’ai-p’ing-chen,tai ping,tai ping zhen,太平,太平镇', 30.2620400, 107.2928700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15120, 'Taiping', 'Taiping', 'T''ai-p''ing-chieh,Taiping,Taiping Zhen,Taipingjie,T’ai-p’ing-chieh,tai ping,tai ping jie,tai ping zhen,太平,太平街,太平镇', 29.9755500, 111.0793700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15121, 'Taipingdian', 'Taipingdian', 'Taiping Xiang,Taipingdian,tai ping dian,tai ping xiang,太平乡,太平甸', 28.5592600, 104.2220300, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15122, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 26.4456700, 118.4186900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15123, 'Taipingxu', 'Taipingxu', 'T''ai-p''ing-hsu,Taiping,Taipingxu,Taipingxu Xiang,T’ai-p’ing-hsü,tai ping wei,tai ping wei xiang,太平圩,太平圩乡', 25.4744400, 112.3280600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15124, 'Taiping', 'Taiping', 'Chihing,Chihinghsien,Shih-hsing,Shih-hsing-hsien,Shih-shing,Shixing Xian,Taiping,Taiping Zhen,shi xing xian,tai ping,tai ping zhen,太平,太平镇,始兴县', 24.9489100, 114.0622700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15125, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 24.2525000, 112.5541100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15126, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,太平', 23.9006000, 117.0151100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15127, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 23.6691500, 112.8892600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15128, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 21.0440000, 110.1570200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15129, 'Taimei', 'Taimei', 'Taimei,Taimei Zhen,tai mei,tai mei zhen,泰美,泰美镇', 23.3234500, 114.4695100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15130, 'Taikang Chengguanzhen', 'Taikang Chengguanzhen', 'T''ai-k''ang-hsien,Taikang,Taikang Chengguanzhen,T’ai-k’ang-hsien,tai kang cheng guan zhen,太康城关镇', 34.0666700, 114.8666700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15131, 'Yanglinjie', 'Yanglinjie', 'T''ai-huai-chen,Taihuai Zhen,T’ai-huai-chen,Yanglinjie,tai huai zhen,yang lin jie,台怀镇,杨林街', 39.0089800, 113.5909000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15132, 'Taihua', 'Taihua', 'Taihua,Taihua Zhen,tai hua,tai hua zhen,太华,太华镇', 25.8148900, 117.7178700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15133, 'Taihu', 'Taihu', 'Taihu,Taihu Zhen,tai hu,tai hu zhen,台湖,台湖镇', 39.8310500, 116.6396700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15134, 'Jinxi', 'Jinxi', 'Jinxi,T''ai-hu-hsien,Taihu,Taihu Xian,T’ai-hu-hsien,jin xi,tai hu xian,太湖县,晋熙', 30.4322600, 116.2921700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15135, 'Shanghe', 'Shanghe', 'Shanghe,Shanghe Zhen,Taihe,shang he,shang he zhen,tai he,上和,上和镇,太和', 30.1603600, 105.9340300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15136, 'Taihe Chengguanzhen', 'Taihe Chengguanzhen', 'T''a-ho,T''ai-ho,T''ai-ho-hsien,Taihe,Taihe Chengguanzhen,T’a-ho,T’ai-ho,T’ai-ho-hsien,tai he cheng guan zhen,太和城关镇', 33.1655200, 115.6488600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15137, 'Taihe', 'Taihe', 'She-hung,Shehong,T''ai-ho,T''ai-ho-ch''ang,T''ai-ho-chen,Taihe,Taykhe,T’ai-ho,T’ai-ho-chen,T’ai-ho-ch’ang,tai he,太和', 30.8712300, 105.3845400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15138, 'Taihe', 'Taihe', 'Taihe,Taihe Zhen,Taiheba,tai he,tai he ba,tai he zhen,太和,太和镇,太河坝', 30.0994900, 106.0489000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15139, 'Taihe', 'Taihe', 'T''ai-ho,T''ai-ho-hsu,Taihe,Taihe Zhen,T’ai-ho,T’ai-ho-hsü,tai he,tai he zhen,太和,太和镇', 27.0527200, 116.6110500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15140, 'Taihe', 'Taihe', 'T''ai-ho,T''ai-ho-shih,Taihe,Taihe Zhen,T’ai-ho,T’ai-ho-shih,tai he,tai he zhen,太和,太和镇', 23.2922800, 113.3496200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15141, 'Mingxing', 'Mingxing', 'Mingxing,Mingxing Zhen,T''ai-ku,T''ai-ku-hsien,Taigu,Taigu Xian,T’ai-ku,T’ai-ku-hsien,ming xing,ming xing zhen,tai gu xian,太谷县,明星,明星镇', 37.4263900, 112.5441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15142, 'Taishan', 'Taishan', 'GJai Son,Hsin-ning,Sunning,Sunninghsien,Sünninghsien,Taicheng,Taicheng Jiedao,Taishan,Taishan Shi,Tajshan'',Thoi-san-su,Thòi-sân-sṳ,Toishan,Toyshan,ZCA,tai cheng,tai cheng jie dao,tai shan,tai shan shi,taisan si,tayshan,tayyshan,Đài Sơn,Тайшань,טאישאן,تائشان,تائیشان,تايشان,تایشان,台城,台城街道,台山,台山市,타이산 시', 22.2513500, 112.7799000, 'CN', '2016-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15143, 'Chengxiang', 'Chengxiang', 'Chengxiang,Chengxiang Zhen,T''ai-ts''ang,T''ai-ts''ang-ch''eng,T''ai-ts''ang-hsien,Taicang,Taicang Shi,T’ai-ts’ang,T’ai-ts’ang-ch’eng,T’ai-ts’ang-hsien,cheng xiang,cheng xiang zhen,tai cang,tai cang shi,城厢,城厢镇,太仓,太仓市', 31.4477800, 121.0938900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15144, 'Taibao', 'Taibao', 'Taibao,Taibao Zhen,tai bao,tai bao zhen,太保,太保镇', 24.6854400, 112.1771600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15145, 'Taibai', 'Taibai', 'T''ai-pai,T''ai-pai-chen,Taibai,Taibai Zhen,Taibaisi,T’ai-pai,T’ai-pai-chen,tai bai,tai bai zhen,太白,太白镇', 29.0872700, 117.6893700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15146, 'Taibai', 'Taibai', 'T''ai-pai,Taibai,Taipai Zhen,T’ai-pai,tai bai,tai bai zhen,太白,太白镇', 28.4085700, 107.0871600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15147, 'Taiba', 'Taiba', 'T''ai-pa,Taiba,Taiba Xiang,T’ai-pa,tai ba,tai ba xiang,太拔,太拔乡', 24.9853600, 116.6354900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15148, 'Tai’an', 'Tai''an', 'T''ai-an-hsien,T''ai-an-shih,Tai''an,Taianfu,Tai’an,Tajan'',T’ai-an-hsien,T’ai-an-shih,Тайань', 36.1852800, 117.1200000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15149, 'Tai’an', 'Tai''an', 'T''ai-an-ch''ang,Tai''an,Tai''an Zhen,Tai’an,Tai’an Zhen,T’ai-an-ch’ang,tai an,tai an zhen,太安,太安镇', 30.0660300, 105.8093400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15150, 'Tafang', 'Tafang', 'Ta-tang,Tafang,Tafang Xiang,ta fang,ta fang xiang,塔坊,塔坊乡', 29.7806400, 117.6642200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15151, 'Tadou', 'Tadou', 'Lianhe Xiang,Lien-ho,T''a-tou,Tadou,T’a-tou,lian he xiang,ta dou,塔兜,联合乡', 26.3715700, 118.2297200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15152, 'Tadianjie', 'Tadianjie', 'T''a-tien-chieh,Tadian,Tadian Zhen,Tadianjie,T’a-tien-chieh,ta dian,ta dian jie,ta dian zhen,塔甸,塔甸街,塔甸镇', 24.2483300, 102.1591700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15153, 'Suzhou', 'Suzhou', 'Su-hsien,Suchow,Suchzhou,Suxian,Suzhou,su zhou shi,Сучжоу,شيۇجۇ شەھىرى,宿州市', 33.6361100, 116.9788900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15154, 'Fuyu', 'Fuyu', 'Fuyu,Su-sung,Su-sung-hsien,Susong,Susong Xian,fu yu,su song xian,孚玉,宿松县', 30.1500000, 116.1166700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15155, 'Suozhen', 'Suozhen', 'Huantai,So-chen,Suozhen,Suozhencun', 36.9538900, 118.1047200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15156, 'Suojie', 'Suojie', 'So-shih,So-shih-chieh,Suojie,Suojie Xiang,Suoshi,suo jie,suo jie xiang,所街,所街乡', 29.8800000, 110.9053100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15157, 'Suonan', 'Suonan', 'Dongxiangzu,Dongxiangzu Zizhixian,So-lo-pa,So-nan-chen,So-nan-pa,Soloba,Suonan,Suonanba,Tung-hsiang,Tung-hsiang-tsu-tzu-chih-hsien,dong xiang zu zi zhi xian,suo nan,东乡族自治县,锁南', 35.6665300, 103.3979200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15158, 'Suocheng', 'Suocheng', 'So-ch''eng,So-ch’eng,Suocheng,Suocheng Zhen,suo cheng,suo cheng zhen,所城,所城镇', 25.2675000, 112.1438900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15159, 'Sunzhen', 'Sunzhen', 'Sun-chen,Sun-chia-chuang,Sun-chuang,Sunzhen,Sunzhenjie,sun zhen,孙镇', 34.9836400, 109.7535700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15160, 'Sunqiao', 'Sunqiao', 'Sun-chia-ch''iao,Sun-chia-ch’iao,Sunjiaqiao,Sunqiao,Sunqiao Zhen,sun qiao,sun qiao zhen,孙桥,孙桥镇', 31.0868000, 113.0144700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15161, 'Sunbu', 'Sunbu', 'Sun-chia-ch''iao,Sun-chia-ch’iao,Sun-chia-fou,Sun-chia-pu,Sunbu,Sunbu Zhen,Sunjiabu,Sunkiapu,sun bu,sun bu zhen,孙埠,孙埠镇', 30.9000000, 118.8827800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15162, 'Sunfang', 'Sunfang', 'Sun-fang-chieh,Sunfang,Sunfang Zhen,sun fang,sun fang zhen,孙坊,孙坊镇', 27.8688400, 116.1818600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15163, 'Sunduan', 'Sunduan', 'Sun-tuan,Sun-tuan-chen,Sunduan,Sunduan Zhen,sun duan,sun duan zhen,孙端,孙端镇', 30.0698100, 120.6965600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15164, 'Sumdo', 'Sumdo', 'Quguoqiongwa,Senduo,Senduo Xiang,Sumdo,qu guo qiong wa,sen duo,sen duo xiang,曲果琼哇,森多,森多乡', 35.5185100, 100.9328000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15165, 'Sulong', 'Sulong', 'Sulong,Sulong Jiedao,su long,su long jie dao,素龙,素龙街道', 22.7170700, 111.6089400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15166, 'Sujiazhuang', 'Sujiazhuang', 'Su-chia-chuang,Sujiazhuang,Sujiazhuang Xiang,su jia zhuang,su jia zhuang xiang,苏家庄,苏家庄乡', 38.4077200, 114.0022900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15167, 'Suizhou', 'Suizhou', 'Suej-cou,Suej-čou,Suejdzou,Sui,Sui-chiu-chhi,Sui-ciu,Sui-hsien,Suichow,Suixian,Sujchzhou,Suî-chiu-chhī,Sùi-ciŭ,Tuy Chau,Tùy Châu,ssu-ijeou si,sui zhou,sui zhou shi,swyzhw,Суејџоу,Суйчжоу,سویژؤ,随州市,隨州,쑤이저우 시', 31.7111100, 113.3630600, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15168, 'Suiyang', 'Suiyang', 'Suiyang,Suiyang Zhen,Suiyangchang,sui yang,sui yang zhen,绥阳,绥阳镇', 28.1178900, 107.7445800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15169, 'Sui Xian Chengguanzhen', 'Sui Xian Chengguanzhen', 'K''uei-ch''iu,K’uei-ch’iu,Sui,Sui Xian Chengguanzhen,Sui-hsien,Suichow,Suixian,Suysyan,sui xian cheng guan zhen,睢县城关镇', 34.4479700, 115.0443900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15170, 'Suixi', 'Suixi', 'Sui-ch''i,Sui-ch''i-k''ou,Sui-ch''i-shih,Sui-chi-chen,Sui-ch’i,Sui-ch’i-k’ou,Sui-ch’i-shih,Sui-hsi,Suixi,sui xi,濉溪', 33.8906700, 116.7747300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15171, 'Suicheng', 'Suicheng', 'Lei-pei,Sui-ch''i,Sui-ch''i-hsien,Sui-ch’i,Sui-ch’i-hsien,Sui-hsi,Suicheng,Suicheng Zhen,Suikai,Suikaihsien,Suixi,sui cheng,sui cheng zhen,遂城,遂城镇', 21.3795100, 110.2505200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15172, 'Suishan', 'Suishan', 'Emei,O-mei,Suishan,sui shan,绥山', 29.6083100, 103.4860300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15173, 'Quyang', 'Quyang', 'Quyang,Sui-an,Sui-p''ing-hsien,Sui-p’ing-hsien,Suiping,qu yang,灈阳', 33.1447200, 113.9902800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15174, 'Suicheng', 'Suicheng', 'Sui-ch''eng-chen,Sui-ch’eng-chen,Sui-ning-ch''eng,Sui-ning-ch’eng,Sui-ning-hsien,Suicheng,Suining', 33.8963000, 117.9330700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15175, 'Suining', 'Suining', 'Soi-ning,Suej-ning,Sui-leng-chhi,Sui-nen-su,Sui-ning-hsien,Suining,Sujnin,Suynin,Sôi-nìng,Súi-nèn-sṳ,Sūi-lêng-chhī,Toai Ninh,Toại Ninh,ssu-ining si,sui ning,sui ning shi,swynyng,Суйнин,سوئنینگ,سوینینگ,遂宁,遂宁市,遂寧,遂寧市,쑤이닝 시', 30.5080200, 105.5733200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15176, 'Suicheng', 'Suicheng', 'Chien-ning,Chien-ning-hsien,Jianning,Jianning Xian,Kienning,Kienninghsien,Suicheng,Suicheng Zhen,jian ning xian,sui cheng,sui cheng zhen,建宁县,濉城,濉城镇', 26.8377900, 116.8359200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15177, 'Sui’an', 'Sui''an', 'Chang-p''u,Chang-p''u-ch''eng,Chang-p''u-hsien,Chang-p’u,Chang-p’u-ch’eng,Chang-p’u-hsien,Chanpuhs,Sui''an,Sui’an,Zhangpu,sui an,绥安', 24.0869800, 117.6091200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15178, 'Sucun', 'Sucun', 'Su-ts''un,Su-ts’un,Sucun,Ts''un,Ts’un,su cun,苏村', 34.6418500, 109.8504700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15179, 'Sucun', 'Sucun', 'Su-ts''un,Su-ts’un,Sucun,Sucun Xiang,su cun,su cun xiang,苏村,苏村乡', 29.9809300, 118.7034200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15180, 'Suchen', 'Suchen', 'Su-ch''en-chuang,Su-ch’en-chuang,Suchen,Suchen Zhen,su chen,su chen zhen,苏陈,苏陈镇', 32.5055100, 120.0137300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15181, 'Suban', 'Suban', 'Suban,Suban Xiang,su ban,su ban xiang,苏坂,苏坂乡', 25.3150000, 117.2747200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15182, 'Su’ao', 'Su''ao', 'Su''ao,Su''ao Zhen,Su’ao,Su’ao Zhen,su ao,su ao zhen,苏澳,苏澳镇', 25.6160200, 119.7066900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15183, 'Songzhuang', 'Songzhuang', 'Songzhuang,Songzhuang Zhen,Sung-chuang,song zhuang,song zhuang zhen,宋庄,宋庄镇', 39.9468500, 116.7256900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15184, 'Songyuan', 'Songyuan', 'Ch''ing-yuan,Ch''ing-yuan-hsien,Ch’ing-yüan,Ch’ing-yüan-hsien,Kingyuan,Kingyuanhsien,Kingyüan,Kingyüanhsien,Qingyuan,Qingyuan Xian,Songyuan,Songyuan Zhen,qing yuan,qing yuan xian,song yuan,song yuan zhen,庆元,庆元县,松源,松源镇', 27.6216700, 119.0591700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15185, 'Songyuan', 'Songyuan', 'Chien-she-chen,Songxi,Songxi Xian,Songyuan,Songyuan Zhen,Sung-ch''i,Sung-ch''i-hsien,Sung-cheng,Sung-ch’i,Sung-ch’i-hsien,Sung-hsi,Sungki,Sungki-hsien,song xi,song xi xian,song yuan,song yuan zhen,松源,松源镇,松溪,松溪县', 27.5273000, 118.7765700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15186, 'Songyuan', 'Songyuan', 'Hsin-hsu,Hsin-hsü,Songyuan,Songyuan Zhen,Sung-yuan,Sung-yuan-hsin-hsu,Sung-yuan-hsu,Sung-yüan,Sung-yüan-hsin-hsü,Sung-yüan-hsü,song yuan,song yuan zhen,松源,松源镇', 24.7359000, 116.3799000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15187, 'Songyang', 'Songyang', 'Songming,Songyang,Sung-ming,Sung-ming-ch''eng,Sung-ming-ch’eng,Sung-ming-hsien,Sung-yang-chen,song yang,嵩阳', 25.3251100, 103.0298100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15188, 'Song Xian Chengguanzhen', 'Song Xian Chengguanzhen', 'Chiu-hsien,Chiu-hsien-chen,Song Xian Chengguanzhen,Songxian,Sung-hsien,song xian cheng guan zhen,嵩县城关镇', 34.1347200, 112.0825000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15189, 'Songxia', 'Songxia', 'Songxia,Songxia Zhen,Sung-hsia,Sung-hsia-chen,song sha,song sha zhen,崧厦,崧厦镇', 30.0976300, 120.8412500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15190, 'Songxi', 'Songxi', 'Songxi,Songxi Zhen,Sung-hsi,song xi,song xi zhen,嵩溪,嵩溪镇', 26.2654700, 116.9450700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15191, 'Songshi', 'Songshi', 'Songshi,Songshi Zhen,Sung-shih,song shi,song shi zhen,嵩市,嵩市镇', 27.7739000, 116.9145400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15192, 'Songshan', 'Songshan', 'Songshan,Songshan Zhen,Sung-shan,Sung-shan-chi,song shan,song shan zhen,松山,松山镇', 37.4104800, 120.8611800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15193, 'Songshan', 'Songshan', 'Songshan,Songshan Zhen,Sung-shan,Sung-shan-li,song shan,song shan zhen,松山,松山镇', 27.6323400, 114.6593800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15194, 'Songmuping', 'Songmuping', 'Songmuping,Songmuping Zhen,Sung-mu-p''ing,Sung-mu-p’ing,song mu ping,song mu ping zhen,松木坪,松木坪镇', 30.1332300, 111.4790200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15195, 'Songkou', 'Songkou', 'Songkou,Songkou Zhen,Sung-k''ou,Sung-k''ou-p''ing,Sung-k''ou-ying,Sung-k’ou,Sung-k’ou-p’ing,Sung-k’ou-ying,song kou,song kou zhen,嵩口,嵩口镇', 26.1441200, 116.8872300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15196, 'Songkou', 'Songkou', 'Songkou,Songkou Zhen,Sung-k''ou,Sung-k’ou,Sungkow,song kou,song kou zhen,嵩口,嵩口镇', 25.8040700, 118.5849400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15197, 'Songkou', 'Songkou', 'Shung-k''ou,Shung-k’ou,Songkou,Songkou Zhen,Sung-k''ou,Sung-k''ou-hsu,Sung-k’ou,Sung-k’ou-hsü,Tsungkow,song kou,song kou zhen,松口,松口镇', 24.5022000, 116.4075300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15198, 'Songkan', 'Songkan', 'Songkan,Songkan Zhen,Sung-k''an,Sung-k’an,song kan,song kan zhen,松坎,松坎镇', 28.5497200, 106.8597200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15199, 'Songqiao', 'Songqiao', 'Songjiaqiao,Songqiao,Songqiao Zhen,Sung-chia-ch''iao,Sung-chia-ch''iao-chen,Sung-chia-ch’iao,Sung-chia-ch’iao-chen,song qiao,song qiao zhen,送桥,送桥镇', 32.6429500, 119.3041500, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15200, 'Songjiang', 'Songjiang', 'Songjiang,Songjiang Qu,Sunchiang,Sung-chiang,Sung-chiang-hsien,Sungkiang,Sungkiang-hsien,Sunkiang,Sunkiangfu,song jiang,song jiang qu,松江,松江区', 31.0359500, 121.2146000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15201, 'Songhu', 'Songhu', 'Songhu,Songhu Zhen,Sung-hu,Sung-hu-chieh,song hu,song hu zhen,松湖,松湖镇', 28.3789800, 115.6505000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15202, 'Songhe', 'Songhe', 'Songhe,Songhe Zhen,Sung-ho,Sung-ho-cheh,Sung-ho-chen,song he,song he zhen,宋河,宋河镇', 31.1964700, 113.2837300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15203, 'Songgang', 'Songgang', 'Songgang,Songgang Jiedao,Sung-kang,song gang,song gang jie dao,松岗,松岗街道', 22.7786600, 113.8454000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15204, 'Songgai', 'Songgai', 'Songgai,Songgai Zhen,Sung-kai,Sung-kai-ch''ang,Sung-kai-chen,Sung-kai-ch’ang,Zhengjiezi,song gai,song gai zhen,zheng jie zi,松溉,松溉镇,正街子', 29.0576200, 105.8920900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15205, 'Songcun', 'Songcun', 'Songcun,Songcun Zhen,Sung-ts''un,Sung-ts’un,song cun,song cun zhen,宋村,宋村镇', 37.0744700, 122.0104100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15206, 'Songcun', 'Songcun', 'Songcun,Songcun Xiang,Sung-ts''un,Sung-ts’un,song cun,song cun xiang,宋村,宋村乡', 29.7252300, 118.9012900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15207, 'Songcheng', 'Songcheng', 'Funing,Funing-fu,Hsia-p''u,Hsia-p''u-hsien,Hsia-p’u,Hsia-p’u-hsien,Siapo,Siapu,Siapu-hsien,Songcheng,Songcheng Jiedao,Xiapu,song cheng,song cheng jie dao,松城,松城街道', 26.8819400, 120.0011100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15208, 'Songbu', 'Songbu', 'Songbu,Songbu Zhen,Sung-fou,Sung-pu,Sungfow,song bu,song bu zhen,宋埠,宋埠镇', 31.0628600, 114.7931100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15209, 'Songbu', 'Songbu', 'Songbu,Songbu Zhen,song bu,song bu zhen,宋埠,宋埠镇', 28.7330600, 115.4934100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15210, 'Shangsongfan', 'Shangsongfan', 'Shangsongfan,Songban,Songfan,shang song fan,song fan,上宋畈,宋畈', 28.9932600, 118.5258700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15211, 'Songbai', 'Songbai', 'Shen-nung-chia,Shennongjia,Songbai,Sung-hsiang-p''ing,Sung-hsiang-p’ing,song bai,松柏', 31.7568500, 110.6725200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15212, 'Song’ao', 'Song''ao', 'Song''ao,Song''ao Zhen,Song’ao,Song’ao Zhen,Sung-ao,Sung-ao-shih,song ao,song ao zhen,松岙,松岙镇', 29.6119300, 121.6859000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15213, 'Sizao', 'Sizao', 'Chung-ssu-tsao,Hsi-ssu-tsao,Sizao,Sizao Zhen,Ssu-tsao,si zao,si zao zhen,四灶,四灶镇', 32.8496900, 120.4630200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15214, 'Siyang', 'Siyang', 'Cengong,Ch''enkung,Ch''ien-kung,Ch’enkung,Ch’ien-kung,Ling-kung,Siyang,Siyang Zhen,Ssu,Ssu-yang,Ssu-yang-chen,Ssuchou,Szechow,Ts''en-kung,Ts''en-kung-hsien,Ts’en-kung,Ts’en-kung-hsien,si yang,si yang zhen,思旸,思旸镇', 27.2116000, 108.7450000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15215, 'Siyang', 'Siyang', 'Shang-ssu,Shang-ssu-hsien,Shangsi,Shangsze,Shangsze-hsien,Siyang,si yang,思阳', 22.1684100, 107.9430900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15216, 'Sicheng', 'Sicheng', 'Sicheng,Sixian,Ssu,Ssu-chou,Ssu-hsien,Suhsien,Szechow,Szehsien,Szu-hsien,si cheng,泗城', 33.4893600, 117.8567900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15217, 'Sixi', 'Sixi', 'Sixi,Sixi Zhen,Ssu-hsi,si xi,si xi zhen,泗溪,泗溪镇', 28.3135000, 115.0819800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15218, 'Siwang', 'Siwang', 'Siwang,Siwang Zhen,si wang,si wang zhen,四望,四望镇', 30.0276600, 115.5515600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15219, 'Sishui', 'Sishui', 'Sishui,Ssu-shui,Ssu-shui-hsien,Szeshuihsien', 35.6488900, 117.2758300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15220, 'Sishi Lijie', 'Sishi Lijie', 'Sishi Lijie,Sishi Lijie Zhen,Ssu-shih-li-chieh,si shi li jie,si shi li jie zhen,四十里街,四十里街镇', 29.1139100, 116.7577600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15221, 'Siqu', 'Siqu', 'Siqu,Siqu Zhen,Ssu-ch''u,Ssu-ch’ü,si qu,si qu zhen,思渠,思渠镇', 28.6733500, 108.3377600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15222, 'Siqiao', 'Siqiao', 'Siqiao,Siqiao Xiang,si qiao,si qiao xiang,泗桥,泗桥乡', 27.1647200, 119.2147200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15223, 'Siquanpu', 'Siquanpu', 'Siquanpu,Siquanpu Zhen,si quan pu,si quan pu zhen,思泉铺,思泉铺镇', 28.1672400, 114.6009200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15224, 'Siqian', 'Siqian', 'Siqian,Siqian Shezu Zhen,Siqian Shezuxiang,Ssu-ch''ien,Ssu-ch’ien,si qian,si qian she zu zhen,司前,司前畲族镇', 27.6682600, 119.7846700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15225, 'Siqian', 'Siqian', 'Siqian,Siqian Zhen,Ssu-ch''ien,Ssu-ch''ien-chieh,Ssu-ch''ien-chien,Ssu-ch''ing,Ssu-ch’ien,Ssu-ch’ien-chieh,Ssu-ch’ien-chien,Ssu-ch’ing,si qian,si qian zhen,司前,司前镇', 24.6684500, 114.0871300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15226, 'Siqian', 'Siqian', 'Siqian,Siqian Zhen,Ssu-ch''ien,Ssu-ch’ien,Szetsin,si qian,si qian zhen,司前,司前镇', 22.4952000, 112.8538800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15227, 'Sipu', 'Sipu', 'Sipu,Sipu Xiang,Ssu-p''u,Ssu-p’u,si pu,si pu xiang,司铺,司铺乡', 28.4353500, 117.7086800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15228, 'Siping', 'Siping', 'Siping,Siping Zhen,Ssu-p''ing,Ssu-p’ing,si ping,si ping zhen,寺坪,寺坪镇', 31.9869100, 111.1318700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15229, 'Simingshan', 'Simingshan', 'Simingshan,Simingshan Zhen,si ming shan,si ming shan zhen,四明山,四明山镇', 29.7358900, 121.1102100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15230, 'Simenqian', 'Simenqian', 'Simen Qianzhen,Simenqian,Ssu-men-ch''ien,Ssu-men-ch’ien,si men qian,si men qian zhen,司门前,司门前镇', 27.4872200, 110.8861100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15231, 'Simen', 'Simen', 'Simen,Simen Zhen,Ssu-men,Ti-ssu-men,Ti-ssu-men-shih,si men,si men zhen,泗门,泗门镇', 30.1616700, 121.0388900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15232, 'Simapu', 'Simapu', 'Simapu,Simapu Zhen,Ssu-ma-p''u,Ssu-ma-p''u-hsu,Ssu-ma-p’u,Ssu-ma-p’u-hsü,si ma pu,si ma pu zhen,司马浦,司马浦镇', 23.2619600, 116.3617100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15233, 'Simao', 'Simao', 'Fu-hsing-chen,SYM,Simao,Simao Zhen,Ssu-mao,Ssu-mao-chen,Ssu-mao-hsien,Szemao,Szemao-hsien,si mao,si mao zhen,思茅,思茅镇', 22.7886300, 100.9748100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15234, 'Silun', 'Silun', 'Silun,Silun Zhen,Ssu-lun,Ssu-lun-hsu,Ssu-lun-hsü,si lun,si lun zhen,泗纶,泗纶镇', 22.7090500, 111.3196500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15235, 'Silihe', 'Silihe', 'Silihe,Silihe Xiang,si li he,si li he xiang,泗里河,泗里河乡', 28.4119400, 111.8227800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15236, 'Silidian', 'Silidian', 'Silidian,Ssu-li-tien,si li dian,四里店', 33.4664300, 112.9157300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15237, 'Sili', 'Sili', 'Sili,Sili Zhen,Ssu-li,si li,si li zhen,泗沥,泗沥镇', 28.4000000, 117.1666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15238, 'Dachang Shandao', 'Dachang Shandao', 'Ch''ang-hai-hsien,Ch''ang-shan,Changhai,Ch’ang-hai-hsien,Ch’ang-shan,Dachang Shandao,Dachang Shandao Zhen,Sikuanshi,Ssu-k''uai-shih,Ssu-k’uai-shih,Ta-ch''ang-shan-tao,Ta-ch’ang-shan-tao,da zhang shan dao,da zhang shan dao zhen,大长山岛,大长山岛镇', 39.2755600, 122.6000000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15239, 'Sikou', 'Sikou', 'Sikou,Sikou Zhen,Ssu-k''ou,Ssu-k''ou-chi,Ssu-k’ou,Ssu-k’ou-chi,Tung-tz''u-k''ou,Tung-tz’u-k’ou,si kou,si kou zhen,寺口,寺口镇', 37.3174700, 120.6351000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15240, 'Sikou', 'Sikou', 'Sikou,Sikou Zhen,Ssu-k''ou,Ssu-k’ou,si kou,si kou zhen,思口,思口镇', 29.3542700, 117.8122600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15241, 'Sikeshu', 'Sikeshu', 'Sikeshu,Sikeshu Xiang,si ke shu,si ke shu xiang,四棵树,四棵树乡', 33.2859600, 112.3489500, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15242, 'Sijiu', 'Sijiu', 'Sijiu,Sijiu Zhen,Ssu-chiu,si jiu,si jiu zhen,四九,四九镇', 22.2090800, 112.8583900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15243, 'Sijiqing', 'Sijiqing', 'Sijiqing,Sijiqing Zhen,si ji qing,si ji qing zhen,四季青,四季青镇', 39.9507200, 116.2654500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15244, 'Sijing', 'Sijing', 'Sijing,Sijing Zhen,Ssu-ching,Ssu-ching-chen,Szeking,si jing,si jing zhen,泗泾,泗泾镇', 31.1144400, 121.2683300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15245, 'Sijia', 'Sijia', 'Sijia,Sijia Zhen,Sijiaba,Ssu-chia,Ssu-chia-pa,si jia,si jia zhen,四甲,四甲镇', 32.0142900, 121.2758300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15246, 'Sigu', 'Sigu', 'Sigu,Sigu Zhen,si gu,si gu zhen,四姑,四姑镇', 31.4178000, 114.4025200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15247, 'Sigaozhuang', 'Sigaozhuang', 'Sigaozhuang,Ssu-kao-chuang', 39.4677800, 117.2502800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15248, 'Si’en', 'Si''en', 'Huan-chiang,Huanjiang,Si''en,Si’en,Ssu-en,Sze-ngen-hsien,Szeenhsien,Szengen,si en,思恩', 24.8419800, 108.2716200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15249, 'Sidui', 'Sidui', 'Nan-ssu-tui,Sidui,Sidui Zhen,Siduijie,Ssu-tui,Ssu-tui-chieh,si dui,si dui zhen,四队,四队镇', 34.4166700, 119.4666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15250, 'Sidu', 'Sidu', 'Sidu,Sidu Zhen,Ssu-tu,si dou,si dou zhen,四都,四都镇', 29.1515400, 114.5902400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15251, 'Sidu', 'Sidu', 'Sidu,Sidu Zhen,Ssu-tu,si dou,si dou zhen,四都,四都镇', 25.6551800, 116.1987100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15252, 'Sidu', 'Sidu', 'Sidu,Sidu Zhen,Ssu-tu,si dou,四都', 23.7835600, 117.2735100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15253, 'Sicheng', 'Sicheng', 'Ling-lo,Ling-lo-hsien,Ling-yun-chen,Ling-yun-hsien,Ling-yün-chen,Ling-yün-hsien,Lingyun,Sicheng,Ssu-ch''eng,Ssu-ch’eng,Sze-cheng-fu,Sze-chêng-fu,Szecheng,si cheng,泗城', 24.4054000, 106.5815400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15254, 'Si’an', 'Si''an', 'Ch''en-chiu-tien,Ch''en-chiu-tien-chen,Chiu-tien,Chiu-tien-chen,Ch’en-chiu-tien,Ch’en-chiu-tien-chen,Si''an,Si''an Zhen,Si’an,Si’an Zhen,Ssu-an,si an,si an zhen,四安,四安镇', 32.1363600, 120.9410100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15255, 'Si’an', 'Si''an', 'Si''an,Si''an Zhen,Si’an,Si’an Zhen,Ssu-an,Ssu-an-chen,Szean,si an,si an zhen,泗安,泗安镇', 30.8983300, 119.6536100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15256, 'Shuyuan', 'Shuyuan', 'Shuyuan,Shuyuan Zhen,shu yuan,shu yuan zhen,书院,书院镇', 30.9312700, 121.8601000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15257, 'Shucheng', 'Shucheng', 'Mu-yang,Shu-ch''eng-chen,Shu-ch’eng-chen,Shu-yang-ch''eng,Shu-yang-ch’eng,Shu-yang-hsien,Shucheng,Shucheng Zhen,Shuyang,Shuyang Xian,shu cheng,shu cheng zhen,shu yang xian,术城,术城镇,沭阳县', 34.1212800, 118.7807800, 'CN', '2015-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15258, 'Shuozhou', 'Shuozhou', 'Shohchow,Shohsien,Shosyan'',Shosyan’,Shou-hsien,Shuo,Shuo-hsien,Shuoxian,Shuozhou,shuo zhou,朔州', 39.3158300, 112.4225000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15259, 'Shuofang', 'Shuofang', 'Shih-fang,Shuofang,Shuofang Jiedao,shuo fang,shuo fang jie dao,硕放,硕放街道', 31.4885700, 120.4399400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15260, 'Shuizhai', 'Shuizhai', 'Shui-chai,Shui-chai-chen,Shui-chai-hsu,Shui-chai-hsü,Shuizhai,Shuizhai Zhen,Wuhua,shui zhai,shui zhai zhen,水寨,水寨镇', 23.9296100, 115.7649900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15261, 'Shuiyuesi', 'Shuiyuesi', 'Shui-yueh-ssu,Shui-yüeh-ssu,Shuiyuesi,Shuiyuesi Zhen,shui yue si,shui yue si zhen,水月寺,水月寺镇', 31.2385300, 111.0140600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15262, 'Shuiyang', 'Shuiyang', 'Shui-yang-chen,Shuiyang,Shuiyang Zhen,shui yang,shui yang zhen,水阳,水阳镇', 31.2297800, 118.7888900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15263, 'Shuixi', 'Shuixi', 'Shui-hsi,Shui-hsi-chieh,Shuixi,Shuixi Zhen,shui xi,shui xi zhen,水西,水西镇', 27.8230500, 115.0298600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15264, 'Shuitu', 'Shuitu', 'Chiang-pei,Chiang-pei-hsien,Shui-t''u-chen,Shui-t''u-t''o,Shui-t’u-chen,Shui-t’u-t’o,Shuitu,Shuitu Zhen,Shuitutuo,T''u-t''o,T''u-t''o-chen,T’u-t’o,T’u-t’o-chen,shui tu,shui tu zhen,水土,水土镇', 29.7822100, 106.4974000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15265, 'Shuitou', 'Shuitou', 'Jiaokou Xian,Shui-t''ou-chen,Shui-t’ou-chen,Shuitou,Shuitou Zhen,jiao kou xian,shui tou,shui tou zhen,交口县,水头,水头镇', 36.9730600, 111.2091000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15266, 'Shuitianzhuang', 'Shuitianzhuang', 'Shuitianzhuang,Shuitianzhuang Xiang,shui tian zhuang,shui tian zhuang xiang,水田庄,水田庄乡', 28.0519400, 110.8122200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15267, 'Shuitianhe', 'Shuitianhe', 'Shui-t''ien-ho,Shui-t’ien-ho,Shuitianhe,Shuitianhe Zhen,shui tian he,shui tian he zhen,水田河,水田河镇', 28.5324600, 109.5838500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15268, 'Shuitianba', 'Shuitianba', 'Shuitianba,Shuitianba Xiang,shui tian ba,shui tian ba xiang,水田坝,水田坝乡', 31.0591900, 110.6772600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15269, 'Shuitianba', 'Shuitianba', 'Shui-t''ien-pa,Shui-t’ien-pa,Shuitianba,Shuitianba Xiang,shui tian ba,shui tian ba xiang,水田坝,水田坝乡', 29.4529100, 109.7205500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15270, 'Shuidatian', 'Shuidatian', 'Shui-t''ien,Shui-t’ien,Shuidatian,Shuitian', 27.8522200, 109.6047200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15271, 'Shuiqian', 'Shuiqian', 'Shui-ch''ien,Shui-ch’ien,Shuiqian,Shuiqian Xiang,shui qian,shui qian xiang,水茜,水茜乡', 26.4665900, 116.7431500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15272, 'Shuiping', 'Shuiping', 'Shuiping,Shuiping Zhen,shui ping,shui ping zhen,水坪,水坪镇', 32.3051200, 109.8107800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15273, 'Shuinan', 'Shuinan', 'Shui-nan-shih,Shuinan,Shuinan Zhen,shui nan,shui nan zhen,水南,水南镇', 26.9578700, 115.3006600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15274, 'Shuinanxu', 'Shuinanxu', 'Shuinanxu,Shuinanxu Xiang,shui nan wei,shui nan wei xiang,水南圩,水南圩乡', 26.8355800, 116.4856100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15275, 'Shuimen', 'Shuimen', 'Shui-men-k''eng,Shui-men-k’eng,Shuimen,Shuimen Shezuxiang,shui men,shui men she zu xiang,水门,水门畲族乡', 26.9717300, 120.0689700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15276, 'Shuikou', 'Shuikou', 'Shui-k''ou-hsu,Shui-k’ou-hsu,Shuikou,Shuikou Zhen,Shuikouxu,shui kou,shui kou zhen,水口,水口镇', 25.1420800, 114.4793100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15277, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 34.9717900, 107.9984700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15278, 'Shuikou', 'Shuikou', 'Shiakou,Shui-kow,Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 26.3836000, 118.7302700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15279, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 25.7117600, 118.4307100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15280, 'Shuikou', 'Shuikou', 'Shui-k''ou-hsu,Shui-k’ou-hsü,Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 23.9837200, 115.8958100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15281, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 22.4547400, 112.7639600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15282, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 22.2500000, 110.9139100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15283, 'Shuijiang', 'Shuijiang', 'Shui-chiang,Shui-chiang-shih,Shuijiang,Shuijiang Zhen,shui jiang,shui jiang zhen,水江,水江镇', 29.2476000, 107.2844300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15284, 'Laixi', 'Laixi', 'Lai-hsi,Laixi,Laixi Shi,Shui-chi,Shui-kou-t''ou,Shui-kou-t’ou,Shuiji,Shuikowtow', 36.8591700, 120.5269400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15285, 'Shuiji', 'Shuiji', 'Shui-chi,Shui-chi-hsien,Shuiji,Shuiji Zhen,Shuiki,Shuiki-hsien,shui ji,shui ji zhen,水吉,水吉镇', 27.4213900, 118.3450200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15286, 'Shuigou', 'Shuigou', 'Shui-kou,Shuigou,Shuigou Zhen,shui gou,shui gou zhen,水沟,水沟镇', 34.7485800, 107.0127900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15287, 'Shuidong', 'Shuidong', 'Shui-tung,Shui-tung-chen,Shuidong,Shuidong Zhen,shui dong,shui dong zhen,水东,水东镇', 30.7883300, 118.9544400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15288, 'Shuidong', 'Shuidong', 'Shui-tang-shih,Shui-tung,Shui-tung-chen,Shuidong,Shuidong Zhen,Sui-tung,Tien-pai,shui dong,shui dong zhen,水东,水东镇', 21.5134000, 111.0018400, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15289, 'Shuidao', 'Shuidao', 'Shui-tao,Shui-tao-chi,Shuidao,Shuidao Zhen,shui dao,shui dao zhen,水道,水道镇', 37.1707200, 121.5782500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15290, 'Shuichun', 'Shuichun', 'Shuichun,Shuichun Zhen,Shuicun,shui chun,shui chun zhen,水唇,水唇镇', 23.3152400, 115.7375800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15291, 'Shuiche', 'Shuiche', '', 27.6869400, 110.9997200, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15292, 'Shuiche', 'Shuiche', 'Shui-ch''e-hsu,Shui-ch’e-hsü,Shuiche,Shuiche Zhen,shui che,shui che zhen,水车,水车镇', 24.0889800, 116.0187400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15293, 'Shuibu', 'Shuibu', 'Shuibu,Shuibu Zhen,shui bu,shui bu zhen,水步,水步镇', 22.3352300, 112.8017600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15294, 'Shuibian', 'Shuibian', 'Shui-pien,Shuibian,Shuibian Zhen,Xiajiang Xian,shui bian,shui bian zhen,xia jiang xian,峡江县,水边,水边镇', 27.6080500, 115.3263600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15295, 'Shuibei', 'Shuibei', 'Shui-pei,Shui-pei-chieh,Shuibei,Shuibei Zhen,shui bei,shui bei zhen,水北,水北镇', 28.0411800, 115.0572500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15296, 'Shuibeijie', 'Shuibeijie', 'Shui-pei,Shuibei,Shuibeijie,Shuibeijie Zhen,shui bei jie,shui bei jie zhen,水北街,水北街镇', 27.6944800, 118.5697400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15297, 'Shuibatang', 'Shuibatang', 'Shixi,Shui-pa-t''ang,Shui-pa-t’ang,Shuibatang,Shuibatang Zhen,shui ba tang,shui ba tang zhen,水坝塘,水坝塘镇', 28.7367100, 107.0746600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15298, 'Shuhong', 'Shuhong', 'Shu-hung,Shu-hung-shih,Shuhong,Shuhong Zhen,shu hong,shu hong zhen,舒洪,舒洪镇', 28.6463800, 120.1561000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15299, 'Shuhe', 'Shuhe', 'Shih-ho-chen,Shu-ho-chen,Shuhe,Shuhezhen,Zhiliang,shu he,shu he zhen,zhi liang,志良,竖河,竖河镇', 31.9925000, 121.6141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15300, 'Shucheng Chengguanzhen', 'Shucheng Chengguanzhen', 'Shu-ch''eng-hsien,Shu-ch’eng-hsien,Shucheng,Shucheng Chengguanzhen,Shucheng Xian,shu cheng cheng guan zhen,shu cheng xian,舒城县,舒城城关镇', 31.4744800, 116.9520700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15301, 'Shuangzhong', 'Shuangzhong', 'Hu-k''ou-hsien,Hu-k''ou-hsien-ch''eng,Hu-k’ou-hsien,Hu-k’ou-hsien-ch’eng,Hukau,Hukou,Hukou Xian,Hukow,Hukow-hsien,Shuangzhong,Shuangzhong Zhen,hu kou,hu kou xian,shuang zhong,shuang zhong zhen,双钟,双钟镇,湖口,湖口县', 29.7429600, 116.2242600, 'CN', '2014-12-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15302, 'Shuangzhao', 'Shuangzhao', 'Shuang-chao,Shuang-chao-chen,Shuang-chao-ling,Shuang-chao-p''u,Shuang-chao-p’u,Shuangzhao,Shuangzhao Zhen,shuang zhao,shuang zhao zhen,双照,双照镇', 34.4022200, 108.6172200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15303, 'Shuangyang', 'Shuangyang', 'Chengnei,Shuangyang,Shuangyang Zhen,cheng nei,shuang yang,shuang yang zhen,双洋,双洋镇,城内', 25.6075000, 117.3600000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15304, 'Shuangxikou', 'Shuangxikou', 'Shuang-ch''i-k''ou,Shuang-ch’i-k’ou,Shuangxikou,Shuangxikou Xiang,shuang xi kou,shuang xi kou xiang,双溪口,双溪口乡', 29.2500000, 111.3666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15305, 'Shuangxiqiao', 'Shuangxiqiao', 'Shuangxi,Shuangxiqiao,Shuangxiqiao Zhen,shuang xi,shuang xi qiao,shuang xi qiao zhen,双溪,双溪桥,双溪桥镇', 29.9270000, 114.4808500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15306, 'Shuangxi', 'Shuangxi', 'Ching-an,Ching-an-ch''eng,Ching-an-ch’eng,Ching-an-hsien,Jing''an Xian,Jing’an Xian,Shuangxi,Shuangxi Zhen,Tsingan,Tsingan-hsien,Tsingonhsien,jing an xian,shuang xi,shuang xi zhen,双溪,双溪镇,靖安县', 28.8629500, 115.3519400, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15307, 'Shuangxi', 'Shuangxi', 'Shuang-ch''i,Shuang-ch’i,Shuang-hsi,Shuangxi,Shuangxi Zhen,shuang xi,shuang xi zhen,双溪,双溪镇', 28.5937600, 119.8729100, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15308, 'Shuangxi', 'Shuangxi', 'Shuang-hsi,Shuangxi', 27.2283300, 109.8558300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15309, 'Shuangxi', 'Shuangxi', 'Ch''iu-p''ing-nan,Ch’iu-p’ing-nan,P''ing-nam,P’ing-nam,Shuang-hsi,Shuangxi,Shuangxi Zhen,shuang xi,shuang xi zhen,双溪,双溪镇', 27.0224800, 119.0414000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15310, 'Shuangwang', 'Shuangwang', 'Shuangwang,Shuangwang Xiang,shuang wang,双王', 34.5264900, 109.4897700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15311, 'Shuangtang', 'Shuangtang', 'Hsi-shuang-t''ang,Hsi-shuang-t’ang,Shuangtang,Shuangtang Zhen,shuang tang,shuang tang zhen,双塘,双塘镇', 38.8709400, 116.9042100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15312, 'Shuangtang', 'Shuangtang', 'Shuangtang,Shuangtang Zhen,shuang tang,shuang tang zhen,双塘,双塘镇', 28.0359600, 116.7321600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15313, 'Shuangshui', 'Shuangshui', 'Shuangshui,Shuangshui Zhen,shuang shui,shuang shui zhen,双水,双水镇', 22.4350100, 112.9944500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15314, 'Shuangshu', 'Shuangshu', '', 39.5638900, 117.0244400, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15315, 'Shuangshi', 'Shuangshi', 'Shuang-shih-ch''iao,Shuang-shih-ch’iao,Shuangshi,Shuangshi Zhen,Shuangshiqiao,shuang shi,shuang shi zhen,双石,双石镇', 29.4003100, 105.8378100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15316, 'Shuangshipu', 'Shuangshipu', 'Feng,Feng-hsien,Fengxian,Shuang-shi-chen,Shuang-shih-chen,Shuang-shih-p''u,Shuang-shih-p’u,Shuangshipu,Shuangshipu Zhen,Shwangshih-chen,feng xian,shuang shi pu,shuang shi pu zhen,凤县,双石铺,双石铺镇', 33.9170500, 106.5246600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15317, 'Shuangqiaoping', 'Shuangqiaoping', 'Shuangqiaoping,Shuangqiaoping Zhen,shuang qiao ping,shuang qiao ping zhen,双桥坪,双桥坪镇', 29.2662000, 111.7728300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15318, 'Longbo', 'Longbo', 'Longbo,Longbozhen,Shuangpai,long po,泷泊', 25.9292200, 111.6222000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15319, 'Shuangnian', 'Shuangnian', 'Shuang-nien,Shuang-nien-ts''un,Shuang-nien-ts’un,Shuangnian,Shuangnian Xiang,shuang nian,shuang nian xiang,双碾,双碾乡', 39.6354700, 112.1007400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15320, 'Shuangmiao', 'Shuangmiao', 'Shuang-miao-chieh,Shuangmiao,shuang miao,双庙', 33.9075000, 113.6342400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15321, 'Shuanglu', 'Shuanglu', 'Shuanglu,Shuanglu Zhen,Shuanglukou,shuang lu,shuang lu zhen,双路,双路镇', 29.8642900, 107.7748300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15322, 'Shuanglong', 'Shuanglong', 'Shuang-lung,Shuanglong,Shuanglong Zhen,shuang long,shuang long zhen,双龙,双龙镇', 29.9597200, 107.2035600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15323, 'Dongsheng', 'Dongsheng', 'Dongsheng,Shuang-liu-ch''eng-kuan-chen,Shuang-liu-ch’eng-kuan-chen,Shuang-liu-hsien,Shuangliu,Shuanlyu,Shwangliu,Shwangliu-hsien,dong sheng,东升', 30.5738300, 103.9212700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15324, 'Shuangliu', 'Shuangliu', 'Shuangliu,Shuangliu Jiedao,shuang liu,shuang liu jie dao,双柳,双柳街道', 30.5922000, 114.6417900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15325, 'Shuanglin', 'Shuanglin', 'Shuang-lin-chen,Shuanglin,Shuanglin Zhen,Songlin,shuang lin,shuang lin zhen,双林,双林镇', 30.7811700, 120.3144000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15326, 'Shuanglin', 'Shuanglin', 'Shuanglin,Shuanglin Zhen,shuang lin,shuang lin zhen,双林,双林镇', 27.9399600, 114.7553300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15327, 'Shuangkou', 'Shuangkou', 'Shuang-k''ou-chen,Shuang-k’ou-chen,Shuangkou,Shuangkou Zhen,shuang kou,shuang kou zhen,双口,双口镇', 39.2389400, 117.0257600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15328, 'Shuangjie', 'Shuangjie', 'Shuang-chieh,Shuangjie,Shuangjie Zhen,shuang jie,shuang jie zhen,双捷,双捷镇', 21.9437600, 111.7814600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15329, 'Shuangjiao', 'Shuangjiao', 'Shuang-chiao,Shuang-chiao-hsu,Shuang-chiao-hsü,Shuangjiao,Shuangjiao Zhen,shuang jiao,shuang jiao zhen,双滘,双窖镇', 22.0987400, 111.3590800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15330, 'Shuangjiang', 'Shuangjiang', 'Shuang-chiang,Shuang-chiang-chen,Shuangjiang,Shuangjiang Jiedao,Yunyang Xian,shuang jiang,shuang jiang jie dao,yun yang xian,云阳县,双江,双江街道', 30.9424000, 108.6812900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15331, 'Shuangjiang', 'Shuangjiang', 'Shuang-chiang,Shuang-chiang-chen,Shuangjiang,Shuangjiang Zhen,Shuantszyanchzhen'',Shuantszyanchzhen’,Xiangjiaba,shuang jiang,shuang jiang zhen,xiang jia ba,双江,双江镇,向家坝', 30.2175400, 105.7452000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15332, 'Shuangjiang', 'Shuangjiang', 'Shuang-chiang,Shuang-chiang-k''ou,Shuang-chiang-k’ou,Shuangjiang,T''ung-tao,T''ung-tao-t''ung-tsu-tzu-chih-hsien,Tongdao,T’ung-tao,T’ung-tao-t’ung-tsu-tzu-chih-hsien,shuang jiang,双江', 26.1546700, 109.7138000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15333, 'Shuangjiang', 'Shuangjiang', 'Eshan,Eshan Yizu Zizhixian,Hsi-o,Ngeshan-hsien,O-shan,O-shan-hsien,O-shan-hsien-i-tsu-tzu-chih-ch''u,O-shan-hsien-i-tsu-tzu-chih-ch’ü,O-shan-i-tsu-tzu-chih-hsien,Shuangjiang,Shuangjiang Zhen,Sihohsien,e shan yi zu zi zhi xian,shuang jiang,shuang jiang zhen,双江,双江镇,峨山彝族自治县', 24.1726100, 102.4004900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15334, 'Shuanghe', 'Shuanghe', 'Shuang-ho-ch''ang,Shuang-ho-ch’ang,Shuanghe,Shuanghe Zhen,Shuanghechang,shuang he,shuang he zhen,双河,双河镇', 29.3207400, 105.5694200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15335, 'Shuanghe', 'Shuanghe', 'Shuang-ho,Shuanghe,Shuanghe Xiang,shuang he,shuang he xiang,双河,双河乡', 31.6744000, 112.8148600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15336, 'Shuanghe', 'Shuanghe', 'Shuang-ho,Shuang-ho-k''ou,Shuang-ho-k’ou,Shuanghe,Shuanghe Zhen,shuang he,shuang he zhen,双河,双河镇', 31.2807900, 112.2705700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15337, 'Shuanghekou', 'Shuanghekou', 'Shuang-ho,Shuanghe,Shuanghekou,Shuanghekou Zhen,shuang he kou,shuang he kou zhen,双河口,双河口镇', 29.6186100, 106.9183300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15338, 'Shuanghe', 'Shuanghe', 'Lanbazi,Shuanghe,Shuanghe Xiang,lan ba zi,shuang he,shuang he xiang,双河,双河乡,烂坝子', 29.5493200, 107.7184100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15339, 'Shuanggou', 'Shuanggou', 'Shuang-kou,Shuang-kou-chen,Shuanggou,Shuanggou Zhen,Shwangkow,shuang gou,shuang gou zhen,双沟,双沟镇', 32.1895700, 112.3805300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15340, 'Shuanggang', 'Shuanggang', 'Shuang-lin,Shuanggang,Shuanggang Zhen,Shuangjiang,shuang gang,shuang gang zhen,双港,双港镇', 39.0439500, 117.3101400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15341, 'Shuanggang', 'Shuanggang', 'Shuang-chiang,Shuang-kang,Shuanggang,Shuanggang Zhen,shuang gang,shuang gang zhen,双港,双港镇', 34.2666700, 119.6666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15342, 'Shuangfeng', 'Shuangfeng', 'Shuang-feng-chen,Shuangfeng,Shuangfeng Zhen,shuang feng,shuang feng zhen,双凤,双凤镇', 31.5166300, 121.0252400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15343, 'Shuangdian', 'Shuangdian', 'Shuang-tien,Shuang-tien-chen,Shuangdian,Shuangdian Zhen,shuang dian,shuang dian zhen,双甸,双甸镇', 32.3518400, 120.8203100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15344, 'Shuangcheng', 'Shuangcheng', 'Che-jung,Che-jung-hsien,Che-jung-hsien-ch''eng,Che-jung-hsien-ch’eng,Che-yang,Shuangcheng,Shuangcheng Zhen,Zherong,Zherong Xian,shuang cheng,shuang cheng zhen,zhe rong,zhe rong xian,双城,双城镇,柘荣,柘荣县', 27.2400000, 119.8944400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15345, 'Shuangbaiyang', 'Shuangbaiyang', 'Shuang-pai-yang,Shuangbaiyang,shuang bai yang,双白杨', 34.5740800, 107.0307300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15346, 'Shouzhan', 'Shouzhan', 'Shou-chan,Shouzhan,Shouzhan Zhen,shou zhan,shou zhan zhen,首占,首占镇', 25.9382100, 119.4797300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15347, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Zhen,Shaoyang,Shou-yang-hsien,Shouyang,Shouyang Xian,Showyang,chao yang,chao yang zhen,shou yang xian,寿阳县,朝阳,朝阳镇', 37.9080100, 113.1504400, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15348, 'Shouchun', 'Shouchun', 'Shou,Shou-hsien,Shouchun,Shouxian,Shouyang,Showchow,Showhsien,Shuo-hsien,shou chun,寿春', 32.5816200, 116.7929100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15349, 'Shoushan', 'Shoushan', '', 26.9644400, 119.1616700, 'CN', '2001-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15350, 'Shoushan', 'Shoushan', 'Shoushan,Shoushan Xiang,shou shan,shou shan xiang,寿山,寿山乡', 26.2438200, 119.2363600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15351, 'Shouguang', 'Shouguang', 'Chiu-shou-kuang,Shou-kuang,Shou-kuang-hsien,Shouguan,Shouguang,Showkwang,Шоугуан', 36.8800000, 118.7375000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15352, 'Shouchang', 'Shouchang', 'Shou-ch''ang-hsien,Shou-ch''ang-hsien-chih,Shou-ch’ang-hsien,Shou-ch’ang-hsien-chih,Shouchang,Shouchang Zhen,Showchang,Showchang-hsien,shou chang,shou chang zhen,寿昌,寿昌镇', 29.3601400, 119.2179600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15353, 'Shizuishan', 'Shizuishan', 'Shih-tsui,Shih-tsui-shan,Shih-tsui-shan-shih,Shih-tsui-tzu,Shitszuyshan'',Shitszuyshan’,Shizuishan', 39.2333300, 106.7694400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15354, 'Shizong', 'Shizong', 'Shih-tsung,Shih-tsung-tien,Shizong,Shizong Zhen,shi zong,shi zong zhen,十总,十总镇', 32.1930300, 121.1216100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15355, 'Shizi', 'Shizi', 'Shih-tzu-p''u,Shih-tzu-p’u,Shizi,Shizi Zhen,Shizipu,shi zi,shi zi zhen,十字,十字镇', 30.9805600, 119.1280600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15356, 'Shizilu', 'Shizilu', 'Chu-nan,Chü-nan,Junan,Shih-tzu-lu,Shizilu', 35.1711100, 118.8288900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15357, 'Shizikou', 'Shizikou', 'Shih-tzu-k''ou,Shih-tzu-k’ou,Shizikou,Shizikou Zhen,shi zi kou,shi zi kou zhen,狮子口,狮子口镇', 29.9872000, 112.0130200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15358, 'Shizhuang', 'Shizhuang', 'Shih-chuang,Shih-chuang-chen,Shizhuang,Shizhuang Zhen,shi zhuang,shi zhuang zhen,石庄,石庄镇', 32.1470200, 120.5174700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15359, 'Shizhuang', 'Shizhuang', 'Shih-chuang,Shih-chuang-chen,Shizhuang,Shizhuang Zhen,shi zhuang,shi zhuang zhen,石庄,石庄镇', 31.9184300, 120.0246000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15360, 'Shizhu', 'Shizhu', 'Shih-chu,Shih-chu-chieh,Shizhu,Shizhu Zhen,shi zhu,shi zhu zhen,石柱,石柱镇', 28.8456700, 120.0959600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15361, 'Shizhen', 'Shizhen', 'Shih-chen,Shih-chen-chieh,Shizhen,Shizhen Zhen,Shizhenjie,shi zhen,shi zhen zhen,石镇,石镇镇', 28.8542500, 116.9662200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15362, 'Shizheng', 'Shizheng', 'Shih-cheng,Shih-cheng-hsu,Shih-cheng-hsü,Shizheng,Shizheng Zhen,shi zheng,shi zheng zhen,石正,石正镇', 24.5153700, 115.8267700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15363, 'Shiyun', 'Shiyun', 'Shiyun,Shiyun Xiang,shen yun,shen yun xiang,什运,什运乡', 18.9948200, 109.6008000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15364, 'Shiye', 'Shiye', 'Shi-yasi,Shih-yeh,Shih-yeh-ssu,Shiye,Shiye Zhen,shi ye,shi ye zhen,石耶,石耶镇', 28.3816800, 109.0574700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15365, 'Shiyang', 'Shiyang', 'Shih-yang,Shiyang,Shiyang Zhen,shi yang,shi yang zhen,仕阳,仕阳镇', 27.3684500, 119.8966800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15366, 'Shiyan', 'Shiyan', 'Shih-tien,Shih-yen,Shih-yen-chen,Shiyan,Shiyan Zhen,shi yan,shi yan zhen,时堰,时堰镇', 32.7225500, 120.1832200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15367, 'Shiyan', 'Shiyan', 'Chap-ian-chhi,Cha̍p-ián-chhī,S-jen,Sek-ieng,Shih-yen,Shih-yen-chen,Shih-yen-shih,Shijan'',Shijen,Shiyan,Shiyan Shi,Shujen,Sĕk-iēng,Thap Yen,Thập Yển,WDS,seuyen si,shi yan,shi yan shi,shyyan,Š-jen,Шиянь,Шијен,Шъйен,شییان,十堰,十堰市,스옌 시', 32.6475000, 110.7780600, 'CN', '2016-03-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15368, 'Shiyan', 'Shiyan', 'Shih-yen,Shijan,Shiyan,Шиян', 32.5666700, 110.7833300, 'CN', '2011-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15369, 'Shijiang', 'Shijiang', 'Shih-hsia-chiang,Shijiang,Shixiajiang,Yu-hsia-chiang', 27.0819400, 110.7933300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15370, 'Shixia', 'Shixia', 'Shih-hsia,Shixia,shi xia,石峡', 33.7834000, 105.3876900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15371, 'Shixia', 'Shixia', 'Shih-hsia,Shixia,Shixia Xiang,shi xia,shi xia xiang,石峡,石峡乡', 27.6731200, 116.9021200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15372, 'Shixi', 'Shixi', 'Shixi,Shixi Zhen,Shixikou,shi xi,shi xi kou,shi xi zhen,狮溪,狮溪口,狮溪镇', 28.8391400, 107.1175400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15373, 'Shixi', 'Shixi', 'Shixi,Shixi Xiang,shi xi,shi xi xiang,石溪,石溪乡', 28.1954200, 120.2432400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15374, 'Dashiwo', 'Dashiwo', 'Dashiwo,Dashiwo Zhen,da shi wo,da shi wo zhen,大石窝,大石窝镇', 39.5542300, 115.8136900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15375, 'Shiwan', 'Shiwan', 'Shih-wan,Shiwan,Shiwan Jiedao,shi wan,shi wan jie dao,石湾,石湾街道', 23.0010700, 113.0770000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15376, 'Shituo', 'Shituo', 'Shituo,Shituo Zhen,shi tuo,shi tuo zhen,石沱,石沱镇', 29.7161300, 107.1356400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15377, 'Shitouzui', 'Shitouzui', 'Shih-t''ou-tsui,Shih-t’ou-tsui,Shitouzui,Shitouzui Zhen,shi tou ju,shi tou ju zhen,石头咀,石头咀镇', 30.9929700, 115.7525600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15378, 'Shitanjing', 'Shitanjing', 'Shih-t''an-ching,Shih-t’an-ching,Shitanjing', 39.2341700, 106.3438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15379, 'Shitang', 'Shitang', 'Shih-t''ang,Shih-t’ang,Shitang,Shitang Zhen,shi tang,shi tang zhen,石塘,石塘镇', 28.1142000, 117.8449300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15380, 'Shitan', 'Shitan', 'Shih-t''an,Shih-t’an,Shitan,Shitan Zhen,shi tan,shi tan zhen,石潭,石潭镇', 34.5748500, 108.3574400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15381, 'Shitan', 'Shitan', 'Shih-t''an,Shih-t''an-chieh,Shih-t’an,Shih-t’an-chieh,Shitan,Shitan Zhen,shi tan,shi tan zhen,石滩,石滩镇', 28.1299100, 115.8380500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15382, 'Shitan', 'Shitan', 'Shih-t''an,Shih-t’an,Shitan,Shitan Zhen,shi tan,shi tan zhen,石潭,石潭镇', 24.1286100, 112.7637700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15383, 'Shitan', 'Shitan', 'Shitan,Shitan Zhen,shi tan,shi tan zhen,石滩,石滩镇', 23.1752800, 113.7858300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15384, 'Qili', 'Qili', 'Ch''i-li,Ch’i-li,Qili,Shih-t''ai,Shih-t’ai,Shitai,Shitai Xian,qi li,shi tai xian,七里,石台县', 30.1990600, 117.4779900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15385, 'Shishi', 'Shishi', 'Shih-shih,Shishi,shi shi,石狮', 24.7403800, 118.6290600, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15386, 'Shishan', 'Shishan', 'Shishan,Shishan Xiang,shi shan,shi shan xiang,市山,市山乡', 27.2122000, 116.4961800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15387, 'Shiqiu', 'Shiqiu', 'Shiqiu,Shiqiu Zhen,shi jiao,shi jiao zhen,石湫,石湫镇', 31.6493200, 118.9087400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15388, 'Shiqiao', 'Shiqiao', 'Shih-ch''iao,Shih-ch’iao,Shiqiao,shi qiao,石桥', 34.7586100, 108.6594400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15389, 'Shiqiao', 'Shiqiao', 'Shih-ch''iao,Shih-ch’iao,Shiqiao,Shiqiao Xiang,shi qiao,shi qiao xiang,石桥,石桥乡', 33.9250300, 113.8981300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15390, 'Shiqiao', 'Shiqiao', 'Shih-ch''iao,Shih-ch''iao-tzu,Shih-ch’iao,Shih-ch’iao-tzu,Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 32.3517300, 111.9750300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15391, 'Shiqiao', 'Shiqiao', 'Shih-ch''iao,Shih-ch’iao,Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 31.9379100, 118.4164200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15392, 'Shiqiaoyi', 'Shiqiaoyi', 'Shih-ch''iao,Shih-ch’iao,Shiqiao,Shiqiaoyi,Shiqiaoyi Xiang,shi qiao yi,shi qiao yi xiang,石桥驿,石桥驿乡', 31.2581300, 112.2184200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15393, 'Shiqiao', 'Shiqiao', 'P''an-yu-hsien,Panyu,P’an-yu-hsien,Shekkiu,Shih-ch''iao,Shih-ch''iao-chen,Shih-ch’iao,Shih-ch’iao-chen,Shikiu,Shiqiao,Shiqiao Jiedao,fan yu,shi qiao,shi qiao jie dao,市桥,市桥街道,番禺', 22.9464000, 113.3576900, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15394, 'Shiqian', 'Shiqian', 'Shih-ch''ien,Shih-ch''ien-hsien,Shih-ch’ien,Shih-ch’ien-hsien,Shihtsien,Shihtsien-hsien,Shiqian', 27.5225000, 108.2280600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15395, 'Shiqi', 'Shiqi', 'Chung-shan,Chung-shan-ku-chih,Heungschan,Heungshan,Hsiang-shan,Shekki,Shih-ch''i,Shih-ch''i-chen,Shih-ch’i,Shih-ch’i-chen,Shiqi,Shiqi Jiedao,Shiqizhen,Zhongshan,shi qi,shi qi jie dao,石岐,石岐街道', 22.5168200, 113.3852100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15396, 'Yilong', 'Yilong', 'Shih-p''ing,Shih-p''ing-hsien,Shih-p’ing,Shih-p’ing-hsien,Shihpingchow,Shiping,Yilong,yi long,异龙', 23.6913700, 102.4870100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15397, 'Shipai', 'Shipai', 'Shih-p''ai,Shih-p''ai-chen,Shih-p’ai,Shih-p’ai-chen,Shihpaitsen,Shipai,Shipai Zhen,shi pai,shi pai zhen,石牌,石牌镇', 30.9863900, 112.5008700, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15398, 'Shipaidong', 'Shipaidong', 'Shipai,Shipai Zhen,Shipaidong,shi pai dong,shi pai zhen,石牌洞,石牌镇', 29.5727100, 109.5868900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15399, 'Shipai', 'Shipai', 'Shih-p''ai,Shih-p’ai,Shipai,Shipai Zhen,shi pai,shi pai zhen,石牌,石牌镇', 25.6544400, 117.8302800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15400, 'Shiniujiang', 'Shiniujiang', 'Shiniujiang,Shiniujiang Zhen,shi niu jiang,shi niu jiang zhen,石牛江,石牛江镇', 28.4333300, 112.1588900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15401, 'Shinao', 'Shinao', 'Shih-nao,Shih-nao-hsu,Shih-nao-hsü,Shinao,Shinao Zhen,shi nao,shi nao zhen,石脑,石脑镇', 28.3908500, 115.2905900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15402, 'Shinan', 'Shinan', 'Shinan,Shinan Zhen,shi nan,shi nan zhen,石南,石南镇', 29.2792700, 113.7129600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15403, 'Shinan', 'Shinan', 'Shih-nan,Shinan,Shinan Zhen,shi nan,shi nan zhen,石南,石南镇', 22.7439000, 109.8742800, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15404, 'Shimenqiao', 'Shimenqiao', 'Shih-men-ch''iao,Shih-men-ch’iao,Shimenqiao,Shimenqiao Zhen,shi men qiao,shi men qiao zhen,石门桥,石门桥镇', 28.9052100, 111.7360600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15405, 'Shimenlou', 'Shimenlou', 'Shih-men-lou,Shimenlou,Shimenlou Zhen,shi men lou,shi men lou zhen,石门楼,石门楼镇', 28.9705000, 114.8541100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15406, 'Shimenjie', 'Shimenjie', 'Shih-men,Shih-men-chieh,Shihmenkai,Shimenjie,Shimenjie Zhen,shi men jie,shi men jie zhen,石门街,石门街镇', 29.5774700, 116.7670600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15407, 'Shimen', 'Shimen', 'Shih-men,Shih-men-ts''un,Shih-men-ts’un,Shimen,Shimen Xiang,shi men,shi men xiang,石门,石门乡', 35.2561100, 111.5422200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15408, 'Shimen', 'Shimen', 'Shimen,Shimen Xiang,shi men,shi men xiang,石门,石门乡', 33.2885500, 112.4845400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15409, 'Shimen', 'Shimen', 'Shih-men,Shih-men-wan,Shih-men-wan-chen,Shih-wan-chen,Shimen,Shimen Zhen,shi men,shi men zhen,石门,石门镇', 30.6274700, 120.4424900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15410, 'Shimen', 'Shimen', 'Shih-men,Shih-men-k''eng,Shih-men-k’eng,Shimen,Shimen Xiang,shi men,shi men xiang,石门,石门乡', 29.6297400, 118.4318800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15411, 'Chujiang', 'Chujiang', 'Chujiang,Chujiang Zhen,Shih-men,Shih-men-hsien,Shimen,Shimen Xian,chu jiang,chu jiang zhen,shi men,shi men xian,楚江,楚江镇,石门,石门县', 29.5771000, 111.3630000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15412, 'Shimen', 'Shimen', 'Shih-men,Shimen,Shimen Zhen,Shimenchang,shi men,shi men zhen,石门,石门镇', 29.1003700, 106.0330400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15413, 'Shimen', 'Shimen', 'Shih-men,Shimen,Shimen Xiang,shi men,shi men xiang,石门,石门乡', 27.7793600, 116.6588900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15414, 'Shima', 'Shima', 'Mapaochang,Shih-ma,Shima,Shima Zhen,ma pao chang,shi ma,shi ma zhen,石马,石马镇,马跑场', 29.6311600, 105.8306500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15415, 'Shima', 'Shima', 'Shih-ma,Shih-ma-hsu,Shih-ma-hsü,Shima,Shima Zhen,shi ma,shi ma zhen,石马,石马镇', 26.9959400, 115.7425500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15416, 'Shima', 'Shima', 'Longhai,Lung-hai,Shih-ma,Shih-ma-chen,Shima,shi ma,Шима,石码', 24.4464700, 117.8121600, 'CN', '2014-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15417, 'Shima', 'Shima', 'Shih-ma,Shima,Shima Zhen,shi ma,shi ma zhen,石马,石马镇', 24.2862700, 115.8257800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15418, 'Lingquan', 'Lingquan', 'Lingquan,Lingquan Zhen,Shih-lou,Shih-lou-hsien,Shihlowhsien,Shilou,Shilou Xian,ling quan,ling quan zhen,shi lou xian,灵泉,灵泉镇,石楼县', 36.9994900, 110.8440000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15419, 'Shilou', 'Shilou', 'Shih-lou,Shilou,Shilou Zhen,shi lou,shi lou zhen,石楼,石楼镇', 22.9734100, 113.4871800, 'CN', '2015-10-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15420, 'Shilong', 'Shilong', 'Shilong,Shilong Zhen,shi long,shi long zhen,石龙,石龙镇', 30.8954100, 112.8421700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15421, 'Xianglong', 'Xianglong', 'Shih-lung,Xianglong,Xianglong Zhen,xiang long,xiang long zhen,香龙,香龙镇', 30.2612500, 106.5758800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15422, 'Shilong', 'Shilong', 'Shehlung,Sheklung,Shih-lung,Shilong,Shilong Zhen,shi long,shi long zhen,石龙,石龙镇', 23.1144400, 113.8472200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15423, 'Shiliyuan', 'Shiliyuan', 'Shih-li-yuan,Shih-li-yüan,Shiliping,Shiliyuan,shi li yuan,十里塬', 34.8969400, 108.4750000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15424, 'Shilu', 'Shilu', 'Ch''ang-chiang,Changjiang,Changjiang Lizu Zizhi Xian,Ch’ang-chiang,Shih-liu,Shih-lu,Shih-lu-chen,Shih-lu-ling,Shiliu,Shilu,Shilu Zhen,chang jiang li zu zi zhi xian,shi lu,shi lu zhen,昌江黎族自治县,石碌,石碌镇', 19.2598400, 109.0488400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15425, 'Tongchuanshi', 'Tongchuanshi', 'Deng-chiong,Dè̤ng-chiŏng,GJong Xuyen,Shih-li-p''u,Shih-li-p’u,Shilipu,T''ung-ch''uan,T''ung-ch''uan-shih,Tang-chhoan-chhi,Tchung-cchuan,Tchung-čchuan,Tongchuan,Tongchuanshi,Tunchuan'',Tungchuan,Tâng-chhoan-chhī,T’ung-ch’uan,T’ung-ch’uan-shih,tong chuan,tong chuan shi,tungchwan si,twngchwan,Đồng Xuyên,Тунгчуан,Тунчуань,تونگچوان,銅川,銅川市,铜川市,퉁촨 시', 35.0747400, 109.0849500, 'CN', '2016-12-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15426, 'Shilipu', 'Shilipu', 'Shih-li-p''u,Shih-li-p’u,Shilipu,Shilipu Zhen,shi li pu,shi li pu zhen,十里铺,十里铺镇', 30.6092900, 112.1806600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15427, 'Shiling', 'Shiling', 'Shiling,Shiling Zhen,shi ling,shi ling zhen,石岭,石岭镇', 21.6509500, 110.1271000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15428, 'Shiliang', 'Shiliang', 'Shih-liang,Shih-liang-chi,Shiliang,Shiliang Zhen,shi liang,shi liang zhen,石良,石良镇', 37.5774700, 120.6613600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15429, 'Shiliang', 'Shiliang', 'Shih-liang,Shih-liang-chen,Shih-liang-chi,Shiliang,Shiliang Zhen,shi liang,shi liang zhen,石梁,石梁镇', 32.6918000, 118.8733400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15430, 'Shiliang', 'Shiliang', 'Shih-liang,Shih-liang-shih,Shiliang,Shiliang Zhen,shi liang,shi liang zhen,石梁,石梁镇', 29.0203000, 118.7828900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15431, 'Shilaorencun', 'Shilaorencun', 'Shilaoren,Shilaorencun,shi lao ren,shi lao ren cun,石老人,石老人村', 36.0972300, 120.4891000, 'CN', '2016-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15432, 'Shikou', 'Shikou', 'Shih-k''ou,Shih-k’ou,Shikou,Shikou Zhen,shi kou,shi kou zhen,石口,石口镇', 28.8290900, 116.6251100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15433, 'Shijing', 'Shijing', 'Shih-ching,Shihtsing,Shijing,shi jing,石井', 24.6195600, 118.4243700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15434, 'Shijing', 'Shijing', 'Shijing,Shijing Zhen,shi jing,shi jing zhen,石颈,石颈镇', 21.6985100, 110.0233000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15435, 'Shijie', 'Shijie', 'Shih-chieh-tu,Shijie,Shijie Zhen,Shijiedu,shi jie,shi jie zhen,誓节,誓节镇', 30.9425700, 119.2199700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15436, 'Shijiazhuang', 'Shijiazhuang', 'Shiczjachzhuan,Shih-chia-chuang,Shijiazhuang,Shijiazhuang Zhen,shi jia zhuang,shi jia zhuang zhen,Шицзячжуан,石家庄,石家庄镇', 38.5753500, 112.0159300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15437, 'Shijiazhuang', 'Shijiazhuang', 'Chen-t''ou,Chen-t’ou,Chentow,Chioh-ka-chng-chhi,Chio̍h-ka-chng-chhī,S''-tia-cuang,SJW,Shiczjachzhuan,Shih-chia-chuang,Shih-chia-chuang-shih,Shih-chuang-shih,Shih-men,Shih-men-shih,Shihjiazhuang,Shihkiachwan,Shihkiachwang,Shijiazhuang,Shijiazhuang Shi,Shitszyachzhuan,Shizhjazhuan,Shudzjadzhuan,Sicsiacsuang,Sidziadzuangas,Sidzjadzuana,Sigjaguango,Sioh-ga-cong,Sitziazouank,Siŏh-gă-cŏng,Swzgyahcuengh,Thach Gia Trang,Thạch Gia Trang,chux ceiy cwng,sa-cyacvanga,seujajwang si,sh-gyʼgwwʼng,shi jia zhuang,shi jia zhuang shi,shidziajuani,shyjyatshwangh,shyjyazhwang,sijiyajhu''anga,sizi''azu''anga,Ŝiĝjaĝŭango,Šidziadžuangas,Šidzjadžuana,Š’-ťia-čuang,Σιτζιαζουάγκ,Шижяжуан,Шицзячжуан,Шиђаџуанг,Шъдзяджуан,Շիցզյաչժուան,שה-גיאגוואנג,شىجياجۇاڭ شەھىرى,شيجياتشوانغ,شیجیاژوانگ,शिजियाझुआंग,ष-च्याच्वांग,ਸ਼ੀਜ਼ੀਆਜ਼ੂਆਂਗ,ฉือเจียจวง,შიძიაჯუანი,石家庄,石家庄市,石家荘,石家荘市,石家莊,石家莊市,스자좡 시', 38.0413900, 114.4786100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15438, 'Shijiazhai', 'Shijiazhai', 'Shih-chia-chai,Shijiazhai,Shijiazhai Xiang,shi jia zhai,shi jia zhai xiang,史家寨,史家寨乡', 38.9244000, 114.2661400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15439, 'Shijiaying', 'Shijiaying', 'Shijiaying,Shijiaying Xiang,shi jia ying,shi jia ying xiang,史家营,史家营乡', 39.8566300, 115.6636400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15440, 'Shiqiao', 'Shiqiao', 'Shih-chia-ch''iao,Shih-chia-ch''iao-chen,Shih-chia-ch’iao,Shih-chia-ch’iao-chen,Shijiaqiao,Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,施桥,施桥镇', 32.3125500, 119.4558100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15441, 'Shijiaochang', 'Shijiaochang', 'Shih-chiao,Shijiao,Shijiaochang', 28.9244400, 106.7561100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15442, 'Shijiao', 'Shijiao', 'Fakang,Fatkong,Fatkong-hsien,Fatkongting,Fo-kang,Fo-kang-hsien,Fogang,Fukang,Shih-chiao,Shih-chiao-chen,Shih-chueh,Shijiao,Shijiao Zhen,shi jiao,shi jiao zhen,石角,石角镇', 23.8694900, 113.5284000, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15443, 'Shijiao', 'Shijiao', 'Shih-chiao,Shih-chiao-hsu,Shih-chiao-hsü,Shijiao,Shijiao Zhen,shi jiao,shi jiao zhen,石角,石角镇', 23.5519600, 112.9699400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15444, 'Shijiang', 'Shijiang', 'Shijiang,Shijiang Xiang,shi jiang,shi jiang xiang,石江,石江乡', 27.8216200, 115.7241000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15445, 'Shijian', 'Shijian', 'Shekkan,Shih-chien,Shih-chien-hsu,Shih-chien-hsü,Shijian,Shijian Zhen,shi jian,shi jian zhen,石涧,石涧镇', 23.5172800, 112.4588200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15446, 'Shijia', 'Shijia', 'Shih-chia,Shih-chia-chen,Shijia,Shijia Zhen,shi jia,施家', 34.8177100, 109.3832100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15447, 'Shijia', 'Shijia', 'Shih-chia-pa,Shijia,Shijia Xiang,shi jia,shi jia xiang,石家,石家乡', 30.2865300, 108.3251600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15448, 'Shijia', 'Shijia', 'Shijia,Shijia Zhen,Shijiahe,shi jia,shi jia zhen,石家,石家镇', 29.2367700, 108.6116500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15449, 'Shihuiqiao', 'Shihuiqiao', 'Shih-hui-ch''iao,Shih-hui-ch’iao,Shihuiqiao,Shihuiqiao Zhen,shi hui qiao,shi hui qiao zhen,拾回桥,拾回桥镇', 30.5531900, 112.2723300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15450, 'Shihuipu', 'Shihuipu', 'Shihuipu,Shihuipu Zhen,shi hui pu,shi hui pu zhen,石灰铺,石灰铺镇', 24.2664400, 113.2307100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15451, 'Shihui', 'Shihui', 'Shih-hui,Shihui,Shihui Zhen,shi hui,shi hui zhen,石会,石会镇', 29.5717700, 108.6101700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15452, 'Shihudang', 'Shihudang', 'Shih-hu-tang,Shihudang,shi hu dang,石湖荡', 30.9851600, 121.1144600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15453, 'Shihuang', 'Shihuang', 'Shih-huang,Shih-huang-shih,Shihuang,Shihuang Zhen,shi huang,shi huang zhen,石璜,石璜镇', 29.5393400, 120.6523600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15454, 'Shihe', 'Shihe', 'Shih-chia-ho,Shih-ho,Shihe,Shihe Zhen,shi he,shi he zhen,石河,石河镇', 30.7581500, 113.0806500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15455, 'Shigutang', 'Shigutang', 'Shigutang,Shigutang Zhen,Shih-ku-hsu,Shih-ku-hsü,Shih-ku-t''ang,Shih-ku-t’ang,shi gu tang,shi gu tang zhen,石牯塘,石牯塘镇', 24.3616000, 113.1461300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15456, 'Shigui', 'Shigui', 'Shigui,Shigui Zhen,Shih-kuei,Shih-kuei-chen,Shih-p''ao-chen,Shih-p’ao-chen,Shin-kuei-chen,shi wei,shi wei zhen,石硊,石硊镇', 31.1881800, 118.3647100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15457, 'Shiguan', 'Shiguan', 'Shiguan,Shiguan Zhen,Shiguanji,Shih-kuan,Shih-kuan-chi,shi guan,shi guan zhen,施官,施官镇', 32.4599400, 118.5738100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15458, 'Shigu', 'Shigu', 'Shigu,Shigu Zhen,Shih-ku,shi gu,shi gu zhen,石鼓,石鼓镇', 21.8250000, 110.7647100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15459, 'Shigou', 'Shigou', 'Shigou,Shih-kou,Ssu-kou,shi gou,柿沟', 34.6965600, 107.0537100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15460, 'Shigou', 'Shigou', 'Shekkow,Shigou,Shigou Zhen,Shih-kou,Shih-kou-hsu,Shih-kou-hsü,shi gou,shi gou zhen,石狗,石狗镇', 23.3703700, 112.5719100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15461, 'Shigongqiao', 'Shigongqiao', 'Shigongqiao,Shigongqiao Zhen,Shih-kong-chow,Shihkungkiao,shi gong qiao,shi gong qiao zhen,石公桥,石公桥镇', 29.1833300, 111.8666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15462, 'Shigezhuang', 'Shigezhuang', 'Shigezhuang,Shigezhuang Zhen,Shih-ko-chuang,Shih-ko-chuang-chen,shi ge zhuang,shi ge zhuang zhen,石各庄,石各庄镇', 39.2966700, 116.8913900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15463, 'Shigang', 'Shigang', 'Shigang,Shigang Zhen,Shih-chiang,Shih-chiang-chen,Shih-kang,Shih-kang-chen,Shihkiang,shi gang,shi gang zhen,石港,石港镇', 32.2186800, 120.9748700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15464, 'Shigang', 'Shigang', 'Shigang,Shigang Zhen,shi gang,shi gang zhen,石岗,石岗镇', 28.4431100, 115.6253400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15465, 'Shifosi', 'Shifosi', 'Hsin-min-shih,Shifosi,Shifosi Zhen,Shih-fo-ssu,shi fu si,shi fu si zhen,石佛寺,石佛寺镇', 33.0791200, 112.1556000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15466, 'Shifosi', 'Shifosi', 'Shifosi,Shifosi Zhen,shi fu si,shi fu si zhen,石佛寺,石佛寺镇', 29.9520500, 115.6244400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15467, 'Shifang', 'Shifang', 'Shifang,shi fang,石坊', 33.0027500, 104.5714500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15468, 'Shifang', 'Shifang', 'Shifang,Shifang Zhen,Shih-fang,shi fang,shi fang zhen,十方,十方镇', 25.0349000, 116.2239200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15469, 'Shidu', 'Shidu', 'Shidu,Shidu Zhen,Shih-tu,Shih-tu-ts''un,Shih-tu-ts’un,shi du,shi du zhen,十渡,十渡镇', 39.6422800, 115.5857100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15470, 'Shidu', 'Shidu', 'Shidu,Shidu Xiang,Shih-tu,shi du,shi du xiang,石渡,石渡乡', 29.2114300, 114.9324700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15471, 'Gaolan Chengguanzhen', 'Gaolan Chengguanzhen', 'Gaolan,Gaolan Chengguanzhen,Gaolan Xian,Kao-lan,Shidongsi,Shih-tung-ssu,gao lan cheng guan zhen,gao lan xian,皋兰县,皋兰城关镇', 36.3346700, 103.9455600, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15472, 'Shidong', 'Shidong', 'Shidong,Shidong Zhen,Shih-tung,shi dong,shi dong zhen,诗洞,诗洞镇', 23.6205600, 112.0672200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15473, 'Shidixi', 'Shidixi', 'Shidi,Shidi Zhen,Shidixi,Shih-t''i-hsi,Shih-t''ien-ch''i,Shih-ti-ch''i,Shih-ti-ch’i,Shih-t’i-hsi,Shih-t’ien-ch’i,shi di,shi di xi,shi di zhen,石堤,石堤西,石堤镇', 29.0428200, 110.1028800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15474, 'Shidi', 'Shidi', 'Shidi,Shidi Zhen,Shih-ti,shi di,shi di zhen,石堤,石堤镇', 28.7526500, 109.1922700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15475, 'Shide', 'Shide', 'Shide,Shide Zhen,Shih-te,Shih-te-chen,Shih-te-ts''un,Shih-te-ts’un,shi de,shi de zhen,史德,史德镇', 34.3911100, 108.4272200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15476, 'Xincheng', 'Xincheng', 'Hsiang-fen,Hsiang-fen-hsien,Shicun,Shih-ts''un,Shih-ts''un-chen,Shih-ts’un,Shih-ts’un-chen,Xiangfen,Xiangfen Xian,Xincheng,Xincheng Zhen,xiang fen xian,xin cheng,xin cheng zhen,新城,新城镇,襄汾县', 35.8750000, 111.4352800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15477, 'Shicong', 'Shicong', 'Shicong,Shicong Zhen,shi cong,shi cong zhen,石淙,石淙镇', 30.7229800, 120.2625900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15478, 'Shichuan', 'Shichuan', 'Shichuan,Shichuan Zhen,Shih-ch''uan,Shih-ch’uan,shi chuan,shi chuan zhen,石船,石船镇', 29.7658400, 106.8228400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15479, 'Shicheng', 'Shicheng', 'Chou-ning,Chou-ning-hsien,Chou-tun,Chou-tun-chen,Chowtun,Shicheng,Shicheng Zhen,Shoutun,Showtan,Zhouning,Zhouning Shi,shi cheng,shi cheng zhen,zhou ning,zhou ning shi,周宁,周宁市,狮城,狮城镇', 27.1067100, 119.3349900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15480, 'Shicao', 'Shicao', 'Shicao,Shih-ts''ao,Shih-ts’ao,shi cao,石槽', 34.7504100, 109.9411400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15481, 'Shicang', 'Shicang', 'Shicang,Shicang Xiang,shi cang,shi cang xiang,石苍,石苍乡', 25.6023800, 118.7518400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15482, 'Shibi', 'Shibi', 'Shibi,Shibi Zhen,Shih-pi,shi bi,shi bi zhen,石鼻,石鼻镇', 28.7299900, 115.5690000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15483, 'Shibi', 'Shibi', 'Shibi,Shibi Zhen,shi bi,shi bi zhen,石壁,石壁镇', 19.1651800, 110.3029000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15484, 'Shibei', 'Shibei', 'Shibei,Shibei Zhen,Shih-p''o-chieh,Shih-pei,Shih-pei-chieh,Shih-p’o-chieh,shi bei,shi bei zhen,石陂,石陂镇', 27.6977600, 118.3600800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15485, 'Shibantan', 'Shibantan', 'Shibantan,Shibantan Zhen,Shih-pan-t''an,Shih-pan-t’an,shi ban tan,shi ban tan zhen,石板滩,石板滩镇', 29.1567000, 111.6340800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15486, 'Shiba', 'Shiba', 'Shiba,Shiba Zhen,Shih-pa,Shih-pa-hsu,Shih-pa-hsü,Shih-po-hsu,Shih-po-hsü,shi ba,shi ba zhen,石坝,石坝镇', 23.5361800, 114.5722900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15487, 'Shezhu', 'Shezhu', 'She-chu,She-chu-chen,Shezhu,Shezhu Zhen,she zhu,she zhu zhen,社渚,社渚镇', 31.3180600, 119.2720300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15488, 'Shexing', 'Shexing', 'She-hsing,Shexing,Shexing Xiang,she xing,she xing xiang,社硎,社硎乡', 25.4926000, 118.6269300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15489, 'Shewopo', 'Shewopo', 'Shewopo,Shewopo Zhen,she wo po,she wo po zhen,蛇窝泊,蛇窝泊镇', 37.1341400, 120.8629100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15490, 'Shewan', 'Shewan', 'Shewan,she wan,赊湾', 32.7340900, 113.2405600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15491, 'Shetan', 'Shetan', 'Shetan,Shetan Zhen,she tan,she tan zhen,社坛,社坛镇', 29.9892400, 107.6152100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15492, 'Sheshiqiao', 'Sheshiqiao', 'She-shih-ch''iao,She-shih-ch’iao,Sheshiqiao,Sheshiqiao Zhen,Yu-shih-ch''iao,Yü-shih-ch’iao,she shi qiao,she shi qiao zhen,佘市桥,佘市桥镇', 29.4430500, 111.5181600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15493, 'Shedian', 'Shedian', 'She-ch''i,She-ch''i-chen,She-ch’i,She-ch’i-chen,Shedian,Shedian Zhen,Shekichen,Sheqi,she dian,赊店', 33.0612800, 112.9425900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15494, 'Shenzhen', 'Shenzhen', 'Shen-ch''uan,Shen-ch''uan-shih,Shen-chen,Shen-ch’üan,Shen-ch’üan-shih,Shenzhen,Shenzhen Zhen,shen zhen,shen zhen zhen,深甽,深甽镇', 29.4159100, 121.3397100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15495, 'Shenzhen', 'Shenzhen', 'Bao''an,Chhum-chun-su,Chhṳ̂m-chun-sṳ,Gorad Shehn''chzhehn'',Pao-an,Pao-an-hsien,SZX,Sen-cen,Sencsen,Sendzenas,Senjeno,Senzen,Sham Chun Hu,Shehn''chzhehn'',Shen''chzhen'',Shen-ch''uan,Shen-ch''uan-chen,Shen-ch''uan-hsu,Shen-ch''üan,Shen-ch''üan-chen,Shen-ch''üan-hsü,Shen-chen,Shen-chun,Shendzen,Shenzhen,Shiem Chun,Shumchun,Shumchün,Shundzhun,Tham Quyen,Thâm Quyến,Tschhimtschun,cenccen,sainazaina,sein cein,senacena,sencena,senjhena,seonjeon si,shen zhen,shen zhen shi,shensen shi,shynzhyn,shynzyn,simcheon,sng''n,Ŝenĵeno,Šen-čen,Šendženas,Šenžen,Горад Шэньчжэнь,Шеньчжень,Шенџен,Шънджън,Шэньчжэнь,שנג''ן,شن‌ژن,شينزين,شینژین,شېنجېن شەھىرى,शेन्झेन,षेंचेन,শেনচেন,ਸ਼ੈਨਜ਼ੈਨ,சென்ச்சென்,షెన్‌జెన్,เซินเจิ้น,深セン市,深圳,深圳市,선전 시,심천', 22.5455400, 114.0683000, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15496, 'Shenzhen', 'Shenzhen', 'Shenzhen,Shenzhen Zhen,shen zhen,shen zhen zhen,深镇,深镇镇', 22.1823000, 111.1179300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15497, 'Yanta', 'Yanta', 'Hsin,Hsin-hsien,Hsin-hsien-ch''eng,Hsin-hsien-ch’eng,Shen-hsien,Shenxian,Sinhsien,Yanta,yan ta,雁塔', 36.2411100, 115.6672200, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15498, 'Shenwan', 'Shenwan', 'Shenwan,Shenwan Zhen,shen wan,shen wan zhen,神湾,神湾镇', 22.2914600, 113.3695100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15499, 'Dongshentou', 'Dongshentou', 'Dongshentou,Shen-t''ou-chen,Shen-t’ou-chen,Shentou Zhen,Tung-shen-t''ou,Tung-shen-t’ou,dong shen tou,shen tou zhen,东神头,神头镇', 39.3868700, 112.5804200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15500, 'Shentangbao', 'Shentangbao', 'Shen-t''ang-pao,Shen-t’ang-pao,Shentangbao,Shentangbao Xiang,shen tang bao,shen tang bao xiang,神堂堡,神堂堡乡', 39.1178000, 113.9233100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15501, 'Shenshan', 'Shenshan', 'Shenshan,Shenshan Zhen,shen shan,shen shan zhen,神山,神山镇', 29.8973500, 114.0256700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15502, 'Shenquan', 'Shenquan', 'Shen-ch''uan,Shen-ch''uan-so-ch''eng,Shen-ch’üan,Shen-ch’üan-so-ch’eng,Shenquan,Shenquan Zhen,Tungao,shen quan,shen quan zhen,神泉,神泉镇', 22.9714200, 116.3156300, 'CN', '2016-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15503, 'Dongcheng', 'Dongcheng', 'Chiu-shen-ch''iu,Chiu-shen-ch’iu,Dongcheng,Shen''tsyu,Shen-ch''iu,Shen-ch''iu-hsien,Shen-ch’iu,Shen-ch’iu-hsien,Shenkiu,Shenkiu-hsien,Shenqiucheng,Shen’tsyu,dong cheng,东城', 33.4123500, 115.0809100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15504, 'Shennan', 'Shennan', 'Shen-nan-chen,Shennan,Shennan Xiang,Shennan''chzhen'',Shennan’chzhen’,shen nan,shen nan xiang,神南,神南乡', 38.9930700, 114.8807000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15505, 'Shenlun', 'Shenlun', 'Shen-chia-lun,Shenlun,Shenlun Zhen,chen lun,chen lun zhen,沈埨,沈埨镇', 32.7902200, 119.9655900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15506, 'Shenlin', 'Shenlin', 'Shenlin,Shenlin Xiang,Shenlinpu,shen lin,shen lin pu,shen lin xiang,神林,神林乡,神林铺', 35.5802700, 105.9247900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15507, 'Shenjing', 'Shenjing', 'Shen-ching,Shen-ching-hsu,Shen-ching-hsü,Shenjing,Shenjing Zhen,shen jing,shen jing zhen,深井,深井镇', 21.9823900, 112.4886200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15508, 'Shenjian', 'Shenjian', 'Shenjian,Shenjian Xiang,shen jian,shen jian xiang,椹涧,椹涧乡', 34.0166700, 113.6866700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15509, 'Shenjiamen', 'Shenjiamen', 'P''u-t''o,Putuo,P’u-t’o,San Ka Mun,Shen-chia-men,Shen-chia-men-chen,Shenjiamen,Shenjiamen Jiedao,Shenjiamenzhen,Shenkiamen,Sinkeamun,chen jia men,chen jia men jie dao,沈家门,沈家门街道', 29.9576300, 122.2980200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15510, 'Shenji', 'Shenji', 'Shen-chia-chi,Shenji,Shenji Zhen,Shenjiaji,chen ji,chen ji zhen,沈集,沈集镇', 30.8573700, 112.3685800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15511, 'Shengze', 'Shengze', 'Sheng-tse,Sheng-tse-chen,Shengze,Shengze Zhen,sheng ze,sheng ze zhen,盛泽,盛泽镇', 30.9088400, 120.6693100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15512, 'Shanhu', 'Shanhu', 'Ch''eng,Ch''eng-hsien,Ch''eng-hsien-ch''eng,Ch’eng,Ch’eng-hsien,Ch’eng-hsien-ch’eng,Shanhu,Shanhu Jiedao,Sheng-hsien,Shengxian,Shengzhou,Shengzhou Shi,shan hu,shan hu jie dao,sheng zhou shi,剡湖,剡湖街道,嵊州市', 29.5958300, 120.8166700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15513, 'Shengshan', 'Shengshan', 'Shengshan,sheng shan,嵊山', 30.7196000, 122.8075900, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15514, 'Shengrenjian', 'Shengrenjian', 'Chiu-p''ing-lu,Chiu-p’ing-lu,Jiupinglu,P''ing-lu-hsien,Pinglu,Pinglu Xian,Pinlu,P’ing-lu-hsien,Sheng-jen-chien,Sheng-jen-chien-chen,Sheng-jen-chien-ts''un,Sheng-jen-chien-ts’un,Shengrenjian,Shengrenjian Zhen,ping lu xian,sheng ren jian,sheng ren jian zhen,圣仁涧,圣仁涧镇,平陆县', 34.8442200, 111.1913100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15515, 'Shengmi', 'Shengmi', 'Hsin-chien,Shangmi Zhen,Sheng-mi,Sheng-mi-chen,Sheng-mi-chieh,Shengmi,Shengmijie,sheng mi,sheng mi zhen,生米,生米镇', 28.5729000, 115.7924900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15516, 'Shengli', 'Shengli', 'Shengli,Shengli Zhen,sheng li,sheng li zhen,胜利,胜利镇', 31.1315300, 115.4617900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15517, 'Shengjiaba', 'Shengjiaba', 'Shengjiaba,Shengjiaba Xiang,sheng jia ba,sheng jia ba xiang,盛家坝,盛家坝乡', 29.9848200, 109.2192600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15518, 'Shenghuang', 'Shenghuang', 'Shenghuang,Shenghuang Zhen,sheng huang,sheng huang zhen,省璜,省璜镇', 25.9872800, 118.7238500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15519, 'Shengtang', 'Shengtang', 'Shenghang,Shengtang,Shengtang Zhen,sheng tang,sheng tang zhen,圣堂,圣堂镇', 22.2905000, 112.3784900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15520, 'Shengang', 'Shengang', 'Shen-chiang,Shen-kang,Shengang,Shengang Zhen,shen gang,shen gang zhen,申港,申港镇', 31.8866100, 120.1384100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15521, 'Shengang', 'Shengang', 'Shen-kang,Shen-kang-hsu,Shen-kang-hsü,Shengang,Shengang Zhen,shen gang,神岗', 23.4857800, 113.5230500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15522, 'Shendu', 'Shendu', 'Shen-tu,Shendu,Shendu Zhen,shen du,shen du zhen,深渡,深渡镇', 29.8675600, 118.6110100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15523, 'Shendang', 'Shendang', 'Shen-tang,Shen-tang-chen,Shendang,Shendang Zhen,chen dang,chen dang zhen,沈荡,沈荡镇', 30.5773600, 120.8212900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15524, 'Shencun', 'Shencun', 'Shen-chia-chen,Shen-ts''un,Shen-ts''un-chen,Shen-ts''un-p''u,Shen-ts’un,Shen-ts’un-chen,Shen-ts’un-p’u,Shencun,Shencun Zhen,chen cun,chen cun zhen,沈村,沈村镇', 31.0516800, 118.8511500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15525, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,Shen-ch''ih,Shen-ch''ih-hsien,Shen-ch''ih-hsien-ch''eng,Shen-ch’ih,Shen-ch’ih-hsien,Shen-ch’ih-hsien-ch’eng,Shenchi Xian,long quan,long quan zhen,shen chi xian,神池县,龙泉,龙泉镇', 39.0844600, 112.1911900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15526, 'Shekou', 'Shekou', 'Shekou,Shekou Jiedao,Shekow,she kou,she kou jie dao,滠口,滠口街道', 30.7139400, 114.3494000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15527, 'Shekou', 'Shekou', 'Hsieh-k''ou,Hsieh-k’ou,Shekou,Shekou Zhen,Shekow,she kou,she kou zhen,社口,社口镇', 27.2119400, 119.5713900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15528, 'Shekou', 'Shekou', 'Shekou,Shekou Jiedao,ZYK,she kou,she kou jie dao,蛇口,蛇口街道', 22.4935900, 113.9156000, 'CN', '2013-10-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15529, 'Shejiaping', 'Shejiaping', 'She-chia-p''ing,She-chia-p’ing,Shejiaping,Shejiaping Xiang,she jia ping,she jia ping xiang,佘家坪,佘家坪乡', 28.9770900, 111.2520800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15530, 'Shejiang', 'Shejiang', 'She-chiang,Shejiang,Shejiang Zhen,Yujiang Zhen,she jiang,she jiang zhen,畲江,畲江镇', 24.0403800, 115.9794200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15531, 'Shegeng', 'Shegeng', 'She-keng,Shegeng,Shegeng Xiang,she geng,she geng xiang,社赓,社赓乡', 28.4356600, 116.6634600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15532, 'Shefu', 'Shefu', 'She-fu-hsu,She-fu-hsü,Shefu,Shefu Xiang,she fu,she fu xiang,社富,社富乡', 26.1673500, 115.3648100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15533, 'Shazipo', 'Shazipo', 'Sha-tzu-p''o,Sha-tzu-p’o,Shazipo,Shazipo Zhen,sha zi po,sha zi po zhen,沙子坡,沙子坡镇', 28.2236100, 108.4755600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15534, 'Shazikou', 'Shazikou', 'Sha-tzu-k''ou,Sha-tzu-k’ou,Shazikou', 36.1150000, 120.5372200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15535, 'Shazi', 'Shazi', 'Shazi,Shazi Zhen,Shazichang,sha zi,sha zi zhen,沙子,沙子镇', 28.5493700, 108.5392500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15536, 'Shazi', 'Shazi', 'Shazi,Shazi Zhen,sha zi,sha zi zhen,沙子,沙子镇', 30.0278100, 108.4078800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15537, 'Shazhouba', 'Shazhouba', 'Sha-chou-pa,Shazhouba,Shazhouba Zhen,sha zhou ba,sha zhou ba zhen,沙洲坝,沙洲坝镇', 25.8847700, 115.9933700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15538, 'Shazhenxi', 'Shazhenxi', 'Sha-chen-hsi,Shazhenxi,Shazhenxi Zhen,sha zhen xi,sha zhen xi zhen,沙镇溪,沙镇溪镇', 30.9584300, 110.6011400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15539, 'Shawo', 'Shawo', 'Shawo,Shawo Xiang,sha wo,sha wo xiang,沙窝,沙窝乡', 38.9981800, 114.0422700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15540, 'Shapu', 'Shapu', 'Sha-yung,Shapu,Shapu Zhen,Shayong,sha pu,sha pu zhen,沙浦,沙浦镇', 23.1571700, 112.6734200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15541, 'Shayang', 'Shayang', 'Sha-yang-chen,Shayang,sha yang,沙洋', 30.7093700, 112.5884900, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15542, 'Yunlong', 'Yunlong', 'Shayachang,Yunlong,Yunlong Zhen,sha ya chang,yun long,yun long zhen,云龙,云龙镇,沙垭场', 30.5228000, 107.6419600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15543, 'Shaxi', 'Shaxi', 'Sha-ch''i,Sha-ch''i-chen,Sha-ch’i,Sha-ch’i-chen,Sha-hsi,Sha-t''ou,Sha-t’ou,Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 31.5661800, 121.0572900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15544, 'Shaxi', 'Shaxi', 'Sha-hsi,Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 29.5160000, 121.1278200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15545, 'Shaxi', 'Shaxi', 'Sha-hsi,Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 26.8935900, 115.5931000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15546, 'Shaxi', 'Shaxi', 'Shaxi,Shaxi Xiang,sha xi,sha xi xiang,沙溪,沙溪乡', 26.3344100, 117.3471600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15547, 'Shaxi', 'Shaxi', 'Sha-ch''i,Sha-ch''i-hsu,Sha-ch’i,Sha-ch’i-hsü,Sha-hsi,Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 24.6169400, 113.6706800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15548, 'Shaxi', 'Shaxi', 'Sha-hsi,Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 22.5055800, 113.3065200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15549, 'Shawu', 'Shawu', 'Shawu,Shawutang,sha wu,沙芜', 26.0194200, 116.9684400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15550, 'Shawan', 'Shawan', 'Shawan,Shawan Zhen,sha wan,sha wan zhen,沙湾,沙湾镇', 33.6273600, 104.5637000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15551, 'Shawan', 'Shawan', 'Sha-wan-chen,Shawan,Shawanzhen,sha wan,沙湾', 29.4111700, 103.5432700, 'CN', '2015-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15552, 'Shawan', 'Shawan', 'Sha-wan-shih,Shawan,Shawan Zhen,sha wan,sha wan zhen,沙湾,沙湾镇', 27.8531100, 119.4651400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15553, 'Shawan', 'Shawan', 'Shawan,Shawan Jiedao,sha wan,sha wan jie dao,沙湾,沙湾街道', 22.9105000, 113.3319900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15554, 'Shashi', 'Shashi', 'Sha-t''o-ssu,Sha-t’o-ssu,Shashi,Shashi Zhen,Shatuo,sha shi,sha shi zhen,sha tuo,沙市,沙市镇,沙沱', 31.3360300, 108.8838400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15555, 'Shatoujiao', 'Shatoujiao', 'Sha Tau Kok,Sha-t''ou,Sha-t''ou-chiao,Sha-t’ou,Sha-t’ou-chiao,Shatoujiao,sha tou jiao,沙头角', 22.5546300, 114.2258900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15556, 'Shatou', 'Shatou', 'Shatou,Shatou Zhen,sha tou,sha tou zhen,沙头,沙头镇', 28.1988800, 120.7573000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15557, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,沙田,沙田镇', 23.9837300, 113.9318000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15558, 'Shataping', 'Shataping', 'Shataping,Shataping Xiang,sha ta ping,sha ta ping xiang,沙塔坪,沙塔坪乡', 29.5885600, 110.0386400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15559, 'Shatang', 'Shatang', 'Shatang,Shatangpu,sha tang,沙塘', 35.5843200, 105.9878000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15560, 'Rensha', 'Rensha', 'Rensha,Rensha Xiang,Shatanchang,ren sha,ren sha xiang,sha tan chang,仁沙,仁沙乡,沙滩场', 30.0530500, 107.5940900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15561, 'Shashi', 'Shashi', 'SHS,Sha-shih,Sha-shih-shih,Sha-sze,Shashi,Shasi,Shaze,Shazhe,Шаши', 30.3072200, 112.2447200, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15562, 'Shashi', 'Shashi', 'Sha-shih,Shashi,Shashi Zhen,sha shi,sha shi zhen,沙市,沙市镇', 27.0236800, 114.0755200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15563, 'Shaping', 'Shaping', 'Sha-p''ing-kuan,Sha-p’ing-kuan,Shaping,Shaping Zhen,Shapingchang,sha ping,sha ping zhen,沙坪,沙坪镇', 30.4746300, 107.4358700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15564, 'Tanjiagang', 'Tanjiagang', 'Sha-p''ing-pa,Sha-p’ing-pa,Shapingba,Shapingba Qu,Tanjiagang,qin jia gang,sha ping ba qu,沙坪坝区,覃家岗', 29.5416600, 106.4554700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15565, 'Shaping', 'Shaping', 'Ebian,O-pien,Shaping,Shapingting,sha ping,沙坪', 29.2308200, 103.2658700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15566, 'Shaping', 'Shaping', 'Gaohe,Hao-shan,Kao-hao,Kao-ho,Sha-p''ing,Sha-p''ing-chen,Sha-p''ing-hsu,Sha-p’ing,Sha-p’ing-chen,Sha-p’ing-hsü,Shaping,Shaping Jiedao,sha ping,sha ping jie dao,沙坪,沙坪街道', 22.7701900, 112.9577600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15567, 'Shapa', 'Shapa', 'Sha-p''a-chiang,Sha-p''a-kang,Sha-p’a-chiang,Sha-p’a-kang,Shapa,Shapa Zhen', 21.5316200, 111.4788400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15568, 'Shaoxing', 'Shaoxing', 'RNX,Sao-sing,Saosing,Shao-hsing,Shaohing,Shaohingfu,Shaosin,Shaosing,Shaoxing,Shawshin shehiri,Siau-heng-chhi,Sieu-hing,Siêu-hĭng,Siāu-heng-chhī,Sjaoxing,Thieu Hung,Thiệu Hưng,saosing si,shao xing,shao xing shi,shawksynj,shawshng,shawshyng,soheung,Ŝaosing,Šao-sing,Шаосин,Шаосинг,شاوشنگ,شاوشینگ,شاوكسينج,紹興,紹興市,绍兴,绍兴市,사오싱 시,소흥', 30.0023700, 120.5786400, 'CN', '2014-05-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15569, 'Shaowu', 'Shaowu', 'Shao-wu-hsien,Shaowu,shao wu,邵武', 27.3408900, 117.4831000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15570, 'Shaoguan', 'Shaoguan', 'Ch''u-chiang,Ch''u-chiang-hsien,Chao-kuan,Ch’ü-chiang,Ch’ü-chiang-hsien,HSC,Kakong,Kiukianghsien,Kukiang,Kukong,Kukong-hsien,Kükiang,Kükong,Kükong-hsien,Sao-kuan,Saoguan,Seu-koan-su,Shao-chou,Shao-kuan,Shaoguan,Shaoguan'',Shaokwan,Shiuchow,Shiukuan,Siau-koan-chhi,Sieu-guang,Siâu-koan-chhī,Sièu-guăng,Sèu-kôan-sṳ,Thieu Quan,Thiều Quan,saogwan si,shao guan,shao guan shi,shawgwan,Ŝaoguan,Šao-kuan,Шаогуан,Шаогуань,שאוגואן,شاؤگوآن,شاوگوان,韶关,韶关市,韶関市,韶關,韶關市,사오관 시', 24.8000000, 113.5833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15571, 'Shaobo', 'Shaobo', 'Shao-po,Shao-po-chen,Shao-pu,Shaobo,Shaobo Zhen,shao bo,shao bo zhen,邵伯,邵伯镇', 32.5308200, 119.5066600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15572, 'Shanzhuang', 'Shanzhuang', 'Shan-chuang,Shanzhuang,Shanzhuang Xiang,shan zhuang,shan zhuang xiang,山庄,山庄乡', 27.5161000, 114.5971100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15573, 'Shanyang', 'Shanyang', 'Shan-yang-chen,Shanyang,Shanyang Zhen,shan yang,shan yang zhen,山阳,山阳镇', 30.7665700, 121.3680700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15574, 'Shanyang', 'Shanyang', 'Shanyang,Shanyang Zhen,shan yang,shan yang zhen,杉洋,杉洋镇', 26.6701900, 119.2050900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15575, 'Shancheng', 'Shancheng', 'Shan,Shan-hsien,Shancheng,Shanxian', 34.7952800, 116.0816700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15576, 'Shanxia', 'Shanxia', 'Shan-hsia,Shanxia,Shanxia Xiang,shan xia,shan xia xiang,山下,山下乡', 27.7985300, 118.3012200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15577, 'Shanwei', 'Shanwei', 'San Vi,San-mi-su,San-mî-sṳ,San-wej,Sang-muoi,Shan''vehj,Shanwei,Swabue,Sán Vĩ,Sáng-muōi,Sòaⁿ-bóe-chhī,san-wei si,shan wei,shan wei shi,shanwy,shanwyy,shanwyyy,Šan-wej,Шаньвэй,شانوئی,شانوی,شانویئی,汕尾,汕尾市,산웨이 시', 22.7819900, 115.3475000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15578, 'Shantoudian', 'Shantoudian', 'Shan-t''ou-tien,Shan-t’ou-tien,Shantoudian,shan tou dian,山头店', 33.7881900, 113.5220700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15579, 'Shantou', 'Shantou', 'SWA,San GJau,San-tchou,San-theu-su,Sang-tau,Santou,Santouo,Shan''tou,Shan-t''ou-shih,Shan-t’ou-shih,Shantou,Shantow,Sjantou,Swatow,Sán Đầu,Sáng-tàu,Sân-thèu-sṳ,Sòaⁿ-thâu-chhī,santeou si,saw thea,shan tou,shan tou shi,shantw,shantww,Ŝantoŭo,Šan-tchou,Šantou,Шантоу,Шаньтоу,שנטאו,شانتو,شانتوؤ,شەنتۇ شەھىرى,ซัวเถา,汕头,汕头市,汕頭,汕頭市,산터우 시', 23.3681400, 116.7147900, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15580, 'Shanting', 'Shanting', '', 35.0752800, 117.4577800, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15581, 'Shantang', 'Shantang', 'Shan-t''ang-hsu,Shan-t’ang-hsü,Shang-t''ang-hsui,Shang-t’ang-hsui,Shantang,Shantang Zhen,shan tang,shan tang zhen,山塘,山塘镇', 23.6370000, 112.9556800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15582, 'Shantaizi', 'Shantaizi', 'Shan-t''ai-tzu,Shan-t’ai-tzu,Shantaizi,dan tai zi,单台子', 39.6861100, 111.4597200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15583, 'Shanqiandian', 'Shanqiandian', 'Hsien-ch''ien-tien,Hsien-ch’ien-tien,Shan-ch''ien-tien,Shan-ch’ien-tien,Shanqiandian,Shanqiandian Zhen,shan qian dian,shan qian dian zhen,山前店,山前店镇', 37.0136100, 120.8686100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15584, 'Shanmen', 'Shanmen', '', 27.2250000, 110.6927800, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15585, 'Shanlian', 'Shanlian', 'Shan-lien,Shan-lien-shih,Shanlian,Shanlian Zhen,shan lian,shan lian zhen,善琏,善琏镇', 30.6968300, 120.3078200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15586, 'Shanli', 'Shanli', 'Men-li,Shanli,Shanli Zhen,shan li,shan li zhen,闪里,闪里镇', 29.8764800, 117.3473700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15587, 'Shankou', 'Shankou', 'Shan-k''ou-chieh,Shan-k’ou-chieh,Shankou,Shankou Zhen,Shankow,shan kou,shan kou zhen,山口,山口镇', 28.8104300, 114.4629700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15588, 'Shankou', 'Shankou', 'Shan-k''ou,Shan-k''ou-ts''un,Shan-k’ou,Shan-k’ou-ts’un,Shankou,Shankou Zhen,shan kou,shan kou zhen,山口,山口镇', 28.0708000, 120.3165400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15589, 'Shanhou', 'Shanhou', 'Shan-hou-chi,Shanhou,shan hou,善厚', 31.8748300, 118.1559600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15590, 'Shanhe', 'Shanhe', 'Shan-ho,Shanhe,Shanhe Xiang,shan he,shan he xiang,山河,山河乡', 35.5166700, 106.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15591, 'Shanhe', 'Shanhe', 'Cheng-ning,Cheng-ning-hsien,Chzhennin,Shan-ho,Shan-ho-chen,Shanhe,Tschong-ning-hien,Tschöng-ning-hien,Zhengning,Zhengning Xian,shan he,zheng ning xian,山河,正宁县', 35.4843600, 108.3639800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15592, 'Shangzhuang', 'Shangzhuang', 'Shangzhuang,Shangzhuang Zhen,shang zhuang,shang zhuang zhen,上庄,上庄镇', 36.9990300, 122.2867000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15593, 'Shangzhuang', 'Shangzhuang', 'Shang-chuang,Shangzhuang,Shangzhuang Zhen,shang zhuang,shang zhuang zhen,尚庄,尚庄镇', 28.2551700, 115.6820000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15594, 'Shangyong', 'Shangyong', 'Shang-yung,Shangyong,Shangyong Zhen,shang yong,shang yong zhen,上涌,上涌镇', 25.7342100, 118.1571600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15595, 'Shangyi', 'Shangyi', 'Shangyi,Shangyi Zhen,shang yi,shang yi zhen,上义,上义镇', 23.2794000, 114.8246600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15596, 'Shangyang', 'Shangyang', 'Shangyang,Shangyang Zhen,shang yang,shang yang zhen,上洋,上洋镇', 21.5904600, 111.5894300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15597, 'Xinkou', 'Xinkou', 'Shangxinkou,Xinkou,xin kou,辛口', 39.1030400, 116.9800600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15598, 'Shangxing', 'Shangxing', 'Shang-hsing,Shang-hsing-chen,Shang-hsing-fou,Shang-hsing-pu,Shangxing,Shangxing Zhen,shang xing,shang xing zhen,上兴,上兴镇', 31.5286300, 119.2483600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15599, 'Shangxi', 'Shangxi', 'Shang-hsi,Shangxi,Shangxi Zhen,shang xi,shang xi zhen,上溪,上溪镇', 29.2848900, 119.9320500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15600, 'Shangxi', 'Shangxi', 'Shangxi,Shangxi Xiang,shang xi,shang xi xiang,上溪,上溪乡', 26.9086800, 115.7635000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15601, 'Shangwuzhuang', 'Shangwuzhuang', 'Shangwuzhuang,Shangwuzhuang Zhen,shang wu zhuang,shang wu zhuang zhen,上五庄,上五庄镇', 36.8538900, 101.4214900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15602, 'Shangtian', 'Shangtian', 'Shang-t''ien-fan,Shang-t''ien-fan-shih,Shang-t’ien-fan,Shang-t’ien-fan-shih,Shangtian,Shangtian Zhen,Shangtianfang,shang tian,shang tian zhen,尚田,尚田镇', 29.6175000, 121.4050000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15603, 'Shangtang', 'Shangtang', 'Shangtang,Shangtang Zhen,shang tang,shang tang zhen,上塘,上塘镇', 28.2919900, 115.7329000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15604, 'Shangtang', 'Shangtang', 'Shang-t''ang,Shang-t''ang-chen,Shang-t’ang,Shang-t’ang-chen,Shangtang,Shangtang Zhen,Yongjia Xian,Yung-chia,shang tang,shang tang zhen,yong jia xian,上塘,上塘镇,永嘉县', 28.1554100, 120.6882000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15605, 'Shangtang', 'Shangtang', 'Shang-hang-hsu,Shang-hang-hsü,Shangtang,Shangtang Zhen,shang tang,shang tang zhen,上唐,上唐镇', 27.3797500, 116.6537700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15606, 'Xincheng', 'Xincheng', 'Chiu-shang-shui,Shang-shui-hsien,Shangshui,Xincheng,xin cheng,新城', 33.5419400, 114.5983300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15607, 'Shangshi', 'Shangshi', 'Shang-shih,Shang-shih-tien,Shangshi,Shangshi Zhen,Shangshidian,shang shi,shang shi zhen,尚市,尚市镇', 31.9423700, 113.2323100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15608, 'Shangsha', 'Shangsha', 'Shang-sha-hsu,Shang-sha-hsü,Shangsha,Shangsha Zhen,shang sha,shang sha zhen,上砂,上砂镇', 23.4757100, 115.6928800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15609, 'Shangqing', 'Shangqing', 'Shang-ch''ing,Shang-ch''ing-kung,Shang-ch’ing,Shang-ch’ing-kung,Shangqing,Shangqing Zhen,shang qing,shang qing zhen,上清,上清镇', 28.0461200, 117.0343200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15610, 'Shangpu', 'Shangpu', 'Shang-p''u-shih,Shang-p’u-shih,Shangpu,Shangpu Zhen,shang pu,shang pu zhen,上浦,上浦镇', 29.9069200, 120.8310100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15611, 'Shangping', 'Shangping', 'Shangping,Shangping Xiang,shang ping,shang ping xiang,上坪,上坪乡', 25.9632900, 117.5073800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15612, 'Shangping', 'Shangping', 'Shang-p''ing-hsu,Shang-p''ing-yu,Shang-p’ing-hsü,Shang-p’ing-yü,Shangping,Shangping Zhen,shang ping,shang ping zhen,上坪,上坪镇', 24.7031000, 115.4457300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15613, 'Shangping', 'Shangping', 'Shangping,Shangping Zhen,shang ping,shang ping zhen,上坪,上坪镇', 24.4803500, 114.6018800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15614, 'Shangpai', 'Shangpai', 'Fei-hsi,Feixi,Feixi Xian,Shang-p''ai-chen,Shang-p''ai-ho,Shang-p''ai-ho-chen,Shang-p’ai-chen,Shang-p’ai-ho,Shang-p’ai-ho-chen,Shangpai,Shangpaihe,fei xi xian,shang pai,上派,肥西县', 31.7456500, 117.1610900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15615, 'Gemo', 'Gemo', 'Gemo,Gemo Xiang,Shang Ngawa,ge mo,ge mo xiang,各莫,各莫乡', 33.0005400, 101.6057500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15616, 'Shangma', 'Shangma', 'Shangma,Shangma Jieban,shang ma,shang ma jie ban,上马,上马街办', 35.5899700, 111.3420400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15617, 'Shanglu', 'Shanglu', 'Shang-lu-fan,Shang-lu-fang,Shanglu,Shanglu Zhen,shang lu,shang lu zhen,上泸,上泸镇', 28.2217400, 117.9469600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15618, 'Shangli', 'Shangli', 'Shang-li,Shang-li-shih,Shangli,Shangli Xian,Shanglishi,shang li,shang li shi,shang li xian,上栗,上栗县,上栗市', 27.8771000, 113.7920000, 'CN', '2014-12-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15619, 'Shangling', 'Shangling', 'Shangling,Shangling Zhen,shang ling,shang ling zhen,上陵,上陵镇', 24.6010900, 114.9898300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15620, 'Shangliang', 'Shangliang', 'Shang-liang-ho-k''ou,Shang-liang-ho-k’ou,Shangliang,Shangliang Xiang,Shanglianghekou,shang liang,shang liang xiang,上两,上两乡', 32.5439700, 106.8431500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15621, 'Shanglian', 'Shanglian', 'Lianpu,Lien-p''u,Lien-p’u,Shanglian,Shanglian Xiang,shang lian,shang lian xiang,上莲,上莲乡', 26.0414400, 118.6483500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15622, 'Shangjiuwu', 'Shangjiuwu', 'Shang-chiu-wu,Shangjiuwu,Shangjiuwu Zhen,shang jiu wu,shang jiu wu zhen,商酒务,商酒务镇', 33.9489600, 112.9776700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15623, 'Shangjing', 'Shangjing', 'Shang-ching,Shangjing,Shangjing Zhen,shang jing,shang jing zhen,上京,上京镇', 25.7225000, 117.6672200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15624, 'Shangjing', 'Shangjing', 'Shang-ching,Shangjing,Shangjing Zhen,Shuang-ching,shang jing,shang jing zhen,上迳,上迳镇', 25.6385000, 119.3059800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15625, 'Shangjin', 'Shangjin', 'Shang-chin,Shang-ching,Shangjin,Shangjin Zhen,Shangtsing,Shantzin,shang jin,shang jin zhen,上津,上津镇', 33.1436500, 110.0396200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15626, 'Jiyuanlu', 'Jiyuanlu', 'Jiyuanlu,Shang-chieh,Shangjie,ji yuan lu,济源路', 34.8225000, 113.2672200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15627, 'Shangjie', 'Shangjie', 'Hsia-chieh-hsiang,Shang-chieh,Shang-chieh-chen,Shangjie,Yang-p''i,Yang-p''i-hsien,Yang-p’i,Yang-p’i-hsien,Yangbi,shang jie,上街', 25.6710600, 99.9802500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15628, 'Shanghuang', 'Shanghuang', 'Shanghuang,Shanghuang Zhen,Shanghuangkkong,Shanghuangqian,shang huang,shang huang kong,shang huang zhen,上磺,上磺崆,上磺镇', 31.3204700, 109.4841600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15629, 'Shanghuang', 'Shanghuang', 'Shang-huang-chen,Shanghuang,Shanghuang Zhen,shang huang,shang huang zhen,上黄,上黄镇', 31.5455200, 119.5650900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15630, 'Shanghu', 'Shanghu', 'Shang-hu-shih,Shanghu,Shanghu Zhen,shang hu,shang hu zhen,尚湖,尚湖镇', 29.1476500, 120.6539800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15631, 'Shanghexi', 'Shanghexi', 'Shang-ho-ch''i,Shang-ho-ch’i,Shanghexi,Shanghexi Xiang,shang he xi,shang he xi xiang,上河溪,上河溪乡', 29.4754700, 109.8027000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15632, 'Linjiang', 'Linjiang', 'Linjiang,Linjiang Zhen,Shang-hang-hsien,Shanghang,Shanghang Xian,lin jiang,lin jiang zhen,shang hang,shang hang xian,上杭,上杭县,临江,临江镇', 25.0516700, 116.4203000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15633, 'Shanghai', 'Shanghai', 'SHA,San''nkae,Sanchajus,Sangaj,Sangay,Sanghaj,Sanghay,Sanhaja,Sanhajo,Sanxay,Schanghai,Shang-hai,Shang-hai-shih,Shangai,Shangaj,Shanghai,Shanghai - shang hai,Shanghai - 上海,Shankhaj,Sjanghae,Sjanghai,Sjanghæ,Szanghaj,Thuong Hai,Thượng Hải,Xangai,cankay,sanghae,sanghai,seiynghi,shang hai,shang hai shi,shanghay,shanghhay,shanhai,zhong guo shang hai,Ŝanhajo,Şangay,Şanghay,Şanxay,Šanchajus,Šangaj,Šanghaj,Šanhaja,Σανγκάη,Шангај,Шанхай,שאנגחאי,شانغهاي,شانگهای,شاڭخەي,شاڭخەي شەھىرى,சாங்காய்,เซี่ยงไฮ้,შანჰაი,上海,上海市,中国上海,상하이,상해', 31.2222200, 121.4580600, 'CN', '2017-07-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15634, 'Shanggu', 'Shanggu', 'Shang-ku,Shanggu,Shanggu Xiang,shang gu,shang gu xiang,上固,上固乡', 26.8022800, 115.5828900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15635, 'Shanggan', 'Shanggan', 'Min-hou,Shang-kan,Shanggan,Shanggan Zhen,shang gan,shang gan zhen,尚干,尚干镇', 25.9274400, 119.3698300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15636, 'Shangfu', 'Shangfu', 'Shang-fu-chen,Shang-shu,Shangfu,Shangfu Zhen,shang fu,shang fu zhen,上富,上富镇', 28.6755600, 115.0041300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15637, 'Shangfang', 'Shangfang', 'Shangfang,Shangfang Xiang,shang fang,shang fang xiang,上方,上方乡', 38.5282900, 114.4586100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15638, 'Shangfang', 'Shangfang', 'Shang-fang-chen,Shangfang,shang fang,上方', 29.2695100, 118.9160600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15639, 'Shangdundu', 'Shangdundu', 'Linchuan,Shang-tun-t''ou,Shang-tun-tu,Shang-tun-t’ou,Shangdundu,Shangdundu Zhen,shang dun du,shang dun du zhen,上顿渡,上顿渡镇', 27.9382700, 116.2926900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15640, 'Shangdian', 'Shangdian', 'Shang-chuang,Shang-tien,Shangdian,Shangdian Zhen,shang dian,尚店', 33.2295200, 113.4472600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15641, 'Shangde', 'Shangde', 'Shangde,shang de,尚德', 32.9072700, 104.7695800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15642, 'Shangdang', 'Shangdang', 'Shang-t''ang-chen,Shang-tang,Shang-t’ang-chen,Shangdang,Shangdang Zhen,shang dang,shang dang zhen,上党,上党镇', 32.0735500, 119.4088400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15643, 'Shangcun', 'Shangcun', 'Shangcun,Shangcun Zhen,shang cun,shang cun zhen,尚村,尚村镇', 34.1551600, 108.4687300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15644, 'Shangchewan', 'Shangchewan', 'Shang Chai Wan,Shangchewan,Shangchewan Zhen,shang che wan,shang che wan zhen,上车湾,上车湾镇', 29.8015700, 113.0061800, 'CN', '2015-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15645, 'Shangcheng Chengguanzhen', 'Shangcheng Chengguanzhen', 'Shangcheng Chengguanzhen,Shangcheng Xian,Shangchenghsien,shang cheng cheng guan zhen,shang cheng xian,商城县,商城城关镇', 31.7952800, 115.4011100, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15646, 'Shangcang', 'Shangcang', 'Shang-ts''ang,Shang-ts''ang-chen,Shang-ts’ang,Shang-ts’ang-chen,Shangcang', 39.8994400, 117.3880600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15647, 'Chongyang', 'Chongyang', 'Chongyang,Shang-ts''ai-hsien,Shang-ts’ai-hsien,Shangcai,Shangtsai,Shantsay,zhong yang,重阳', 33.2592200, 114.2420400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15648, 'Shangbei', 'Shangbei', 'Shang-pei,Shang-pei-chen,Shangbei,Shangbei Zhen,shang bei,shang bei zhen,上碑,上碑镇', 38.4841700, 114.4570300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15649, 'Shangbaishi', 'Shangbaishi', 'Pai-shih,Shang-pai-shih,Shangbaishi,Shangbaishi Zhen,shang bai shi,shang bai shi zhen,上白石,上白石镇', 27.2430600, 119.7238900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15650, 'Shangbahe', 'Shangbahe', 'Shang-pa-ho,Shangbahe,Shangbanhe Zhen,shang ba he,shang ba he zhen,上巴河,上巴河镇', 30.6509500, 115.1043400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15651, 'Shangba', 'Shangba', 'Shang-pa,Shangba,Shangba Tujiazu Xiang,shang ba,shang ba tu jia zu xiang,上坝,上坝土家族乡', 28.8315400, 107.5804200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15652, 'Shang’an', 'Shang''an', 'Shang''an,Shang''an Zhen,Shang''andong,Shang-an,Shang-an-ts''un,Shang-an-ts’un,Shang’an,Shang’an Zhen,Shang’andong,shang an,shang an zhen,上安,上安镇', 38.0630800, 114.2076900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15653, 'Shandang', 'Shandang', 'Shan-tang,Shandang,Shandang Zhen,shan dang,shan dang zhen,山砀,山砀镇', 27.6318800, 115.7971900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15654, 'Qingquan', 'Qingquan', 'Qingquan,Shan''dan'',Shan-tan,Shan-tan-hsien,Shandan,Shandan Chengguanzhen,Shandan Xian,Shan’dan’,Tan-shan,qing quan,shan dan,shan dan cheng guan zhen,shan dan xian,山丹,山丹县,山丹城关镇,清泉', 38.7931200, 101.0886800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15655, 'Shancheng', 'Shancheng', 'Shancheng,Shancheng Xiang,Xianchengbu,shan cheng,shan cheng xiang,山城,山城乡', 36.9567900, 107.0266300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15656, 'Shancheng', 'Shancheng', 'Shancheng,T''ai-ning-hsien,Taining,T’ai-ning-hsien,shan cheng,杉城', 26.9005300, 117.1631200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15657, 'Shancheng', 'Shancheng', 'Nan-ching,Nan-ching-ch''eng,Nan-ching-ch’eng,Nan-ching-hsien,Nanjing,Shan-ch''eng-chen,Shan-ch’eng-chen,Shancheng,shan cheng,山城', 24.4915500, 117.3456800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15658, 'Shamen', 'Shamen', 'Shamen,Shamen Zhen,sha men,sha men zhen,沙门,沙门镇', 28.2417700, 121.3775600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15659, 'Shaliuhe', 'Shaliuhe', 'Gangca,Gangcha Xian,Kang-ch''a,Kang-ch’a,Sha-liu-ho,Shaliuhe,gang cha xian,sha liu he,刚察县,沙柳河', 37.3260000, 100.1343900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15660, 'Shaliu', 'Shaliu', 'Sha-liu-chen,Shaliu,Shaliu Zhen,sha liu,sha liu zhen,沙柳,沙柳镇', 29.1500000, 121.4000000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15661, 'Shangshaleng', 'Shangshaleng', 'Sha-leng-ho,Shalenghe Xiang,Shang-sha-leng-ho,Shangshaleng,sha leng he xiang,shang sha leng,上沙塄,沙塄河乡', 39.1979000, 112.4888200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15662, 'Shalang', 'Shalang', 'Sha-lang-hsu,Shalang,Shalang Zhen,Shä-lang-hsü,sha lang,sha lang zhen,沙琅,沙琅镇', 21.7861800, 111.2153200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15663, 'Shakou', 'Shakou', 'Sha-k''ou-hsu,Sha-k’ou-hsü,Shakou,Shakou Zhen,sha kou,sha kou zhen,沙口,沙口镇', 24.4269900, 113.5157700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15664, 'Shajing', 'Shajing', 'Scha-tsing,Sha-ching,Sha-ching-tsu,Sha-ching-tzu,Shajing,Shajing Zhen,Shajingzi,Shatszintszo,Shatszintszö,sha jing,sha jing zhen,沙井,沙井镇', 39.1000000, 100.2666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15665, 'Shajing', 'Shajing', 'Sha-ching,Shajing,Shajing Zhen,sha jing,沙迳', 23.5903200, 114.0950500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15666, 'Shajing', 'Shajing', 'Sha-ching,Shajing,Shajing Jiedao,Shatsing,sha jing,sha jing jie dao,沙井,沙井街道', 22.7462800, 113.8190300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15667, 'Shajiang', 'Shajiang', 'Sha-chiang,Shajiang', 26.7825000, 119.9669400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15668, 'Shahu', 'Shahu', 'Shahu,Shahu Zhen,sha hu,sha hu zhen,沙湖,沙湖镇', 30.1725300, 113.6736500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15669, 'Shahu', 'Shahu', 'Sha-hu-hsu,Sha-hu-hsü,Shahu,Shahu Zhen,sha hu,sha hu zhen,沙湖,沙湖镇', 22.3897800, 112.4398000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15670, 'Shahe', 'Shahe', 'Lin-tse,Linze,Linze Chengguanzhen,Linze Xian,Scha-ho-pu,Sha-ho,Sha-ho-chen,Sha-ho-p''u,Sha-ho-pao,Sha-ho-p’u,Shahe,Shahepu,Shahezhen,Shakhe,lin ze cheng guan zhen,lin ze xian,sha he,临泽县,临泽城关镇,沙河', 39.1416500, 100.1783600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15671, 'Shahejie', 'Shahejie', 'Chiu-chiang,Jiujiang,Sha-ho,Sha-ho-p''u,Sha-ho-p’u,Shahe,Shahejie,Shahejie Zhen,Shahezhen,Shahochen,sha he jie,sha he jie zhen,沙河街,沙河街镇', 29.6079400, 115.8872000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15672, 'Shahedian', 'Shahedian', 'Sha-ho-tien,Shahedian,Shahedian Zhen,sha he dian,沙河店', 32.9969400, 113.7248600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15673, 'Shahe', 'Shahe', 'Fan-chih,Fan-chih-hsien,Sha-ho,Sha-ho-chen,Shahe,Shahe Zhen,sha he,sha he zhen,砂河,砂河镇', 39.2708300, 113.5477800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15674, 'Shahe', 'Shahe', 'Sha-ho,Shahe,Shahe Zhen,sha he,sha he zhen,沙河,沙河镇', 37.0391300, 119.7695700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15675, 'Shahecheng', 'Shahecheng', 'Sha-ho,Sha-ho-ch''eng-kuan,Sha-ho-ch’eng-kuan,Sha-ho-hsien,Shahe,Shahecheng,Shahhsien,Shakhe', 36.9383300, 114.5058300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15676, 'Shahe', 'Shahe', 'Sha-ho-tzu,Shahe,Shahe Zhen,Shahezi,sha he,sha he zhen,沙河,沙河镇', 32.2030000, 106.7257700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15677, 'Shagou', 'Shagou', 'Guorenduo,Shagou,Shagou Xiang,guo ren duo,sha gou,sha gou xiang,沙沟,沙沟乡,郭仁多', 35.9171700, 100.9364900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15678, 'Shagedu', 'Shagedu', 'Chun-ko-erh-ch''i,Chun-ko-erh-ch’i,Dzhungar-Ci,Jungar Qi,O-erh-to-ssu-tso-i-ch''ien-ch''i,O-erh-to-ssu-tso-i-ch’ien-ch’i,Sha-ch''i-tu,Sha-ch’i-tu,Sha-ko-tu,Shagedu,Shagedu Zhen,Zhunge''er Qi,Zhunge’er Qi,sha ge du,sha ge du zhen,zhun ge er qi,Джунгар-Ци,准格尔旗,沙圪堵,沙圪堵镇', 39.6475000, 110.8594400, 'CN', '2013-11-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15679, 'Shagang', 'Shagang', 'Sha-kang,Shagang,Shagang Zhen,sha gang,sha gang zhen,沙岗,沙岗镇', 30.0666700, 112.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15680, 'Shadui', 'Shadui', 'Sha-tui,Shadui,Shadui Zhen,sha dui,sha dui zhen,沙堆,沙堆镇', 29.3053100, 113.8978400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15681, 'Shadui', 'Shadui', 'Sha-tui,Shadui,Shadui Zhen,sha dui,sha dui zhen,沙堆,沙堆镇', 22.3051400, 113.1462000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15682, 'Shadaoguan', 'Shadaoguan', 'Sha-tao-kuan,Shadaoguan,Shadaoguan Zhen,sha dao guan,sha dao guan zhen,沙道观,沙道观镇', 30.1728400, 111.9220400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15683, 'Shadaogou', 'Shadaogou', 'Sah-tao-kou,Shadaogou,Shadaogou Zhen,sha dao gou,sha dao gou zhen,沙道沟,沙道沟镇', 29.6938900, 109.5563900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15684, 'Shaba', 'Shaba', 'Shaba,Shaba Zhen,sha ba,sha ba zhen,砂坝,砂坝镇', 29.2665300, 110.0171100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15685, 'Se’ergu', 'Se''ergu', 'Se''ergu,Se''ergu Xiang,Sergu,Se’ergu,Se’ergu Xiang,se er gu,se er gu xiang,色尔古,色尔古乡', 31.9382500, 103.4194200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15686, 'Sailaitang', 'Sailaitang', 'Baima,Banma,Banma Xian,Pan-ma,Sai-lai-t''ang,Sai-lai-t’ang,Sailaitang,Sailaitang Zhen,Seraitang,Sêraitang,ban ma,ban ma xian,sai lai tang,sai lai tang zhen,斑玛,斑玛县,赛来塘,赛来塘镇', 32.9351900, 100.7375700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15687, 'Seke', 'Seke', 'Se-ta,Serkog,Sêrkog,se ke,色柯', 32.2714600, 100.3331600, 'CN', '2007-07-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15688, 'Sazhubxi', 'Sazhubxi', 'Sazhubxi,Shazhuyu,Shazhuyu Xiang,sha zhu yu,sha zhu yu xiang,沙珠玉,沙珠玉乡', 36.2833300, 100.2833300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15689, 'Sanzhen', 'Sanzhen', 'San-chen,Sanzhen,Sanzhen Zhen,san zhen,san zhen zhen,三圳,三圳镇', 24.5915100, 116.1280700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15690, 'Sanzhang', 'Sanzhang', 'San-chang,San-chang-ts''un,San-chang-ts’un,Sanzhang,Sanzhang Zhen,san zhang,三张', 34.4467300, 109.4607300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15691, 'Sanzao', 'Sanzao', 'San-tsao,Sanzao,Ssu-tsao', 32.8166700, 120.3500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15692, 'Sanzao', 'Sanzao', 'San-tsao,San-tsao-hsu,San-tsao-hsü,Sanzao,Sanzao Zhen,san zao,san zao zhen,三灶,三灶镇', 22.0529700, 113.3428300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15693, 'Sanyuan Chengguanzhen', 'Sanyuan Chengguanzhen', 'Chengguan Zhen,San-yuan-hsien,San-yüan-hsien,Sanyuan Chengguanzhen,cheng guan zhen,san yuan cheng guan zhen,三原城关镇,城关镇', 34.6147200, 108.9283300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15694, 'Sanyuan', 'Sanyuan', 'Sanyuan,Sanyuan Zhen,Tanshanba,san yuan,san yuan zhen,tan shan ba,三元,三元镇,滩山坝', 30.1046100, 107.6518200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15695, 'Sanyu', 'Sanyu', 'San-yu-chen,San-yu-chia,San-yü-chen,San-yü-chia,Sanyu,Sanyu Zhen,Sanyuzhen,san yu,san yu zhen,三余,三余镇', 32.1296000, 121.2868300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15696, 'Sanying', 'Sanying', 'Sanying,Sanying Zhen,san ying,san ying zhen,三营,三营镇', 36.2815400, 106.1554600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15697, 'Sanyantang', 'Sanyantang', 'San-yen-t''ang,San-yen-t’ang,Sanyantang,Sanyantang Zhen,san yan tang,san yan tang zhen,三眼塘,三眼塘镇', 28.7672200, 112.3569400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15698, 'Sanyang', 'Sanyang', 'San-yang-chen,Sanyang,Sanyang Zhen,Sanyangzhen,san yang,san yang zhen,三阳,三阳镇', 31.9266000, 121.4718800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15699, 'Sanyang', 'Sanyang', 'Sanyang,Sanyang Xiang,Sanyangkeng,san yang,san yang xiang,三阳,三阳乡', 30.0231700, 118.7833400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15700, 'Sanyanggang', 'Sanyanggang', 'San-yang-kang,Sanyanggang,Sanyanggang Zhen,san yang gang,san yang gang zhen,三阳港,三阳港镇', 28.9766000, 111.3460300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15701, 'Sanyang', 'Sanyang', 'Sanyang,Sanyang Zhen,san yang,san yang zhen,三阳,三阳镇', 31.3164700, 113.1844800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15702, 'Sanyang', 'Sanyang', 'Sanyang,Sanyang Zhen,san yang,san yang zhen,三阳,三阳镇', 27.9231200, 114.3886400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15703, 'Sanya', 'Sanya', 'Gorad San''ja,SYX,Sam-a-chhi,Sam-a-chhī,Sama,Samah,San''ja,San-ah,San-ja,San-ya-chen,San-ya-chiang,San-ya-chiang-shih,Sang-a,Sanj,Sanya,Senya shehiri,Săng-ā,Tam A,Tam Á,Ya Xian,Ya-hsien,Yai-hsien,Yehsien,san ya,san ya shi,sanya,ssan-ya si,Горад Санья,Санья,سانيا,سانیا,ซานย่า,སན་ཡ་གྲོང་ཁྱེར།,三亚,三亚市,三亜市,三亞,싼야 시', 18.2430600, 109.5050000, 'CN', '2014-08-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15704, 'Sanxing', 'Sanxing', 'San-hsing-chen,Sanxing,Sanxing Zhen,Sanxingzhen,san xing,san xing zhen,三星,三星镇', 31.9681200, 121.1154100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15705, 'Sanxing', 'Sanxing', 'San-hsing,San-hsing-chen,Sanxing,Sanxing Zhen,san xing,san xing zhen,三星,三星镇', 31.7489700, 121.2733700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15706, 'Sanxing', 'Sanxing', 'San-hsing,San-pai-ch''iu,San-pai-ch’iu,San-pai-hsing,San-po-ch''iu,San-po-ch’iu,Sanxing,Sanxing Zhen,san xing,san xing zhen,三兴,三兴镇', 28.2155300, 114.4614400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15707, 'Sanxi', 'Sanxi', 'San-hsi-k''ou,San-hsi-k’ou,Sanxi,Sanxi Zhen,Sanxikou,san xi,san xi zhen,三溪,三溪镇', 29.8261700, 114.9397800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15708, 'Sanxiang', 'Sanxiang', 'P''ing-lan,P''inglam,P’ing-lan,P’inglam,San-hsiang,Sanxiang,Sanxiang Zhen,san xiang,san xiang zhen,三乡,三乡镇', 22.3505400, 113.4202600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15709, 'Sanxi', 'Sanxi', 'San-ch''i,San-ch''i-chen,San-ch’i,San-ch’i-chen,San-hsi,Sanxi,Sanxi Zhen,san xi,san xi zhen,三溪,三溪镇', 30.3777400, 118.4277600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15710, 'Sanxi', 'Sanxi', 'San-hsi,Sanxi,Sanxi Xiang,san xi,san xi xiang,三溪,三溪乡', 27.1439200, 116.3924800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15711, 'Santang', 'Santang', 'San-t''ang-shih,San-t’ang-shih,Santang,Santang Xiang,san tang,san tang xiang,三塘,三塘乡', 28.7352500, 116.5675500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15712, 'Sanshilipu', 'Sanshilipu', 'Sanshilipu,Sanshilipu Zhen,Shilipu,san shi li pu,san shi li pu zhen,三十里铺,三十里铺镇', 36.0975500, 107.7783900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15713, 'Sanshan', 'Sanshan', 'San-shan-chieh,Sanshan,Sanshan Qu,san shan,san shan qu,三山,三山区', 31.2231900, 118.2244800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15714, 'Sanshan', 'Sanshan', 'San Shah,Sanshan,Sanshan Zhen,san shan,san shan zhen,三山,三山镇', 25.5347500, 119.5167500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15715, 'Sansha', 'Sansha', 'Sansha,Sansha Zhen,san sha,san sha zhen,三沙,三沙镇', 26.9242000, 120.2087700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15716, 'Sanrao', 'Sanrao', 'Chiu-jao-p''ing,Chiu-jao-p’ing,Jao-p''ing,Jao-p''ing-hsien,Jao-p’ing,Jao-p’ing-hsien,San-jao,Sanrao,Sanrao Zhen,san rao,san rao zhen,三饶,三饶镇', 23.9851200, 116.8224000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15717, 'Sanqu', 'Sanqu', 'San-ch''u-chen,San-ch’ü-chen,Sanqu,Sanqu Zhen,Wangjiaba,san qu,san qu zhen,wang jia ba,三驱,三驱镇,汪家坝', 29.6415700, 105.6216100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15718, 'Sanquan', 'Sanquan', 'San-ch''uan,San-ch''uan-chen,San-ch’üan,San-ch’üan-chen,Sanquan,Sanquan Zhen,san quan,san quan zhen,三泉,三泉镇', 35.6752800, 111.1580600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15719, 'Sanqiao', 'Sanqiao', 'San-ch''iao,San-ch''iao-chen,San-ch’iao,San-ch’iao-chen,Sanqiao,Sanqiao Jieban,san qiao,san qiao jie ban,三桥,三桥街办', 34.2868400, 108.8355300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15720, 'Sanqiao', 'Sanqiao', 'Sanqiao,Sanqiao Zhen,san qiao,san qiao zhen,三桥,三桥镇', 29.0578300, 107.5031700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15721, 'Sanming', 'Sanming', 'SQJ,Sam-beng-chhi,Sam-bêng-chhī,Sam-min-su,San''min,San-ming,San-ming-hsien,San-ming-shih,San-yuan,San-yuan-hsien,San-yüan,San-yüan-hsien,Sang-ming,Sanming,Senming shehiri,Sâm-mìn-sṳ,Săng-mìng,Tam Minh,san ming,san ming shi,sanmng,sanmyng,ssanming si,Санминг,Саньмин,سانمنگ,سانمینگ,三明,三明市,싼밍 시', 26.2486100, 117.6186100, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15722, 'Sanmiaoqian', 'Sanmiaoqian', 'San-miao-ch''ien,San-miao-ch’ien,Sanmiaoqian,Sanmiaoqian Xiang,Sanmiaoqiao,san miao qian,san miao qian xiang,三庙前,三庙前乡', 28.9703000, 116.7673200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15723, 'Sanmenpo', 'Sanmenpo', 'Sanmenpo,Sanmenpo Zhen,san men po,san men po zhen,三门坡,三门坡镇', 19.7165500, 110.5580500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15724, 'Sanmao', 'Sanmao', 'San-mao-chen,Sanmao,Sanmaozhen,Yang-chung,Yang-chung-hsien,Yangzhong Shi,san mao,san mao zhen,yang zhong shi,三茅,三茅镇,扬中市', 32.2393100, 119.8153600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15725, 'Sanlong', 'Sanlong', 'Lung-wang-miao,San-lung,Sanlong,Sanlong Zhen,san long,san long zhen,三龙,三龙镇', 33.4184900, 120.5108500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15726, 'Sanlong', 'Sanlong', 'San-lung,San-lung-chieh,San-lung-shih,Sanlong,Sanlong Xiang,san long,san long xiang,三龙,三龙乡', 29.3852900, 117.1451100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15727, 'Sanligang', 'Sanligang', 'San-li-kang,Sanligang,Sanligang Zhen,san li gang,san li gang zhen,三里岗,三里岗镇', 31.4935300, 113.0734500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15728, 'Sanlifan', 'Sanlifan', 'Sanlifan,Sanlifan Zhen,san li fan,san li fan zhen,三里畈,三里畈镇', 30.8355300, 115.2665900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15729, 'Sanlicheng', 'Sanlicheng', 'Sanlicheng,Sanlicheng Zhen,san li cheng,san li cheng zhen,三里城,三里城镇', 31.8001200, 114.2036800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15730, 'Sanli', 'Sanli', 'Sanli,Sanli Xiang,san li,san li xiang,三里,三里乡', 28.6809000, 116.3784800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15731, 'Sankui', 'Sankui', 'Sankui,Sankui Zhen,Xiuxibian,san kui,san kui zhen,xiu xi bian,三魁,三魁镇,秀溪边', 27.4283300, 119.9130300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15732, 'Sankou', 'Sankou', 'San-k''ou-chen,San-k’ou-chen,Sankou,Sankou Zhen,san kou,san kou zhen,三口,三口镇', 30.2592800, 118.2137400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15733, 'Sankou', 'Sankou', 'Sankou,san kou,三口', 30.0988700, 119.7420600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15734, 'Sankeng', 'Sankeng', 'San-k''eng-hsu,San-k’eng-hsü,Sankeng,Sankeng Zhen,san keng,san keng zhen,三坑,三坑镇', 23.6000000, 112.8000000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15735, 'Sanjie', 'Sanjie', 'San-chieh,San-chieh-chen,Sanjie,Sanjie Zhen,san jie,san jie zhen,三界,三界镇', 29.7590900, 120.8478600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15736, 'Sanjiaocheng', 'Sanjiaocheng', 'Hai-yen,Haiyan,Haiyan Xian,Hsing-lung-chuang,San-chiao-ch''eng,San-chiao-ch’eng,Sanjiaocheng,hai yan xian,san jiao cheng,三角城,海晏县', 36.8908300, 100.9997200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15737, 'Sanjiao', 'Sanjiao', 'San-chiao,San-chiao-chen,Sanjiao,Sanjiao Zhen,san jiao,san jiao zhen,三角,三角镇', 29.0502800, 106.7363900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15738, 'Sanjiang', 'Sanjiang', 'San-chiang-k''ou,San-chiang-k’ou,Sanjiang,Sanjiang Zhen,Sanjiangkou,san jiang,san jiang zhen,三江,三江镇', 28.2926900, 116.0047400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15739, 'Sanjiang', 'Sanjiang', 'San-ch''i-ch''ang,San-chiang,San-ch’i-ch’ang,San-hsi-ch''ang,San-hsi-ch’ang,Sanjiang,Sanjiang Zhen,Sanjiangchang,san jiang,san jiang zhen,三江,三江镇', 28.9447200, 106.7105600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15740, 'Sanjiang', 'Sanjiang', 'San-chiang,Sanjiang,Sanjiang Zhen,san jiang,san jiang zhen,三江,三江镇', 28.6787600, 107.4812000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15741, 'Sanjiang', 'Sanjiang', 'Chin-p''ing,Chin-p''ing-hsien,Chin-p’ing,Chin-p’ing-hsien,Jinping,Kinping,Kinping-hsien,Kinpingsiang,San-chiang,San-chiang-chen,Sanjiang,Sanjiang Zhen,Sankiang,san jiang,san jiang zhen,三江,三江镇', 26.6749000, 109.1960000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15742, 'Sanjiang', 'Sanjiang', 'Liannan,Lien-nan,Lien-nan-yao-tsu-tzu-chih-ch''u,Lien-nan-yao-tsu-tzu-chih-ch’ü,Lien-nan-yao-tsu-tzu-chih-hsien,Linnam,Samkong,San-chiang,San-chiang-ch''eng,San-chiang-chen,San-chiang-ch’eng,San-chiang-hsu,San-chiang-hsü,Sanjiang,Sanjiang Zhen,san jiang,san jiang zhen,三江,三江镇', 24.7206300, 112.2944200, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15743, 'Sanjiang', 'Sanjiang', 'Samkong,San-chiang,Sanjiang,Sanjiang Zhen,san jiang,san jiang zhen,三江,三江镇', 22.4345500, 113.1031400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15744, 'Sanjiang', 'Sanjiang', 'Samkong,San-chiang,San-chiang-shih,Sanjiang,Sanjiang Zhen,Sankiang,Tam Ko,san jiang,san jiang zhen,三江,三江镇', 19.8806200, 110.6010200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15745, 'Sanjia', 'Sanjia', 'San-chia,San-chia-chen,Sanjia,Sanjia Zhen,Sankia,san jia,san jia zhen,三甲,三甲镇', 32.0508300, 121.6641700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15746, 'Sanjia', 'Sanjia', 'San-chia-shih,Sanjia,Sanjia Jiedao,Sanjiazhen,san jia,san jia jie dao,三甲,三甲街道', 28.6137800, 121.4733900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15747, 'Sanjia', 'Sanjia', 'San-chia,Sanjia,Sanjia Zhen,san jia,san jia zhen,三甲,三甲镇', 22.0666700, 111.5000000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15748, 'Sanhui', 'Sanhui', 'San-hui-pa,Sanhui,Sanhui Zhen,Sanhuiba,san hui,san hui zhen,三汇,三汇镇', 30.0816700, 106.5912000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15749, 'Sanhui', 'Sanhui', 'San-hui-ch''ang,San-hui-ch’ang,Sanhui,Sanhui Zhen,san hui,san hui zhen,三汇,三汇镇', 30.3800600, 107.8687100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15750, 'Xiaodu', 'Xiaodu', 'Sanhuichang,Xiaodu,Xiaodu Zhen,san hui chang,xiao du,xiao du zhen,三汇场,小渡,小渡镇', 29.9620700, 105.8867800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15751, 'Sanhu', 'Sanhu', 'Sanhu,Sanhu Zhen,Sanhuchen,san hu,san hu zhen,三湖,三湖镇', 27.9241600, 115.4280500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15752, 'Sanhe', 'Sanhe', 'San-ho-chen,Sanhe,Sanhe Xiang,Sanhe Zhen,Shangsanhe,Shangsanhe Zhen,san he,san he zhen,shang san he,shang san he zhen,三和,三和镇,上三和,上三和镇', 31.8787400, 121.1151400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15753, 'Sanhe', 'Sanhe', 'Sanhe,san he,三河', 33.2992700, 105.1669200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15754, 'Sanhekou', 'Sanhekou', 'San-ho,San-ho-k''ou,San-ho-k’ou,Sanhe,Sanhekou,Sanhekou Zhen,san he kou,san he kou zhen,三河口,三河口镇', 31.3301200, 115.2255400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15755, 'Sanhe', 'Sanhe', 'San-ho,San-ho-t''u,San-ho-t’u,Sanhe,Sanhe Zhen,Sanhetu,san he,san he zhen,三合,三合镇', 28.0690900, 106.3480100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15756, 'Sanhe', 'Sanhe', 'San-ho,Sanhe,Sanhe Zhen,san he,san he zhen,三河,三河镇', 24.4009100, 116.5666400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15757, 'Sangzi', 'Sangzi', 'Sangzi,Shang-tzu', 39.9055600, 117.1572200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15758, 'Sangzhou', 'Sangzhou', 'Sang-chou,Sang-chou-chen,Sangchow,Sangzhou,Sangzhou Zhen,sang zhou,sang zhou zhen,桑洲,桑洲镇', 29.1574600, 121.3163300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15759, 'Sangzhe', 'Sangzhe', 'Sang-che-p''ing,Sang-che-p’ing,Sang-chia-p''ing,Sang-chia-p’ing,Sangzhe,Sangzhe Zhen,Sangzheping,sang zhe,sang zhe zhen,桑柘,桑柘镇', 29.2783700, 108.3982200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15760, 'Sangzhen', 'Sangzhen', 'Sang-chen,Sang-chia-chen,Sangzhen,Sangzhenjiedao,sang zhen,桑镇', 34.2561100, 108.3461100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15761, 'Sangyuan', 'Sangyuan', 'Sang-yuan-chen,Sang-yüan-chen,Sangyuan,Sangyuan Zhen,Santsyuan,Wu-ch''iao,Wu-ch’iao,Wuqiao,sang yuan,sang yuan zhen,桑园,桑园镇', 37.6256000, 116.3825900, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15762, 'Sanguansi', 'Sanguansi', 'San-kuan,San-kuan-shih,San-kuan-ssu,Sanguansi,Sanguansi Tujiazuxiang,san guan si,san guan si tu jia zu xiang,三官寺,三官寺土家族乡', 29.4306800, 110.6523700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15763, 'Sanguanmiao', 'Sanguanmiao', 'San-kuan-miao,Sanguanmiao,san guan miao,三官庙', 34.2548500, 109.4160000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15764, 'Sanguandian', 'Sanguandian', 'San-kuan-tien,Sanguandian,Sanguandian Jiedao,san guan dian,san guan dian jie dao,三官殿,三官殿街道', 32.5146300, 111.4844300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15765, 'Sangmu', 'Sangmu', 'Sang-mu-ch''ang,Sang-mu-ch’ang,Sangmu,Sangmu Zhen,sang mu,sang mu zhen,桑木,桑木镇', 28.2152800, 106.2688900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15766, 'Sangke', 'Sangke', 'La-sze,Sangke,Sangke Xiang,Sangkog,sang ke,sang ke xiang,桑科,桑科乡', 35.1249700, 102.4441100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15767, 'Sangengluo', 'Sangengluo', 'Sangengluo,Sangengluo Zhen,san geng luo,san geng luo zhen,三更罗,三更罗镇', 18.8630600, 110.1805100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15768, 'Sanduo', 'Sanduo', 'San-to,San-to-chen,Sanduo,Sanduo Zhen,Santowchen,san duo,san duo zhen,三垛,三垛镇', 32.8191700, 119.6598400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15769, 'Sandun', 'Sandun', 'San-tun,San-tun-chen,Sandun,Sandun Zhen,san dun,san dun zhen,三墩,三墩镇', 30.3247000, 120.0776300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15770, 'Sandu', 'Sandu', 'San-tu,Sandu,Sandu Zhen,san dou,san dou zhen,三都,三都镇', 29.5362000, 119.5703800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15771, 'Sandu', 'Sandu', 'San-tu,Sandu,Sandu Zhen,san dou,san dou zhen,三都,三都镇', 29.1746800, 114.6852300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15772, 'Sandu', 'Sandu', 'San-tu,San-tu-hsu,San-tu-hsü,Sandu,Sandu Zhen,san dou,san dou zhen,三都,三都镇', 28.5699200, 114.4463700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15773, 'Songqi', 'Songqi', 'San-fu-ao,San-tu,San-tu-ao,San-tu-tao,Sandu,Sandu Zhen,Santuao,Songqi,san dou,san dou zhen,song qi,三都,三都镇,松岐', 26.6388800, 119.6689800, 'CN', '2017-05-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15774, 'Sandouping', 'Sandouping', 'San-tou-p''ing,San-tou-p’ing,San-yu-p''ing,San-yu-p’ing,Sandouping,Sandouping Zhen,Santowping,san dou ping,san dou ping zhen,三斗坪,三斗坪镇', 30.8117000, 111.0150100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15775, 'Sandian', 'Sandian', 'San-tien,San-tien-chieh,San-tien-shih,Sandian,Sandian Jiedao,san dian,san dian jie dao,三店,三店街道', 30.9309300, 114.7919000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15776, 'Sandao', 'Sandao', 'Sandao,Sandao Zhen,san dao,san dao zhen,三道,三道镇', 18.4669900, 109.6643600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15777, 'Sanchang', 'Sanchang', 'San-ch''ang-shih,San-ch’ang-shih,Sanchang,Sanchang Zhen,san chang,san chang zhen,三厂,三厂镇', 31.8946800, 121.2410300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15778, 'Sanchakou', 'Sanchakou', '', 39.7844400, 117.3186100, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15779, 'Sankou', 'Sankou', 'Sanchakou,Sankou,Sankou Zhen,san kou,san kou zhen,三口,三口镇', 34.1833300, 119.4833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15780, 'Sanchagang', 'Sanchagang', 'San-ch''a-kang,San-ch’a-kang,Sanchagang,Sanchagang Zhen,san cha gang,san cha gang zhen,三汊港,三汊港镇', 29.2741800, 116.3909200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15781, 'Sancha', 'Sancha', 'San-ch''a-ho,San-ch’a-ho,Sancha,Sancha Zhen,san cha,san cha zhen,三岔,三岔镇', 36.0511000, 107.0454000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15782, 'Sancha', 'Sancha', 'San-ch''a-i,San-ch’a-i,Sancha,Sancha Zhen,san cha,san cha zhen,三岔,三岔镇', 33.8409700, 106.6721200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15783, 'Sancha', 'Sancha', 'Sancha,Sancha Xiang,san cha,san cha xiang,三岔,三岔乡', 30.2763200, 109.6215900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15784, 'Sancha', 'Sancha', 'Sancha,Sancha Xiang,san cha,san cha xiang,三岔,三岔乡', 29.0622200, 110.5644400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15785, 'Sancang', 'Sancang', 'San-ts''ang,San-ts''ang-ho,San-ts’ang,San-ts’ang-ho,Sancang,Sancang Zhen,san cang,san cang zhen,三仓,三仓镇', 32.7666700, 120.6666700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15786, 'Sanbao', 'Sanbao', 'San-p''u,San-p’u,Sanbao,Sanbao Zhen,Sanbu,san bao,san bao zhen,三堡,三堡镇', 38.5588900, 100.7775000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15787, 'Changsha', 'Changsha', 'Ch''ang-sha-chen,Changsha,Changsha Jiedao,Ch’ang-sha-chen,K''ai-p''ing-hsien,Kaiping,K’ai-p’ing-hsien,San-pu,San-pu-chen,Sanbu,kai ping,zhang sha,zhang sha jie dao,开平,长沙,长沙街道', 22.3812400, 112.6849200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15788, 'Sanbiao', 'Sanbiao', 'San-piao,Sanbiao,Sanbiao Xiang,san biao,san biao xiang,三标,三标乡', 25.0420800, 115.5902200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15789, 'Sanban', 'Sanban', 'San-pan,Sanban,Sanban Zhen,san ban,san ban zhen,三班,三班镇', 25.4506300, 118.2879800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15790, 'Ruyang Chengguanzhen', 'Ruyang Chengguanzhen', 'I-yang,I-yang-hsien,Ju-yang,Ruyang,Ruyang Chengguanzhen,ru yang cheng guan zhen,汝阳城关镇', 34.1502800, 112.4583300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15791, 'Ruxi', 'Ruxi', 'Ruxi,Ruxi Zhen,ru xi,ru xi zhen,汝溪,汝溪镇', 30.4985300, 108.0700100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15792, 'Rushanzhai', 'Rushanzhai', 'Ju-shan-chai,Rushanzhai,Rushanzhai Zhen,ru shan zhai,ru shan zhai zhen,乳山寨,乳山寨镇', 36.8849400, 121.4461400, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15793, 'Rushankou', 'Rushankou', 'Ju-shan-k''ou,Ju-shan-k’ou,Rushankou,Rushankou Zhen,ru shan kou,ru shan kou zhen,乳山口,乳山口镇', 36.8653700, 121.5072000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15794, 'Ruoshui', 'Ruoshui', 'Jo-shui,Ruoshui,Zhoshuy', 27.0019400, 109.9666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15795, 'Runzhen', 'Runzhen', 'Jun-chen,Runzhen,T''ung-jun-chen,Tunzhun''chzhen,Tunzhun’chzhen,T’ung-jun-chen,run zhen,闰镇', 34.8700000, 108.5075000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15796, 'Rende', 'Rende', 'Hsun-tien,Hsun-tien-hsien,Hsun-tien-hui-tsu-tzu-chih-hsien,Hsün-tien,Hsün-tien-hsien,Hsün-tien-hui-tsu-tzu-chih-hsien,Rende,Runde,Suntien-hsien,Suntienchow,Süntien-hsien,Xundian,ren de,仁德', 25.5582100, 103.2760400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15797, 'Runing', 'Runing', 'Ju-nan,Ju-nan-hsien,Juning,Runan,Runing,ru ning,汝宁', 33.0011100, 114.3541700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15798, 'Rulong', 'Rulong', 'Chan-hua,Chan-hua-hsien,Chzhankhua,Hsin-lung,Huai-jou,Khuayzhou,Nyagrong,Rulong,Rulong Zhen,Tan-hua,Wuxi,Xinlong,ru long,ru long zhen,茹龙,茹龙镇', 30.9411600, 100.3108700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15799, 'Rulin', 'Rulin', 'Ju-lin,Ju-ts''un-chen,Ju-ts’un-chen,Rulin,Rulin Zhen,ru lin,ru lin zhen,儒林,儒林镇', 31.5879000, 119.6178500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15800, 'Rulin', 'Rulin', 'Ch''eng-pu,Ch''eng-pu-hsien,Ch''eng-pu-miao-tsu-tzu-chih-hsien,Chenbu,Chengbu,Ch’eng-pu,Ch’eng-pu-hsien,Ch’eng-pu-miao-tsu-tzu-chih-hsien,Ju-lin-chen,Rulin,Zhulin''chzhen'',Zhulin’chzhen’,ru lin,儒林', 26.3470400, 110.2662700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15801, 'Ruixi', 'Ruixi', 'Ruixi,Ruixi Zhen,Ruixu,rui xi,rui xi zhen,瑞溪,瑞溪镇', 19.7344200, 110.1246100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15802, 'Ruishi', 'Ruishi', 'Jui-t''a-p''u,Jui-t’a-p’u,Ruishi,Ruitapu Zhen,rui shi,rui ta pu zhen,瑞塔铺镇,瑞市', 29.4186100, 110.2657500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15803, 'Ruilin', 'Ruilin', 'Jui-lin,Jui-lin-chai,Ruilin,Ruilin Zhen,rui lin,rui lin zhen,瑞林,瑞林镇', 26.1675300, 115.8417500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15804, 'Ruihong', 'Ruihong', 'Jui-hung,Jui-hung-chen,Ruihong,Ruihong Zhen,rui hong,rui hong zhen,瑞洪,瑞洪镇', 28.7303000, 116.4049000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15805, 'Guwei', 'Guwei', 'Guwei,Guwei Zhen,Jui-ch''eng,Jui-ch''eng-hsien,Jui-ch’eng,Jui-ch’eng-hsien,Ruicheng,Ruicheng Xian,Zhuychei,gu wei,gu wei zhen,rui cheng xian,古魏,古魏镇,芮城县', 34.7103400, 110.6571000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15806, 'Ruhu', 'Ruhu', 'Ch''i-ju-hu,Ch''i-nu,Ch''i-nu-hu,Ch''i-nu-hu-hsu,Ch’i-ju-hu,Ch’i-nu-hu-hsü,Ch’i-nü,Ch’i-nü-hu,Ju-hu,Ruhu,Ruhu Zhen,ru hu,ru hu zhen,汝湖,汝湖镇', 23.1833300, 114.4500000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15807, 'Rucheng', 'Rucheng', 'Ju-ch''eng-chen,Ju-ch’eng-chen,Ju-kao,Ju-kao-ch''eng,Ju-kao-ch’eng,Ju-kao-hsien,Rucheng,Rucheng Zhen,Rugao Shi,ru cheng,ru cheng zhen,ru gao shi,如城,如城镇,如皋市', 32.3883300, 120.5552800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15808, 'Rudong', 'Rudong', 'Rudong,Rudong Xiang,Rudongpu,ru dong,ru dong pu,ru dong xiang,如东,如东乡,如东铺', 29.7333300, 111.9833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15809, 'Rudong', 'Rudong', 'Ju-tung,Ju-tung-hsu,Ju-tung-hsü,Rudong,Rudong Zhen,Yutung,ru dong,ru dong zhen,儒洞,儒洞镇', 21.6000000, 111.4333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15810, 'Rucheng Chengguanzhen', 'Rucheng Chengguanzhen', 'Ju-ch''eng,Ju-ch''eng-hsien,Ju-ch’eng,Ju-ch’eng-hsien,Ju-kuei,Kuei-yang,Kweiyang,Kweiyanghsien,Rucheng,Rucheng Chengguanzhen,Rucheng Xian,Yu-ch''eng,Yu-ch’eng,ru cheng cheng guan zhen,ru cheng xian,汝城县,汝城城关镇', 25.5364100, 113.7154700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15811, 'Rucheng', 'Rucheng', 'Ju-yuan,Ju-yuan-ch''eng-kuan,Ju-yuan-hsien,Ju-yuan-hsien-ch''eng,Ju-yuan-yao-tsu-tzu-chih-hsien,Ju-yüan,Ju-yüan-ch’eng-kuan,Ju-yüan-hsien,Ju-yüan-hsien-ch’eng,Ju-yüan-yao-tsu-tzu-chih-hsien,Jui-yuan,Jui-yüan,Rucheng,Rucheng Zhen,Ruyuan,Yuyuan,Yuyuanhsien,Yuyüanhsien,ru cheng,ru cheng zhen,乳城,乳城镇', 24.7794500, 113.2702500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15812, 'Ru’ao', 'Ru''ao', 'Ju-ao,Ju-ao-shih,Ru''ao,Ru''ao Zhen,Ru’ao,Ru’ao Zhen,ru ao,ru ao zhen,儒岙,儒岙镇', 29.3594700, 120.9166300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15813, 'Rouyuan', 'Rouyuan', 'Hua-ch''ih,Hua-ch’ih,Huachi,Jou-yuan-ch''eng,Jou-yuan-ch''eng-tzu,Jou-yuan-li,Jou-yüan-ch’eng,Jou-yüan-ch’eng-tzu,Jou-yüan-li,Rouyuan,Rouyuan Zhen,Rouyuanchengzi,rou yuan,rou yuan zhen,柔远,柔远镇', 36.4609300, 107.9831100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15814, 'Rongxiang', 'Rongxiang', 'Jung-hsiang,Jung-hsiang-chen,Rongxiang,Rongxiang Jiedao,Tung-hsiang,rong xiang,rong xiang jie dao,荣巷,荣巷街道', 31.5576000, 120.2304500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15815, 'Rongwo', 'Rongwo', 'Longwu Zhen,Lung-wu,Lung-wu-chen,Lung-wu-ssu,Rongwo,T''ung-jen,T''ung-jen-hsien,Tongren,Tongren Xian,Tunzhen'',Tunzhen’,T’ung-jen,T’ung-jen-hsien,long wu,long wu zhen,tong ren,tong ren xian,同仁,同仁县,隆务,隆务镇', 35.5148300, 102.0160000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15816, 'Rongshui', 'Rongshui', 'Chiu-jung-hsien,Jung,Jung-hsien,Jung-shui,Jung-shui-chen,Jung-shui-hsien,Rongshui,Ta-miao-shan,Ta-miao-shan-miao-tsu-tzu-chih-ch''u,Ta-miao-shan-miao-tsu-tzu-chih-ch’ü,rong shui,融水', 25.0666700, 109.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15817, 'Ronggui', 'Ronggui', 'Guizhou,JUNGKI,Jung-ch''i,Jung-ch’i,Kuei-chou,Kwaichow,Kweichow,Ronggui,Ronggui Jiedao,Rongqi,rong gui,rong gui jie dao,容桂,容桂街道', 22.7625900, 113.2518000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15818, 'Rongmei', 'Rongmei', 'Hao-feng,Hao-feng-hsien,Hefeng,Hefeng Xian,Ho-feng,Hofeng-hsien,Rongmei,Rongmei Zhen,he feng,he feng xian,rong mei,rong mei zhen,容美,容美镇,鹤峰,鹤峰县', 29.8933300, 110.0261100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15819, 'Ronglong', 'Ronglong', 'Jung-lung-ch''ang,Jung-lung-ch’ang,Ronglong,Ronglong Zhen,Ronglongchang,rong long,rong long zhen,荣隆,荣隆镇', 29.4358900, 105.4486500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15820, 'Rongkou', 'Rongkou', 'Jung-k''ou,Jung-k’ou,Rongkou,Rongkou Xiang,rong kou,rong kou xiang,溶口,溶口乡', 29.7454000, 117.5410300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15821, 'Rongjiawan', 'Rongjiawan', 'Jung-chia-wan,Jungchiangwan,Jungkiawan,Rongjiawan,Yueyang,Yueyang Xian,rong jia wan,yue yang xian,岳阳县,荣家湾', 29.1500000, 113.1024300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15822, 'Rongjiang', 'Rongjiang', 'Nan-k''ang-hsien,Nan-k’ang-hsien,Nankang,Nankang Shi,Nankung,Rongjiang,nan kang shi,rong jiang,南康市,蓉江', 25.6624700, 114.7503400, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15823, 'Rongcheng', 'Rongcheng', 'Ch''ing-yang,Ch''ing-yang-hsien,Ch’ing-yang,Ch’ing-yang-hsien,Qingyang,Qingyang Xian,Rongcheng,Tsingyang,Tsingyanghsien,qing yang xian,rong cheng,蓉城,青阳县', 30.6428100, 117.8351500, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15824, 'Fuqing', 'Fuqing', 'Fu-ch''ing,Fu-ch''ing-hsien,Fu-ch''ing-hsien-ch''eng,Fu-ch’ing,Fu-ch’ing-hsien,Fu-ch’ing-hsien-ch’eng,Fucin'',Fuqing,Futsing,Putsinghsien,Rongcheng,Фуцинь', 25.7250000, 119.3794400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15825, 'Jieyang', 'Jieyang', 'Chieh-yang,Chieh-yang-hsien,Chieh-yung,Chien Yang,Czejan,Giek-iong,Giék-iòng,Jieyang,Kiat-iong-chhi,Kiat-iông-chhī,Kiehyang,Kityang,Kityang-hsien,Rongcheng,SWA,Tie-jang,Yet Duong,Yết Dương,jie yang,jie yang shi,jieyang si,jy yang,jyyyang,Ťie-jang,Цзеян,جی یانگ,جیئیانگ,جیه‌یانگ,掲陽市,揭阳,揭阳市,揭陽,지에양 시', 23.5418000, 116.3658100, 'CN', '2014-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15826, 'Rongcheng', 'Rongcheng', 'Jung,Jung-ch''eng-chen,Jung-ch’eng-chen,Jung-hsien,Jung-yun,Jung-yün,Rongcheng,Rongcheng Zhen,Rongxian,Rongzhou,Yung-hsien,rong cheng,rong cheng zhen,rong zhou,容城,容城镇,容州', 22.8584200, 110.5464300, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15827, 'Rizhao', 'Rizhao', 'Donggang,Jichaohsien,Jih-chao,Jih-chao-hsien,Rijao,Rizhao,Rizhao Jiedao,dong gang,ri zhao,ri zhao jie dao,ri zhao shi,东港,日照,日照市,日照街道', 35.4275000, 119.4552800, 'CN', '2014-04-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15828, 'Rixinhe', 'Rixinhe', 'Jih-hsin-chen,Jih-hsing-chen,Rixinhe,Rixinzhen,Shaozhi,Shaozhi Zhen,ri xin he,shao zhi,shao zhi zhen,少直,少直镇,日新河', 31.9225000, 121.6797200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15829, 'Rixi', 'Rixi', 'Rixi,Rixi Xiang,ri xi,ri xi xiang,日溪,日溪乡', 26.3501400, 119.2721700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15830, 'Rifeng', 'Rifeng', 'Hsin-ch''eng,Hsin-ch’eng,Li-ch''uan-hsien,Li-ch’uan-hsien,Lichuan,Lichuan Xian,Lichwan,Lichwan-hsien,Rifeng,Rifeng Zhen,Sincheng,li chuan xian,ri feng,ri feng zhen,日峰,日峰镇,黎川县', 27.2972800, 116.9110700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15831, 'Ridong', 'Ridong', 'Jih-tung,Ridong,Ridong Xiang,ri dong,ri dong xiang,日东,日东乡', 25.9839200, 116.2700900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15832, 'Reshi', 'Reshi', 'Je-Shih,Reshi,Reshi Zhen,Reshuikeng,re shi,re shi zhen,re shui keng,热市,热市镇,热水坑', 29.3213700, 111.3224800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15833, 'Renzhuang', 'Renzhuang', 'Jen-chuang,Jen-chuang-ts''un,Jen-chuang-ts’un,Renzhuang,Renzhuang Zhen,ren zhuang,ren zhuang zhen,仁庄,仁庄镇', 28.0452800, 120.2475600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15834, 'Renyi', 'Renyi', 'Jen-i-ch''ang,Jen-i-ch’ang,Renyi,Renyi Zhen,Renyichang,ren yi,ren yi zhen,仁义,仁义镇', 29.5074300, 105.4782700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15835, 'Renxian', 'Renxian', 'Jen-hsien,Renxian,Renxian Zhen,Shahepu,ren xian,ren xian zhen,sha he pu,仁贤,仁贤镇,沙河铺', 30.6609200, 107.6789500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15836, 'Rentian', 'Rentian', 'Jen-t''ien,Jen-t’ien,Rentian,Rentian Zhen,ren tian,ren tian zhen,壬田,壬田镇', 25.9872700, 116.1166100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15837, 'Renshan', 'Renshan', 'Jen-shan,Jen-shan-hsu,Jen-shan-hsü,Nien-shan,Nimshan,Renshan,Renshan Zhen,ren shan,ren shan zhen,稔山,稔山镇', 22.8359900, 114.8048700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15838, 'Renqiu', 'Renqiu', 'Jen-ch''iu,Jen-ch''iu-ch''eng-kuan,Jen-ch''iu-hsien,Jen-ch’iu,Jen-ch’iu-ch’eng-kuan,Jen-ch’iu-hsien,Jenkiu,Jenkiuhsien,Renqiu,Zhen''tsyu,Zhen’tsyu,ren qiu shi,任丘市', 38.6988900, 116.0936100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15839, 'Renju', 'Renju', 'Jen-chu,Jen-chü,Renju,Renju Zhen,ren ju,ren ju zhen,仁居,仁居镇', 24.8170200, 115.8831100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15840, 'Renhua', 'Renhua', 'Jen-hua,Jen-hua-hsien,Renhua,Yanfa,Yanfa-hsien,ren hua,仁化', 25.0912500, 113.7444600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15841, 'Renheping', 'Renheping', 'Jen-ho-p''ing,Jen-ho-p’ing,Renheping,Renheping Zhen,ren he ping,ren he ping zhen,仁和坪,仁和坪镇', 30.1022200, 111.2366900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15842, 'Renhe', 'Renhe', 'Jen-ho-chi,Renhe,Renhe Zhen,Renheji,ren he,ren he zhen,人和,人和镇', 36.8908200, 122.2999800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15843, 'Renhe', 'Renhe', 'Jen-ho,Renhe,Renhe Jiedao,ren he,ren he jie dao,人和,人和街道', 29.6245100, 106.5255700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15844, 'Renhe', 'Renhe', 'Jen-ho,Jen-ho-hsu,Jen-ho-hsü,Renhe,Renhe Zhen,ren he,ren he zhen,仁和,仁和镇', 27.6565700, 115.2603600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15845, 'Renhe', 'Renhe', 'Jen-ho,Jen-ho-chen,Jen-ho-chieh,Jenhokai,Renhe,Yung-jen,Yung-jen Old City,ren he,仁和', 26.4992600, 101.7386100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15846, 'Renfengzhuang', 'Renfengzhuang', 'Jen-feng-chuang,Renfengzhuang', 39.3113900, 117.6622200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15847, 'Rencun', 'Rencun', 'Rencun,Rencun Zhen,ren cun,ren cun zhen,稔村,稔村镇', 22.6594800, 112.3662600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15848, 'Renchaoxi', 'Renchaoxi', 'Jen-ch''ao-ch''i,Jen-ch''ao-hsi,Jen-ch’ao-ch’i,Jen-ch’ao-hsi,Renchaoxi,Rengchaoxi Xiang,ren chao xi,ren chao xi xiang,人潮溪,人潮溪乡', 29.6089800, 110.5856700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15849, 'Raoshi', 'Raoshi', 'Jao-p''o-ch''iao,Jao-p’o-ch’iao,Jao-shih,Jao-shih-ch''iao,Jao-shih-ch’iao,Raoshi,Raoshi Xiang,rao shi,rao shi xiang,遶市,遶市乡', 27.8500500, 114.1432300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15850, 'Ranghe', 'Ranghe', 'Jang-ho,Jang-ho-chen,Jangho Cheno,Kun-ho,Ranghe,rang he,瀼河', 33.6922300, 112.8508200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15851, 'Quzi', 'Quzi', 'Ch''u-tzu,Ch''u-tzu-chen,Ch’u-tzu-chen,Ch’ü-tzu,Huan,Huan-hsien,Quzi,Quzi Zhen,Tsyuytszochzhen,Tsyuytszöchzhen,qu zi,qu zi zhen,曲子,曲子镇', 36.2932300, 107.5120400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15852, 'Quzi', 'Quzi', 'Ch''u-tzu,Ch’ü-tzu,Liu-tzu,Quzi,qu zi,渠子', 34.8656500, 108.1876500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15853, 'Quzhou', 'Quzhou', 'Cchue-cou,Ch''u,Ch''u-chou,Ch''u-hsien,Ch''u-hsien-ch''eng,Chu-chow,Chuchowfu,Ch’ü,Ch’ü-chou,Ch’ü-hsien,Ch’ü-hsien-ch’eng,Cjujchzhou,Cu Chau,Cù Châu,Gu-ciu,Gṳ̀-ciŭ,JUZ,Ku-chiu-chhi,Kû-chiu-chhī,Quxian,Quzhou,chwijeou si,chywzhww,kw zhw,kwjaw,qu zhou,qu zhou shi,Čchü-čou,Цюйчжоу,كو زهو,چیوژوو,کوجاو,衢州,衢州市,취저우 시', 28.9594400, 118.8686100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15854, 'Quyangqiao', 'Quyangqiao', 'Ch''u-yang,Ch''u-yang-ch''iao-chen,Ch''u-yang-chi,Ch''u-yang-chiao,Ch’ü-yang,Ch’ü-yang-chi,Ch’ü-yang-chiao,Ch’ü-yang-ch’iao-chen,Quyangqiao,Quyangqiao Xiang,Tsuyangchi,qu yang qiao,qu yang qiao xiang,曲阳桥,曲阳桥乡', 38.2370500, 114.4773700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15855, 'Quyang', 'Quyang', 'Ching,Ching-chou,Ching-hsien,Ching-hsien-ch''eng,Ching-hsien-ch’eng,Jingxian,Quyang,Tsingchow,Tsinghsien,Tszinsyan'',Tszinsyan’,qu yang,渠阳', 26.5750700, 109.6380800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15856, 'Quxia', 'Quxia', 'Ch''u-hsia-chen,Ch’ü-hsia-chen,Hsia-ma-yu,Hsia-ma-yu-chen,Hsia-ma-yü,Hsia-ma-yü-chen,Hsia-mu-yu,Hsia-mu-yü,Quxia,Quxia Zhen,qu xia,qu xia zhen,曲霞,曲霞镇', 32.1003700, 120.1569800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15857, 'Quxi', 'Quxi', 'Quxi,Quxi Xiang,qu xi,qu xi xiang,曲溪,曲溪乡', 25.6537600, 116.9151700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15858, 'Quxi', 'Quxi', 'Quxi,Quxi Jiedao,qu xi,qu xi jie dao,曲溪,曲溪街道', 23.5713400, 116.4315200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15859, 'Lechang', 'Lechang', 'Ch''iu-ch''u-wo,Ch''u-wu,Ch''u-wu-hsien,Ch’iu-ch’ü-wo,Ch’ü-wu,Ch’ü-wu-hsien,Kuwo,Kuwohsien,Küwo,Lechang,Lechang Zhen,Quwo Xian,Tsyuyvo,le chang,le chang zhen,qu wo xian,乐昌,乐昌镇,曲沃县', 35.6420100, 111.4672200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15860, 'Qutang', 'Qutang', 'Ch''u-t''ang,Ch''u-t''ang-chen,Ch’ü-t’ang,Ch’ü-t’ang-chen,Kutang,Qutang,Qutang Zhen,qu tang,qu tang zhen,曲塘,曲塘镇', 32.4964100, 120.3270800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15861, 'Qushui', 'Qushui', 'Ch''u-shui,Ch''u-shui-ch''ang,Ch’ü-shui,Ch’ü-shui-ch’ang,Qushui,Qushui Xiang,qu shui,qu shui xiang,曲水,曲水乡', 30.6831600, 108.0205300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15862, 'Qunke', 'Qunke', 'Gucheng,Qunke,Qunke Zhen,gu cheng,qun ke,qun ke zhen,古城,群科,群科镇', 36.0487500, 101.9820500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15863, 'Qulai', 'Qulai', 'Ch''u-lai,Ch’ü-lai,Qulai,Qulai Xiang,qu lai,qu lai xiang,曲濑,曲濑乡', 27.0596600, 114.8604500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15864, 'Qihama', 'Qihama', 'Qihama,Qihama Xiang,Qukama,qi ha ma,qi ha ma xiang,齐哈玛,齐哈玛乡', 33.3813200, 101.9855100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15865, 'Qujing', 'Qujing', 'Cchue-ting,Ch''u-ching,Ch''u-ching-hsien,Chiu-ch''u-ching,Chiu-ch’ü-ching,Ch’ü-ching,Ch’ü-ching-hsien,Cjujczin,Khiok-cheng-chhi,Khiok-chēng-chhī,Khuc Tinh,Khúc Tĩnh,Ku-tsing-fu,Kuoh-ceng,Kutsing,Kutsinghsien,Kuóh-cêng,Kü-tsing-fu,Kütsing,Nan-ning,Qujing,Qujing Hiria,chu cing,chwijing si,chwjng,qu jing,qu jing shi,Čchü-ťing,Цюйцзин,چوجنگ,ฉู่จิ้ง,曲靖,曲靖市,취징 시', 25.4833300, 103.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15866, 'Qujie', 'Qujie', 'Ch''u-chieh,Ch''u-chieh-shih,Ch’ü-chieh,Ch’ü-chieh-shih,Kukkai,Kükkai,Qujie,Qujie Zhen,qu jie,qu jie zhen,曲界,曲界镇', 20.4855600, 110.3255600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15867, 'Qujiang', 'Qujiang', 'Ch''u,Ch''u-hsien,Ch’ü,Ch’ü-hsien,Qujiang,Quxian,Tsyuysyan'',Tsyuysyan’,qu jiang,渠江', 30.8420600, 106.9678500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15868, 'Qujiang', 'Qujiang', 'Ch''u-chiang,Ch''u-chiang-chen,Ch’ü-chiang,Ch’ü-chiang-chen,Qujiang,Qujiang Zhen,qu jiang,qu jiang zhen,曲江,曲江镇', 28.2471500, 115.7909700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15869, 'Qufu', 'Qufu', 'Cchue-fu,Ch''u-fou,Ch''u-fou-hsien,Ch''u-fou-hsien-ch''eng,Ch''u-fu-hsien,Chu-fu,Chü-fu,Ch’u-fu-hsien,Ch’ü-fou,Ch’ü-fou-hsien,Ch’ü-fou-hsien-ch’eng,Cjujfu,Csuefu,Csüfu,Khuc Phu,Khúc Phụ,Kinfowhsien,Kufow,Küfow,Qufu,chwipu si,cufu,cuphu,qu fu shi,qwfw,tshywfw,tsiuipu,zwpw,Čchü-fu,Цюйфу,צופו,تشيوفو,قوفو,चूफ़ू,ചൂഫു,ციუიფუ,ጩፉ,曲阜市,취푸 시', 35.5966700, 116.9911100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15870, 'Panlong', 'Panlong', 'Ch''ueh-shan,Ch''ueh-shan-hsien,Chiu-shan,Ch’üeh-shan,Ch’üeh-shan-hsien,Kioshan,Kioshan-hsien,Panlong,Queshan,pan long,盘龙', 32.8022200, 114.0191700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15871, 'Qucun', 'Qucun', 'Ch''u-ts''un,Ch''u-ts''un-chen,Ch’ü-ts’un,Ch’ü-ts’un-chen,Qucun,Qucun Zhen,qu cun,qu cun zhen,曲村,曲村镇', 35.7333400, 111.5450300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15872, 'Quanzhou', 'Quanzhou', 'Ch''uan,Ch''uan-chou,Ch''uan-chou-chen,Ch''uan-hsien,Ch''uan-hsien-ch''eng,Chuanchow,Ch’üan,Ch’üan-chou,Ch’üan-chou-chen,Ch’üan-hsien,Ch’üan-hsien-ch’eng,Quanzhou,quan zhou,全州', 25.9445900, 111.0363900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15873, 'Quanzhou', 'Quanzhou', 'Cchuean-cou,Ch''uan-chou,Ch''uan-chou-shih,Chhien-chu-su,Chhièn-chû-sṳ,Chin-chiang,Chin-chiang-hsien,Chinchew,Chinchu,Choan-chiu-chhi,Chuanchowfu,Chueenju shehiri,Chôan-chiu-chhī,Chüanchowfu,Chüenju shehiri,Ch’üan-chou,Ch’üan-chou-shih,Ciong-ciu,Ciuandzou,Ciòng-ciŭ,Cjuan''chzhou,JJN,Quantsjou,Quanzhou,Tsin-chiang,Tsingkianghsien,Tsinkiang,Tuyen Chau,Tuyền Châu,Zaitun,Zayton,che wiyn cow,chwanzhw,chwianjeou si,chwynzhw,kwanzhw,quan zhou,quan zhou shi,tshwantshw,Čchüan-čou,Čiuandžou,Цюаньчжоу,تشوانتشو,چوئنژو,چوانژو,کوانژو,เฉวียนโจว,泉州,泉州市,취안저우 시', 24.9138900, 118.5858300, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15874, 'Quanzhai', 'Quanzhai', 'Ch''uan-chai,Ch’üan-chai,Kuan-chai,Quanzhai,Quanzhai Zhen,quan zhai,quan zhai zhen,权寨,权寨镇', 33.4424600, 113.8583600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15875, 'Quanxi', 'Quanxi', 'Ch''uan-hsi,Ch’üan-hsi,Quanxi,Quanxi Zhen,quan xi,quan xi zhen,泉溪,泉溪镇', 32.0345200, 109.6903300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15876, 'Quanshang', 'Quanshang', 'Ch''uan-shang,Ch’üan-shang,Quanshang,Quanshang Zhen,quan shang,quan shang zhen,泉上,泉上镇', 26.4192200, 116.9623600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15877, 'Chengxiang', 'Chengxiang', 'Ch''eng-hsiang-chen,Ch''ien-nan-hsien,Ch''uan-nan,Chengxiang,Chengxiang Zhen,Ch’eng-hsiang-chen,Ch’ien-nan-hsien,Ch’üan-nan,Kien-nan,Kiennan-hsien,Quannan Xian,cheng xiang,cheng xiang zhen,quan nan xian,全南县,城厢,城厢镇', 24.7463600, 114.5249100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15878, 'Quankou', 'Quankou', 'Quankou,Quankou Tujiazu Xiang,quan kou,quan kou tu jia zu xiang,泉口,泉口土家族乡', 28.5507300, 108.1363800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15879, 'Quanjiang', 'Quanjiang', 'Lung-ch''uan,Lung-ch’uan,Quanjiang,Sui-ch''uan-hsien,Sui-ch’uan-hsien,Suichuan,Suichuan Xian,Suichwan,Suichwan-hsien,quan jiang,sui chuan xian,泉江,遂川县', 26.3095500, 114.5129200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15880, 'Quangang', 'Quangang', 'Ch''uan-chiang,Ch''uan-chiang-chieh,Ch’üan-chiang,Ch’üan-chiang-chieh,Quangang,Quangang Zhen,quan gang,quan gang zhen,泉港,泉港镇', 28.1559400, 115.5965800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15881, 'Qizili', 'Qizili', 'Ch''i-tzu-li,Ch’i-tzu-li,Qizili,Qizili Zhen,qi zi li,qi zi li zhen,杞梓里,杞梓里镇', 30.0017000, 118.7405800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15882, 'Qizhou', 'Qizhou', 'Ch''i-ch''un,Ch''i-ch''un-hsien,Ch''i-chou,Ch’i-chou,Ch’i-ch’un,Ch’i-ch’un-hsien,Kichau,Kichow,Kichow-fu,Kichowhup,Kichun,Kichun-hsien,Qizhou,Qizhou Zhen,qi zhou,qi zhou zhen,蕲州,蕲州镇', 30.0666700, 115.3333300, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15883, 'Qizhen', 'Qizhen', 'Ch''i-chen,Ch''i-chia-chai,Ch’i-chen,Ch’i-chia-chai,Qizhen,Tsitszyachay,qi zhen,齐镇', 34.2106200, 107.7136000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15884, 'Qiying', 'Qiying', 'Ch''i-ying,Ch’i-ying,Qiying,Qiying Zhen,qi ying,qi ying zhen,七营,七营镇', 36.5032400, 106.1486200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15885, 'Wuxi', 'Wuxi', 'Ch''i-yang,Ch''i-yang-ch''eng,Ch''i-yang-hsien,Ch’i-yang,Ch’i-yang-ch’eng,Ch’i-yang-hsien,Kiyang,Kiyang-hsien,Qiyang,Wuxi,Wuxi Zhen,wu xi,wu xi zhen,浯溪,浯溪镇', 26.5844000, 111.8590000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15886, 'Qixia', 'Qixia', 'Ch''i-hsia,Ch''i-hsia-chieh,Ch''i-hsia-shan,Ch’i-hsia,Ch’i-hsia-chieh,Ch’i-hsia-shan,Hsi-hsia-shan,Qixia,Qixia Jiedao,Qixiashan,qi xia,qi xia jie dao,栖霞,栖霞街道', 32.1387000, 118.9420400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15887, 'Zhaoyu', 'Zhaoyu', 'Ch''i,Ch''i-hsien,Ch''i-hsien-ch''eng,Ch’i,Ch’i-hsien,Ch’i-hsien-ch’eng,Kihsien,Qi Xian,Qixian,Zhaoyu,Zhaoyu Zhen,qi xian,zhao yu,zhao yu zhen,昭余,昭余镇,祁县', 37.3552800, 112.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15888, 'Qi Xian Chengguanzhen', 'Qi Xian Chengguanzhen', 'Ch''i,Ch''i-hsien,Ch’i,Ch’i-hsien,Kihsien,Qi Xian Chengguanzhen,Qixian,qi xian cheng guan zhen,杞县城关镇', 34.5500000, 114.7833300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15889, 'Zhuangyuan', 'Zhuangyuan', 'Ch''i-hsia,Ch''i-hsia-hsien,Ch’i-hsia,Ch’i-hsia-hsien,Qixia,Qixia Shi,Tsisia,Zhuangyuan,qi xia shi,zhuang yuan,庄园,栖霞市', 37.3055300, 120.8274700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15890, 'Qiuxi', 'Qiuxi', 'Qiuxi,Qiuxi Zhen,qiu xi,qiu xi zhen,秋溪,秋溪镇', 27.8487700, 116.2717900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15891, 'Qiulu', 'Qiulu', 'Qiulu,Qiulu Zhen,qiu lu,qiu lu zhen,萩芦,萩芦镇', 25.5264400, 119.0888100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15892, 'Qiukou', 'Qiukou', 'Ch''iu-k''ou,Ch’iu-k’ou,Qiukou,Qiukou Zhen,qiu kou,qiu kou zhen,秋口,秋口镇', 29.3470100, 117.8996400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15893, 'Qiujin', 'Qiujin', 'Ch''iu-chin,Ch''iu-ching,Ch''iu-ching-chieh,Chiu-ching-shih,Ch’iu-chin,Ch’iu-ching,Ch’iu-ching-chieh,Qiujin,Qiujin Zhen,qiu jin,qiu jin zhen,虬津,虬津镇', 29.1694400, 115.6789500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15894, 'Qiucun', 'Qiucun', 'Ch''iu-ts''un,Ch''iu-ts''un-chen,Ch''iu-ts''un-ling,Ch’iu-ts’un,Ch’iu-ts’un-chen,Ch’iu-ts’un-ling,Qiucun,Qiucun Zhen,qiu cun,qiu cun zhen,裘村,裘村镇', 29.6044400, 121.6213900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15895, 'Qiuchuan', 'Qiuchuan', 'Ch''iu-ch''uan,Ch''iu-chuan-chen,Ch’iu-chuan-chen,Ch’iu-ch’uan,Qiuchuan,Qiuchuan Zhen,qiu chuan,qiu chuan zhen,球川,球川镇', 28.8666700, 118.3166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15896, 'Qiu’ai', 'Qiu''ai', 'Ch''iu-ai,Ch''iu-chieh,Ch''iu-i,Ch''iu-yai,Ch''iu-yai-chen,Ch’iu-ai,Ch’iu-chieh,Ch’iu-i,Ch’iu-yai,Ch’iu-yai-chen,Qiu''ai,Qiu''ai Zhen,Qiu’ai,Qiu’ai Zhen,Yin-hsien,qiu ai,qiu ai zhen,邱隘,邱隘镇', 29.8519800, 121.6316100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15897, 'Qiting', 'Qiting', 'Ch''i-t''ing-ch''iao,Ch''i-t''ing-ch''iao-chen,Ch’i-t’ing-ch’iao,Ch’i-t’ing-ch’iao-chen,Hsien-t''ing-ch''iao-chen,Hsien-ting-ch''iao,Hsien-ting-ch’iao,Hsien-t’ing-ch’iao-chen,Qiting,Qiting Jiedao,Qitingqiao,qi ting,qi ting jie dao,屺亭,屺亭街道', 31.4367700, 119.8601300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15898, 'Qiting', 'Qiting', 'Ch''i-t''ing,Ch’i-t’ing,Kiting,Qiting,Qiting Zhen,qi ting,qi ting zhen,岐亭,岐亭镇', 31.0142300, 114.7422300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15899, 'Qitao', 'Qitao', 'Ch''i-t''ao,Ch’i-t’ao,Qitao,Qitao Xiang,qi tao,qi tao xiang,七套,七套乡', 34.1666700, 119.8500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15900, 'Qitan', 'Qitan', 'Ch''i-t''an,Ch’i-t’an,Qitan,Qitan Zhen,qi tan,qi tan zhen,淇滩,淇滩镇', 28.4804600, 108.4557200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15901, 'Qishuyan', 'Qishuyan', 'Ch''i-shu,Ch''i-shu-yen,Ch''i-shu-yen-chen,Ch’i-shu,Ch’i-shu-yen,Ch’i-shu-yen-chen,Qishuyan,Qishuyan Jiedao,Shu Ch''ang-chou-shih,Shu Ch’ang-chou-shih,Tsihuyen,qi shu yan,qi shu yan jie dao,戚墅堰,戚墅堰街道', 31.7280000, 120.0543800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15902, 'Qishui', 'Qishui', 'Ch''i-shui,Ch’i-shui,Qishui,Qishui Zhen,qi shui,qi shui zhen,企水,企水镇', 20.7539800, 109.7781300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15903, 'Qishi', 'Qishi', 'Ch''i-shih,Ch’i-shih,Qishi,Qishi Zhen,qi shi,qi shi zhen,企石,企石镇', 23.0723600, 114.0220900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15904, 'Qiqin', 'Qiqin', 'Ch''i-ch''in,Ch''i-ch''in-chieh,Ch’i-ch’in,Ch’i-ch’in-chieh,Qiqin,Qiqin Zhen,qi qin,qi qin zhen,七琴,七琴镇', 27.7056900, 115.6050900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15905, 'Qiqiao', 'Qiqiao', 'Ch''i-ch''iao,Ch’i-ch’iao,Qiqiao,Qiqiao Zhen,qi qiao,qi qiao zhen,漆桥,漆桥镇', 31.3879800, 118.9871000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15906, 'Qiping', 'Qiping', 'Ch''i-p''ing,Ch''i-p''ing-ao,Ch’i-p’ing,Ch’i-p’ing-ao,Qiping,Qiping Zhen,qi ping,qi ping zhen,棋坪,棋坪镇', 28.6654900, 114.2044100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15907, 'Qiping', 'Qiping', 'Ch''i-p''ing,Ch’i-p’ing,Qiping,Qiping Miaozu Xiang,qi ping,qi ping miao zu xiang,棋坪,棋坪苗族乡', 28.4333300, 110.1833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15908, 'Qiongshan', 'Qiongshan', 'Ch''iung-chou,Ch''iung-shan,Ch''iung-shan-hsien,Ch’iung-chou,Ch’iung-shan,Ch’iung-shan-hsien,Hoihow,Kiung chow fu,Kiungchow,Kiungshan,Kiungshan-hsien,Qiongshan,Qiongzhou', 20.0058300, 110.3541700, 'CN', '2013-10-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15909, 'Qiongxi', 'Qiongxi', 'Ha-la-ma,Hongyuan,Hung-yuan,Hung-yüan,Hurama,Li Hsien,Qiongxi,qiong xi,邛溪', 32.7927200, 102.5429300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15910, 'Qionghu', 'Qionghu', 'Qionghu,Yuan-chiang,Yuan-chiang-hsien,Yuanjiang Shi,Yuankiang,Yuankiang-hsien,Yuen Kong,Yüan-chiang,Yüan-chiang-hsien,Yüankiang,Yüankiang-hsien,qiong hu,yuan jiang shi,沅江市,琼湖', 28.8406100, 112.3739900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15911, 'Qinzhou', 'Qinzhou', 'Cchin-cou,Ch''in,Ch''in-chou,Ch''in-chou-chen,Ch''in-chou-chuang-tsu-tzu-chih-hsien,Ch''in-hsien,Chinchow,Ch’in,Ch’in-chou,Ch’in-chou-chen,Ch’in-chou-chuang-tsu-tzu-chih-hsien,Ch’in-hsien,Cin''chzhou,Ginhcouh,Kham Chau,Khim-chiu-chhi,Khim-chiu-chhī,Khim-chu-su,Khâm Châu,Khîm-chû-sṳ,King-ciu,Kĭng-ciŭ,Qinzhou,Yamchow,Yamhsien,chinjeou si,chnzhww,kynzhw,qin zhou,qin zhou shi,Čchin-čou,Циньчжоу,چنژوؤ,چنژوو,کینژو,欽州,欽州市,钦州,钦州市,친저우 시', 21.9729600, 108.6261200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15912, 'Qinzao', 'Qinzao', 'Ch''in-tsao,Ch''in-tsao-chen,Ch’in-tsao,Ch’in-tsao-chen,Qinzao,Qinzao Jiedao,Qinzao Zhen,qin zao,qin zao jie dao,qin zao zhen,秦灶,秦灶街道,秦灶镇', 32.0638300, 120.8621600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15913, 'Qinhe', 'Qinhe', 'Ch''in-yuan,Ch''in-yuan-hsien,Ch’in-yüan,Ch’in-yüan-hsien,Qinhe,Qinhe Zhen,Qinyuan,Qinyuan Xian,Tsin''yuan'',Tsin’yuan’,qin he,qin he zhen,qin yuan xian,沁河,沁河镇,沁源县', 36.5013900, 112.3247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15914, 'Tanbei', 'Tanbei', 'Ch''in-yang,Ch''in-yang-hsien,Ch’in-yang,Ch’in-yang-hsien,Huai-ching,Hwai-king-fu,Hwaiking,Qinyang,Tanbei,Tsinyang-hsien,qin bei,覃杯', 35.0880600, 112.9394400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15915, 'Dingchang', 'Dingchang', 'Ch''in-hsien,Ch’in-hsien,Dingchang,Dingchang Zhen,Qin Xian,Qinxian,ding chang,ding chang zhen,qin xian,定昌,定昌镇,沁县', 36.7630600, 112.6872200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15916, 'Qintong', 'Qintong', 'Ch''in-t''ung,Ch''in-t''ung-chen,Chen-t''ung,Chen-t''ung-chen,Chen-t’ung,Chen-t’ung-chen,Ch’in-t’ung,Ch’in-t’ung-chen,Qintong,Qintong Zhen,Tsintung,qin tong,qin tong zhen,溱潼,溱潼镇', 32.6496900, 120.0923400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15917, 'Qinting', 'Qinting', 'Lianhua,Lianhua Xian,Lien-hua,Lien-hua-chen,Lien-hua-hsien,Lienhwa,Lienhwa-hsien,Qinshui,Qinting,lian hua xian,qin ting,琴亭,莲花县', 27.1241200, 113.9490200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15918, 'Longgang', 'Longgang', 'Ch''in-shui,Ch''in-shui-hsien,Ch’in-shui,Ch’in-shui-hsien,Longgang,Longgang Zhen,Qinshui,Qinshui Xian,Tsin''shuy,Tsin’shuy,long gang,long gang zhen,qin shui xian,沁水县,龙港,龙港镇', 35.6894100, 112.1579800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15919, 'Qinnan', 'Qinnan', 'Ch''in-nan,Ch''in-nan-ts''ang,Qinnancang', 33.2530600, 119.9133300, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15920, 'Qinlan', 'Qinlan', 'Ch''in-lan,Ch''in-lan-chen,Ch’in-lan,Ch’in-lan-chen,Qinlan,Qinlan Zhen,qin lan,qin lan zhen,秦栏,秦栏镇', 32.6014200, 119.1664100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15921, 'Qinhuangdao', 'Qinhuangdao', 'BPE,Cchin-chuang-tao,Ch''in-huang-tao,Ch''in-huang-tao-shih,Chin-hong-to-chhi,Ching Wang Tao,Chinwangtao,Chinxuangdaw shehiri,Chîn-hông-tó-chhī,Ch’in-huang-tao,Ch’in-huang-tao-shih,Cin''khuandao,Cing-huong-do,Cinhuangdao,Cinhuangdauo,Cinkhuandao,Cinkhuangdao,Cjinhuandao,Cjiņhuandao,Cìng-huòng-dō̤,Qinhuangdao,Qínhuángdǎo,SHP,Tan Hoang GJao,Tần Hoàng Đảo,chinhwangdao si,kynghwangdaw,qin huang dao,qin huang dao shi,tshnhwanghdaw,Ĉinhŭangdaŭo,Čchin-chuang-tao,Činhuangdao,Ћинхуангдао,Цинхуандао,Циньхуандао,Ціньхуандао,تشنهوانغداو,چینہوانگداو,کینگهوانگداو,秦皇岛,秦皇岛市,秦皇島,秦皇島市,친황다오 시', 39.9316700, 119.5883300, 'CN', '2016-12-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15922, 'Qingzhou', 'Qingzhou', 'Ch''ing-chou,Ch’ing-chou,Qingzhou,Qingzhou Zhen,Tsingchow,qing zhou,qing zhou zhen,青州,青州镇', 26.5315300, 117.9771800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15923, 'Qingyundian', 'Qingyundian', 'Ch''ing-yu-tien,Ch''ing-yun-tien,Ch’ing-yu-tien,Ch’ing-yün-tien,Qingyundian,Qingyundian Zhen,qing yun dian,qing yun dian zhen,青云店,青云店镇', 39.6769500, 116.5068800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15924, 'Qingyuan', 'Qingyuan', 'Ch''ing-hsu,Ch''ing-hsu-hsien,Ch''ing-yuan,Ch''ing-yuan-ch''eng,Ch''ing-yuan-hsien,Ch’ing-hsü,Ch’ing-hsü-hsien,Ch’ing-yüan,Ch’ing-yüan-ch’eng,Ch’ing-yüan-hsien,Qingxu,Qingxu Xian,Qingyuan,Qingyuan Zhen,Sukowhsien,Sükowhsien,T''sinyuan'',Tsingyuanhsien,Tsingyüanhsien,T’sinyuan’,qing xu xian,qing yuan,qing yuan zhen,清徐县,清源,清源镇', 37.6174800, 112.3258300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15925, 'Qingyang', 'Qingyang', 'Ch''ing-yang,Ch''ing-yang-chen,Ch’ing-yang,Ch’ing-yang-chen,Qingyang,Qingyang Zhen,qing yang,qing yang zhen,青阳,青阳镇', 31.7652500, 120.2518800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15926, 'Qingyangyi', 'Qingyangyi', 'Ch''ing-yang-i,Ch’ing-yang-i,Qingyangyi,Qingyangyi Zhen,qing yang yi,qing yang yi zhen,青羊驿,青羊驿镇', 33.0844300, 106.3901100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15927, 'Qingcheng', 'Qingcheng', 'An-hua,Qingcheng,Qingcheng Zhen,Qingyang,Tsinyan,qing cheng zhen,庆城镇', 35.9989000, 107.8854700, 'CN', '2016-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15928, 'Jinjiang', 'Jinjiang', 'Ceng-gong,Ch''ing-yang,Ch''ing-yang-chen,Chin-chiang,Chin-kang-chhi,Chìn-kang-chhī,Ch’ing-yang,Ch’ing-yang-chen,Czin''czjan,Céng-gŏng,JJN,Jinjiang,Jinjiang Shi,Jìnjiāng,Qingyang,Qingyang Zhen,Tan Giang,Tsin-kong-su,Tsìn-kông-sṳ,Tấn Giang,jin jiang,jin jiang shi,jinjang si,jnjyang,jnjyang  fwjyan,jynjyang,qing yang,qing yang zhen,Цзиньцзян,جنجیانگ,جنجیانگ، فوجیان,جینجیانگ,晉江,晋江,晋江市,青阳,青阳镇,진장 시', 24.8197800, 118.5741500, 'CN', '2013-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15929, 'Qinglang', 'Qinglang', 'Ch''ing-hsi,Chiu-ch''ing-ch''i,Chiu-ch’ing-ch’i,Ch’ing-hsi,Qinglang,Qingxi', 27.1247200, 108.7327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15930, 'Qingxi', 'Qingxi', 'Ch''ing-ch''i,Choulin,Ch’ing-ch’i,Qingxi,Tsintsi,qing xi,清溪', 26.4311400, 110.3548900, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15931, 'Qingxi', 'Qingxi', 'Ch''ing-ch''i,Ch''ing-ch''i-hsu,Ch’ing-ch’i,Ch’ing-ch’i-hsü,Qingxi,Qingxi Xiang,qing xi,qing xi xiang,清溪,清溪乡', 25.2294900, 115.6139200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15932, 'Qingxi', 'Qingxi', 'Ch''ing-ch''i,Ch''ing-ch''i-hsu,Ch''ing-ch''i-t''ang,Ch''ing-hsi,Ch''ing-hsi-hsu,Ch’ing-ch’i,Ch’ing-ch’i-hsü,Ch’ing-ch’i-t’ang,Ch’ing-hsi,Ch’ing-hsi-hsü,Qingxi,Qingxi Zhen,Tsyang-kai,qing xi,qing xi zhen,清溪,清溪镇', 22.8371300, 114.1647700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15933, 'Qingu', 'Qingu', 'Qingu,Qingu Zhen,qin gu,qin gu zhen,秦古,秦古镇', 32.4259200, 109.8276300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15934, 'Qingtangpu', 'Qingtangpu', 'Ch''ing-t''ang-p''u,Ch’ing-t’ang-p’u,Qingtang,Qingtangpu,Qingtangpu Zhen,qing tang pu,qing tang pu zhen,清塘铺,清塘铺镇', 28.0519600, 111.7631700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15935, 'Qingtang', 'Qingtang', 'Ch''ing-t''ang,Ch''ing-t''ang-hsu,Ch’ing-t’ang,Ch’ing-t’ang-hsü,Qingtang,Qingtang Zhen,qing tang,qing tang zhen,青塘,青塘镇', 24.2148700, 113.8448600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15936, 'Qingtaiping', 'Qingtaiping', 'Ch''ing-t''ai-p''ing,Ch’ing-t’ai-p’ing,Qingtaiping,Qingtaiping Zhen,qing tai ping,qing tai ping zhen,清太坪,清太坪镇', 30.4833500, 110.2172000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15937, 'Chengguan', 'Chengguan', 'Ch''ing-shui-ho,Ch''ing-shui-ho-hsien,Ch''ung-shui-ho,Chengguan,Chengguan Zhen,Ch’ing-shui-ho,Ch’ing-shui-ho-hsien,Ch’ung-shui-ho,Qingshuihe,Tsingshuiho,cheng guan,cheng guan zhen,qing shui he,城关,城关镇,清水河', 39.9072200, 111.6733300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15938, 'Qingshuihe', 'Qingshuihe', 'Ch''in-ho,Ch''ing-shui-ho,Ch’in-ho,Ch’ing-shui-ho,Qingshuihe,Qinhe,Qinhe Xiang,qin he xiang,qing shui he,亲和乡,清水河', 39.7219800, 113.1078300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15939, 'Qingshui', 'Qingshui', 'Ch''ing-shui,Ch’ing-shui,Qingshui,Qingshui Zhen,Shang-ch''ing-shui-ts''un,Shang-ch’ing-shui-ts’un,qing shui,qing shui zhen,清水,清水镇', 39.9442100, 115.6147700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15940, 'Qingshui', 'Qingshui', 'Ch''ing-shui-chen,Ch''ing-shui-ho,Ch’ing-shui-chen,Ch’ing-shui-ho,Qingshui,Qingshui Jiedao,Qingshuizhen,qing shui,qing shui jie dao,清水,清水街道', 31.3181000, 118.4774300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15941, 'Qingshizui', 'Qingshizui', 'Ch''ing-shih-tsui,Ch’ing-shih-tsui,Qingshizui,Qingshizui Zhen,qing shi zui,qing shi zui zhen,青石嘴,青石嘴镇', 37.4666700, 101.4333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15942, 'Qingshan', 'Qingshan', 'Ch''ing-shan,Ch''ing-shan-ch''iao,Ch’ing-shan,Ch’ing-shan-ch’iao,Qingshan,Qingshan Xiang,Qingshanqiao,qing shan,qing shan xiang,青山,青山乡', 29.6941600, 116.6979400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15943, 'Qingshanhu', 'Qingshanhu', 'Ch''ing-shan,Ch’ing-shan,Qingshan,Qingshanhu,Qingshanhu Jiedao,qing shan,qing shan hu,qing shan hu jie dao,青山,青山湖,青山湖街道', 30.2506000, 119.8120800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15944, 'Qingquan', 'Qingquan', 'Ch''i-shui,Ch''i-shui-hsien-ch''eng,Ch’i-shui,Ch’i-shui-hsien-ch’eng,Cincjuan'',Hsi-shui,Hsi-shui-hsien,Kishui-hsien,Qingquan,Qingshui Zhen,Sishui,Xishui,Xishui Xian,qing quan,qing quan zhen,xi shui xian,Цинцюань,浠水县,清泉,清泉镇', 30.4511300, 115.2559300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15945, 'Qingqu', 'Qingqu', 'Qingqu,Qingqu Zhen,qing qu,qing qu zhen,青曲,青曲镇', 32.8768200, 110.6280200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15946, 'Qingqiaoyi', 'Qingqiaoyi', 'Ch''ing-ch''iao-ho,Ch''ing-ch''iao-i,Ch''ing-ch''iao-p''u,Ch’ing-ch’iao-ho,Ch’ing-ch’iao-i,Ch’ing-ch’iao-p’u,Qingqiaoyi,qing qiao yi,青桥驿', 33.3289700, 106.9761700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15947, 'Qingping', 'Qingping', 'Qingping,Qingping Zhen,qing ping,qing ping zhen,清平,清平镇', 29.9769600, 106.5205700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15948, 'Qingshuitang', 'Qingshuitang', 'Ch''ing-p''ing,Ch’ing-p’ing,Qingping,Qingping Zhen,Qingshuitang,qing ping zhen,qing shui tang,青坪镇,青水塘', 29.7976900, 109.0694200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15949, 'Qingping', 'Qingping', 'Ch''ing-p''ing,Ch''ing-ping-hsu,Ch’ing-ping-hsü,Ch’ing-p’ing,Qingping,Qingping Zhen,qing ping,qing ping zhen,青平,青平镇', 21.6248000, 109.9189700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15950, 'Qingmuguan', 'Qingmuguan', 'Ch''ing-mu-kuan,Chingmukwan,Ch’ing-mu-kuan,Qingmuguan,Qingmuguan Zhen,qing mu guan,qing mu guan zhen,青木关,青木关镇', 29.6752800, 106.2952800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15951, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Zhen,Qinglongjie,qing long,qing long jie,qing long zhen,青龙,青龙街,青龙镇', 24.4427800, 102.9825000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15952, 'Qinglian', 'Qinglian', 'Ch''ing-lien,Ch''ing-lien-hsu,Chinglienchu,Ch’ing-lien,Ch’ing-lien-hsü,Qinglian,Qinglian Zhen,Tsinglin,qing lian,qing lian zhen,青莲,青莲镇', 24.4644200, 112.7553400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15953, 'Qingkou', 'Qingkou', 'Ch''ing-k''ou,Ch''ing-k''ou-chen,Ch’ing-k’ou,Ch’ing-k’ou-chen,Ganyu Xian,Kan-yu,Kan-yu-hsien,Kan-yü,Kan-yü-hsien,Qingkou,Qingkou Zhen,Tsingkow,gan yu xian,qing kou,qing kou zhen,赣榆县,青口,青口镇', 34.8482800, 119.1083500, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15954, 'Qingjiangqiao', 'Qingjiangqiao', 'Ch''ing-chiang-ch''iao,Ch’ing-chiang-ch’iao,Qingjiang,Qingjiang Xiang,Qingjiangqiao', 26.6044400, 110.9852800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15955, 'Huai''an', 'Huai''an', 'Ch''ing-chiang,Ch''ing-chiang-p''u,Ch''ing-chiang-shih,Ch’ing-chiang,Ch’ing-chiang-p’u,Ch’ing-chiang-shih,HIA,Huai''an,Huai-yin,Huai-yin-ch''eng,Huai-yin-ch’eng,Huai-yin-hsien,Huai-yin-shih,Huaiyin,Hwaiyin,Hwaiyin-hsien,Qingjiang,Tsingkiangpo,Tsinkiangpu', 33.5886100, 119.0191700, 'CN', '2013-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15956, 'Qingjiang', 'Qingjiang', 'Ch''ing-chiang,Ch’ing-chiang,Qingjiang,Qingjiang Xiang,qing jiang,qing jiang xiang,清江,清江乡', 29.1921100, 114.7871400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15957, 'Qingjiang', 'Qingjiang', 'Ch''ing-chiang,Ch''ing-chiang-tu,Ch''ing-chiang-tu-shih,Ch’ing-chiang,Ch’ing-chiang-tu,Ch’ing-chiang-tu-shih,Qingjiang,Qingjiang Zhen,qing jiang,qing jiang zhen,清江,清江镇', 28.2764900, 121.1012700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15958, 'Qinghua', 'Qinghua', 'Bo''ai,Bo’ai,Ch''ing-hua,Ch''ing-hua-chen,Ch’ing-hua,Ch’ing-hua-chen,Po-ai,Po-ai-hsien,Qinghua,Tsinghwachen,qing hua,清化', 35.1650000, 113.0616700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15959, 'Qinghua', 'Qinghua', 'Ch''ing-hua,Ch''ing-hua-chen,Ch’ing-hua,Ch’ing-hua-chen,Qinghua,Qinghua Zhen,qing hua,qing hua zhen,青化,青化镇', 34.4256900, 107.8363100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15960, 'Qinghua', 'Qinghua', 'Ch''ing-feng-chen,Ch''ing-hua,Ch''ing-hua-chen,Ch’ing-feng-chen,Ch’ing-hua,Ch’ing-hua-chen,Hsia-ch''ing-hua,Hsia-ch’ing-hua,Qinghua,qing hua,青化', 34.1840900, 108.0285400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15961, 'Qinghua', 'Qinghua', 'Ch''ing-hua,Ch’ing-hua,Qinghua,Qinghua Zhen,qing hua,qing hua zhen,清华,清华镇', 29.4190100, 117.7743300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15962, 'Qinghaihu', 'Qinghaihu', 'Qinghaihu,Qinghaihu Xiang,qing hai hu,qing hai hu xiang,青海湖,青海湖乡', 36.8383300, 100.8208300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15963, 'Qingguang', 'Qingguang', 'Ch''ing-kuang,Ch’ing-kuang,Qingguang,Qingguang Zhen,qing guang,qing guang zhen,青光,青光镇', 39.1988300, 117.0331400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15964, 'Qinggang', 'Qinggang', 'Ch''ing-chiang,Ch''ing-chiang-shih,Ch''ing-kang,Ch''ing-kang-shih,Ch’ing-chiang,Ch’ing-chiang-shih,Ch’ing-kang,Ch’ing-kang-shih,Qinggang,Qinggang Zhen,qing gang,qing gang zhen,清港,清港镇', 28.2521400, 121.2847300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15965, 'Qingfu', 'Qingfu', 'Ch''ing-fu,Ch''ing-fu-hsien,Ch’ing-fu,Ch’ing-fu-hsien,Kingfu-hsien,Qingfu,qing fu,庆符', 28.4370100, 104.5162200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15966, 'Qingfeng Chengguanzhen', 'Qingfeng Chengguanzhen', 'Ch''ing-feng,Ch''ing-feng-hsien,Ch’ing-feng,Ch’ing-feng-hsien,Qingfeng,Qingfeng Chengguanzhen,Tsingfenghsien,qing feng,qing feng cheng guan zhen,清丰,清丰城关镇', 35.9036100, 115.1052800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15967, 'Qingfeng', 'Qingfeng', 'Ch''ing-feng,Ch''ing-feng-chen,Ch’ing-feng,Ch’ing-feng-chen,Qingfeng,Qingfeng Zhen,qing feng,qing feng zhen,青峰,青峰镇', 32.0462400, 110.9674000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15968, 'Qingdao', 'Qingdao', 'Cching-tao,Ch''ing-tao,Ch''ing-tao-shih,Chheng-to-chhi,Chheng-tó-chhī,Chindao,Ching-do,Chĭng-dō̤,Ch’ing-tao,Ch’ing-tao-shih,Cindao,Cingdao,Cjindao,Csingtao,Qingdao,Qingdao Shi,Sindao,TAO,Thanh GJao,Thanh Đảo,Tsin''nktao,Tsingtao,Tsingtau,ching tea,chingdao si,chngڈaw,chyngdaw,chyng‌dayw,cingada''o,kigada''o,kuyintavo,qing dao,qing dao shi,tshynghdaw,zyngdʼw,Čching-tao,Čingdao,Τσινγκτάο,Ћингдао,Циндао,Ціндао,Чиндао,Чиңдау,Ցինդաո,צינגדאו,تشينغداو,چنگڈاؤ,چىڭداۋ شەھىرى,چینگداؤ,چینگ‌دائو,चिंगदाओ,ਕਿੰਗਦਾਓ,குயிங்தவோ,ชิงเต่า,ချင်းတောင်မြို့,青岛,青岛市,青島,青島市,칭다오 시', 36.0648800, 120.3804200, 'CN', '2017-05-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15969, 'Qingcun', 'Qingcun', 'Ch''ing-ts''un,Ch''ing-ts''un-chiang,Ch''ing-ts''un-chiang-chen,Ch''ing-ts''un-kang,Ch''ing-ts''un-kang-chen,Ch’ing-ts’un,Ch’ing-ts’un-chiang,Ch’ing-ts’un-chiang-chen,Ch’ing-ts’un-kang,Ch’ing-ts’un-kang-chen,Qingcun,Qingcungang,qing cun,青村', 30.9247300, 121.5799400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15970, 'Qingciyao', 'Qingciyao', 'Ch''ing-tz''u-yao,Ch’ing-tz’u-yao,Qingciyao,Qingciyao Zhen,qing ci yao,qing ci yao zhen,青磁窑,青磁窑镇', 39.6198300, 113.7676100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15971, 'Qingyuan', 'Qingyuan', 'Cching-juean,Ch''ing-yuan,Ch''ing-yuan-hsien,Chheng-oan-chhi,Chheng-oán-chhī,Chhin-yen-su,Chhîn-yén-sṳ,Ching-uong,Chĭng-uōng,Ch’ing-yüan,Ch’ing-yüan-hsien,Cinujuan'',Qingcheng,Qingyuan,Thanh Vien,Thanh Viễn,Tsingyuan,Tsingyun,Tsingyunhsien,Tsingyüan,Tsingyün,Tsingyünhsien,ching-wian si,chngywan,chyngywan,kyngwan,qing yuan,qing yuan shi,Čching-jüan,Цинъюань,چنگیوآن,چینگیوان,کینگوان,清远,清远市,清遠,清遠市,칭위안 시', 23.7000000, 113.0333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15972, 'Qingban', 'Qingban', 'Ch''ing-pan-ch''iao,Ch’ing-pan-ch’iao,Qingban,Qingban Xiang,qing ban,qing ban xiang,青板,青板乡', 28.5166700, 117.5333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15973, 'Qindu', 'Qindu', 'Ch''in-tu,Ch''in-tu-chen,Ch’in-tu,Ch’in-tu-chen,Qindu,Qindu Zhen,Qinduzhen,qin du,qin du zhen,秦度,秦度镇', 34.1025000, 108.7508300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15974, 'Qincheng', 'Qincheng', 'Nan-feng-hsien,Nanfeng,Nanfeng Xian,Qincheng,Qincheng Zhen,nan feng xian,qin cheng,qin cheng zhen,南丰县,琴城,琴城镇', 27.2127000, 116.5300800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15975, 'Qimeng', 'Qimeng', 'Ch''i-meng,Ch’i-meng,Qimeng', 26.4847200, 108.9994400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15976, 'Qishan', 'Qishan', 'Ch''i-men,Ch''i-men-hsien,Ch’i-men,Ch’i-men-hsien,Kimen,Kimenhsien,Qimen,Qishan,Qishan Zhen,qi shan,祁山', 29.8443100, 117.7193700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15977, 'Qiliping', 'Qiliping', 'Ch''i-li-p''ing,Ch’i-li-p’ing,Qiliping,Qiliping Zhen,qi li ping,qi li ping zhen,七里坪,七里坪镇', 31.4651500, 114.6492600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15978, 'Qilin', 'Qilin', 'Ch''i-lin,Ch''i-lin-chen,Ch’i-lin,Ch’i-lin-chen,Qilin,Qilin Zhen,qi lin,qi lin zhen,麒麟,麒麟镇', 31.9366200, 121.3491300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15979, 'Qiling', 'Qiling', 'Ch''i-ling,Ch’i-ling,Jingxia,Qiling,Qiling Xiang,jing xia,qi ling,qi ling xiang,井下,岐岭,岐岭乡', 24.6755500, 116.8877400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15980, 'Qiling', 'Qiling', 'Ch''i-ling,Ch''i-ling-shih,Ch’i-ling,Ch’i-ling-shih,Kiling,Qiling,Qiling Zhen,qi ling,qi ling zhen,岐岭,岐岭镇', 24.0911100, 115.4475800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15981, 'Qilidian', 'Qilidian', 'Ch''i-li-tien,Ch’i-li-tien,Qilidian,Qilidian Jiedao,Runzhou Qu,qi li dian,qi li dian jie dao,run zhou qu,七里甸,七里甸街道,润州区', 32.1820600, 119.4008400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15982, 'Qili', 'Qili', 'Qili,Qili Xiang,qi li,qi li xiang,七里,七里乡', 28.4478100, 116.2684800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15983, 'Qijing', 'Qijing', 'Ch''i-ching,Chi-ching-hsu,Chi-ching-hsü,Ch’i-ching,Qijing,Qijing Zhen,Tsatking,qi jing,qi jing zhen,七径,七径镇', 21.5685700, 110.9940600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15984, 'Qijiaxi', 'Qijiaxi', 'Qijiaxi,Qijiaxi Xiang,qi jia xi,qi jia xi xiang,七甲溪,七甲溪乡', 28.8687400, 110.6479300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15985, 'Qijiaping', 'Qijiaping', 'Ch''i-chia-p''ing,Ch’i-chia-p’ing,Qijiaping,Qijiaping Zhen,qi jia ping,qi jia ping zhen,七甲坪,七甲坪镇', 28.8848500, 110.8536400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15986, 'Qihe', 'Qihe', 'Ch''i-chia-ho,Ch’i-chia-ho,Qihe,Qihe Zhen,Qijiahe,qi he,qi he zhen,qi jia he,漆家河,漆河,漆河镇', 29.1327800, 111.3753900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15987, 'Qihong', 'Qihong', 'Ch''a-k''ou,Ch''ang-t''ou,Ch''i-hung,Ch’a-k’ou,Ch’ang-t’ou,Ch’i-hung,Qihong,Qihong Xiang,qi hong,qi hong xiang,祁红,祁红乡', 29.6952400, 117.6688000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15988, 'Qigong', 'Qigong', 'Ch''i-kung,Ch''i-kung-hsu,Ch’i-kung,Ch’i-kung-hsü,Qigong,Qigong Zhen,qi gong,qi gong zhen,七拱,七拱镇', 24.3018500, 112.5584400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15989, 'Qietong', 'Qietong', 'Qietong,Qietong Xiang,jia tong,jia tong xiang,茄通,茄通乡', 28.7104600, 109.8769200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15990, 'Qidu', 'Qidu', 'Ch''i-tu,Ch’i-tu,Qidu', 26.7652800, 119.5472200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15991, 'Hongqiao', 'Hongqiao', 'Ch''i-tung,Ch’i-tung,Hongqiao,Hung-ch''iao,Hung-ch''iao-chen,Hung-ch''iao-shih,Hung-ch’iao,Hung-ch’iao-chen,Hung-ch’iao-shih,Hungkiao,Khuncjao,Qidong,hong qiao,Хунцяо,洪桥', 26.7683700, 112.1081400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15992, 'Xiumei', 'Xiumei', 'Ch''i-ch''ung-yen,Ch’i-ch’ung-yen,Qichongyan,Xiumei,Xiumei Zhen,qi zhong yan,xiu mei,xiu mei zhen,七重堰,修梅,修梅镇', 29.5139100, 111.6258600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15993, 'Qibu', 'Qibu', 'Qibu,Qibu Xiang,qi bu,qi bu xiang,齐埠,齐埠乡', 28.7215100, 116.8639800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15994, 'Qibu', 'Qibu', 'Ch''i-pu,Ch’i-pu,Qibu,Qibu Zhen,qi bu,qi bu zhen,七步,七步镇', 27.0764400, 119.3426300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15995, 'Qibu', 'Qibu', 'Ch''i-pu,Ch’i-pu,Qibu', 26.5075000, 119.5450000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15996, 'Qiawan', 'Qiawan', 'Ch''ia-wan,Ch’ia-wan,Qiawan,Qiawan Zhen,qia wan,qia wan zhen,洽湾,洽湾镇', 27.2741200, 116.5749900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15997, 'Qiashui', 'Qiashui', 'Qiashui,Qiashui Zhen,qia shui,qia shui zhen,洽水,洽水镇', 24.0878100, 112.3323800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15998, 'Qiaozhuang', 'Qiaozhuang', 'Ch''iao-ch''un,Ch''iao-chuang,Ch''iao-chuang-chen,Ch''ing-ch''uan,Ch’iao-chuang,Ch’iao-chuang-chen,Ch’iao-ch’un,Ch’ing-ch’uan,Qiaozhuang,Qingchuan,Qingchuan Xian,Qingchuan Zhen,qiao zhuang,qiao zhuang zhen,qing chuan xian,乔庄,乔庄镇,青川县', 32.5902600, 105.2334300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(15999, 'Qiaozhen', 'Qiaozhen', 'Ch''iao-chen,Ch''iao-shang-chen,Ch’iao-chen,Ch’iao-shang-chen,Qiaozhen,Tsyaoshanchzhen'',Tsyaoshanchzhen’,qiao zhen,桥镇', 34.4865500, 107.1391800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16000, 'Qiaoxu', 'Qiaoxu', 'Ch''iao-hsu,Ch’iao-hsü,Qiaoxu,Qiaoxu Zhen,qiao wei,qiao wei zhen,桥圩,桥圩镇', 22.9561600, 109.7607200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16001, 'Qiaoxia', 'Qiaoxia', 'Ch''iao-hsia,Ch''iao-hsia-chieh,Ch''iao-hsia-chien,Ch''iao-hsia-ts''un,Ch’iao-hsia,Ch’iao-hsia-chieh,Ch’iao-hsia-chien,Ch’iao-hsia-ts’un,Qiaoxia,Qiaoxia Zhen,Qiaoxiajie,qiao xia,qiao xia zhen,桥下,桥下镇', 28.1692300, 120.5554600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16002, 'Qiaowa', 'Qiaowa', 'Bowa,Jiaowu,Mu-li-tsang-tsu-tzu-chih-hsien,Muli,Qiaowa,qiao wa,乔瓦', 27.9307900, 101.2778100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16003, 'Qiaotou', 'Qiaotou', 'Ch''iao-t''ou,Ch''iao-tzu-t''ou,Ch’iao-tzu-t’ou,Ch’iao-t’ou,Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 37.3188400, 122.2812700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16004, 'Qiaotou', 'Qiaotou', 'Ch''iao-t''ou,Ch''iao-t''ou-chen,Ch’iao-t’ou,Ch’iao-t’ou-chen,Datong Huizu Tuzu Zizhixian,Hsiang-shan,Qiaotou,Ta-t''ung,Ta-t''ung-hsien,Ta-t’ung,Ta-t’ung-hsien,da tong hui zu tu zu zi zhi xian,qiao tou,大通回族土族自治县,桥头', 36.9350000, 101.6736100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16005, 'Qiaotou', 'Qiaotou', 'Qiaotou,qiao tou,桥头', 33.7536900, 104.8141800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16006, 'Qiaotou', 'Qiaotou', 'Qiaotou,qiao tou,桥头', 33.1076300, 104.8116800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16007, 'Qiaotou', 'Qiaotou', 'Ch''iao-t''ou,Ch''iao-t''ou-chen,Ch’iao-t’ou,Ch’iao-t’ou-chen,Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 33.0551500, 112.8101500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16008, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Xiang,Qiaotouba,qiao tou,qiao tou xiang,桥头,桥头乡', 30.1092700, 108.2579500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16009, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 19.9645100, 109.9263700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16010, 'Qiaoting', 'Qiaoting', 'Ch''iao-t''ing,Ch’iao-t’ing,Qiaoting,Qiaoting Xiang,qiao ting,qiao ting xiang,乔亭,乔亭乡', 30.3888900, 118.5466700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16011, 'Qiaosi', 'Qiaosi', 'Ch''iao-ssu,Ch''iao-ssu-chen,Ch’iao-ssu,Ch’iao-ssu-chen,Kiaosze,Qiaosi,Qiaosi Zhen,qiao si,qiao si zhen,乔司,乔司镇', 30.3516000, 120.2855900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16012, 'Qiaoshe', 'Qiaoshe', 'Ch''iao-she,Ch’iao-she,Qiaoshe,Qiaoshe Zhen,qiao she,qiao she zhen,樵舍,樵舍镇', 28.8500000, 115.9833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16013, 'Qiaonan', 'Qiaonan', 'Ch''iao-nan,Ch’iao-nan,Qiaonan,Qiaonan Zhen,qiao nan,桥南', 34.3433300, 109.5926200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16014, 'Qiaomu', 'Qiaomu', 'Ch''iao-mu,Ch''iao-mu-wan,Ch''iao-wan,Ch’iao-mu,Ch’iao-mu-wan,Ch’iao-wan,Qiaomu,Qiaomu Xiang,Qiaomuwan,qiao mu,qiao mu xiang,乔木,乔木乡', 30.7036700, 118.0772500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16015, 'Qiaolin', 'Qiaolin', 'Ch''iao-lin,Ch''iao-lin-chen,Ch’iao-lin,Ch’iao-lin-chen,Qiaolin,Qiaolin Zhen,qiao lin,qiao lin zhen,桥林,桥林镇', 31.9467300, 118.5265000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16016, 'Qiaojia', 'Qiaojia', 'Ch''iao-chia-p''u,Ch’iao-chia-p’u,Qiaojia,Qiaojia Zhen,Qiaojiapu,qiao jia,qiao jia pu,qiao jia zhen,谯家,谯家铺,谯家镇', 28.3029000, 108.4467500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16017, 'Qiaojiang', 'Qiaojiang', 'Ch''iao-chiang,Ch’iao-chiang,Qiaojiang', 27.9372200, 110.6763900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16018, 'Qiaogu', 'Qiaogu', '', 39.3125000, 117.7247200, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16019, 'Qiaodong', 'Qiaodong', 'Ch''iao-tung,Ch’iao-tung,Qiaodong,Qiaodong Zhen,qiao dong,qiao dong zhen,桥东,桥东镇', 28.0583900, 115.8195700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16020, 'Wanrongjiang', 'Wanrongjiang', 'Ch''ien-ch''eng,Ch''ien-ch''eng-hsien,Ch''ien-chou,Ch''ien-chou-chen,Chiu-ch''ien-ch''eng,Chiu-ch’ien-ch’eng,Ch’ien-chou,Ch’ien-chou-chen,Ch’ien-ch’eng,Ch’ien-ch’eng-hsien,Kiencheng,Kiencheng-hsien,Kienchow,Qianzhouzhen,Wanrongjiang,Wanrongjiang Xiang,wan rong jiang,wan rong jiang xiang,万溶江,万溶江乡', 28.2570900, 109.6927800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16021, 'Qianzhou', 'Qianzhou', 'Ch''ien-chou,Chien-chou-chen,Ch’ien-chou,Qianzhou,Qianzhou Zhen,qian zhou,qian zhou zhen,前洲,前洲镇', 31.6918200, 120.2133300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16022, 'Qi’an', 'Qi''an', 'Ch''i-an,Ch''i-an-chen,Ch’i-an,Ch’i-an-chen,Qi''an,Qi''an Zhen,Qi''anzhen,Qi’an,Qi’an Zhen,Qi’anzhen,qi an,qi an zhen,骑岸,骑岸镇', 32.1779200, 121.0490600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16023, 'Yuqian', 'Yuqian', 'Ch''ien-yang,Ch’ien-yang,Qianyang,Yu-ch''ien,Yu-ch''ien-hsien,Yu-ch''ien-hsien-chih,Yuqian,Yuqian Zhen,Yutsien,Yutsien-hsien,Yü-ch’ien,Yü-ch’ien-hsien,Yü-ch’ien-hsien-chih,Yütsien-hsien,wu qian,於潜', 30.1881000, 119.3931500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16024, 'Qianxiang', 'Qianxiang', 'Qianxiang,Qianxiang Zhen,qian xiang,qian xiang zhen,千祥,千祥镇', 29.0426000, 120.3135800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16025, 'Qianwu', 'Qianwu', 'Ch''ien-wu,Ch’ien-wu,Qianwu,Qianwu Zhen,gan wu,gan wu zhen,乾务,乾务镇', 22.1643600, 113.2306900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16026, 'Qiansuo', 'Qiansuo', 'Ch''ien-so,Ch’ien-so,Qiansuo,Qiansuo Jiedao,Qiansuozhen,Tsienso,qian suo,qian suo jie dao,前所,前所街道', 28.6990500, 121.4465700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16027, 'Qianshan', 'Qianshan', 'Ch''ien-shan,Ch’ien-shan,Qianshan,Qianshan Xiang,qian shan,qian shan xiang,钱山,钱山乡', 27.3481500, 114.1335300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16028, 'Qianshan', 'Qianshan', 'Ch''ien-shan,Ch''ien-shan-chai,Ch’ien-shan,Ch’ien-shan-chai,Qianshan,Qianshan Jiedao,Tsinshan,qian shan,qian shan jie dao,前山,前山街道', 22.2433300, 113.5211100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16029, 'Qianshan', 'Qianshan', 'Ch''ien-shan,Ch''ien-shan-hsu,Ch''ien-shan-shih,Ch’ien-shan,Ch’ien-shan-hsü,Ch’ien-shan-shih,Qianshan,Qianshan Zhen,qian shan,qian shan zhen,前山,前山镇', 20.4267800, 110.4611500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16030, 'Qianqiu', 'Qianqiu', 'Ch''ien-ch''iu,Ch''ien-ch''iu-chen,Ch’ien-ch’iu,Ch’ien-ch’iu-chen,I-ma,Qianqiu,Qianqiu Zhen,Yima,qian qiu,qian qiu zhen,千秋,千秋镇', 34.7423000, 111.8720000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16031, 'Qianqing', 'Qianqing', 'Ch''ien-ch''ing,Ch''ien-ch''ing-chen,Ch’ien-ch’ing,Ch’ien-ch’ing-chen,Qianqing,Qianqing Zhen,qian qing,qian qing zhen,钱清,钱清镇', 30.1250500, 120.4051200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16032, 'Qianqiao', 'Qianqiao', 'Ch''ien-ch''iao-chen,Ch’ien-ch’iao-chen,Qianqiao,qian qiao,钱桥', 31.6007200, 120.2253200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16033, 'Qianping', 'Qianping', 'Qianping,qian ping,前坪', 25.8454300, 117.8639100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16034, 'Qianpai', 'Qianpai', 'Ch''ien-p''ai,Ch''ien-p''ai-hsu,Ch’ien-p’ai,Ch’ien-p’ai-hsü,Qianpai,Qianpai Zhen,qian pai,qian pai zhen,钱排,钱排镇', 22.3645700, 111.2611400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16035, 'Qianling', 'Qianling', 'Baojing,Baojing Xian,Pao-ching,Pao-ching-hsien,Paotsing,Paotsing-hsien,Qianling,bao jing xian,qian ling,保靖县,迁陵', 28.7118700, 109.6459700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16036, 'Qiankou', 'Qiankou', 'Ch''ien-k''ou,Ch''ien-k''ou-chen,Ch’ien-k’ou,Ch’ien-k’ou-chen,Qiankou,Qiankou Zhen,Tsienkow,qian kou,qian kou zhen,潜口,潜口镇', 29.8705600, 118.2952800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16037, 'Qianjia', 'Qianjia', 'Ch''ien-chia,Ch''ien-chia-tung,Ch’ien-chia,Ch’ien-chia-tung,Qianjia,Qianjia Zhen,qian jia,qian jia zhen,千家,千家镇', 18.5692400, 109.0820300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16038, 'Qianhuang', 'Qianhuang', 'Ch''ien-huang,Ch''ien-huang-chen,Ch’ien-huang,Ch’ien-huang-chen,Qianhuang,Qianhuang Zhen,qian huang,qian huang zhen,前黄,前黄镇', 31.5969600, 119.9612100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16039, 'Qianguan', 'Qianguan', 'Ch''ien-kuan,Ch''ien-kuan-hsu,Ch’ien-kuan,Ch’ien-kuan-hsü,Qianguan,Qianguan Zhen,qian guan,qian guan zhen,千官,千官镇', 22.8666700, 111.5833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16040, 'Qiangtou', 'Qiangtou', 'Ch''iang-t''ou,Ch''iang-t''ou-chen,Ch’iang-t’ou,Ch’iang-t’ou-chen,Qiangtou,Qiangtou Zhen,qiang tou,qiang tou zhen,墙头,墙头镇', 29.4638900, 121.7805600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16041, 'Qiangbai', 'Qiangbai', 'Ch''iang-pai,Ch''iang-pai-chen,Ch’iang-pai,Ch’iang-pai-chen,Qiangbai,Qiangbai Zhen,qiang bai,羌白', 34.7471400, 109.8103800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16042, 'Qianfang', 'Qianfang', 'Ch''ien-fang,Ch’ien-fang,Qianfang,Qianfang Zhen,qian fang,qian fang zhen,前坊,前坊镇', 28.5235100, 116.2335700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16043, 'Qiandong', 'Qiandong', 'Ch''ien-tung,Ch''ien-tung-chen,Ch’ien-tung,Ch’ien-tung-chen,Qiandong,Qiandong Zhen,qian dong,qian dong zhen,阡东,阡东镇', 34.5211100, 108.6377800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16044, 'Qiandong', 'Qiandong', 'Ch''ien-tung,Ch''ien-tung-hsu,Ch’ien-tung,Ch’ien-tung-hsü,Qiandong,Qiandong Zhen,qian dong,qian dong zhen,钱东,钱东镇', 23.6779700, 116.9063400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16045, 'Qiandeng', 'Qiandeng', 'Qiandeng,Qiandeng Zhen,qian deng,qian deng zhen,千灯,千灯镇', 31.2669800, 120.9969400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16046, 'Dayang', 'Dayang', 'Ch''ien-ts''un,Ch’ien-ts’un,Dayang,Dayang Zhen,Qiancun,da yang,da yang zhen,qian cun,前村,大洋,大洋镇', 28.5092600, 120.2575600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16047, 'Qiancheng', 'Qiancheng', 'Ch''ien-ch''eng,Ch''ien-ch''eng-chen,Ch''ien-yang,Ch''ien-yang-hsien,Chiu-ch''ien-yang,Chiu-ch’ien-yang,Ch’ien-ch’eng,Ch’ien-ch’eng-chen,Ch’ien-yang,Ch’ien-yang-hsien,Kienyang,Kienyang-hsien,Qiancheng,Tsyan''chen,Tsyan’chen,qian cheng,黔城', 27.1850100, 109.7654300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16048, 'Qiagai', 'Qiagai', 'Qiagai,qia gai,恰盖', 34.8449600, 103.4591300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16049, 'Zixiao', 'Zixiao', 'Ch''ia-ts''un,Ch’ia-ts’un,Qiacun,Zixiao,Zixiao Zhen,qia cun,zi xiao,zi xiao zhen,洽村,紫霄,紫霄镇', 27.0175900, 116.2825100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16050, 'Qabqir', 'Qabqir', 'Qabqir,Qabqir Jiedao,Qiabuqi,ka bu qi,ka bu qi jie dao,卡布其,卡布其街道', 39.6161100, 106.8736100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16051, 'Qabqa', 'Qabqa', 'Ch''ia-pai-t''a-leng,Ch''ia-pu-ch''ia,Ch''ia-pu-ch''ia-chen,Ch''ia-pu-ch''ia-kou,Ch’ia-pai-t’a-leng,Ch’ia-pu-ch’ia,Ch’ia-pu-ch’ia-chen,Ch’ia-pu-ch’ia-kou,Gabadalen,Gonghe,Gonghe Xian,K''a-pai-t''a-la,K''a-pu-k''a,Kaba Talen,Kaba-tala,Kung-ho,Kung-ho-hsien,K’a-pai-t’a-la,K’a-pu-k’a,Qabqa,Qiabuqia,gong he xian,qia bo qia,共和县,恰卜恰', 36.2813900, 100.6130600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16052, 'Puzi', 'Puzi', 'P''u-tzu-chiao,Puzi,Puzi Zhen,Puzijiao,P’u-tzu-chiao', 26.9863900, 109.7763900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16053, 'Puzi', 'Puzi', 'Puzi,Puzi Zhen,Puziba,pu zi,pu zi zhen,普子,普子镇', 29.6329200, 108.3282500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16054, 'Puyuan', 'Puyuan', 'P''u-yuan-chen,Puyuan,Puyuan Zhen,P’ü-yuan-chen,pu yuan,pu yuan zhen,濮院,濮院镇', 30.6802200, 120.6291200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16055, 'Puyang Chengguanzhen', 'Puyang Chengguanzhen', 'K''ai-chou,Kaichow,K’ai-chou,P''u-yang-hsien,Puyan'',Puyang,Puyang Chengguanzhen,Puyan’,P’u-yang-hsien,pu yang,pu yang cheng guan zhen,濮阳,濮阳城关镇', 35.7050600, 115.0140900, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16056, 'Puyang', 'Puyang', 'Puyang,Puyang Zhen,pu yang,pu yang zhen,浦阳,浦阳镇', 29.9873500, 120.2485000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16057, 'Puyang', 'Puyang', 'P''u-chiang,P''u-chiang-hsien-ch''eng,P''u-yang-chen,Pujiang,Pukiang,Pukianghsien,Puyang,Puyang Jiedao,P’u-chiang,P’u-chiang-hsien-ch’eng,P’u-yang-chen,pu yang,pu yang jie dao,浦阳,浦阳街道', 29.4567900, 119.8887200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16058, 'Pucheng', 'Pucheng', 'P''u,P''u-hsien,Pu Xian,Pucheng,Pucheng Zhen,Pusyan'',Pusyan’,Puxian,P’u,P’u-hsien,pu cheng,pu cheng zhen,pu xian,蒲县,蒲城,蒲城镇', 36.4136100, 111.0950000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16059, 'Puwa', 'Puwa', 'P''u-wa-ts''un,Puwa,Puwa Xiang,P’u-wa-ts’un,pu wa,pu wa xiang,蒲洼,蒲洼乡', 39.7373900, 115.5337400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16060, 'Putou', 'Putou', 'P''u-t''ou-chen,Putou,Putou Zhen,P’u-t’ou-chen,pu tou,pu tou zhen,浦头,浦头镇', 32.3813100, 119.8284100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16061, 'Puting', 'Puting', 'De''an,De’an,Puting,Puting Zhen,Te-an,Te-an-hsien,Teian,Teian-hsien,pu ting,pu ting zhen,蒲亭,蒲亭镇', 29.3312900, 115.7574600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16062, 'Futian', 'Futian', 'Fu-t''en,Fu-t''ien-ch''iao,Fu-t’en,Fu-t’ien-ch’iao,Futian,Futian Xiang,P''u-ti''en-ch''iao,P''ut''ien,Putian,P’u-ti’en-ch’iao,P’ut’ien,fu tian,fu tian xiang,甫田,甫田乡', 29.2683000, 114.9589200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16063, 'Putian', 'Putian', 'Buo-dieng,Buò-dièng,Hinghwa,Hinghwafu,Hsing-hua,P''u-t''ien,P''u-t''ien-hsien,P''u-t''ien-hsien-ch''eng,Pchu-tchien,Pho-chhan-chhi,Phu GJien,Phu-thien-su,Phô͘-chhân-chhī,Phù-thièn-sṳ,Phủ Điền,Putian,Putian Shi,Putjan'',Putjen,Putyen shehiri,P’u-t’ien,P’u-t’ien-hsien,P’u-t’ien-hsien-ch’eng,ho tian,ho tian shi,pu tian,pu tian shi,putyen si,pwtyan,Путянь,Путјен,پوتیان,ホ田,ホ田市,莆田,莆田市,푸톈 시', 25.4394400, 119.0102800, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16064, 'Putang', 'Putang', 'P''u-t''ang-chen,Putang,Putang Zhen,P’u-t’ang-chen,pu tang,pu tang zhen,濮塘,濮塘镇', 31.7124000, 118.6492400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16065, 'Pushi', 'Pushi', 'P''u-shih,P''u-shih-chen,Pushi,Pushi Zhen,P’u-shih,P’u-shih-chen,pu shi,pu shi zhen,浦市,浦市镇', 28.0819400, 110.0955600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16066, 'Pushang', 'Pushang', 'Pushang,Pushang Zhen,bu shang,bu shang zhen,埔上,埔上镇', 26.9337000, 117.7702600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16067, 'Purong', 'Purong', 'Purong,Purong Zhen,pu rong,pu rong zhen,普戎,普戎镇', 28.8587300, 109.6165000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16068, 'Puqian', 'Puqian', 'P''u-ch''ien,P''u-ch''ien-shih,Pachin,Pochin,Potsin,Puqian,Puqian Zhen,Putsien,Putsin,P’u-ch’ien,P’u-ch’ien-shih,pu qian,pu qian zhen,铺前,铺前镇', 20.0262700, 110.5775400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16069, 'Puqi', 'Puqi', 'P''u-ch''i,P''u-ch''i-hsien,Puchihhsien,Puqi,P’u-ch’i,P’u-ch’i-hsien', 29.7166700, 113.8833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16070, 'Puqi', 'Puqi', 'P''u-ch''i,Puki,Puqi,Puqi Zhen,P’u-ch’i,pu qi,pu qi zhen,蒲岐,蒲岐镇', 28.1665700, 121.0521600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16071, 'Pumiao', 'Pumiao', 'P''u-ching,P''u-ching-chen,P''u-ching-hsu,P''u-maio,P''u-miao-chen,P''u-miao-hsu,Pu chi,Pumiao,Pumiao Zhen,P’u-ching,P’u-ching-chen,P’u-ching-hsü,P’u-maio,P’u-miao-chen,P’u-miao-hsü,Yongning,Yung-ning,Yung-ning-hsien,pu miao,pu miao zhen,蒲庙,蒲庙镇', 22.7586700, 108.4811100, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16072, 'Pulandian', 'Pulandian', 'Adams,Hou-lung-fang,Hsin-chin,Huranten,P''u-lan-tien,P''u-lan-tien-chen,Po-lan-te,Pulandian,P’u-lan-tien,P’u-lan-tien-chen,Xinjin', 39.3952800, 121.9669400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16073, 'Pukou', 'Pukou', 'Pukou,Pukou Xiang', 26.5222200, 109.5558300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16074, 'Pukou', 'Pukou', 'Pukou,Pukou Zhen,pu kou,pu kou zhen,浦口,浦口镇', 26.2482400, 119.5979000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16075, 'Pujijie', 'Pujijie', 'P''u-chi-chen,P''u-chi-chieh,Pujijie,P’u-chi-chen,P’u-chi-chieh,pu ji jie,普集街', 34.2332500, 108.2451300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16076, 'Puji', 'Puji', 'P''u-chi,Puji,Puji Zhen,Pujichang,P’u-chi,pu ji,pu ji zhen,普济,普济镇', 32.2390800, 106.4547800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16077, 'Puji', 'Puji', 'P''u-ch''i,P''u-ch''i-kuan,Puji,Puji Zhen,P’u-ch’i,P’u-ch’i-kuan,pu ji,pu ji zhen,普济,普济镇', 29.9819800, 112.5337100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16078, 'Puji', 'Puji', 'P''u-ke,P''u-ko,P''u-ko-ch''ang,P''u-ko-she-chih-chu,Puge,Puji,Pule,P’u-ke,P’u-ko,P’u-ko-ch’ang,P’u-ko-she-chih-chü,pu ji,普基', 27.3801900, 102.5412600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16079, 'Puhua', 'Puhua', 'P''u-hua-chen,Puhua,Puhua Zhen,P’u-hua-chen,pu hua,普化', 34.1560900, 109.3951200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16080, 'Puhechang', 'Puhechang', 'P''u-ho,P''u-ho-ch''ang,Puhe,Puhechang,P’u-ho,P’u-ho-ch’ang', 28.9525000, 106.8311100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16081, 'Pu’er', 'Pu''er', 'P''u-erh-tu,Pu''er,Pu''er Zhen,Pu''erdu,Pu’er,Pu’er Zhen,Pu’erdu,P’u-erh-tu,pu er,pu er zhen,普洱,普洱镇', 28.2500000, 104.1666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16082, 'Pudong', 'Pudong', 'P''u-tung,Pho GJong,Phố Đông,Pootung,Pudong,Pudun,P’u-tung,pu dong,pu dong xin qu,shang hai pu dong,Пудун,上海浦东,浦东,浦东新区,浦東新区', 31.2351300, 121.5275900, 'CN', '2012-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16083, 'Pucheng Chengguanzhen', 'Pucheng Chengguanzhen', 'P''u-ch''eng-hsien,Pucheng Chengguanzhen,P’u-ch’eng-hsien,pu cheng cheng guan zhen,蒲城城关镇', 34.9561100, 109.5840600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16084, 'Pu’an', 'Pu''an', 'Chien-chou,Chien-ke,Chien-ko,Chien-ko-hsien,Chien-kê,Jiange,Jiange Xian,Kienchow Peh,Kienko,Kienko-hsien,Pu''an,Pu''an Zhen,Pu’an,Pu’an Zhen,Tszyan''ge,Tszyan’ge,jian ge xian,pu an,pu an zhen,剑阁县,普安,普安镇', 32.0372800, 105.4668600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16085, 'Poyang', 'Poyang', 'Boyang,Jao-chou,Jaochow,P''o-yang-chen,P''o-yang-hsien,P''o-yang-hsien-ch''eng,Pojankhu,Poyang,Poyang Xian,Poyang Zhen,P’o-yang-chen,P’o-yang-hsien,P’o-yang-hsien-ch’eng,po yang,po yang xian,po yang zhen,Поянху,鄱阳,鄱阳县,鄱阳镇', 28.9924200, 116.6675400, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16086, 'Poxi', 'Poxi', 'P''o-hsi,P''o-hsi-chen,P''o-shu-wan,P''u-shu-wan,Poxi,Poxi Zhen,Poxizhen,P’o-hsi,P’o-hsi-chen,P’o-shu-wan,P’u-shu-wan,pu xi,pu xi zhen,朴席,朴席镇', 32.2958300, 119.3149200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16087, 'Potou', 'Potou', 'Potou,Potou Zhen,po tou,po tou zhen,坡头,坡头镇', 21.2684100, 110.4354500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16088, 'Potan', 'Potan', 'Potan,Potan Xiang,po tan,po tan xiang,皤滩,皤滩乡', 28.7436300, 120.5357100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16089, 'Wangge’ertang', 'Wangge''ertang', 'Panggurtang,Ponggartang,Wangge''ertang,Wangge''ertang Xiang,Wangge’ertang,Wangge’ertang Xiang,Yuan-ka-t''an,Yüan-ka-t’an,wang ge er tang,wang ge er tang xiang,བང་གུར་ཐང,王格尔塘,王格尔塘乡', 35.2417200, 102.8330700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16090, 'Pogan', 'Pogan', 'P''o-kan,P''o-kan-chieh,Pogan,Pogan Xiang,P’o-kan,P’o-kan-chieh,po gan,po gan xiang,珀玕,珀玕乡', 28.3271200, 116.7833100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16091, 'Podu', 'Podu', 'Podu,Podu Zhen,po du,po du zhen,坡渡,坡渡镇', 28.7541700, 106.8261100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16092, 'Pitong', 'Pitong', 'P''i,P''i-hsien,Pisyan'',Pisyan’,Pitong,Pixian,P’i,P’i-hsien,pi tong,郫筒', 30.8099300, 103.8825300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16093, 'Pisha', 'Pisha', 'Dongfeng,Ning-nan-hsien,Ningnan,Pisha,Tung-feng-kung-she,pi sha,披砂', 27.0705700, 102.7577100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16094, 'Pingyuan', 'Pingyuan', 'Pingyuan,Pingyuan Tujiazu Xiang,Shanyuan,ping yuan,ping yuan tu jia zu xiang,shan yuan,平原,平原土家族乡,杉园', 28.1541000, 107.8488100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16095, 'Guhuai', 'Guhuai', 'Guhuai,Pingyu,gu huai,古槐', 32.9586000, 114.6255000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16096, 'Pingyin', 'Pingyin', 'P''ing-yin-hsien,Pingyin,P’ing-yin-hsien', 36.2830600, 116.4452800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16097, 'Pingyi', 'Pingyi', 'P''ing-i,P''ing-i-chen,P''ing-i-chi,Pingyi,P’ing-i,P’ing-i-chen,P’ing-i-chi,Ta-p''ing-i,Ta-p’ing-i', 35.5005600, 117.6308300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16098, 'Gutao', 'Gutao', 'Gutao,Gutao Zhen,P''ing-yao-hsien,Pin''yao,Pingyao,Pingyao County,Pingyao Xian,Pinujao,Pin’yao,P’ing-yao-hsien,Xian de Pingyao,gu tao,gu tao zhen,ping yao xian,Пинъяо,古陶,古陶镇,平遥县,平遥県', 37.2025000, 112.1780600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16099, 'Pingyao', 'Pingyao', 'P''ing-yao-chen,Pingyao,P’ing-yao-chen,ping yao,瓶窑', 30.4005600, 119.9633300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16100, 'Pingyang', 'Pingyang', 'Pingyang,Pingyang Zhen,ping yang,ping yang zhen,平阳,平阳镇', 38.8171900, 114.4702400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16101, 'Pingxiang', 'Pingxiang', 'Bing-hiong,Binh Huong,Bìng-hiŏng,Bình Hương,Dingsiang,P''ing-hsiang,P''ing-hsiang-chen,P''ing-hsiang-hsien,P''ing-hsiang-hsien-ch''eng,P''ing-hsiang-shih,PXG,Pching-siang,Pheng-hiong-chhi,Phin-hiong-su,Phêng-hiong-chhī,Phìn-hiông-sṳ,Pingsiang,Pingsiang-hsien,Pingsjang,Pingxiang,Pingxiang Shi,Pinsjan,P’ing-hsiang,P’ing-hsiang-chen,P’ing-hsiang-hsien,P’ing-hsiang-hsien-ch’eng,P’ing-hsiang-shih,ping xiang,ping xiang shi,pingsyang si,pngshyang,pyngshyang,Пингсјанг,Пинсян,پنگشیانگ,پینگشیانگ,萍乡,萍乡市,萍郷,萍郷市,萍鄉,핑샹 시', 27.6167200, 113.8535300, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16102, 'Pingxi', 'Pingxi', 'P''ing-ch''i,Pingxi,Pingxi Xiang,P’ing-ch’i,ping xi,ping xi xiang,平溪,平溪乡', 27.3422900, 119.3236100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16103, 'Pingxi', 'Pingxi', 'Pingxi,Pingxi Xiang,ping xi,ping xi xiang,坪溪,坪溪乡', 27.1157100, 115.9310500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16104, 'Pingwang', 'Pingwang', 'P''ing-wang-chen,Pingwang,Pingwang Zhen,P’ing-wang-chen,ping wang,ping wang zhen,平望,平望镇', 30.9766700, 120.6361100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16105, 'Pingtang', 'Pingtang', 'Pingtang,Pingtang Zhen,ping tang,ping tang zhen,坪塘,坪塘镇', 28.0847200, 112.9150000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16106, 'Pingtang', 'Pingtang', 'Pingtang,Pingtang Zhen,ping tang,ping tang zhen,平塘,平塘镇', 22.4832100, 111.3509100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16107, 'Pingtan', 'Pingtan', 'Pingtan,Pingtan Zhen,ping tan,ping tan zhen,平滩,平滩镇', 29.8459400, 105.8778200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16108, 'Pingtan', 'Pingtan', 'P''ing-t''an-yu,P''ing-tan-hsu,Pingtan,Pingtan Zhen,P’ing-tan-hsü,P’ing-t’an-yü,ping tan,ping tan zhen,平潭,平潭镇', 23.0500000, 114.5833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16109, 'Qingyang', 'Qingyang', 'P''ing-shun-hsien,Pingshun,Pingshun Xian,Pinshun'',Pinshun’,P’ing-shun-hsien,Qingyang,Qingyang Zhen,ping shun xian,qing yang,qing yang zhen,平顺县,青羊,青羊镇', 36.2071200, 113.4172100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16110, 'Pingshui', 'Pingshui', 'P''ing-shui-chen,Pingshui,Pingshui Zhen,P’ing-shui-chen,ping shui,ping shui zhen,平水,平水镇', 29.8936400, 120.6194000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16111, 'Pingshui', 'Pingshui', 'Huangsha Pu,P''ing-shui-hsu,Pingshui,Pingshui Zhen,P’ing-shui-hsü,huang sha pu,ping shui,ping shui zhen,平水,平水镇,黄沙铺', 26.8430100, 113.4013600, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16112, 'Pingshi', 'Pingshi', 'P''ing-shih,P''ing-shih-hsu,Pingshek,Pingshi,Pingshi Zhen,P’ing-shih,P’ing-shih-hsü,ping shi,ping shi zhen,坪石,坪石镇', 25.2849200, 113.0598000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16113, 'Pingshan', 'Pingshan', 'P''ing-shan-hsu,P''ing-shan-shih,Pingshan,Pingshan Zhen,P’ing-shan-hsü,P’ing-shan-shih,ping shan,ping shan zhen,屏山,屏山镇', 26.2181500, 116.2832600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16114, 'Pingshan', 'Pingshan', 'Pingshan,ping shan,屏山', 25.5927800, 117.8927800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16115, 'Pingshan', 'Pingshan', 'Lu-ch''uan,Lu-ch''uan-hsien,Lu-ch’üan,Lu-ch’üan-hsien,Luquan,P''ing-shan-chen,Pingshan,P’ing-shan-chen,ping shan,屏山', 25.5198500, 102.4758100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16116, 'Pingshan', 'Pingshan', 'Hui-tung,Huidong,Ping-shan-hsu,Ping-shan-hsü,Pingshan,ping shan,平山', 22.9937600, 114.7131100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16117, 'Pingshan', 'Pingshan', 'P''ing-shan-hsu,Phyungsan,Pingshan,Pingshan Jiedao,P’ing-shan-hsü,ping shan,ping shan jie dao,坪山,坪山街道', 22.6939600, 114.3346300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16118, 'Pingsha', 'Pingsha', 'Pingsha,Pingsha Nongchang,Pingsha Zhen,ping sha,ping sha zhen,平沙,平沙镇', 22.1060300, 113.1925700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16119, 'Pingqiao', 'Pingqiao', 'Hsin-yang,P''ing-ch''iao,Pingqiao,Pingqiao Jiedao,P’ing-ch’iao,Xinyang,ping qiao,ping qiao jie dao,xin yang,信阳,平桥,平桥街道', 32.0958300, 114.1202800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16120, 'Pingnan', 'Pingnan', 'P''ing-t''ien,Pingnan,Pingnan Zhen,Pingtian,P’ing-t’ien,ping nan,ping nan zhen,ping tian,坪田,屏南,屏南镇', 27.8425000, 119.0833300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16121, 'Pingnan', 'Pingnan', 'Pingnam,Pingnam-hsien,Pingnamyun,Pingnamyün,Pingnan,Pingnan Zhen,ping nan,ping nan zhen,平南,平南镇', 23.5421800, 110.3894600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16122, 'Pingmu', 'Pingmu', 'P''ing-mou,P''ing-mou-chen,P''ing-shui,Pingmu,Pingmu Zhen,P’ing-mou,P’ing-mou-chen,P’ing-shui,ping mu,ping mu zhen,平木,平木镇', 33.9810300, 107.0333400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16123, 'Pingma', 'Pingma', 'P''ing-ma-chen,Pingma,P’ing-ma-chen,T''ien-tung,Tiandong,T’ien-tung,ping ma,平马', 23.6374300, 107.1014000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16124, 'Pingluo Chengguanzhen', 'Pingluo Chengguanzhen', 'P''ing-lo,Pingluo,Pingluo Chengguanzhen,Pingluo Xian,P’ing-lo,ping luo cheng guan zhen,ping luo xian,平罗县,平罗城关镇', 38.9037700, 106.5412800, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16125, 'Pingluo', 'Pingluo', 'Pingluo,Pingluo Zhen,ping luo,ping luo zhen,平洛,平洛镇', 33.5488000, 105.4103300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16126, 'Pinglumiao', 'Pinglumiao', 'Pinglu,Pinglumiao,ping lu miao,平路庙', 34.9099400, 109.7344500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16127, 'Pingling', 'Pingling', 'P''ing-ling-hsu,Pingling,Pingling Zhen,P’ing-ling-hsü,ping ling,ping ling zhen,平陵,平陵镇', 23.6512600, 114.3432200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16128, 'Pinglin', 'Pinglin', 'Pinglin,Pinglin Zhen,ping lin,ping lin zhen,平林,平林镇', 31.8247600, 112.7093300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16129, 'Pinglin', 'Pinglin', 'P''ing-lin-shih,P''ing-lin-ssu,P''ing-ling,Pinglin,Pinglin Zhen,Pinglishin,P’ing-lin-shih,P’ing-lin-ssu,P’ing-ling,ping lin,ping lin zhen,平林,平林镇', 31.4154500, 113.6053600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16130, 'Pinglidian', 'Pinglidian', 'P''ing-li-tien,Pinglidian,Pinglidian Zhen,P’ing-li-tien,ping li dian,ping li dian zhen,平里店,平里店镇', 37.2890300, 120.0214500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16131, 'Pingliang', 'Pingliang', 'Bing-liong,Binh Luong,Bìng-liòng,Bình Lương,P''ing-liang-hsien,P''ing-liang-shih,Pching-liang,Peng-liang-chhi,Pilian,Pingliang,Pingliang Shi,Pinljan,Pinlyan,Pêng-liâng-chhī,P’ing-liang-hsien,P’ing-liang-shih,ping liang,ping liang shi,pinglyang si,pnglyang,Пинлян,Պիլիան,پنگلیانگ,平凉,平凉市,平涼,平涼市,핑량 시', 35.5391700, 106.6861100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16132, 'Pingli', 'Pingli', 'Pingli,Pingli Zhen,ping li,ping li zhen,平里,平里镇', 29.7366600, 117.6091100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16133, 'Pingle', 'Pingle', 'Chiu-p''ing-lo,Chiu-p’ing-lo,P''ing-lo,P''ing-lo-chen,P''ing-lo-hsien,Pingle,P’ing-lo,P’ing-lo-chen,P’ing-lo-hsien,ping le,平乐', 24.6452200, 110.6430600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16134, 'Pingkan', 'Pingkan', 'Pingkan,Pingkan Zhen,ping kan,ping kan zhen,坪坎,坪坎镇', 33.8637100, 106.9978700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16135, 'Pingjin', 'Pingjin', 'Bintszinba,P''ing-chin-p''u,Ping-ching-pa,Pingjin,Pingjin Zhen,Pingjinpu,P’ing-chin-p’u,ping jin,ping jin zhen,屏锦,屏锦镇', 30.6117600, 107.5449700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16136, 'Hanchang', 'Hanchang', 'Hanchang,P''ing-chiang,Ping-chiang-hsien,Pingjiang,Pingjiang Xian,Pingkiang-hsien,P’ing-chiang,han chang,ping jiang xian,平江县,汉昌', 28.7000000, 113.5833300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16137, 'Pingjiang', 'Pingjiang', 'P''ing-chiang,Pingjiang,P’ing-chiang', 25.9705600, 108.3952800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16138, 'Pinghu', 'Pinghu', 'Pinghu,Pinghu Xiang,ping hu,ping hu xiang,平湖,平湖乡', 30.9090300, 115.3581400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16139, 'Pinghu', 'Pinghu', 'P''ing-hu-chen,Pinghu,Pinghu Zhen,P’ing-hu-chen,ping hu,ping hu zhen,平湖,平湖镇', 26.7373100, 118.7920700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16140, 'Pinghu', 'Pinghu', 'Pinghu,Pinghu Jiedao,ping hu,ping hu jie dao,平湖,平湖街道', 22.6906200, 114.1170300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16141, 'Pinghai', 'Pinghai', 'Pinghai,Pinghai Zhen,ping hai,ping hai zhen,平海,平海镇', 25.1853800, 119.2685100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16142, 'Pinghai', 'Pinghai', 'Pinghai,Pinghai Zhen,Pinghoi,ping hai,ping hai zhen,平海,平海镇', 22.6176200, 114.8720700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16143, 'Pingpu', 'Pingpu', 'P''ing-kou-p''u,Pinggoupu,Pingpu,Pingpu Zhen,P’ing-kou-p’u,ping pu,ping pu zhen,平铺,平铺镇', 31.0100600, 118.3217500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16144, 'Pinggang', 'Pinggang', 'P''ing-kang,P''ing-kang-hsu,Pinggang,Pinggang Zhen,P’ing-kang,P’ing-kang-hsü,ping gang,ping gang zhen,平冈,平冈镇', 21.7547400, 111.8776400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16145, 'Pingfeng', 'Pingfeng', 'Pingfeng,ping feng,平峰', 35.7418200, 105.5619700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16146, 'Pingdu', 'Pingdu', 'P''ing-tu,P''ing-tu-hsien,Pindu,Pingdu,P’ing-tu,P’ing-tu-hsien,Пинду', 36.7844400, 119.9463900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16147, 'Pingdu', 'Pingdu', 'An-fu-hsien,Anfu,Anfu Xian,Pingdu,Pingdu Zhen,an fu xian,ping dou,ping dou zhen,安福县,平都,平都镇', 27.3863000, 114.6101800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16148, 'Pingdingshan', 'Pingdingshan', 'Bing-ding-sang,Binh GJinh Son,Bìng-dīng-săng,Bình Đỉnh Sơn,Chu-ko-chen,Chu-ko-miao,P''ing-ting-shan,P''ing-ting-shan-shih,Pching-ting-san,Pching-ting-šan,Peng-teng-san-chhi,Pindinshan,Pindinshan'',Pindinshan’,Pingdingsano,Pingdingshan,Pingdingsjan,Pingdingŝano,Pêng-téng-san-chhī,P’ing-ting-shan,P’ing-ting-shan-shih,Tekshi choqqiliq tagh shehiri,ping ding shan,ping ding shan shi,pingdingsan si,pyngdyngshan,Пингдингшан,Пиндиншан,Пиндиншань,پنگڈنگشان,پینگدینگشان,平頂山,平頂山市,平顶山,平顶山市,핑딩산 시', 33.7384700, 113.3011900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16149, 'Guanshan', 'Guanshan', 'Guanshan,Guanshan Zhen,P''ing-ting,P''ing-ting-hsien,P''ing-ting-hsien-ch''eng,Pindin,Pingding,Pingding Xian,Piutingchow,P’ing-ting,P’ing-ting-hsien,P’ing-ting-hsien-ch’eng,guan shan,guan shan zhen,ping ding,ping ding xian,冠山,冠山镇,平定,平定县', 37.8081000, 113.5970000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16150, 'Pingding', 'Pingding', 'P''ing-ting,Pingding,Pingding Zhen,P’ing-ting,ping ding,ping ding zhen,平定,平定镇', 22.0135500, 110.4013300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16151, 'Pingchuan', 'Pingchuan', 'Pingchuan,Pingchuan Zhen,Wu-p''ing-hsien,Wu-p’ing-hsien,Wuping,Wuping Xian,ping chuan,ping chuan zhen,wu ping,wu ping xian,平川,平川镇,武平,武平县', 25.0945300, 116.0960100, 'CN', '2013-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16152, 'Pingchao', 'Pingchao', 'P''ing-ch''ao-chen,P''ing-ch''ao-chien,P''ing-ch''ao-shih,Pingchao,Pingchao Zhen,P’ing-ch’ao-chen,P’ing-ch’ao-chien,P’ing-ch’ao-shih,ping chao,ping chao zhen,平潮,平潮镇', 32.1013300, 120.7406700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16153, 'Pingba', 'Pingba', 'Pingba,Pingba Zhen,ping ba,ping ba zhen,坪坝,坪坝镇', 31.9982300, 108.5173700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16154, 'Pingba', 'Pingba', 'P''ing-pa,P''ing-pa-chen,Pingba,Pingba Zhen,P’ing-pa,P’ing-pa-chen,ping ba,ping ba zhen,坪坝,坪坝镇', 31.3152700, 113.3165300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16155, 'Picheng', 'Picheng', 'P''i-ch''eng-chen,Picheng,Picheng Zhen,P’i-ch’eng-chen,pi cheng,pi cheng zhen,埤城,埤城镇', 32.1187400, 119.7038600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16156, 'Xinguan', 'Xinguan', 'P''ien-kuan,P''ien-kuan-hsien,Pianguan,Pianguan Xian,Pienkwanhsien,Pyan''guan'',Pyan’guan’,P’ien-kuan,P’ien-kuan-hsien,Xinguan,Xinguan Zhen,pian guan xian,xin guan,xin guan zhen,偏关县,新关,新关镇', 39.4552700, 111.5300100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16157, 'Piancheng', 'Piancheng', 'P''ien-ch''eng,P''ien-ch''eng-pao,Piancheng,P’ien-ch’eng,P’ien-ch’eng-pao,pian cheng,偏城', 35.9663400, 105.9694800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16158, 'Pengzhai', 'Pengzhai', 'Pengzhai,Pengzhai Zhen,peng zhai,peng zhai zhen,彭寨,彭寨镇', 24.3646300, 115.0809500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16159, 'Longcheng', 'Longcheng', 'Longcheng,Longcheng Zhen,P''eng-tse Hsien,Pengze Xian,P’eng-tse Hsien,long cheng,long cheng zhen,peng ze xian,彭泽县,龙城,龙城镇', 29.8968800, 116.5554600, 'CN', '2014-12-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16160, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Zhen,Pengyang,Pengyang Xian,bai yang,bai yang zhen,peng yang,peng yang xian,彭阳,彭阳县,白阳,白阳镇', 35.8511000, 106.6390000, 'CN', '2015-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16161, 'Penguanzhuang', 'Penguanzhuang', 'P''en-kuan-chuang,Penguanzhuang,Penkwan,P’en-kuan-chuang', 39.4841700, 117.8133300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16162, 'Pengsi', 'Pengsi', 'Pengsi,Pengsi Zhen,peng si,peng si zhen,彭思,彭思镇', 30.2725800, 115.2716500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16163, 'Pengshi', 'Pengshi', 'P''eng-shih,P''eng-shih-ho,Pengshi,Pengshi Zhen,Pengshihho,P’eng-shih,P’eng-shih-ho,peng shi,peng shi zhen,彭市,彭市镇', 30.4531700, 113.1831600, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16164, 'Penglai', 'Penglai', 'P''eng-lai-chen,Penglai,Penglaizhen,Ponlaychzhen'',Pynlaychzhen'',Pynlaychzhen’,Pönlaychzhen’,P’eng-lai-chen,peng lai,蓬莱', 30.5821700, 105.2514100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16165, 'Penglai', 'Penglai', 'Lianmeng,Penglai,Penglai Zhen,lian meng,peng lai,peng lai zhen,联盟,蓬莱,蓬莱镇', 25.1322200, 118.0913900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16166, 'Penglai', 'Penglai', 'P''eng-lai-shih,Penglai,Penglai Zhen,P’eng-lai-shih,peng lai,peng lai zhen,蓬莱,蓬莱镇', 19.5378500, 110.5359800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16167, 'Pengkou', 'Pengkou', 'P''eng-kow,Pengkou,Pengkou Zhen,P’eng-kow,peng kou,peng kou zhen,朋口,朋口镇', 25.5309300, 116.6844500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16168, 'Penghu', 'Penghu', 'Chenban,Penghu,Penghu Zhen,chen ban,peng hu,peng hu zhen,蓬壶,蓬壶镇,陈坂', 25.3830600, 118.1516700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16169, 'Pancheng', 'Pancheng', 'P''an-ch''eng-chi,P''eng-ch''eng-chi,Pancheng,Pancheng Zhen,Pengchengji,P’an-ch’eng-chi,P’eng-ch’eng-chi,pan cheng,pan cheng zhen,盘城,盘城镇', 32.2121800, 118.7081200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16170, 'Pengcheng', 'Pengcheng', 'P''eng-ch''eng-chen,Penchenchzhen'',Penchenchzhen’,Pengcheng,P’eng-ch’eng-chen', 36.4311100, 114.1700000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16171, 'Pendiqing', 'Pendiqing', 'Pendiqing,Pendiqing Xiang,pen de qing,pen de qing xiang,盆地青,盆地青乡', 39.9419100, 112.0038300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16172, 'Peishe', 'Peishe', 'P''ei-she-ts''un,Peishe,Peishe Xiang,P’ei-she-ts’un,pei she,pei she xiang,裴社,裴社乡', 35.2973100, 111.3187900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16173, 'Peicheng', 'Peicheng', 'P''ei,P''ei-ch''eng-chen,P''ei-hsien,Peicheng,Peixian,P’ei,P’ei-ch’eng-chen,P’ei-hsien', 34.7361100, 116.9247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16174, 'Paotai', 'Paotai', 'Paotai,Paotai Zhen,pao tai,pao tai zhen,炮台,炮台镇', 23.5222300, 116.4955300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16175, 'Panzhuang', 'Panzhuang', 'P''an-chia-chuang,P''an-chuang,P''an-chuang-chen,P''ang-chuang,Panerh,Pang-kia-chwang,Panzhuang,Panzhuang Zhen,P’an-chia-chuang,P’an-chuang,P’an-chuang-chen,P’ang-chuang,pan zhuang,pan zhuang zhen,潘庄,潘庄镇', 39.3394300, 117.4682000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16176, 'Dadukou', 'Dadukou', 'Dadukou,Dadukou Jiedao,Dukou,Pan''chzhikhua,Panzhihua,Ta-tu-k''ou,Ta-tu-k’ou,Tu-k''ou,Tu-k''ou-shih,Tu-k’ou,Tu-k’ou-shih,da du kou,da du kou jie dao,Паньчжихуа,大渡口,大渡口街道', 26.5479000, 101.7053900, 'CN', '2014-09-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16177, 'Panyang', 'Panyang', 'Panyang,Panyang Xiang,pan yang,pan yang xiang,泮洋,泮洋乡', 26.5495000, 118.8313000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16178, 'Panxin', 'Panxin', 'Panxin,Panxin Zhen,pan xin,pan xin zhen,盘信,盘信镇', 28.0224300, 109.2362000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16179, 'Qingnianlu', 'Qingnianlu', 'P''an-ch''i,P''an-hsi,P''o-hsi,P''o-hsi-chieh,Panki,Panxi,Panxi Zhen,Posi,P’an-ch’i,P’an-hsi,P’o-hsi,P’o-hsi-chieh,Qingnianlu,pan xi,pan xi zhen,qing nian lu,盘溪,盘溪镇,青年路', 24.2230600, 103.0980600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16180, 'Pantang', 'Pantang', 'Pantang,Pantang Jiedao,pan tang,pan tang jie dao,潘塘,潘塘街道', 30.9979900, 114.8882400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16181, 'Pantang', 'Pantang', 'Pantang,Pantang Zhen,pan tang,pan tang zhen,盘塘,盘塘镇', 29.2147300, 111.5061600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16182, 'Panlong', 'Panlong', 'P''an-shih-chen,P''an-t''o,Pan-shin-chen,Panlong,Panlong Zhen,Panshizhen,P’an-shih-chen,P’an-t’o,pan long,pan long zhen,盘龙,盘龙镇', 30.9065400, 108.7096500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16183, 'Panlong', 'Panlong', 'P''an-lung-chen,Panlong,Panlong Zhen,Panlongchang,P’an-lung-chen,pan long,pan long zhen,盘龙,盘龙镇', 29.5002500, 105.3706600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16184, 'Panlian', 'Panlian', 'I-mi-ssu,Mi-i,Mi-i-chieh,Mi-i-ssu,Miyi,Miyikai,Panlian,pan lian,攀连', 26.8877800, 102.1083600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16185, 'Panjing', 'Panjing', 'Panjing,Panjing Xiang,pan jing,pan jing xiang,泮境,泮境乡', 25.0528600, 116.5282000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16186, 'Panjiawan', 'Panjiawan', 'P''an-chia-wan,Panjiawan,Panjiawan Xiang,P’an-chia-wan,pan jia wan,pan jia wan xiang,潘家湾,潘家湾乡', 30.2210900, 111.1991900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16187, 'Pangushan', 'Pangushan', 'P''an-ku-shan,Pangushan,Pangushan Zhen,P’an-ku-shan,pan gu shan,pan gu shan zhen,盘古山,盘古山镇', 25.6428000, 115.4223400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16188, 'Pangguang', 'Pangguang', 'P''ang-kuang,P''ang-kuang-chen,P''ang-lung,P''ang-lung-chen,Pangguang,Pangguang Zhen,P’ang-kuang,P’ang-kuang-chen,P’ang-lung,P’ang-lung-chen,pang guang,pang guang zhen,庞光,庞光镇', 34.0288900, 108.6619400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16189, 'Panggezhuang', 'Panggezhuang', 'P''ang-ko-chuang,Panggezhuang,P’ang-ko-chuang', 39.8047200, 117.1661100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16190, 'Pandu', 'Pandu', 'P''an-tu,Pandu,Pandu Xiang,P’an-tu,pan du,pan du xiang,潘渡,潘渡乡', 26.2363900, 119.4502600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16191, 'Jiangkou', 'Jiangkou', 'Hu Chiang Kou,Hu-chiang-k''ou-hsu,Hu-chiang-k’ou-hsü,Jiangkou,Jiangkou Zhen,P''a-chiang-k''ou,P''a-chiang-k''ou-hsu,P''ao-chiang-kou,P''ao-chiang-kou-hsu,Pajiangkou,Pakonghow,P’a-chiang-k’ou,P’a-chiang-k’ou-hsü,P’ao-chiang-kou,P’ao-chiang-kou-hsü,jiang kou,jiang kou zhen,江口,江口镇', 23.7369400, 113.2211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16192, 'Paizhou', 'Paizhou', 'P''ai-chou,Pae Chu,Paichow,Paizhou,Paizhou Zhen,Peo Cho,P’ai-chou,pai zhou,pai zhou zhen,牌洲,牌洲镇', 30.2094900, 113.9278400, 'CN', '2015-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16193, 'Fatou', 'Fatou', 'Fatou,Fatou Xiang,P''ai-t''ou-chen,Paitou,P’ai-t’ou-chen,fa tou,筏头', 30.5463900, 119.8516700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16194, 'Paitou', 'Paitou', 'P''ai-t''ou-chen,Paitou,Paitou Zhen,Paitow,P’ai-t’ou-chen,pai tou,pai tou zhen,牌头,牌头镇', 29.6062400, 120.1507800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16195, 'Paitan', 'Paitan', 'P''ai-t''an-hsu,Paitan,Paitan Zhen,P’ai-t’an-hsü,pai tan,pai tan zhen,派潭,派潭镇', 23.4861500, 113.7711500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16196, 'Paishi', 'Paishi', 'P''ai-shih,Paishi,Paishi Zhen,P’ai-shih,pai shi,pai shi zhen,排市,排市镇', 29.7220000, 115.0545100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16197, 'Paipu', 'Paipu', 'P''ai-p''u-shih,Paipu,Paipu Zhen,P’ai-p’u-shih,pai pu,pai pu zhen,排浦,排浦镇', 19.6398100, 109.1586100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16198, 'Pailou', 'Pailou', 'P''ai-lou-kang,Pailou,Pailou Xiang,P’ai-lou-kang,pai lou,pai lou xiang,牌楼,牌楼乡', 31.0544700, 112.2820700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16199, 'Paibu', 'Paibu', 'P''ai-pu,Paibu,Paibu Zhen,P’ai-pu,pai bu,pai bu zhen,排埠,排埠镇', 28.4338800, 114.2481700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16200, 'Paibi', 'Paibi', 'P''ai-pi,Paibi,Paibi Xiang,P’ai-pi,pai bi,pai bi xiang,排碧,排碧乡', 28.3833300, 109.5333300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16201, 'Oumiao', 'Oumiao', 'Ou-chia-miao,Ou-chia-tien,Oukiamiao,Oumiao,Oumiao Zhen,ou miao,ou miao zhen,欧庙,欧庙镇', 31.8611900, 112.1678300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16202, 'Oujiangcha', 'Oujiangcha', 'Ou-chiang-ch''a,Ou-chiang-ch’a,Oujiangcha,Oujiangcha Zhen,ou jiang cha,ou jiang cha zhen,欧江岔,欧江岔镇', 28.4688200, 112.5958900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16203, 'Oljoq', 'Oljoq', 'Ao-le-chao-ch''i,Ao-le-chao-ch’i,Aolezhaoqi Zhen,Etuokeqian Qi,Oljoq,Otog Qianqi,ao lei zhao qi,ao lei zhao qi zhen,e tuo ke qian qi,敖勒召其,敖勒召其镇,鄂托克前旗', 38.1797900, 107.4750600, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16204, 'Obo', 'Obo', 'Ebao,Ebao Zhen,Ebo,Hongtu,Hongtucheng,O-po,O-po-ch''eng,O-po-ch’eng,Obo,e bao,e bao zhen,hong tu,hong tu cheng,峨堡,峨堡镇,红土,红土城', 37.9646300, 100.9329900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16205, 'Nyinqug', 'Nyinqug', 'Ningxiu,Ningxiu Longwaduo,Ningxiu Xiang,Nyinqug,ning xiu,ning xiu long wa duo,ning xiu xiang,宁秀,宁秀乡,宁秀龙哇多', 35.2085400, 100.8528600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16206, 'Nurigai', 'Nurigai', 'Nurigai,Nurigai Sumu,nu ri gai,nu ri gai su mu,努日盖,努日盖苏木', 39.4943200, 101.0804000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16207, 'Nuojiang', 'Nuojiang', 'Nuojiang,T''ung-chiang,T''ung-chiang-hsien,Tongjiang,Tungkiang,Tungkiang-hsien,T’ung-chiang,T’ung-chiang-hsien,nuo jiang,诺江', 31.9156200, 107.2427300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16208, 'Nübu', 'Nubu', 'Nubu,Nubu Zhen,Nübu,Nübu Zhen,nu bu,nu bu zhen,女埠,女埠镇', 29.2625900, 119.4611400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16209, 'Guang’an', 'Guang''an', 'Guang''an,Guang’an,Kuang-an,Kuang-an-hsien,Kwang-an-hsien,Kwangan,Kwanganchow,Nonghui,guang an,广安', 30.4741300, 106.6369600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16210, 'Nizui', 'Nizui', 'Ni-tsui,Nizui,Nizui Zhen,ni ju,ni ju zhen,泥咀,泥咀镇', 32.0248300, 112.0172000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16211, 'Niyang', 'Niyang', 'Niyang,Niyang Zhen,Niyangzhen,ni yang,ni yang zhen,泥阳,泥阳镇', 33.8194400, 105.8213900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16212, 'Nixi', 'Nixi', 'Ni-hsi,Ni-hsi-ch''ung,Ni-hsi-ch’ung,Nixi,Nixi Xiang,Nixi Zhen,Nixichong,ni xi,ni xi xiang,ni xi zhen,泥溪,泥溪乡,泥溪镇', 29.7922100, 116.8640600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16213, 'Niutian', 'Niutian', 'Niu-t''ien,Niu-t''ien-hsu,Niu-t’ien,Niu-t’ien-hsü,Niutian,Niutian Zhen,niu tian,niu tian zhen,牛田,牛田镇', 27.3012500, 115.7231900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16214, 'Niutang', 'Niutang', 'Niu-t''ang-ch''iao,Niu-t’ang-ch’iao,Niutang,Niutang Zhen,Niutangqiao,niu tang,niu tang zhen,牛塘,牛塘镇', 31.7342500, 119.8943100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16215, 'Niushou', 'Niushou', 'Niushou,Niushou Zhen,niu shou,niu shou zhen,牛首,牛首镇', 32.0984400, 111.9693800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16216, 'Niushan', 'Niushan', 'Donghai Zhen,Niu-shan-chen,Niu-shan-chuang,Niushan,Tung-hai,dong hai zhen,niu shan,东海镇,牛山', 34.5235200, 118.7649500, 'CN', '2015-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16217, 'Niujiapai', 'Niujiapai', '', 39.5222200, 117.2894400, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16218, 'Niudaokou', 'Niudaokou', '', 39.7861100, 117.2522200, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16219, 'Niuchehe', 'Niuchehe', 'Daifuyu,Niu-ch''e-ho,Niu-ch’e-ho,Niuchehe,Niuchehe Xiang,da fu yu,niu che he,niu che he xiang,大富堉,牛车河,牛车河乡', 29.0484900, 110.9749700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16220, 'Niubitan', 'Niubitan', 'Niu-pi-t''an,Niu-pi-t’an,Niubitan,Niubitan Zhen,niu bi tan,niu bi tan zhen,牛鼻滩,牛鼻滩镇', 29.0086200, 111.8602400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16221, 'Nishi', 'Nishi', 'Hupingshan,Hupingshan Zhen,Ni-sha,Ni-sha-shih,Ni-shih,Nishi,hu ping shan,hu ping shan zhen,ni shi,壶瓶山,壶瓶山镇,泥市', 29.9355200, 110.7782300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16222, 'Ningzhou', 'Ningzhou', 'Chengjiao,Hua-ning-hsien,Huaning,Huaning Xian,Li,Li-hsien,Ning-chou,Ningchow,Ningzhou,Ningzhou Zhen,cheng jiao,hua ning,hua ning xian,ning zhou,ning zhou zhen,华宁,华宁县,城郊,宁州,宁州镇', 24.1877000, 102.9170000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16223, 'Shunling', 'Shunling', 'Ning-yuan-hsien,Ning-yüan-hsien,Ningyuan,Shunling,Shunlingzhen,shun ling,舜陵', 25.5916700, 111.9302800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16224, 'Ningyang', 'Ningyang', 'Ning-yang-hsien,Ningyang,Ninyan', 35.7641700, 116.7913900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16225, 'Yutan', 'Yutan', 'Ning-hsiang,Ning-hsiang-hsien,Ningsiang,Ningsiang-hsien,Ningxiang,Ningxiang Xian,Yutan,ning xiang xian,yu tan,宁乡县,玉潭', 28.2583100, 112.5604800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16226, 'Xinning', 'Xinning', 'Ning,Ning Xian,Ning-chou,Ning-hsien,Ningchow,Ningxian,Ninsyan'',Ninsyan’,Xinning,ning xian,xin ning,宁县,新宁', 35.4950600, 107.9203800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16227, 'Ningxi', 'Ningxi', 'Ning-ch''i,Ning-ch’i,Ning-hsi,Ningxi,Ningxi Zhen,ning xi,ning xi zhen,宁溪,宁溪镇', 28.5896700, 120.9705900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16228, 'Fenghuang', 'Fenghuang', 'Feng-huang-ts''un,Feng-huang-ts’un,Fenghuang,Fenghuang Zhen,Nin''u,Ning-wu-hsien,Ningwu,Ningwu Xian,Ningwufu,Nin’u,Ting-wu,feng huang,feng huang zhen,ning wu xian,凤凰,凤凰镇,宁武县', 38.9978000, 112.2977900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16229, 'Hanyuan', 'Hanyuan', 'Ch''iang-chou,Ch’iang-chou,Hanyuan,Hanyuan Zhen,Ning-ch''iang,Ning-ch''iang-hsien,Ning-ch’iang,Ning-ch’iang-hsien,Ningkiang,Ningkiang-hsien,Ningkiangchow,Ningqiang,Ningqiang Xian,Nintsyan,han yuan,han yuan zhen,ning qiang,ning qiang xian,宁强,宁强县,汉源,汉源镇', 32.8340000, 106.2503500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16230, 'Ningling Chengguanzhen', 'Ningling Chengguanzhen', 'Chiu-ning-ling,Nin-lin,Ning-ling-hsien,Ningling,Ningling Chengguanzhen,Ninlinghsien,ning ling cheng guan zhen,宁陵城关镇', 34.4500000, 115.3166700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16231, 'Ningjin', 'Ningjin', 'Ning-chin-so,Ning-ching-so,Ningjin,Ningjin Jiedao,Ningjin Zhen,Ningjinsuo,ning jin,ning jin jie dao,ning jin zhen,宁津,宁津街道,宁津镇', 36.9863000, 122.5020000, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16232, 'Ningjin', 'Ningjin', 'Ning-chin,Ning-ching,Ning-ching-ch''eng-kuan,Ning-ching-ch’eng-kuan,Ning-ching-hsien,Ningjin,Ningtsing,Nintszin,ning jin,宁津', 37.6498500, 116.7932800, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16233, 'Ninghe', 'Ninghe', 'Chiu-ning-ho,Ho-chen,Jiuninghe,Ning-ho,Ning-ho-hsien,Ninghe,Ninghezhen', 39.4619400, 117.7625000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16234, 'Ninghai', 'Ninghai', 'Mou-p''ing,Mou-p''ing-hsien,Mou-p’ing,Mou-p’ing-hsien,Mowping,Muping,Ning-hai,Ninghai,Ninghai Jiedao,Ninghaichow,ning hai,ning hai jie dao,宁海,宁海街道', 37.3842200, 121.6085900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16235, 'Ninghai', 'Ninghai', 'Ning-hai-hsien,Ninghai,ning hai,宁海', 29.2891700, 121.4247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16236, 'Ning’er', 'Ning''er', 'Ning''er,Ning-erh,Ning-erh-chen,Ning-erh-hsien,Ning’er,P''u-erh,Pu''er,Pu-erh-pu,Puerhfu,Pu’er,P’u-erh,ning er,宁洱', 23.0405300, 101.0368300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16237, 'Ningdun', 'Ningdun', 'Ningdun,Ningdun Zhen,ning dun,ning dun zhen,宁墩,宁墩镇', 30.4588900, 119.1083300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16238, 'Ningchegu', 'Ningchegu', 'Dahebei,Ning-ch''e-ku,Ning-ch’e-ku,Ningchegu,Ta-ho-pei,ning che gu,宁车沽', 39.1588900, 117.6625000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16239, 'Ningbo', 'Ningbo', 'Chiang-pei-an,Gorad Ninbo,Leng-pho-chhi,Lêng-pho-chhī,NGB,Nen-po-su,Ninbo,Ning-hsien,Ning-po,Ning-po-shih,Ningbo,Ningbo Shi,Ningbó,Ningpo,Ninh Ba,Nèn-pô-sṳ,Nìng-pŏ̤,Yin-hsien,hning paw,nangbw,ning bo,ning bo shi,ningbo si,nngbw,nynghbw,Горад Нінбо,Нинбо,Нингбо,Нінбо,نانگبو,ننگبو,نىڭبو شەھىرى,نينغبو,หนิงปัว,宁波,宁波市,寧波,寧波市,닝보 시', 29.8781900, 121.5494500, 'CN', '2014-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16240, 'Nijiangping', 'Nijiangping', 'Nijiangping,Nijiangping Xiang,ni jiang ping,ni jiang ping xiang,逆江坪,逆江坪乡', 28.7000000, 111.5166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16241, 'Xinjie', 'Xinjie', 'Ni-hsu-chuang,Ni-hsü-chuang,Ni-hu-chuang,Nihuzhuang,Xinjie,Xinjie Zhen,ni hu zhuang,xin jie,xin jie zhen,倪浒庄,新街,新街镇', 32.3365500, 120.1101700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16242, 'Nieying', 'Nieying', 'Nieh-ying,Nieh-ying-chen,Nieying,Nieying Zhen,nie ying,nie ying zhen,聂营,聂营镇', 39.1263900, 113.1330600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16243, 'Nieqiao', 'Nieqiao', 'Nieh-ch''iao,Nieh-ch’iao,Nieqiao,Nieqiao Zhen,nie qiao,nie qiao zhen,聂桥,聂桥镇', 29.3923700, 115.6525500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16244, 'Niejiahe', 'Niejiahe', 'Nieh-chia-ho,Niejiahe,Niejiahe Zhen,nie jia he,nie jia he zhen,聂家河,聂家河镇', 30.3047400, 111.2957900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16245, 'Nianyushan', 'Nianyushan', 'Nianyushan,Nianyushan Zhen,Nien-yu-shan,Nien-yü-shan,Yeh-yu-shan,Yeh-yü-shan,Yen-yu-shan,Yen-yü-shan,nian yu shan,nian yu shan zhen,鲇鱼山,鲇鱼山镇', 29.2067100, 117.1037800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16246, 'Nianqiao', 'Nianqiao', 'Nianqiao,Nien-ch''iao,Nien-ch’iao,Tung-nien-ch''iao,Tung-nien-ch’iao,nian qiao,埝桥', 34.8083000, 109.8613300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16247, 'Niangxi', 'Niangxi', 'Hsin-shao,Niang-ch''i,Niang-ch''i-chen,Niang-ch’i,Niang-ch’i-chen,Niang-hsi,Niangxi,Xinshao,niang xi,酿溪', 27.3085600, 111.4318600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16248, 'Oula', 'Oula', 'Ngura,Ngüra,Ogura,Ogüra,Ou-la,Oula,Oula Xiang,ou la,ou la xiang,欧拉,欧拉乡', 34.0765400, 101.7218300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16249, 'Neixiang Chengguanzhen', 'Neixiang Chengguanzhen', 'Nei-hsiang,Nei-hsiang-hsien,Nei-siang,Neixiang,Neixiang Chengguanzhen,nei xiang cheng guan zhen,内乡城关镇', 33.0466700, 111.8436100, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16250, 'Neixi', 'Neixi', 'Neixi,Neixi Xiang,nei xi,nei xi xiang,内溪,内溪乡', 28.9048300, 109.3245000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16251, 'Neijiang', 'Neijiang', 'Lai-kang-chhi,Lāi-kang-chhī,Nehjczjan,Nei-chiang,Nei-chiang-hsien,Nei-chiang-shih,Neijiang,Neikiang,Neikianghsien,Nej-tiang,Nej-ťiang,Nejgjan,Nejĝjan,Noi Giang,Noi-geng,Nui-kong-su,Nui-kông-sṳ,Nô̤i-gĕ̤ng,Nội Giang,nayjyang,nei jiang,nei jiang shi,neijang si,Нејђанг,Нэйцзян,نائجیانگ,نایجیانگ,內江,内江,内江市,네이장 시', 29.5835400, 105.0621600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16252, 'Neihuang Chengguanzhen', 'Neihuang Chengguanzhen', 'Nei-huang-hsien,Neihuang,Neihuang Chengguanzhen,nei huang cheng guan zhen,内黄城关镇', 35.9508300, 114.9022200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16253, 'Nawu', 'Nawu', 'Na-wu-hsu,Na-wu-hsü,Nawu,Nawu Zhen,na wu,na wu zhen,那务,那务镇', 22.0038900, 110.5874000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16254, 'Napo Chengxiangzhen', 'Napo Chengxiangzhen', 'Chanpin-hsien,Chen-pien,Chen-pien-hsien,Mu-pien,Mu-pien-hsien,Napo,Napo Chengxiangzhen,na po cheng xiang zhen,那坡城厢镇', 23.4794400, 105.7915700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16255, 'Naodian', 'Naodian', 'Nao-tien,Nao-tien-chi,Naodian,Naodian Zhen,nao dian,nao dian zhen,闹店,闹店镇', 33.8544000, 113.2110300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16256, 'Nanzhou', 'Nanzhou', 'Nan,Nan Xian,Nan-hsien,Nanchowting,Nanxian,Nanzhou,nan xian,nan zhou,南县,南洲', 29.3595500, 112.4024300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16257, 'Nanzhao Chengguanzhen', 'Nanzhao Chengguanzhen', 'Chengguan Zhen,Li-ch''ing-tien,Li-ch’ing-tien,Nan-chao,Nan-chao-hsien,Nan-shao,Nanzhao,Nanzhao Chengguanzhen,nan zhao,nan zhao cheng guan zhen,南召,南召城关镇', 33.4924900, 112.4272300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16258, 'Nanzhao', 'Nanzhao', 'Chao-an,Chao-an-hsien,Nanzhao,Nanzhao Zhen,Zhao''an,Zhao’an,nan zhao,nan zhao zhen,南诏,南诏镇', 23.7199000, 117.1710300, 'CN', '2013-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16259, 'Nanzhang Chengguanzhen', 'Nanzhang Chengguanzhen', 'Nan-chang,Nan-chang-hsien,Nanzhang,Nanzhang Chengguanzhen,nan zhang cheng guan zhen,南漳城关镇', 31.7839400, 111.8275200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16260, 'Nanzha', 'Nanzha', 'Nan-cha,Nan-cha-chen,Nanzha,Nanzha Zhen,nan zha,nan zha zhen,南闸,南闸镇', 31.8552900, 120.2410500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16261, 'Nanyulinxi', 'Nanyulinxi', 'Nanyulin Xiang,Nanyulinxi,Yu-lin-ts''un,Yü-lin-ts’un,nan yu lin xi,nan yu lin xiang,南榆林乡,南榆林西', 39.2089200, 112.6814200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16262, 'Nanyuan', 'Nanyuan', 'Nan-wan,Nanyuan,Nanyuan Jiedao,nan yuan,nan yuan jie dao,南苑,南苑街道', 39.8033700, 116.3903600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16263, 'Nanyuan', 'Nanyuan', 'Nanyuan,Nanyuan Xiang,nan yuan,nan yuan xiang,南源,南源乡', 27.4884900, 116.4078800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16264, 'Nanyuan', 'Nanyuan', 'Nanyuan,Nanyuan Xiang,nan yuan,nan yuan xiang,南院,南院乡', 27.4772200, 119.7777800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16265, 'Nanyu', 'Nanyu', 'Nan-hsu,Nanyu,Nanyu Zhen,nan yu,nan yu zhen,南屿,南屿镇', 25.9776500, 119.2160000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16266, 'Nanyang', 'Nanyang', 'Nan-yang,Nan-yang-ts''un,Nan-yang-ts’un,Nanyang,Nanyang Zhen,Nanyangcun,nan yang,nan yang zhen,南阳,南阳镇', 31.8738900, 121.7088900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16267, 'Nanyang', 'Nanyang', 'Lam-iong-chhi,Lâm-iông-chhī,NNY,Nam Duong,Nam Dương,Nan''jan,Nan-jang,Nan-yang-shih,Nang-iong,Nanjang,Nanyan,Nanyang,Nanyang i Henan,Nenyang shehiri,Nàng-iòng,nan yang,nan yang shi,nan-yang si,Наньян,Нанјанг,نانیانگ، ہینان,南阳市,南陽,南陽市,난양 시', 32.9947200, 112.5327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16268, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 27.3933300, 119.5891700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16269, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Xiang,nan yang,nan yang xiang,南阳,南阳乡', 26.3573000, 117.9665700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16270, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Xiang,Nanyangtou,nan yang,nan yang tou,nan yang xiang,南洋,南洋乡,南洋头', 25.4030600, 117.3458300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16271, 'Shaxiaba', 'Shaxiaba', 'Nanyang,Nanyang Zhen,Shaxiaba,nan yang,nan yang zhen,sha xia ba,南阳,南阳镇,沙下坝', 25.3223600, 116.5002300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16272, 'Nanya', 'Nanya', 'Nanya,Nanya Zhen,nan ya,nan ya zhen,南雅,南雅镇', 26.8762500, 118.3074700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16273, 'Nanxun', 'Nanxun', 'Han-hsun,Han-hsün,Nan-hsun,Nan-hsun-chen,Nan-hsün,Nan-hsün-chen,Nanxun,Nanxun Zhen,Nanzin,nan xun,nan xun zhen,南浔,南浔镇', 30.8690200, 120.4199400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16274, 'Nanxing', 'Nanxing', 'Nan-hsing,Nan-hsing-tsun,Nanxing,Nanxing Zhen,nan xing,nan xing zhen,南星,南星镇', 33.7684800, 106.6709700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16275, 'Nanxing', 'Nanxing', 'Nan-hsing,Nan-hsing-shih,Nanxing,Nanxing Zhen,nan xing,nan xing zhen,南兴,南兴镇', 20.8037600, 110.0936300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16276, 'Nanxindian', 'Nanxindian', 'Nan-hsin-tien,Nanxindian,Nanxindian Xiang,nan xin dian,nan xin dian xiang,南辛店,南辛店乡', 35.9695500, 111.3592200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16277, 'Nanxiashu', 'Nanxiashu', 'Hsia-shu,Hsia-shu-chen,Nan-hsia-shu,Nanxiashu,Nanxiashu Jiedao,nan xia shu,nan xia shu jie dao,南夏墅,南夏墅街道', 31.6295100, 119.9393800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16278, 'Nanxiang', 'Nanxiang', 'Nan-hsiang,Nan-hsiang-chen,Nansiang,Nanxiang,Nanxiang Zhen,nan xiang,nan xiang zhen,南翔,南翔镇', 31.2997900, 121.3118000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16279, 'Nanxi', 'Nanxi', 'Nanxi,Nanxi Zhen,nan xi,nan xi zhen,南溪,南溪镇', 31.1134000, 108.8370800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16280, 'Nanxi', 'Nanxi', 'Nan-ch''i,Nan-ch''i-hsien,Nan-ch’i,Nan-ch’i-hsien,Nan-hsi,Nanki,Nanki-hsien,Nanxi,nan xi,南溪', 28.8420900, 104.9795800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16281, 'Nantou', 'Nantou', 'Namtau,Namtow,Nantou,Nantou Jiedao,Pao-an,Ta-hsin-chieh,nan tou,nan tou jie dao,南头,南头街道', 22.5355700, 113.9156400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16282, 'Rengang', 'Rengang', 'Jen-chia-chiang-chen,Jen-chiang,Nan-t''ung-kang,Nan-t’ung-kang,Nantonggang,Rengang,Rengang Jiedao,ren gang,ren gang jie dao,任港,任港街道', 32.0106500, 120.8346900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16283, 'Nantong', 'Nantong', 'Lam-thong-chhi,Lâm-thong-chhī,NTG,Nam Thong,Nam Thông,Nan''tun,Nan-t''ung,Nan-t''ung-hsien,Nan-t''ung-shih,Nan-tchung,Nan-t’ung,Nan-t’ung-hsien,Nan-t’ung-shih,Nang-tung,Nantong,Nantun,Nantung,Nentung shehiri,Nàng-tŭng,T''ung-chou,Tunchow,Tungchow,T’ung-chou,hna nthng,nan tong,nan tong shi,nantang,nantung si,nantwng,Нантун,Нантунг,Наньтун,نانتانگ,نانتونگ,หนานทง,南通,南通市,난퉁 시', 32.0302800, 120.8747200, 'CN', '2014-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16284, 'Nantong', 'Nantong', 'Nantong,Nantong Zhen,nan tong,nan tong zhen,南通,南通镇', 25.9384300, 119.2528100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16285, 'Nantian', 'Nantian', 'Nan-t''ien,Nan-t''ien-shih,Nan-t’ien,Nan-t’ien-shih,Nantian,Nantian Zhen,nan tian,nan tian zhen,南田,南田镇', 27.9209200, 119.9568500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16286, 'Nantang', 'Nantang', 'Nantang,Nantang Zhen,nan tang,nan tang zhen,南塘,南塘镇', 22.9106700, 115.9135100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16287, 'Nantang', 'Nantang', 'Nantang,Nantang Zhen,nan tang,nan tang zhen,南塘,南塘镇', 22.0619200, 110.7890200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16288, 'Nanshui', 'Nanshui', 'Nanshui,Nanshui Zhen,nan shui,nan shui zhen,南水,南水镇', 22.0325800, 113.2402500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16289, 'Nanshu', 'Nanshu', 'Nanshu,Nanshu Zhen,nan shu,nan shu zhen,南墅,南墅镇', 37.0201400, 120.3373100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16290, 'Nanshenzao', 'Nanshenzao', 'Nan-shen-tsao,Nanshenzao,Nanshenzao Zhen,nan chen zao,nan chen zao zhen,南沈灶,南沈灶镇', 32.7833300, 120.5333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16291, 'Nansheng', 'Nansheng', 'Nancheng Jiedao,Nansheng,nan sheng,nan sheng jie dao,南盛,南盛街道', 21.7327900, 110.7081300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16292, 'Nanshe', 'Nanshe', 'Hsin-nan-she,Nanshe,Nanshe Xiang,nan she,南社', 34.7732000, 109.1114900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16293, 'Nanshan', 'Nanshan', 'Nan-shan-pa,Nanshan,Nanshan Zhen,Nanshanba,nan shan,nan shan zhen,南山,南山镇', 25.5990500, 116.4961000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16294, 'Nanshan', 'Nanshan', 'Nanshan,Nanshan Zhen,nan shan,nan shan zhen,南山,南山镇', 26.6198600, 118.3247000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16295, 'Nansha', 'Nansha', 'Nansha,nan sha,南沙', 23.1803700, 102.8333000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16296, 'Nanri', 'Nanri', 'Nanri,Nanri Zhen,nan ri,nan ri zhen,南日,南日镇', 25.2171900, 119.4784000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16297, 'Nanrenfu', 'Nanrenfu', '', 39.6461100, 117.1916700, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16298, 'Nanquan', 'Nanquan', 'Kuan-ch''uan,Kuan-ch’uan,Lan-ch''uan-ts''un,Lan-ch’üan-ts’un,Nan-ch''uan,Nan-ch’üan,Nanquan,Nanquan Xiang,nan quan,nan quan xiang,南泉,南泉乡', 39.4204200, 113.1771900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16299, 'Nanqiu', 'Nanqiu', 'Nanqiu,Nanqiu Xiang,nan jiao,nan jiao xiang,南湫,南湫乡', 36.8995100, 106.7233900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16300, 'Nanqiao', 'Nanqiao', 'Nan-ch''iao,Nan-ch''iao-shih,Nan-ch’iao,Nan-ch’iao-shih,Nanqiao,Nanqiao Zhen,nan qiao,nan qiao zhen,南桥,南桥镇', 18.6742300, 110.1421100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16301, 'Pucheng', 'Pucheng', 'Fu-chang,Nanpu,Nanpu Zhen,P''u-ch''eng-hsien,Pucheng,Pucheng Xian,P’u-ch’eng-hsien,nan pu,nan pu zhen,pu cheng,pu cheng xian,南浦,南浦镇,浦城,蒲城县', 27.9233300, 118.5333300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16302, 'Nanpu', 'Nanpu', 'Nanpu,Nanpu Xiang,nan pu,nan pu xiang,南浦,南浦乡', 24.2547200, 117.5463900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16303, 'Yongle', 'Yongle', 'Nan''pin,Nanping,Nan’pin,Yongle,yong le,永乐', 33.2646500, 104.2327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16304, 'Nanping', 'Nanping', 'Nanping,Nanping Xiang,nan ping,nan ping xiang,南坪,南坪乡', 30.4306700, 108.7943600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16305, 'Nanping', 'Nanping', 'Chiu-kung-an,Kung-an,Kung-an-hsien,Nanping,Nanping Zhen,nan ping,nan ping zhen,南平,南平镇', 29.9094800, 112.0741300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16306, 'Nanping', 'Nanping', 'Lam-peng-chhi,Lâm-pêng-chhī,Nam Binh,Nam Bình,Nam-phin-su,Nan''pin,Nan-p''ing-hsien,Nan-p''ing-hsien-ch''eng,Nan-p''ing-shih,Nan-pching,Nan-p’ing-hsien,Nan-p’ing-hsien-ch’eng,Nan-p’ing-shih,Nang-bing,Nanping,Nenping shehiri,Nàm-phìn-sṳ,Nàng-bìng,Yenping,Yenping-fu,nan ping,nan ping shi,nanping si,nanpng,nanpyng,Наньпин,نانپنگ,نانپینگ,南平,南平市,난핑 시', 26.6450000, 118.1736100, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16307, 'Nanping', 'Nanping', 'Nanping,Nanping Zhen,nan ping,nan ping zhen,南屏,南屏镇', 22.2257000, 113.4970100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16308, 'Nanpi', 'Nanpi', 'Nan-p''i-ch''eng-kuan,Nan-p''i-hsien,Nan-p’i-ch’eng-kuan,Nan-p’i-hsien,Nanpi,nan pi,南皮', 38.0333300, 116.7000000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16309, 'Nanniu', 'Nanniu', 'Nan-niu-ts''un,Nan-niu-ts’un,Nanniu,Nanniu Xiang,Nanniutun,nan niu,nan niu xiang,南牛,南牛乡', 38.1967700, 114.6410300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16310, 'Nanning', 'Nanning', 'Lam-leng-chhi,Lâm-lêng-chhī,NNG,Nam Ninh,Nam-nen-su,Namzningz,Nan''nin,Nan-ning,Nan-ning-shih,Nang-ning,Nanin,Naning,Naningas,Naningo,Nannin,Nannina,Nanning,Nanning Shi,Naņnina,Nàm-nèn-sṳ,Nàng-nìng,Yung-ning,Yung-ning-hsien,hnan hning,nan ning,nan ning shi,nananinga,nanning si,nannyng,nanyng,nanyngh,Нанин,Нанинг,Наньнин,Наньнін,ناننینگ,نانينغ,نانینگ,نان‌نینگ,نەننىڭ شەھىرى,नाननींग,หนานหนิง,ནན་ཉིང་གྲོང་ཁྱེར།,南宁,南宁市,南寧,南寧市,난닝 시', 22.8166700, 108.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16311, 'Nanmuping', 'Nanmuping', '', 27.3111100, 109.6786100, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16312, 'Nanmo', 'Nanmo', 'Nanmo,Nanmo Zhen,Nanmozhuang,nan mo,nan mo zhen,南莫,南莫镇', 32.5948400, 120.2769100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16313, 'Nanmiao', 'Nanmiao', 'Nanmiao,Nanmiao Xiang,nan miao,nan miao xiang,南庙,南庙乡', 27.6879300, 114.4127600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16314, 'Nanmeng', 'Nanmeng', 'Nan-meng-chen,Nanmeng,Nanmeng Zhen,nan meng,nan meng zhen,南孟,南孟镇', 38.2058400, 114.7760500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16315, 'Nanmaizhu', 'Nanmaizhu', '', 39.5025000, 117.7447200, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16316, 'Nanma', 'Nanma', 'I-yuan,I-yüan,Nanma,Nanma Zhen,Yiyuan,nan ma,nan ma zhen,南麻,南麻镇', 36.1847800, 118.1548600, 'CN', '2014-10-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16317, 'Quanfu', 'Quanfu', 'Nan-ma-shih,Nanma,Nanma Zhen,Quanfu,nan ma zhen,quan fu,南马镇,泉府', 29.1039000, 120.2201700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16318, 'Nanlu', 'Nanlu', 'Nanlu,nan lu,南路', 30.6406200, 119.8716900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16319, 'Nanlü', 'Nanlu', 'Nam Lu,Namli,Nan-ko-shih,Nan-lu-shih,Nan-lü-shih,Nanlu,Nanlu Zhen,Nanlü,Nanlü Zhen,nan lu,nan lu zhen,南吕,南吕镇', 19.2501100, 110.0754500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16320, 'Nanlong', 'Nanlong', 'Nan-pu,Nan-pu-hsien,Nanbu,Nanlong,nan long,南隆', 31.3533300, 106.0630900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16321, 'Nanlinqiao', 'Nanlinqiao', 'Nan-lin-ch''iao,Nan-lin-ch’iao,Nanlinqiao,Nanlinqiao Zhen,nan lin qiao,nan lin qiao zhen,南林桥,南林桥镇', 29.5723500, 114.3484300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16322, 'Jishan', 'Jishan', 'Jishan,Nan-ling-hsien,Nanling,ji shan,籍山', 30.9214900, 118.3301700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16323, 'Nanling', 'Nanling', 'Nanling,Nanling Zhen,nan ling,nan ling zhen,南岭,南岭镇', 23.3221500, 115.4061600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16324, 'Nanle Chengguanzhen', 'Nanle Chengguanzhen', 'Nan''yue,Nan-lo,Nan-lo-hsien,Nanle,Nanle Chengguanzhen,Nan’yue,nan le cheng guan zhen,南乐城关镇', 36.0761600, 115.1990500, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16325, 'Nanlang', 'Nanlang', 'Namlong,Nan-lang-hsu,Nan-lang-hsü,Nanlang,Nanlang Zhen,nan lang,nan lang zhen,南朗镇,南蓢', 22.4917100, 113.5373600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16326, 'Nankun', 'Nankun', 'Nan-chen-shih,Nan-k''un-shih,Nan-k’un-shih,Nankun,Nankun Zhen,nan kun,nan kun zhen,南坤,南坤镇', 19.3211900, 109.9421300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16327, 'Nankou', 'Nankou', 'Nankou,nan kou,南口', 26.6261600, 117.4184300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16328, 'Nankou', 'Nankou', 'Nan-k''ou-hsu,Nan-k’ou-hsü,Nankou,Nankou Zhen,nan kou,nan kou zhen,南口,南口镇', 24.2743700, 115.9875300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16329, 'Nankengzai', 'Nankengzai', 'Nan-k''eng-tzu,Nan-k’eng-tzu,Nankengzai,nan keng zi,南坑仔', 26.2833300, 117.8833300, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16330, 'Nankeng', 'Nankeng', 'Nan-k''eng-hsu,Nan-k’eng-hsü,Nankeng,Nankeng Xiang,nan keng,nan keng xiang,南坑,南坑乡', 26.6038400, 115.6684600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16331, 'Nankang', 'Nankang', 'Hingtzu,Hsing-tzu,Hsing-tzu-hsien,Nan-k''ang-chen,Nan-k’ang-chen,Nangkang,Nankang,Nankang Zhen,Nankang-fu,Singtze,Singtze-hsien,Tsingtzeh,Tsingtzehsien,Xingzi,Xingzi Xian,nan kang,nan kang zhen,xing zi xian,南康,南康镇,星子县', 29.4465400, 116.0406800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16332, 'Nanjing', 'Nanjing', 'Gorad Nankin,Lâm-kiaⁿ-chhī,NKG,Nam Kinh,Nam-kin-su,Namkin,Nan''czin,Nan''zhin,Nan-ching,Nan-ching-shih,Nanchino,Nanchinum,Nandzing,Nandzjina,Nandžing,Nang-ging,Nanjing,Nanjing Shi,Nankijn,Nankin,Nankinas,Nanking,Nankingo,Nankín,Nanquim,Nanquin,Nanquín,Nantsin''nk,Nanzging,Naņdzjina,Nàm-kîn-sṳ,Nàng-gĭng,hnan cing,namgyeong,nan jing,nan jing shi,nanajiga,nanajinga,nancin,nanjina,nanjing,nanjing si,nanjinga,nanjng,nanjyng,nanjyngh,nʼngyng,Ναντσίνγκ,Горад Нанкін,Нанкин,Нанкинг,Нанкін,Наньжин,Наньцзин,Нәнҗиң,Նանկին,נאנגינג,نانجنگ,نانجينغ,نانجینگ,نەنجىڭ شەھىرى,नांजिंग,नानजिंग,नान्जिङ,ਨਾਨਜਿੰਗ,நாஞ்சிங்,നാൻജിങ്,หนานจิง,နန်ကျင်းမြို့,ნანკინი,南京,南京市,난징,난징 시,남경', 32.0616700, 118.7777800, 'CN', '2017-06-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16333, 'Nanjing', 'Nanjing', 'Nan-ching,Nan-ching-hsu,Nan-ching-hsü,Nanjing,Nanjing Zhen,Nankin,nan jing,nan jing zhen,Нанкин,南迳,南迳镇', 24.6862900, 114.4012900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16334, 'Nanjie', 'Nanjie', 'Guangning,Kuang-ning,Kuang-ning-hsien,Kwongning,Kwongning-hsien,Nan-chieh,Nan-chieh-chen,Nanjie,Nanjie Zhen,nan jie,nan jie zhen,南街,南街镇', 23.6341400, 112.4347800, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16335, 'Nanjiao', 'Nanjiao', 'Nanjiao,Nanjiao Xiang,nan jiao,nan jiao xiang,南窖,南窖乡', 39.7646400, 115.8399300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16336, 'Nanjiangkou', 'Nanjiangkou', 'Nan-chiang-k''ou,Nan-chiang-k’ou,Nanjiangkou,Nanjiangkou Zhen,nan jiang kou,nan jiang kou zhen,南江口,南江口镇', 23.1257900, 111.8100300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16337, 'Nanjiang', 'Nanjiang', 'Nan''tszyan,Nan-chiang,Nan-chiang-hsien,Nanjiang,Nanjiang Xian,Nanjiang Zhen,Nankiang,Nankiang-hsien,Nan’tszyan,nan jiang,nan jiang xian,nan jiang zhen,南江,南江县,南江镇', 32.3538900, 106.8323800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16338, 'Nanjian', 'Nanjian', 'Nan-chien,Nan-chien-chen,Nan-chien-i-tsu-tzu-chih-hsien,Nanjian,Nankien,nan jian,南涧', 25.0480100, 100.5322400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16339, 'Nanjia', 'Nanjia', 'Nan-chia,Nan-chia-ts''un,Nan-chia-ts’un,Nanjia,Nanjia Zhen,nan gu,nan gu zhen,南贾,南贾镇', 35.8111400, 111.3672000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16340, 'Zhujiaqiao', 'Zhujiaqiao', 'Chu-chia-ch''iao,Chu-chia-ch’iao,Nan-chi,Nanji,Nanji Xiang,Nanjixiang,Zhujiaqiao,nan ji,nan ji xiang,zhu jia qiao,南极,南极乡,朱家桥', 30.3991700, 119.0677800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16341, 'Nanhuatang', 'Nanhuatang', 'Nan-hua-chen,Nanhuatang,Nanhuatang Zhen,nan hua tang,nan hua tang zhen,南化塘,南化塘镇', 33.1155900, 110.9097300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16342, 'Nanhuang', 'Nanhuang', 'Nan Hwang,Nan-huang-chi,Nanhuang,Nanhuang Zhen,nan huang,nan huang zhen,南黄,南黄镇', 36.9781300, 121.7924800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16343, 'Nanhu', 'Nanhu', 'Nanhu,Nanhu Zhen,nan hu,nan hu zhen,南湖,南湖镇', 35.3376900, 105.9603700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16344, 'Nanhezhong', 'Nanhezhong', 'Nan-ho-chung,Nanhezhong,Nanhezhong Zhen,nan he zhong,nan he zhong zhen,南河种,南河种镇', 39.4854200, 113.2573500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16345, 'Nanheng', 'Nanheng', 'Nanheng,Nanheng Xiang,nan heng,nan heng xiang,南亨,南亨乡', 24.7020200, 114.7979900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16346, 'Nanhe', 'Nanhe', 'Nanhe,Nanhe Zhen,nan he,nan he zhen,南河,南河镇', 34.2500000, 119.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16347, 'Nangu', 'Nangu', 'Nan-ku-ch''eng,Nan-ku-ch’eng,Nangu,Nangu Zhen,Nangucheng,nan gu,nan gu zhen,南古,南古镇', 38.5391400, 100.4599500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16348, 'Guantao', 'Guantao', 'Guantao,Kuan-t''ao,Kuan-t’ao,Nan-kuan-t''ao,Nan-kuan-t’ao,Nanguantao,guan tao,馆陶', 36.5409900, 115.2829300, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16349, 'Nangong', 'Nangong', 'Nan''gun,Nan-kung,Nan-kung-ch''eng-kuan,Nan-kung-ch’eng-kuan,Nan-kung-hsien,Nangong,Nan’gun', 37.3580600, 115.3744400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16350, 'Nangaoqiao', 'Nangaoqiao', 'Baique Xiang,Nan-chia-ch''iao,Nan-chia-ch’iao,Nangaoqiao,bai que xiang,nan gao qiao,南皋桥,白雀乡', 30.9207100, 120.0977700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16351, 'Nangang', 'Nangang', 'Nan-kang,Nangang,Nangang Xiang,nan gang,nan gang xiang,南岗,南岗乡', 34.2438900, 119.1441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16352, 'Nangang', 'Nangang', 'Nan-kang,Nangang,Nangang Jiedao,nan gang,nan gang jie dao,南岗,南岗街道', 23.1009300, 113.5416600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16353, 'Nanfeng', 'Nanfeng', 'Nan-feng-chen,Nanfeng,Nanfeng Xiang,Nanfeng Zhen,nan feng,nan feng zhen,南丰,南丰镇', 31.8800200, 120.6648100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16354, 'Nanfeng', 'Nanfeng', 'Nan-feng-chieh,Nanfeng,Nanfeng Zhen,nan feng,nan feng zhen,南峰,南峰镇', 29.2630300, 116.5614000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16355, 'Nanfeng', 'Nanfeng', 'Hoikin,Hoikin-hsien,K''ai-chien,K''ai-chien-hsien,K’ai-chien,K’ai-chien-hsien,Nan-feng-chen,Nanfeng,Nanfeng Zhen,nan feng,nan feng zhen,南丰,南丰镇', 23.7269500, 111.7972300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16356, 'Nanfeng', 'Nanfeng', 'Namfung,Nan-feng-shih,Nanfeng,Nanfeng Zhen,nan feng,nan feng zhen,南丰,南丰镇', 19.4101800, 109.5502400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16357, 'Nanfang', 'Nanfang', 'Nan-fang-chen,Nanfang,Nanfang Zhen,nan fang,nan fang zhen,南访,南访镇', 34.7086100, 108.3330600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16358, 'Duji', 'Duji', 'Duji,Nan-tu-chi,Nanduji,Tu-chi,du ji,杜集', 33.9976500, 116.8284000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16359, 'Nandu', 'Nandu', 'Nan-tu,Nan-tu-chen,Nandu,Nandu Zhen,nan du,nan du zhen,南渡,南渡镇', 31.4415600, 119.3289700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16360, 'Nandu', 'Nandu', 'Nan-tu,Nan-tu-hsu,Nan-tu-hsü,Nandu', 22.8525000, 110.8233300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16361, 'Nandong', 'Nandong', 'Nandong,Nandong Zhen,nan dong,nan dong zhen,南董,南董镇', 38.1030500, 114.7581700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16362, 'Nanding', 'Nanding', 'Nan-ting,Nanding', 36.7483300, 118.0558300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16363, 'Nandian', 'Nandian', 'Nan-tien-chen,Nandian,Nandian Zhen,Nantien,nan dian,nan dian zhen,南甸,南甸镇', 38.3861600, 114.1272000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16364, 'Nandashan', 'Nandashan', 'Nan-ta-shan,Nandashan,Nandashan Zhen,nan da shan,nan da shan zhen,南大膳,南大膳镇', 29.0125000, 112.7136100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16365, 'Nandan Chengguanzhen', 'Nandan Chengguanzhen', 'Nan-tan,Nan-tan-chen,Nan-tan-hsien,Nandan,Nandan Chengguanzhen,Nantanchow,nan dan cheng guan zhen,南丹城关镇', 25.0103600, 107.5571200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16366, 'Nancun', 'Nancun', 'Nan-ts''un,Nan-ts''un-chen,Nan-ts’un,Nan-ts’un-chen,Nancun,Nancun Zhen,nan cun,nan cun zhen,南村,南村镇', 38.0619400, 114.6365100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16367, 'Nancun', 'Nancun', 'Nan-ts''un,Nan-ts’un,Nancun,Nancun Zhen,Zezhou Xian,nan cun,nan cun zhen,ze zhou xian,南村,南村镇,泽州县', 35.4635000, 112.7960000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16368, 'Nancun', 'Nancun', 'Nan-ts''un,Nan-ts’un,Nancun,Nancun Xiang,nan cun,nan cun xiang,南村,南村乡', 27.3098400, 115.9200200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16369, 'Nancun', 'Nancun', 'Nan-ts''un,Nan-ts’un,Nancun,Nancun Zhen,nan cun,nan cun zhen,南村,南村镇', 23.0140700, 113.3893100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16370, 'Nanchong', 'Nanchong', 'Lam-chhiong-chhi,Lâm-chhiong-chhī,NAO,Nam Sung,Nan''chun,Nan-cchung,Nan-ch''ung,Nan-ch''ung-hsien,Nan-ch''ung-shih,Nan-ch’ung,Nan-ch’ung-hsien,Nan-ch’ung-shih,Nan-čchung,Nanchong,Nanchung,Nang-chung,Nan’chun,Nàng-chṳ̆ng,Shun''tsin,Shun-ch''ing,Shun-ch’ing,Shunking,Shun’tsin,nan chong,nan chong shi,nanchung si,nanchwng,Нанчунг,Наньчун,نانچونگ,南充,南充市,난충 시', 30.7950800, 106.0847300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16371, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Zhen,nan cheng,nan cheng zhen,南城,南城镇', 34.5616700, 119.2241700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16372, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Zhen,nan cheng,nan cheng zhen,南埕,南埕镇', 25.6365400, 118.3843100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16373, 'Nanchangshan', 'Nanchangshan', 'Ch''ang-tao,Changdao,Changdao Xian,Ch’ang-tao,Nanchangshan,Sihou,Ssu-hou-ts''un,Ssu-hou-ts’un,nan zhang shan,zhang dao xian,南长山,长岛县', 37.9152200, 120.7324700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16374, 'Nanchang', 'Nanchang', 'Gorad Nan''chan,KHN,Lam-chhiong-chhi,Lâm-chhiong-chhī,Nam Xuong,Nam Xương,Nam-chhong-su,Nan''chan,Nan-cchang,Nan-ch''ang-hsien,Nan-ch''ang-shih,Nan-ch’ang-hsien,Nan-ch’ang-shih,Nan-čchang,Nancana,Nancangas,Nancano,Nanchan,Nanchang,Nanchang-fu,Nancianga,Nancsang,Nang-chiong,Nanzcangh,Nanĉano,Nančangas,Naņčana,Nàm-chhông-sṳ,Nàng-chiŏng,nan chang,nan chang shi,nanacanga,nanacham,nanachanna,nanchang,nanchang si,nantshangh,nʼnzʼng,Горад Наньчан,Нанчан,Нанчанг,Наньчан,נאנצאנג,نانتشانغ,نانچانگ,نەنچاڭ شەھىرى,नानचांग,নানছাং,ਨਾਨਛਾਂਙ,နန်ချောင့်မြို့,南昌,南昌市,난창 시', 28.6839600, 115.8530600, 'CN', '2015-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16375, 'Nancang', 'Nancang', 'Nancang,nan cang,南仓', 39.2040900, 117.1362500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16376, 'Nancaicun', 'Nancaicun', 'Nancaicun,Ts''ai-ts''un,Ts’ai-ts’un', 39.4752800, 117.0161100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16377, 'Nanbin', 'Nanbin', 'Nanbin,Nanbin Zhen,Shih-chu,Shih-chu-hsien,Shizhu Tujiazu Zizhixian,nan bin,nan bin zhen,shi zhu tu jia zu zi zhi xian,南宾,南宾镇,石柱土家族自治县', 29.9994000, 108.1091300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16378, 'Nanbao', 'Nanbao', 'Nanbao,Nanbao Zhen,nan bao,nan bao zhen,南宝,南宝镇', 19.6824200, 109.5959600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16379, 'Cezi', 'Cezi', 'Cezi,Cezixiang,Nan''ao,Nan-ao-ts''un,Nan-ao-ts’un,Nan’ao,ce zi,ce zi xiang,nan ao,冊子,冊子乡,南岙', 30.0833300, 121.9330600, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16380, 'Nan’an', 'Nan''an', 'Dayu,Dayu Xian,Nan''an,Nan-an-chen,Nananfu,Nan’an,Ta-sou,Ta-yu,Ta-yu-hsien,Ta-yü,Ta-yü-hsien,da yu xian,nan an,南安,大余县', 25.3997700, 114.3621800, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16381, 'Gaoyao', 'Gaoyao', 'Gaoyao,Nan''an,Nan’an,gao yao,高要', 23.0243200, 112.4455500, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16382, 'Naji', 'Naji', 'Naji,Naji Zhen,na ji,na ji zhen,那吉,那吉镇', 22.1214100, 112.1596300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16383, 'Nahuo', 'Nahuo', 'Nahuo,Nahuo Zhen,na huo,na huo zhen,那霍,那霍镇', 21.8909200, 111.2386200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16384, 'Nada', 'Nada', 'Chan-hsien,Danxian,Danzhou,Danzhou Shi,Na-ta,Na-ta-chen,Na-ta-shih,Nada,Nada Zhen,Nodoa,Tan-hsien,dan zhou shi,na da,na da zhen,儋州市,那大,那大镇', 19.5225700, 109.5786000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16385, 'Muzidian', 'Muzidian', 'Mu-tzu-tien,Mu-tzu-tien-chi,Muzidian,Muzidian Zhen,mu zi dian,mu zi dian zhen,木子店,木子店镇', 31.1904900, 115.3603800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16386, 'Muzhou', 'Muzhou', 'Mu-chou,Muzhou,Muzhou Zhen,mu zhou,mu zhou zhen,睦洲,睦洲镇', 22.4576900, 113.1609800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16387, 'Muyudian', 'Muyudian', 'Mu-yu-tien,Mu-yü-tien,Muyudian,Muyudian Zhen,mu yu dian,mu yu dian zhen,沐浴店,沐浴店镇', 37.0300000, 120.7533300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16388, 'Muyang', 'Muyang', 'Mu-yang-chen,Muyang,Muyang Zhen,mu yang,mu yang zhen,穆阳,穆阳镇', 27.0610400, 119.5211200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16389, 'Muxi', 'Muxi', 'Mu-ch''uan-hsien,Mu-ch’uan-hsien,Muchuan,Muxi,mu xi,沐溪', 28.9596400, 103.9008600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16390, 'Muxi', 'Muxi', 'Muxi,Muxi Xiang,mu xi,mu xi xiang,木溪,木溪乡', 28.0922200, 110.5886100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16391, 'Muri', 'Muri', 'Mole,Mole Zhen,Mu-li,Muri,mo lei,mo lei zhen,默勒,默勒镇', 37.6896600, 100.7257900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16392, 'Mulan', 'Mulan', 'Mulan,Mulan Xiang,mu lan,mu lan xiang,木兰,木兰乡', 26.4960300, 116.3901900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16393, 'Mujiangping', 'Mujiangping', 'Mu-chiang-p''ing,Mu-chiang-p’ing,Mujiangping,Mujiangping Zhen,mu jiang ping,mu jiang ping zhen,木江坪,木江坪镇', 28.0498100, 109.7206100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16394, 'Muhuguan', 'Muhuguan', 'Mu-hu-kuan,Muhuguan,Muhuguan Zhen,mu hu guan,牧护关', 34.0442300, 109.5772500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16395, 'Muhuang', 'Muhuang', 'Muhuang,Muhuang Zhen,mu huang,mu huang zhen,木黄,木黄镇', 28.0876100, 108.6896500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16396, 'Muge', 'Muge', 'Muge,Muge Zhen,mu ge,mu ge zhen,木格,木格镇', 23.5176900, 112.1712000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16397, 'Mugan', 'Mugan', 'Mugan,Mugan Zhen,Muganhe,mu gan,mu gan zhen,木杆,木杆镇', 28.1666700, 103.9666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16398, 'Mugang', 'Mugang', 'Mu-kang,Mugang,Mugang Zhen,mu gang,mu gang zhen,木港,木港镇', 29.7233900, 115.2462100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16399, 'Mu’er', 'Mu''er', 'Mu''er,Mu''er Zhen,Mu-erh,Mu’er,Mu’er Zhen,mu er,mu er zhen,木耳,木耳镇', 29.8060100, 106.6443900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16400, 'Mudong', 'Mudong', 'Mu-tung,Mu-tung-ch''ang,Mu-tung-chen,Mu-tung-ch’ang,Mudong,Mudong Zhen,mu dong,mu dong zhen,木洞,木洞镇', 29.5750000, 106.8405600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16401, 'Mudian', 'Mudian', 'Mu-tien,Mudian,Mudian Xiang,mu dian,mu dian xiang,穆店,穆店乡', 32.9183900, 118.6075400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16402, 'Shangyang', 'Shangyang', 'Mu-tai-k''ou,Mu-tai-k’ou,Mudaikou,Shangyang,Shangyang Zhen,mu dai kou,shang yang,shang yang zhen,上垟,上垟镇,木岱口', 27.9647200, 118.8658300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16403, 'Mucheng', 'Mucheng', 'Mu-ch''eng-chen,Mu-chuan-tien,Mu-ch’eng-chen,Mu-luan-tien,Mucheng,Wu-chih,Wuzhi,mu cheng,木城', 35.0955600, 113.3900000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16404, 'Mubo', 'Mubo', 'Mubo,Mubo Xiang,mu bo,mu bo xiang,木钵,木钵乡', 36.4462800, 107.4359400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16405, 'Moyuan', 'Moyuan', 'Moyuan,Moyuan Xiang,mo yuan,mo yuan xiang,漠源,漠源乡', 26.6792500, 117.5502600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16406, 'Moxi', 'Moxi', 'Mo-hsi-t''ou,Mo-hsi-t’ou,Moxi,Moxi Xiang,Moxitou,mo xi,mo xi xiang,磨溪,磨溪乡', 29.3658100, 115.5801200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16407, 'Moudao', 'Moudao', 'Mou-tao,Moudao,Moudao Zhen,mou dao,mou dao zhen,谋道,谋道镇', 30.4357000, 108.6785900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16408, 'Motou', 'Motou', 'Mo-t''ou-chen,Mo-t’ou-chen,Motou,Motou Zhen,mo tou,mo tou zhen,磨头,磨头镇', 32.2837900, 120.5594100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16409, 'Moshi', 'Moshi', 'Mo-shih,Moshi,Moshi Zhen,mo shi,mo shi zhen,磨市,磨市镇', 29.7637600, 110.9490400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16410, 'Moping', 'Moping', 'Moping,Moping Xiang,mo ping,mo ping xiang,磨坪,磨坪乡', 30.8127600, 110.4266100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16411, 'Mailing', 'Mailing', 'Mailing,mai ling,麦岭', 33.7742000, 113.6446900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16412, 'Moganshan', 'Moganshan', 'Mo-kan-shan,Moganshan,Moganshan Zhen,mo gan shan,mo gan shan zhen,莫干山,莫干山镇', 30.6011300, 119.8944600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16413, 'Shangmofang', 'Shangmofang', 'Mo-fang-pao,Mofang,Shangmofang,Shangmofang Xiang,shang mo fang,shang mo fang xiang,上磨坊,上磨坊乡', 39.1049900, 113.0179700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16414, 'Mocun', 'Mocun', 'Mo-ts''un,Mo-ts''un-hsu,Mo-ts’un,Mo-ts’un-hsü,Mocun,Mocun Zhen,mo cun,mo cun zhen,莫村,莫村镇', 23.4101300, 112.1069500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16415, 'Miyang', 'Miyang', 'Mi-lo,Mi-lo-hsien,Mi-lo-hsien-i-tsu-tzu-chih-ch''u,Mi-lo-hsien-i-tsu-tzu-chih-ch’ü,Mile,Mile Xian,Miyang,mi lei,mi lei xian,mi yang,弥勒,弥勒县,弥阳', 24.4041700, 103.4427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16416, 'Qingping', 'Qingping', 'Mi,Mi-hsien,Mixian,Qingping,Xinmi,qing ping,青屏', 34.5365600, 113.3752600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16417, 'Mishi', 'Mishi', 'Mi-t''o-ssu,Mi-t’o-ssu,Mishi,Mishi Zhen,Mituosi,mi shi,mi shi zhen,弥市,弥市镇', 30.2275100, 112.1184700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16418, 'Minzhu', 'Minzhu', 'Minzhu,Minzhu Xiang,min zhu,min zhu xiang,民主,民主乡', 25.0025200, 115.9397900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16419, 'Minzhong', 'Minzhong', 'Min-chung,Minzhong,Minzhong Zhen,min zhong,min zhong zhen,民众,民众镇', 22.6242100, 113.4876500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16420, 'Chengjiao Chengguanzhen', 'Chengjiao Chengguanzhen', 'Chengguanzhen,Chengjiao,Chengjiao Chengguanzhen,MIN''SYAN,MIN’SYAN,Min,Min Xian,Min Xian Chengjiao Chengguanzhen,Min-hsien,Minchow,Minxian,cheng guan zhen,cheng jiao,cheng jiao cheng guan zhen,min xian,min xian cheng jiao cheng guan zhen,城关镇,城郊,城郊城关镇,岷县,岷县城郊城关镇', 34.4358300, 104.0305600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16421, 'Mintang', 'Mintang', 'Mentang,Mentang Xiang,Mintang,men tang,men tang xiang,门堂,门堂乡', 33.8000000, 101.0333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16422, 'Minquan Chengguanzhen', 'Minquan Chengguanzhen', 'Li-pa-chi,Min-ch''uan,Min-ch''uan-hsien,Min-ch’üan,Min-ch’üan-hsien,Minquan,Minquan Chengguanzhen,min quan cheng guan zhen,民权城关镇', 34.6644900, 115.1329900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16423, 'Sanlei', 'Sanlei', 'Chen-fan,Chentan,Chzhen''-fan,Chzhen’-fan,Min''tsin'',Min-ch''in,Min-ch’in,Minqin,Minqin Xian,Min’tsin’,Sanlei,min qin xian,san lei,三雷,民勤县', 38.6263900, 103.0883300, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16424, 'Minqiao', 'Minqiao', 'Min-ch''iao,Min-chia-ch''iao,Min-chia-ch’iao,Min-ch’iao,Minqiao,Minqiao Zhen,min qiao,min qiao zhen,闵桥,闵桥镇', 32.9026400, 119.1668700, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16425, 'Hongshui', 'Hongshui', 'Dunle,Hongshui,Hung-shui,Min-lo,Min-lo-hsien,Minle,Minle Chengguanzhen,Minle Xian,Tung-lo,hong shui,min le cheng guan zhen,min le xian,民乐县,民乐城关镇,洪水', 38.4245700, 100.7926000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16426, 'Minle', 'Minle', 'Min-lo,Minle,Minle Zhen,min le,min le zhen,民乐,民乐镇', 28.3851400, 109.2985400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16427, 'Minle', 'Minle', 'Minle,Minle Zhen,min le,民乐', 23.6591700, 113.4670000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16428, 'Minjian', 'Minjian', 'Ma-pien,Ma-pien-hsien,Mabian,Mapienting,Minjian,min jian,民建', 28.8462200, 103.5457500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16429, 'Minhang', 'Minhang', 'Min-hang-chen,Ming-hang,Minhang,Shang-hai,min xing,闵行', 31.1088100, 121.3747100, 'CN', '2012-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16430, 'Mingyuedian', 'Mingyuedian', 'Ming-yueh-tien,Ming-yüeh-tien,Mingyuedian,Mingyuedian Zhen,ming yue dian,ming yue dian zhen,明月店,明月店镇', 38.4560200, 114.8911300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16431, 'Mingyu', 'Mingyu', 'Ming-yu-chen,Ming-yü-chen,Mingyu,Mingyu Zhen,ming yu,ming yu zhen,鸣玉,鸣玉镇', 29.3069000, 107.1179200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16432, 'Mingxikou', 'Mingxikou', 'Mingxikou,Mingxikou Zhen,ming xi kou,ming xi kou zhen,明溪口,明溪口镇', 28.7000000, 110.3166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16433, 'Mingtong', 'Mingtong', 'Ming-t''ung-ching,Ming-t’ung-ching,Mingtong,Mingtong Zhen,Mingtongjing,ming tong,ming tong zhen,明通,明通镇', 31.7731900, 108.5410400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16434, 'Mingshui', 'Mingshui', 'Chang-ch''iu,Chang-ch’iu,Ming-shui-chen,Mingshui,Zhangqiu', 36.7166700, 117.5000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16435, 'Mingkou', 'Mingkou', 'Mingkou,Mingkou Zhen,ming kou,ming kou zhen,名口,名口镇', 28.9185200, 117.4305800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16436, 'Mingguang', 'Mingguang', 'Chia-shan,Chia-shan-hsien,Jiashan,Ming-kuang,Ming-kuang-chen,Mingguang,Mingkwang', 32.7801700, 117.9637800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16437, 'Minggang', 'Minggang', 'Ming-chiang,Ming-kang,Minggang,Mingkiang,Mintszyan', 32.4586100, 114.0486100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16438, 'Mingfeng', 'Mingfeng', 'Mingfeng,Yuan''an,Yuan-an-hsien,Yuan’an,Yüan-an-hsien,ming feng,鸣凤', 31.0616700, 111.6427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16439, 'Mingdu', 'Mingdu', 'Ming-tu,Ming-tu-chen,Mingdu,Mingdu Zhen,Wu-tu-chen,ming du,鸣犊', 34.1305200, 109.1026400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16440, 'Hecheng', 'Hecheng', 'Gaoming,Hecheng,Hecheng Jiedao,Kao-ming,Kao-ming-hsien,Koming,Koming-hsien,Mingcheng,he cheng,he cheng jie dao,荷城,荷城街道', 22.9043500, 112.8849900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16441, 'Min’an', 'Min''an', 'Longshan Xian,Lung-shan,Lung-shan-hsien,Min''an,Min''an Zhen,Min’an,Min’an Zhen,long shan xian,min an,min an zhen,民安,民安镇,龙山县', 29.4595000, 109.4370000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16442, 'Min’an', 'Min''an', 'Min''an,Min-an-chen,Min’an,min an,闽安', 26.0496200, 119.4996400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16443, 'Miluo Chengguanzhen', 'Miluo Chengguanzhen', 'Ku-lo,Mi-lo,Mi-lo-hsien,Miluo,Miluo Chengguanzhen,Miluo Shi,mi luo cheng guan zhen,mi luo shi,汨罗城关镇,汨罗市', 28.8107000, 113.0661600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16444, 'Ganlu', 'Ganlu', 'Ganlu,Ganlu Zhen,Miliangpu,gan lu,gan lu zhen,mi liang pu,甘露,甘露镇,米粮铺', 29.2527300, 115.7639100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16445, 'Mi’ersi', 'Mi''ersi', 'Mi''er,Mi''ersi,Mi''ersi Zhen,Mi-erh-ssu,Mi’er,Mi’ersi,Mi’ersi Zhen,mi r si,mi r si zhen,觅儿寺,觅儿寺镇', 31.0373500, 114.5356300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16446, 'Micheng', 'Micheng', 'Mi-ch''eng-chen,Mi-ch’eng-chen,Mi-tu,Mi-tu-chen,Mi-tu-chieh,Mi-tu-hsien,Micheng,Midu,mi cheng,弥城', 25.3203700, 100.4993100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16447, 'Miaoyu', 'Miaoyu', 'Miaoyu,Miaoyu Zhen,Miaoyucao,miao yu,miao yu cao,miao yu zhen,庙宇,庙宇槽,庙宇镇', 30.8686800, 109.6461400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16448, 'Miaoxi', 'Miaoxi', 'Miao-hsi,Miao-hsi-shih,Miaoxi,Miaoxi Xiang,Miaoxi Zhen,miao xi,miao xi xiang,miao xi zhen,妙西,妙西乡,妙西镇', 30.7819600, 120.0040000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16449, 'Miaotang', 'Miaotang', 'Jiaoliang,Miaotang,Miaotang Zhen,jiao liang,miao tang,miao tang zhen,庙塘,庙塘镇,教良', 28.5584400, 107.1682000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16450, 'Miaotan', 'Miaotan', 'Miaotan,Miaotan Zhen,miao tan,miao tan zhen,庙滩,庙滩镇', 32.1411900, 111.7484900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16451, 'Miaoshou', 'Miaoshou', 'Miaoshou,Miaoshou Zhen,miao shou,miao shou zhen,庙首,庙首镇', 30.2663900, 118.3913900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16452, 'Miaoshi', 'Miaoshi', 'Miaoshi,Miaoshi Zhen,miao shi,miao shi zhen,苗市,苗市镇', 29.5437600, 111.2424500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16453, 'Miaoqian', 'Miaoqian', 'Miao-ch''ien,Miao-ch’ien,Miaoqian,Miaoqian Zhen,miao qian,miao qian zhen,庙前,庙前镇', 25.3298800, 116.6799400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16454, 'Miaoling', 'Miaoling', 'Miaoling,Miaoling Zhen,miao ling,miao ling zhen,庙岭,庙岭镇', 30.4496200, 114.6155200, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16455, 'Miaogou', 'Miaogou', 'Miao-kou,Miaogou,Miaogou Xiang,miao gou,miao gou xiang,庙沟,庙沟乡', 36.8808500, 107.9166000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16456, 'Miaofengshan', 'Miaofengshan', 'Miaofengshan,Miaofengshan Zhen,miao feng shan,miao feng shan zhen,妙峰山,妙峰山镇', 39.9742200, 116.0485400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16457, 'Miaoba', 'Miaoba', 'Miao-pa,Miaoba,miao ba,庙坝', 33.1685000, 106.3203300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16458, 'Jiannan', 'Jiannan', 'Jiannan,Mianzhu,Mien-chu,Mien-chu-hsien,Myan''chzhu,Myan’chzhu,jian nan,剑南', 31.3435500, 104.1958800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16459, 'Mianyang', 'Mianyang', 'Bian-iong-chhi,Biân-iông-chhī,MIG,Mianyang,Mianyang Shi,Mien Duong,Mien-chou,Mien-jang,Mien-yang,Mien-yang-hsien,Mienchow,Mieng-iong,Mienjan,Mièng-iòng,Miên Dương,Mjan''jan,Mjenjang,Myan''yan,Myan’yan,mian yang,mian yang shi,myanyang,myen-yang si,Миенян,Мяньян,Мјенјанг,ميەنياڭ شەھىرى,میانیانگ,綿陽,綿陽市,绵阳,绵阳市,몐양 시', 31.4678400, 104.6816800, 'CN', '2015-08-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16460, 'Mianyang', 'Mianyang', 'Mianxian,Mianyang,Mianyang Zhen,Mien,Mien-hsien,mian xian,mian yang,mian yang zhen,勉县,勉阳,勉阳镇', 33.1570300, 106.6944500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16461, 'Chengxiang', 'Chengxiang', 'Chengxiang,Mianning,Mien-ning,Mien-ning-hsien,cheng xiang,城厢', 28.5526200, 102.1682000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16462, 'Mianhu', 'Mianhu', 'Mianhu,Mianhu Zhen,Mien-hu,Mien-hu-hsu,Mien-hu-hsü,Mienfu,mian hu,mian hu zhen,棉湖,棉湖镇', 23.4410400, 116.1387200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16463, 'Mianchi Chengguanzhen', 'Mianchi Chengguanzhen', 'Chiu-mien-ch''ih,Chiu-mien-ch’ih,Mianchi,Mianchi Chengguanzhen,Mien-ch''ih,Mien-ch''ih-hsien,Mien-ch’ih,Mien-ch’ih-hsien,Min''chi,Min’chi,Sheng-ch''ih,Sheng-ch’ih,mian chi cheng guan zhen,渑池城关镇', 34.7541700, 111.7594400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16464, 'Mentougou', 'Mentougou', 'Men-t''ou-kou,Men-t''ou-kou-ho-t''an,Men-t’ou-kou,Men-t’ou-kou-ho-t’an,Mentougou,men tou gou,门头沟', 39.9381900, 116.0930700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16465, 'Wenlan', 'Wenlan', 'Meng-tzu,Meng-tzu-ch''eng,Meng-tzu-ch’eng,Meng-tzu-hsien,Mengtsz,Mengtszhsien,Mengtze-hsien,Mengzi,Mongtseau,Mongtze,Wenlan,Wenlan Zhen,wen lan,文澜', 23.3600200, 103.4368400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16466, 'Mengzhai', 'Mengzhai', 'Meng-chai,Mengzhai,Mengzhai Zhen,meng zhai,孟寨', 33.5425200, 113.6088900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16467, 'Mengyin', 'Mengyin', 'Meng-yin-hsien,Mengyin', 35.7069400, 117.9263900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16468, 'Huichang', 'Huichang', 'Huichang,Meng,Meng-hsien,Mengzhou,hui chang,会昌', 34.9037600, 112.7842600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16469, 'Mengxi', 'Mengxi', 'Meng-hsi,Mengxi,Mengxi Zhen,Mengxisi,meng xi,meng xi si,meng xi zhen,梦溪,梦溪寺,梦溪镇', 29.7500000, 111.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16470, 'Mengxi', 'Mengxi', 'Mengxi,Mengxi Zhen,meng xi,meng xi zhen,孟溪,孟溪镇', 28.0808100, 108.9764100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16471, 'Mengshan', 'Mengshan', 'Mengshan,Mengshan Xiang,meng shan,meng shan xiang,蒙山,蒙山乡', 28.1230200, 114.9631200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16472, 'Mengshan', 'Mengshan', 'Meng-shan-chen,Meng-shan-hsien,Mengshan,Wing-on,Winganchow,Wingonchow,Yung-an,meng shan,蒙山', 24.2140500, 110.5177500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16473, 'Mengquan', 'Mengquan', 'Meng-ch''uan,Meng-ch’üan,Mengquan', 39.8252800, 117.4766700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16474, 'Mengquan', 'Mengquan', 'Baiyanghu,Mengquan,Mengquan Zhen,bai yang hu,meng quan,meng quan zhen,白洋湖,蒙泉,蒙泉镇', 29.4146800, 111.4749800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16475, 'Menglie', 'Menglie', 'Chiang-ch''eng,Chiang-ch''eng-ha-ni-tsu-i-tsu-tzu-chih-hsien,Chiang-ch''eng-hsien,Chiang-ch’eng,Chiang-ch’eng-ha-ni-tsu-i-tsu-tzu-chih-hsien,Chiang-ch’eng-hsien,Jiangcheng,Kiangcheng-hsien,Meng-lieh,Meng-lieh-chieh,Mengli,Menglie,Mengliejie,meng lie,勐烈', 22.5596700, 101.8679000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16476, 'Mengla', 'Mengla', 'Mengla,Mong La,Muong La,Pan-na-meng-la,meng la,勐腊', 21.4685900, 101.5506900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16477, 'Mengjiaxi', 'Mengjiaxi', 'Meng-chia,Meng-chia-ch''i,Meng-chia-ch’i,Mengjiaxi,Mengjiaxi Zhen,meng jia xi,meng jia xi zhen,孟家溪,孟家溪镇', 29.8549700, 112.0884600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16478, 'Menghe', 'Menghe', 'Meng-ho,Meng-ho-ch''eng,Meng-ho-ch’eng,Menghe,Menghe Zhen,meng he,meng he zhen,孟河,孟河镇', 32.0161500, 119.8494100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16479, 'Mengcun', 'Mengcun', 'Meng-ts''un,Meng-ts''un-chen,Meng-ts’un,Meng-ts’un-chen,Mengcun,meng cun,孟村', 34.1664600, 109.2151800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16480, 'Mengcheng Chengguanzhen', 'Mengcheng Chengguanzhen', 'Meng-ch''eng-hsien,Meng-ch’eng-hsien,Mengcheng,Mengcheng Chengguanzhen,meng cheng cheng guan zhen,蒙城城关镇', 33.2661100, 116.5660500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16481, 'Mengbi', 'Mengbi', 'Mengbi,Mengbixiang,meng bi,meng bi xiang,猛必,猛必乡', 29.3810200, 109.7975200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16482, 'Meizhuang', 'Meizhuang', 'Mei-chuang,Mei-chuang-shih,Meizhuang,Meizhuang Zhen,mei zhuang,mei zhuang zhen,梅庄,梅庄镇', 28.5889900, 116.4062200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16483, 'Meizhu', 'Meizhu', 'Mei-chu,Mei-chu-chen,Meizhu,Meizhu Zhen,mei zhu,mei zhu zhen,梅渚,梅渚镇', 31.2617300, 119.2096600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16484, 'Meizhou', 'Meizhou', 'Chia-ying,Kaying,MXZ,Mai Chau,Mai Châu,Mehjchzhou,Mei,Mei-ch''eng-chen,Mei-ch’eng-chen,Mei-hsien,Meixian,Meizhou,Meizhou Shi,Mej-cou,Mej-čou,Moi-chiu-su,Mui-chiu-chhi,Mui-ciu,Mòi-chiu-sṳ,Mùi-ciŭ,Mûi-chiu-chhī,mawzhwa,mei zhou,mei zhou shi,meijeou si,myyyzhww,myyzhw,Мэйчжоу,مئیژو,ماوژوا,میئیژوؤ,梅州,梅州市,메이저우 시', 24.2885900, 116.1176800, 'CN', '2016-10-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16485, 'Meizhou', 'Meizhou', 'Mei-chou,Mei-chou-hsun,Mei-chou-hsün,Meizhou,mei zhou,梅洲', 23.8085600, 117.3133100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16486, 'Meiyuan', 'Meiyuan', 'Mei-yuan-chen,Mei-yüan-chen,Meiyuan,Meiyuan Zhen,mei yuan,美原', 34.9449800, 109.3528800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16487, 'Meiyan', 'Meiyan', 'Hai-yen,Hai-yen-chen,Mei-yen,Mei-yen-chen,Meiyan,Meiyan Jiedao,Meiyan Zhen,mei yan,mei yan jie dao,mei yan zhen,梅偃,梅偃街道,梅偃镇', 30.9787400, 120.5858200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16488, 'Meixing', 'Meixing', 'Hsiao-chin,Hsin-chieh-tzu,MOWKUNG,Meixing,Mou-kun,Mou-kung,Mou-kung-hsien,Mougun,Mowkung-hsien,Mowkungting,Siaokin,Sin''tszetszo,Sin''tszetszy,Sinkaisze,Sin’tszetszy,Sin’tszetszö,Xiaojin,Xiaojin Xian,Zainlha,mei xing,xiao jin xian,小金县,美兴', 30.9990700, 102.3601900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16489, 'Meixian', 'Meixian', 'Mei-hsien,Mei-hsien-fan,Meixian,Meixian Zhen,mei xian,mei xian zhen,梅仙,梅仙镇', 26.2409000, 118.2479200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16490, 'Meixi', 'Meixi', 'Meixi,Meixi Xiang,mei xi,mei xi xiang,梅溪,梅溪乡', 28.7720100, 116.3947900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16491, 'Meitianhu', 'Meitianhu', 'Meitianhu,Meitianhu Zhen,mei tian hu,mei tian hu zhen,梅田湖,梅田湖镇', 29.5241700, 112.3619400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16492, 'Meitang', 'Meitang', 'Meitang,Meitang Xiang,mei tang,mei tang xiang,梅塘,梅塘乡', 27.0976600, 114.8070500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16493, 'Meishan', 'Meishan', 'Chin-chai,Chin-chai-hsien,Jinzhai,Jinzhai Xian,Mei-shan-chen,Meishan,jin zhai xian,mei shan,梅山,金寨县', 31.7291300, 115.9124100, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16494, 'Meishan', 'Meishan', 'Meishan,Meishan Zhen,mei shan,mei shan zhen,煤山,煤山镇', 31.1032200, 119.7349700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16495, 'Meishan', 'Meishan', 'Meishan,Meishan Xiang,mei shan,mei shan xiang,梅山,梅山乡', 25.9556800, 117.9171800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16496, 'Meishan', 'Meishan', 'Meinuzuoji,Meishan,Meishan Zhen,mei shan,mei shan zhen,梅山,梅山镇', 25.1198600, 118.4659900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16497, 'Meipu', 'Meipu', 'Meipu,Meipu Zhen,mei pu,mei pu zhen,梅铺,梅铺镇', 33.0136800, 111.1896100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16498, 'Wuchuan', 'Wuchuan', 'Hai-lu,Mei-lu-shih,Mei-mao,Meilu,Muiluk,Wuchuan,wu chuan,吴川', 21.4571300, 110.7659100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16499, 'Meilong', 'Meilong', 'Mei-lung,Mei-lung-hsu,Mei-lung-hsü,Meilong,Meilong Zhen,mei long,mei long zhen,梅陇,梅陇镇', 22.8914700, 115.2113800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16500, 'Meiling', 'Meiling', 'Meiling,Meiling Zhen,mei ling,mei ling zhen,梅岭,梅岭镇', 25.2949800, 114.3570800, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16501, 'Meilin', 'Meilin', 'Mei-ts''un,Mei-ts’un,Meilin,Meilin Zhen,mei lin,mei lin zhen,梅林,梅林镇', 30.5669700, 119.0806300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16502, 'Meilin', 'Meilin', 'Meilin,Meilin Xiang,mei lin,mei lin xiang,梅林,梅林乡', 29.1871400, 117.8777900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16503, 'Meilin', 'Meilin', 'Meilin,Meilin Zhen,mei lin,mei lin zhen,梅林,梅林镇', 28.2795500, 115.6566900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16504, 'Meilin', 'Meilin', 'Gan Xian,Kan-hsien,Mei-lin-chen,Meilin,Meilin Zhen,gan xian,mei lin,mei lin zhen,梅林,梅林镇,赣县', 25.8730800, 115.0108000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16505, 'Meilin', 'Meilin', 'Meilin,Meilin Zhen,mei lin,mei lin zhen,梅林,梅林镇', 23.6393700, 115.6128400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16506, 'Meili', 'Meili', 'Meili,Meili Zhen,mei li,mei li zhen,梅李,梅李镇', 31.7090200, 120.8649100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16507, 'Meikeng', 'Meikeng', 'Mei-k''eng-hsu,Mei-k’eng-hsü,Meikeng,Meikeng Zhen,mei keng,mei keng zhen,梅坑,梅坑镇', 24.0101200, 114.1118000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16508, 'Meijiang', 'Meijiang', 'Meijiang,Meijiang Zhen,mei jiang,mei jiang zhen,梅江,梅江镇', 28.2635600, 109.0268500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16509, 'Meijiang', 'Meijiang', 'Meijiang,Meijiang Zhen,Ning-tu,Ning-tu-hsien,Ningdu Xian,mei jiang,mei jiang zhen,ning dou xian,宁都县,梅江,梅江镇', 26.4758300, 116.0150000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16510, 'Meihua', 'Meihua', 'Meihua,Meihua Zhen,mei hua,mei hua zhen,梅花,梅花镇', 25.1767800, 113.0734100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16511, 'Meihua', 'Meihua', 'Meihua,Meihua Zhen,mei hua,mei hua zhen,袂花,袂花镇', 21.5786600, 110.9352100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16512, 'Meigang', 'Meigang', 'Meigang,Meigang Xiang,mei gang,mei gang xiang,梅港,梅港乡', 28.4369500, 116.8144800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16513, 'Meicun', 'Meicun', 'Mei-ts''un,Mei-ts’un,Meicun,Meicun Zhen,mei cun,mei cun zhen,梅村,梅村镇', 31.5462300, 120.4302300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16514, 'Meichuan', 'Meichuan', 'Kuang-chi,Kuang-chi-hsien,Kwangchi,Mei-ch''uan-chen,Mei-ch’uan-chen,Meichuan,Meichuan Zhen,mei chuan,mei chuan zhen,梅川,梅川镇', 30.1294600, 115.5959700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16515, 'Meicheng', 'Meicheng', 'Ch''ien-shan,Ch’ien-shan,Meicheng,Qianshan,Qianshan Xian,Tsienshanhsien,mei cheng,qian shan xian,梅城,潜山县', 30.6344900, 116.5798000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16516, 'Meicheng', 'Meicheng', 'Jiande,Kienteh,Kientehsien,Mei-ch''eng-chen,Mei-ch’eng-chen,Meicheng,Meicheng Zhen,Yen-chou,Yen-chow-fu,Yenchow,mei cheng,mei cheng zhen,梅城,梅城镇', 29.5428900, 119.4990700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16517, 'Meicheng', 'Meicheng', 'Meicheng,Min-ch''ing,Min-ch''ing-hsien,Min-ch''ing-hsien-ch''eng,Min-ch’ing,Min-ch’ing-hsien,Min-ch’ing-hsien-ch’eng,Min-tsing-hsien,Minqing,Mintsing,mei cheng,梅城', 26.2152800, 118.8611100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16518, 'Meichang', 'Meichang', '', 39.3661100, 117.1805600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16519, 'Mazhuang', 'Mazhuang', 'Mazhuang,ma zhuang,马庄', 39.2094700, 117.1331100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16520, 'Mazhuang', 'Mazhuang', 'Ma-chuang,Ma-chuang-chen,Mazhuang,Mazhuang Zhen,ma zhuang,ma zhuang zhen,马庄,马庄镇', 34.4369400, 108.6555600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16521, 'Mazhu', 'Mazhu', 'Ma-chu,Ma-chu-chen,Mazhu,Mazhu Zhen,ma zhu,ma zhu zhen,马渚,马渚镇', 30.0780100, 121.0470000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16522, 'Mazhou', 'Mazhou', 'Ma-chou,Ma-chou-hsu,Ma-chou-hsü,Mazhou,Mazhou Zhen,ma zhou,ma zhou zhen,麻州,麻州镇', 25.5083800, 115.7752800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16523, 'Mazhaozhen', 'Mazhaozhen', 'Ma-chao,Ma-chao-chen,Mazhao Zhen,Mazhaozhen,ma zhao,ma zhao zhen,马召,马召镇', 34.0702600, 108.1899800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16524, 'Mazhang', 'Mazhang', 'Ma-chang,Ma-chang-shih,Macheung,Mazhang,Mazhang Zhen,ma zhang,ma zhang zhen,麻章,麻章镇', 21.2757400, 110.3221200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16525, 'Mazha', 'Mazha', 'Ma-cha,Ma-cha-hsu,Ma-cha-hsü,Mazha,Mazha Zhen,ma zha,ma zha zhen,麻榨,麻榨镇', 23.4506900, 114.0096500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16526, 'Mayong', 'Mayong', 'Ma-yung,Machong,Mayong,Mayong Zhen,ma yong,ma yong zhen,麻涌,麻涌镇', 23.0571000, 113.5676800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16527, 'Mayingzhuang', 'Mayingzhuang', 'Ma-ying-chuang,Mayingzhuang,Mayingzhuang Xiang,ma ying zhuang,ma ying zhuang xiang,马营庄,马营庄乡', 39.3694700, 112.9857500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16528, 'Maying', 'Maying', 'Ma-ying-ts''un,Ma-ying-ts’un,Maying,Maying Xiang,ma ying,ma ying xiang,马营,马营乡', 39.7197200, 112.7169400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16529, 'Damaying', 'Damaying', 'Damaying,Damaying Xiang,Maying,da ma ying,da ma ying xiang,大马营,大马营乡', 38.3666700, 101.2000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16530, 'Maying', 'Maying', 'Ma-ying-chen,Maying,ma ying,马营', 35.3052400, 105.0209300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16531, 'Maying', 'Maying', 'Ma-ying-chen,Maying,Maying Zhen,ma ying,ma ying zhen,马营,马营镇', 34.3415400, 107.2289300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16532, 'Mayanhe', 'Mayanhe', 'Ma-yen,Ma-yen-ho,Mayan,Mayanhe,ma yan he,麻沿河', 34.0725000, 105.7369400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16533, 'Mayang', 'Mayang', 'Ma-yang-t''an,Ma-yang-t’an,Mayang,Mayang Zhen,Mayangtan,ma yang,ma yang zhen,麻洋,麻洋镇', 30.4363900, 113.2648700, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16534, 'Maxu', 'Maxu', 'Maxu,Maxu Zhen,ma wei,ma wei zhen,马圩,马圩镇', 28.1335700, 116.4674400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16535, 'Maxiang', 'Maxiang', 'Ma-chiang,Ma-hsiang,Mahang,Maxiang,Maxiang Zhen,ma xiang,ma xiang zhen,马巷,马巷镇', 24.6670600, 118.2461000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16536, 'Mawu', 'Mawu', 'Ma-wu-pa,Mawu,Mawu Zhen,ma wu,ma wu zhen,马武,马武镇', 29.7872700, 108.3452000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16537, 'Mawu', 'Mawu', 'Mawu,Mawu Zhen,Mawuchang,ma wu,ma wu zhen,马武,马武镇', 29.5925000, 107.3133700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16538, 'Mawei', 'Mawei', 'Ma-wei,Ma-wei-chen,Mawei,Mawei Zhen,Maweipo,ma wei,ma wei zhen,马嵬,马嵬镇', 34.3163900, 108.3716700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16539, 'Mawang', 'Mawang', 'Ma-wang-ts''un,Ma-wang-ts’un,Mawang,Mawang Jieban,Mawangcun,Mawangzhen,ma wang,ma wang jie ban,马王,马王街办', 34.2041700, 108.7125000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16540, 'Mawang', 'Mawang', 'Ma-wang-ch''ang,Ma-wang-ch’ang,Mawang,Mawang Zhen,ma wang,ma wang zhen,麻旺,麻旺镇', 28.8933100, 108.9511400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16541, 'Matoupu', 'Matoupu', 'Matoupu,Matoupu Zhen,ma tou pu,ma tou pu zhen,码头铺,码头铺镇', 29.7712800, 111.4115800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16542, 'Xinmatou', 'Xinmatou', 'Ch''iu-hsien,Ch’iu-hsien,Ma-t''ou-chen,Ma-t’ou-chen,Matou,Qiuxian,Xinmatou,qiu xian,xin ma tou,新马头,邱县', 36.8180200, 115.1704700, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16543, 'Matou', 'Matou', 'Ma-t''ou-ch''en,Ma-t’ou-ch’en,Makau,Matou,Matou Zhen,ma tou,ma tou zhen,码头,码头镇', 29.8314600, 115.5773900, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16544, 'Matou', 'Matou', 'Matou,Matou Zhen,ma tou,ma tou zhen,码头,码头镇', 25.1924400, 118.3631900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16545, 'Matou', 'Matou', 'Ma-t''ou-hsu,Ma-t’ou-hsü,Matou,Matou Zhen,ma tou,ma tou zhen,马头,马头镇', 24.1251000, 114.3202300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16546, 'Matou', 'Matou', 'Kuo-te,Kuo-te-chen,Kuo-te-hsien,Kwoteh,Kwoteh-hsien,Ma-t''ou-chen,Ma-t’ou-chen,Matou,P''ing-kuo,P''ing-kuo-hsien,P’ing-kuo,P’ing-kuo-hsien,ma tou,马头', 23.3553400, 107.5564000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16547, 'Matiwan', 'Matiwan', 'Matiwan,ma ti wan,马蹄湾', 33.4781900, 106.0489600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16548, 'Matang', 'Matang', 'Ma-t''ang-chen,Ma-t’ang-chen,Matang,Matang Zhen,Matangzhen,ma tang,ma tang zhen,马塘,马塘镇', 32.3207000, 121.0374500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16549, 'Mashui', 'Mashui', 'Mashui,Mashui Zhen,ma shui,ma shui zhen,马水,马水镇', 22.1166700, 111.6833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16550, 'Mashi', 'Mashi', 'Ma-shih,Mashi,Mashi Zhen,ma shi,ma shi zhen,马市,马市镇', 25.0296000, 114.1478600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16551, 'Mashankou', 'Mashankou', 'Mashankou,Mashankou Zhen,ma shan kou,ma shan kou zhen,马山口,马山口镇', 33.2057700, 112.0026100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16552, 'Mashan', 'Mashan', 'Ma-shan-chen,Ma-shan-shih,Mashan,Mashan Zhen,ma shan,ma shan zhen,马山,马山镇', 30.0793700, 120.6580300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16553, 'Marzhing', 'Marzhing', 'Manzhang,Manzhang Xiang,Marzhing,Mori Gongmada,man zhang,man zhang xiang,mo ri gong ma da,满掌,满掌乡,莫日贡玛达', 33.3000000, 100.4000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16554, 'Markog', 'Markog', 'Makehe,Makehe Xiang,Markog,Zeda,ma ke he,ma ke he xiang,ze da,泽达,玛柯河,玛柯河乡', 33.0836200, 100.4777500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16555, 'Maqiao', 'Maqiao', 'Ma-ch''iao-k''ou,Ma-ch''iao-k''ou-shih,Ma-ch’iao-k’ou,Ma-ch’iao-k’ou-shih,Makiakow,Maqiao,Maqiao Zhen,ma qiao,ma qiao zhen,马桥,马桥镇', 31.7537400, 110.9321400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16556, 'Maqiao', 'Maqiao', 'Ma-ch''iao,Ma-ch''iao-chen,Ma-ch’iao,Ma-ch’iao-chen,Maqiao,Maqiao Zhen,ma qiao,ma qiao zhen,马桥,马桥镇', 31.4085100, 118.6031700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16557, 'Maqiao', 'Maqiao', 'Ma-ch''iao,Ma-ch''iao-shih,Ma-ch’iao,Ma-ch’iao-shih,Maqiao,Maqiao Zhen,ma qiao,ma qiao zhen,马桥,马桥镇', 29.8073400, 114.3544200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16558, 'Maping', 'Maping', 'Ma-p''ing-chiang,Ma-p’ing-chiang,Maping,Maping Zhen,Mapingkang,ma ping,ma ping zhen,马坪,马坪镇', 31.6009300, 113.5505500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16559, 'Mapeng', 'Mapeng', 'Mapeng,Mapeng Zhen,Mapengwan,ma peng,ma peng zhen,马棚,马棚镇', 32.8949100, 119.4185300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16560, 'Maozui', 'Maozui', 'Mao-tsui,Maozui,Maozui Zhen,mao ju,mao ju zhen,毛咀,毛咀镇', 30.4185900, 113.0315100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16561, 'Maoyang', 'Maoyang', 'Mao-yang-ts''un,Mao-yang-ts’un,Maoyang,Maoyang Xiang,mao yang,mao yang xiang,毛垟,毛垟乡', 27.7244400, 119.3830600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16562, 'Maoyang', 'Maoyang', 'Maoyang,Maoyang Zhen,mao yang,毛阳', 18.9321800, 109.5368800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16563, 'Maotian', 'Maotian', 'Mao-t''ien,Mao-t’ien,Maotian,Maotian Xiang,mao tian,mao tian xiang,茅田,茅田乡', 30.8034700, 109.8844800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16564, 'Maoshi', 'Maoshi', 'Mao-shih,Maoshi,Maoshi Zhen,mao shi,mao shi zhen,毛市,毛市镇', 29.8985900, 113.0076600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16565, 'Maoshan', 'Maoshan', 'Mao-shan-ts''un,Mao-shan-ts’un,Maoshan,Maoshan Zhen,mao shan,mao shan zhen,茅山,茅山镇', 32.7417800, 120.0062500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16566, 'Maopingchang', 'Maopingchang', 'Maoping,Maopingchang,Maopingchang Zhen,mao ping chang,mao ping chang zhen,茅坪场,茅坪场镇', 31.1426700, 111.6746100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16567, 'Maoping', 'Maoping', 'Maoping,mao ping,茅坪', 30.8297200, 110.9777800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16568, 'Maoping', 'Maoping', 'Maoping,Maoping Xiang,mao ping,mao ping xiang,茅坪,茅坪乡', 29.3420100, 109.4901000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16569, 'Maoping', 'Maoping', 'Fang-p''ing,Fang-p’ing,Maoping,Maoping Zhen', 26.7369400, 109.2211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16570, 'Maoping', 'Maoping', 'Maoping,Maoping Zhen,T''u-ch''iao,T’u-ch’iao', 26.5197200, 110.4119400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16571, 'Maoming', 'Maoming', 'Bo-beng-chhi,Bō͘-bêng-chhī,Chaozhou,Hsin-p''o,Hsin-p’o,Maiu-ming,Mao-ming,Mao-ming-shih,Maomin,Maoming,Mau Danh,Meu-miang-su,Meu-miàng-sṳ,Mâiu-mìng,Mậu Danh,mao ming,mao ming shi,maoming si,mawmng,mawmyng,Маомин,Маоминг,ماومنگ,ماومینگ,茂名,茂名市,마오밍 시', 21.6500000, 110.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16572, 'Maomiaoji', 'Maomiaoji', 'Baiquan,Baiquan Jiedao,Mao-miao-chi,Maomiaoji,bai quan,bai quan jie dao,mao miao ji,柏泉,柏泉街道,茅庙集', 30.7305900, 114.1174400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16573, 'Maolin', 'Maolin', 'Mao-lin-chen,Mao-lin-ts''un,Mao-lin-ts’un,Maolin,Maolin Zhen,mao lin,mao lin zhen,茂林,茂林镇', 30.5089600, 118.2481900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16574, 'Maoli', 'Maoli', 'Mao-lao-tien,Maoli,Maoli Zhen,Maolidian,mao li,mao li zhen,毛李,毛李镇', 30.5069400, 112.4725000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16575, 'Maojing', 'Maojing', 'Mao-ching,Maojing,Maojing Xiang,mao jing,mao jing xiang,毛井,毛井乡', 36.4644800, 106.6065600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16576, 'Haimen', 'Haimen', 'Hai-men-hsien,Haimen,Haimen Shi,Haimen Zhen,Haimenting,Mao-chia-chen,Maojiazhen,hai men,hai men shi,hai men zhen,海门,海门市,海门镇', 31.8961900, 121.1727400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16577, 'Maojiazao', 'Maojiazao', 'Mao-chia-tsao,Maojiazao,Maojiazao Zhen,mao jia zao,mao jia zao zhen,毛家皂,毛家皂镇', 39.9187400, 113.2695800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16578, 'Maojiagang', 'Maojiagang', 'Mao-chia-chiang,Maojiagang,Maojiagang Zhen,mao jia gang,mao jia gang zhen,毛家港,毛家港镇', 30.0438900, 112.0686100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16579, 'Maogou', 'Maogou', 'Mao-kou-chai,Maogou,Maogou Zhen,mao gou,mao gou zhen,毛沟,毛沟镇', 28.6009800, 109.3743100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16580, 'Maogang', 'Maogang', 'Liu-chiang-chen,Mao-chiang,Mao-chiang-chen,Mao-kang,Mao-kang-chen,Maogang,mao gang,泖港', 30.9348700, 121.2090100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16581, 'Maodian', 'Maodian', 'Mao-tien,Maodian,Maodian Zhen,mao dian,mao dian zhen,茅店,茅店镇', 25.9058300, 115.0448200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16582, 'Maodi', 'Maodi', 'Mao-ti,Maodi,Maodi Zhen,mao de,mao de zhen,茂地,茂地镇', 26.7025100, 118.0736500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16583, 'Maoba', 'Maoba', 'Mao-pa,Maoba,Maoba Xiang,mao ba,mao ba xiang,毛坝,毛坝乡', 30.0241000, 109.0428500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16584, 'Liangshuijing', 'Liangshuijing', 'Liangshuijing,Manshui,Manshui Xiang,liang shui jing,man shui,man shui xiang,凉水井,漫水,漫水乡', 29.2883800, 109.2764300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16585, 'Manjiang', 'Manjiang', 'Man-chiang,Manjiang,Manjiang Xiang,Mankiang,man jiang,man jiang xiang,漫江,漫江乡', 28.8231100, 114.4051500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16586, 'Quedantang', 'Quedantang', 'Guinan,Guynan'',Guynan’,Kuei-nan,Mang-la,Mangla Xiang,Mangra,Quedantang,mang la xiang,que dan tang,却旦塘,茫拉乡', 35.6502200, 100.6000600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16587, 'Malou', 'Malou', 'Malou,ma lou,马楼', 33.6798700, 112.9859700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16588, 'Maling', 'Maling', 'Maling,Maling Zhen,ma ling,ma ling zhen,马岭,马岭镇', 36.2175700, 107.6432600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16589, 'Tianya', 'Tianya', 'Ma-ling-shih,Maling,Tianya,Tianya Zhen,Yamamia,Yamamin,tian ya,tian ya zhen,天涯,天涯镇', 18.3083500, 109.3267600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16590, 'Malin', 'Malin', '', 26.4550000, 110.6416700, 'CN', '2004-05-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16591, 'Malichang', 'Malichang', 'Malichang,Malichang Zhen,ma li chang,ma li chang zhen,麻栗场,麻栗场镇', 28.4354600, 109.4911500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16592, 'Malianzhuang', 'Malianzhuang', 'Ma-lien-chuang,Malianzhuang,Malianzhuang Zhen,ma lian zhuang,ma lian zhuang zhen,马连庄,马连庄镇', 37.0748400, 120.4625100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16593, 'Maliang', 'Maliang', 'Maliang,Maliang Zhen,Maliangping,ma liang,ma liang zhen,马良,马良镇', 31.5386200, 111.3182500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16594, 'Maliang', 'Maliang', 'Maliang,Maliang Zhen,Maling,ma liang,ma liang zhen,马良,马良镇', 30.8856500, 112.5479300, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16595, 'Malianchuan', 'Malianchuan', 'Ma-lien-ch''uan,Ma-lien-ch’uan,Malian Xiang,Malianchuan,ma lian chuan,ma lian xiang,马连乡,马连川', 35.8095900, 105.9243500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16596, 'Malian', 'Malian', 'Ma-lien,Ma-lien-ts''un,Ma-lien-ts’un,Malian,Malian Zhen,ma lian,ma lian zhen,马连,马连镇', 34.3688100, 108.3340500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16597, 'Mali', 'Mali', 'Ma-li-chen,Ma-li-p''o-kung-she,Ma-li-p''o-shih,Ma-li-p’o-kung-she,Ma-li-p’o-shih,Mali,Malipo,ma li,麻栗', 23.1262100, 104.7409000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16598, 'Makou', 'Makou', 'Makou,Makou Zhen,ma kou,ma kou zhen,马口,马口镇', 30.5685600, 113.8329500, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16599, 'Makou', 'Makou', 'Makou,Makou Zhen,ma kou,ma kou zhen,马口,马口镇', 28.9568500, 115.7614800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16600, 'Majing’ao', 'Majing''ao', 'Ma-ching-ao,Majing''ao,Majing''ao Zhen,Majing’ao,Majing’ao Zhen,ma jing ao,ma jing ao zhen,马颈坳,马颈坳镇', 28.4063900, 109.7970800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16601, 'Majin', 'Majin', 'Kinmachen,Ma-chin,Ma-chin-chen,Ma-chin-chien,Majin,Majin Zhen,ma jin,ma jin zhen,马金,马金镇', 29.3035700, 118.4123800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16602, 'Majie', 'Majie', 'Ma-chieh,Majie,Majiezi,ma jie,马街', 25.0319000, 102.6380000, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16603, 'Majian', 'Majian', 'Ma-chien,Ma-chien-shih,Majian,Majian Zhen,ma jian,ma jian zhen,马涧,马涧镇', 29.3115000, 119.5989100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16604, 'Majiadian', 'Majiadian', 'Ma-chia-tien,Majiadian', 39.6577800, 117.2661100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16605, 'Zhijiang', 'Zhijiang', 'Chih-chiang,Chikiang,GJN,Ma-chia-tien,Majiadian,Zhijiang', 30.4213900, 111.7533300, 'CN', '2014-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16606, 'Maji', 'Maji', 'Ma-chi,Ma-chia-chi,Maji,Maji Zhen,ma ji,ma ji zhen,马集,马集镇', 32.5311600, 118.8079300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16607, 'Maji', 'Maji', 'Ma-chi,Maji,Maji Zhen,ma ji,ma ji zhen,马集,马集镇', 32.3545800, 119.1670600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16608, 'Maiwang', 'Maiwang', 'Maiwang,Maiwang Zhen,Mowangtsui,mai wang,mai wang zhen,脉旺,脉旺镇', 30.4974900, 113.5960900, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16609, 'Maishi', 'Maishi', 'Mai-shih,Maishi,Maishi Zhen,mai shi,mai shi zhen,麦市,麦市镇', 29.1709200, 113.9575600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16610, 'Maima', 'Maima', 'Maima,Manrima,Manrima Xiang,man ri ma,man ri ma xiang,曼日玛,曼日玛乡', 33.6408600, 102.0687500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16611, 'Maichen', 'Maichen', 'Mai-ch''en-hsu,Mai-ch’en-hsü,Maichen,Maichen Zhen,mai chen,mai chen zhen,迈陈,迈陈镇', 20.3350000, 109.9948100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16612, 'Mahuiling', 'Mahuiling', 'Mahuiling,Mahuiling Zhen,ma hui ling,ma hui ling zhen,马迴岭,马迴岭镇', 29.4461400, 115.8016600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16613, 'Souziqiu', 'Souziqiu', 'Mahekou,Mahekou Baizuxiang,Souziqiu,ma he kou,ma he kou bai zu xiang,suo zi qiu,梭子丘,马合口,马合口白族乡', 29.5434900, 110.3633600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16614, 'Mahekou', 'Mahekou', 'Ma-ho-k''ou,Ma-ho-k’ou,Mahekou,Mahekou Zhen,ma he kou,ma he kou zhen,麻河口,麻河口镇', 29.2983300, 112.2813900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16615, 'Magutian', 'Magutian', 'Ma-ku-t''ien,Ma-ku-t’ien,Magutian,Magutian Zhen,ma gu tian,马谷田', 32.6738300, 113.4737300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16616, 'Magong', 'Magong', 'Ma-kung,Ma-tsung,Magong,ma gong,马宫', 22.7901900, 115.2385300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16617, 'Magitang', 'Magitang', 'Chien-cha,Jainca,Janca,Jianza,Jianza Xian,Ma-k''o,Ma-k''o-t''ang,Ma-kai-t''ang,Ma-kai-t’ang,Ma-k’o,Ma-k’o-t’ang,Magitang,Maketang Zhen,jian zha,jian zha xian,ma ke tang,ma ke tang zhen,尖扎,尖扎县,马克唐,马克唐镇', 35.9385900, 102.0296800, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16618, 'Magang', 'Magang', 'Magang,Magang Zhen,ma gang,ma gang zhen,麻岗,麻岗镇', 21.5460700, 111.1680200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16619, 'Majiang', 'Majiang', 'Majiang,Majiang Zhen,ma jiang,ma jiang zhen,马江,马江镇', 26.7116100, 113.5400000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16620, 'Ma’e', 'Ma''e', 'Ma''e,Ma''e Zhen,Ma-o,Ma-o-chen,Ma’e,Ma’e Zhen,ma e,ma e zhen,马额,马额镇', 34.8244400, 108.9302800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16621, 'Ma’e', 'Ma''e', 'Ma''e,Ma''e Zhen,Ma-o,Ma-o-chen,Ma’e,Ma’e Zhen,ma e,马额', 34.4032200, 109.3846900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16622, 'Madian', 'Madian', 'Hsi-ma-tien,Ma-tien,Madian,Madian Zhen,ma dian,ma dian zhen,马甸,马甸镇', 32.2354600, 119.9584700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16623, 'Madaotou', 'Madaotou', 'Ma-tao-t''ou,Ma-tao-t’ou,Madaotou,Madaotou Xiang,ma dao tou,ma dao tou xiang,马道头,马道头乡', 39.8761100, 112.7686100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16624, 'Madao', 'Madao', 'Ma-tao,Ma-tao-chen,Ma-tao-i,Madao,Madao Zhen,Madaoi,Mataoyi,ma dao,ma dao zhen,马道,马道镇', 33.4241800, 107.0001400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16625, 'Madang', 'Madang', 'Ma-tang,Madang,Madang Zhen,Matung,ma dang,ma dang zhen,马垱,马垱镇', 29.9906400, 116.6544300, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16626, 'Macheng', 'Macheng', 'Macheng,Macheng Zhen,Machengpu,ma cheng,ma cheng zhen,麻城,麻城镇', 30.9087400, 112.2898400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16627, 'Macheng', 'Macheng', 'HBM,Ma-ch''eng-hsien,Ma-ch’eng-hsien,Macheng,Máchéng,ma cheng,ma cheng shi,macheong si,麻城,麻城市,마청 시', 31.1801300, 115.0221300, 'CN', '2013-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16628, 'Machang', 'Machang', 'Ma-ch''ang-chen,Ma-ch’ang-chen,Machang,Machang Zhen,ma chang,ma chang zhen,马厂,马厂镇', 34.0833300, 119.0166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16629, 'Mabugang', 'Mabugang', 'Mabugang,Mabugang Zhen,ma bu gang,ma bu gang zhen,麻布岗,麻布岗镇', 24.5891700, 115.4144700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16630, 'Mabu', 'Mabu', 'Ma-pu,Mabu,Mabu Zhen,ma bu,ma bu zhen,马埠,马埠镇', 27.5600000, 115.3924400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16631, 'Mabi', 'Mabi', 'Ma-pi,Mabi,Mabi Zhen,ma bi,ma bi zhen,马鼻,马鼻镇', 26.3754200, 119.6560400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16632, 'Maba', 'Maba', 'Ma-chia-pa,Ma-pa,Maba,Maba Zhen,ma ba,ma ba zhen,马坝,马坝镇', 32.9799100, 118.7805200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16633, 'Maba', 'Maba', 'Ch''u-chiang,Ch’ü-chiang,Ma-pa,Ma-pa-hsu,Ma-pa-hsü,Maba,Qujiang,ma ba,马坝', 24.6841300, 113.5983900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16634, 'Ma’ao', 'Ma''ao', 'Ma''ao,Ma''ao Zhen,Ma-ao-chieh,Ma-shih-ch''ieh,Ma-shih-ch’ieh,Ma’ao,Ma’ao Zhen,ma ao,ma ao zhen,马坳,马坳镇', 29.0553700, 114.3269500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16635, 'Ma’an', 'Ma''an', 'Ma''an,Ma''anshi,Ma-an-shih,Ma’an,Ma’anshi', 26.9775000, 110.7211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16636, 'Ma’anshan', 'Ma''anshan', 'Kai-yuan,Ma''anshan,Ma''anshan Shi,Ma-an-shan-shih,Mang-shan,Ma’anshan,Ma’anshan Shi,ma an shan,ma an shan shi,马鞍山,马鞍山市', 31.6857900, 118.5100800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16637, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Zhen,Ma-an-kuan,Ma’an,Ma’an Zhen,ma an,ma an zhen,马安,马安镇', 32.9774000, 110.2066500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16638, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Zhen,Ma-an-chen,Ma’an,Ma’an Zhen,Yuan-chia-ch''iao,Yüan-chia-ch’iao,ma an,ma an zhen,马鞍,马鞍镇', 30.1473000, 120.5817400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16639, 'Luzhou', 'Luzhou', 'Khehfehj,LZO,Lo Chau,Lo-chiu-chhi,Lu,Lu-chou,Lu-chou-shih,Lu-ciu,Lu-cou,Lu-hsien,Lu-čou,Luchow,Luchzhou,Ludzhou,Ludzou,Lutsjou,Luzhou,Lô Châu,Lô͘-chiu-chhī,Lù-ciŭ,lu zhou,lu zhou shi,lujeou si,lwjw,lwzhww,Луджоу,Лучжоу,Луџоу,Хэфэй,لوجو,لوژوو,泸州,泸州市,瀘州,瀘州市,루저우 시', 28.8903000, 105.4257500, 'CN', '2013-05-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16640, 'Luzhi', 'Luzhi', 'Lu-chih,Lu-chih-chen,Luzhi,Luzhi Zhen,lu zhi,lu zhi zhen,甪直,甪直镇', 31.2764200, 120.8676200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16641, 'Luzhai', 'Luzhai', 'Lu-chai,Lu-chai-chen,Lu-chai-hsu,Lu-chai-hsü,Luzhai,lu zhai,鹿寨', 24.4975400, 109.7331500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16642, 'Luyuan', 'Luyuan', 'Gaolin,Gaoling,Kao-ling,Kao-ling-hsien,Kao-ling-hsien-ch''eng,Kao-ling-hsien-ch’eng,Luyuan,lu yuan,鹿苑', 34.5359600, 109.0850800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16643, 'Xiguan', 'Xiguan', 'Lu-i,Lu-i-hsien,Luyi,Xiguan,xi guan,西关', 33.8666700, 115.4666700, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16644, 'Luyang', 'Luyang', '', 27.6238900, 110.0988900, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16645, 'Luxu', 'Luxu', 'Binyang,Binzhou,Lu-hsu,Lu-hsu-chen,Lu-hsü,Lu-hsü-chen,Luxu,Pin-yang,Pin-yang-hsien,lu wei,芦圩', 23.2211700, 108.8029900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16646, 'Lüxiang', 'Luxiang', 'Lu-hsiang,Luxiang,Luxiang Zhen,Lü-hsiang,Lüxiang,lu xiang,lu xiang zhen,吕巷,吕巷镇', 30.8298500, 121.1701000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16647, 'Luxia', 'Luxia', 'Lu-hsia,Luxia', 26.9300000, 118.8072200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16648, 'Luxi', 'Luxi', 'Lu-ch''i,Lu-ch’i,Luxi,Luxi Xiang,lu xi,lu xi xiang,芦溪,芦溪乡', 29.7073600, 117.5065200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16649, 'Luxi', 'Luxi', 'Lu-hsi,Luxi,Luxi Xian,Luxi Zhen,lu xi,lu xi xian,lu xi zhen,芦溪,芦溪县,芦溪镇', 27.6361800, 114.0352900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16650, 'Luwan', 'Luwan', 'Luwan,lu wan,卢湾', 31.2090800, 121.4633500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16651, 'Lutou', 'Lutou', 'Lu-t''ou-chen,Lu-t’ou-chen,Lutou,Lutou Zhen,lu tou,lu tou zhen,鹿头,鹿头镇', 32.2455000, 112.9298700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16652, 'Lutian', 'Lutian', 'Lutian,Lutian Zhen,lu tian,lu tian zhen,芦田,芦田镇', 25.0231700, 117.8241200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16653, 'Lütian', 'Lutian', 'Lu-t''ien,Lutian,Lutian Zhen,Lvtian Zhen,Lü-t’ien,Lütian,Lütian Zhen,lu tian,lu tian zhen,吕田,吕田镇', 23.8111100, 113.9441300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16654, 'Lusi', 'Lusi', 'Lusi,Lusi Xiang,Lusibu,lu ci,lu ci bu,lu ci xiang,鸬鹚,鸬鹚乡,鸬鹚埠', 28.8987400, 117.3033800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16655, 'Lüsigang', 'Lusigang', 'Lu-ssu,Lu-ssu-chen,Lusi,Lusigang,Lusigang Zhen,Lusze,Lü-ssu,Lü-ssu-chen,Lüsi,Lüsigang,Lüsigang Zhen,lu si gang,lu si gang zhen,吕四港,吕四港镇', 32.0553300, 121.5955400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16656, 'Lüshun', 'Lushun', 'Lu-shun-k''ou,Lu-shun-k''ou-ch''u,Lu-shun-shih,Lueshun,Lueshunkou,Lushun,Lusunkchou,Lušunkchou,Lü-shun-k’ou,Lü-shun-k’ou-ch’ü,Lü-shun-shih,Lüshun,Lüshunkou,Por Arthur,Port Arthur,Port-Artur,Redzyun,Riojun,Ryojun,Rëdzyun,lu shun,lu shun kou qu,lwisun,port-artur,Порт-Артур,פורט ארתור,旅順,旅顺口区,뤼순', 38.8000000, 121.2666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16657, 'Lushui', 'Lushui', 'Lushui,Lushui Zhen,Zhuzishan,lu shui,lu shui zhen,zhu zi shan,潞水,潞水镇,竹子山', 26.9597500, 113.5558100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16658, 'Liushikou', 'Liushikou', 'Liushi,Liushi Zhen,Liushikou,Lu-shih-k''ou,Lu-shih-k''ou-shih,Lü-shih-k’ou,Lü-shih-k’ou-shih,liu shi kou,liu shi zhen,六石口,六石镇', 29.3059700, 120.3321000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16659, 'Lushi Chengguanzhen', 'Lushi Chengguanzhen', 'Lu-shih,Lushi,Lushi Chengguanzhen,lu shi cheng guan zhen,卢氏城关镇', 34.0486100, 111.0327800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16660, 'Lushi', 'Lushi', 'Lu-shih,Lushi,Lushi Zhen,lu shi,lu shi zhen,卢市,卢市镇', 30.6664900, 113.3361700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16661, 'Lushar', 'Lushar', 'Huang-chung,Huang-chung-hsien,Huangzhong,Huangzhong Xian,Lu-sha-erh,Lu-sha-erh-chen,Lusha''er,Lushar,Lusha’er,T''a-erh-ssu,T’a-erh-ssu,huang zhong xian,lu sha er,湟中县,鲁沙尔', 36.4841600, 101.5632800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16662, 'Lüshan', 'Lushan', 'Lu-shan-chen,Lushan,Lushan Zhen,Lü-shan-chen,Lüshan,Lüshan Zhen,lu shan,lu shan zhen,吕山,吕山镇', 30.9302200, 119.9179100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16663, 'Luyang', 'Luyang', 'Lu-shan-hsien,Lushan,Luyang,Luyang Jiedao,lu yang,lu yang jie dao,鲁阳,鲁阳街道', 33.7356400, 112.9050800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16664, 'Luqiao', 'Luqiao', 'Lu-ch''iao,Lu-ch''iao-chen,Lu-ch’iao,Lu-ch’iao-chen,Luqiao,Luqiao Zhen,Yu-ch''iao-chen,Yü-ch’iao-chen,lu qiao,lu qiao zhen,鲁桥,鲁桥镇', 34.6850000, 108.9177800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16665, 'Luqiao', 'Luqiao', 'Jagsamka,Lu-ting,Lu-ting-chiao,Lu-ting-hsien,Luding,Luding Xian,Luqiao,Lutingkiao,lu ding xian,lu qiao,泸定县,泸桥', 29.9324600, 102.2316300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16666, 'Luqiao', 'Luqiao', 'Lu-ch''iao,Lu-ch''iao-chen,Lu-ch’iao,Lu-ch’iao-chen,Luqiao,Luqiaozhen,lu qiao,路桥', 28.5802300, 121.3749100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16667, 'Luozhou', 'Luozhou', 'Lo-chou,Lo-chou-chen,Luozhou,Luozhou Zhen,Min-hou,Min-hou-hsien,luo zhou,luo zhou zhen,螺洲,螺洲镇', 25.9853200, 119.3442100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16668, 'Luoyuan', 'Luoyuan', 'Lo-yuan,Lo-yuan-chieh,Lo-yüan,Lo-yüan-chieh,Luoyuan,Luoyuan Zhen,Luoyuanjie,luo yuan,洛源', 34.2001400, 109.8172800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16669, 'Luoyang', 'Luoyang', 'Lo-yang-tien,Lojan,Luoyang,Luoyang Zhen,Luoyangdian,luo yang,luo yang zhen,Лоян,洛阳,洛阳镇', 31.4729300, 113.4253200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16670, 'Luoyang', 'Luoyang', 'Gorad Lajan,Honan,Honanfu,LYA,Lac Duong,Lo-yand,Lo-yang,Lo-yang-hsien,Lo-yang-shih,Lojan,Lojan shaary,Lojang,Lok-iong,Lok-iong-chhi,Lo̍k-iông-chhī,Luo-jang,Luojan,Luojang,Luojangas,Luojango,Luoyang,Lŏk-iòng,Lŭojango,Lạc Dương,lk xei yng,loiani,lu''oyanga,luo yang,luo yang shi,lwoyang si,lwwyang,lwyangh,lwywyang,Горад Лаян,Лоян,Лоян шаары,Луоян,Луојанг,לוו-יאנג,لوئویانگ,لوویانگ,لويانغ,لوياڭ شەھىرى,लुओयांग,ลกเอี๋ยง,ལུའོ་དབྱང་།,ლოიანი,洛阳,洛阳市,洛陽,洛陽市,뤄양 시', 34.6836100, 112.4536100, 'CN', '2014-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16671, 'Luoyang', 'Luoyang', 'Lo-yang,Lo-yang-ch''iao-chen,Lo-yang-ch’iao-chen,Lojan,Luoyang,Luoyang Zhen,luo yang,luo yang zhen,Лоян,洛阳,洛阳镇', 31.6470000, 120.0765100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16672, 'Luoyang', 'Luoyang', 'Chiu-t''ai-shun,Chiu-t’ai-shun,Lo-yang,Lo-yang-chen,Lojan,Luoyang,Luoyang Zhen,Taishun,Taishun Xian,luo yang,luo yang zhen,tai shun,tai shun xian,Лоян,泰顺,泰顺县,罗阳,罗阳镇', 27.5613900, 119.7113900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16673, 'Luoyang', 'Luoyang', 'Lo-yang,Lojan,Luoyang,luo yang,Лоян,洛阳', 24.9593800, 118.6830000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16674, 'Luoyang', 'Luoyang', 'Luoyang,Luoyang Zhen,luo yang,luo yang zhen,洛阳,洛阳镇', 24.6782700, 113.0436400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16675, 'Luoyang', 'Luoyang', 'Boluo,Fu-ch''eng,Fu-ch''eng-chen,Fu-ch’eng,Fu-ch’eng-chen,Hsien-ch''eng-chen,Hsien-ch’eng-chen,Lojan,Luoyang,Luoyang Zhen,Po-ch''eng-chen,Po-ch’eng-chen,Po-lo,Po-lo-hsien,Poklo,Poklohsien,luo yang,Лоян,罗阳', 23.1624400, 114.2734200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16676, 'Luoxiong', 'Luoxiong', 'Lo-p''ing,Lo-p''ing-hsien,Lo-p’ing,Lo-p’ing-hsien,Lopingchow,Luoping,Luoxiong,luo xiong,罗雄', 24.8855800, 104.2922500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16677, 'Luoxi', 'Luoxi', 'Lo-hsi,Luoxi,Luoxi Xiang,luo xi,luo xi xiang,罗溪,罗溪乡', 29.0898100, 114.9825500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16678, 'Luoxi', 'Luoxi', 'Luoxi,Luoxi Zhen,luo xi,luo xi zhen,罗溪,罗溪镇', 28.4149000, 116.1507400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16679, 'Luowa', 'Luowa', 'Luowa,Luowa Xiang,luo wa,luo wa xiang,罗洼,罗洼乡', 36.2603800, 106.5816200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16680, 'Luotuo’ao', 'Luotuo''ao', 'Luotuo''ao,Luotuo''ao Zhen,Luotuo’ao,Luotuo’ao Zhen,luo tuo ao,luo tuo ao zhen,骆驼坳,骆驼坳镇', 30.6864100, 115.3925700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16681, 'Luotuo', 'Luotuo', 'Lo-t''o-ch''iao,Lo-t’o-ch’iao,Luotouzhen,Luotuo,Luotuo Jiedao,luo tuo,luo tuo jie dao,骆驼,骆驼街道', 29.9845400, 121.5901600, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16682, 'Luotian', 'Luotian', 'Luotian,Luotian Zhen,luo tian,luo tian zhen,罗田,罗田镇', 27.5402600, 115.0490900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16683, 'Luotian', 'Luotian', 'Luotian,Luotian Zhen,luo tian,luo tian zhen,螺田,螺田镇', 27.0129900, 115.5389800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16684, 'Luoshe', 'Luoshe', 'Lo-she,Lo-she-chen,Luoshe,Luoshe Zhen,luo she,luo she zhen,洛社,洛社镇', 31.6443600, 120.1823200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16685, 'Luoshe', 'Luoshe', 'Lo-she-chen,Luoshe,Luoshe Zhen,luo she,luo she zhen,洛舍,洛舍镇', 30.6344400, 120.0888900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16686, 'Luoshan Chengguanzhen', 'Luoshan Chengguanzhen', 'Lo-shan,Lo-shan-hsien,Luoshan,Luoshan Chengguanzhen,luo shan cheng guan zhen,罗山城关镇', 32.2031800, 114.5094200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16687, 'Luoshan', 'Luoshan', 'Kin Lo Shan,Lo-shan,Luoshan,Luoshan Zhen,luo shan,luo shan zhen,螺山,螺山镇', 29.6687300, 113.3128200, 'CN', '2015-11-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16688, 'Luorong', 'Luorong', 'Chiu-lo-jung,Lo-jung,Lo-jung-hsien,Lo-jung-hsien-ch''eng,Lo-jung-hsien-ch’eng,Loyung-hsien,Luorong', 24.4058300, 109.6086100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16689, 'Luoqiao', 'Luoqiao', 'Luoqiao,Luoqiao Jiedao,luo qiao,luo qiao jie dao,罗桥,罗桥街道', 30.1467800, 114.9542600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16690, 'Luoqiao', 'Luoqiao', 'Li-liao,Lo-ch''iao,Lo-ch’iao,Luoqiao,luo qiao,罗桥', 26.4726500, 119.0039200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16691, 'Luoqi', 'Luoqi', 'Lo-ch''i,Lo-ch’i,Luoqi,Luoqi Zhen,luo qi,luo qi zhen,洛碛,洛碛镇', 29.7141000, 106.9334100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16692, 'Luoping', 'Luoping', 'Luoping,Luoping Zhen,luo ping,luo ping zhen,骡坪,骡坪镇', 31.2065900, 110.0867900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16693, 'Luoping', 'Luoping', 'Luoping,Luoping Zhen,luo ping,luo ping zhen,罗坪,罗坪镇', 29.2318200, 115.2573800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16694, 'Luoping', 'Luoping', 'Luoping,Luoping Zhen,luo ping,luo ping zhen,罗平,罗平镇', 22.6247700, 111.5667100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16695, 'Luoning Chengguanzhen', 'Luoning Chengguanzhen', 'Lo-ning,Lo-ning-hsien,Luninghsien,Luoning,Luoning Chengguanzhen,Yiungninghsien,Yung-ning,luo ning cheng guan zhen,洛宁城关镇', 34.3877800, 111.6558300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16696, 'Luolong', 'Luolong', 'Lo-lung,Luolong,Luolong Zhen,luo long,luo long zhen,洛龙,洛龙镇', 29.0725000, 107.7002800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16697, 'Luokou', 'Luokou', 'Lo-k''ou,Lo-k’ou,Luokou,Luokou Zhen,luo kou,luo kou zhen,洛口,洛口镇', 26.8532400, 116.0701800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16698, 'Luokeng', 'Luokeng', 'Lo-k''eng,Lo-k''eng-hsu,Lo-k’eng,Lo-k’eng-hsü,Luokeng,Luokeng Zhen,luo keng,luo keng zhen,罗坑,罗坑镇', 24.5170000, 113.3362800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16699, 'Luojiu', 'Luojiu', 'Lo-chiu,Luojiu', 27.5158300, 109.8088900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16700, 'Luojing', 'Luojing', 'Luojing,Luojing Zhen,luo jing,luo jing zhen,罗泾,罗泾镇', 31.4782000, 121.3390700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16701, 'Luojiaping', 'Luojiaping', 'Luojiaping,Luoping,Luoping Xiang,luo jia ping,luo ping,luo ping xiang,罗坪,罗坪乡,罗家坪', 29.7551900, 110.6985000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16702, 'Luojiang', 'Luojiang', 'Lo-chiang,Lo-chiang-chen,Lo-chiang-hsien,Lokiang,Lokiang-hsien,Lotszyan,Luojiang,luo jiang,罗江', 31.3049700, 104.5048400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16703, 'Luodian', 'Luodian', 'Lo-chia-tien,Luodian,Luodian Xiang,Luojiadian,luo dian,luo dian xiang,骆店,骆店乡', 31.5473100, 113.7793800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16704, 'Luohuang', 'Luohuang', 'Lo-huang,Luohuang,Luohuang Zhen,Luohuangshi,luo huang,luo huang zhen,珞璜,珞璜镇', 29.3466200, 106.4351400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16705, 'Luohong', 'Luohong', 'Lo-hung,Luohong,Luohongxiang,Zhongluohong,luo hong,luo hong xiang,zhong luo hong,中罗洪,罗洪,罗洪乡', 27.5555600, 111.0752800, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16706, 'Luohe', 'Luohe', 'Lo-he,Lo-ho,Lo-ho-chai,Lo-ho-shih,Lokheh,Lui-ho-chhi,Luo-che,Luohe,Luokhe,Lúi-hô-chhī,T''a-ho,T''a-ho-chai,Tak-o,Thap Ha,Tháp Hà,Ták-ò̤,T’a-ho,T’a-ho-chai,luo he,luo he shi,lwhy,lwoheo si,raku he shi,Лохэ,Луохе,لوهی,ラク河市,漯河,漯河市,뤄허 시', 33.5639400, 114.0427200, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16707, 'Luogang', 'Luogang', 'Lo-kang,Luogang,Luogang Zhen,luo gang,luo gang zhen,螺岗,螺岗镇', 23.7298800, 112.5095100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16708, 'Luofu', 'Luofu', 'Lo-fu,Luofu,Luofu Zhen,luo fu,luo fu zhen,罗浮,罗浮镇', 24.5271100, 115.5792600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16709, 'Luoshi', 'Luoshi', 'Lo-fang,Lo-fang-chieh,Luofang,Luoshi,Luoshi Zhen,luo shi,luo shi zhen,罗市,罗市镇', 28.6833300, 115.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16710, 'Luofang', 'Luofang', 'Luofang,Luofang Zhen,luo fang,luo fang zhen,罗坊,罗坊镇', 27.8548200, 115.1127000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16711, 'Luofang', 'Luofang', 'Lo-fang,Luofang,luo fang,罗坊', 25.9125000, 117.0077800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16712, 'Luofang', 'Luofang', 'Lo-fang,Luofang,Luofang Xiang,luo fang,luo fang xiang,罗坊,罗坊乡', 25.7506800, 116.6836900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16713, 'Luocheng', 'Luocheng', 'Lo-ch''eng-chen,Lo-ch’eng-chen,Lo-ting,Lo-ting-hsien,Lotingchow,Luocheng,Luocheng Jiedao,Luoding,luo cheng,luo cheng jie dao,luo ding,罗城,罗城街道,罗定', 22.7695300, 111.5688200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16714, 'Luodian', 'Luodian', 'Lo-tien,Luodian,Luodian Zhen,luo dian,luo dian zhen,罗店,罗店镇', 31.1127300, 113.3921300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16715, 'Luodian', 'Luodian', 'Luodian,Luodian Zhen,luo dian,luo dian zhen,罗店,罗店镇', 29.1616000, 119.6141500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16716, 'Luocun', 'Luocun', 'Lo-ts''un,Lo-ts’un,Luocun,Luocun Jiedao,luo cun,luo cun jie dao,罗村,罗村街道', 23.0564000, 113.0328000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16717, 'Luochuan', 'Luochuan', 'Luochuan,Luochuan Xiang,luo chuan,luo chuan xiang,罗川,罗川乡', 36.6122000, 106.0016700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16718, 'Luocheng', 'Luocheng', 'Guanghan,Han-chou,Hanchow,Kuang-han,Kuang-han-hsien,Kwanghan,Kwanghan-hsien,Luocheng,luo cheng,雒城', 30.9802100, 104.2808100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16719, 'Luocheng', 'Luocheng', 'Lo-ch''eng-p''u,Lo-ch’eng-p’u,Luocheng,luo cheng,罗城', 29.3848100, 104.0286200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16720, 'Luocheng', 'Luocheng', 'Huei-an,Hui''an,Hui-an-hsien,Hui’an,Hweian,Hweianhsien,Luocheng,luo cheng,螺城', 25.0323100, 118.7949500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16721, 'Luobei', 'Luobei', 'Luobei,Luobei Xiang,luo bei,luo bei xiang,罗陂,罗陂乡', 27.1507300, 115.7031300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16722, 'Luo’ao', 'Luo''ao', 'Lo-ao,Lo-wa,Luo''ao,Luo''ao Zhen,Luo’ao,Luo’ao Zhen,luo ao,luo ao zhen,罗坳,罗坳镇', 25.9347300, 115.2929500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16723, 'Lunjiao', 'Lunjiao', 'Lun-chiao,Lunjiao,Lunjiao Jiedao,lun jiao,lun jiao jie dao,伦教,伦教街道', 22.8739700, 113.2120900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16724, 'Luncang', 'Luncang', 'Luncang,Luncang Zhen,Yuanmeidu,lun cang,lun cang zhen,仑苍,仑苍镇', 25.0096400, 118.2806400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16725, 'Lufu', 'Lufu', 'Dongfanghong,Lu-nan-hsien,Lu-nan-i-tsu-tzu-chih-hsien,Lufu,Lunan,Lunan-chow,Shilin Yizu Zizhixian,lu fu,shi lin yi zu zi zhi xian,石林彝族自治县,鹿阜', 24.7602000, 103.2664700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16726, 'Lümeng', 'Lumeng', 'Lumeng,Lumeng Xiang,Lumengdu,Lümeng,Lümeng Xiang,Lümengdu,lu meng,lu meng xiang,吕蒙,吕蒙乡', 29.2695700, 117.1716200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16727, 'Lukou', 'Lukou', 'Lu-k''ou-chen,Lu-k’ou-chen,Lukou,Lukou Zhen,lu kou,lu kou zhen,禄口,禄口镇', 31.7708200, 118.8681700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16728, 'Lukou', 'Lukou', 'Lukou,Lukou Zhen,lu kou,lu kou zhen,路口,路口镇', 30.4925500, 114.9363900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16729, 'Lukou', 'Lukou', 'Lukou,Lukou Zhen,lu kou,lu kou zhen,路口,路口镇', 29.5709900, 114.2061600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16730, 'Lukou', 'Lukou', 'Chu-chou,Chu-chou-hsien,Lu-k''ou-shih,Lu-k’ou-shih,Lukou,Lukow,Zhuzhou,Zhuzhou Xian,lu kou,zhu zhou xian,柱洲县,渌口', 27.7029200, 113.1520200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16731, 'Lukou', 'Lukou', 'Lukou,Lukou Zhen,lu kou,lu kou zhen,路口,路口镇', 27.2836300, 114.1002000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16732, 'Lujiao', 'Lujiao', 'Lujiao,Lujiao Zhen,Lujiaotuo,lu jiao,lu jiao zhen,鹿角,鹿角镇', 29.1343600, 108.2852300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16733, 'Lujiao', 'Lujiao', 'Lujiao,Lujiao Zhen,lu jiao,lu jiao zhen,鹿角,鹿角镇', 29.1533300, 113.0075000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16734, 'Lucheng', 'Lucheng', 'Lu-chiang,Lu-chiang-hsien,Lucheng,Lujiang,Lujiang Xian,Lukiang,Lukiang-hsien,lu cheng,lu jiang xian,庐城,庐江县', 31.2335700, 117.2805700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16735, 'Lubu', 'Lubu', 'Lu-chia-pu,Lubu,Lubu Zhen,Lujiabu,lu bu,lu bu zhen,陆埠,陆埠镇', 29.9905200, 121.2303400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16736, 'Lujia', 'Lujia', 'Lu-chia,Lu-chia-pang,Lu-chia-peng,Lu-chia-peng-chen,Lu-chia-pin,Lu-chia-pin-chen,Lu-hsia-peng,Lu-hsia-peng-chen,Lujia,Lujia Zhen,Lujiabang,Lujiabangzhen,lu jia,lu jia zhen,陆家,陆家镇', 31.3158900, 121.0435000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16737, 'Luhua', 'Luhua', 'Heishui,Lu-hua-ch''eng,Lu-hua-ch’eng,Luhua,Lukhuachen,lu hua,芦花', 32.0670800, 102.9878600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16738, 'Lugouqiao', 'Lugouqiao', 'Lu-kou-ch''iao,Lu-kou-ch’iao,Lugouqiao,Lugouqiao Jiedao,Van''pin,Van’pin,Wan-p''ing-hsien,Wan-p’ing-hsien,Wanping,lu gou qiao,lu gou qiao jie dao,卢沟桥,卢沟桥街道', 39.8688000, 116.2774500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16739, 'Lugang', 'Lugang', 'Lu Kiang,Lu-chiang,Lu-kang,Lu-kang-chen,Lugang,Lugang Zhen,Wu Chi Yang,Wu-hu,Wu-hu-hsien,lu gang,lu gang zhen,鲁港,鲁港镇', 31.2728400, 118.3356400, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16740, 'Lugang', 'Lugang', 'Lugang,Lugang Xiang,lu gang,lu gang xiang,鹿冈,鹿冈乡', 27.4049200, 115.6186200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16741, 'Lufeng', 'Lufeng', 'Hsu-p''u,Hsu-p''u-hsien,Hsü-p’u,Hsü-p’u-hsien,Lufeng,Supu,Supu-hsien,Süpu-hsien,Xupu,lu feng,卢峰', 27.9094400, 110.5858300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16742, 'Lufeng', 'Lufeng', 'Fengji,Lufeng,Lufeng Shezuxiang,feng ji,lu feng,lu feng she zu xiang,丰济,庐丰,庐丰畲族乡', 24.9502000, 116.5084500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16743, 'Lüeyang Chengguanzhen', 'Lueyang Chengguanzhen', 'Liao-yang,Lioyan,Loayang,Lueh-yang,Lueh-yang-hsien,Lueyang,Lueyang Chengguanzhen,Lüeh-yang,Lüeh-yang-hsien,Lüeyang,Lüeyang Chengguanzhen,e yang,e yang cheng guan zhen,略阳,略阳城关镇', 33.3320500, 106.1549600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16744, 'Ludu', 'Ludu', 'Lu-tu-ch''iao,Lu-tu-ch’iao,Ludu,Ludu Xiang,Ludu Zhen,Luduqiao,lu du,lu du zhen,陆渡,陆渡镇', 31.4725200, 121.1844700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16745, 'Daxing', 'Daxing', 'Daxing,Daxing Zhen,Luchun,Lüchun,Ta-hsing-chai,Ta-hsing-chen,Ta-hsing-chieh,da xing,大兴', 22.9691600, 102.4061100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16746, 'Luhua', 'Luhua', 'Lu-ch''eng-chen,Lu-ch''eng-hsien,Lu-ch’eng-chen,Lu-ch’eng-hsien,Luchen,Lucheng,Lucheng Shi,Luhua,Luhua Jiedao,lu cheng,lu cheng shi,lu hua,lu hua jie dao,潞华,潞华街道,潞城,潞城市', 36.3313900, 113.2244400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16747, 'Lücheng', 'Lucheng', 'Lu-ch''eng-chen,Lucheng,Lucheng Zhen,Lü-ch’eng-chen,Lücheng,Lücheng Zhen,lu cheng,lu cheng zhen,吕城,吕城镇', 31.8985200, 119.7347100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16748, 'Lucheng', 'Lucheng', 'Lu-ch''eng-chen,Lu-ch’eng-chen,Lucheng,Lucheng Jiedao,Qishuyan Qu,lu cheng,lu cheng jie dao,qi shu yan qu,戚墅堰区,潞城,潞城街道', 31.7632400, 120.0458800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16749, 'Kangding', 'Kangding', 'Dardo,K''an-ting,K''ang-ting,K''ang-ting-hsien,KGT,Kandin,Kangding,Ta-chien-lu,Tarchendo,Tatsienlu,Tatsientu,Кандин,དར་མད།,དར་མདོ།', 30.0022200, 101.9569000, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16750, 'Wenquan', 'Wenquan', 'Lu-ch''eng-chen,Lu-ch''uan-hsien,Lu-ch’eng-chen,Lu-ch’uan-hsien,Lucheng,Luchuan,Luchwan,Luchwan-hsien,Wenquan,wen quan,温泉', 22.3252800, 110.2555600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16751, 'Lubu', 'Lubu', 'Lu-pu,Lubu,Lubu Zhen,lu bu,lu bu zhen,禄步,禄步镇', 23.1723300, 112.2829800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16752, 'Lubiaojie', 'Lubiaojie', 'Lu-piao,Lu-piao-chieh,Lubiao,Lubiao Zhen,Lubiaojie,lu biao,lu biao jie,lu biao zhen,禄脿,禄脿街,禄脿镇', 24.9756300, 102.2686900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16753, 'Lubao', 'Lubao', 'Lu-pao,Lu-pao-hsu,Lu-pao-hsü,Lubao,Lubao Zhen,lu bao,lu bao zhen,芦苞,芦苞镇', 23.3527800, 112.8963900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16754, 'Luanzhou', 'Luanzhou', 'Lu-an,Luan Xian,Luan-chou,Luan-hsien,Luan-hsien-ch''eng,Luan-hsien-ch''eng-kuan,Luan-hsien-ch’eng,Luan-hsien-ch’eng-kuan,Luanzhou,Lwanchow,Lwanhsien,luan xian,luan zhou,滦县,滦州', 39.7500000, 118.7333300, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16755, 'Luanchuan Chengguanzhen', 'Luanchuan Chengguanzhen', 'Luan-ch''uan-chen,Luan-ch’uan-chen,Luanchuan,Luanchuan Chengguanzhen,Luanchuan Xiang,luan chuan,luan chuan cheng guan zhen,luan chuan xiang,栾川,栾川乡,栾川城关镇', 33.7808000, 111.6130000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16756, 'Luancheng', 'Luancheng', 'Luan''chen,Luan-ch''eng-ch''eng-kuan,Luan-ch''eng-hsien,Luan-ch’eng-ch’eng-kuan,Luan-ch’eng-hsien,Luancheng,Luan’chen,Lwanchenghsien', 37.8791700, 114.6516700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16757, 'Lu’an', 'Lu''an', 'Liu-an,Liu-an-hsien,Liuanchow,Lu''an,Lu''an Shi,Lu’an,Lu’an Shi,liu an,liu an shi,六安,六安市', 31.7569400, 116.4913900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16758, 'Louzhuang', 'Louzhuang', 'Louzhuang,Louzhuang Zhen,lou zhuang,lou zhuang zhen,娄庄,娄庄镇', 32.5564400, 120.2207600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16759, 'Louguan', 'Louguan', 'Chi-chia,Chiao-chia,Chiao-chia-chen,Lou-kuan,Louguan,Louguan Zhen,lou guan,lou guan zhen,楼观,楼观镇', 34.0930100, 108.2991200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16760, 'Loufan', 'Loufan', 'Ho-chia-chuang,Hsin-lou-fan,Lou-fan-chen,Loufan,Loufan Xian,Loufan Zhen,lou fan,lou fan xian,lou fan zhen,娄烦,娄烦县,娄烦镇', 38.0918000, 111.8072100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16761, 'Loudi', 'Loudi', 'Lau GJe,Leu-di,Lo-te-chhi,Lou-ti,Lou-ti-chen,Lou-ti-shih,Loudi,Lâu Để,Lèu-dī,Lô͘-té-chhī,lou di,lou di shi,lwady,lwdy,lwodi si,Лоуди,لؤدی,لوادی,娄底市,婁底,婁底市,뤄디 시', 27.7344400, 111.9944400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16762, 'Longzhouping', 'Longzhouping', 'Ch''ang-yang-hsien,Changyang,Ch’ang-yang-hsien,Longzhouping,Longzhouping Zhen,long zhou ping,long zhou ping zhen,龙舟坪,龙舟坪镇', 30.4952500, 111.1597900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16763, 'Longzhou', 'Longzhou', 'Li-chiang,Longzhou,Lung-ching,Lung-ching-hsien,Lung-chou,Lung-chou-chen,Lung-hsien,Lung-shou,Lungchow,Lungchow-hsien,long zhou,龙州', 22.3996700, 106.7896700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16764, 'Longzhong', 'Longzhong', 'Longzhong,Longzhong Jiedao,Lung-chung,long zhong,long zhong jie dao,隆中,隆中街道', 32.0103600, 112.0814200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16765, 'Longyuanba', 'Longyuanba', 'Longyuanba,Longyuanba Zhen,Lung-yuan-pa,Lung-yüan-pa,long yuan ba,long yuan ba zhen,龙源坝,龙源坝镇', 24.9432000, 114.4501900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16766, 'Longzhou', 'Longzhou', 'Longyou,Longyou Xian,Longzhou,Longzhou Jiedao,Lung-yu,Lung-yu-hsien,Lung-yu-hsien-ch''eng,Lung-yu-hsien-ch’eng,long you xian,long zhou,long zhou jie dao,龙洲,龙洲街道,龙游县', 29.0327800, 119.1701500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16767, 'Longyang', 'Longyang', 'Longyang,Longyang Zhen,Lung-yang,Lung-yang-chen,long yang,龙阳', 34.8453700, 109.6871000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16768, 'Longyan', 'Longyan', 'LCX,Leng-na-chhi,Liung-ngam-su,Liùng-ngâm-sṳ,Long Nham,Longyan,Longyan Shi,Longyen shehiri,Lung-jen,Lung-ngang,Lung-yen,Lung-yen-hsien,Lungyenchow,Lunujan'',Lêng-nâ-chhī,Lṳ̀ng-ngàng,langyan,long yan,long yan shi,lung-yen si,lwnghyan,lwngyan,Лунъянь,لانگیان,لونغيان,لونگیان,竜岩,竜岩市,龍岩,龍岩市,龙岩,龙岩市,룽옌 시', 25.1072200, 117.0225000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16769, 'Longxu', 'Longxu', 'Cangwu,Jung-hsu,Jung-hsü,Longxu,Lung-hsu,Lung-hsu-chen,Lung-hsü,Lung-hsü-chen,Ts''ang-wu,Ts''ang-wu-hsien,Ts’ang-wu,Ts’ang-wu-hsien,Yunghu,Yunghü,long wei,龙圩', 23.4166700, 111.2333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16770, 'Longxing', 'Longxing', 'Longxing,Longxing Zhen,Lung-hsing,long xing,long xing zhen,龙兴,龙兴镇', 29.7019900, 106.7911000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16771, 'Longxing', 'Longxing', 'Longxing,Longxing Zhen,Lung-hsing,long xing,long xing zhen,隆兴,隆兴镇', 28.6744600, 107.5455600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16772, 'Longxian Chengguanzhen', 'Longxian Chengguanzhen', 'Long Xian,Longxian,Longxian Chengguanzhen,Lung,Lung-chou,Lung-hsien,Lungchow,Lunsyan'',Lunsyan’,long xian,long xian cheng guan zhen,陇县,陇县城关镇', 34.9073400, 106.8496500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16773, 'Longxian', 'Longxian', 'Longxian,Longxian Zhen,Lung-hsien,Lung-hsien-chen,Lung-hsien-hsu,Lung-hsien-hsü,Lungsinhu,Lungsinhü,Weng-yuan-hsien,Weng-yüan-hsien,Wengyuan Xian,long xian,long xian zhen,weng yuan xian,翁源县,龙仙,龙仙镇', 24.3452500, 114.1356800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16774, 'Longxi', 'Longxi', 'Longxi,Longxi Zhen,Lung-hsi,long xi,long xi zhen,龙溪,龙溪镇', 23.1422700, 114.1219500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16775, 'Longwo', 'Longwo', 'Longwo,Longwo Zhen,Lung-wo,Lung-wo-hsu,long wo,long wo zhen,龙窝,龙窝镇', 23.4757000, 115.3017900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16776, 'Longwen', 'Longwen', 'Longwen,Longwen Zhen,long wen,long wen zhen,隆文,隆文镇', 24.5946400, 116.3468100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16777, 'Longtou’an', 'Longtou''an', 'Longtou''an,Longtou’an,Lung-t''ou-an,Lung-t’ou-an,Lungtowan', 27.6702800, 110.3361100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16778, 'Longtou', 'Longtou', 'Longtou,Longtou Zhen,long tou,long tou zhen,隆头,隆头镇', 28.8707200, 109.4429300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16779, 'Longting', 'Longting', 'Longting,Longting Xiang,long ting,long ting xiang,龙廷,龙廷乡', 24.6546300, 115.6066200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16780, 'Longtian', 'Longtian', 'Longtian,Longtian Zhen,Lung-t''ien,Lung-t’ien,long tian,long tian zhen,龙田,龙田镇', 28.0166700, 111.9333300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16781, 'Longtian', 'Longtian', 'Longtian,Longtian Zhen,Lung-t''ien,Lung-t’ien,long tian,long tian zhen,龙田,龙田镇', 25.6117200, 119.4549000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16782, 'Longtian', 'Longtian', 'Longtian,Longtian Zhen,Lung-t''ien,Lung-t’ien,long tian,long tian zhen,龙田,龙田镇', 24.2187700, 115.7092300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16783, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,Longtanshui,long tan,long tan shui,long tan zhen,龙潭,龙潭水,龙潭镇', 28.9619800, 111.1309500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16784, 'Longtanping', 'Longtanping', 'Longtanping,Longtanping Zhen,long tan ping,long tan ping zhen,龙潭坪,龙潭坪镇', 29.6769200, 110.1566300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16785, 'Longtanhe', 'Longtanhe', 'Longtanhe,Longtanhe Zhen,Lung-t''an-ho,Lung-t’an-ho,long tan he,long tan he zhen,龙潭河,龙潭河镇', 29.2433800, 111.0760500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16786, 'Longtang', 'Longtang', 'Longtang,Longtang Xiang,long tang,long tang xiang,龙塘,龙塘乡', 28.4427800, 111.4019400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16787, 'Longtang', 'Longtang', 'Longtang,Longtang Zhen,Lung-t''ang,Lung-t’ang,long tang,long tang zhen,龙塘,龙塘镇', 23.5988900, 113.0700000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16788, 'Longtang', 'Longtang', 'Longtang,Longtang Zhen,long tang,long tang zhen,龙塘,龙塘镇', 20.3211100, 110.3425800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16789, 'Longhe', 'Longhe', 'Longhe,Longhe Zhen,Longtang,Lung-t''ang,Lung-t’ang,long he,long he zhen,龙河,龙河镇', 19.3817700, 110.2102400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16790, 'Longtan', 'Longtan', 'Longtan,Longtan Jiedao,Lung-t''an,Lung-t''an-chen,Lung-t’an,Lung-t’an-chen,long tan,long tan jie dao,龙潭,龙潭街道', 32.1680900, 119.0492600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16791, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,Longtanba,Lung-t''an,Lung-t’an,long tan,long tan zhen,龙潭,龙潭镇', 29.4463100, 107.1021700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16792, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,Lung-t''an,Lung-t’an,long tan,long tan zhen,龙潭,龙潭镇', 28.7571600, 108.9641400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16793, 'Longtan', 'Longtan', 'Longtan,Lung-t''an,Lung-t''an-ssu,Lung-t’an,Lung-t’an-ssu', 27.4113900, 110.5363900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16794, 'Longshui', 'Longshui', 'Longshui,Longshui Zhen,Lung-shui,Lung-shui-chen,long shui,long shui zhen,龙水,龙水镇', 29.5655500, 105.7620500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16795, 'Longqu', 'Longqu', 'Longqu,Longqu Xiang,Longshoubu,long qu,long qu xiang,龙渠,龙渠乡', 38.8297200, 100.2938900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16796, 'Longshi', 'Longshi', 'Longshi,Longshi Zhen,Lung-shih-chen,long shi,long shi zhen,龙市,龙市镇', 30.2146900, 106.4574300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16797, 'Longsheng', 'Longsheng', 'Longsheng,Lung-sheng,Lung-sheng-hsien,Lung-sheng-ko-tsu-lien-ho-tzu-chih-hsien,Lung-sheng-ko-tsu-tzu-chih-hsien,long sheng,龙胜', 25.7936100, 110.0091700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16798, 'Longsheng', 'Longsheng', 'Longsheng,Longsheng Zhen,Lung-sheng,long sheng,long sheng zhen,龙胜,龙胜镇', 22.5443100, 112.4596300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16799, 'Longshan', 'Longshan', 'Longshan,Longshan Zhen,Lung-shan,long shan,long shan zhen,龙山,龙山镇', 30.0786100, 121.5527800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16800, 'Longshan', 'Longshan', 'Longshan,Longshan Zhen,Lung-shan,long shan,long shan zhen,龙山,龙山镇', 23.7505600, 113.3881500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16801, 'Longquan', 'Longquan', 'Longquan,Longquanyi,Lung-ch''uan-i,Lung-ch’üan-i,Luntsyuan''i,Luntsyuan’i,long quan,龙泉', 30.5613000, 104.2689300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16802, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,long quan,long quan zhen,龙泉,龙泉镇', 37.3323600, 121.7722300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16803, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,long quan,long quan zhen,龙泉,龙泉镇', 30.7309500, 111.4902300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16804, 'Longquan', 'Longquan', 'I-men,I-men-hsien,Longquan,Longquan Zhen,Luncjuan'',Yimen,Yimen Xian,long quan,yi men,yi men xian,Лунцюань,易门,易门县,龙泉', 24.6719300, 102.1613000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16805, 'Longping', 'Longping', 'Longping,Longping Xiang,Lung-p''ing,Lung-p’ing,long ping,long ping xiang,龙坪,龙坪乡', 30.8138800, 110.1489400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16806, 'Longping', 'Longping', 'Longping,Longping Zhen,Lung-p''ing,Lung-p’ing,long ping,long ping zhen,龙坪,龙坪镇', 29.8695600, 115.6974200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16807, 'Longnan', 'Longnan', 'Longnan,Longnan Xian,Longnan Zhen,Lung-nan,Lung-nan-chen,Lung-nan-hsien,long nan,long nan xian,long nan zhen,龙南,龙南县,龙南镇', 24.9000000, 114.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16808, 'Longmu', 'Longmu', 'Longmu,Longmu Zhen,long mu,long mu zhen,龙母,龙母镇', 24.2635600, 115.4356500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16809, 'Longmen', 'Longmen', 'Longmen,Longmen Zhen,Lung-men-chen,long men,long men zhen,龙门,龙门镇', 30.7981900, 107.6871200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16810, 'Longmen', 'Longmen', 'Longmen,Longmen Xiang,Lung-men,Yang-ch''un,Yang-ch’un,long men,long men xiang,龙门,龙门乡', 30.3735800, 118.1144600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16811, 'Longhua', 'Longhua', 'Longhua,Longhua Zhen,Longmen,Lung-men,long hua,long hua zhen,long men,龙华,龙华镇,龙门', 29.2102800, 106.2072500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16812, 'Longmen', 'Longmen', 'Longmen,Longmen Jiedao,Lung-men,long men,long men jie dao,龙门,龙门街道', 25.0969700, 116.9678200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16813, 'Longmen', 'Longmen', 'Longmen,Lung-men,Lung-men-hsu,Lung-men-hsü', 24.9597200, 118.0888900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16814, 'Longcheng', 'Longcheng', 'Longcheng,Longcheng Jiedao,Longmen,Lung-ch''eng-chen,Lung-ch’eng-chen,Lung-men,Lung-men-hsien,Lungmoon,long cheng,long cheng jie dao,龙城,龙城街道', 23.7333300, 114.2500000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16815, 'Longmen', 'Longmen', 'Longmen,Longmen Zhen,Lung-men,Lung-men-hsu,Lung-men-hsü,Lung-men-shih,long men,long men zhen,龙门,龙门镇', 20.7109400, 110.0364700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16816, 'Longmen', 'Longmen', 'Ling-men-shih,Longmen,Longmen Zhen,Lung-men,long men,long men zhen,龙门,龙门镇', 19.4429300, 110.3255300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16817, 'Longlin', 'Longlin', 'Longlin,long lin,龙林', 33.9427800, 105.0673900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16818, 'Longlisuo', 'Longlisuo', 'Longli,Longlisuo,Lung-li-so', 26.4141700, 109.1022200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16819, 'Longgang', 'Longgang', 'Longgang,Longgang Jiedao,Longkou,Lung-k''ou,Lung-kou-shih,Lung-k’ou,Lungkow,long gang,long gang jie dao,龙港,龙港街道', 37.6518100, 120.3306300, 'CN', '2014-05-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16820, 'Longkou', 'Longkou', 'Longkou,Longkou Zhen,Lung-k''ou,Lung-k’ou,long kou,long kou zhen,龙口,龙口镇', 29.9412200, 113.7586700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16821, 'Longkou', 'Longkou', 'Longkou,Longkou Zhen,Lung-k''ou,Lung-k''ou-chen,Lung-k’ou,Lung-k’ou-chen,Lungkow,long kou,long kou zhen,龙口,龙口镇', 26.1858300, 115.3008800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16822, 'Longju', 'Longju', 'Longju,Longju Zhen,Lung-chu-pa,Lung-chü-pa,long ju,long ju zhen,龙驹,龙驹镇', 30.6109000, 108.6351800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16823, 'Longju', 'Longju', 'Longju,Longju Zhen,Lung-chu,Lung-chü,long ju,long ju zhen,龙苴,龙苴镇', 34.3666700, 119.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16824, 'Longjin', 'Longjin', 'Ch''ing-liu,Ch''ing-liu-hsien,Ch’ing-liu,Ch’ing-liu-hsien,Donghua,Longjin,Longjin Zhen,Qingliu,dong hua,long jin,long jin zhen,qing liu,东华,清流,龙津,龙津镇', 26.1819700, 116.8146400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16825, 'Longjie', 'Longjie', 'Longjie,Longjie Zhen,Lung-chieh,long jie,long jie zhen,隆街,隆街镇', 24.1850200, 114.3599200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16826, 'Longjiao', 'Longjiao', 'Aokouchang,Longjiao,Longjiao Zhen,ao kou chang,long jiao,long jiao zhen,坳口场,龙角,龙角镇', 30.8143700, 108.8568600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16827, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Zhen,Lung-chiang,Lung-chiang-hsu,Lung-chiang-hsü,Lung-t''ing-hsu,Lung-t’ing-hsü,Lungkong,long jiang,long jiang zhen,隆江,隆江镇', 22.9888000, 116.1921100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16828, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Zhen,Lun-kong,Lung-chiang,Lung-chiang-Hsu,Lung-chiang-Hsü,Lungkong,long jiang,long jiang zhen,龙江,龙江镇', 22.8865300, 113.0681500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16829, 'Longhutang', 'Longhutang', 'Longhutang,Longhutang Zhen,Longhuzhen,Lung-hu-chan,Lung-hu-chen,Lung-k''u-chen,Lung-k’u-chen,Lung-yao-chen,long hu tang,long hu tang zhen,龙虎塘,龙虎塘镇', 31.8538600, 119.9814500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16830, 'Longhua', 'Longhua', 'Longhua,Longhua Zhen,Lung-hua,long hua,long hua zhen,龙华,龙华镇', 25.3447400, 118.6510700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16831, 'Longhua', 'Longhua', 'Longhua,Longhua Zhen,Lung-ho,Lung-hua,Lung-hua-hsu,Lung-hua-hsü,long hua,long hua zhen,龙华,龙华镇', 23.6117700, 114.1948600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16832, 'Longhua', 'Longhua', 'Longhua,Longhua Zhen,Lung-hua,long hua,long hua zhen,龙华,龙华镇', 23.1918700, 114.1017600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16833, 'Longhua', 'Longhua', 'Longhua,Longhua Jiedao,Lung Wa,Lung-hua,Lung-hua-hsu,Lung-hua-hsü,long hua,long hua jie dao,龙华,龙华街道', 22.6578400, 114.0089300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16834, 'Longhu', 'Longhu', 'Longhu,Longhu Zhen,long hu,long hu zhen,龙湖,龙湖镇', 23.5572500, 116.6462800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16835, 'Longgun', 'Longgun', 'Longgun,Longgun Zhen,Lung-kun,long gun,long gun zhen,龙滚,龙滚镇', 19.0512000, 110.5247300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16836, 'Longgong', 'Longgong', 'Longgong,Longgong Xiang,Lung-kung,long gong,long gong xiang,隆宫,隆宫乡', 27.4902800, 118.9441700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16837, 'Longgao', 'Longgao', 'Longgao,Longgao Zhen,Lung-kao,long gao,long gao zhen,龙高,龙高镇', 34.9552800, 108.3150300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16838, 'Longgang', 'Longgang', 'Dazu,Longgang,Longgang Jiedao,Ta-tsu,Ta-tsu-hsien,long gang,long gang jie dao,龙岗,龙岗街道', 29.6974400, 105.7136900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16839, 'Longgang', 'Longgang', 'Longgang,Longgang Zhen,Lung-kang,long gang,long gang zhen,龙港,龙港镇', 29.6255800, 114.9502800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16840, 'Longgang Shezu', 'Longgang Shezu', 'Longgang,Longgang Shezu,Longgang Shezu Xiang,Lung-kang,Lung-kang-hsu,Lung-kang-hsü,long gang she zu,long gang she zu xiang,龙冈畲族,龙冈畲族乡', 26.7384200, 115.5830900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16841, 'Longgang', 'Longgang', 'Longgang,Longgang Xiang,Lung-kang,Lung-kang-hsu,Lung-kang-hsü,long gang,long gang xiang,龙岗,龙岗乡', 26.1087500, 116.2600400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16842, 'Longgang', 'Longgang', 'District de Longgang,Liung-kong-khi,Liùng-kông-khî,Long Cuong,Long Cương,Longgang,Longgang Barrutia,Longgang District,Longgang Jiedao,Lun-kong,Lung-kang,Lung-kang-hsu,Lung-kang-hsü,Lungkonghu,langang,long gang,long gang jie dao,long gang qu,lung-gang gu,لانگانگ,竜崗区,龍崗區,龙岗,龙岗区,龙岗街道,룽강 구', 22.7228900, 114.2632600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16843, 'Longfengba', 'Longfengba', 'Longfengba,Longfengba Zhen,Lung-feng-pa,long feng ba,long feng ba zhen,龙凤坝,龙凤坝镇', 30.3879300, 109.5070600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16844, 'Longde Chengguanzhen', 'Longde Chengguanzhen', 'Longde,Longde Chengguanzhen,Longde Xian,Lunde,Lung-te,Lung-te-hsien,Lungteh,long de,long de cheng guan zhen,long de xian,隆德,隆德县,隆德城关镇', 35.6125000, 106.1166700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16845, 'Longcun', 'Longcun', 'Longcun,Longcun Xiang,long cun,long cun xiang,龙村,龙村乡', 27.2534100, 118.4950100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16846, 'Longcun', 'Longcun', 'Longcun,Longcun Zhen,Lung-ts''un,Lung-ts’un,long cun,long cun zhen,龙村,龙村镇', 23.5524400, 115.5329700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16847, 'Longchuan', 'Longchuan', 'Cheh-nam,Chen-nan,Chen-nan-chou,Chen-nan-hsien,Longchuan,Lung-ch''uan-chen,Lung-ch’uan-chen,Nanhua,long chuan,龙川', 25.1615200, 101.2941800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16848, 'Longchi', 'Longchi', 'Longchi,Longchi Zhen,long chi,long chi zhen,龙池,龙池镇', 28.6099600, 109.0491900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16849, 'Longcheng', 'Longcheng', 'Longcheng,long cheng,陇城', 35.0009600, 105.9733900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16850, 'Longcheng', 'Longcheng', 'Hsiao,Hsiao-hsien,Hsiao-hsien-ch''eng,Hsiao-hsien-ch’eng,Longcheng,Lung-ch''eng,Lung-ch''eng-chen,Lung-ch’eng,Lung-ch’eng-chen,Siaohsien,Xiaoxian,long cheng,龙城', 34.1844800, 116.9507700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16851, 'Longcheng', 'Longcheng', 'Ch''eng-kung,Ch''eng-kung-hsien,Chenggong,Chenggong Xian,Ch’eng-kung,Ch’eng-kung-hsien,Longcheng,Longcheng Zhen,Lung-ch''eng-chen,Lung-ch’eng-chen,cheng gong,cheng gong xian,long cheng,long cheng zhen,呈贡,呈贡县,龙城,龙城镇', 24.8982700, 102.7996500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16852, 'Longbu', 'Longbu', 'Longbu,Longbu Zhen,Lung-pu,long bu,long bu zhen,龙布,龙布镇', 25.4734800, 115.3760000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16853, 'Long’an', 'Long''an', 'Long''an,Long’an,Lun''yan'',Lung-yan,Lungan,Lunganfu,Lun’yan’,P''ing-wu-hsien,Pingwu,Pinu,P’ing-wu-hsien,long an,龙安', 32.4093400, 104.5286800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16854, 'Long’an', 'Long''an', 'Long''an,Long''an Zhen,Long’an,Long’an Zhen,Lung-an,Lung-an-chen,long an,long an zhen,龙安,龙安镇', 27.2274100, 116.8034100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16855, 'Long’an Chengxiangzhen', 'Long''an Chengxiangzhen', 'Long''an,Long''an Chengxiangzhen,Long’an,Long’an Chengxiangzhen,Lung-an,Lung-an-hsiang,Lung-an-hsien,long an cheng xiang zhen,隆安城厢镇', 23.2071200, 107.6509000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16856, 'Lizui', 'Lizui', 'Li-tsui,Li-tsui-shih,Lizui,Lizui Zhen,li ju,li ju zhen,黎咀,黎咀镇', 24.3442100, 115.3300200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16857, 'Lizi', 'Lizi', 'Lizi,Lizi Xiang,li zi,li zi xiang,栗子,栗子乡', 29.8112700, 107.9244700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16858, 'Lizhuangzi', 'Lizhuangzi', '', 39.0041700, 117.5255600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16859, 'Lizhu', 'Lizhu', 'Li-chu,Li-chu-shih,Lizhu,Lizhu Zhen,li zhu,li zhu zhen,漓渚,漓渚镇', 29.9552800, 120.4666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16860, 'Lizhai', 'Lizhai', 'Li-chai,Lizhai,Lizhai Xiang,li zhai,li zhai xiang,李宅,李宅乡', 29.0084300, 117.9189100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16861, 'Liyuan', 'Liyuan', 'Liyuan,Liyuan Zhen,li yuan,li yuan zhen,礼元,礼元镇', 35.5069300, 111.3232400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16862, 'Liyuan', 'Liyuan', 'Liyuan,Liyuan Jiedao,li yuan,li yuan jie dao,蠡园,蠡园街道', 31.5439100, 120.2619600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16863, 'Liyuan', 'Liyuan', 'Liyuan,Liyuan Zhen,Sang-chih,Sang-chih-hsien,Sangzhi,Sangzhi Xian,li yuan,li yuan zhen,sang zhi,sang zhi xian,桑植,桑植县,澧源,澧源镇', 29.3953700, 110.1559100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16864, 'Liye', 'Liye', 'Li-yeh,Liya,Liye,Liye Zhen,li ye,li ye zhen,里耶,里耶镇', 28.7893600, 109.2924200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16865, 'Liyang', 'Liyang', 'Hsu-yang-chen,Hsü-yang-chen,Li-yang,Liyang,Liyang Zhen,li yang,栎阳', 34.5851500, 109.2085700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16866, 'Liyang', 'Liyang', 'Hexian,Ho,Ho-han,Ho-hsien,Hochow,Liyang,Liyang Zhen,he xian,li yang,li yang zhen,历阳,历阳镇,和县', 31.7177200, 118.3573100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16867, 'Licheng', 'Licheng', 'Li-ch''eng-chen,Li-ch’eng-chen,Li-yang-ch''eng,Li-yang-ch’eng,Li-yang-hsien,Licheng,Licheng Zhen,Liyang,Liyang Shi,li cheng,li cheng zhen,li yang shi,凓城,凓城镇,溧阳市', 31.4281300, 119.4835300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16868, 'Liyang', 'Liyang', 'Li-yang-chieh,Liyang,Liyang Zhen,li yang,li yang zhen,力洋,力洋镇', 29.3066700, 121.6150000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16869, 'Lixu', 'Lixu', 'Chou-ts''un,Chou-ts’un,Li-hsu,Li-hsü,Lixu,Lixu Zhen,li wei,li wei zhen,黎圩,黎圩镇', 28.0686100, 116.6316500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16870, 'Lixiqiao', 'Lixiqiao', 'Li-ch''i-ch''iao,Li-ch’i-ch’iao,Litsitsyao,Lixiqiao', 26.7947200, 110.4180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16871, 'Lixin Chengguanzhen', 'Lixin Chengguanzhen', 'Li-hsin,Li-hsin-chi,Li-hsin-p''u,Li-hsin-p’u,Liu-hsien-p''u,Liu-hsien-p’u,Lixin,Lixin Chengguanzhen,li xin cheng guan zhen,利辛城关镇', 33.1432800, 116.2271800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16872, 'Lixin', 'Lixin', 'Li-hsin,Li-hsin-hsun,Li-hsin-hsün,Lixin,Lixin Zhen,li xin,li xin zhen,里心,里心镇', 26.8312700, 116.6705100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16873, 'Lixian', 'Lixian', 'Li-hsien,Li-hsien-chen,Ligzhuichzhen'',Ligzhuichzhen’,Lixian,Lixian Zhen,li xian,li xian zhen,礼贤,礼贤镇', 39.5562500, 116.4475700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16874, 'Liyang', 'Liyang', 'Li,Li-chou,Li-hsien,Li-hsien-ch''eng,Li-hsien-ch’eng,Li-yang-chen,Lichow,Lixian,Liyang,Liyang Zhen,li xian,li yang,li yang zhen,澧县,澧阳,澧阳镇', 29.6518000, 111.7520000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16875, 'Lixi', 'Lixi', 'Li-hsi,Lixi,Lixi Zhen,li xi,li xi zhen,栗溪,栗溪镇', 31.2712700, 111.9831000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16876, 'Lixi', 'Lixi', 'Li-hsi,Lixi,Lixi Zhen,li xi,li xi zhen,澧溪,澧溪镇', 29.2485900, 114.8382200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16877, 'Lixi', 'Lixi', 'Li-hsi,Lixi,Lixi Zhen,li xi,li xi zhen,梨溪,梨溪镇', 27.6280900, 116.3666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16878, 'Lixi', 'Lixi', 'Lixi,Lixi Zhen,li xi,li xi zhen,黎溪,黎溪镇', 23.9463000, 113.2540200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16879, 'Liwang', 'Liwang', 'Li-wang-pu,Liwang,Liwang Zhen,Liwangbu,li wang zhen,李旺镇', 36.6674400, 106.1013300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16880, 'Liuzikou', 'Liuzikou', 'Liu-tzu-k''ou,Liu-tzu-k’ou,Liutze,Liuzikou', 39.8702800, 117.3466700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16881, 'Liuzhuang', 'Liuzhuang', 'Liu-chuang,Liuchwang,Liuzhuang,Liuzhuang Zhen,liu zhuang,liu zhuang zhen,刘庄,刘庄镇', 33.1377000, 120.2928900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16882, 'Liuzhi', 'Liuzhi', 'Liuzhi,Liuzhi Jiedao,Liuzhidian,liu zhi,liu zhi jie dao,六指,六指街道', 30.8845300, 114.4948300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16883, 'Liuyin', 'Liuyin', 'Liuyin,Liuyin Zhen,liu yin,liu yin zhen,柳荫,柳荫镇', 29.9620700, 106.6099600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16884, 'Guankou', 'Guankou', 'Guankou,Liu-yang-hsien,Liujang,Liuyang,Liuyang Shi,guan kou,liu yang,liu yang shi,Лиуянг,关口,浏阳,浏阳市', 28.1586100, 113.6270900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16885, 'Liuxia', 'Liuxia', 'Liu-hsia,Liu-hsia-chen,Liuxia,Liuxia Jiedao,Liuxia Zhen,liu xia,liu xia jie dao,liu xia zhen,留下,留下街道,留下镇', 30.2454600, 120.0528700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16886, 'Liuwudian', 'Liuwudian', 'Liuwudian,liu wu dian,刘五店', 24.5555200, 118.1955800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16887, 'Liutao', 'Liutao', 'Liutao,Liutao Xiang,liu tao,liu tao xiang,六套,六套乡', 34.1127800, 119.7941700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16888, 'Liusi', 'Liusi', 'Liu-ssu-ch''iao,Liu-ssu-ch’iao,Liusi,Liusi Zhen,Liusiqiao,liu si,liu si zhen,流泗,流泗镇', 29.7878400, 116.3603300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16889, 'Liushui', 'Liushui', 'Liu-shui-kou,Liushui,Liushui Zhen,Liushuigou,liu shui,liu shui zhen,流水,流水镇', 31.5670700, 112.4479800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16890, 'Liushui', 'Liushui', 'Liushui,Liushui Zhen,liu shui,liu shui zhen,流水,流水镇', 25.5759100, 119.8310800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16891, 'Liushi', 'Liushi', 'Liu-shih,Liu-shih-chen,Liushi,Liushi Zhen,liu shi,liu shi zhen,柳市,柳市镇', 28.0508600, 120.8990200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16892, 'Liushan', 'Liushan', 'Liu-shan-chen,Liushan,Liushan Zhen,liu shan,liu shan zhen,留山,留山镇', 33.4736600, 112.5461900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16893, 'Puning', 'Puning', 'Liu-sha-chen,Liu-sha-hsu,Liu-sha-hsü,Liusha,OPQ,P''u-ning-hsien,Pho Ninh,Phổ Ninh,Puning,P’u-ning-hsien,pu ning,pu ning shi,puning si,pwnyng,پونینگ,普宁,普宁市,普寧,普寧市,푸닝 시', 23.3107200, 116.1686900, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16894, 'Liurenba', 'Liurenba', 'Liu-jen-pa,Liurenba,Liurenba Zhen,liu ren ba,liu ren ba zhen,刘仁八,刘仁八镇', 29.9378500, 114.8301400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16895, 'Liuqu', 'Liuqu', 'Liu-ch''u,Liu-ch''u-chen,Liu-ch’ü,Liu-ch’ü-chen,Liuqu,Liuqu Zhen,liu qu,流曲', 34.8664600, 109.2654800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16896, 'Liuqiao', 'Liuqiao', 'Liu-ch''iao,Liu-ch’iao,Liuqiao,Liuqiao Zhen,Pei-liu-ch''iao,Pei-liu-ch''iao-chen,Pei-liu-ch’iao,Pei-liu-ch’iao-chen,liu qiao,liu qiao zhen,刘桥,刘桥镇', 32.1685600, 120.8368400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16897, 'Liupai', 'Liupai', 'Liu-p''ai-chen,Liu-p''ai-hsiang,Liu-p''ai-hsu,Liu-p’ai-chen,Liu-p’ai-hsiang,Liu-p’ai-hsü,Liupai,T''ien-o,Tian''e,Tian’e,T’ien-o,liu pai,六排', 25.0400000, 107.1731500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16898, 'Liuliping', 'Liuliping', 'Liuliping,Liuliping Zhen,liu li ping,liu li ping zhen,六里坪,六里坪镇', 32.5338800, 110.9809000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16899, 'Liulin', 'Liulin', 'Liu-lin-chen,Liulin,Liulin Xian,Liulin Zhen,liu lin,liu lin xian,liu lin zhen,柳林,柳林县,柳林镇', 37.4533300, 110.9018900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16900, 'Liulin', 'Liulin', 'Liu-lin-chen,Liu-lin-p''u,Liu-lin-p’u,Liulin,Liulin Zhen,liu lin,liu lin zhen,柳林,柳林镇', 34.5494300, 107.3094000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16901, 'Liulin', 'Liulin', 'Liu-lin-tien,Liulin,Liulin Zhen,liu lin,liu lin zhen,柳林,柳林镇', 31.5394100, 113.2324700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16902, 'Liulin', 'Liulin', 'Liu-chia-lin,Liulin,liu lin,柳林', 30.2693600, 115.1459300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16903, 'Liulihe', 'Liulihe', 'Liu-li-ho,Liu-li-ho-chen,Liulihe,Liulihe Zhen,Lyulikhe,liu li he,liu li he zhen,琉璃河,琉璃河镇', 39.5965400, 116.0309500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16904, 'Liuli', 'Liuli', 'Liuli,Liuli Zhen,liu li,liu li zhen,六里,六里镇', 24.3113800, 113.9655200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16905, 'Liukuaizhuang', 'Liukuaizhuang', 'Liukuaizhuang,liu kuai zhuang,刘快庄', 39.2478900, 117.3394100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16906, 'Liukou', 'Liukou', 'Liukou,Liukou Zhen,liu kou,liu kou zhen,流口,流口镇', 29.7050300, 117.7817900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16907, 'Liujiaxia', 'Liujiaxia', 'Hsiao-ch''uan,Hsiao-ch’uan,Liu-chia-hsia,Liujiaxia,Xiaochuan,Yongjing,Yongjing Xian,Yung-ching,liu jia xia,yong jing xian,刘家峡,永靖县', 35.9340000, 103.3183100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16908, 'Zhujita', 'Zhujita', 'Liu-chia-p''ing,Liu-chia-p’ing,Liujiaping,Liujiaping Baizuxiang,Zhujita,liu jia ping,liu jia ping bai zu xiang,zhu ji ta,刘家坪,刘家坪白族乡,珠矶塔', 29.4675400, 110.2242900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16909, 'Liujiagou', 'Liujiagou', 'Liu-chia-kou,Liujiagou,Liujiagou Zhen,liu jia gou,liu jia gou zhen,刘家沟,刘家沟镇', 37.7661500, 120.8848900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16910, 'Liujiage', 'Liujiage', 'Liu-chia-ko,Liujiage,Liujiage Zhen,liu jia ge,liu jia ge zhen,刘家隔,刘家隔镇', 30.7580200, 113.8085600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16911, 'Liujiachang', 'Liujiachang', 'Liu-chia-ch''ang,Liu-chia-ch’ang,Liujiachang,Liujiachang Zhen,liu jia chang,liu jia chang zhen,刘家场,刘家场镇', 30.0606000, 111.4706800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16912, 'Liuhao', 'Liuhao', 'Liu-chia,Liu-chia-chen,Liuhao,Liuhao Zhen,Liujia,Liujia Zhen,Liujiazhen,liu hao,liu hao zhen,liu jia,liu jia zhen,六甲,六甲镇,刘浩,刘浩镇', 32.0580500, 121.4855500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16913, 'Liuji', 'Liuji', 'Liu-chi,Liuji,Liuji Zhen,liu ji,刘集', 34.7733600, 109.3064000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16914, 'Liuji', 'Liuji', 'Liu-chi,Liu-chia-chi,Liuji,Liuji Zhen,liu ji,liu ji zhen,刘集,刘集镇', 32.4340000, 119.2508700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16915, 'Liuji', 'Liuji', 'Liuji,Liuji Zhen,liu ji,liu ji zhen,刘集,刘集镇', 31.3686600, 114.3702100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16916, 'Liuhuang', 'Liuhuang', 'Liu-huang-shih,Liuhuang,Liuhuang Zhen,Liuwong,liu huang,liu huang zhen,留隍,留隍镇', 23.9110300, 116.4541300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16917, 'Liuhou', 'Liuhou', 'Liu-hou-chi,Liuhou,Liuhou Zhen,Liuhouji,liu hou,liu hou zhen,刘猴,刘猴镇', 31.4844700, 112.0222500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16918, 'Liuhe', 'Liuhe', 'Liu-ho,Liuhe,liu he,柳河', 33.3170300, 112.8007600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16919, 'Liuhe', 'Liuhe', 'Liu-ho,Liu-ho-chen,Liuhe,Liuhe Zhen,liu he,liu he zhen,浏河,浏河镇', 31.5086200, 121.2627600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16920, 'Liuhe', 'Liuhe', 'Liuhe,Liuhe Zhen,liu he,liu he zhen,刘河,刘河镇', 30.3003200, 115.5782800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16921, 'Liugu', 'Liugu', 'Liu-ku,Liu-ku-chen,Liugu,Liugu Zhen,liu gu,留古', 34.7441700, 109.2777100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16922, 'Liufu', 'Liufu', 'Liu-fu-chen,Liu-tu,Liufu,Liufu Zhen,T''ai-yang-sheng,T’ai-yang-sheng,liu fu,liu fu zhen,刘府,刘府镇', 32.7763900, 117.3375000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16923, 'Liufang', 'Liufang', 'Liufang,Liufang Xiang,liu fang,liu fang xiang,流芳,流芳乡', 29.5416600, 116.2661400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16924, 'Liuduzhai', 'Liuduzhai', 'Chai-shih,Hetian Xiang,Liu-tu-chai,Liuduzhai,Liuduzhai Zhen,Lung-hui,Lung-hui-hsien,Lunghwei,Sai-shih,he tian xiang,liu dou zhai,liu dou zhai zhen,六都寨,六都寨镇,荷田乡', 27.3661100, 110.9350000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16925, 'Liudu', 'Liudu', 'Liu-tu,Liudu,Liudu Zhen,liu du,liu du zhen,流渡,流渡镇', 28.3111000, 107.5049200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16926, 'Liudu', 'Liudu', 'Liu-tu,Liudu,Liudu Zhen,liu dou,liu dou zhen,六都,六都镇', 23.0772900, 112.0033900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16927, 'Liudong', 'Liudong', 'Liudong,Liudong Zhen,liu dong,liu dong zhen,刘洞,刘洞镇', 33.1552200, 111.1150100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16928, 'Liucheng', 'Liucheng', 'Liucheng,Wen-chiang,Wen-chiang-hsien,Wenjiang,Wenkiang,Wenkiang-hsien,liu cheng,柳城', 30.7000000, 103.8377100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16929, 'Liucheng', 'Liucheng', 'Liu-ch''eng-hsu,Liu-ch’eng-hsü,Liucheng,Liucheng Zhen,Lyuschang,liu cheng,liu cheng zhen,柳城,柳城镇', 24.0348100, 115.1182000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16930, 'Liuche', 'Liuche', 'Liu-ch''e-hsu,Liu-ch’e-hsü,Liuche,Liuche Zhen,liu che,liu che zhen,留车,留车镇', 24.7287600, 115.6352200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16931, 'Liubo', 'Liubo', 'Liubo,Liubo Xiang,liu bao,liu bao xiang,柳薄,柳薄乡', 28.2219900, 109.4588500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16932, 'Liuba', 'Liuba', 'Liuba,Liuba Zhen,liu ba,liu ba zhen,六坝,六坝镇', 38.6488900, 100.7186100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16933, 'Liuba', 'Liuba', 'Liu-pa,Liu-pa-hsien,Liu-pa-hsien-ch''eng,Liu-pa-hsien-ch’eng,Liuba,Lyuba,liu ba,留坝', 33.6186100, 106.9188900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16934, 'Aozhong', 'Aozhong', 'Aozhong,Liu''ao Zhen,Liu’ao Zhen,ao zhong,liu ao zhen,六鳌镇,鳌中', 23.9350100, 117.7477100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16935, 'Liu’anzhuang', 'Liu''anzhuang', 'Liu''anzhuang,Liu’anzhuang,liu an zhuang,刘安庄', 39.2386800, 117.1981900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16936, 'Liqiao', 'Liqiao', 'Li-ch''iao,Li-ch’iao,Li-hsien-ch''iao,Li-hsien-ch’iao,Li-t''ou-ch''iao,Li-t’ou-ch’iao,Liqiao,Liqiao Zhen,Litouqiao,li qiao,li qiao zhen,狸桥,狸桥镇', 31.2174000, 118.9212400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16937, 'Litian', 'Litian', 'Litian,Litian Xiang,Litianjie,hai tian,hai tian xiang,浬田,浬田乡', 27.2112200, 114.7294900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16938, 'Litian', 'Litian', 'Li-t''ien,Li-t’ien,Litian,Litian Zhen,li tian,li tian zhen,澧田,澧田镇', 27.0169100, 114.1401300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16939, 'Litian', 'Litian', 'Litian,li tian,里田', 26.0151700, 116.6996400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16940, 'Lita', 'Lita', 'Li-t''a-hsu,Li-t’a-hsü,Lita,Lita Zhen,li ta,li ta zhen,里塔,里塔镇', 27.3588000, 116.5355200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16941, 'Lishui', 'Lishui', 'Ch''u-chou,Chuchow,Chuchowfu,Chuzhoufu,Ch’u-chou,La-cui,Le Thuy,Le-chui-chhi,Li-shui-hsien,Li-suej,Li-šuej,Lishui,Lishui Shi,Lishui Xian,Lishui i Zhejiang,Lishuj,Lisjui,Lâ̤-cūi,Lē-chúi-chhī,Lệ Thủy,chu zhou fu,li shui,li shui shi,li shui xian,lisu-i si,lyshay,lyshwy,lyshwyy,Лишуй,ليشوي,لیشای,لیشوئی,丽水,丽水县,丽水市,处州府,麗水,麗水市,리수이 시', 28.4604200, 119.9102900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16942, 'Lishi', 'Lishi', 'Li-shan,Li-shan-hsien,Li-shih,Li-shih-hsien,Lishan Xian,Lishi,Lishi Qu,Yongning Zhou,Yung-ning,Yungningchow,Yunin,li shan xian,li shi,li shi qu,yong ning zhou,永宁州,离山县,离石,离石区', 37.5155600, 111.1341700, 'CN', '2013-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16943, 'Lishi', 'Lishi', 'Lishi,Lishi Zhen,Lishiba,li shi,li shi zhen,李市,李市镇', 29.0788800, 106.2620000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16944, 'Lishi', 'Lishi', 'Li-shih,Lishi,Lishi Zhen,li shi,li shi zhen,犁市,犁市镇', 24.9014300, 113.5248700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16945, 'Lishi', 'Lishi', 'Dingnan,Dingnan Xian,Hsia-li,Lishi,Ting-nan,Ting-nan-hsien,ding nan xian,li shi,厉市,定南县', 24.8045900, 115.0332500, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16946, 'Lishao', 'Lishao', 'Lishao,Lishao Zhen,li shao,li shao zhen,黎少,黎少镇', 22.7200600, 111.4613800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16947, 'Lintong', 'Lintong', 'Lin''tun,Lin-t''ung,Lin-t''ung-hsien,Lin-t’ung,Lin-t’ung-hsien,Lintong,Lin’tun,Lishan,lin tong,临潼', 34.3780300, 109.2089200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16948, 'Lishan', 'Lishan', 'Lishan,Lishan Zhen,Lishanchen,li shan,li shan zhen,厉山,厉山镇', 31.8576400, 113.2950500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16949, 'Liren', 'Liren', 'Liren,Liren Zhen,li ren,li ren zhen,里仁,里仁镇', 24.8989600, 114.8781200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16950, 'Liquan Chengguanzhen', 'Liquan Chengguanzhen', 'Li-ch''uan,Li-ch''uan-hsien,Li-ch''uan-hsien-ch''eng,Li-ch’üan,Li-ch’üan-hsien,Li-ch’üan-hsien-ch’eng,Liquan Chengguanzhen,cheng guan zhen,li quan cheng guan zhen,城关镇,礼泉城关镇', 34.4811100, 108.4236100, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16951, 'Liqizhuang', 'Liqizhuang', 'Li-ch''i-chuang,Li-ch’i-chuang,Liqizhuang,Liqizhuang Jiedao,li qi zhuang,li qi zhuang jie dao,李七庄,李七庄街道', 39.0698200, 117.1619800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16952, 'Lipu', 'Lipu', 'Li-p''u-chen,Li-p''u-shih,Li-p’u-chen,Li-p’u-shih,Lipu,Lipu Zhen,li pu,li pu zhen,澧浦,澧浦镇', 29.1046300, 119.8044000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16953, 'Linzi', 'Linzi', 'Lin-tzu,Lin-tzu-chen,Linzi,Linzi Zhen,lin zi,lin zi zhen,林梓,林梓镇', 32.2977300, 120.7413600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16954, 'Liuzhou', 'Liuzhou', 'LZH,Linzhou,Liu-chiang,Liu-chou,Liu-chou-shih,Liuchow,Liuchowfu,Liuzhou,Ma-p''ing,Ma-p’ing,Mapinghsien,liu zhou,柳州', 24.3125800, 109.3891600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16955, 'Linyi', 'Linyi', 'I-chou,Ichow,Ichowfu,LYI,Lam Nghi,Lan-shan,Lim-ki-chhi,Lin''i,Lin-i,Lin-i-hsien,Lin-i-shih,Ling-gi,Linji,Linyi,Liuyihsien,Lâm Nghi,Lìng-gì,Lîm-kî-chhī,Yichow,lin yi,lin yi shi,lin-i si,lnyy,lynyay,Линьи,Линји,لنیی,لینیای,临沂,临沂市,臨沂,臨沂市,린이 시', 35.0630600, 118.3427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16956, 'Chang’an', 'Chang''an', 'Ch''ang-an,Ch''ang-an-i,Chang''an,Chang''an Zhen,Chang-an-yi,Chang’an,Chang’an Zhen,Ch’ang-an,Ch’ang-an-i,Lin-hsiang,Lin-hsiang-hsien,Linxiang,Linxiang Shi,lin xiang,lin xiang shi,zhang an,zhang an zhen,临湘,临湘市,长安,长安镇', 29.4718000, 113.4440000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16957, 'Linquan', 'Linquan', 'Lin,Lin Xian,Lin''syan'',Lin-hsien,Linquan,Linquan Zhen,Linxian,Lin’syan’,lin quan,lin quan zhen,lin xian,临县,临泉,临泉镇', 37.9796500, 111.0205900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16958, 'Kaiyuan', 'Kaiyuan', 'Kaiyuan,Lin,Lin''syan'',Lin-hsien,Linxian,Linzhou,Lin’syan’,kai yuan,开元', 36.0681300, 113.8220900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16959, 'Linxia Chengguanzhen', 'Linxia Chengguanzhen', 'Ho-chou,Khechzhou,Lin''sja,Lin''sya,Lin-hsia,Lin-hsia-hsien,Lin-hsia-shih,Lin-hsin,Linsia,Linxia,Linxia Chengguanzhen,Linxia Shi,Lin’sya,lin xia cheng guan zhen,lin xia shi,Линься,临夏城关镇,临夏市', 35.6002800, 103.2063900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16960, 'Linxi', 'Linxi', 'Lin-hsi,Lin-hsi-chuang,Linsi,Linxi,lin xi,林西', 39.7118300, 118.4495400, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16961, 'Linxi', 'Linxi', 'Lin-ch''i,Lin-ch''i-chen,Lin-ch’i,Lin-ch’i-chen,Lin-hsi,Linxi,Linxi Zhen,lin xi,lin xi zhen,临溪,临溪镇', 29.9902300, 118.5353000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16962, 'Linwu Chengguanzhen', 'Linwu Chengguanzhen', 'Lin-wu-hsien,Linwu,Linwu Chengguanzhen,lin wu,lin wu cheng guan zhen,临武,临武城关镇', 25.2324700, 112.5398100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16963, 'Lintou', 'Lintou', 'Lin-t''ou,Lin-t''ou-hsu,Lin-t’ou,Lin-t’ou-hsü,Lintou,Lintou Zhen,Lintouxu,lin tou,lin tou zhen,林头,林头镇', 21.6657200, 111.0486500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16964, 'Lintingkou', 'Lintingkou', 'Lin-t''ing,Lin-t''ing-chen,Lin-t’ing,Lin-t’ing-chen,Lintingkou', 39.6302800, 117.5002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16965, 'Linshui', 'Linshui', '', 36.4247200, 114.2047200, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16966, 'Linshi', 'Linshi', 'Lin-shih-chen,Linshi,Linshi Zhen,lin shi,lin shi zhen,蔺市,蔺市镇', 29.6669800, 107.1923300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16967, 'Linshe', 'Linshe', 'Linshe,lin she,林畲', 26.3183900, 117.0711900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16968, 'Linshanhe', 'Linshanhe', 'Lin-shan-ho,Lin-shan-ho-chieh,Linshanhe,Linshanhe Zhen,Linshano,lin shan he,lin shan he zhen,淋山河,淋山河镇', 30.7426700, 114.8840900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16969, 'Linshan', 'Linshan', 'Lin-shan-wei,Lin-shan-wei-ch''eng,Lin-shan-wei-ch’eng,Linshan,Linshan Zhen,lin shan,lin shan zhen,临山,临山镇', 30.1539500, 120.9918200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16970, 'Meishan', 'Meishan', 'Ju-chou,Lin-ju,Lin-ju-hsien,Linru,Meishan,Ruzhou,Yuchow,Yüchow,mei shan,煤山', 34.1616700, 112.8297200, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16971, 'Linquan Chengguanzhen', 'Linquan Chengguanzhen', 'Lin-ch''uan,Lin-ch''uan-hsien,Lin-ch’üan,Lin-ch’üan-hsien,Linquan,Linquan Chengguanzhen,Shen-ch''iu,Shen-ch''iu-chi,Shen-ch’iu,Shen-ch’iu-chi,lin quan cheng guan zhen,临泉城关镇', 33.0850600, 115.2902300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16972, 'Linqu', 'Linqu', 'Lin-ch''u,Lin-ch''u-hsien,Lin-ch’ü,Lin-ch’ü-hsien,Linqu', 36.5155600, 118.5397200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16973, 'Linqiong', 'Linqiong', 'Ch''iung-lai,Chiung-lai-hsien,Chiungchou,Ch’iung-lai,Kiungchow,Kiunglaihsien,Kung-lai,Linqiong,Qionglai,Tsyunlay,lin qiong,临邛', 30.4158700, 103.4608900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16974, 'Qingnian', 'Qingnian', 'Lin-ch''ing,Lin-ch''ing-hsien,Lin-ch''ing-shih,Lin-ch’ing,Lin-ch’ing-hsien,Lin-ch’ing-shih,Linqing,Lintsing,Lintsingchow,Qingnian,lin qing,qing nian,临青,青年', 36.8403200, 115.7118300, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16975, 'Linqi', 'Linqi', 'Lin-ch''i,Lin-ch’i,Linki,Linqi,Linqi Zhen,lin qi,lin qi zhen,临岐,临岐镇', 29.8527800, 119.1155100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16976, 'Linpu', 'Linpu', 'Lin-p''u-chen,Lin-p’u-chen,Linpu,Linpu Zhen,lin pu,lin pu zhen,临浦,临浦镇', 30.0440600, 120.2449300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16977, 'Linping', 'Linping', 'Lin-p''ing-chen,Lin-p’ing-chen,Linping,Linping Zhen,lin ping,lin ping zhen,临平,临平镇', 34.4644400, 108.0966700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16978, 'Linping', 'Linping', 'Lin-p''ing-chen,Lin-p’ing-chen,Linping,Linpingzhen,Yu-hang Hsien,Yuhang,Yü-hang Hsien,lin ping,lin ping zhen,临平,临平镇', 30.4225000, 120.2972200, 'CN', '2013-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16979, 'Linli', 'Linli', 'Anfu,Anfu Zhen,Lin-li-hsien,Linli,Linli Xian,an fu,an fu zhen,lin li,lin li xian,临澧,临澧县,安福,安福镇', 29.4500000, 111.6500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16980, 'Linkuang', 'Linkuang', 'Linkuang,Linkuang Zhen,lin kuang,lin kuang zhen,磷矿,磷矿镇', 31.2954300, 112.4187500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16981, 'Linkou', 'Linkou', '', 26.2480600, 109.8636100, 'CN', '2004-05-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16982, 'Linjiang', 'Linjiang', 'Lin-chiang-ch''ang,Lin-chiang-ch’ang,Linjiang,Linjiang Zhen,Linjiangchang,lin jiang,lin jiang zhen,临江,临江镇', 29.2452200, 105.9566300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16983, 'Linjiang', 'Linjiang', 'Lin-chiang,Linjiang,lin jiang,临江', 33.0621800, 104.9214200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16984, 'Linjiang', 'Linjiang', 'Lin-chiang,Lin-chiang-shih,Lin-chiang-ssu,Linjiang,Linjiang Zhen,lin jiang,lin jiang zhen,临江,临江镇', 31.0995600, 108.2196400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16985, 'Linjiang', 'Linjiang', 'Lin-chiang,Lin-chiang-chieh,Linjiang,Linjiang Zhen,Linkiangkai,lin jiang,lin jiang zhen,临江,临江镇', 27.8240900, 118.4554600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16986, 'Linhai', 'Linhai', 'LHC,Lin-hai-hsien,Linhai,T''ai-chou,Taichow,Taichowfu,Taizhou,T’ai-chou,lin hai,临海', 28.8553500, 121.1447000, 'CN', '2017-04-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16987, 'Lingyao', 'Lingyao', 'Lingyao,Lingyao Xiang,ling yao,ling yao xiang,岭腰,岭腰乡', 27.4721900, 118.9826300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16988, 'Lingcheng', 'Lingcheng', 'Chiu-ling-hsien,Ling,Ling-hsien,Lingcheng,Lingxian,Linsyan'',Linsyan’,Te-hsien,ling cheng,陵城', 37.3313300, 116.5695300, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16989, 'Xiayang', 'Xiayang', 'Ling,Ling-chen,Ling-hsien,Lingxian,Ninghsien,Xiayang,Yanling Xian,xia yang,yan ling xian,炎陵县,霞阳', 26.4888500, 113.7679600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16990, 'Lingxia', 'Lingxia', 'Ling-hsia,Lingxia,Lingxia Xiang,ling xia,ling xia xiang,岭下,岭下乡', 27.0777800, 118.9600000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16991, 'Lingxi', 'Lingxi', 'Ling-ch''i-chen,Ling-ch’i-chen,Ling-hsi,Lingxi,Yongshun,Yongshun Xian,Yung-shun,Yung-shun-hsien,Yungshunfu,ling xi,yong shun xian,永顺县,灵溪', 29.0050000, 109.8447200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16992, 'Dongta', 'Dongta', 'Dongta,Dongta Zhen,Lin''u,Lin-wu,Linchow,Linchzhou,Ling-chou,Ling-wu-hsien,Lingwu,Lingwu Shi,Lin’u,dong ta,dong ta zhen,ling wu shi,东塔,东塔镇,灵武市', 38.0814000, 106.3444400, 'CN', '2015-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16993, 'Lingtou', 'Lingtou', 'Lingtou,Lingtou Xiang,ling tou,ling tou xiang,岭头,岭头乡', 26.1888500, 119.2724900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16994, 'Lingtang', 'Lingtang', 'Ling-t''ang-ch''iao,Ling-t''ang-ch''iao-chen,Ling-t’ang-ch’iao,Ling-t’ang-ch’iao-chen,Lingtang,Lingtang Huizu Xiang,Lingtangqiao,ling tang,ling tang hui zu xiang,菱塘,菱塘回族乡', 32.6912000, 119.2268600, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16995, 'Cuifeng', 'Cuifeng', 'Cuifeng,Cuifeng Zhen,Ling-shih,Ling-shih-hsien,Ling-shih-hsien-ch''eng,Ling-shih-hsien-ch’eng,Lingshi,Lingshi Xian,Linshi,cui feng,cui feng zhen,ling shi xian,灵石县,翠峰,翠峰镇', 36.8451700, 111.7817200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16996, 'Lingshan', 'Lingshan', 'Ling-shan-chen,Lingshan,Lingshan Zhen,ling shan,ling shan zhen,灵山,灵山镇', 38.7899700, 114.6352000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16997, 'Lingshan', 'Lingshan', 'Lingshan,Lingshan Zhen,ling shan,ling shan zhen,灵山,灵山镇', 19.9691700, 110.4281100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16998, 'Wuling', 'Wuling', 'Ling-ch''iu,Ling-ch''iu-hsien,Ling-ch’iu,Ling-ch’iu-hsien,Lingkiuhsien,Lingqiu,Lingqiu Xian,Wuling,Wuling Zhen,ling qiu xian,wu ling,wu ling zhen,武灵,武灵镇,灵丘县', 39.4679900, 114.1484300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(16999, 'Lingqiao', 'Lingqiao', 'Ling-ch''iao,Ling-ch’iao,Lingqiao,Lingqiao Zhen,ling qiao,ling qiao zhen,灵桥,灵桥镇', 30.0303200, 120.0292700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17000, 'Lingqian', 'Lingqian', 'Ling-ch''ien,Ling-ch''ien-chen,Ling-ch’ien,Ling-ch’ien-chen,Lingqian,Lingqian Zhen,ling qian,ling qian zhen,陵前,陵前镇', 34.7605600, 108.9838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17001, 'Lingkou', 'Lingkou', 'Lingkou,Lingkou Zhen,ling kou,零口', 34.4774900, 109.3609800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17002, 'Lingkou', 'Lingkou', 'Ling-k''ou-chen,Ling-k’ou-chen,Lingkou,Lingkou Zhen,ling kou,ling kou zhen,陵口,陵口镇', 31.9500800, 119.6537300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17003, 'Lingjiang', 'Lingjiang', 'Cangxi,Lingjiang,Ts''ang-ch''i-hsien,Ts''ang-hsi,Tsangki-hsien,Ts’ang-ch’i-hsien,Ts’ang-hsi,ling jiang,陵江', 31.7346000, 105.9316200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17004, 'Linghu', 'Linghu', 'Ling-hu-chen,Linghu,Linghu Zhen,Wu-hsing,Wu-hsing-hsien,ling hu,ling hu zhen,菱湖,菱湖镇', 30.7175200, 120.1731100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17005, 'Lingdian', 'Lingdian', 'Ling-tien,Ling-tien-chen,Lingdian,Lingdian Zhen,Lingdianzhen,Linjiang,Linjiang Zhen,lin jiang,lin jiang zhen,ling dian,ling dian zhen,临江,临江镇,灵甸,灵甸镇', 31.8666800, 121.4202400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17006, 'Lingdi', 'Lingdi', 'Ling-ti,Lingdi,Lingdi Xiang,ling di,ling di xiang,岭底,岭底乡', 28.2062600, 118.2988800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17007, 'Lingdi', 'Lingdi', 'Ling-ti,Lingdi,Lingdi Zhen,ling de,ling de zhen,灵地,灵地镇', 25.8692000, 116.8126900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17008, 'Lingda', 'Lingda', 'Ling-ta,Lingda,Lingda Xiang,ling da,ling da xiang,凌笪,凌笪乡', 31.2037700, 119.2961200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17009, 'Chongwen', 'Chongwen', 'Chongwen,Chongwen Zhen,L''ing-ch''uan-hsien,Lin-chuan,Lingchuan,Lingchuan Xian,L’ing-ch’uan-hsien,chong wen,chong wen zhen,ling chuan xian,崇文,崇文镇,陵川县', 35.7749100, 113.2507900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17010, 'Lingchuan', 'Lingchuan', 'Lingchuan,Lingchuan Zhen,ling chuan,ling chuan zhen,灵川,灵川镇', 25.2960700, 118.9616300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17011, 'Lingcheng', 'Lingcheng', 'Ling-ch''eng-chen,Ling-ch’eng-chen,Ling-pi,Ling-pi-hsien,Lingbi,Lingcheng,ling cheng,灵城', 33.5376600, 117.5335700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17012, 'Lingcheng', 'Lingcheng', 'Beiliu,Lingcheng,Paklow,Paklow-hsien,Pei-liu,Pei-liu-hsien,Pie-liu', 22.7072200, 110.3491700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17013, 'Lingcheng', 'Lingcheng', 'Ling-shan-hsien,Lingcheng,Lingcheng Zhen,Lingshan,ling cheng,ling cheng zhen,灵城,灵城镇', 22.4231700, 109.2930300, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17014, 'Lingbei', 'Lingbei', 'Lingbei,Lingbei Zhen,ling bei,ling bei zhen,岭背,岭背镇', 26.0510400, 115.4668900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17015, 'Lingbei', 'Lingbei', 'Ling-pei,Lingbei,Lingbei Zhen,ling bei,ling bei zhen,岭背,岭背镇', 24.6145500, 112.7031700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17016, 'Lincheng', 'Lincheng', 'Hsien-ch''eng-chen,Hsien-ch’eng-chen,Limkao-hsien,Limko,Limkohsien,Limkou,Limkow,Lin''chehn,Lin-kae,Lin-kao,Lin-kao-chen,Lin-kao-hsien,Lincheng,Lincheng Zhen,Lingao,Lingao Xian,Lunkao,lin cheng,lin cheng zhen,lin gao xian,Линьчэн,临城,临城镇,临高县', 19.9077800, 109.6858300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17017, 'Lingang', 'Lingang', 'Lin-Kang,Lin-chiang,Lingang,Lingang Zhen,lin gang,lin gang zhen,临港,临港镇', 29.0288900, 117.3083700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17018, 'Linfeng', 'Linfeng', 'Linfeng,Linfeng Zhen,lin feng,lin feng zhen,邻封,邻封镇', 29.8910000, 107.2197100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17019, 'Linfen', 'Linfen', 'LFQ,Lam Phan,Lim-hun-chhi,Lin''fehn'',Lin''fyn'',Lin-fen,Lin-fen-hsien,Linfen,Linfen Shi,Ling-hung,Lâm Phần,Lìng-hŭng,Lîm-hun-chhī,Pingyang,Pingyangfu,Saratsi,Yaodu Qu,lin fen,lin fen shi,linpeon si,lynfn,lynfyn,ping yang,ping yang fu,yao dou qu,Линфен,Линьфынь,Линьфэнь,لینفن,لینفین,临汾,临汾市,尧都区,平阳,平阳府,臨汾,臨汾市,린펀 시', 36.0888900, 111.5188900, 'CN', '2016-04-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17020, 'Lindian', 'Lindian', 'Lin-chia-tien,Lin-tien,Lindian,Lindian Zhen,lin dian,蔺店', 34.7217500, 109.6021400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17021, 'Linjiadai', 'Linjiadai', 'Lin-chia-tai-chen,Lin-tai,Lindai,Lindai Zhen,Linjiadai,lin dai zhen,lin jia dai,林埭镇,林家埭', 30.6546900, 121.0981400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17022, 'Lincheng', 'Lincheng', 'Lincheng,lin cheng,林城', 30.9337400, 119.7868200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17023, 'Lincheng', 'Lincheng', 'Hui-t''ung,Hui-t''ung-hsien,Hui-t’ung,Hui-t’ung-hsien,Huitong,Hweitung,Hweitung-hsien,Khoytun,Lincheng,lin cheng,林城', 26.8693200, 109.6633600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17024, 'Linchen', 'Linchen', 'Linchen,Linchen Zhen,lin chen,lin chen zhen,林尘,林尘镇', 21.8318400, 110.5746600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17025, 'Lin’an', 'Lin''an', 'Lin''an,Lin''an Shi,Lin-an-hsien,Lin-an-hsien-ch''eng,Lin-an-hsien-ch’eng,Lin’an,Lin’an Shi,lin an,lin an shi,临安,临安市', 30.2358300, 119.7180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17026, 'Limin', 'Limin', 'Li-min-pao,Limin,Limin Zhen,li min,li min zhen,利民,利民镇', 39.3077700, 112.1203500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17027, 'Limiao', 'Limiao', 'Limiao,Limiao Zhen,li miao,li miao zhen,李庙,李庙镇', 31.8321300, 111.6780600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17028, 'Xishan', 'Xishan', 'Li-ling-ch''eng,Li-ling-ch’eng,Li-ling-hsien,Lilin,Liling,Liling Shi,Xishan,li ling,li ling shi,xi shan,Лилин,西山,醴陵,醴陵市', 27.6666700, 113.5000000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17029, 'Lili', 'Lili', 'Fenhu Zhen,Li-li-chen,Lili,Lili Jiedao,fen hu zhen,li li,li li jie dao,汾湖镇,黎里,黎里街道', 30.9940900, 120.7068600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17030, 'Likou', 'Likou', 'Likou,Likou Zhen,li kou,li kou zhen,历口,历口镇', 29.9009100, 117.5078100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17031, 'Lijiaxiang', 'Lijiaxiang', 'Li-chia-hsiang,Lijiaxiang,li jia xiang,李家巷', 30.9508300, 119.9758300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17032, 'Lijia', 'Lijia', 'Li-chia,Li-chia-ch''iao,Li-chia-ch''iao-chen,Li-chia-ch’iao,Li-chia-ch’iao-chen,Lijia,Lijia Xiang,Lijia Zhen,Lijiaqiao,li jia,li jia zhen,礼嘉,礼嘉镇', 31.6297300, 120.0105100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17033, 'Lijiang', 'Lijiang', 'Li-chiang,Lijiang,Lijiang Xiang,li jiang,li jiang xiang,溧江,溧江乡', 27.8381100, 115.4657100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17034, 'Lijiang', 'Lijiang', 'Hsiao-yen,Lijiang,Yuan-chiang,Yuan-chiang-hsien,Yuanjiang,Yuankiang,Yuankiang-hsien,Yüan-chiang,Yüan-chiang-hsien,Yüankiang,Yüankiang-hsien,li jiang,澧江', 23.5711000, 102.0041700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17035, 'Lijiahe', 'Lijiahe', 'Li-chia-ho,Lijiahe,Lijiahe Xiang,li jia he,li jia he xiang,李家河,李家河乡', 29.5891200, 109.4565900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17036, 'Liji', 'Liji', 'Hsiao-li,Hsiao-li-chi,Li-chi,Liji,Liji Xiang,Xiaoliji,li ji,li ji xiang,李集,李集乡', 34.1050000, 119.2527800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17037, 'Liji', 'Liji', 'Li-chi,Liji,Liji Zhen,li ji,li ji zhen,李集,李集镇', 30.8724700, 114.6657700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17038, 'Lihu', 'Lihu', 'Lihu,Lihu Zhen,li hu,li hu zhen,里湖,里湖镇', 23.3604000, 116.0407400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17039, 'Liheng', 'Liheng', 'Li-heng-chi,Li-heng-chuang,Liheng,Liheng Zhen,Lihengzhuang,li heng,li heng zhen,李恒,李恒镇', 34.1333300, 119.0500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17040, 'Lihen', 'Lihen', 'Li''an Xiang,Li-an,Lihen,Li’an Xiang,li an xiang,li hen,利安乡,黎痕', 29.7541600, 116.9922300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17041, 'Lihai', 'Lihai', 'Li-hai-so,Li-hai-so-ch''eng,Li-hai-so-ch’eng,Lihai,Lihai Zhen,li hai,li hai zhen,沥海,沥海镇', 30.1200600, 120.7580200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17042, 'Ligonggang', 'Ligonggang', 'Ligonggang,Ligonggang Zhen,li gong gang,li gong gang zhen,理公港,理公港镇', 29.0949600, 111.2014900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17043, 'Ligang', 'Ligang', 'Li-chiang,Li-kang,Li-kang-chen,Ligang,Ligang Zhen,li gang,li gang zhen,利港,利港镇', 31.9247200, 120.0786100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17044, 'Lifuta', 'Lifuta', 'Lifuta,Lifuta Zhen,li fu ta,li fu ta zhen,利福塔,利福塔镇', 29.3437600, 110.0745200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17045, 'Lieqiao', 'Lieqiao', 'Lieh-ch''iao,Lieh-ch’iao,Lieqiao,Lieqiao Xiang,lie qiao,lie qiao xiang,烈桥,烈桥乡', 28.5637700, 117.5223200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17046, 'Liebu', 'Liebu', 'Liebu,Liebu Xiang,Lieh-pao,lie bao,lie bao xiang,烈堡,烈堡乡', 39.3256100, 111.9559400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17047, 'Lidu', 'Lidu', 'Li-tu-chen,Lidu,Lidu Zhen,li du,li du zhen,李渡,李渡镇', 29.7576900, 107.2735300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17048, 'Lidong', 'Lidong', 'Lidong,Lidong Zhen,li dong,li dong zhen,里洞,里洞镇', 22.4676100, 112.1818400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17049, 'Lidian', 'Lidian', 'Lidian,li dian,李店', 35.2268200, 105.6875500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17050, 'Lidian', 'Lidian', 'Li-tien,Li-tien-chen,Lidian,Lidian Zhen,li dian,li dian zhen,李典,李典镇', 32.3218400, 119.5760600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17051, 'Lidian', 'Lidian', 'Li-chia-tien,Lidian,Lidian Zhen,li dian,li dian zhen,李店,李店镇', 31.2160400, 113.7578600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17052, 'Lidao', 'Lidao', 'Li-tao,Lidao,Lidao Zhen,Litau,li dao,li dao zhen,俚岛,俚岛镇', 37.2273300, 122.5840300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17053, 'Licun', 'Licun', 'Li-ts''un,Li-ts''un-chen,Li-ts’un,Li-ts’un-chen,Licun,Licun Zhen,li cun,li cun zhen,李村,李村镇', 38.1954800, 114.3398800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17054, 'Licun', 'Licun', 'Li-ts''un,Li-ts’un,Licun,Licun Zhen,li cun,li cun zhen,里村,里村镇', 35.7607300, 111.4547500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17055, 'Licun', 'Licun', 'Li-ts''un,Li-ts’un,Licun,Licun Xiang,li cun,li cun xiang,利村,利村乡', 25.8470600, 115.3927400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17056, 'Lichuan', 'Lichuan', 'Li-ch''uan-hsien,Li-ch’uan-hsien,Lichuan,Lichuan'',Lichwan-hsien,Личуань', 30.3000000, 108.8500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17057, 'Lihou', 'Lihou', 'Li-ch''eng-hsien,Li-ch’eng-hsien,Lichen,Licheng,Licheng Xian,Lihou,Lihou Zhen,li cheng xian,li hou,li hou zhen,黎侯,黎侯镇,黎城县', 36.5028900, 113.3694500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17058, 'Licheng', 'Licheng', 'Laipo,Laipo-hsien,Li-ch''eng-chen,Li-ch’eng-chen,Li-p''u-hsien,Li-p’u-hsien,Licheng,Lipu,li cheng,荔城', 24.5064900, 110.3891900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17059, 'Licheng', 'Licheng', 'Licheng,Licheng Jiedao,Tseng-ch''eng,Tseng-ch''eng-hsien,Tseng-ch’eng,Tseng-ch’eng-hsien,Tsengching,Tsengshing,Zengcheng,ceng cheng,li cheng,li cheng jie dao,曾城,荔城,荔城街道', 23.2954900, 113.8246500, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17060, 'Libu', 'Libu', 'Li-pu,Libu,Libu Zhen,li bu,li bu zhen,黎埠,黎埠镇', 24.5574200, 112.4177200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17061, 'Libei', 'Libei', 'Feng-p''o-ch''iao,Feng-p’o-ch’iao,Li-pei,Libei,Libei Zhen,li bei,li bei zhen,礼陂,礼陂镇', 27.6460100, 116.1329300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17062, 'Libao', 'Libao', 'Li-pao,Li-pao-chen,Libao,Libao Zhen,Lipu,li bao,li bao zhen,李堡,李堡镇', 32.5630600, 120.6838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17063, 'Liaoyan', 'Liaoyan', 'Liaoyan,Liaoyan Xiang,liao yan,liao yan xiang,蓼沿,蓼沿乡', 26.3692200, 119.4235000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17064, 'Liaoquan', 'Liaoquan', 'Liao-ch''uan,Liao-ch’uan,Liaoquan,Liaoquan Xiang,liao quan,liao quan xiang,蓼泉,蓼泉乡', 39.3500000, 100.0333300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17065, 'Miaojia', 'Miaojia', 'Liaojiacun,Liaojiacun Zhen,Miaojia,liao jia cun zhen,miao zhai,廖家村镇,苗寨', 29.3901700, 109.9950300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17066, 'Liaogao', 'Liaogao', 'Liaogao,Liaogao Zhen,Songtao,Songtao Miaozu Zizhixian,Sung-t''ao,Sung-t''ao-hsien,Sung-t''ao-miao-tsu-tzu-chih-hsien,Sung-t’ao,Sung-t’ao-hsien,Sung-t’ao-miao-tsu-tzu-chih-hsien,liao gao,liao gao zhen,song tao miao zu zi zhi xian,松桃苗族自治县,蓼皋,蓼皋镇', 28.1700000, 109.1950000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17067, 'Liaocheng', 'Liaocheng', 'Liao-ccheng,Liao-ch''eng-hsien,Liao-ch''eng-shih,Liao-ch’eng-hsien,Liao-ch’eng-shih,Liao-čcheng,Liaoceng,Liaocheng,Liaoĉeng,Lieu Thanh,Lieu-siang,Liâu-siâⁿ-chhī,Lièu-siàng,Liêu Thành,Ljaochehn,Ljaocheng,Tung-ch''ang,Tung-ch’ang,Tungchangfu,liao cheng,liao cheng shi,lyaocheong si,lyawchyng,Љаоченг,Ляочэн,لیاوچینگ,聊城,聊城市,랴오청 시', 36.4559600, 115.9776600, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17068, 'Liaobu', 'Liaobu', 'Liao-pu,Liaobu,Liaobu Zhen,liao bu,liao bu zhen,寮步,寮步镇', 22.9998900, 113.8815700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17069, 'Lianzhou', 'Lianzhou', 'Lianxian,Lianzhou,Lianzhou Zhen,Lien,Lien-chou,Lien-chou-chen,Lien-chou-ko-tsu-tzu-chih-hsien,Lien-hsien,Lien-yang,Linchow,Linhsien,lian zhou,lian zhou zhen,连州,连州镇', 24.7818600, 112.3712000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17070, 'Lianzhou', 'Lianzhou', 'Hepu,Ho-p''u,Ho-p''u-hsien,Ho-p’u,Ho-p’u-hsien,Hoppo,Hoppohsien,Lianzhou,Lianzhou Zhen,Lien-chou,Lien-chou-chen,Limchow,Limchowfu,Linchow,lian zhou,lian zhou zhen,廉州,廉州镇', 21.6662100, 109.2011600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17071, 'Lianyun', 'Lianyun', 'Lao-yao,Lianyun,Lianyun Jiedao,Lianyungang,Lianyungang Shi,Lien-yun,Lien-yun-chiang,Lien-yun-kang,Lien-yun-shih,Lien-yün,Lien-yün-chiang,Lien-yün-kang,Lien-yün-shih,lian yun,lian yun gang,lian yun jie dao,连云,连云港,连云街道', 34.7319400, 119.4425000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17072, 'Liantang', 'Liantang', 'Chang-lien-t''ang,Chang-lien-t''ang-chen,Chang-lien-t’ang,Chang-lien-t’ang-chen,Liantang,Liantang Zhen,Lien-t''ang,Lien-t’ang,Tung-lien-t''ang-chen,Tung-lien-t’ang-chen,lian tang,lian tang zhen,练塘,练塘镇', 31.0116700, 121.0460600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17073, 'Liantang', 'Liantang', 'Liantang,Liantang Zhen,Lien-t''ang,Lien-t’ang,lian tang,lian tang zhen,莲塘,莲塘镇', 22.9550200, 112.4530500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17074, 'Liantan', 'Liantan', 'Liantan,Liantan Zhen,Lien-t''an,Lien-tan-shih,Lien-t’an,lian tan,lian tan zhen,连滩,连滩镇', 22.9352300, 111.7236900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17075, 'Lianshi', 'Lianshi', 'Lianshi,Lianshi Zhen,Lien-shih,Lien-shih-chen,lian shi,lian shi zhen,练市,练市镇', 30.7084600, 120.4167200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17076, 'Lianran', 'Lianran', 'Anning,Anning Shi,Anning-chow,Lianran,Lianran Zhen,an ning,an ning shi,lian ran,lian ran zhen,安宁,安宁市,连然,连然镇', 24.9227100, 102.4849600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17077, 'Lianjiangkou', 'Lianjiangkou', 'Lianjiangkou,Lianjiangkou Zhen,Lien Chang Kou,Lien-chiang-k''ou,Lien-chiang-k''ou-hsu,Lien-chiang-k’ou,Lien-chiang-k’ou-hsü,lian jiang kou,lian jiang kou zhen,连江口,连江口镇', 24.0380200, 113.3106700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17078, 'Lianhuasi', 'Lianhuasi', 'Lianhuasi,Lianhuasi Zhen,Lianhuasizhan,Lien-hua-ssu,Lien-hua-ssu-chan,lian hua si,莲花寺', 34.5245800, 109.8408600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17079, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,lian hua,lian hua zhen,莲花,莲花镇', 28.1169400, 112.7663900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17080, 'Lianhu', 'Lianhu', 'Lianhu,Lianhu Xiang,lian hu,lian hu xiang,莲湖,莲湖乡', 28.9954900, 116.5419900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17081, 'Lianhe', 'Lianhe', 'Lianhe,Lianhe Xiang,Lien-ho,lian he,lian he xiang,莲荷,莲荷乡', 28.3833300, 117.5833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17082, 'Lianhe', 'Lianhe', 'Lianhe,lian he,莲河', 24.5729800, 118.3417100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17083, 'Lianhe', 'Lianhe', 'Lianhe,Lianhe Jiedao,Lien-ho,lian he,lian he jie dao,联和,联和街道', 23.2161300, 113.4077300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17084, 'Liangzhu', 'Liangzhu', 'Liang-chu,Liang-chu-chen,Liangzhu,Liangzhu Zhen,liang zhu,liang zhu zhen,良渚,良渚镇', 30.3793000, 120.0470300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17085, 'Wuwei', 'Wuwei', 'Liang-chou,Liang-chow,Liangzhou,Wu-wei-hsien,Wuwei,Wuwei Shi,wu wei,wu wei shi,武威,武威市', 37.9267200, 102.6320200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17086, 'Liangyaping', 'Liangyaping', '', 27.7183300, 110.6708300, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17087, 'Liangxiang', 'Liangxiang', 'Liang-hsiang,Liang-hsiang-chen,Liang-hsiang-hsien,Liangsiang,Liangxiang,Liangxiangzhen,Lyansyan,liang xiang,良乡', 39.7359800, 116.1329500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17088, 'Liangwangzhuang', 'Liangwangzhuang', 'Liang-wang-chuang,Liangwang,Liangwangzhuang,Liangwangzhuang Xiang,liang wang zhuang,liang wang zhuang xiang,良王庄,良王庄乡', 39.0267600, 116.9599800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17089, 'Liangwa', 'Liangwa', 'Liang-wu,Liangwa,Liangwa Zhen,liang wa,liang wa zhen,梁洼,梁洼镇', 33.8458600, 112.9252200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17090, 'Liangting', 'Liangting', 'Liang-t''ing-chen,Liang-t''ing-ssu,Liang-t’ing-chen,Liang-t’ing-ssu,Liangting,Liangting Zhen,Yu-t''ing,Yu-t''ing-chen,Yu-t''ing-ssu,Yü-t’ing,Yü-t’ing-chen,Yü-t’ing-ssu,liang ting,liang ting zhen,两亭,两亭镇', 34.7887000, 107.4897200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17091, 'Liangshuikou', 'Liangshuikou', 'Liangshuikou,Liangshuikou Zhen,liang shui kou,liang shui kou zhen,凉水口,凉水口镇', 29.5413900, 110.0963900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17092, 'Liangshuihe', 'Liangshuihe', 'Liangshuihe,Liangshuihe Zhen,liang shui he,liang shui he zhen,凉水河,凉水河镇', 32.6463500, 111.4661000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17093, 'Liangshui', 'Liangshui', 'Liangshui,Liangshui Zhen,liang shui,liang shui zhen,两水,两水镇', 33.4317700, 104.8090900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17094, 'Liangshan', 'Liangshan', 'LIA,Liang-p''ing-hsien,Liang-p’ing-hsien,Liang-shan-hsien,Liangping Xian,Liangshan,Liangshan Zhen,liang ping xian,liang shan,liang shan zhen,梁山,梁山镇,梁平县', 30.6740900, 107.7938000, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17095, 'Liangshan', 'Liangshan', 'Liangshan,Liangshan Zhen,liang shan,liang shan zhen,良山,良山镇', 27.6724000, 114.9061300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17096, 'Liangnong', 'Liangnong', 'Liang-lung,Liang-t''ung,Liang-t''ung-chen,Liang-t’ung,Liang-t’ung-chen,Liangnong,Liangnong Zhen,liang nong,liang nong zhen,梁弄,梁弄镇', 29.9127800, 121.0746500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17097, 'Liangkou', 'Liangkou', 'Leungkowhu,Leungkowhü,Liang-k''ou-hsu,Liang-k’ou-hsü,Liangkou,Liangkou Zhen,liang kou,liang kou zhen,良口,良口镇', 23.7227800, 113.7311200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17098, 'Xincheng', 'Xincheng', 'Liang-chia-yu-fang,Liangjiayoufang,Xincheng,Xincheng Zhen,Youyu Xian,Yu-yu,Yu-yü,xin cheng,xin cheng zhen,you yu xian,右玉县,新城,新城镇', 39.9867700, 112.4613500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17099, 'Lianghui', 'Lianghui', 'Lianghui,Lianghui Xiang,Xingcangku,liang hui,liang hui xiang,xin cang ku,两汇,两汇乡,新仓库', 29.6352600, 107.1004800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17100, 'Lianghekou', 'Lianghekou', 'Hsia-liang-ho-k''ou,Hsia-liang-ho-k’ou,Liang-ho-k''ou,Liang-ho-k’ou,Lianghekou,Lianghekou Zhen,liang he kou,liang he kou zhen,两河口,两河口镇', 33.3500000, 106.3500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17101, 'Lianghekou', 'Lianghekou', 'Liang-ho-k''ou,Liang-ho-k’ou,Lianghekou,Lianghekou Zhen,liang he kou,liang he kou zhen,两河口,两河口镇', 30.8724900, 110.5749200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17102, 'Lianghe', 'Lianghe', 'Liang-ho,Lianghe,Lianghe Xiang,liang he,liang he xiang,两河,两河乡', 38.3346100, 114.1580100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17103, 'Liangguang', 'Liangguang', 'Liangguang,Liangguang Zhen,liang guang,liang guang zhen,良光,良光镇', 21.5666700, 110.5475600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17104, 'Liangfang', 'Liangfang', 'Liangfang,Liangfang Zhen,liang fang,liang fang zhen,良坊,良坊镇', 27.2131900, 114.0388900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17105, 'Liangduo', 'Liangduo', 'Liang-to,Liang-to-chen,Liangduo,Liangduo Zhen,liang duo,liang duo zhen,梁垛,梁垛镇', 32.7763500, 120.3637300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17106, 'Liangdong', 'Liangdong', 'Liang-tung,Liangdong,Liangtong Zhen,liang dong,liang dong zhen,良垌,良垌镇', 21.4994600, 110.3967500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17107, 'Liangdang Chengguanzhen', 'Liangdang Chengguanzhen', 'Chengguanzhen,Liang-tang,Liang-tang-hsien,Liangdang,Liangdang Chengguanzhen,Liangdang Xian,Lyandan,liang dang,liang dang cheng guan zhen,liang dang xian,两当,两当县,两当城关镇', 33.9097200, 106.3022200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17108, 'Liangcunchang', 'Liangcunchang', 'Liang-ts''un,Liang-ts’un,Liangcun,Liangcunchang', 28.4066700, 106.4244400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17109, 'Liangcun', 'Liangcun', 'Liang-ts''un,Liang-ts’un,Liangcun,Liangcun Zhen,liang cun,liang cun zhen,良村,良村镇', 26.5590400, 115.5760600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17110, 'Liangcun', 'Liangcun', 'Liang-ts''un,Liang-ts’un,Liangcun,Liangcun Zhen,liang cun,liang cun zhen,梁村,梁村镇', 23.9504400, 112.0140100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17111, 'Lianfeng', 'Lianfeng', 'Liancheng,Lianfeng,Lien-ch''eng,Lien-ch''eng-hsien,Lien-ch’eng,Lien-ch’eng-hsien,lian feng,莲峰', 25.7044100, 116.7216200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17112, 'Liandu', 'Liandu', 'Liandou Zhen,Liandu,lian dou,lian dou zhen,莲都,莲都镇', 23.5898800, 111.8206900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17113, 'Liancun', 'Liancun', 'Liancun,lian cun,廉村', 33.6110200, 113.4742600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17114, 'Liancheng', 'Liancheng', 'Guangnan,Kuang-nan,Kuang-nan-hsien,Kwangnan,Kwangnan-hsien,Kwangnanfu,Liancheng,Pao-ning,lian cheng,莲城', 24.0519200, 105.0749700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17115, 'Lianjiang', 'Lianjiang', 'Lei-pei,Liancheng,Lianjiang,Lien-chiang,Lien-chiang-hsien,Limkong,Limkong-hsien,Lunkong,Shih-ch''eng,Shih-ch’eng,lian jiang,廉江', 21.6467300, 110.2817200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17116, 'Liancai', 'Liancai', 'Liancai,Liancaipu,Liancaizhen,Lien-ts''ai-p''u,Lien-ts’ai-p’u,lian cai,联财', 35.5597600, 105.8596500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17117, 'Lhakangtang', 'Lhakangtang', 'Lhakangtang,Luohantang,Luohantang Xiang,luo han tang,luo han tang xiang,罗汉堂,罗汉堂乡', 36.1160900, 101.1990400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17118, 'Lezhu', 'Lezhu', 'Le-chu,Lezhu,Lezhu Zhen,le zhu,le zhu zhen,簕竹,簕竹镇', 22.6952700, 112.1146300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17119, 'Leyu', 'Leyu', 'Leyu,Leyu Zhen,Lo-yu,Lo-yu-chen,Lo-yü,Lo-yü-chen,le yu,le yu zhen,乐余,乐余镇', 31.9285300, 120.6976800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17120, 'Letianxi', 'Letianxi', 'Le-t''ien-hsi,Le-t’ien-hsi,Letianxi,Letianxi Zhen,le tian xi,le tian xi zhen,乐天溪,乐天溪镇', 30.8697500, 111.0715500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17121, 'Lesuhe', 'Lesuhe', 'Le-su-ho,Le-su-ho-k''ou,Le-su-ho-k’ou,Lesuhe,Lesuhe Zhen,Lo-su-ho,Lo-su-ho-k''ou,Lo-su-ho-k’ou,le su he,le su he zhen,乐素河,乐素河镇', 33.2032700, 106.0362400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17122, 'Leshan', 'Leshan', 'Chia-ting,Kiating,Kiatingfu,Lac Son,Le-san,Le-šan,Lehshan'',Leshan,Lo-shan,Lo-shan-hsien,Lok-san-chhi,Lok-sang,Lo̍k-san-chhī,Lŏk-săng,Lạc Sơn,le shan,le shan shi,leosan si,lyshan,Лэшань,لیشان,乐山,乐山市,楽山市,樂山,러산 시', 29.5622700, 103.7638600, 'CN', '2015-06-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17123, 'Leping', 'Leping', 'Leping,Leping Shi,Leping Zhen,Lo-p''ing-chen,Lo-p''ing-hsien,Lo-p’ing-chen,Lo-p’ing-hsien,le ping,le ping shi,le ping zhen,乐平,乐平市,乐平镇', 28.9666700, 117.1166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17124, 'Leping', 'Leping', 'Leping,Leping Zhen,le ping,le ping zhen,乐平,乐平镇', 23.2641100, 113.0189300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17125, 'Lengshuitan', 'Lengshuitan', 'Leng-shui-t''an-shih,Leng-shui-t''ang,Leng-shui-t’an-shih,Leng-shui-t’ang,Lengshuitan,Lengshuitanqu,leng shui tan,冷水滩', 26.4111000, 111.5955900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17126, 'Lengshui', 'Lengshui', 'Leng-shui-chi,Lengshui,Lengshui Zhen,Lengshuipu,Lunsuipu,leng shui,leng shui zhen,冷水,冷水镇', 31.1121500, 112.4347600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17127, 'Lengshuijiang', 'Lengshuijiang', 'Lanh Thuy Giang,Leng-chiang,Leng-chiang-shih,Leng-shui-chen,Leng-shui-chiang,Leng-shui-chiang-shih,Lengshuijiang,Lãnh Thủy Giang,leng shui jiang,leng shui jiang shi,leongsu-ijang si,冷水江,冷水江市,렁수이장 시', 27.6880600, 111.4294400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17128, 'Lengshuiguan', 'Lengshuiguan', 'Lengshui,Lengshuiguan,Lengshuiguan Xiang,leng shui guan,leng shui guan xiang,冷水关,冷水关乡', 29.3815500, 107.1437800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17129, 'Lengji', 'Lengji', 'Leng-chi,Leng-chia-chi,Lengji,Lengji Zhen,leng ji,leng ji zhen,冷集,冷集镇', 32.3674400, 111.5931200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17130, 'Leliu', 'Leliu', 'Leliu,Leliu Jiedao,lei liu,lei liu jie dao,勒流,勒流街道', 22.8605600, 113.1189800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17131, 'Leli', 'Leli', 'Leli,Lo-li,Lo-li-chen,Lo-li-chieh,Lo-li-fou,Lo-li-hsu,Lo-li-hsü,T''ien-lin,Tianlin,T’ien-lin,le li,乐里', 24.3540500, 106.2437000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17132, 'Lejian', 'Lejian', 'Lejian,Lejian Xiang,le jian,le jian xiang,乐俭,乐俭乡', 28.4051200, 107.3569400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17133, 'Leiyang', 'Leiyang', 'Lei-yang-hsien,Leiyang,lei yang,耒阳', 26.4023800, 112.8590800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17134, 'Leijiadian', 'Leijiadian', 'Lei-chia-tien,Leijiadian,Leijiadian Zhen,lei jia dian,lei jia dian zhen,雷家店,雷家店镇', 30.8869900, 115.7518100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17135, 'Leiguan', 'Leiguan', 'Lei-kuan-chi,Leiguan,Leiguan Zhen,Leiguanji,lei guan,lei guan zhen,雷官,雷官镇', 32.3462400, 118.6159600, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17136, 'Leigong', 'Leigong', 'Lei-kung-tien,Leigong,Leigong Zhen,Leigongdian,lei gong,lei gong zhen,雷公,雷公镇', 31.2935500, 113.5111100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17137, 'Leifeng', 'Leifeng', 'Leifeng,Leifeng Zhen,lei feng,lei feng zhen,雷峰,雷峰镇', 25.5762200, 118.2939300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17138, 'Leidian', 'Leidian', 'Leidian,Leidian Zhen,lei dian,lei dian zhen,雷甸,雷甸镇', 30.5224100, 120.1405100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17139, 'Lecheng', 'Lecheng', 'Lechang,Lecheng,Lecheng Jiedao,Lo-ch''ang,Lo-ch''ang-hsien,Lo-ch’ang,Lo-ch’ang-hsien,Loh Ch''ang,Loh Ch’ang,Lohchong-hsien,Lokcheon,Lokchong,le cheng,le cheng jie dao,乐城,乐城街道', 25.1280000, 113.3504100, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17140, 'Lecheng', 'Lecheng', 'Lecheng,Lecheng Zhen,le cheng,le cheng zhen,乐城,乐城镇', 23.3535100, 112.3324500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17141, 'Le’an', 'Le''an', 'Le''an,Le''an Xiang,Le''anqiao,Le’an,Le’an Xiang,Le’anqiao,le an,le an xiang,乐安,乐安乡', 28.0913900, 111.5886100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17142, 'Lazi', 'Lazi', 'Lazi,Lazikou,la zi,la zi kou,腊子,腊子口', 34.0663400, 103.8940200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17143, 'Lasengmiao', 'Lasengmiao', 'Lasengmiao,Lasengmiao Zhen,la seng miao,la seng miao zhen,拉僧庙,拉僧庙镇', 39.3230600, 106.8355600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17144, 'La’ershan', 'La''ershan', 'La''ershan,La''ershan Zhen,Larshan,La’ershan,La’ershan Zhen,la er shan,la er shan zhen,腊尔山,腊尔山镇', 28.0845000, 109.3822500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17145, 'Laozhuang', 'Laozhuang', 'Laozhuang,Laozhuang Zhen,Shan-sun-lao-chuang,lao zhuang,lao zhuang zhen,老庄,老庄镇', 33.1365200, 112.2795000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17146, 'Laoyingpan', 'Laoyingpan', 'Laoyingpan,Laoyingpan Zhen,lao ying pan,lao ying pan zhen,老营盘,老营盘镇', 26.5591700, 115.2163900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17147, 'Laoxin', 'Laoxin', 'Lao-hsin-k''ou,Lao-hsin-k’ou,Laoxin,Laoxin Zhen,Laoxinkou,lao xin,lao xin zhen,老新,老新镇', 30.1904800, 112.8513200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17148, 'Laoqiao', 'Laoqiao', 'Lao-ch''iao,Lao-chen,Lao-ch’iao,Lao-hsia,Lao-hsia-chen,Laoqiao,Laoqiao Zhen,lao qiao,lao qiao zhen,姥桥,姥桥镇', 31.6085800, 118.3017300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17149, 'Laoqiao', 'Laoqiao', 'Laoqiao,Laoqiao Zhen,lao qiao,lao qiao zhen,醪桥,醪桥镇', 27.3023100, 115.1420800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17150, 'Laolong', 'Laolong', 'Lao-lung,Lao-lung-chen,Lao-lung-ssu,Laolong,Laolong Zhen,Longchuan,Lung-ch''uan,Lung-ch''uan-hsien,Lung-ch’uan,Lung-ch’uan-hsien,lao long,lao long zhen,老隆,老隆镇', 24.1025300, 115.2492100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17151, 'Laoliangcang', 'Laoliangcang', 'Laoliangcang,Laoliangcang Zhen,lao liang cang,lao liang cang zhen,老粮仓,老粮仓镇', 28.0750000, 112.1919400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17152, 'Laohekou', 'Laohekou', 'Guanghua,Ho-k''ou-chen,Ho-k’ou-chen,Kuang-hua,LHK,Lao-ho-k''ou,Lao-ho-k’ou,Laohekou,Laohokow,Lǎohékǒu,lao he kou,老河口', 32.3858300, 111.6677800, 'CN', '2017-07-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17153, 'Laogang', 'Laogang', 'Lao-chiang,Lao-chiang-chen,Lao-kang,Lao-kang-chen,Laogang,lao gang,老港', 31.0291700, 121.8430600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17154, 'Laodian', 'Laodian', 'Lao-tien,Laodian,Laodian Zhen,lao dian,lao dian zhen,涝店,涝店镇', 34.1714000, 108.5641800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17155, 'Laodaosi', 'Laodaosi', 'Lao-tao-shih,Lao-tao-ssu,Laodaosi,Laodaosi Zhen,lao dao si,lao dao si zhen,老道寺,老道寺镇', 33.1685000, 106.8842800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17156, 'Laocheng', 'Laocheng', 'Laocheng,Laocheng Zhen,Mo-shih,Sung-tsu,Sung-tzu,Sung-tzu-hsien,Sungtze,lao cheng,lao cheng zhen,老城,老城镇', 30.3452300, 111.7091000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17157, 'Laocheng', 'Laocheng', 'Laocheng,Laocheng Zhen,lao cheng,lao cheng zhen,老城,老城镇', 24.6878500, 114.9893000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17158, 'Lanzhou', 'Lanzhou', 'Kao-lan-hsien,Kaolan,LHW,Lan Chau,Lan Châu,Lan''chzhou,Lan''chzhou shaary,Lan''zhou,Lan-chiu-chhi,Lan-chou,Lan-chou-shih,Lan-cou,Lan-čou,Lanchjou,Lanchow,Lanchowfu,Lancsou,Landzhou,Landzou,Landžou,Lang-ciu,Langouo,Lantsjou,Lantsoou,Lanzcouh,Lanzhou,Lanzhou Shi,Lanĝoŭo,Laņdžou,Làng-ciŭ,Lân-chiu-chhī,hlan cow,lan zhou,lan zhou shi,lanazu,lanjeou si,lanjhu,lantshw,lanzhw,Λαντσόου,Ланджоу,Ланьжоу,Ланьчжоу,Ланьчжоу шаары,Ланџоу,لانتشو,لانزہو,لانژو,لەنجۇ شەھىرى,लान्झू,ਲਾਨਜ਼ੂ,หลานโจว,ལན་ཀྲོའུ།,兰州,兰州市,蘭州,蘭州市,란저우 시', 36.0570100, 103.8398700, 'CN', '2017-06-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17159, 'Lanzhong', 'Lanzhong', 'Lanzhong,Lanzhong Zhen,lan zhong,lan zhong zhen,蓝钟,蓝钟镇', 24.0655600, 111.9480000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17160, 'Lanxia', 'Lanxia', 'Lan-hsia,Lanxia,Lanxia Xiang,lan xia,lan xia xiang,岚下,岚下乡', 26.9608800, 117.9855700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17161, 'Lanxi', 'Lanxi', 'Lan-hsi,Lanxi,Lanxi Zhen,lan xi,lan xi zhen,兰溪,兰溪镇', 30.3469400, 115.1420500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17162, 'Lanxi', 'Lanxi', 'Lan-ch''i,Lan-ch''i-hsien,Lan-ch''i-hsien-ch''eng,Lan-ch’i,Lan-ch’i-hsien,Lan-ch’i-hsien-ch’eng,Lan-hsi,Lanxi', 29.2158800, 119.4715600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17163, 'Lanxi', 'Lanxi', 'Houligang,Lan-hsi,Lanxi,Lanxi Zhen,hou li gang,lan xi,lan xi zhen,厚里岗,蓝溪,蓝溪镇', 24.9140600, 116.6168500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17164, 'Lantian', 'Lantian', 'Lan-t''ien,Lan-t’ien,Lantian,Lantian Zhen,lan tian,lan tian zhen,兰田,兰田镇', 29.9067800, 118.0871400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17165, 'Lianyuan', 'Lianyuan', 'Lan-t''ien,Lan-t''ien-chen,Lan-t''ien-shih,Lan-t’ien,Lan-t’ien-chen,Lan-t’ien-shih,Lantian,Lianyuan,Lien Nguyen,Lien-yuan,Lien-yüan,Liên Nguyên,lian yuan,lian yuan shi,lyen-wian si,涟源,涟源市,漣源市,롄위안 시', 27.6883300, 111.6641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17166, 'Lantian', 'Lantian', 'Lan-t''ien,Lan-t''ien-ch''ang,Lan-t''ien-fang,Lan-t’ien,Lan-t’ien-ch’ang,Lan-t’ien-fang,Lantian', 27.0250000, 109.2947200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17167, 'Lantian', 'Lantian', 'Futian Yaozuxiang,Lan-t''ien,Lan-t’ien,Lantian,Lantian Yaozuxiang,Lantianyaozuxiang,lan tian,lan tian yao zu xiang,蓝田,蓝田瑶族乡', 23.8628700, 114.2267800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17168, 'Lantang', 'Lantang', 'Lantang,Lantang Zhen,lan tang,lan tang zhen,蓝塘,蓝塘镇', 23.4138200, 114.9329300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17169, 'Tafeng', 'Tafeng', 'Lan-chia,Lan-shan-hsien,Lanshan,Tafeng,ta feng,塔峰', 25.3540700, 112.1898700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17170, 'Lanqiao', 'Lanqiao', 'Lan-ch''iao,Lan-ch''iao-chen,Lan-ch’iao,Lan-ch’iao-chen,Lanqiao,lan qiao,蓝桥', 34.0743100, 109.4579300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17171, 'Lanli', 'Lanli', '', 27.8869400, 109.9186100, 'CN', '2004-05-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17172, 'Lankou', 'Lankou', 'Lan-k''ou-hsu,Lan-k’ou-hsü,Lankou,Lankou Zhen,lan kou,lan kou zhen,蓝口,蓝口镇', 23.9499800, 115.0851700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17173, 'Langya', 'Langya', 'Langya,Langya Zhen,Langyaxu,lang ya,lang ya xu,lang ya zhen,琅琊,琅琊徐,琅琊镇', 29.0077000, 119.4950200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17174, 'Rangxi', 'Rangxi', 'Lang-hsi-kang,Langxi Zhen,Langxigang,Rangxi,Rangxi Zhen,lang xi zhen,rang xi,rang xi zhen,浪西镇,瀼溪,瀼溪镇', 29.9154900, 116.7224100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17175, 'Langxi', 'Langxi', 'Langxi,Langxi Xiang,lang xi,lang xi xiang,朗溪,朗溪乡', 28.9218000, 110.3090400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17176, 'Langxi', 'Langxi', 'Langxi,Langxi Zhen,lang xi,lang xi zhen,郎溪,郎溪镇', 28.0116000, 108.4787700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17177, 'Languan', 'Languan', 'Lan-t''ien,Lan-t''ien-hsien,Lan-tyan,Lan-t’ien,Lan-t’ien-hsien,Languan,Languan Zhen,Lantian,lan guan,lan guan zhen,蓝关,蓝关镇', 34.1575400, 109.3141500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17178, 'Langtang', 'Langtang', 'Langtang,Langtang Zhen,lang tang,lang tang zhen,琅塘,琅塘镇', 28.0052800, 111.1486100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17179, 'Langshan', 'Langshan', 'Langshan,Langshan Zhen,lang shan,lang shan zhen,狼山,狼山镇', 31.9568600, 120.8856500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17180, 'Langqiao', 'Langqiao', 'Lang-ch''iao,Lang-ch''iao-ho,Lang-ch’iao,Lang-ch’iao-ho,Langqiao,Langqiao Zhen,lang qiao,lang qiao zhen,榔桥,榔桥镇', 30.4776700, 118.4526400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17181, 'Langqi', 'Langqi', 'Lang-ch''i,Lang-ch’i,Langqi,Langqi Zhen,lang qi,lang qi zhen,琅岐,琅岐镇', 26.0888200, 119.5713000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17182, 'Langping', 'Langping', 'Langping,Langping Zhen,lang ping,lang ping zhen,榔枰,榔枰镇', 30.6133600, 110.5076100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17183, 'Langfang', 'Langfang', 'An-tz''u,An-tz’u,Anci,LFA,Lanfan,Lang-fang-chen,Langfang,lang fang shi,Ланфан,廊坊市', 39.5097200, 116.6947200, 'CN', '2013-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17184, 'Langao Chengguanzhen', 'Langao Chengguanzhen', 'Chuan-p''ing,Chuan-p’ing,Lan-kao,Lan-kao-hsien,Lan-kao-hsien-ch''eng,Lan-kao-hsien-ch’eng,Langao,Langao Chengguanzhen,Langao Xian,lan gao cheng guan zhen,lan gao xian,岚皋县,岚皋城关镇', 32.3002800, 108.8930600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17185, 'Lankao Chengguanzhen', 'Lankao Chengguanzhen', 'Chengguan,Chengguan Xiang,Lan-feng-hsien,Lanfeng,Lankao,Lankao Chengguanzhen,Tung-jen,cheng guan,cheng guan xiang,lan kao cheng guan zhen,兰考城关镇,城关,城关乡', 34.8329400, 114.8071800, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17186, 'Weichanglu', 'Weichanglu', 'I,I-hsien,Lai-chou,Lai-chow-fu,Laichow,Laizhou,Laizhou Shi,Weichanglu,Weichanglu Jiedao,Ye Xian,Yeh,Yehsien,Yixian,lai zhou,lai zhou shi,wen chang lu,wen chang lu jie dao,ye xian,掖县,文昌路,文昌路街道,莱州,莱州市', 37.1807300, 119.9421700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17187, 'Laizhou', 'Laizhou', 'Chia-chou,Lai-chou,Laizhou,Laizhou Zhen,lai zhou,lai zhou zhen,来舟,来舟镇', 26.6276000, 117.9850500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17188, 'Laiyuan', 'Laiyuan', 'Laiyuan,Laiyuan Xiang,Xiacun,lai yuan,lai yuan xiang,赖源,赖源乡', 25.5630900, 117.0205700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17189, 'Laiyang', 'Laiyang', 'Lai-yang-hsien,Lai-yank,Laiyang', 36.9758300, 120.7136100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17190, 'Laiwu', 'Laiwu', 'Chiu-lai-wu,Lai Vu,Lai-bu-chhi,Lai-wu-hsien,Laiwu,Laj-wu,Laju,Lâi-bû-chhī,lai wu,lai wu shi,laiu si,layww,Лайу,لائوو,莱芜市,莱蕪市,萊蕪,라이우 시', 36.1927800, 117.6569400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17191, 'Laisu', 'Laisu', 'Laisu,Laisu Zhen,Laisuchang,lai su,lai su zhen,来苏,来苏镇', 29.2659700, 105.7780200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17192, 'Laishan', 'Laishan', 'Lai-shan-chi,Laishan,Laishan Zhen,lai shan,lai shan zhen,莱山,莱山镇', 37.3919800, 121.3804500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17193, 'Xiangfeng', 'Xiangfeng', 'Lai-feng-hsien,Laifeng Shi,Laifeng Xian,Xiangfeng,lai feng xian,xiang feng,来凤县,翔凤', 29.5076100, 109.4026600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17194, 'Laifang', 'Laifang', 'Laifang,lai fang,赖坊', 25.9360300, 116.8841500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17195, 'Laidian', 'Laidian', 'Laidian,Laidian Zhen,lai dian,lai dian zhen,赖店,赖店镇', 25.3343000, 118.7222000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17196, 'Laicun', 'Laicun', 'Lai-ts''un,Lai-ts''un-hsu,Lai-ts’un,Lai-ts’un-hsü,Laicun,Laicun Zhen,lai cun,lai cun zhen,赖村,赖村镇', 26.3471500, 115.8189200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17197, 'Laibin', 'Laibin', 'Lai Tan,Lai Tân,Lai-bing,Lai-pin,Lai-pin-chen,Lai-pin-chhi,Lai-pin-hsien,Laibin,Laiping,Laj-pin,Lajbin'',Leizbingz,Loi-pin-su,Lài-bĭng,Lâi-pin-chhī,Lòi-pîn-sṳ,lai bin,lai bin shi,laibin si,laybn,laybyn,layybn,Лайбинь,لائبن,لائیبن,لایبین,來賓,来宾市,来賓市,라이빈 시', 23.7000000, 109.2666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17198, 'Labuleng', 'Labuleng', 'Hsia-ho,Hsia-ho-hsien,La-pu-leng,Labran,Labrang,Labuleng,Labuleng Zhen,Lapulengsze,Lorang Trashikhyil,Syakhe,Te-wu-lu,Te-wu-lu-shih,Xiahe,Xiahe Xian,la bo leng,la bo leng zhen,xia he xian,夏河县,拉卜楞,拉卜楞镇', 35.2012500, 102.5211700, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17199, 'Labu', 'Labu', 'La-pao,La-pao-chen,La-pao-chieh,La-pao-hsu,La-pao-hsü,Labu,Lapu,Liu-chiang,Liu-chiang-hsien,la bao,拉堡', 24.2598500, 109.3341500, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17200, 'Kyinzhi', 'Kyinzhi', 'Kyinzhi,Qingzhen,Qingzhen Xiang,qing zhen,qing zhen xiang,清珍,清珍乡', 34.1474300, 100.1881400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17201, 'Zhongtie', 'Zhongtie', 'Jilang,Kyiling,Zhongtie,Zhongtie Xiang,ji lang,zhong tie,zhong tie xiang,中铁,中铁乡,吉浪', 35.2448100, 100.1329000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17202, 'Kunyang', 'Kunyang', 'Kunyang,P''ing-yang-hsien,P''ing-yang-hsien-ch''eng,Pingyang,P’ing-yang-hsien,P’ing-yang-hsien-ch’eng', 27.6658300, 120.5658300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17203, 'Kunyang', 'Kunyang', 'Chin-ning,Chiu-k''un-yang,Chiu-k''un-yang-hsien-ch''eng,Chiu-k’un-yang,Chiu-k’un-yang-hsien-ch’eng,Jinning,Jinning Xian,K''un-yang-hsien,Kunyang,Kunyang Zhen,K’un-yang-hsien,jin ning xian,kun yang,kun yang zhen,昆阳,昆阳镇,晋宁县', 24.6675300, 102.5919000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17204, 'Kunming', 'Kunming', 'Con Minh,Côn Minh,Gvwnhmingz,K''un-ming-hsien,K''un-ming-shih,KMG,Kchun-ming,Khun-beng-chhi,Khun-bêng-chhī,Kong-ming,Kounmink,Kuenming,Kun''min,Kun''min shaary,Kun''min'',Kunmin,Kunmina,Kunming,Kunming Shi,Kunmingas,Kunmingo,Kuņmina,Kŏng-mìng,Kүn''min,K’un-ming-hsien,K’un-ming-shih,Yun-nan,Yunnanfu,Yün-nan,Yünnanfu,kanamiga,khunh ming,kun ming,kun ming shi,kunaminga,kunming si,kunminga,kwnmng,kwnmyng,kwnmyngh,qwnmyng,Κουνμίγκ,Куенминг,Кунмин,Куньмин,Куньмин шаары,Куньминь,Куньмін,Күньмин,Կունմին,קונמינג,كونمينغ,كۈنمىڭ شەھىرى,کونمنگ,کونمینگ,کون‌مینگ,कुनमिंग,कुन्मिंग,ਕਨਮਿੰਗ,คุนหมิง,ကူမင်းမြို့,კუნმინი,昆明,昆明市,쿤밍 시', 25.0388900, 102.7183300, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17205, 'Kuiyong', 'Kuiyong', 'K''uei-yung,K''uei-yung-hsu,Khitschhung,Kuiyong,Kuiyong Jiedao,K’uei-yung,K’uei-yung-hsü,kui yong,kui yong jie dao,葵涌,葵涌街道', 22.6378900, 114.4157300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17206, 'Kuitan', 'Kuitan', 'K''uei-t''an,K''uei-t''an-hsu,Keulon,Kuitan,Kuitan Zhen,Kweitam,Kweitan,K’uei-t’an,K’uei-t’an-hsü,kui tan,kui tan zhen,葵潭,葵潭镇', 23.0633900, 115.9922600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17207, 'Kuimeishan', 'Kuimeishan', 'Kuimeishan,Kuimeishan Zhen,kui mei shan,kui mei shan zhen,岿美山,岿美山镇', 24.6689800, 114.8877900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17208, 'Kuihu', 'Kuihu', 'K''uei-hu,K''uei-t''an,K''uei-t''an-chen,Kuihu,Kuihu Zhen,K’uei-hu,K’uei-t’an,K’uei-t’an-chen,kui hu,kui hu zhen,奎湖,奎湖镇', 31.1497700, 118.4084900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17209, 'Kuidou', 'Kuidou', 'K''uei-tou,Kuidou,Kuidou Zhen,K’uei-tou,kui dou,kui dou zhen,魁斗,魁斗镇', 25.1336100, 118.1550000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17210, 'Kuantian', 'Kuantian', 'K''uan-t''ien,Kuantian,Kuantian Xiang,K’uan-t’ien,kuan tian,kuan tian xiang,宽田,宽田乡', 25.9986100, 115.6636000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17211, 'Kuangyuan', 'Kuangyuan', 'Dongfeng,I-liang,I-liang-hsien,Kuangyuan,Yiliang,Yiliang Xian,kuang yuan,yi liang,yi liang xian,匡远,宜良,宜良县', 24.9137900, 103.1478900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17212, 'Kuangyan', 'Kuangyan', 'K''uang-yen,K''uang-yen-shih,Kuangyan,Kuangyan Zhen,K’uang-yen,K’uang-yen-shih,kuang yan,kuang yan zhen,匡堰,匡堰镇', 30.1512700, 121.2958600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17213, 'Kuanghe', 'Kuanghe', 'K''uang-chia-ho,Kuanghe,Kuanghe Xiang,Kuangjiahe,K’uang-chia-ho,kuang he,kuang he xiang,匡河,匡河乡', 30.7047100, 115.5553500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17214, 'Kuanchuan', 'Kuanchuan', 'K''uan-ch''uan-p''u,Kuanchuan,Kuanchuan Xiang,K’uan-ch’uan-p’u,kuan chuan,kuan chuan xiang,宽川,宽川乡', 32.9943700, 106.2594000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17215, 'Kouzhen', 'Kouzhen', 'K''ou-chen,K''ou-t''ou-chen,Koutouzhen,Kouzhen,K’ou-chen,K’ou-t’ou-chen,kou zhen,口镇', 34.7088900, 108.6975000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17216, 'Koutou', 'Koutou', 'K''ou-t''ou-chen,Koutou,Koutou Zhen,K’ou-t’ou-chen,kou tou,kou tou zhen,口头,口头镇', 38.6044800, 114.3838500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17217, 'Koujiahe', 'Koujiahe', 'K''ou-chia-ho,Koujiahe,K’ou-chia-ho,kou jia he,寇家河', 34.7188200, 107.0644500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17218, 'Kou’an', 'Kou''an', 'An-k''ou,An-k’ou,Gaogang Qu,K''ou-an-chen,Kou''an,Kou''an Jiedao,Kou’an,Kou’an Jiedao,Kowan,K’ou-an-chen,gao gang qu,kou an,kou an jie dao,口岸,口岸街道,高港区', 32.3082000, 119.8756800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17219, 'Konglong', 'Konglong', 'K''ung-lung,K''ung-lung-chen,Konglong,Konglong Zhen,K’ung-lung,K’ung-lung-chen,kong long,kong long zhen,孔垄,孔垄镇', 29.8866800, 115.9032300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17220, 'Huzhuang', 'Huzhuang', 'Chou-chia-yuan,Chou-chia-yüan,Dongkong Jiazhuang,Huzhuang,Huzhuang Zhen,K''ung-chia-chuang,Kongjiazhuang,K’ung-chia-chuang,Tung-k''ung-chia-chuang,Tung-k’ung-chia-chuang,dong kong jia zhuang,hu zhuang,hu zhuang zhen,东孔家庄,胡庄,胡庄镇', 32.3518400, 120.0214400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17221, 'Kongwan', 'Kongwan', 'K''ung-chia-wan,Kongjiawan,Kongwan,Kongwan Zhen,K’ung-chia-wan,kong wan,kong wan zhen,孔湾,孔湾镇', 31.5709600, 112.2663400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17222, 'Ketian', 'Ketian', 'Ketian,Ketian Zhen,ke tian,ke tian zhen,客田,客田镇', 28.8908500, 108.2507700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17223, 'Kesha', 'Kesha', 'K''o-sha,Kesha,Kesha Xiang,K’o-sha,ke sha,ke sha xiang,颗沙,颗沙乡', 29.0958000, 109.9475700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17224, 'Kengzikou', 'Kengzikou', 'Banzhong,Kengzikou,Kengzikou Zhen,ban zhong,keng zi kou,keng zi kou zhen,坂中,坑仔口,坑仔口镇', 25.4221400, 118.0173700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17225, 'Kengyuan', 'Kengyuan', 'Kengyuan,Kengyuan Zhen,keng yuan,keng yuan zhen,坑园,坑园镇', 26.3396400, 119.7647600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17226, 'Kengtian', 'Kengtian', 'Kengtian,Kengtian Xiang,keng tian,keng tian xiang,坑田,坑田乡', 27.3450000, 115.3787300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17227, 'Kengdi', 'Kengdi', 'Kengdi,Kengdi Xiang,keng di,keng di xiang,坑底,坑底乡', 27.5876100, 119.5148900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17228, 'Kelu', 'Kelu', 'K''o-lu,Kelu,Kelu Zhen,K’o-lu,ke lu,ke lu zhen,客路,客路镇', 21.0869400, 110.0171100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17229, 'Lanyi', 'Lanyi', 'K''o-lan,K''o-lan-hsien,K''o-lan-hsien-ch''eng,Kelan,Kelan Xian,Kolanchow,K’o-lan,K’o-lan-hsien,K’o-lan-hsien-ch’eng,Lanyi,Lanyi Zhen,ke lan xian,lan yi,lan yi zhen,岚漪,岚漪镇,岢岚县', 38.7198300, 111.5978300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17230, 'Kefang', 'Kefang', 'Kefang,ke fang,客坊', 26.7174000, 116.5869400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17231, 'Kedian', 'Kedian', 'K''o-tien,Kedian,Kedian Zhen,K’o-tien,ke dian,ke dian zhen,客店,客店镇', 31.3605300, 112.8674700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17232, 'Kanshi', 'Kanshi', 'K''an-shih,Kanshi,Kanshi Zhen,Kunshih,K’an-shih,T''ai-p''ing,T’ai-p’ing,kan shi,kan shi zhen,坎市,坎市镇', 24.9186100, 116.8883300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17233, 'Kanshan', 'Kanshan', 'K''an-shan-chen,Kanshan,Kanshan Zhen,K’an-shan-chen,kan shan,kan shan zhen,坎山,坎山镇', 30.1939700, 120.4071400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17234, 'Kangshan', 'Kangshan', 'Hung-shan,Kangshan,Kangshan Xiang,kang shan,kang shan xiang,康山,康山乡', 28.8812200, 116.4311300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17235, 'Kangmei', 'Kangmei', 'Kangmei,Kangmei Zhen,Taixing,kang mei,kang mei zhen,tai xing,太兴,康美,康美镇', 25.0399700, 118.4706700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17236, 'Ganglong', 'Ganglong', 'Ganglong,Ganglong Xiang,Kanglung,Saixi Duoka,gang long,gang long xiang,sai xi duo ka,岗龙,岗龙乡,赛西多卡', 33.7622800, 100.2564500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17237, 'Fucheng', 'Fucheng', 'Fucheng,Hsin-chi,Hsin-chi-hsia,Hsin-chi-pao,K''ang-lo,K''ang-lo-hsien,K''ang-lo-she-chih-chu,Kangle,Kangle Xian,K’ang-lo,K’ang-lo-hsien,K’ang-lo-she-chih-chü,fu cheng,kang le xian,康乐县,附城', 35.3725000, 103.7055600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17238, 'Kangle', 'Kangle', 'Kangle,Kangle Jiedao,Kangle Zhen,Wan-tsai,Wan-tsai-hsien,Wan-tsai-hsien-ch''eng,Wan-tsai-hsien-ch’eng,Wanzai,Wanzai Xian,kang le,kang le jie dao,kang le zhen,wan zai xian,万载县,康乐,康乐街道,康乐镇', 28.0955700, 114.4500700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17239, 'Kaiyuan', 'Kaiyuan', 'A-mi,Ami-hsien,Amichow,K''ai-yuan-hsien,Kaiyuan,Kajjuan'',K’ai-yüan-hsien,kai yuan,Кайюань,开远', 23.6976700, 103.3037200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17240, 'Kaiping', 'Kaiping', 'K''ai-p''ing-chen,Kaiping,K’ai-p’ing-chen,kai ping,开平', 39.6779800, 118.2521700, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17241, 'Xinning', 'Xinning', 'Hsin-ning,K''ai-chiang,K''ai-chiang-hsien,Kaijiang,Kaikiang,Kaikianghsien,Kaytszan,K’ai-chiang,K’ai-chiang-hsien,Sin''nin,Sinning,Sinninghsien,Sin’nin,Xinning,xin ning,新宁', 31.0851500, 107.8650800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17242, 'Kaihua Chengguanzhen', 'Kaihua Chengguanzhen', 'Chengguan Zhen,K''ai-hua-hsien,K''ai-hua-hsien-ch''eng,Kaihua,Kaihua Chengguanzhen,Kaihwa,Kaihwa-hsien,K’ai-hua-hsien,K’ai-hua-hsien-ch’eng,cheng guan zhen,kai hua,kai hua cheng guan zhen,城关镇,开化,开化城关镇', 29.1458600, 118.4090300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17243, 'Kaihua', 'Kaihua', 'Kaihua,Kaihwa,Kaihwafu,Wen-shan-hsien,Wenshan,kai hua,开化', 23.3695000, 104.2772100, 'CN', '2013-04-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17244, 'Kaifeng', 'Kaifeng', 'Gorad Kajfehn,K''ai-feng-hsien,K''ai-feng-shih,Kai Feng,Kai-feng Fu,Kai-fêng Fu,Kai-hung,Kaifeng,Kajfehn,Kajfen,Kajfeng,Kajfyn,Kayfin,Kchaj-feng,Keyfeng shehiri,Keyféng shehiri,Khai Phong,Khai-hong-chhi,Khai-hong-chhī,Kăi-hŭng,K’ai-feng-hsien,K’ai-feng-shih,kai feng,kai feng shi,kaipeong si,kayfng,kayfngh,kayfyng,khi feing,Горад Кайфэн,Кайфен,Кайфын,Кайфэн,Кајфенг,קאיפנג,كايفنغ,کائفینگ,کایفنگ,ไคเฟิง,კაიფინი,ካይፈንግ,开封,开封市,開封,開封市,카이펑 시', 34.7986000, 114.3074200, 'CN', '2014-08-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17245, 'Juye', 'Juye', 'Chin-yeh,Chu-yeh,Chu-yeh-hsien,Chü-yeh,Chü-yeh-hsien,Juye,Juye Zhen,Kuyehhsien,ju ye,ju ye zhen,巨野,巨野镇', 35.3947200, 116.0883300, 'CN', '2016-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17246, 'Juxing', 'Juxing', 'Chu-hsing,Chu-hsing-chen,Chü-hsing,Chü-hsing-chen,Juxing,Juxing Zhen,Juxingzhen,Wangbao,Wangbao Zhen,ju xing,ju xing zhen,wang bao,wang bao zhen,王鲍,王鲍镇,聚星,聚星镇', 31.9663900, 121.5427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17247, 'Juxi', 'Juxi', 'Chu-hsi,Chü-hsi,Juxi,Juxi Zhen,ju xi,ju xi zhen,莒溪,莒溪镇', 25.4946500, 116.7387100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17248, 'Juting', 'Juting', 'Chu-t''ing,Chü-t’ing,Juting,ju ting,巨亭', 33.0553400, 106.0845300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17249, 'Jushui', 'Jushui', 'Chu-shui,Chü-shui,Jushui,Jushui Xiang,ju shui,ju shui xiang,举水,举水乡', 27.4958300, 119.1738900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17250, 'Junzhuang', 'Junzhuang', 'Junzhuang,Junzhuang Zhen,jun zhuang,jun zhuang zhen,军庄,军庄镇', 40.0011900, 116.0927000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17251, 'Junxi', 'Junxi', 'Datian,Junxi,Ta-t''ien,Ta-t''ien-ch''eng,Ta-t''ien-hsien,Ta-t’ien,Ta-t’ien-ch’eng,Ta-t’ien-hsien,da tian,jun xi,均溪,大田', 25.6979500, 117.8454100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17252, 'Junshanpu', 'Junshanpu', 'Chun-shan-p''u,Chün-shan-p’u,Junshanpu,Junshanpu Zhen,jun shan pu,jun shan pu zhen,军山铺,军山铺镇', 28.7044400, 112.1641700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17253, 'Junshan', 'Junshan', 'Junshan,Junshan Jiedao,jun shan,jun shan jie dao,军山,军山街道', 30.4048200, 114.0827000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17254, 'Aikou', 'Aikou', 'Aikou,Aikou Zhen,Junling,ai kou,ai kou zhen,jun ling,峻岭,隘口,隘口镇', 28.3294300, 108.8027100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17255, 'Junliangcheng', 'Junliangcheng', 'Ch''un-liang-ch''eng,Ch’ün-liang-ch’eng,Junliangcheng,Junliangcheng Jiedao,jun liang cheng,jun liang cheng jie dao,军粮城,军粮城街道', 39.0647600, 117.4467300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17256, 'Junlian', 'Junlian', 'Chun-lien,Chün-lien,Junlian,Kunlien,Kunlien-hsien,Künlien-hsien,Yun-lien,Yun-lien-hsien,Yün-lien,Yün-lien-hsien,jun lian,筠连', 28.1710600, 104.5116200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17257, 'Junkou', 'Junkou', 'Chun-k''ou,Chün-k’ou,Junkou,Junkou Zhen,jun kou,jun kou zhen,均口,均口镇', 26.6581400, 116.7946700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17258, 'Jundian', 'Jundian', 'Chun-tien,Chün-tien,Jundian,Jundian Zhen,jun dian,jun dian zhen,军店,军店镇', 32.0572500, 110.6179400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17259, 'Junchuan', 'Junchuan', 'Chun-ch''uan,Chun-ch''uan-tien,Chunchwantien,Chün-ch’uan,Chün-ch’uan-tien,Junchuan,Junchuan Zhen,jun chuan,jun chuan zhen,均川,均川镇', 31.6520600, 113.2184300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17260, 'Juncheng', 'Juncheng', 'Chun-ch''eng,Chün-ch’eng,Juncheng,Juncheng Zhen,jun cheng,jun cheng zhen,军城,军城镇', 38.9327700, 114.6971100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17261, 'Junbu', 'Junbu', 'Junbu,Junbu Xiang,jun bu,jun bu xiang,君埠,君埠乡', 26.7045200, 115.6656400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17262, 'Jun’an', 'Jun''an', 'Chun-an,Chün-an,Jun''an,Jun''an Zhen,Jun’an,Jun’an Zhen,jun an,jun an zhen,均安,均安镇', 22.7057500, 113.1467800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17263, 'Jugezhuang', 'Jugezhuang', 'Jugezhuang,Jugezhuang Zhen,ju ge zhuang,ju ge zhuang zhen,莒格庄,莒格庄镇', 37.1666700, 121.6833300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17264, 'Juexi', 'Juexi', 'Chueh-hsi,Chueh-hsi-so-ch''eng,Chüeh-hsi,Chüeh-hsi-so-ch’eng,Juexi,Juexi Jiedao,jue xi,jue xi jie dao,爵溪,爵溪街道', 29.4736100, 121.9472200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17265, 'Juegang', 'Juegang', 'Chueh-chiang,Chueh-chiang-chen,Chueh-kang,Chuehkiang,Chüeh-chiang,Chüeh-chiang-chen,Chüeh-kang,Chüehkiang,Ju-tung,Juegang,Juegang Zhen,Juegangzhen,Rudong Xian,jue gang,jue gang zhen,ru dong xian,如东县,掘港,掘港镇', 32.3173700, 121.1855200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17266, 'Longhu', 'Longhu', 'Juding,Longhu,Longhu Zhen,ju ding,long hu,long hu zhen,居丁,龙湖,龙湖镇', 19.5774800, 110.3944800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17267, 'Juanshui', 'Juanshui', 'Juanshui,T''ung-ch''eng,T''ung-ch''eng-hsien,Tongcheng,T’ung-ch’eng,T’ung-ch’eng-hsien,juan shui,隽水', 29.3030700, 113.8867600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17268, 'Juancheng', 'Juancheng', 'Chiu-chuan-cheng,Chiu-chüan-cheng,Chuan-ch''eng,Chuan-ch''eng-ku-chih,Chüan-ch’eng,Chüan-ch’eng-ku-chih,Juancheng,Wang-ku-tui,juan cheng,鄄城', 35.5615700, 115.5013400, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17269, 'Liulin', 'Liulin', 'Cho-ni,Cho-ni-she-chih-chu,Cho-ni-she-chih-chü,Chone,Chzhoni,Jone,Jonê,Knyazya Dzhoni,Liulin,Liulin Zhen,Zhuoni,Zhuoni Xian,liu lin,liu lin zhen,zhuo ni,zhuo ni xian,卓尼,卓尼县,柳林,柳林镇', 34.5897200, 103.5041700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17270, 'Shuangqiao', 'Shuangqiao', 'Chi-yuan,Chi-yuan-hsien,Chi-yüan,Chi-yüan-hsien,Jiyuan,Jiyuan Shi,Jiyuan Xian,Shuangqiao,Shuangqiao Jiedao,Tsiyuanhsien,ji yuan,ji yuan shi,ji yuan xian,shuang qiao,shuang qiao jie dao,双桥,双桥街道,济源,济源县,济源市', 35.0900000, 112.5800000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17271, 'Jiyang', 'Jiyang', 'Chi-yang,Jiyang,Jiyang Zhen,ji yang,ji yang zhen,吉阳,吉阳镇', 27.1393200, 118.1316700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17272, 'Jixin', 'Jixin', 'Chi-hsin,Jixin,Jixin Zhen,ji xin,ji xin zhen,吉信,吉信镇', 28.1075600, 109.6055800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17273, 'Jixiang', 'Jixiang', 'Jixiang,Jixiang Xiang,ji xiang,ji xiang xiang,吉巷,吉巷乡', 26.6727500, 118.9121900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17274, 'Jichang', 'Jichang', 'Chi,Chi-chen,Chi-hsien,Chi-hsien-ch''eng,Chi-hsien-ch’eng,Ji Xian,Jichang,Jichang Zhen,Jixian,Kichow,ji chang,ji chang zhen,ji xian,吉县,吉昌,吉昌镇', 36.1011100, 110.6733300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17275, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Xiang,Chi,Chi-hsien,Hsin-hsiang,Jixian,Kihsien,Wee-hui,Wei-hui,Weihui,Weihwei,cheng jiao,cheng jiao xiang,城郊,城郊乡', 35.4049500, 114.0604300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17276, 'Jixian', 'Jixian', 'Chi-hsien,Jixian,Jixian Zhen,Nan-chi-hsien,ji xian,ji xian zhen,集贤,集贤镇', 34.0886300, 108.3978300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17277, 'Jiwei', 'Jiwei', 'Jiwei,Jiwei Zhen,ji wei,ji wei zhen,吉卫,吉卫镇', 28.3334400, 109.4178800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17278, 'Jiuzihe', 'Jiuzihe', 'Chiu-tzu-ho,Jiuzihe,Jiuzihe Zhen,jiu zi he,jiu zi he zhen,九资河,九资河镇', 31.1408400, 115.6712200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17279, 'Jiuzhou', 'Jiuzhou', 'Jiuzhou,Jiuzhou Zhen,jiu zhou,jiu zhou zhen,旧州,旧州镇', 19.7712500, 110.4052900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17280, 'Jiuzhen', 'Jiuzhen', 'Jiuzhen,Jiuzhen Zhen,jiu zhen,jiu zhen zhen,九真,九真镇', 30.7474000, 113.2147600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17281, 'Yuhang', 'Yuhang', 'Chiu-yu-hang,Chiu-yü-hang,Jiuyuhang,Yu-hang-chen,Yu-hang-hsien,Yu-hang-hsien-ch''eng,Yuhang,Yuhang Zhen,Yü-hang-chen,Yü-hang-hsien-ch’eng,yu hang,余杭', 30.2752800, 119.9325000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17282, 'Yongping', 'Yongping', 'Chiu-yung-shou,Jiuyongshou,Yongping,Yung-p''ing,Yung-p’ing,Yung-shou-hsien,Yung-shou-ku-chih,yong ping,永平', 34.8108300, 108.0413900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17283, 'Huayuan', 'Huayuan', 'Chiu-hsiang-ch''eng,Chiu-hsiang-ch’eng,Hsiang-ch''eng,Hsiang-ch''eng-hsien,Hsiang-ch’eng,Hsiang-ch’eng-hsien,Huayuan,Jiuxiangcheng,Molingzhenlaocheng,Siangchenghsien,hua yuan,花园', 33.4688000, 114.8731400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17284, 'Jiuxian', 'Jiuxian', 'Chiu-hsien,Chiu-hsien-chen,Jiuxian,Jiuxian Xiang,jiu xian,jiu xian xiang,旧县,旧县乡', 33.4954500, 113.2996500, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17285, 'Jiuxian', 'Jiuxian', 'Chiu-hsien,Jiuxian,Jiuxian Zhen,jiu xian,jiu xian zhen,旧县,旧县镇', 31.1206300, 111.6074400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17286, 'Jiuxian', 'Jiuxian', 'Chiu-hsien,Jiuxian,Jiuxian Zhen,jiu xian,jiu xian zhen,旧县,旧县镇', 29.8620300, 106.2028800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17287, 'Jiuxian', 'Jiuxian', 'Chiu-hsien,Chiu-hsien-chen,Chiu-hsien-fou,Jiuxian,Jiuxian Jiedao,jiu xian,jiu xian jie dao,旧县,旧县街道', 29.8022400, 119.6239700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17288, 'Jiuxian', 'Jiuxian', 'Jiuxian,Jiuxian Xiang,jiu xian,jiu xian xiang,旧县,旧县乡', 27.6052800, 118.8558300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17289, 'Jiuxian', 'Jiuxian', 'Jiuxian,Jiuxian Xiang,jiu xian,jiu xian xiang,旧县,旧县乡', 25.2239700, 116.4976000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17290, 'Jiuxi', 'Jiuxi', 'Chiu-hsi,Jiuxi,Jiuxi Xiang,jiu xi,jiu xi xiang,九溪,九溪乡', 29.1810100, 111.2717400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17291, 'Wugong', 'Wugong', 'Chiu-wu-kung,Jiuwugong,Ugun,Wu-kung,Wu-kung-hsien,Wugong,Wugong Zhen,wu gong,wu gong zhen,武功,武功镇', 34.3283000, 108.1076100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17292, 'Jiusi', 'Jiusi', 'Chiu-ssu,Jiusi,Jiusi Xiang,jiu si,jiu si xiang,旧司,旧司乡', 29.4336300, 109.2550700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17293, 'Jiupu', 'Jiupu', 'Chiu-p''u,Chiu-p’u,Jiupu,Jiupu Zhen,jiu pu,jiu pu zhen,旧铺,旧铺镇', 32.8144700, 118.6779300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17294, 'Ningshan Chengguanzhen', 'Ningshan Chengguanzhen', 'Chiu-ning-shan,Jiuningshan,Lao-ch''eng,Lao-ch’eng,Ning-shan-hsien,Ningshan,Ningshan Chengguanzhen,Ningshan Xian,Ningshen-hsien,Ningsiating,Ninshan,ning shan cheng guan zhen,ning shan xian,宁陕县,宁陕城关镇', 33.3315300, 108.3068500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17295, 'Jiulong', 'Jiulong', 'Chiu-lung,Chiu-lung-chen,Jiulong,Jiulong Zhen,jiu long,jiu long zhen,久隆,久隆镇', 31.9080600, 121.5713900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17296, 'Yangjiaping', 'Yangjiaping', 'Chiu-lung-p''o,Chiu-lung-p''u,Chiu-lung-p’o,Chiu-lung-p’u,Jiulongpo,Jiulongpo Qu,Yangjiaping,jiu long po qu,yang jia ping,九龙坡区,杨家坪', 29.5051200, 106.5013500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17297, 'Jiulonggang', 'Jiulonggang', 'Chiu-lung-kang,Jiulonggang,Jiulonggang Zhen,jiu long gang,jiu long gang zhen,九龙岗,九龙岗镇', 32.6200000, 117.0800000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17298, 'Jiulong', 'Jiulong', 'Chiu-lung,Jiulong,Jiulong Zhen,jiu long,jiu long zhen,九龙,九龙镇', 28.5212100, 116.6330300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17299, 'Jiulong', 'Jiulong', 'Jiulong,Jiulong Zhen,jiu long,jiu long zhen,九龙,九龙镇', 24.1393700, 112.9059600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17300, 'Lianzhu', 'Lianzhu', 'Jiulian,Lianzhu,Meikiang,Mo-chiang,Mo-chiang-hsien,Mojiang,Mokianghsien,T''a-lang,T''a-lang-t''ing,T’a-lang,T’a-lang-t’ing,lian zhu,联珠', 23.4084400, 101.7102800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17301, 'Jiukou', 'Jiukou', 'Chiu-k''ou,Chiu-k''ou-chen,Chiu-k’ou,Chiu-k’ou-chen,Jiukou,Jiukou Zhen,Kinkow,Kiukow,jiu kou,jiu kou zhen,旧口,旧口镇', 30.8643900, 112.6661100, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17302, 'Jiujie', 'Jiujie', 'Jiujie,jiu jie,九街', 33.5510900, 113.7645100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17303, 'Jiujie', 'Jiujie', 'Jiujie,Jiujie Jiedao,jiu jie,jiu jie jie dao,旧街,旧街街道', 30.8350500, 114.9211500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17304, 'Xixiang', 'Xixiang', 'Chiu-chieh,Hsin-an,Jiujie,Pao-an,Pao-an-hsien,Sinon,Sunon,Xixiang,Xixiang Jiedao,xi xiang,xi xiang jie dao,西乡,西乡街道', 22.5930600, 113.8889000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17305, 'Jiujiang', 'Jiujiang', 'Chiu-chiang,Chiu-chiang-hsien,Chiu-chiang-shih,Ciuciang,Cuu Giang,Czjuczjan,Cửu Giang,Dzjudzjan,JIU,Jiujiang,Kiukiang,Kiukiang-hsien,Te-hua,Tiou-tiang,jiu jiang,jiu jiang shi,jujang si,Ťiou-ťiang,Ђуђанг,Дзюдзян,Цзюцзян,ཅིའུ་ཅང་།,九江,九江市,주장 시', 29.7047500, 116.0020600, 'CN', '2014-12-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17306, 'Jiujiang', 'Jiujiang', 'Chiu-chiang,Chiu-chiang-hsu,Chiu-chiang-hsü,Jiujiang,Jiujiang Zhen,Kiukiang,Kowkong,jiu jiang,jiu jiang zhen,九江,九江镇', 22.8359300, 113.0067200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17307, 'Jiuhua', 'Jiuhua', 'Chiu-hua-chen,Chiu-hua-shan,Jiuhua,Jiuhua Zhen,jiu hua,jiu hua zhen,九华,九华镇', 32.1372000, 120.6527700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17308, 'Jiuhe', 'Jiuhe', 'Chiu-ho,Chiu-ho-hsu,Chiu-ho-hsü,Chiu-ho-shih,Jiuhe,Jiuhe Zhen,jiu he,jiu he zhen,九和,九和镇', 23.4956300, 115.0608200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17309, 'Jiuguan', 'Jiuguan', 'Chiu-kuan,Chiu-kuan-shih,Jiuguan,Jiuguan Zhen,Sheng-she,jiu guan,jiu guan zhen,旧馆,旧馆镇', 30.8380900, 120.2768000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17310, 'Jiufeng', 'Jiufeng', 'Chiu-feng,Chiu-feng-hsu,Chiu-feng-hsü,Jiufeng,Jiufeng Zhen,jiu feng,jiu feng zhen,九峰,九峰镇', 25.3500000, 113.3666700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17311, 'Jiufang', 'Jiufang', 'Chiu-fang,Jiufang,Mo-chia-chiu-fang,Wu-chia-chiu-fang,jiu fang,酒房', 34.8145100, 107.3927400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17312, 'Jiudu', 'Jiudu', 'Jiudu,Jiudu Zhen,Tinghouku,jiu dou,jiu dou zhen,九都,九都镇', 25.2048100, 118.4543100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17313, 'Jiudian', 'Jiudian', 'Chiu-tien,Jiudian,Jiudian Xiang,jiu dian,jiu dian xiang,酒店,酒店乡', 29.6437600, 107.3399000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17314, 'Jiuchenggong', 'Jiuchenggong', 'Jiuchenggong,Lin-yu,Lin-yu-hsien,Lin-yu-hsien-ch''eng,Lin-yu-hsien-ch’eng,Lingyu,Linyou,Tangjiu Chenggong,jiu cheng gong,lin you,九成宫,麟游', 34.6786800, 107.7875800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17315, 'Jiucheng', 'Jiucheng', 'Chiu-ch''eng,Chiu-ch’eng,Jiucheng,Jiucheng Zhen,jiu cheng,jiu cheng zhen,旧城,旧城镇', 28.7413800, 107.6803700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17316, 'Jiucaizhuang', 'Jiucaizhuang', 'Chiu-ts''ai-chuang,Chiu-ts’ai-chuang,Jiucaizhuang,jiu cai zhuang,韭菜庄', 39.8419400, 111.9022200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17317, 'Jiubao', 'Jiubao', 'Jiubao,Jiubao Zhen,jiu bao,jiu bao zhen,九堡,九堡镇', 25.9457100, 115.9004600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17318, 'Jitian', 'Jitian', 'Chi-t''ien,Chi-t’ien,Jitian,Jitian Zhen,Lianshan,Lien-shan,ji tian,ji tian zhen,吉田,吉田镇', 24.5720400, 112.0753200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17319, 'Jitan', 'Jitan', 'Chi-t''an,Chi-t''an-hsu,Chi-t’an,Chi-t’an-hsü,Jitan,Jitan Zhen,ji tan,ji tan zhen,吉潭,吉潭镇', 24.9489600, 115.7435800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17320, 'Jishui', 'Jishui', 'Chi-shui,Chi-shui-chi,Jishui', 33.7333300, 115.4000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17321, 'Qianzhou', 'Qianzhou', 'Ch''ien-ch''eng,Chi-shou,Chi-shou-hsien,Ch’ien-ch’eng,Jishou,Jishou Shi,Kishow,Qianzhou,So-li,gan zhou,ji shou,ji shou shi,乾州,吉首,吉首市', 28.3192500, 109.7334600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17322, 'Jifeng', 'Jifeng', 'Chi-shan,Chi-shan-hsien,Jifeng,Jifeng Zhen,Jishan,Jishan Xian,Tsishanhsien,ji feng,ji feng zhen,ji shan xian,稷山县,稷峰,稷峰镇', 35.6134700, 110.9585400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17323, 'Jinzipai', 'Jinzipai', 'Chin-tzu-p''ai,Chin-tzu-p’ai,Jinzipai,Jinzipai Zhen,jin zi pai,jin zi pai zhen,金字牌,金字牌镇', 29.8463100, 117.8077800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17324, 'Jinzhuang', 'Jinzhuang', 'Jinzhuang,Jinzhuang Zhen,jin zhuang,jin zhuang zhen,金装,金装镇', 23.8013900, 111.8652800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17325, 'Jinzhou', 'Jinzhou', 'Chin,Chin-chou,Chin-chou-chen,Chin-chow,Chin-hsien,Czin''chzhou,Jinxian,Jinzhou,Kin,Kinchow,Kinhsien,Kinshu,Kinsyu,Tschintschou,Цзиньчжоу', 39.1000000, 121.7166700, 'CN', '2011-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17326, 'Jinze', 'Jinze', 'Chin-tse,Chin-tse-chen,Jinze,Jinze Zhen,jin ze,jin ze zhen,金泽,金泽镇', 31.0371400, 120.9147000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17327, 'Jinyuan', 'Jinyuan', 'Chin-yuan,Chin-yuan-hsien,Chin-yüan,Chin-yüan-hsien,Chiu-chin-yuan,Chiu-chin-yüan,Jinyuan,Jinyuan Jiedao,Jinyuan Qu,T''ai-yuan,T''ai-yuan-chen,Taiyuanhsien,T’ai-yüan,T’ai-yüan-chen,jin yuan,jin yuan jie dao,jin yuan qu,晋源,晋源区,晋源街道', 37.7269400, 112.4708300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17328, 'Jinxiu', 'Jinxiu', 'Chin-hsiu,Chin-hsiu-chen,Chin-hsiu-hsiang,Chin-hsiu-ku-chih,Chin-hsiu-ts''un,Chin-hsiu-ts’un,Jinxiu,Kinsiu,Ta-yao-shan,Ta-yao-shan-hsien-yao-tsu-tzu-chih-ch''u,Ta-yao-shan-hsien-yao-tsu-tzu-chih-ch’ü,Ta-yao-shan-yao-tsu-tzu-chih-ch''u,Ta-yao-shan-yao-tsu-tzu-chih-ch’ü,Ta-yao-shan-yao-tsu-tzu-chih-hsien,jin xiu,金秀', 24.1372100, 110.1800900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17329, 'Jinxiang', 'Jinxiangzhen', 'Chin-chen-wei,Chin-chen-wei-ch''eng,Chin-chen-wei-ch’eng,Chin-hsiang,Jinxiang,Jinxiangzhen,Kinchenwei,Kinsiang,jin xiang,金乡', 27.4326500, 120.6062500, 'CN', '2011-09-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17330, 'Jintian', 'Jintian', 'Chin-t''ien,Chin-t’ien,Jintian,Jintian Xiang,jin tian,jin tian xiang,金田,金田乡', 27.1501700, 114.4386000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17331, 'Jintao', 'Jintao', 'Fuquan,Jintao,Jintao Zhen,jin tao,jin tao zhen,金淘,金淘镇', 25.1203600, 118.3527200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17332, 'Jintang', 'Jintang', 'Jintang,Jintang Zhen,jin tang,jin tang zhen,金塘,金塘镇', 30.0057900, 121.8662100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17333, 'Jintang', 'Jintang', 'Chin-t''ang,Chin-t’ang,Jintang,Jintang Zhen,jin tang,jin tang zhen,金塘,金塘镇', 29.3138900, 114.1699300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17334, 'Jintang', 'Jintang', 'Jintang,Jintang Zhen,jin tang,jin tang zhen,金塘,金塘镇', 21.7517300, 110.8424000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17335, 'Jintan', 'Jintan', 'Chin-t''an,Chin-t’an,Jintan,Jintan Zhen,jin tan,jin tan zhen,金滩,金滩镇', 27.2716900, 115.1186700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17336, 'Jintan', 'Jintan', 'Chin-t''an,Chin-t’an,Jintan,Jintan Zhen,jin tan,jin tan zhen,浸潭,浸潭镇', 24.0594400, 112.8080600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17337, 'Jinshiqiao', 'Jinshiqiao', 'Chin-shih-ch''iao,Chin-shih-ch’iao,Jinshiqiao,Jinshiqiao Zhen,jin shi qiao,jin shi qiao zhen,金石桥,金石桥镇', 27.5842500, 110.9363400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17338, 'Jinshi', 'Jinshi', 'Chin-shih,Ching-shih,Ching-shih-chen,Ching-shih-shih,Jinshi,Jinshi Shi,Tsingshih,jin shi,jin shi shi,津市,津市市', 29.6048700, 111.8701200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17339, 'Jinshi', 'Jinshi', 'Chin-shih,Chin-shih-chen,Hsin-ning,Hsin-ning-hsien,Jinshi,Sinning,Sinning-hsien,Xinning,jin shi,金石', 26.4179600, 110.8001700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17340, 'Jinshan', 'Jinshan', 'Chin-shan,Chin-shan-chen,Jinshan,Jinshanzhen,jin shan,金山', 34.2899000, 109.3808500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17341, 'Jinshanwei', 'Jinshanwei', 'Chin-shan-wei,Chin-shan-wei-ch''eng,Chin-shan-wei-ch’eng,Chinshan,Jinshanwei,Jinwei,Kin-shan,jin shan wei,金山卫', 30.7233300, 121.3150000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17342, 'Jinshanpu', 'Jinshanpu', 'Chin-shan-p''u,Chin-shan-p’u,Jinshanpu,Jinshanpu Xiang,jin shan pu,jin shan pu xiang,金山铺,金山铺乡', 39.2946800, 113.6791300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17343, 'Jinshandian', 'Jinshandian', 'Jinshandian,Jinshandian Zhen,jin shan dian,jin shan dian zhen,金山店,金山店镇', 30.1428500, 114.8644500, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17344, 'Jinshan', 'Jinshan', 'Jinshan,Lu-feng-hsien,Lufeng,jin shan,金山', 25.1150800, 102.0983300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17345, 'Jinshan', 'Jinshan', 'Chin-shan,Jinshan,Jinshan Zhen,jin shan,jin shan zhen,锦山,锦山镇', 19.9980400, 110.6895700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17346, 'Jinsha', 'Jinsha', 'Chin-sha,Chin-sha-chen,Czin''sha,Jinsha,Jinsha Zhen,Kinsha,Nan-t''ung,Nan-t''ung-hsien,Nan-t’ung,Nan-t’ung-hsien,Nantong,Tongzhou,Tongzhou Shi,jin sha,jin sha zhen,tong zhou,tong zhou shi,Цзиньша,通州,通州市,金沙,金沙镇', 32.0898200, 121.0735500, 'CN', '2014-11-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17347, 'Jinsha', 'Jinsha', 'Chin-sha,Jinsha,Jinsha Zhen,jin sha,jin sha zhen,金沙,金沙镇', 30.2644000, 118.7298200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17348, 'Jinsha', 'Jinsha', 'Chin-sha,Jinsha,Jinsha Zhen,jin sha,jin sha zhen,金沙,金沙镇', 26.1816500, 118.7092800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17349, 'Jinrui', 'Jinrui', 'Chin-jui,Jinrui,Jinrui Zhen,jin rui,jin rui zhen,金瑞,金瑞镇', 27.9267700, 114.2018200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17350, 'Jinqu', 'Jinqu', 'Chin-ch''u,Chin-ch''u-chen,Chin-ch’ü,Chin-ch’ü-chen,Jinqu,Jinqu Zhen,jin qu,jin qu zhen,金渠,金渠镇', 34.2119000, 107.7789000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17351, 'Jinping', 'Jinping', 'Ch''ung-hsin,Ch''ung-hsin-hsien,Changsin,Chongxin,Chongxin Xian,Chunsin'',Chunsin’,Ch’ung-hsin,Ch’ung-hsin-hsien,Jinbing,Jinping,Tsungsin,chong xin xian,jin ping,崇信县,锦屏', 35.3143500, 107.0292300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17352, 'Jinping', 'Jinping', 'Jinping,Jinping Zhen,jin ping,jin ping zhen,锦屏,锦屏镇', 34.5166700, 119.1166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17353, 'Jinping', 'Jinping', 'Ching-tung,Ching-tung-hsien,Jingdong,Jinping,Kingtung-hsien,Kingtungsin,Kingtungting,jin ping,锦屏', 24.4337400, 100.8198900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17354, 'Jinping', 'Jinping', 'Ch''iu-pei,Ch''iu-pei-hsien,Ch’iu-pei,Ch’iu-pei-hsien,Jinping,Kiupehhsien,Qiubei,jin ping,锦屏', 24.0305400, 104.2270200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17355, 'Jinhe', 'Jinhe', 'Chin-ho,Chin-p''ing,Chin-p''ing-hsien,Chin-p’ing,Chin-p’ing-hsien,Chin-sha,Ho-chin,Jinhe,Jinping,Wang-pu-chieh,Wang-pu-t''ien,Wang-pu-t’ien,Wangpatien,Wangpotien,jin he,金河', 22.7666700, 103.2500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17356, 'Jinpanling', 'Jinpanling', 'Jinpanling,Jinpanling Zhen,jin pan ling,jin pan ling zhen,金盘岭,金盘岭镇', 29.3353500, 116.9955200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17357, 'Jinnan', 'Jinnan', 'Jinnan,Jinnan Zhen,jin nan,jin nan zhen,金南,金南镇', 32.9552600, 119.0391600, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17358, 'Jinli', 'Jinli', 'Chin-li,Jinli,Jinli Zhen,jin li,jin li zhen,金利,金利镇', 23.0786100, 112.7773900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17359, 'Jinkou', 'Jinkou', 'Chin-k''ou,Chin-k’ou,Jinkou,Jinkou Jiedao,Jinkou Zhen,Kin Kow,King Kau,Wu-ch''ang,Wu-ch''ang-hsien,Wu-ch’ang,Wu-ch’ang-hsien,jin kou,jin kou jie dao,金口,金口街道', 30.3400800, 114.1298900, 'CN', '2015-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17360, 'Jinjing', 'Jinjing', 'Chin-ching,Jinjing,Kintsing', 24.5750000, 118.5972200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17361, 'Jinjiang', 'Jinjiang', 'An-jen,Anjenhsien,Chin-chiang,Chin-chiang-chen,Jinjiang,Jinjiang Zhen,Yu-chiang,Yu-chiang-hsien,Yu-chiang-hsien-ch''eng,Yukiang,Yü-chiang,Yü-chiang-hsien,Yü-chiang-hsien-ch’eng,jin jiang,jin jiang zhen,锦江,锦江镇', 28.4005100, 116.8998300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17362, 'Jinjiang', 'Jinjiang', 'Ch''eng-mai New City,Ch''eng-mai-hsien,Chengmai,Chengmai Xian,Chin-chiang,Chin-chiang-chen,Chin-chiang-shih,Ching-mae,Chinkiang,Ch’eng-mai New City,Ch’eng-mai-hsien,Fa Hi,Jinjiang,Kimkang,Teng-mai-hsien,Tsingmai,Tsingmai-hsien,cheng mai xian,jin jiang,澄迈县,金江', 19.7287800, 110.0085100, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17363, 'Jinjiahe', 'Jinjiahe', 'Chin-chia-ho,Jinjiahe,Jinjiahe Zhen,jin jia he,jin jia he zhen,金家河,金家河镇', 33.3409700, 105.9670300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17364, 'Jinji', 'Jinji', 'Chin-chi,Chin-chia-chi,Jinji,Jinji Zhen,jin ji,jin ji zhen,金集,金集镇', 32.5582300, 119.0673800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17365, 'Jinji', 'Jinji', 'Chin-chi,Chin-chi-hsu,Chin-chi-hsü,Jinji', 23.2280600, 110.8261100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17366, 'Jinji', 'Jinji', 'Jinji,Jinji Zhen,jin ji,jin ji zhen,金鸡,金鸡镇', 22.1666700, 112.4833300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17367, 'Jining', 'Jining', 'Ca-ning,Che-leng-chhi,Chi-ning,Chi-ning-hsien,Chi-ning-shih,Chè-lêng-chhī,Csining,Czinin,Cá̤-nìng,Gjining,JNG,Jining,Te Ninh,Ti-ning,Tsi-ning-hsien,Tsining,Tế Ninh,gynyng,ji ning,ji ning shi,jining si,jnyng,jynyng,Ĝjining,Ťi-ning,Цзинин,גינינג,جنینگ,جینینگ,济宁市,済寧市,濟寧,지닝 시', 35.4050000, 116.5813900, 'CN', '2013-04-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17368, 'Jinhui', 'Jinhui', 'Chin-hui-ch''iao,Chin-hui-ch’iao,Jinhui,Jinhuiqiao,jin hui,金汇', 30.9897300, 121.4925100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17369, 'Jinhua', 'Jinhua', 'Chin-hua,Chin-hua-hsien,Chin-hua-hsien-ch''eng,Chin-hua-hsien-ch’eng,Chin-hua-shih,Czin''khua,Ging-hua,Gĭng-huà,Jinhua,Jinhua Shi,Kim Hoa,Kim-fa-su,Kim-hoa-chhi,Kim-hoâ-chhī,Kinhwa,Kinhwa-hsien,Kinhwafu,Kîm-fà-sṳ,Tin-chua,jin hua,jin hua shi,jin hua xian,jinhwa si,jynhwa,Ťin-chua,Цзиньхуа,جنہوا,جينهوا,جینهوا,金华,金华市,金華,金華市,金華縣,진화 시', 29.1067800, 119.6442100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17370, 'Jinhe', 'Jinhe', 'Chin-ho,Chin-ho-chen,Jinhe,Ma-yang,Ma-yang-hsien', 27.7169400, 109.6047200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17371, 'Jinhe', 'Jinhe', 'Chin-ho,Jinhe,Jinhe Zhen,jin he,jin he zhen,锦和,锦和镇', 20.5707900, 110.4108300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17372, 'Jingzhou', 'Jingzhou', 'Chiang-ling,Chiang-ling-hsien,Ching-chou,Chingchou-fu,Czinchzhou,Dzindzhou,Ging-ciu,Gĭng-ciŭ,Jiangling,Jingtsjou,Jingzhou,Keng-chiu-chhi,Keng-chiu-chhī,Kiangling,Kiangling-hsien,Kingchow,Kingchowfu,Kingling,Kinh Chau,Kinh Châu,SHS,Ting-cou,jing zhou,jing zhou shi,jingjeou si,jngzhww,jyangzhw,Ťing-čou,Дзинджоу,Цзинчжоу,جنگژوو,جیانگژو,荆州市,荊州,荊州市,징저우 시', 30.3502800, 112.1902800, 'CN', '2014-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17373, 'Jingzhou', 'Jingzhou', 'Jingzhou,Jingzhou Zhen,Qingzhou Zhen,jing zhou,jing zhou zhen,汫洲,汫洲镇', 23.6328500, 116.9318400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17374, 'Wulan', 'Wulan', 'Ching-yuan,Ching-yuan-hsien,Ching-yüan,Ching-yüan-hsien,Hsin-ch''eng,Hsin-ch’eng,Jingyuan,Jingyuan Chengguanzhen,Jingyuan Xian,Tszin-yuan'',Tszin-yuan’,Wulan,jing yuan cheng guan zhen,jing yuan xian,wu lan,乌兰,靖远县,靖远城关镇', 36.5654100, 104.6840100, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17375, 'Xiangshui', 'Xiangshui', 'Ching-yuan,Ching-yuan-hsien-hui-tsu-tzu-chih-ch''u,Ching-yuan-hsien-hui-tsu-tzu-chih-ch’ü,Ching-yuan-hui-tsu-tzu-chih-hsien,Ching-yüan,Ching-yüan-hui-tsu-tzu-chih-hsien,Hsien-ch''eng,Hsien-ch’eng,Hua-p''ing-tsch''uan-t''ing,Hua-p’ing-tsch’uan-t’ing,Huaping,Jingyuan,Jingyuan Xian,Khuapin,Xiangshui,Xiangshui Zhen,hua ping,jing yuan,jing yuan xian,xiang shui,xiang shui zhen,化平,泾源,泾源县,香水,香水镇', 35.4769500, 106.3311200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17376, 'Jingyao', 'Jingyao', 'Ching-yao,Ching-yao-chen,Jingyao,Jingyao Zhen,jing yao,荆姚', 34.8454000, 109.4441000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17377, 'Jingyang', 'Jingyang', 'Ching-yang,Jingyang,Zhenba Xian,jing yang,zhen ba xian,泾洋,镇巴县', 32.5166700, 107.8833300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17378, 'Jingyang', 'Jingyang', 'Ching-te,Ching-te-hsien,Jingde,Jingyang,Tsingteh,Tsingtehhsien,jing yang,旌阳', 30.2919400, 118.5425000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17379, 'Yancheng', 'Yancheng', 'Ching-yen,Ching-yen-hsien,Jingyan,Tsingyuan,Tsingyuan-hsien,Tsingyüan,Tsingyüan-hsien,Yancheng,yan cheng,研城', 29.6506800, 104.0672300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17380, 'Tianchang', 'Tianchang', 'Ching-ching,Ching-hsing,Ching-hsing-hsien,Ching-nan,Chiu-ching-hsing,Jingnan,Jingxing,Jiujingxing,Tianchang,Tianchang Zhen,Tsingsinghsien', 37.9980600, 114.0155600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17381, 'Xiluodu', 'Xiluodu', 'Ching-kuei,Ching-ti,Ching-ti-pa,Jingxin,Kingti,Tsingti,Tsingtipa,Xiluodu,Yongshan,Yongshan Xian,Yung-shan,xi luo du,yong shan xian,永善县,溪落渡', 28.2442500, 103.6384900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17382, 'Jingxin', 'Jingxin', 'Jingxin,Jingxin Zhen,jing xin,jing xin zhen,径心,径心镇', 24.2284100, 115.9335400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17383, 'Jingzhou', 'Jingzhou', 'Ching,Ching-chou,Ching-hsien,Ching-hsien-ch''eng-kuan,Ching-hsien-ch’eng-kuan,Jingxian,Jingzhou,Kingchow,Kinghsien,Tszinsyan'',Tszinsyan’,jing zhou,景州', 37.6886800, 116.2595800, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17384, 'Jingchuan', 'Jingchuan', 'Ching,Ching-hsien,Jingchuan,Jingxian,Kinghsien,jing chuan,泾川', 30.6891600, 118.4043100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17385, 'Jingxi', 'Jingxi', 'Ching-hsi,Jingxi,Jingxi Jiedao,jing xi,jing xi jie dao,荆西,荆西街道', 26.1945400, 117.5452600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17386, 'Jingu', 'Jingu', 'Jingu,Jingu Zhen,jin gu,jin gu zhen,金谷,金谷镇', 25.1725000, 118.1158300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17387, 'Jingtou', 'Jingtou', 'Jingtou,Jingtou Zhen,jing tou,jing tou zhen,迳头,迳头镇', 23.9697700, 113.6774800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17388, 'Jingping', 'Jingping', 'Ching-p''ing,Ching-p''ing-chen,Ching-p’ing,Ching-p’ing-chen,Jingping,Jingping Zhen,Pinglu Qu,Tsingpingchen,Tszin''pin,Tszin’pin,jing ping,jing ping zhen,ping lu qu,井坪,井坪镇,平鲁区', 39.5200000, 112.2838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17389, 'Jingning Chengguanzhen', 'Jingning Chengguanzhen', 'Ching-ning,Ching-ning-hsien,Jingning,Jingning Chengguanzhen,Tszinnin,jing ning,jing ning cheng guan zhen,静宁,静宁城关镇', 35.5203600, 105.7230100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17390, 'Jingnao', 'Jingnao', 'Jingnao,Jingnao Xiang,jing nao,jing nao xiang,迳脑,迳脑乡', 25.0060000, 115.0266700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17391, 'Jingmen', 'Jingmen', 'Ching-men,Ching-men-hsien,Czinmehn'',Ging-muong,Gĭng-muòng,Jingmen,Keng-bun-chhi,Keng-bûn-chhī,King monn,King mönn,King-men-chow,Kingmen,Kingmen-hsien,Kinh Mon,Kinh Môn,Ting-men,jing men,jing men shi,jingmeon si,jngmyn,Ťing-men,Цзинмэнь,جنگمین,جىڭمېن شەھىرى,荆门市,荊門,荊門市,징먼 시', 31.0336100, 112.2047200, 'CN', '2011-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17392, 'Jingmao', 'Jingmao', 'Ching-mao,Ching-mao-ts''un,Ching-mao-ts’un,Jingmao,Jingmao Xiang,jing mao,jing mao xiang,景毛,景毛乡', 35.8818300, 111.3558600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17393, 'Jinglou', 'Jinglou', 'Jinglou,Jinglou Zhen,jing lou,jing lou zhen,经楼,经楼镇', 28.1001200, 115.4260700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17394, 'Jinglongqiao', 'Jinglongqiao', 'Jinglongqiao,Jinglongqiao Xiang,jing long qiao,jing long qiao xiang,景龙桥,景龙桥乡', 29.3031600, 111.0969800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17395, 'Jingling', 'Jingling', 'Jingling,T''ien-men,T''ien-men-hsien,Tianmen,T’ien-men,T’ien-men-hsien', 30.6500000, 113.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17396, 'Jingling', 'Jingling', 'Jingling,Jingling Zhen,jing ling,jing ling zhen,镜岭,镜岭镇', 29.3734300, 120.7828900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17397, 'Echeng', 'Echeng', 'Ching-le,Ching-lo,Ching-lo-hsien,Dzinle,Echeng,Echeng Zhen,Jingle,Jingle Xian,Tsinglo,Tsinglohsien,e cheng,e cheng zhen,jing le xian,静乐县,鹅城,鹅城镇', 38.3744400, 111.9716700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17398, 'Jingkou', 'Jingkou', 'Ching-k''ou,Ching-k’ou,Jingkou,Jingkou Zhen,jing kou,jing kou zhen,迳口,迳口镇', 23.5077800, 112.8250000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17399, 'Jingjiang', 'Jingjiang', 'Ching-chiang-tien,Ching-chiang-tien-shih,Jingjiang,Jingjiang Zhen,Jingjiangdian,jing jiang,jing jiang zhen,靖江,靖江镇', 30.2334400, 120.4623600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17400, 'Jingcheng', 'Jingcheng', 'Ching-ch''eng-chen,Ching-chiang,Ching-chiang-hsien,Ching-ch’eng-chen,Jingcheng,Jingcheng Zhen,Jingjiang,jing cheng,jing cheng zhen,jing jiang,靖城,靖城镇,靖江', 32.0141700, 120.2625000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17401, 'Jinghai', 'Jinghai', 'Ching-hai,Ching-hai-ch''eng-kuan,Ching-hai-ch’eng-kuan,Ching-hai-hsien,Jinghai,Jinghai Xian,Jinghai Zhen,Tsing hai,Tsinghaihsien,jing hai,jing hai xian,jing hai zhen,静海,静海县,静海镇', 38.9337300, 116.9269900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17402, 'Jinghai', 'Jinghai', 'Ching-hai,Jinghai,Jinghai Zhen,Tsinghai,jing hai,jing hai zhen,靖海,靖海镇', 23.0108500, 116.5276400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17403, 'Jingguan', 'Jingguan', 'Ching-kuan-ch''ang,Ching-kuan-chen,Ching-kuan-ch’ang,Jingguan,Jingguan Zhen,jing guan,jing guan zhen,静观,静观镇', 29.8954500, 106.5639000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17404, 'Jinggongqiao', 'Jinggongqiao', 'Ching-kung-ch''iao,Ching-kung-ch’iao,Jinggongqiao,Jinggongqiao Zhen,jing gong qiao,jing gong qiao zhen,经公桥,经公桥镇', 29.7484500, 117.2134000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17405, 'Jinggan', 'Jinggan', 'Ching-yang,Ching-yang-hsien,Ching-yang-hsien-ch''eng,Ching-yang-hsien-ch’eng,Jinggan,Jinggan Zhen,Jingyang,Kingyang,Tszin''yan,Tszin’yan,jing gan,jing gan zhen,jing yang,泾干,泾干镇,泾阳', 34.5300000, 108.8341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17406, 'Jingdezhen', 'Jingdezhen', 'Ching-te-chen,Ching-te-chen-shih,Czindehchzhehn'',Fou-liang,Fou-liang-hsien,Fowliang,Fowliang-hsien,JDZ,Jingdezhen,Jingdezhen Shi,Kingtechen,Kingteh,Kingtehchen,Kingtehchin,jing de zhen,jing de zhen shi,Цзиндэчжэнь,景徳鎮,景德镇,景德镇市', 29.2947000, 117.2078900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17407, 'Jingchuan Chengguanzhen', 'Jingchuan Chengguanzhen', 'Ching-ch''uan,Ching-chou,Ching-ch’uan,Jingchuan,Jingchuan Chengguanzhen,Jingchuan Xian,Tszinchuan'',Tszinchuan’,jing chuan cheng guan zhen,jing chuan xian,泾川县,泾川城关镇', 35.3319400, 107.3611100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17408, 'Zhangping', 'Zhangping', 'Chang-p''ing,Chang-p''ing-hsien,Chang-p''ing-hsien-ch''eng,Chang-p’ing,Chang-p’ing-hsien,Chang-p’ing-hsien-ch’eng,Jingcheng,Qingcheng Jiedao,Zhangping,Zhangping Shi,qing cheng jie dao,zhang ping,zhang ping shi,漳平,漳平市,青城街道', 25.2997200, 117.4150000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17409, 'Jing’an', 'Jing''an', 'Jing''an,Jing''an Xiang,Jing’an,Jing’an Xiang,jing an,jing an xiang,靖安,靖安乡', 39.1043800, 100.4109400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17410, 'Jing’an', 'Jing''an', 'Ching-an,Doumen,Jing''an,Jing''an Zhen,Jing’an,Jing’an Zhen,Tou-men,Tou-men-hsu,Tou-men-hsü,Tou-men-t''u-ch''eng,Tou-men-t’u-ch’eng,Towmoon,jing an,jing an zhen,井岸,井岸镇', 22.2107200, 113.2921800, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17411, 'Jinfeng', 'Jinfeng', 'Chin-feng-chen,Jinfeng,Jinfeng Zhen,jin feng,jin feng zhen,锦丰,锦丰镇', 31.9616500, 120.6470900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17412, 'Jinfeng', 'Jinfeng', 'Chin-feng,Chin-feng-chen,Jinfeng,Jinfeng Zhen,jin feng,jin feng zhen,金峰,金峰镇', 25.9787100, 119.6230400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17413, 'Jin’e', 'Jin''e', 'Jin''e,Jin’e,Longchang,Lung-ch''ang,Lung-ch''ang-hsien,Lung-ch’ang,Lung-ch’ang-hsien,jin e,金鹅', 29.3431300, 105.2844300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17414, 'Jindui', 'Jindui', 'Chin-tui-ch''eng,Chin-tui-ch’eng,Jindui,Jindui Zhen,Jinduicheng,jin dui,金堆', 34.3340200, 109.9674700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17415, 'Jindu', 'Jindu', 'Jindu,Jindu Zhen,jin du,jin du zhen,金渡,金渡镇', 23.0505300, 112.5150100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17416, 'Jindou', 'Jindou', 'Jindou,Jindou Zhen,Wumei,jin dou,jin dou zhen,wu mei,五美,锦斗,锦斗镇', 25.4323800, 118.1017000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17417, 'Jindong', 'Jindong', 'Jindong,Jintong Zhen,jin dong,jin dong zhen,金垌,金垌镇', 22.4624500, 110.7807800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17418, 'Jincun', 'Jincun', 'Chin-ts''un,Chin-ts’un,Jincun,Jincun Zhen,jin cun,jin cun zhen,金村,金村镇', 35.5019400, 112.9058300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17419, 'Jincun', 'Jincun', 'Jincun,jin cun,靳村', 33.9512500, 112.2622300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17420, 'Jinchang', 'Jinchang', 'Baijiazui,Czin''chan,Ging-chiong,Gĭng-chiŏng,JIC,Jinchang,Jinchang Shi,Jinchuan,Jinchuanzhen,Kim Xuong,Kim Xương,Kim-chhiong-chhi,Kim-chhiong-chhī,Tin-cchang,jin chang,jin chang shi,jinchang si,jnchang,Ťin-čchang,Цзиньчан,Ցզինչան,جنچانگ,金昌,金昌市,진창 시', 38.5006200, 102.1937900, 'CN', '2014-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17421, 'Jinchuan', 'Jinchuan', 'Chin-ch''uan,Chin-ch’uan,Ching-hua,Ching-hua-hsien,Jinchuan,Jinchuan Xian,Quqen,Quqên,Sui-ching,Sui-ching-t''un,Sui-ching-t’un,Suytszin,Ta-chin,Ta-chin-hsien,Tszinkhua,jin chuan,jin chuan xian,金川,金川县', 31.4755100, 102.0588400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17422, 'Jinchuan', 'Jinchuan', 'Hsin-kan,Hsin-kan-hsien,Hsin-kan-hsien-ch''eng,Hsin-kan-hsien-ch’eng,Jinchuan,Jinchuan Zhen,Sinkan,Sinkan-hsien,Xingan,Xingan Xian,jin chuan,jin chuan zhen,xin gan xian,新干县,金川,金川镇', 27.7603600, 115.3885000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17423, 'Jincheng', 'Jincheng', 'Ceng-siang,Chin-ch''eng,Chin-ch''eng-hsien,Chin-ch’eng,Chin-ch’eng-hsien,Chìn-siâⁿ-chhī,Czin''chehn,Céng-siàng,Dzinchun,Jincheng,Jincheng Shi,Tan Thanh,Tse-chou,Tseh-chow-fu,Tsehchow,Tsincheng,Tsinchenghsien,Tấn Thành,jin cheng,jin cheng shi,jincheong si,jnchyng,jynchn,Ђинченг,Дзинчън,Цзиньчэн,جنچینگ,جینچن,晉城,晋城,晋城市,진청 시', 35.5022200, 112.8327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17424, 'Jincheng', 'Jincheng', 'Hsi-ch''ung,Hsi-ch''ung-hsien,Hsi-ch’ung,Hsi-ch’ung-hsien,Jincheng,Sichun,Sichung,Sichunghsien,Xichong,jin cheng,晋城', 30.9971200, 105.8819100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17425, 'Jincheng', 'Jincheng', 'Jincheng,Lei-po,Lei-po-hsien,Leibo,Leipoting,jin cheng,锦城', 28.2664800, 103.5683800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17426, 'Jincheng', 'Jincheng', 'Jincheng,Wu-ting,Wu-ting-hsien,Wuding,Wutingchow,jin cheng,近城', 25.5014700, 102.4005800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17427, 'Jincheng', 'Jincheng', 'Chin-ch''eng,Chin-ch’eng,Chin-ning,Jincheng,Jincheng Zhen,jin cheng,jin cheng zhen,晋城,晋城镇', 24.7022200, 102.7441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17428, 'Jinbi', 'Jinbi', 'Chin-pi,Chin-pi-chen,Chin-pi-chieh,Jinbi,Ta-yao,Ta-yao-hsien,jin bi,金碧', 25.7085500, 101.3367900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17429, 'Jinan', 'Jinan', 'Ca-nang,Che-lam-chhi,Chi-nam-su,Chi-nan,Chi-nan-shih,Chi-nàm-sṳ,Chè-lâm-chhī,Cijnanz,Cinanum,Csinan,Czinan'',Cá̤-nàng,Dzinan,Dzinanas,Dzjinana,Dzjinaņa,Ginano,Gorad Czinan'',Jinan,Jinan Shi,Li-ch''eng,Li-ch’eng,Szinan,TNA,Te Nam,Ti-nan,Tsi-nan-fu,Tsinah,Tsinan,Tzinan,Tế Nam,Zhinan'',ci hnan,cinana,gynʼn,ji nan,ji nan shi,jinan si,jinana,jynan,Ĝinano,Ťi-nan,Τζινάν,Ђинан,Горад Цзінань,Дзинан,Жинань,Цзинань,Цзінань,Ցզինան,גינאן,جىنەن شەھىرى,جينان,جینان,जीनान,ਚੀਨਾਨ,จี่หนาน,ཅི་ནན།,ကျီနန်မြို့,济南,济南市,済南,済南市,濟南,濟南市,지난 시', 36.6683300, 116.9972200, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17430, 'Jin’an', 'Jin''an', 'Jin''an,Jin’an,Songpan,Sung-p''an,Sung-p''an-hsien,Sung-p’an,Sung-p’an-hsien,Sungqu,jin an,进安', 32.6394100, 103.5968300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17431, 'Jimo', 'Jimo', 'Chi-mo,Chi-mo-hsien,Jimo,Tsimo,Tsimohsien,ji mo shi,即墨市', 36.3897200, 120.4622200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17432, 'Jilong', 'Jilong', 'Chi-lung,Chi-lung-hsu,Chi-lung-hsü,Jilong,Jilong Zhen,ji long,ji long zhen,吉隆,吉隆镇', 22.8000000, 114.9166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17433, 'Daqinglu', 'Daqinglu', 'Daqinglu,Jiliqu,da qing lu,大庆路', 34.8992700, 112.5831400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17434, 'Jijiazhuang', 'Jijiazhuang', 'Chi-chia-chuang,Jijiazhuang,Jijiazhuang Xiang,ji jia zhuang,ji jia zhuang xiang,吉家庄,吉家庄乡', 39.8489100, 113.4541400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17435, 'Jijiang', 'Jijiang', 'Chiang-chin,Chiang-ching,Chiang-ching-ch''eng,Chiang-ching-ch’eng,Chiang-ching-hsien,Jiangjin Qu,Jijiang,Jijiang Jiedao,Kiangtsin,Kiangtsing-hsien,ji jiang,ji jiang jie dao,jiang jin qu,几江,几江街道,江津区', 29.2899300, 106.2500100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17436, 'Jijia', 'Jijia', 'Chi-chia,Chi-chia-shih,Jijia,Jijia Zhen,ji jia,ji jia zhen,纪家,纪家镇', 20.9531100, 109.7947700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17437, 'Jiedu', 'Jiedu', 'Chieh-chu-tu,Jiedu,Jiedu Zhen,Jiezhudu,jie du,jie du zhen,接渡,接渡镇', 28.9500000, 117.1666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17438, 'Jiexiu', 'Jiexiu', 'Chieh-hsien,Chieh-hsiu,Chieh-hsiu-hsien,Czesju,Gioi Huu,Giới Hưu,Jiexiu,Jiexiu Shi,Kiehsiu,Kiehsuihsien,jesyu si,jie xiu,jie xiu shi,jyyshyw,Цзесю,جیئشیو,介休,介休市,제슈 시', 37.0244400, 111.9125000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17439, 'Jietou', 'Jietou', 'Chiatou,Chieh-t''ou,Chieh-t''ou-chen,Chieh-t’ou,Chieh-t’ou-chen,Jietou,Jietou Zhen,jie tou,jie tou zhen,街头,街头镇', 29.1158800, 120.8037600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17440, 'Jieting', 'Jieting', 'Jieting,Jieting Zhen,jie ting,jie ting zhen,街亭,街亭镇', 29.6442800, 120.2710800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17441, 'Jieshui', 'Jieshui', 'Jieshui,Jieshui Xiang,jie shui,jie shui xiang,界水,界水乡', 27.7850300, 114.7594500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17442, 'Jieshou', 'Jieshou', 'Chieh-shou,Chieh-shou-chen,Chieh-shou-chi,Chieh-shou-shih,Chiehshow,Shou-t''ai,jie shou,jie shou shi,界首,界首市', 33.2633800, 115.3610800, 'CN', '2009-08-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17443, 'Jieshou', 'Jieshou', 'Chieh-shou,Chieh-shou-shih,Jieshou,Jieshou Zhen,Maotangxia,jie shou,jie shou zhen,mao tang xia,毛塘下,界首,界首镇', 26.6066600, 113.4060700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17444, 'Jieshi', 'Jieshi', 'Chieh-shih,Chieh-shih-ch''eng,Chieh-shih-ch’eng,Jieshi,Jieshi Zhen,Kitchioh,jie shi,jie shi zhen,碣石,碣石镇', 22.8102700, 115.8305800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17445, 'Jiesheng', 'Jiesheng', 'Chiapcheng,Chieh-sheng,Chieh-sheng-so-ch''eng,Chieh-sheng-so-ch''eng-ko,Chieh-sheng-so-ch’eng,Chieh-sheng-so-ch’eng-ko,Jiesheng,Jiesheng Zhen,Siacheng,jie sheng,jie sheng zhen,捷胜,捷胜镇', 22.7180900, 115.4475600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17446, 'Jielong', 'Jielong', 'Chieh-lung,Chieh-lung-ch''ang,Chieh-lung-ch’ang,Jielong,Jielong Zhen,Jielongchang,jie long,jie long zhen,接龙,接龙镇', 29.2494600, 106.7766300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17447, 'Xinmen', 'Xinmen', 'Chieh-k''ou,Chieh-k’ou,Chiehkouchen,Jiekou,Jiekou Zhen,Kaikow,Kaikowchen,Xinmen,jie kou,jie kou zhen,xin men,新门,街口,街口镇', 29.7518400, 118.7237800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17448, 'Jiekou', 'Jiekou', 'Ch''ung-fa,Chieh-k''ou,Chieh-k''ou-chen,Chieh-k’ou,Chieh-k’ou-chen,Ch’ung-fa,Conghua,Jiekou,Jiekou Jiedao,Ts''ung-hua,Ts''ung-hua-hsien,Tsung-fa-hsien,Tsungfa,Ts’ung-hua,Ts’ung-hua-hsien,cong hua,jie kou,jie kou jie dao,从化,街口,街口街道', 23.5499200, 113.5809900, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17449, 'Jiekeng', 'Jiekeng', 'Chieh-k''eng,Chieh-k’eng,Jiekeng,Jiekeng Xiang,jie keng,jie keng xiang,界坑,界坑乡', 28.4474700, 120.4042300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17450, 'Jiehu', 'Jiehu', 'Chieh-hu,Chieh-hu-chi,I-nan,Jiehu,Yinan', 35.5427800, 118.4550000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17451, 'Jieheshi', 'Jieheshi', 'Chieh-ho-shih,Jieheshi,Jieheshi Zhen,jie he shi,jie he shi zhen,街河市,街河市镇', 30.0134300, 111.7146400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17452, 'Jieguanting', 'Jieguanting', 'Chieh-kuan-t''ing,Chieh-kuan-t’ing,Jieguanting,Jieguanting Zhen,Tszeguan''tin,Tszeguan’tin,jie guan ting,jie guan ting zhen,接官亭,接官亭镇', 33.2680600, 106.2519400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17453, 'Jiefangyan', 'Jiefangyan', 'Jiefangyan,Jiefangyan Xiang,jie fang yan,jie fang yan xiang,解放岩,解放岩乡', 28.1289600, 109.7383900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17454, 'Xinjiebu', 'Xinjiebu', 'Chieh-pu,Jiebu,Xinjiebu,Xinjiebu Xiang,xin jie bu,xin jie bu xiang,新界埠,新界埠乡', 28.2259800, 115.0574000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17455, 'Jiebu', 'Jiebu', 'Chieh-pu,Jiebu,Jiebu Xiang,jie bu,jie bu xiang,界埠,界埠乡', 27.7693900, 115.3785700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17456, 'Xinji', 'Xinji', 'Jicun,Xinji,ji cun,xin ji,新济,济村', 26.3380800, 116.5551500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17457, 'Jibu', 'Jibu', 'Jibu,Jibu Zhen,ji bu,ji bu zhen,吉埠,吉埠镇', 26.0210300, 115.1569400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17458, 'Jiazi', 'Jiazi', 'Chia-tzu,Jiazi,Jiazi Zhen,Kapchi,Kapohi,jia zi,jia zi zhen,甲子,甲子镇', 22.8793200, 116.0731800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17459, 'Jiazhuyuan', 'Jiazhuyuan', 'Jiazhuyuan,Jiazhuyuan Zhen,jia zhu yuan,jia zhu yuan zhen,夹竹园,夹竹园镇', 29.9913000, 112.1105700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17460, 'Jiazhuang', 'Jiazhuang', 'Chia-chuang,Jiazhuang,Jiazhuang Xiang,gu zhuang,gu zhuang xiang,贾庄,贾庄乡', 39.2421500, 112.5326700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17461, 'Jiazhuang', 'Jiazhuang', 'Chia-chuang,Chia-chuang-chen,Jiazhuang,Jiazhuang Zhen,gu zhuang,gu zhuang zhen,贾庄,贾庄镇', 38.0991900, 114.0385800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17462, 'Jiaxing', 'Jiaxing', 'Chia-hsing,Chia-hsing-hsien,Chia-hsing-hsien-ch''eng,Chia-hsing-hsien-ch’eng,Chiahsing-Fu,Czjasin,Dziasingas,Dzjasin,Ga-hing,Gia Hung,Gia Hưng,Gă-hĭng,JXS,Jiaxing,Ka-heng-chhi,Ka-heng-chhī,Ka-shing-fu,Kashing,Kashing-hsien,Tia-sing,jasing si,jia xing,jia xing shi,jyashng,jyshang,Ťia-sing,Ђасинг,Дзясин,Цзясин,Цзясін,جياشىڭ شەھىرى,جیاشنگ,جیشانگ,嘉兴,嘉兴市,嘉興,嘉興市,자싱 시', 30.7522000, 120.7500000, 'CN', '2012-11-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17463, 'Jiaxiang', 'Jiaxiang', 'Chia-hsiang,Chia-hsiang-hsien,Chia-hsing,Jiaxiang,Jiaxiang Zhen,Kiasiang,Tsyasyan,jia xiang,jia xiang zhen,嘉祥,嘉祥镇', 35.3960600, 116.3480000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17464, 'Jiaxian', 'Jiaxian', 'Chengguan Zhen,Chia,Chia-hsien,Fu-ch''eng,Fu-ch’eng,Jia Xian,Jia Xian Chengguanzhen,Kiahsien,Tszyasyan,jia xian,jia xian cheng guan zhen,郏县,郏县城关镇', 33.9683300, 113.2080600, 'CN', '2016-11-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17465, 'Jiasi', 'Jiasi', 'Chia-ssu,Chia-ssu-ch''iao,Chia-ssu-ch’iao,Jiasi,Jiasi Zhen,Jiasichang,Jiasiqiao,gu si,gu si zhen,贾嗣,贾嗣镇', 29.1156900, 106.4469100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17466, 'Jiashi', 'Jiashi', 'Jiashi,Jiashi Xiang,gu shi,gu shi xiang,贾市,贾市乡', 28.9714700, 109.4019000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17467, 'Jiaqu', 'Jiaqu', 'Chia-ch''u,Chia-ch''u-chen,Chia-ch’ü,Chia-ch’ü-chen,Jiaqu,gu qu,贾曲', 34.9177500, 109.5418900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17468, 'Jiaqiao', 'Jiaqiao', 'Jiaqiao,Jiaqiao Xiang,Jiaqiao Zhen,jia qiao,jia qiao xiang,jia qiao zhen,架桥,架桥乡,架桥镇', 29.1669100, 111.4974900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17469, 'Jiapu', 'Jiapu', 'Chia-p''u,Chia-p’u,Jiapu,Jiapu Zhen,jia pu,jia pu zhen,夹浦,夹浦镇', 31.1045900, 119.9387900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17470, 'Jiaozuo', 'Jiaozuo', 'Chiao-tso,Chiao-tso-chen,Chiao-tso-kung-k''uang-ch''u,Chiao-tso-kung-k’uang-ch’ü,Chiao-tso-shih,Chiau-chok-chhi,Chiau-chok-chhī,Cieu-cauk,Ciĕu-cáuk,Czjaoczo,Gjaoguo,Jiaozuo,Tiao-cuo,Tieu Tac,Tiêu Tác,Tsiaotso,Tszyaotszochzhen,jaojjwo si,jiao zuo,jiao zuo shi,jyawzww,zhyawzw,Ĝjaoĝuo,Ťiao-cuo,Ђаоцуо,Цзяоцзо,جیاوزوو,ژیاوزو,焦作,焦作市,자오쭤 시', 35.2397200, 113.2330600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17471, 'Jiaoziya', 'Jiaoziya', 'Chiao-tzu-wu,Chiao-tzu-ya,Jiaoziya,Jiaoziya Zhen,jiao zi ya,jiao zi ya zhen,教字垭,教字垭镇', 29.2886100, 110.3222200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17472, 'Jiaoyuan', 'Jiaoyuan', 'Chiao-yuan,Chiao-yüan,Jiaoyuan,Jiaoyuan Zhen,jiao yuan,jiao yuan zhen,椒园,椒园镇', 30.0209300, 109.4416900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17473, 'Jiaoyang', 'Jiaoyang', 'Chiao-yang,Jiaoyang,Jiaoyang Xiang,jiao yang,jiao yang xiang,蛟洋,蛟洋乡', 25.2278900, 116.7365600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17474, 'Jiaoxie', 'Jiaoxie', 'Chiao-hsieh,Chiao-hsieh-chen,Jiaoxie,Jiaoxie Zhen,jiao xie,交斜', 34.6651400, 109.6859600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17475, 'Jiaowei', 'Jiaowei', 'Chiao-wei,Jiaowei,Jiaowei Zhen,jiao wei,jiao wei zhen,郊尾,郊尾镇', 25.3065100, 118.8303300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17476, 'Liuheng', 'Liuheng', 'Chiao-t''ou,Chiao-t’ou,Jiaotou,Jiaotouzhen,Liuheng,Liuheng Zhen,jiao tou zhen,liu heng,liu heng zhen,六横,六横镇,峧头镇', 29.7448100, 122.1089600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17477, 'Jiaotang', 'Jiaotang', 'Chiao-t''ang,Chiao-t’ang,Jiaotang,Jiaotang Zhen,jiao tang,jiao tang zhen,蛟塘,蛟塘镇', 29.3103300, 115.9243500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17478, 'Jiaotan', 'Jiaotan', 'Chiao-t''an,Chiao-t''un,Chiao-t’an,Chiao-t’un,Jiaotan,Jiaotan Zhen,jiao tan,jiao tan zhen,蛟潭,蛟潭镇', 29.5499900, 117.2121500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17479, 'Jiaoshi', 'Jiaoshi', 'Chiao-shih-pa,Jiaoshi,Jiaoshi Zhen,Jiaoshiba,jiao shi,jiao shi zhen,焦石,焦石镇', 29.7160700, 107.5976000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17480, 'Jiaoqiao', 'Jiaoqiao', 'Jiaoqiao,Jiaoqiao Zhen,jiao qiao,jiao qiao zhen,蛟桥,蛟桥镇', 28.7455300, 115.8587800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17481, 'Jiaoqi', 'Jiaoqi', 'Jiaoqi,Jiaoqi Zhen,jiao qi,jiao qi zhen,焦圻,焦圻镇', 29.6483300, 112.0819600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17482, 'Jiaocheng', 'Jiaocheng', 'Chen-p''ing,Chen-p’ing,Chiao-ch''eng,Chiao-ch''eng-chen,Chiao-ch’eng,Chiao-ch’eng-chen,Chiao-ling,Chiao-ling-hsien,Chiuling,Chiuling-hsien,Chuiling,Jiaocheng,Jiaocheng Zhen,Jiaoling,Jiaoling Xian,jiao cheng,jiao cheng zhen,jiao ling,jiao ling xian,蕉城,蕉城镇,蕉岭,蕉岭县', 24.6573200, 116.1670900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17483, 'Jiaokui', 'Jiaokui', 'I-liang,I-liang-hsien,Jiaokui,Yiliang,Yiliang-hsien,jiao kui,角奎', 27.5941400, 104.0047800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17484, 'Jiaokou', 'Jiaokou', 'Chiao-k''ou,Chiao-k''ou-chen,Chiao-k’ou,Chiao-k’ou-chen,Jiaokou,Jiaokou Zhen,jiao kou,交口', 34.5501600, 109.2968000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17485, 'Jiaogong', 'Jiaogong', 'Jiaogong,jiao gong,角弓', 33.5654700, 104.6463700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17486, 'Jiaodai', 'Jiaodai', 'Chiao-tai,Chiao-tai-chen,Jiaodai,Jiaodai Zhen,jiao dai,焦岱', 34.0594100, 109.2463900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17487, 'Jiaocun', 'Jiaocun', 'Chiao-ts''un,Chiao-ts’un,Jiaocun,Jiaocun Zhen,jiao cun,jiao cun zhen,焦村,焦村镇', 30.1919300, 118.0667800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17488, 'Tianning', 'Tianning', 'Chiao-ch''eng,Chiao-ch''eng-hsien,Chiao-ch’eng,Chiao-ch’eng-hsien,Jiaocheng,Jiaocheng Xian,Kiaochenghsien,Tianning,Tianning Zhen,Tszyaochen,jiao cheng xian,tian ning,tian ning zhen,交城县,天宁,天宁镇', 37.5472200, 112.1605300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17489, 'Jiaozhou', 'Jiaozhou', 'Chiao,Chiao-hsien,Jiaocheng,Jiaoxian,Jiaozhou,Kiaochow,Kiaohsien', 36.2838900, 120.0033300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17490, 'Ningde', 'Ningde', 'Jiaocheng,Ning-te,Ning-te-hsien,Ningde,Ningteh,Ningtehhsien,ning de,ning de shi,نىڭدې شەھىرى,宁德,宁德市', 26.6616700, 119.5227800, 'CN', '2017-05-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17491, 'Jiaoba', 'Jiaoba', 'Jiaoba,Jiaoba Xiang,jiao ba,jiao ba xiang,蕉坝,蕉坝乡', 28.8071100, 108.0909900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17492, 'Juzhen', 'Juzhen', 'Chien-chen,Chu-chen,Chü-chen,Jianzhen,Juzhen,Juzhen Zhen,ju zhen,ju zhen zhen,苴镇,苴镇镇', 32.4144500, 121.1953900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17493, 'Jiancheng', 'Jiancheng', 'Chien-chou,Chien-yang,Chien-yang-hsien,Jiancheng,Jianyang,Kienchow,Kienchow Nan,Kienyang-hsien,Tszyan''yan,Tszyan’yan,jian cheng,简城', 30.3909700, 104.5491200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17494, 'Jianxi', 'Jianxi', 'Jianxi,Jianxi Zhen,jian xi,jian xi zhen,建西,建西镇', 26.8147200, 117.9513200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17495, 'Jiantou', 'Jiantou', 'Jiantou,Jiantou Zhen,jian tou,jian tou zhen,涧头,涧头镇', 24.0514000, 114.7006000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17496, 'Jiantiao', 'Jiantiao', 'Chien-t''iao,Chien-t''iao-so,Chien-t''iao-so-ch''eng,Chien-t’iao,Chien-t’iao-so,Chien-t’iao-so-ch’eng,Jiantiao,Jiantiao Zhen,Kientiao,jian tiao,jian tiao zhen,健跳镇,键跳', 29.0438900, 121.6275000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17497, 'Jiantianjie', 'Jiantianjie', 'Chien-t''ien,Chien-t’ien,Jiantian,Jiantianjie,Jiantianjie Xiang,jian tian jie,jian tian jie xiang,枧田街,枧田街乡', 29.4230400, 116.9858200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17498, 'Lin’an', 'Lin''an', 'Chien-shui,Chien-shui-hsien,Jianshui,Kienshui,Kienshui-hsien,Lin''an,Lin''an Zhen,Linanfu,Lin’an,Lin’an Zhen,lin an,临安', 23.6025500, 102.8309200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17499, 'Jianshe', 'Jianshe', 'Chien-she,Jianshe,Jianshe Zhen,jian she,jian she zhen,建设,建设镇', 25.9814300, 117.7823600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17500, 'Jianshan', 'Jianshan', 'Jianshan,Jianshan Zhen,Pipa Dadian,jian shan,jian shan zhen,pi pa da dian,尖山,尖山镇,枇杷大店', 31.4339600, 108.8953300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17501, 'Jianshan', 'Jianshan', 'Chien-shan,Chien-shan-ssu,Jianshan,Jianshan Xiang,jian shan,jian shan xiang,尖山,尖山乡', 29.7028500, 108.9989500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17502, 'Jianshan', 'Jianshan', 'Chien-shan,Jianshan,Jianshan Zhen,jian shan,jian shan zhen,尖山,尖山镇', 29.2249900, 120.7162300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17503, 'Jianshan', 'Jianshan', 'Jianshan,Jianshan Zhen,jian shan,jian shan zhen,建山,建山镇', 28.1304200, 115.1903500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17504, 'Jianqiao', 'Jianqiao', 'Chien-ch''iao,Chien-ch''iao-chen,Chien-ch’iao,Chien-ch’iao-chen,Jianqiao,Jianqiao Zhen,Kienkiao,jian qiao,jian qiao zhen,笕桥,笕桥镇', 30.3195500, 120.2151200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17505, 'Jian’ou', 'Jian''ou', 'Chien-ning,Chien-ou,Chien-ou-hsien,Chien-ou-hsien-ch''eng,Chien-ou-hsien-ch’eng,Jian''ou,Jian''ou Shi,Jian’ou,Jian’ou Shi,Kienning,Kienningfu,Kienow,Kienowhsien,Zhicheng,jian ou,jian ou shi,zhi cheng,建瓯,建瓯市,芝城', 27.0469400, 118.3252800, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17506, 'Jiannan', 'Jiannan', 'Chien-nan,Jiannan,Jiannan Zhen,jian nan,jian nan zhen,建南,建南镇', 30.4391900, 108.5339800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17507, 'Tongzilin', 'Tongzilin', 'Jiankang,Tongzilin,Yanbian,Yen-pien,Yen-pien-hsien,tong zi lin,桐子林', 26.7003900, 101.8513400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17508, 'Jianjun', 'Jianjun', 'Chien-chun,Chien-chun-chen,Chien-chün,Chien-chün-chen,Jianjun,Jianjun Zhen,Ku-tun,Yongshou,Yung-shou,Yung-shou-hsien,jian jun,jian jun zhen,yong shou,永寿,监军,监军镇', 34.6913900, 108.1397200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17509, 'Jianjiang', 'Jianjiang', 'Chien-chiang,Jianjiang', 26.5497200, 119.7550000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17510, 'Jiangzhou', 'Jiangzhou', 'Jiangzhou,Jiangzhou Zhen,jiang zhou,jiang zhou zhen,江洲,江洲镇', 29.7875900, 116.1201400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17511, 'Jiangzhang', 'Jiangzhang', 'Chiang-chang,Chiang-chang-chen,Jiangzhang,Jiangzhang Zhen,jiang zhang,jiang zhang zhen,绛帐,绛帐镇', 34.2597400, 107.9220400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17512, 'Jiangzao', 'Jiangzao', 'Jiangzao,Jiangzao Zhen,jiang zao,jiang zao zhen,姜灶,姜灶镇', 31.9966900, 121.0325000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17513, 'Xiaopu', 'Xiaopu', 'Chiang-yung,Jiangyong,Xiaopu,Xiaopuzhen,Yung-ming,Yung-ming-hsien,xiao pu,潇浦', 25.2391700, 111.3166400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17514, 'Jiangyin', 'Jiangyin', 'Jiangyin,Jiangyin Zhen,jiang yin,jiang yin zhen,江阴,江阴镇', 25.4602200, 119.3159800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17515, 'Jiangyi', 'Jiangyi', 'Chiang-i,Jiangyi,Jiangyi Zhen,jiang yi,jiang yi zhen,江益,江益镇', 29.2116200, 115.7726300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17516, 'Jiangyan', 'Jiangyan', 'Chiang-yen,Chiang-yen-chen,Jiangyan,Jiangyan Shi,Jiangyan Zhen,Kiangyen,T''ai-hsien,Taixian,T’ai-hsien,jiang yan,jiang yan shi,jiang yan zhen,姜堰,姜堰市,姜堰镇', 32.5061100, 120.1427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17517, 'Jiangya', 'Jiangya', 'Chiang-ya,Jiangya,Jiangya Zhen,jiang ya,jiang ya zhen,江垭,江垭镇', 29.5042800, 110.7638200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17518, 'Jiangxigou', 'Jiangxigou', 'Chiang-hsi-kou,Jiangxigou,Jiangxigou Xiang,jiang xi gou,jiang xi gou xiang,江西沟,江西沟乡', 36.6333300, 100.2666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17519, 'Gujiang', 'Gujiang', 'Chang-hsien,Chiang,Chiang-chen,Chiang-hsien,Chiang-hsien-ch''eng,Chiang-hsien-ch’eng,Gujiang,Gujiang Zhen,Jiang Xian,Jiangxian,Kianghsien,Tszyan''syan,Tszyan’syan,gu jiang,gu jiang zhen,jiang xian,古绛,古绛镇,绛县', 35.4939900, 111.5533400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17520, 'Jiangwei', 'Jiangwei', 'Jiangwei,Jiangwei Zhen,jiang wei,jiang wei zhen,江尾,江尾镇', 24.4312600, 114.1264500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17521, 'Jiangwang', 'Jiangwang', 'Chiang-wang-miao,Jiangwang,Jiangwang Jiedao,Jiangwangmiao,jiang wang,jiang wang jie dao,蒋王,蒋王街道', 32.3647700, 119.3695200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17522, 'Jiangwan', 'Jiangwan', 'Chiang-wan,Jiangwan,Jiangwan Zhen,jiang wan,jiang wan zhen,江湾,江湾镇', 29.3719400, 118.0469400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17523, 'Jiangwan', 'Jiangwan', 'Chiang-wan,Jiangwan,Jiangwan Zhen,jiang wan,jiang wan zhen,江湾,江湾镇', 24.6268100, 113.2281100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17524, 'Jiangwakou', 'Jiangwakou', 'Chiang-wa-k''ou,Chiang-wa-k’ou,Jiangwakou', 39.5225000, 117.7025000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17525, 'Jianguang', 'Jianguang', 'Feng-ch''eng-hsien,Feng-ch’eng-hsien,Fengcheng,Fengcheng Shi,Jianguang,feng cheng,feng cheng shi,丰城,丰城市', 28.1937700, 115.7836000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17526, 'Jiangtun', 'Jiangtun', 'Chiang-t''un,Chiang-t’un,Jiangtun,Jiangtun Zhen,jiang tun,jiang tun zhen,江屯,江屯镇', 23.7197900, 112.6184000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17527, 'Jiangtian', 'Jiangtian', 'Chiang-t''ien,Chiang-t’ien,Jiangtian,Jiangtian Zhen,Kengtien,jiang tian,jiang tian zhen,江田,江田镇', 25.8194700, 119.5751800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17528, 'Jiangshi', 'Jiangshi', 'Chiang-shih-chieh,Jiangshi,Tszyansitsze', 27.1233300, 109.7377800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17529, 'Jiangshan', 'Jiangshan', 'Chiang-shan,Ching-shan-chen,Jiangshan,Jiangshan Zhen,jiang shan,jiang shan zhen,姜山,姜山镇', 29.7711900, 121.5314900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17530, 'Jiangshan', 'Jiangshan', 'Jiangshan,Jiangshan Xiang,jiang shan,jiang shan xiang,江山,江山乡', 25.1801600, 116.9732800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17531, 'Jiangqiao', 'Jiangqiao', 'Chiang-ch''iao-chen,Chiang-ch’iao-chen,Jiangqiao,Jiangqiao Zhen,jiang qiao,jiang qiao zhen,江桥,江桥镇', 31.2389600, 121.3248400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17532, 'Jiangning', 'Jiangning', 'Chiang-ning,Chiang-ning-chen,Jiangning,Jiangning Jiedao,Tung-shan-chen,jiang ning,jiang ning jie dao,江宁,江宁街道', 31.8661200, 118.6031000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17533, 'Jiangna', 'Jiangna', 'Chiang-na,Chiang-na-chen,Jiangna,Kiangna,Yanshan,Yen-shan,Yen-shan-hsien,jiang na,江那', 23.6092000, 104.3731200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17534, 'Jiangmen', 'Jiangmen', 'Chiang-men,Chiang-men-ch''eng,Chiang-men-ch’eng,Chiang-men-shih,Czjanmehn'',Czjanmyn'',Dziangmenas,Dzjanmun,Geng-muong,Giang Mon,Giang Môn,Gjanmen,Gĕ̤ng-muòng,Hsin-hui,Hsin-hui-hsien,Jiangmen,Kang-mng-chhi,Kang-mn̂g-chhī,Kong-mun-su,Kongmoon,Kongmoon City,Kongmun,Kông-mùn-sṳ,Pakhai,Sunwui,Tiang-men,Wom Moon,ZBD,jangmeon si,jiang men,jiang men shi,jyangmn,jyangmyn,zhyangmn,Ĝjanmen,Ťiang-men,Ђангмен,Дзянмън,Цзянмынь,Цзянмэнь,جیانگمن,جیانگمین,ژیانگمن,江門,江門市,江门,江门市,장먼 시', 22.5833300, 113.0833300, 'CN', '2015-11-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17535, 'Jiangluo', 'Jiangluo', 'Chiang-lang-pa,Chiang-lo-chen,Chiang-lo-pa,Jiangluo,Jiangluo Zhen,Tszyanlanba,jiang luo,jiang luo zhen,江洛,江洛镇', 33.9013900, 105.8219400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17536, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou-chen,Chiang-k’ou-chen,Jiangkou,Jiangkou Zhen,jiang kou,jiang kou zhen,江口,江口镇', 31.2223800, 108.7937700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17537, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou,Chiang-k''ou-chen,Chiang-k’ou,Chiang-k’ou-chen,Jiangkou,Jiangkou Zhen,Tszyankouchzhen'',Tszyankouchzhen’,jiang kou,jiang kou zhen,江口,江口镇', 33.7305200, 107.0500200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17538, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou,Chiang-k''ou-chen,Chiang-k’ou,Chiang-k’ou-chen,Jiangkou,P''ing-ch''ang-she-chih-chu,Pingchang,P’ing-ch’ang-she-chih-chü,Tszyankou,jiang kou,江口', 31.5650600, 107.0973600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17539, 'Jiangkou', 'Jiangkou', 'Jiangkou,Jiangkou Zhen,San-chiang-k''ou,San-chiang-k’ou,jiang kou,jiang kou zhen,江口,江口镇', 29.7329000, 121.4036700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17540, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou,Chiang-k''ou-ch''ang,Chiang-k''ou-chen,Chiang-k’ou,Chiang-k’ou-chen,Chiang-k’ou-ch’ang,Jiangkou,Jiangkou Zhen,Kiangkowchen,jiang kou,jiang kou zhen,江口,江口镇', 29.2427900, 107.8772300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17541, 'Jiangkouxu', 'Jiangkouxu', 'Chiang-k''ou,Chiang-k’ou,Jiangkou,Jiangkouxu,Kiangkow', 27.6941700, 109.7358300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17542, 'Jiangkou', 'Jiangkou', 'Hsin-feng-chiang-k''ou,Hsin-feng-chiang-k’ou,Jiangkou,Jiangkou Zhen,jiang kou,jiang kou zhen,江口,江口镇', 25.9570100, 115.1330200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17543, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou,Chiang-k’ou,Jiangkou,Jiangkou Zhen,Kiang-k''ou,Kiang-k’ou,Kiangkow,jiang kou,jiang kou zhen,江口,江口镇', 25.4869400, 119.1983400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17544, 'Jiangkou', 'Jiangkou', 'Chiang-k''ou,Chiang-k''ou-chen,Chiang-k''ou-hsu,Chiang-k’ou,Chiang-k’ou-chen,Chiang-k’ou-hsü,Fengkai,Jiangkou,Jiangkou Zhen,Te-feng,jiang kou,jiang kou zhen,江口,江口镇', 23.4391600, 111.4974000, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17545, 'Jiangjing', 'Jiangjing', 'Chiang-chin,Jiangjing,Jiangjing Zhen,jiang jing,jiang jing zhen,江镜,江镜镇', 25.5547800, 119.4199100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17546, 'Jiangfang', 'Jiangfang', 'Jiangfang,Jiangfang Xiang,Jiangjiafang,jiang fang,蒋坊', 26.5015800, 110.3464000, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17547, 'Jiangbu', 'Jiangbu', 'Chiang-chia-pu,Jiangbu,Jiangbu Xiang,Jiangjiabu,jiang bu,jiang bu xiang,江埠,江埠乡', 28.6310200, 116.5795900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17548, 'Jiangjia', 'Jiangjia', 'Jiangjia,Jiangjia Zhen,jiang jia,jiang jia zhen,姜家,姜家镇', 29.4760200, 118.6595000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17549, 'Jianghua', 'Jianghua', 'Chiang-hua-ch''iao,Chiang-hua-ch’iao,Jianghua,Jianghua Zhen,Jianghuaqiao,jiang hua,jiang hua zhen,蒋华,蒋华镇', 32.0734100, 120.0089500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17550, 'Jianghong', 'Jianghong', 'Chiang-hung,Chiang-hung-hsu,Chiang-hung-hsü,Jianghong,Jianghong Xu,Jianghong Zhen,jiang hong,jiang hong zhen,江洪,江洪镇', 21.0159400, 109.7163800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17551, 'Jianggu', 'Jianggu', 'Chiang-ku,Chiang-ku-hsu,Chiang-ku-hsü,Jianggu,Jianggu Zhen,Kongkuk,jiang gu,jiang gu zhen,江谷,江谷镇', 23.5057900, 112.6583400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17552, 'Jianggezhuang', 'Jianggezhuang', 'Jianggezhuang,Jianggezhuang Zhen,jiang ge zhuang,jiang ge zhuang zhen,姜格庄,姜格庄镇', 37.4138700, 121.8163300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17553, 'Jianggang', 'Jianggang', 'Ch''iang-chiang,Ch''iang-kang,Ch’iang-chiang,Ch’iang-kang,Jianggang,Jianggang Zhen,Nan-ch''iang,Nan-ch’iang,jiang gang,jiang gang zhen,弶港,弶港镇', 32.7403100, 120.8456900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17554, 'Jiangduo', 'Jiangduo', 'Chiang-to,Chiang-to-chen,Jiangduo,Jiangduo Zhen,jiang duo,jiang duo zhen,蒋垛,蒋垛镇', 32.3660800, 120.2410700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17555, 'Gangdong', 'Gangdong', 'Chiang-tung,Gangdong,Jiangdong', 27.9169400, 110.8341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17556, 'Jiangcun', 'Jiangcun', 'Chiang-ts''un,Chiang-ts’un,Jiangcun,Jiangcun Xiang,Ta-chiang-ts''un,Ta-chiang-ts’un,jiang cun,jiang cun xiang,江村,江村乡', 29.7720000, 117.3631800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17557, 'Jianggao', 'Jianggao', 'Chiang-ts''un,Chiang-ts’un,Jiangcun,Jianggao,Jianggao Zhen,Kongchuen,Kongtsun,jiang gao,jiang gao zhen,江高,江高镇', 23.2670100, 113.2304200, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17558, 'Jiangcheng', 'Jiangcheng', 'Chiang-ch''eng,Chiang-ch''uan,Chiang-ch''uan-hsien,Chiang-ch’eng,Chiang-ch’uan,Chiang-ch’uan-hsien,Chiu-chiang-ch''uan,Chiu-chiang-ch’uan,Jiangcheng,Jiangcheng Zhen,Kiangchwan,Kiangchwan-hsien,jiang cheng,jiang cheng zhen,江城,江城镇', 24.4241700, 102.8050000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17559, 'Yangjiang', 'Yangjiang', 'Chiang-ch''eng-chen,Chiang-ch’eng-chen,Duong Giang,Dương Giang,Iong-gong,Iong-kang-chhi,Iòng-gŏng,Iông-kang-chhī,Janczjan,Jang-tiang,Jang-ťiang,Jiangcheng,Liang-yang,Yang-chiang,Yang-chiang-hsien,Yangjiang,Yeungkong,Yeungkong-hsien,Yong-kong-su,Yòng-kông-sṳ,yang jiang,yang jiang shi,yang jyang,yangjang si,yangzhyang,yngjyang,Јангђанг,Янцзян,یانگ جیانگ,یانگژیانگ,ینگجیانگ,阳江,阳江市,陽江,陽江市,양장 시', 21.8556300, 111.9627200, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17560, 'Jiangbei', 'Jiangbei', 'Chiang-pei-hsu,Chiang-pei-hsü,Jiangbei,Jiangbei Zhen,Jiangbeixu,jiang bei,jiang bei zhen,江背,江背镇', 26.3011700, 115.4825700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17561, 'Jiang’an Qu', 'Jiang''an Qu', 'Jiang''an,Jiang''an Qu,Jiang’an,Jiang’an Qu,jiang an,jiang an qu,江岸,江岸区', 30.6089000, 114.3068300, 'CN', '2016-02-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17562, 'Jiang’an', 'Jiang''an', 'Chiang-an,Chiang-an-hsien,Jiang''an,Jiang’an,Kiangan,Kiangan-hsien,jiang an,江安', 28.7333500, 105.0683000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17563, 'Jianfeng', 'Jianfeng', 'Jianfeng,Jianfeng Xiang,jian feng,jian feng xiang,尖峰,尖峰乡', 26.7507900, 116.4767500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17564, 'Jianfeng', 'Jianfeng', 'Chien-feng,Jianfeng,Jianfeng Zhen,Jianfengling,jian feng,jian feng zhen,尖峰,尖峰镇', 18.6697000, 108.7263700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17565, 'Jiandou', 'Jiandou', 'Chien-tou,Jiandou,Jiandou Zhen,jian dou,jian dou zhen,剑斗,剑斗镇', 25.3228300, 117.9293800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17566, 'Jiancheng', 'Jiancheng', 'Chien-ch''eng,Chien-ch’eng,Jiancheng,Jiancheng Zhen,jian cheng,jian cheng zhen,建城,建城镇', 23.1366500, 111.5387900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17567, 'Jiancha', 'Jiancha', 'Chien-ch''a''-hsi,Chien-ch’a’-hsi,Jiancha,Jiancha Zhen,Jianchaxi,jian cha,jian cha xi,jian cha zhen,煎茶,煎茶溪,煎茶镇', 28.1493000, 107.9723100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17568, 'Jianchang', 'Jianchang', 'Chien-ch''ang,Chien-ch’ang,Jianchang,Jianchang Zhen,Kienchang,Kienchangfu,Nan-ch''eng-hsien,Nan-ch’eng-hsien,Nancheng,Nancheng Xian,jian chang,jian chang zhen,nan cheng xian,南城县,建昌,建昌镇', 27.5583100, 116.6397800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17569, 'Jianba', 'Jianba', 'Chien-pa,Jianba,Jianba Zhen,jian ba,jian ba zhen,枧坝,枧坝镇', 28.0793700, 107.0408600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17570, 'Ji’an', 'Ji''an', 'Chi-an,Chi-an-shih,Czian'',JGS,Ji''an,Ji''an Shi,Ji’an,Ji’an Shi,Kian,Kian-hsien,Kianfu,Luling,ji an,ji an shi,Цзиань,吉安,吉安市', 27.1171600, 114.9792700, 'CN', '2013-06-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17571, 'Jiamiao', 'Jiamiao', 'Jiamiao,Jiamiao Xiang,gu miao,gu miao xiang,贾庙,贾庙乡', 30.7961800, 115.0819800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17572, 'Jiamaying', 'Jiamaying', 'Cha-ma-ying,Chia-ma-ying,Chiama,Jiamaying', 37.2080600, 115.9500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17573, 'Jiamachi', 'Jiamachi', 'Jiamachi,Jiamachi Zhen,jia ma chi,jia ma chi zhen,甲马池,甲马池镇', 29.5079800, 108.9753100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17574, 'Jialu', 'Jialu', 'Chia-lu,Jialu,Jialu Zhen,jia lu,jia lu zhen,甲路,甲路镇', 30.4268200, 118.8463100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17575, 'Jialou', 'Jialou', 'Chia-lou,Jialou,Kialow,Shen-lou,Tszyalou,gu lou,贾楼', 32.8947300, 113.4507200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17576, 'Guangyuan', 'Guangyuan', 'GYS,Guangjuen,Guangyuan,Guanujuan'',Guong-nguong,Guōng-nguòng,Gǔangyúan,Jialing,Kong-goan-chhi,Kuan-yuan,Kuan-yüan,Kuang-juean,Kuang-jüan,Kuang-yuan,Kuang-yuan-hsien,Kuang-yüan,Kuang-yüan-hsien,Kwangyuan,Kwangyuanhsien,Kwangyüan,Kwangyüanhsien,Kóng-goân-chhī,Quang Nguyen,Quảng Nguyên,guang yuan,guang yuan shi,gwang-wian si,gwangywan,Гуангјуен,Гуанъюань,گوانگیوان,广元,广元市,広元市,廣元,광위안 시', 32.4420100, 105.8230000, 'CN', '2013-11-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17577, 'Jiale', 'Jiale', 'Jiale,Jiale Zhen,jia le,jia le zhen,加乐,加乐镇', 19.5772300, 110.0113800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17578, 'Jialai', 'Jialai', 'Chia-lai,Jialai,Jialai Zhen,Ka lai,Kialoi,jia lai,jia lai zhen,加来,加来镇', 19.7080600, 109.6955600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17579, 'Yancheng', 'Yancheng', 'Chia-chiang,Chia-chiang-hsien,Jiajiang,Kiakiang,Kiakiang-hsien,Yancheng,yan cheng,漹城', 29.7435700, 103.5667900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17580, 'Qionghai', 'Qionghai', 'BAR,Ch''iung-hai,Ch''iung-tung,Ch''iung-tung-hsien,Chia-chi,Chia-chi-chen,Chia-chi-shih,Ch’iung-hai,Ch’iung-tung,Ch’iung-tung-hsien,Jiaji,Jiaji Zhen,Kachek,Katchek,QHX,Qionghai,Qionghai Shi,chunghai si,jia ji,qiong hai,qiong hai shi,嘉积,琼海市,瓊海,瓊海市,충하이 시', 19.2425000, 110.4641700, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17581, 'Jiahu', 'Jiahu', 'Jiahu,Jiahu Xiang,jia hu,jia hu xiang,夹湖,夹湖乡', 24.7101500, 114.6528800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17582, 'Jiahe', 'Jiahe', 'Chia-ho,Chia-ho-kuan,Jiahe,Jiahe Zhen,jia he,jia he zhen,夹河,夹河镇', 32.8773700, 110.0257400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17583, 'Jiahe', 'Jiahe', 'Chia-ho,Jiahe,Jiahe Jiedao,jia he,jia he jie dao,嘉禾,嘉禾街道', 23.2282700, 113.2695100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17584, 'Jiadingzhen', 'Jiadingzhen', 'Chia-tang,Chia-ting,Chia-ting-hsien,Jiading,Jiadingzhen,Jiadingzhen Jiedao,Kiating,Kiating Ku,jia ding,jia ding zhen,jia ding zhen jie dao,嘉定,嘉定镇,嘉定镇街道', 31.3857500, 121.2446500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17585, 'Jiading', 'Jiading', 'Hsin-feng,Hsin-feng-hsien,Jiading,Sinfeng,Sinfeng-hsien,Xinfeng,Xinfeng Xian,jia ding,xin feng xian,信丰县,嘉定', 25.4295000, 114.9280400, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17586, 'Jiacun', 'Jiacun', 'Chia-ts''un,Chia-ts''un-chen,Chia-ts’un,Chia-ts’un-chen,Jiacun,Jiacun Zhen,gu cun,gu cun zhen,贾村,贾村镇', 34.4529400, 107.2042500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17587, 'Jiachuan', 'Jiachuan', 'Chia-ch''uan,Chia-ch''uan-chen,Chia-ch’uan,Chia-ch’uan-chen,Jiachuan,Jiachuan Zhen,jia chuan,jia chuan zhen,嘉川,嘉川镇', 32.2090700, 106.2149400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17588, 'Huzhou', 'Huzhou', 'HZC,Hu-chou,Hu-chou-shih,Huchow,Huchowfu,Huhinghsien,Huzhou,Huzhou Shi,Wu-hsing,Wu-hsing-hsien,Wu-hsing-hsien-ch''eng,Wu-hsing-hsien-ch’eng,Wuhing,Wuxing,Wuxing Qu,hu zhou,hu zhou shi,wu xing,wu xing qu,吴兴,吴兴区,湖州,湖州市', 30.8703000, 120.0933000, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17589, 'Huzhen', 'Huzhen', 'Huchen,Huzhen,Huzhen Zhen,hu zhen,hu zhen zhen,湖镇,湖镇镇', 29.0645100, 119.2918000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17590, 'Huzhen', 'Huzhen', 'Hu-chen,Huzhen,Huzhen Zhen,hu zhen,hu zhen zhen,壶镇,壶镇镇', 28.8077400, 120.2526400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17591, 'Huzhen', 'Huzhen', 'Hu-chen,Hu-chen-hsu,Huzhen,Huzhen Zhen,hu zhen,hu zhen zhen,湖镇,湖镇镇', 23.2466100, 114.1500000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17592, 'Huyuan', 'Huyuan', 'Huyuan,Huyuan Xiang,hu yuan,hu yuan xiang,湖源,湖源乡', 26.1294400, 117.7695700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17593, 'Huyu', 'Huyu', 'Hu-yu-ts''un,Hu-yü-ts’un,Huyu,Huyu Xiang,hu yu,hu yu xiang,胡峪,胡峪乡', 39.2005200, 113.1026100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17594, 'Huyang', 'Huyang', 'Huyang,Huyang Xiang,T''ang-kou,T''ang-kou-chen,T’ang-kou,T’ang-kou-chen,hu yang,hu yang xiang,湖阳,湖阳乡', 31.3858300, 118.8225200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17595, 'Huyang', 'Huyang', 'Hu-yang-chen,Hucheng,Huyang,Huyang Zhen,Xikou,hu yang,hu yang zhen,湖洋,湖洋镇', 25.4064900, 118.4231800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17596, 'Huyang', 'Huyang', 'Huyang,Huyang Xiang,hu yang,hu yang xiang,湖洋,湖洋乡', 25.0429700, 116.3195700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17597, 'Huxi', 'Huxi', 'Hu-hsi-ho,Huxi,Huxi Xiang,Huxi Zhen,Huxihe,hu xi,hu xi zhen,虎溪,虎溪镇', 29.5988900, 106.3058300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17598, 'Huxiaoqiao', 'Huxiaoqiao', 'Hu-hsiao-ch''iao,Hu-hsiao-ch''iao-chen,Hu-hsiao-ch’iao,Hu-hsiao-ch’iao-chen,Huanggu Zhen,Huxiaoqiao,hu xiao qiao,huang gu zhen,虎啸桥,黄姑镇', 30.6704000, 121.1572400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17599, 'Ganting', 'Ganting', 'Ganting,Ganting Zhen,Hu,Hu Xian,Hu-hsien,Khusyan,gan ting,gan ting zhen,hu xian,户县,甘亭,甘亭镇', 34.1024100, 108.6140600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17600, 'Huxi', 'Huxi', 'Hu-hsi,Huxi,Huxi Zhen,hu xi,hu xi zhen,湖溪,湖溪镇', 29.1792900, 120.3909600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17601, 'Hutou', 'Hutou', 'Houqian,Hutou,Hutou Zhen,Hutow,hou qian,hu tou,hu tou zhen,后墘,湖头,湖头镇', 25.2352800, 118.0347200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17602, 'Hutang', 'Hutang', 'Hutang,hu tang,湖塘', 31.5342900, 119.4900000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17603, 'Mishixiang', 'Mishixiang', 'Hushu,Mishixiang,Mishixiang Jiedao,mi shi xiang,mi shi xiang jie dao,米市巷,米市巷街道', 30.2948300, 120.1434200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17604, 'Hushi', 'Hushi', 'Hu-shih,Hushi,Hushi Zhen,hu shi,hu shi zhen,笏石,笏石镇', 25.3177800, 119.0884200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17605, 'Xushan', 'Xushan', 'Cixi,Cixi Shi,Hu-shan-chen,Hu-shan-so-ch''eng,Hu-shan-so-ch’eng,Hushan,Tz''u-ch''i,Tz''u-hsi,Tz’u-ch’i,Tz’u-hsi,Xushan,Xushan Jiedao,ci xi,ci xi shi,hu shan,hu shan jie dao,慈溪,慈溪市,浒山,浒山街道', 30.1764000, 121.2457000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17606, 'Hushan', 'Hushan', 'Hushan,Hushan Xiang,gu shan,gu shan xiang,鹄山,鹄山乡', 28.0678900, 115.0041700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17607, 'Hushan', 'Hushan', 'Hushan,Hushan Xiang,San-lai-chou,Sanlaizhou,hu shan,hu shan xiang,san lai zhou,三来州,湖山,湖山乡', 24.4702600, 116.8735700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17608, 'Huqiu', 'Huqiu', 'Huqiu,Huqiu Zhen,hu qiu,hu qiu zhen,湖坵,虎邱,虎邱镇', 25.0036100, 117.9894400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17609, 'Huping', 'Huping', 'Huping,Huping Xiang,hu ping,hu ping xiang,湖坪,湖坪乡', 27.1929900, 115.7479900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17610, 'Huozhuangzi', 'Huozhuangzi', 'Huozhuangzi,huo zhuang zi,霍庄子', 39.2914800, 117.3135800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17611, 'Huoxian', 'Huoxian', 'Huo-hsien,Huoxian,Huoxian Zhen,K''uo-hsien,Kuo-hsien-chen,K’uo-hsien,huo xian,huo xian zhen,漷县,漷县镇', 39.7754200, 116.7838600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17612, 'Huotong', 'Huotong', 'Ho-t''ung,Ho-t’ung,Huo-t''ung,Huo-t’ung,Huotong', 26.8497200, 119.4180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17613, 'Huotian', 'Huotian', 'Huotian,Huotian Zhen,huo tian,huo tian zhen,火田,火田镇', 24.0055600, 117.3830600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17614, 'Huoshaoping', 'Huoshaoping', 'Huoshaoping,Huoshaoping Xiang,huo shao ping,huo shao ping xiang,火烧坪,火烧坪乡', 30.5070500, 110.7274200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17615, 'Huoshaodian', 'Huoshaodian', 'Huo-shao-tien,Huoshaodian,huo shao dian,火烧店', 33.5424200, 106.9199400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17616, 'Huoqiu Chengguanzhen', 'Huoqiu Chengguanzhen', 'Ho-ch''iu,Ho-ch''iu-hsien,Ho-ch’iu,Ho-ch’iu-hsien,Huo-ch''iu,Huo-ch’iu,Huoqiu,Huoqiu Chengguanzhen,Hwokiu,Hwokiu-hsien,huo qiu cheng guan zhen,霍邱城关镇', 32.3547300, 116.2939000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17617, 'Huomachong', 'Huomachong', 'Huo-ma-ch''ung,Huo-ma-ch’ung,Huomachong', 27.8833300, 110.2300000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17618, 'Huolu', 'Huolu', 'Huai-lu,Huo-lu-ch''eng-kuan,Huo-lu-ch’eng-kuan,Huo-lu-hsien,Huolu,Hwailu,Kholu,Luquan,huo lu,获鹿', 38.0805600, 114.2961100, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17619, 'Huolu', 'Huolu', 'Huolu,Huolu Zhen,Huolupu,huo lu,huo lu zhen,火炉,火炉镇', 29.3942200, 107.8725400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17620, 'Huolongping', 'Huolongping', 'Huo-lung-p''ing,Huo-lung-p’ing,Huolongping,Huolongping Xiang,Hwolungping,huo long ping,huo long ping xiang,活龙坪,活龙坪乡', 29.8367400, 108.7242700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17621, 'Huoli', 'Huoli', 'Ho-li,Ho-li-chen,Houli Zhen,Huoli,huo li,huo li zhen,霍里,霍里镇', 31.6938400, 118.5765200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17622, 'Huojia Chengguanzhen', 'Huojia Chengguanzhen', 'Huo-chia,Huo-chia-hsien,Huojia,Huojia Chengguanzhen,Hwokia,Hwokia-hsien,Khotszya,huo jia cheng guan zhen,获嘉城关镇', 35.2655600, 113.6505600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17623, 'Huogezhuang', 'Huogezhuang', '', 39.7438900, 117.3675000, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17624, 'Huocheng', 'Huocheng', 'Huocheng,Huocheng Zhen,huo cheng,huo cheng zhen,霍城,霍城镇', 38.4031800, 101.0548700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17625, 'Huochang', 'Huochang', 'Huochang,Huochang Tujiazuxiang,huo chang,huo chang tu jia zu xiang,火场,火场土家族乡', 28.9289700, 110.5447600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17626, 'Yong’an', 'Yong''an', 'Hun-yuan-hsien,Hun-yüan-hsien,Hunyuan Xian,Khun''yuan'',Khun’yuan’,Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,hun yuan xian,yong an,yong an zhen,永安,永安镇,浑源县', 39.6957100, 113.6870800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17627, 'Humen', 'Humen', 'Fumunchai,Fumuntschai,Hu-men-chai,Hu-nien,Humen,Humen Zhen,Khumehn'',hu men,hu men zhen,Хумэнь,虎门,虎门镇', 22.8189900, 113.6730600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17628, 'Hulu', 'Hulu', 'Hu-lu-chai,Hulu,Hulu Zhen,Huluzhai,hu lu,hu lu zhen,葫芦,葫芦镇', 28.5431200, 109.7580100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17629, 'Huliao', 'Huliao', 'Dapu,Dapu Xian,Hu-liao-hsu,Hu-liao-hsü,Huliao,Huliao Zhen,Huliaoxu,Ta-pu,Ta-pu-hsien,da bu,da bu xian,hu liao,hu liao zhen,大埔,大埔县,湖寮,糊寮镇', 24.3576400, 116.6866300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17630, 'Hulei', 'Hulei', 'Hulei,Hulei Zhen,Xiahu,hu lei,hu lei zhen,xia hu,下湖,湖雷,湖雷镇', 24.7949600, 116.8150000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17631, 'Hule', 'Hule', 'Holossu,Hu-le-ssu,Hu-lo-ssu,Hu-lo-ssu-chen,Hule,Hule Zhen,Hulesi,hu le,hu le zhen,胡乐,胡乐镇', 30.3533500, 118.7727900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17632, 'Hukou', 'Hukou', 'Hu-k''ou-hsu,Hu-k’ou-hsü,Hukou,Hukou Zhen,Hukouxu,hu kou,hu kou wei,hu kou zhen,湖口,湖口圩,湖口镇', 26.6062900, 113.6516100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17633, 'Hukou', 'Hukou', 'Hukou,Hukou Zhen,hu kou,hu kou zhen,湖口,湖口镇', 25.1727600, 114.4012600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17634, 'Hukeng', 'Hukeng', 'Hukeng,Hukeng Zhen,hu keng,hu keng zhen,浒坑,浒坑镇', 27.4730200, 114.3084300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17635, 'Hukeng', 'Hukeng', 'Hukeng,Hukeng Zhen,hu keng,hu keng zhen,湖坑,湖坑镇', 24.6489400, 116.9455700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17636, 'Hujiaying', 'Hujiaying', 'Hujiaying,Hujiaying Zhen,hu jia ying,hu jia ying zhen,胡家营,胡家营镇', 32.7804400, 110.2555700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17637, 'Huji', 'Huji', 'Hu-chia-chi,Huji,Huji Zhen,Hujiaji,hu ji,hu ji zhen,胡集,胡集镇', 32.5166700, 120.3833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17638, 'Hujiagou', 'Hujiagou', 'Hu-chia-kou,Hujiagou,Sanhu,Sanhu Xiang,hu jia gou,san hu xiang,三胡乡,胡家沟', 29.5740700, 109.3233200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17639, 'Huhe', 'Huhe', 'Hu-chia-tun,Hu-chia-tun-chen,Hu-ho,Huhe,Huhe Zhen,Hujiadun,hu he,hu he zhen,hu jia dun,护河,护河镇,护驾墩', 31.5110200, 118.5896300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17640, 'Hujiaba', 'Hujiaba', 'Hu-chia-pa,Hujiaba,Hujiaba Zhen,hu jia ba,hu jia ba zhen,胡家坝,胡家坝镇', 32.9775900, 106.4688100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17641, 'Huji', 'Huji', 'Hu-chi,Huji,Huji Zhen,hu ji,hu ji zhen,胡集,胡集镇', 31.4333300, 112.3152800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17642, 'Huizhou', 'Huizhou', 'Chuej-cou,Chuej-čou,Fi-chu-su,Fi-chû-sṳ,HUZ,Hie-ciu,Hiê-ciŭ,Hue Chau,Hui-chiu-chhi,Hui-chou,Hui-chou-ch''eng,Hui-chou-chen,Hui-chou-ch’eng,Hui-chou-shih,Hui-yang,Hui-yang-hsien,Huichou-fu,Huitsjou,Huizhou,Huệ Châu,Hūi-chiu-chhī,Khojchzhou,Khuehjchzhou,Khuejdzou,Kuei-shan,Waichow,Waichowfu,Waiyeung,Weichow,Xuyjo shehiri,hu-ijeou si,hui zhou,hui zhou shi,hwyzhw,Хойчжоу,Хуејџоу,Хуэйчжоу,هویژو,ہوئیژوؤ,ہوئیژوو,恵州,恵州市,惠州,惠州市,후이저우 시', 23.1114700, 114.4152300, 'CN', '2015-03-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17643, 'Huiyi', 'Huiyi', 'Huiyi,Huiyi Zhen,hui yi,hui yi zhen,会仪,会仪镇', 28.6166700, 104.2166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17644, 'Chengguan', 'Chengguan', 'Chengguan,Hui,Hui-hsien,Huixian,Hwihsien,cheng guan,城关', 35.4586100, 113.7977800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17645, 'Huixian Chengguanzhen', 'Huixian Chengguanzhen', 'Chengguan Zhen,Hui,Hui-ch''eng,Hui-ch’eng,Hui-hsien,Hui-hsien-ch''eng,Hui-hsien-ch’eng,Huixian,Huixian Chengguanzhen,Khuysyan'',Khuysyan’,cheng guan zhen,hui xian,hui xian cheng guan zhen,城关镇,徽县,徽县城关镇', 33.7683300, 106.0808300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17646, 'Huiwen', 'Huiwen', 'Huiwen,Huiwen Zhen,hui wen,hui wen zhen,会文,会文镇', 19.4633700, 110.7246400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17647, 'Huitang', 'Huitang', 'Huitang,Huitang Zhen,hui tang,hui tang zhen,灰汤,灰汤镇', 27.9900000, 112.3302800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17648, 'Huishi', 'Huishi', 'Hui-ning-hsien,Huining,Huishi,Huishi Zhen,Khuynin,hui shi,会师', 35.6919600, 105.0485800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17649, 'Huishangang', 'Huishangang', 'Hui-shan-chiang,Hui-shan-kang,Huishangang,Huishangang Zhen,hui shan gang,hui shan gang zhen,灰山港,灰山港镇', 28.2894400, 112.2386100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17650, 'Xinshichang', 'Xinshichang', 'Huishan,Huishan Zhen,Shuangcai,Xinshichang,hui shan zhen,shuang cai,xin shi chang,双彩,回山镇,新市场', 29.2798600, 120.8067400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17651, 'Huilongshan', 'Huilongshan', 'Chiung-lung-shan,Hui-lung-shan,Huilongshan,Huilongshan Zhen,hui long shan,hui long shan zhen,回龙山,回龙山镇', 30.6180400, 114.9769900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17652, 'Huilong', 'Huilong', 'Ch''i-tung,Ch''i-tung-hsien,Chen-yang-shih,Ch’i-tung,Ch’i-tung-hsien,Huilong,Huilong Zhen,Kvidonga,Qidong,Qidong Shi,Wei-tung-chen,Weidong,hui long,hui long zhen,qi dong,qi dong shi,Квидонга,启动,启动市,汇龙,汇龙镇', 31.8111100, 121.6550000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17653, 'Huilong', 'Huilong', 'Hui-lung,Huilong,Huilong Zhen,hui long,hui long zhen,迴龙,迴龙镇', 27.4807300, 118.4075300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17654, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 24.1513000, 113.9267800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17655, 'Huili', 'Huili', 'Huili,Huili Zhen,hui li,hui li zhen,回里,回里镇', 37.3330200, 121.3184200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17656, 'Huili Chengguanzhen', 'Huili Chengguanzhen', 'Hui-li-hsien,Huili,Huili Chengguanzhen,Hweili,Hweili-hsien,Hweilichow,hui li,hui li cheng guan zhen,会理,会理城关镇', 26.6625600, 102.2439200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17657, 'Huikou', 'Huikou', 'Huikou,Huikou Zhen,Huikoujie,hui kou,hui kou zhen,汇口,汇口镇', 29.8183200, 116.2453700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17658, 'Huifeng', 'Huifeng', 'Hui-feng-chen,Huifeng,Huifeng Xiang,Huifeng Zhen,hui feng,hui feng zhen,惠丰,惠丰镇', 31.7847300, 121.6333500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17659, 'Huidong', 'Huidong', 'Ch''ien-chin-kung-she,Ch’ien-chin-kung-she,Hui-tung,Huidong,Hweitung,Ts''an-yu-kuan,Ts''an-yu-pa,Ts’an-yü-kuan,Ts’an-yü-pa,Ying-p''an,Ying-p’an,hui dong,会东', 26.6374500, 102.5756800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17660, 'Huicheng', 'Huicheng', 'Hsi-hsien,Hui-ch''eng-chen,Hui-chou,Hui-ch’eng-chen,Huicheng,Huicheng Zhen,Hweichow,Hweichow Sihsen,She,She Xian,She-hsien,She-hsin,Sihsien,hui cheng,hui cheng zhen,she xian,徽城,徽城镇,歙县', 29.8692500, 118.4336400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17661, 'Huicheng', 'Huicheng', 'Hui-ch''eng-chen,Hui-ch’eng-chen,Hui-lai-hsien,Huicheng,Huilai,Hweilai,Hweilai-hsien,hui cheng,惠城', 23.0384500, 116.2898800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17662, 'Xinhui', 'Xinhui', 'Chiu-hsin-hui,District de Xinhui,Hsin-hui,Hsin-hui Old City,Hsin-hui-chiu-ch''eng,Hsin-hui-chiu-ch’eng,Hsin-hui-hsien,Hsin-hui-ku-chih,Hui-ch''eng-chen,Hui-ch’eng-chen,Huicheng,Sanwui,Sin-fi-khi,Sun-hui,Sun-wei,Sunweihsien,Sunwui,Sunwui Old City,Sîn-fi-khî,Tan Hoi,Tân Hội,Xinhui,Xinhui District,shynhwy,sinhu-i gu,xin hui,xin hui qu,شینهوی,新会,新会区,新會,新會區,신후이 구', 22.4560000, 113.0482000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17663, 'Huibu', 'Huibu', 'Hui-pu,Huibu,Huibu Xiang,hui bu,hui bu xiang,会埠,会埠乡', 28.7256300, 115.1816300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17664, 'Huibu', 'Huibu', 'Hui-pu,Huibu,Huibu Zhen,hui bu,hui bu zhen,灰埠,灰埠镇', 28.2940900, 115.2518700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17665, 'Longquan', 'Longquan', 'Hu-kuan,Hu-kuan-hsien,Huguan,Huguan Xian,Hukwanhsien,Khuguan,Longquan,Longquan Zhen,hu guan xian,long quan,long quan zhen,壶关县,龙泉,龙泉镇', 36.1173600, 113.1857100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17666, 'Hufeng', 'Hufeng', 'Hu-feng-chen,Hufeng,Hufeng Zhen,Hufengchang,hu feng,hu feng zhen,虎峰,虎峰镇', 29.7155000, 106.1108900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17667, 'Hufang', 'Hufang', 'Hufang,Hufang Zhen,hu fang,hu fang zhen,湖坊,湖坊镇', 28.1622200, 117.5501800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17668, 'Hufang', 'Hufang', 'Hufang,Hufang Zhen,hu fang,hu fang zhen,胡坊,胡坊镇', 26.2180400, 117.2291200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17669, 'Hudong', 'Hudong', 'Hudong,Hudong Xiang,hu dong,hu dong xiang,虎洞,虎洞乡', 36.5489900, 106.9721900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17670, 'Hudong', 'Hudong', 'Hudong,Hudong Zhen,Hutung,hu dong,hu dong zhen,湖东,湖东镇', 22.8178000, 115.9506500, 'CN', '2016-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17671, 'Hudai', 'Hudai', 'Hu-tai,Hu-tai-chen,Hudai,Hudai Zhen,hu dai,hu dai zhen,胡埭,胡埭镇', 31.5487800, 120.1189500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17672, 'Hucun', 'Hucun', 'Hu-ts''un,Hu-ts’un,Hucun,Hucun Zhen,hu cun,hu cun zhen,湖村,湖村镇', 26.3504500, 116.8461800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17673, 'Huchang', 'Huchang', 'Huchang,Huchang Zhen,hu chang,hu chang zhen,胡场,胡场镇', 30.3774700, 113.3010800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17674, 'Danxi', 'Danxi', 'Danxi,Danxi Zhen,Hu-pien,Hu-pien-ts''un,Hu-pien-ts’un,Hubian,dan xi,dan xi zhen,hu bian,淡溪,淡溪镇,湖边', 28.2317700, 120.9905600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17675, 'Hubei', 'Hubei', 'Hu-pei,Hu-pei-ts''un,Hu-pei-ts’un,Hubei,Hubei Xiang,Khubehj,hu bei,hu bei xiang,Хубэй,虎北,虎北乡', 38.9984200, 112.0114400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17676, 'Huazhuang', 'Huazhuang', 'Hua-chuang,Hua-ta-fang-chuang,Huazhuang,Huazhuang Jiedao,Huazhuang Zhen,hua zhuang,hua zhuang jie dao,华庄,华庄街道', 31.4832800, 120.3429600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17677, 'Huazhou', 'Huazhou', 'Fachow,Fahsien,Fu-ch''eng-chen,Fu-ch’eng-chen,Hau-hsien,Hua,Hua-chou,Hua-hsien,Huazhou', 21.6333300, 110.5833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17678, 'Huazhai', 'Huazhai', 'Hua-chai-tzu,Huazhai,Huazhai Xiang,Huazhaizi,hua zhai,hua zhai xiang,花寨,花寨乡', 38.6219400, 100.3583300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17679, 'Huazhaizi', 'Huazhaizi', 'Huazhai,Huazhaizi,Huazhaizi Xiang,hua zhai zi,hua zhai zi xiang,花寨子,花寨子乡', 38.5000000, 101.2166700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17680, 'Huazangsi', 'Huazangsi', 'Hua-tsang-ssu,Huazangsi,Tianzhu Zangzu Zizhixian,hua cang si,tian zhu cang zu zi zhi xian,华藏寺,天祝藏族自治县', 36.9765300, 103.1352200, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17681, 'Huayuan', 'Huayuan', 'Hua-yuan-shih,Hua-yüan-shih,Huayuan,Hwayuan,Hwayüan,hua yuan,花园', 31.3142200, 114.0177500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17682, 'Huayuan', 'Huayuan', 'Hua-yuan-chen,Hua-yuan-hsien,Hua-yüan-chen,Hua-yüan-hsien,Huayuan,Huayuan Xian,Yang-sui,Yung-sui,Yung-sui-hsien,hua yuan,hua yuan xian,花垣,花垣县', 28.5881500, 109.4757800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17683, 'Huayuan', 'Huayuan', 'Hua-yuan-shih,Hua-yüan-shih,Huayuan,Khuayuan''shi,Khuayuan’shi', 26.9136100, 110.5358300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17684, 'Shuanghejiedao', 'Shuanghejiedao', 'Huaying,Shuang-ho,Shuanghe,Shuanghejiedao,shuang he jie dao,双河街道', 30.3744800, 106.7726600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17685, 'Huayin', 'Huayin', 'Hua-yin-hsien,Hua-yin-hsien-ch''eng,Hua-yin-hsien-ch’eng,Huayin,Hwayinhsien,Khuayanchuan', 34.5652800, 110.0663900, 'CN', '2016-08-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17686, 'Huayang', 'Huayang', 'Hua-yang-ch''uan,Hua-yang-ch’uan,Huayang,hua yang,华阳', 34.4155300, 109.9938600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17687, 'Huayang', 'Huayang', 'Chi-ch''i,Chi-ch''i-hsien,Chi-ch’i,Chi-ch’i-hsien,Chi-hsi,Chiki,Chikihsien,Huayang,Huayang Zhen,Jixi,hua yang,hua yang zhen,华阳,华阳镇', 30.0708700, 118.5903200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17688, 'Huazhou', 'Huazhou', 'Hua,Hua-hsien,Hua-hsien-ch''eng,Hua-hsien-ch’eng,Huaxian,Huazhou,Huazhou Zhen,Hwahsien,Khuasyan,hua zhou,hua zhou zhen,华州,华州镇', 34.5152300, 109.7575900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17689, 'Huaxijie', 'Huaxijie', 'Hua-hsi-chen,Huaxi Zhen,Huaxijie,hua xi jie,hua xi zhen,华溪街,华溪镇', 24.0750100, 103.0139800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17690, 'Huating', 'Huating', 'Huating,Huating Zhen,hua ting,hua ting zhen,华亭,华亭镇', 31.4624400, 121.2370700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17691, 'Huating', 'Huating', 'Huating,Huating Zhen,hua ting,hua ting zhen,华亭,华亭镇', 25.3816200, 118.8878900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17692, 'Huashi', 'Huashi', 'Hua-shih,Hua-shu,Hua-shu-chen,Huashi,Huashi Zhen,hua shi,hua shi zhen,华士,华士镇', 31.8343900, 120.4633500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17693, 'Huarong', 'Huarong', 'Hua-jung,Hua-jung-chen,Huarong,Huarong Zhen,hua rong,hua rong zhen,华容,华容镇', 30.5333300, 114.7333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17694, 'Huarong Chengguanzhen', 'Huarong Chengguanzhen', 'Hua-jung,Hua-jung-hsien,Huarong,Huarong Chengguanzhen,Huarong Xian,Hwajung-hsien,Hwayunghsien,hua rong cheng guan zhen,hua rong xian,华容县,华容城关镇', 29.5188900, 112.5483700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17695, 'Huaqiu', 'Huaqiu', 'Hua-ch''iu,Hua-ch''iu-pa,Hua-ch’iu,Hua-ch’iu-pa,Huaqiu,Huaqiu Zhen,Huaqiuba,hua qiu,hua qiu zhen,花秋,花秋镇', 28.1166500, 106.6022500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17696, 'Huaqiao', 'Huaqiao', 'Hua-chia-ch''iao-chen,Hua-chia-ch’iao-chen,Huajiaqiao,Huaqiao,Huaqiao Zhen,hua jia qiao,hua qiao,hua qiao zhen,花家桥,花桥,花桥镇', 31.3015600, 121.0846400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17697, 'Huaqiao', 'Huaqiao', 'Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,花桥,花桥镇', 30.0128300, 115.7168900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17698, 'Huaqiao', 'Huaqiao', 'Hua-ch''iao,Hua-ch''iao-chen,Hua-ch''iao-shih,Hua-ch’iao,Hua-ch’iao-chen,Hua-ch’iao-shih,Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,花桥,花桥镇', 28.9234200, 121.4770800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17699, 'Huaqiao', 'Huaqiao', 'Hua-ch''iao,Hua-ch’iao,Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,画桥,画桥镇', 28.5161400, 117.0428800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17700, 'Huaqiao', 'Huaqiao', 'Hua-ch''iao,Hua-ch’iao,Huaqiao,Huaqiao Xiang,hua qiao,hua qiao xiang,花桥,花桥乡', 28.5349100, 114.9594100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17701, 'Huaqiao', 'Huaqiao', 'Hua-ch''iao,Hua-ch’iao,Huaqiao', 27.7080600, 110.1419400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17702, 'Huaping', 'Huaping', 'Huaping,Huaping Xiang,hua ping,hua ping xiang,花坪,花坪乡', 30.4432500, 109.9881200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17703, 'Huaping', 'Huaping', 'Huaping,Huaping Zhen,hua ping,hua ping zhen,花坪,花坪镇', 28.0392300, 107.7927700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17704, 'Huantuo', 'Huantuo', 'Huantuo,huan tuo,欢坨', 39.2263400, 117.3239000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17705, 'Huaqiao', 'Huaqiao', 'Hua-ch''iao,Hua-ch’iao,Huanqiao,Huaqiao,Huaqiao Xiang,hua qiao,hua qiao xiang,花桥,花桥乡', 27.5948700, 118.7166800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17706, 'Fenghuangshan', 'Fenghuangshan', 'Fenghuangshan,Hua-nien,Huanian,Huanian Zhen,feng huang shan,hua nian,hua nian zhen,凤凰山,化念,化念镇', 24.0796600, 102.2065700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17707, 'Huangzhuang', 'Huangzhuang', 'Huang-chuang,Huang-chuang-chen,Huangzhuang', 39.4816700, 117.5136100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17708, 'Huangzhuang', 'Huangzhuang', 'Huang-chuang,Huangzhuang,Huangzhuang Jiedao,huang zhuang,huang zhuang jie dao,黄庄,黄庄街道', 39.3428400, 117.0551500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17709, 'Huangzhuang', 'Huangzhuang', '', 39.3147200, 117.0533300, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17710, 'Huangzhu', 'Huangzhu', 'Huang-chu,Huang-chu-shih,Huangzhu,Huangzhu Zhen,Vongchuk,Wangchiu,Wongchuk,huang zhu,huang zhu zhen,黄竹,黄竹镇', 19.4785200, 110.4387000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17711, 'Huangzhou', 'Huangzhou', 'Huang-chou,Huang-chou-chen,Huang-chou-fu,Huang-kang,Huang-kang-hsien,Huang-kang-ku-chih,Huanggang,Huangzhou,Hwangchow,Hwangchow-fu,Hwangkang,Hwangkang-hsien,Khuanchzhou,Wongkong,Хуанчжоу', 30.4500000, 114.8000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17712, 'Huangzhan', 'Huangzhan', 'Huang chan,Huangzhan,Huangzhan Zhen,huang zhan,huang zhan zhen,黄站,黄站镇', 31.5792600, 114.4982700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17713, 'Huangzhai', 'Huangzhai', 'Huang-chai,Huang-chai-chen,Huang-t''u-chai,Huang-t''u-chai-chen,Huang-t’u-chai,Huang-t’u-chai-chen,Huangzhai,Huangzhai Zhen,Hwangtuchai,Yang-ch''u,Yang-ch’ü,Yangqu,Yangqu Xian,huang zhai,huang zhai zhen,yang qu xian,阳曲县,黄寨,黄寨镇', 38.0751400, 112.6594600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17714, 'Huangze', 'Huangze', 'Huang-tse,Huang-tse-chen,Huangze,Huangze Zhen,huang ze,huang ze zhen,黄泽,黄泽镇', 29.5789400, 120.9236500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17715, 'Huangyuan Chengguanzhen', 'Huangyuan Chengguanzhen', 'Huang-yuan-hsien,Huang-yüan-hsien,Huangyuan,Huangyuan Chengguanzhen,Huangyuan Xian,Hwangyuan,Tan-ka-erh,Tangar,Thangkar,huang yuan cheng guan zhen,huang yuan xian,湟源县,湟源城关镇', 36.6874900, 101.2708400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17716, 'Huangyan', 'Huangyan', 'HYN,Huang-yen,Huang-yen-hsien,Huang-yen-hsien-ch''eng,Huang-yen-hsien-ch’eng,Huangyan,Hwang-yen-hsien,Hwangyen,huang yan,黄岩', 28.6501000, 121.2659100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17717, 'Huangxikou', 'Huangxikou', 'Huang-hsi-k''ou,Huang-hsi-k’ou,Huangxikou', 27.7188900, 110.3850000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17718, 'Donglai', 'Donglai', 'Donglai,Donglai Jiedao,Huang,Huang-hsien,Huangcheng,Huangxian,Hwanghsien,dong lai,dong lai jie dao,东莱,东莱街道', 37.6470700, 120.5227000, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17719, 'Huangwan', 'Huangwan', 'Huang-wan-chen,Huangwan,Huangwan Xiang,Huangwan Zhen,Wang-wan-chen,huang wan,huang wan xiang,huang wan zhen,黄湾,黄湾乡,黄湾镇', 30.3671500, 120.7953100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17720, 'Huangling', 'Huangling', 'Huangling,Huangling Xiang,Huangtuling,huang ling,huang ling xiang,黄岭,黄岭乡', 29.7999000, 116.5652300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17721, 'Huangtukuang', 'Huangtukuang', 'Huang-t''u-t''ang,Huang-t’u-t’ang,Huangtukeng,Huangtukuang,Khuantuken', 26.9152800, 110.4077800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17722, 'Huangtugang', 'Huangtugang', 'Huang-t''u-kang,Huang-t’u-kang,Huangtugang,Huangtugang Zhen,huang tu gang,huang tu gang zhen,黄土岗,黄土岗镇', 31.3837800, 115.0761700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17723, 'Huangtugang', 'Huangtugang', 'Huang-t''u-kang,Huang-t’u-kang,Huangtugang,Huangtugang Zhen,huang tu gang,huang tu gang zhen,黄土岗,黄土岗镇', 27.8953700, 115.2283300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17724, 'Huangtudian', 'Huangtudian', 'Huang-t''u-tien,Huang-t’u-tien,Huangtudian,Huangtudian Zhen,huang tu dian,huang tu dian zhen,黄土店,黄土店镇', 28.7325000, 111.6811100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17725, 'Huangtu', 'Huangtu', 'Heng-kung-chen,Heng-t''u,Heng-t’u,Huangtu,Huangtu Zhen,huang tu,huang tu zhen,璜土,璜土镇', 31.8744500, 120.0364700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17726, 'Huangtu', 'Huangtu', 'Huangtu,Huangtu Xiang,Huangtupo,huang tu,huang tu po,huang tu xiang,黄土,黄土乡,黄土坡', 28.7039400, 108.2639600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17727, 'Huangtian', 'Huangtian', 'Huangtian,Huangtian Zhen,huang tian,huang tian zhen,黄田,黄田镇', 23.8764900, 114.9866000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17728, 'Huangtian', 'Huangtian', 'Huang-t''ien,Huang-t’ien,Huangtian,Huangtian Zhen,huang tian,huang tian zhen,黄田,黄田镇', 23.4463700, 112.5317000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17729, 'Huangtang', 'Huangtang', 'Huang-t''ang-chen,Huang-t’ang-chen,Huangtang,Huangtang Zhen,huang tang,huang tang zhen,皇塘,皇塘镇', 31.7837700, 119.6894800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17730, 'Huangtang', 'Huangtang', 'Huang-t''ang-hsu,Huang-t’ang-hsü,Huangtang,Huangtang Zhen,huang tang,huang tang zhen,黄塘,黄塘镇', 23.6924100, 114.9913200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17731, 'Huangtan', 'Huangtan', 'Huangtan,Huangtan Zhen,huang tan,huang tan zhen,黄滩,黄滩镇', 30.9035500, 113.5709900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17732, 'Huangtan', 'Huangtan', 'Huangtan,Huangtan Zhen,huang tan,huang tan zhen,黄潭,黄潭镇', 30.6607900, 113.0847800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17733, 'Huangtan', 'Huangtan', 'Huangtan,Huangtan Xiang,huang tan,huang tan xiang,黄坛,黄坛乡', 29.5223900, 117.0783800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17734, 'Huangtan', 'Huangtan', 'Heng-t''an,Heng-t''an-shih,Heng-t’an,Heng-t’an-shih,Huang-t''an,Huang-t’an,Huangtan,Huangtan Zhen,huang tan,huang tan zhen,黄坛,黄坛镇', 29.2961100, 121.3583300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17735, 'Huangtan', 'Huangtan', 'Huangtan,Huangtan Zhen,huang tan,huang tan zhen,黄潭,黄潭镇', 26.6771200, 117.3204800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17736, 'Huangshi', 'Huangshi', 'Huang-shih,Huang-shih-kuan,Huangshi,Huangshi Xiang,Huangshi Zhen,Huangshiguan,huang shi,huang shi xiang,黄石,黄石乡', 26.2416300, 115.9343100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17737, 'Huangshi', 'Huangshi', 'Chuang-s,Chuang-š,HSD,Hoang Thach,Hoàng Thạch,Huan-shi,Huan-shih,Huang-shih,Huang-shih-shih,Huangshi,Huangshi Shi,Huangsi,Huangsji,Huangŝi,Huangši,Hwangshih,Khuangshi,Khuanshi,Khuanshu,Ng-chioh-chhi,N̂g-chio̍h-chhī,Shi hui yao,Shi-hu-yao,Shihhweiyao,Shihpao,Shikhoyya,Uong-sioh,Uòng-siŏh,huang shi,huang shi shi,hwangseu si,hwangshy,Хуангши,Хуанши,Хуаншъ,خۇئاڭشى شەھىرى,هوانگشی,ہوانگشی,黃石市,黄石,黄石市,황스 시', 30.2470600, 115.0481400, 'CN', '2013-10-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17738, 'Huangshi', 'Huangshi', 'Huang-shih,Huang-shih-shih,Huangshi,Huangshi Zhen,huang shi,huang shi zhen,黄石,黄石镇', 29.1822600, 111.1951500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17739, 'Huangshi', 'Huangshi', 'Huang-shih,Huangshi,Huangshi Zhen,huang shi,huang shi zhen,黄石,黄石镇', 25.3778600, 119.0724200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17740, 'Huangsha', 'Huangsha', 'Huang-sha-ch''iao,Huang-sha-ch’iao,Huangsha,Huangsha Zhen,Huangshaqiao,huang sha,huang sha zhen,黄沙,黄沙镇', 28.9228900, 114.6714900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17741, 'Huangshanguan', 'Huangshanguan', 'Huang-shan-kuan,Huangshanguan,Huangshanguan Zhen,huang shan guan,huang shan guan zhen,黄山馆,黄山馆镇', 37.5437600, 120.2757300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17742, 'Huangshan', 'Huangshan', 'Huangshan,Huangshan Zhen,huang shan,huang shan zhen,璜山,璜山镇', 29.5731600, 120.3245000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17743, 'Huangshan', 'Huangshan', 'Huangshan,huang shan,黄山', 26.8263400, 100.2190600, 'CN', '2014-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17744, 'Huanggang', 'Huanggang', 'Huang-sha-kang,Huanggang,Huanggang Zhen,Huangshagang,huang gang,huang gang zhen,黄港,黄港镇', 28.8606600, 114.7643400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17745, 'Huangshagang', 'Huangshagang', 'Huang-sha-kang,Huangsha,Huangshagang,Huangshagang Zhen,huang sha gang,huang sha gang zhen,黄沙岗,黄沙岗镇', 28.3158600, 115.3675500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17746, 'Huangsha', 'Huangsha', 'Huang-sha-chen,Huangsha,Huangsha Zhen,huang sha,huang sha zhen,黄沙,黄沙镇', 33.1330100, 106.7868800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17747, 'Huangshapu', 'Huangshapu', 'Huang-sha-p''u,Huang-sha-p’u,Huangsha,Huangshapu,Huangshapu Zhen,huang sha pu,huang sha pu zhen,黄沙铺,黄沙铺镇', 29.7419700, 114.6799300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17748, 'Huangsangkou', 'Huangsangkou', 'Huangsangkou,Huangsangkou Zhen,huang sang kou,huang sang kou zhen,黄颡口,黄颡口镇', 30.0141800, 115.3279500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17749, 'Huangrangping', 'Huangrangping', 'Huangrangping,Huangrangping Xiang,huang rang ping,huang rang ping xiang,黄壤坪,黄壤坪乡', 28.6833300, 111.0000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17750, 'Huangqiao', 'Huangqiao', 'Huang-ch''iao,Huang-ch''iao-chen,Huang-ch’iao,Huang-ch’iao-chen,Huangqiao,Huangqiao Zhen,Hwangkiao,Wangkia,huang qiao,huang qiao zhen,黄桥,黄桥镇', 32.2407200, 120.2327900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17751, 'Huangqiao', 'Huangqiao', 'Huang-ch''iao,Huang-ch''iao-p''u,Huang-ch’iao,Huang-ch’iao-p’u,Huangqiao', 27.0219400, 110.8405600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17752, 'Huangqiang', 'Huangqiang', 'Huangqiang,Huangqiang Zhen,huang qiang,huang qiang zhen,黄羌,黄羌镇', 23.1513700, 115.4186100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17753, 'Huangqi', 'Huangqi', 'Huang-ch''i,Huang-ch’i,Huangqi,Huangqi Zhen,huang qi,huang qi zhen,黄岐,黄岐镇', 26.3240400, 119.8837000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17754, 'Dasha', 'Dasha', 'Dasha,Dasha Jiedao,Huangpu,Whampoa,da sha,da sha jie dao,Даша,大沙,大沙街道', 23.1103700, 113.4418000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17755, 'Huangpu', 'Huangpu', 'Huangpu,Huangpu Zhen,huang pu,huang pu zhen,黄圃,黄圃镇', 22.7167100, 113.3366000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17756, 'Huangpo', 'Huangpo', 'Huang-p''o-hsu,Huang-p’o-hsü,Huangpo,Huangpo Zhen,Wu-ch''uan,Wu-ch''uan-hsien,Wu-ch’uan,Wu-ch’uan-hsien,huang po,huang po zhen,黄坡,黄坡镇', 21.3168100, 110.5882200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17757, 'Huangpi', 'Huangpi', 'Huang-p''o,Huang-pei,Huang-pei-hsien,Huang-p’o,Huangpi,Huangpi Qu,Hwangpei,Hwangpei-hsien,huang bei,huang bei qu,黄陂,黄陂区', 30.8845300, 114.3778900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17758, 'Huangnan', 'Huangnan', 'Huangnan,Huangnan Xiang,huang nan,huang nan xiang,黄南,黄南乡', 28.5291300, 120.6812800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17759, 'Huangmu', 'Huangmu', 'Huang-mu,Huang-mu-tu,Huangmu,Huangmu Zhen,Huangmudu,huang mu,huang mu zhen,黄墓,黄墓镇', 31.0772000, 118.3587400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17760, 'Huangmei', 'Huangmei', 'Huang-mei-hsien,Huangmei,Hwangmei,Hwangmei-hsien,huang mei,黄梅', 30.1923500, 116.0249600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17761, 'Huangmaoyuan', 'Huangmaoyuan', '', 27.4041700, 110.4747200, 'CN', '2004-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17762, 'Huangmao', 'Huangmao', 'Huangmao,Huangmao Zhen,huang mao,huang mao zhen,黄茅,黄茅镇', 28.1077300, 114.0727200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17763, 'Huangludian', 'Huangludian', 'Huang-lu-tien,Huangludian,Huangludian Zhen,huang lu dian,huang lu dian zhen,皇路店,皇路店镇', 33.2562800, 112.6356200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17764, 'Huanglong', 'Huanglong', 'Huang-lung,Huang-lung-tang,Huanglong,Huanglong Zhen,Huanglongdang,huang long,huang long zhen,黄龙,黄龙镇', 31.9738900, 112.4558300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17765, 'Huanglong', 'Huanglong', 'Huang-lung-p''u,Huang-lung-p’u,Huang-lung-ts''un,Huang-lung-ts’un,Huanglong', 26.5413900, 110.9344400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17766, 'Huangliu', 'Huangliu', 'Huang-liu-shih,Huangliu,Huangliu Zhen,huang liu,huang liu zhen,黄流,黄流镇', 18.5026300, 108.7891800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17767, 'Huangli', 'Huangli', 'Huang-li-chen,Huangli,Huangli Zhen,huang li,huang li zhen,湟里,湟里镇', 31.6355300, 119.7121100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17768, 'Huangli', 'Huangli', 'Huangli,Huangli Jiedao,huang li,huang li jie dao,黄历,黄历街道', 25.9117200, 117.3758000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17769, 'Huangkeng', 'Huangkeng', 'Huangkeng,Huangkeng Zhen,huang keng,huang keng zhen,黄坑,黄坑镇', 25.2242500, 114.5054100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17770, 'Huangjinjing', 'Huangjinjing', 'Huang-chin-ching,Huangjinjing,huang jin jing,黄金井', 27.5856300, 110.8913300, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17771, 'Huangjing', 'Huangjing', 'Heng-ching,Heng-ching-chen,Huang-ching,Huang-ching-chen,Huangjing,Huanjing Zhen,huang jing,huang jing zhen,璜泾,璜泾镇', 31.6518200, 121.1050000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17772, 'Huangjindong', 'Huangjindong', 'Huangjindong,Huangjindong Xiang,huang jin dong,huang jin dong xiang,黄金洞,黄金洞乡', 29.9518200, 109.0769100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17773, 'Huangjindong', 'Huangjindong', 'Huangjindong,Huangjindong Xiang,huang jin dong,huang jin dong xiang,黄金洞,黄金洞乡', 28.6515900, 114.0548700, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17774, 'Huangjinbu', 'Huangjinbu', 'Huang-chin-fou,Huang-chin-pu,Huangjinbu,Huangjinbu Zhen,Hwangkinfow,huang jin bu,huang jin bu zhen,黄金埠,黄金埠镇', 28.4792200, 116.8028600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17775, 'Huangjin', 'Huangjin', 'Huangjin,Huangjin Zhen,huang jin,huang jin zhen,黄金,黄金镇', 23.9935900, 116.3741400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17776, 'Huangjia', 'Huangjia', 'Huangjia,Huangjia Zhen,Shangyanxi,huang jia,huang jia zhen,shang yan xi,上岩西,黄家,黄家镇', 29.1239600, 108.0569400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17777, 'Huangji', 'Huangji', 'Huang-chi,Huangji,Huangji Zhen,huang ji,huang ji zhen,黄集,黄集镇', 32.3113900, 112.1326400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17778, 'Huanghuatan', 'Huanghuatan', 'Huanghuatan,Huanghuatan Xiang,huang hua tan,huang hua tan xiang,黄花滩,黄花滩乡', 39.6536100, 113.8419400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17779, 'Huanghuai', 'Huanghuai', 'Huanghuai,Huanghuai Zhen,huang huai,huang huai zhen,黄槐,黄槐镇', 24.4683600, 115.7751400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17780, 'Huanghua', 'Huanghua', 'Huang-chia-ch''ang,Huang-chia-ch’ang,Huanghua,Huanghua Xiang,Huanghuachang,huang hua,huang hua xiang,黄花,黄花乡', 30.8597600, 111.3784500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17781, 'Huanghu', 'Huanghu', 'Huang-hu-chen,Huanghu,Hwanghu,huang hu,黄湖', 30.4504600, 119.8065200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17782, 'Huangge', 'Huangge', 'Huang-ko,Huangge,Huangge Zhen,huang ge,huang ge zhen,黄阁,黄阁镇', 22.8285200, 113.5062900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17783, 'Huanggang', 'Huanggang', 'Huang-kang,Huang-kang-k''ou,Huang-kang-k’ou,Huanggang,Huanggang Xiang,Huanggangkou,huang gang,huang gang xiang,黄岗,黄岗乡', 28.4834600, 114.5435400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17784, 'Huanggang', 'Huanggang', 'Feng-kang,Fengkanghsu,Fengkanghsü,Fengkansu,Fengkansü,Huang-kang,Huanggang,Huanggang Zhen,huang gang,huang gang zhen,凰岗,凰岗镇', 29.1560900, 117.0034000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17785, 'Huanggang', 'Huanggang', 'Huang-kang,Huang-kang-ch''eng,Huang-kang-chen,Huang-kang-ch’eng,Huanggang,Huanggang Zhen,Jao-p''ing,Jao-p’ing,Khuangan,Ng kng,Raoping,Ung Kung,huang gang,Хуанган,黄冈', 23.6770400, 116.9996100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17786, 'Lizhai', 'Lizhai', 'Huangfangkou,Lizhai,Lizhai Xiang,huang fang kou,li zhai,li zhai xiang,李宅,李宅乡,黄放口', 28.3912800, 120.1977100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17787, 'Huangfang', 'Huangfang', 'Huangfang,Huangfang Xiang,huang fang,huang fang xiang,黄坊,黄坊乡', 26.9796900, 116.8791900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17788, 'Huangduobu', 'Huangduobu', 'Huangduobu,Huangduobu Xiang,huang duo bao,huang duo bao xiang,黄铎堡,黄铎堡乡', 36.3067800, 106.0661700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17789, 'Huangdu', 'Huangdu', 'Huang-tu,Huang-tu-chen,Huangdu,Huangdu Zhen,Hwangtu,huang du,huang du zhen,黄渡,黄渡镇', 31.2767200, 121.2077700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17790, 'Huangdu', 'Huangdu', 'Huangdu,Huangdu Zhen,huang dou,huang dou zhen,黄都,黄都镇', 28.4031900, 107.7443200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17791, 'Huangdao', 'Huangdao', 'Huang-tao,Huang-tao-chen,Huangdao,huang dao,黄道', 34.0678700, 113.1590700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17792, 'Daxing', 'Daxing', 'Dasin,Daxing,Huang-ts''un,Huang-ts''un-chen,Huang-ts’un,Huang-ts’un-chen,Huangcun,Ta-hsing,Ta-hsing-hsien,da xing,Дасин,大兴', 39.7402500, 116.3269300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17793, 'Huangcun', 'Huangcun', 'Huancun Xiang,Huang-ts''un,Huang-ts’un,Huangcun,huang cun,huang cun xiang,黄村,黄村乡', 30.6086800, 118.3270200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17794, 'Huangcun', 'Huangcun', 'Huang-ts''un,Huang-ts’un,Huangcun,Huangcun Xiang,huang cun,huang cun xiang,黄村,黄村乡', 28.5106800, 120.0490100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17795, 'Huangcun', 'Huangcun', 'Huang-ts''un,Huang-ts’un,Huangcun,Huangcun Zhen,huang cun,huang cun zhen,黄村,黄村镇', 23.8354600, 115.2264700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17796, 'Dingcheng', 'Dingcheng', 'Dingcheng,Huang-ch''uan-hsien,Huang-chou,Huang-ch’uan-hsien,Huangchuan,Hwangchwan,Hwangchwan-hsien,Hwangehwan,Kuang-chou,Kwangchow,ding cheng,定城', 32.1272200, 115.0394400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17797, 'Yamen', 'Yamen', 'Aimen Zhen,Heng-ch''ung-hsu,Heng-ch’ung-hsü,Huang-ch''ung,Huang-ch''ung-hsu,Huang-ch’ung,Huang-ch’ung-hsü,Huangchongxu,Yamen,Yaxi,ya men,ya men zhen,崖门,崖门镇', 22.2993600, 113.0484800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17798, 'Huangchi', 'Huangchi', 'Huang-ch''ih,Huang-ch''ih-chen,Huang-ch’ih,Huang-ch’ih-chen,Huangchi,Huangchi Zhen,Huangchizhen,Hwangchih,huang chi,huang chi zhen,黄池,黄池镇', 31.3016300, 118.6003800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17799, 'Huangcaotuo', 'Huangcaotuo', 'Huangcaotuo,huang cao tuo,荒草坨', 39.1794000, 117.3215600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17800, 'Huangcai', 'Huangcai', 'Huang-ts''ai,Huang-ts''ai-shih,Huang-ts’ai,Huang-ts’ai-shih,Huangcai,Huangcai Zhen,Hwangtsai,huang cai,huang cai zhen,黄材,黄材镇', 28.1566700, 112.1211100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17801, 'Huangbizhuang', 'Huangbizhuang', 'Huangbizhuang,Huangbizhuang Zhen,huang bi zhuang,huang bi zhuang zhen,黄壁庄,黄壁庄镇', 38.2504800, 114.3133100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17802, 'Huangbei', 'Huangbei', 'Huang-p''o-hsu,Huang-pei,Huang-p’o-hsü,Huangbei,Huangbei Zhen,huang bei,huang bei zhen,黄陂,黄陂镇', 27.3018100, 116.1242200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17803, 'Huangbei', 'Huangbei', 'Huang-p''o,Huang-pei,Huang-p’o,Huangbei,Huangbei Zhen,huang bei,huang bei zhen,黄陂,黄陂镇', 26.6922200, 115.8488900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17804, 'Huangbei', 'Huangbei', 'Huang-p''o,Huang-pei,Huang-pei-hsu,Huang-pei-hsü,Huang-p’o,Huangbei,Huangbei Zhen,Huangpi Zhen,Wongpo,huang bei,huang bei zhen,黄陂,黄陂镇', 24.4114700, 115.7381400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17805, 'Huangbayi', 'Huangbayi', 'Huang-pa-i,Huangbayi,Huangbayi Xiang,Hwangpayi,Khuanbai,huang ba yi,huang ba yi xiang,黄坝驿,黄坝驿乡', 32.7548300, 106.1267200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17806, 'Huangban', 'Huangban', 'Huang-pan,Huangban,Huangban Xiang,huang ban,huang ban xiang,黄板,黄板乡', 28.2538200, 109.1599700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17807, 'Huang’ao', 'Huang''ao', 'Huang''ao,Huang''ao Xiang,Huang’ao,Huang’ao Xiang,huang ao,huang ao xiang,黄坳,黄坳乡', 28.9795700, 114.8059600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17808, 'Hong’an Chengguanzhen', 'Hong''an Chengguanzhen', 'Chengguan Zhen,Hong''an,Hong''an Chengguanzhen,Hong''an Xian,Hong’an,Hong’an Chengguanzhen,Hong’an Xian,Huang''an,Huang-an-hsien,Huang’an,Hung-an,Hwangan,Hwanganhsien,hong an cheng guan zhen,红安城关镇', 31.3620800, 114.6368900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17809, 'Huanfeng', 'Huanfeng', 'Han-shan-hsien,Huanfeng,huan feng,环峰', 31.7166700, 118.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17810, 'Huandiqiao', 'Huandiqiao', 'Huandiqiao,Huandiqiao Jiedao,hai de qiao,hai de qiao jie dao,还地桥,还地桥街道', 30.2094500, 114.8233800, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17811, 'Huancheng', 'Huancheng', 'Huai-hsien,Huan,Huan-hsien,Huancheng,Huancheng Zhen,Huanxian,Khuan''syan'',Khuan’syan’,huan cheng,huan cheng zhen,环城,环城镇', 36.5756100, 107.2959600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17812, 'Huamu', 'Huamu', 'Huamu,Huamu Zhen,hua mu,hua mu zhen,花木,花木镇', 31.2109000, 121.5439300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17813, 'Huaminglou', 'Huaminglou', 'Huaminglou,Huaminglou Zhen,hua ming lou,hua ming lou zhen,花明楼,花明楼镇', 28.0527800, 112.6141700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17814, 'Hualongyan', 'Hualongyan', 'Hualongyan,Hualongyan Zhen,hua long yan,hua long yan zhen,化龙堰,化龙堰镇', 32.0626400, 110.5437500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17815, 'Huajialing', 'Huajialing', 'Huajialing,hua jia ling,华家岭', 35.3792700, 105.0091800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17816, 'Huaizhong', 'Huaizhong', 'Huai-chung,Huaizhong,Huaizhong Zhen,huai zhong,huai zhong zhen,怀忠,怀忠镇', 27.0875800, 114.3595500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17817, 'Huaiyuan Chengguanzhen', 'Huaiyuan Chengguanzhen', 'Huai-yuan-hsien,Huai-yüan-hsien,Huaiyuan,Huaiyuan Chengguanzhen,Hwaiyuan,Hwaiyuanhsien,Hwaiyüan,huai yuan cheng guan zhen,怀远城关镇', 32.9589300, 117.1656600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17818, 'Huaiyang Chengguanzhen', 'Huaiyang Chengguanzhen', 'Ch''en-chou,Chenchow,Chenchowfu,Ch’en-chou,Huai-yang-hsien,Huaiyang,Huaiyang Chengguanzhen,Hwaiyang,huai yang cheng guan zhen,淮阳城关镇', 33.7333300, 114.8833300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17819, 'Huaiya', 'Huaiya', 'Huai-ya-chen,Huaiya,Huaiya Zhen,huai ya,huai ya zhen,槐芽,槐芽镇', 34.2075400, 107.8725600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17820, 'Huaitu', 'Huaitu', 'Huaitu,huai tu,淮土', 26.1918400, 116.4696700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17821, 'Yunzhong', 'Yunzhong', 'Huai-jen,Huai-jen-chen,Huai-jen-hsien,Huairen Xian,Hwaijensha,Yunzhong,Yunzhong Zhen,huai ren xian,yun zhong,yun zhong zhen,云中,云中镇,怀仁县', 39.8270700, 113.0962200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17822, 'Huainan', 'Huainan', '', 32.6263900, 116.9969400, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17823, 'Huainan', 'Huainan', 'Huainan,Huainan Xiang,huai nan,huai nan xiang,槐南,槐南乡', 25.9890600, 117.7288800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17824, 'Yanshi Chengguanzhen', 'Yanshi Chengguanzhen', 'Huaimiao,Yanshi,Yanshi Chengguanzhen,Yen-shih,Yen-shih-hsien,yan shi cheng guan zhen,偃师城关镇', 34.7160100, 112.7956800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17825, 'Huaicheng', 'Huaicheng', 'Huai-ch''eng-chen,Huai-chi,Huai-chi-hsien,Huai-ch’eng-chen,Huaicheng,Huaicheng Zhen,Huaiji,Waitsap,Waitsap-hsien,huai cheng,huai cheng zhen,怀城,怀城镇', 23.9195200, 112.1762900, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17826, 'Huaihua', 'Huaihua', 'Chuaj-chua,HJJ,Hoai Hoa,Hoai-hoa-chhi,Hoài Hóa,Hoâi-hoà-chhī,Huai-hua,Huaihua,Huài-huá,Khuajkhua,Yu-shu-wan-chen,Yushuwan,Yü-shu-wan-chen,huai hua,huai hua shi,hwaihwa si,Хуайхуа,ہوایہوا,怀化市,懐化市,懷化,화이화 시', 27.5633700, 110.0040400, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17827, 'Huaihe', 'Huaihe', 'Huai-ho-tien,Huaihe,Huaihe Zhen,huai he,huai he zhen,淮河,淮河镇', 32.3463900, 113.5883700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17828, 'Huaidian', 'Huaidian', 'Huai-tien,Huai-tien-chen,Huaidian,Khuaydyan,Shen-ch''iu,Shen-ch’iu,Shenqiu', 33.4333300, 115.0333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17829, 'Huaidao', 'Huaidao', 'Huai-tao,Huaidao,Huaidao Xiang,huai dao,huai dao xiang,怀道,怀道乡', 38.6784800, 112.2413600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17830, 'Huaibei', 'Huaibei', 'Chuaj-pej,Hoai Bac,Hoai-pak-chhi,Hoài Bắc,Hoâi-pak-chhī,Hsu-kou,Hsü-kou,Huai-baek,Huai-pei,Huai-pei-shih,Huaibei,Huaibejus,Huaibėjus,Huajbej,Huaybey,Huài-báe̤k,Khuajbehj,Khuajbej,Sui-hsi-shih,huai bei,huai bei shi,hwaibei si,hwayby,Хуайбей,Хуайбэй,Хуајбеј,Հուայբեյ,هوایبی,ہوآئیبئی,ہوائیبوئی,淮北,淮北市,화이베이 시', 33.9744400, 116.7916700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17831, 'Huagu', 'Huagu', 'Hua-ku,Hua-ku-t''ang,Hua-ku-t’ang,Huagu,Huagutang,hua gu,花鼓', 30.9150500, 119.2948200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17832, 'Huaguo', 'Huaguo', 'Huaguo,Huaguo Jiedao,hua guo,hua guo jie dao,花果,花果街道', 32.6428400, 110.6743900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17833, 'Huage', 'Huage', 'Huage,Huage Zhen,hua ge,hua ge zhen,华阁,华阁镇', 29.2977800, 112.6583300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17834, 'Huagai', 'Huagai', 'Huagai,hua gai,花荄', 31.5463300, 104.5553200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17835, 'Huafeng', 'Huafeng', 'Hua''an Xian,Hua-an-hsien,Hua-feng-chen,Huafeng,Huafeng Zhen,Hua’an Xian,Hwaan,Hwafeng,hua an xian,hua feng,hua feng zhen,华丰,华丰镇,华安县', 25.0016700, 117.5275000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17836, 'Huacheng', 'Huacheng', 'Huacheng,Majinpu,Majinpu Xiang,hua cheng,ma jin pu,ma jin pu xiang,化城,马金铺,马金铺乡', 24.7885400, 102.8062300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17837, 'Huacheng', 'Huacheng', 'Ch''ang-lo,Changlok,Chonglok,Ch’ang-lo,Huacheng,Huacheng Zhen,Ngfah,Nghwa,Ngwa,Wu-hua,hua cheng,hua cheng zhen,华城,华城镇', 24.0670300, 115.6130900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17838, 'Huacao', 'Huacao', 'Hua-ts''ao-chen,Hua-ts’ao-chen,Huacao,Huacao Zhen,hua cao,hua cao zhen,华漕,华漕镇', 31.2069000, 121.2867200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17839, 'Huabu', 'Huabu', 'Hau-fou,Hua-pu,Huabu,Huabu Zhen,hua bu,hua bu zhen,华埠,华埠镇', 29.0181800, 118.3483700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17840, 'Huabeitun', 'Huabeitun', 'Hua-pei-t''un,Hua-pei-ts''un,Hua-pei-ts’un,Hua-pei-t’un,Huabeitun,Huabeitun Xiang,hua bei tun,hua bei tun xiang,化北屯,化北屯乡', 38.6988500, 112.1005200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17841, 'Houzhen', 'Houzhen', 'Hou-chen,Hou-tzu,Hou-tzu-chen,Houzhen,Houzizhen,hou zhen,厚镇', 34.2597900, 109.5079900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17842, 'Houzhai', 'Houzhai', 'Hou-chai,Hou-chai-chen,Houzhai,Houzhai Zhen,Lung-ao,Nan''ao,Nan’ao,hou zhai,hou zhai zhen,后宅,后宅镇', 23.4249100, 117.0207400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17843, 'Houxiang', 'Houxiang', '', 39.5127800, 117.1158300, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17844, 'Housuo', 'Housuo', 'Hou-so,Hou-so-ts''un,Hou-so-ts’un,Housuo,Housuo Xiang,hou suo,hou suo xiang,后所,后所乡', 39.3108300, 112.8438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17845, 'Houping', 'Houping', 'Houping,Houping Zhen,hou ping,hou ping zhen,后坪,后坪镇', 31.7439600, 111.2218400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17846, 'Houping', 'Houping', 'Houping,Houping Zhen,hou ping,hou ping zhen,后坪,后坪镇', 29.0669400, 110.3211100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17847, 'Houmen', 'Houmen', 'Hau-men,Houmen,hou men,鲘门', 22.8135400, 115.1544200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17848, 'Xintian', 'Xintian', 'Ch''u-wo,Ch''u-wu,Ch’ü-wo,Ch’ü-wu,Hou-ma-chen,Hou-ma-shih,Houma,Houma Shi,Howma,Khouma,Xintian,Xintian Xiang,hou ma shi,xin tian,xin tian xiang,侯马市,新田,新田乡', 35.6135800, 111.3566000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17849, 'Houjie', 'Houjie', 'Hou-chieh,Houjie,Houjie Zhen,Howkai,hou jie,hou jie zhen,厚街,厚街镇', 22.9445500, 113.6558500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17850, 'Houjiagang', 'Houjiagang', 'Hou-chia-kang,Houjiagang,Houjiagang Xiang,hou jia gang,hou jia gang xiang,侯家岗,侯家岗乡', 29.5232700, 116.8473800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17851, 'Houjia', 'Houjia', 'Hou-chia-chi,Houjia,Houjia Zhen,hou jia,hou jia zhen,侯家,侯家镇', 37.0198700, 122.0899500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17852, 'Hougong', 'Hougong', 'Hou-kung,Hougong,Hougong Xiang,hou gong,hou gong xiang,后宫,后宫乡', 35.3577800, 111.3983200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17853, 'Hougang', 'Hougang', 'Hougang,Hougang Zhen,hou gang,hou gang zhen,后港,后港镇', 32.6868000, 120.2544100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17854, 'Hougang', 'Hougang', 'Hou-Kang,Hougang,Hougang Zhen,hou gang,hou gang zhen,后港,后港镇', 30.5172200, 112.3838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17855, 'Houbai', 'Houbai', 'Hou-pai-shu,Houbai,Houbai Zhen,Houbaishu,hou bai,hou bai zhen,后白,后白镇', 31.8078000, 119.1785800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17856, 'Hou’an', 'Hou''an', 'Hou''an,Hou''an Xiang,Hou’an,Hou’an Xiang,hou an,hou an xiang,厚岸,厚岸乡', 30.5492400, 118.0518100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17857, 'Hor', 'Hor', 'Heri,Heri Xiang,Ho-jih,Hor,Huanke Rizha,he ri,he ri xiang,huan ke ri zha,合日乡,和日,环科日扎', 35.2323500, 100.9866200, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17858, 'Hongzhou', 'Hongzhou', 'Hongzhou,Hung-chou', 26.1258300, 109.4088900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17859, 'Hongyuan', 'Hongyuan', 'Hongyuan,Hongyuan Zhen,Hung-yuan,Hung-yüan,hong yuan,hong yuan zhen,洪源,洪源镇', 29.3217500, 117.1502600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17860, 'Hongyansi', 'Hongyansi', 'Hongyansi,Hongyansi Zhen,Hung-yen-ssu,hong yan si,hong yan si zhen,红岩寺,红岩寺镇', 30.5500600, 109.9026100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17861, 'Hongyang', 'Hongyang', 'Hongyang,Hung-yang', 26.5286100, 119.4625000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17862, 'Hongyanxi', 'Hongyanxi', 'Hongyan,Hongyanxi,Hongyanxi Xiang,Hongyanxi Zhen,Hung-yen,hong yan xi,hong yan xi xiang,hong yan xi zhen,红岩溪,红岩溪乡,红岩溪镇', 29.2859600, 109.6325600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17863, 'Hongxingqiao', 'Hongxingqiao', 'Hongxingqiao,Hung-ch''i-chen,Hung-ch’i-chen,Hung-hsing-ch''iao,Hung-hsing-ch’iao,hong xing qiao,虹星桥', 30.9233300, 119.8688900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17864, 'Hongxi', 'Hongxi', 'Hongjiatan,Hongxi,Hongxi Zhen,Hung-chia-t''an-chen,Hung-chia-t’an-chen,hong xi,hong xi zhen,洪溪,洪溪镇', 30.9108800, 120.8384900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17865, 'Hongxi', 'Hongxi', 'Hong-ch''i-chen,Hong-ch’i-chen,Hongxi,Hongxi Zhen,hong xi,hong xi zhen,虹溪,虹溪镇', 24.1450000, 103.3197200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17866, 'Hongwei', 'Hongwei', 'Hongwei,Hongwei Xiang,Hung-wei,hong wei,hong wei xiang,鸿尾,鸿尾乡', 26.1690500, 118.9962600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17867, 'Haoshui', 'Haoshui', 'Haoshui,Haoshui Xiang,Hongtulu,hao shui,hao shui xiang,hong tu lu,好水,好水乡,红土路', 35.6500000, 106.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17868, 'Dahuaishu', 'Dahuaishu', 'Dahuaishu,Dahuaishu Zhen,Hongtong,Hongtong Xian,Hung-chao,Hung-chao-hsien,Hung-tung,Hung-tung-hsien,Khundun,da huai shu,da huai shu zhen,hong dong xian,大槐树,大槐树镇,洪洞县', 36.2655600, 111.6752800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17869, 'Hongtian', 'Hongtian', 'Hongtian,Hongtian Zhen,Hung-t''ien,Hung-t’ien,hong tian,hong tian zhen,洪田,洪田镇', 25.8565100, 117.2490100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17870, 'Hongtang', 'Hongtang', 'Hongtang,Hongtang Zhen,Hongtangxiang,Hung-t''ang-hsiang,Hung-t’ang-hsiang,hong tang,hong tang zhen,洪塘,洪塘镇', 29.9517500, 121.5060700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17871, 'Hongtang', 'Hongtang', 'Hongtang,Hongtang Zhen,Hung-t''ang,Hung-t''ang-shih,Hung-t’ang,Hung-t’ang-shih,hong tang,hong tang zhen,洪塘,洪塘镇', 27.9047400, 114.2887800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17872, 'Hongsipu', 'Hongsipu', 'Hongsipu,Hongsipu Zhen,Hung-ssu-p''u,Hung-ssu-pao,Hung-ssu-p’u,hong si bao,hong si bao zhen,红寺堡,红寺堡镇', 37.3991700, 106.0602800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17873, 'Hongsihu', 'Hongsihu', 'Hongsihu,Hongsihu Xiang,hong si hu,hong si hu xiang,红寺湖,红寺湖乡', 38.8966400, 101.1687400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17874, 'Hongshi', 'Hongshi', 'Hongshi,Hongshi Zhen,Hongshiba,hong shi,hong shi zhen,红狮,红狮镇', 30.9875800, 109.0241800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17875, 'Hongshanyao', 'Hongshanyao', 'Hongshanyao,Hongshanyao Xiang,hong shan yao,hong shan yao xiang,红山窑,红山窑乡', 38.3000000, 101.6000000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17876, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Zhen,hong shan,hong shan zhen,红山,红山镇', 30.7699900, 115.6500500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17877, 'Hongqiao', 'Hongqiao', 'Hongqiao,hong qiao,洪桥', 30.9892800, 119.9848000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17878, 'Hongqiao', 'Hongqiao', 'Hongqiao,Hongqiao Zhen,Hung-ch''iao,Hung-ch''iao-chen,Hung-chia-chen,Hung-ch’iao,Hung-ch’iao-chen,hong qiao,hong qiao zhen,虹桥,虹桥镇', 28.2214500, 121.0286000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17879, 'Hongmiao', 'Hongmiao', 'Hongmiao,Hongmiao Zhen,Hongmiaotang,Hung-miao,Hung-miao-t''ang,Hung-miao-t’ang,hong miao,hong miao zhen,红庙,红庙镇', 32.8643900, 106.9135800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17880, 'Hongmen', 'Hongmen', 'Hongmen,Hongmen Zhen,Hung-men,hong men,hong men zhen,洪门,洪门镇', 27.4917800, 116.7106900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17881, 'Honglu', 'Honglu', 'Honglu,Honglu Zhen,Hung-lu,hong lu,hong lu zhen,红炉,红炉镇', 29.3519800, 105.7268000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17882, 'Honglu', 'Honglu', 'Honglu,Honglu Zhen,Hung-lu,hong lu,hong lu zhen,宏路,宏路镇', 25.7058100, 119.3142000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17883, 'Honglong', 'Honglong', 'Honglong,Honglongdian,Hsia-chiang-wu,Huang-lung-tien,Hung-lung,Hung-lung-tien,hong long,虹龙', 30.4987500, 119.0044700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17884, 'Honglin', 'Honglin', 'Honglin,Honglin Zhen,Honglinqiao,Hung-lin-ch''iao,Hung-lin-ch’iao,hong lin,hong lin zhen,洪林,洪林镇', 30.9797200, 118.9820200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17885, 'Hongling', 'Hongling', 'Hongling,Hongling Zhen,hong ling,hong ling zhen,红岭,红岭镇', 24.4714700, 113.9570500, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17886, 'Honglan', 'Honglan', 'Honglan,Honglan Zhen,Hung-lan,Hung-lan-fou,hong lan,hong lan zhen,洪蓝,洪蓝镇', 31.6073200, 118.9802300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17887, 'Honglai', 'Honglai', 'Honglai,Honglai Zhen,Hung-lai,hong lai,hong lai zhen,洪濑,洪濑镇', 25.0789500, 118.5162600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17888, 'Hongkou', 'Hongkou', 'Hongkew,Hongkou,Hung-k''ou,Hung-k''ou-ch''u,Hung-k’ou,Hung-k’ou-ch’ü,hong kou,虹口', 31.2500000, 121.4891700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17889, 'Donghe', 'Donghe', 'Donghe,Donghe Zhen,Feng-chia-pa,Fengjiaba,Hongjiang,Vantsanba,Wang-ts''ang,Wang-ts''ang-hsien,Wang-ts''ang-pa,Wang-ts’ang,Wang-ts’ang-hsien,Wang-ts’ang-pa,Wangcang,Wangcang Xian,Wangsangpa,dong he,dong he zhen,wang cang,wang cang xian,东河,东河镇,旺苍,旺苍县', 32.2334100, 106.3012600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17890, 'Hongjiang', 'Hongjiang', 'Hongjiang,Hongjiang Xiang,Hung-chiang,hong jiang,hong jiang xiang,洪江,洪江乡', 27.6202700, 114.3929200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17891, 'Hongjiang', 'Hongjiang', 'Ch''ien-yang,Ch’ien-yang,Hongjiang,Hung-chiang,Hung-chiang-chen,Hung-chiang-shih,Hungkiang,Khuntszyan', 27.1100000, 109.9955600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17892, 'Hongjiaguan', 'Hongjiaguan', 'Hongjiaguan,Hongjiaguan Baizuxiang,Hung-chia-kuan,hong jia guan,hong jia guan bai zu xiang,洪家关,洪家关白族乡', 29.4770800, 110.1667700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17893, 'Hongjia', 'Hongjia', 'Hongjia,Hongjia Jiedao,Hung-chia,Hung-chia-ch''ang,Hung-chia-ch’ang,Hungkia,Hungkiachang,hong jia,hong jia jie dao,洪家,洪家街道', 28.6142100, 121.4131500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17894, 'Honghuatao', 'Honghuatao', 'Honghuatao,Honghuatao Zhen,Hung-Hwa-Kau,Hung-hua-t''ao,Hung-hua-t’ao,Hung-wha-taou,hong hua tao,hong hua tao zhen,红花套,红花套镇', 30.5145300, 111.4034000, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17895, 'Honghe', 'Honghe', 'Honghe,Honghe Xiang,hong he,hong he xiang,红河,红河乡', 35.7666700, 106.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17896, 'Hongdu', 'Hongdu', 'Hongdu,Hongdu Zhen,hong du,hong du zhen,洪渡,洪渡镇', 28.9625900, 108.3132500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17897, 'Hongde', 'Hongde', 'Hongde,Hongde Xiang,Hung-te,Hung-te-ch''eng,Hung-te-ch’eng,Hung-to-tsch''ong,Hung-tö-tsch’öng,Hungtu,Khunde,Kung-te-ch''eng,Kung-te-ch’eng,hong de,hong de xiang,洪德,洪德乡', 36.7413800, 107.1843100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17898, 'Hongchuan', 'Hongchuan', 'Hongchuan,Hongchuan Zhen,hong chuan,hong chuan zhen,红川,红川镇', 33.7505600, 105.8908300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17899, 'Hong’an', 'Hong''an', 'Hong''an,Hong''an Zhen,Hong’an,Hong’an Zhen,hong an,hong an zhen,洪安,洪安镇', 28.5022800, 109.2666100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17900, 'Hezuoqiao', 'Hezuoqiao', 'Hezuoqiao,Hezuoqiao Xiang,he zuo qiao,he zuo qiao xiang,合作桥,合作桥乡', 29.2180600, 110.5750000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17901, 'Hezuo', 'Hezuo', 'Hei-ts''o,Hei-ts’o,Hezuo,Hezuo Shi,Hezuo Zhen,Hezuozhen,Ho-tso,Hu-yen-k''eng-erh,Hu-yen-k’eng-erh,Khuyankor,Khuyankyr,Khuyankör,Te-wu-lu,Te-wu-lu-shih,he zuo,he zuo shi,he zuo zhen,合作,合作市,合作镇', 34.9855600, 102.9094400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17902, 'Hezhi', 'Hezhi', 'Hezhi,Hezhi Xiang,Ho-chih,Ho-chih-ts''un,Ho-chih-ts’un,he zhi,he zhi xiang,贺职,贺职乡', 39.0927500, 111.8501600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17903, 'Hezheng Chengguanzhen', 'Hezheng Chengguanzhen', 'Hezheng,Hezheng Chengguanzhen,Hezheng Xian,Ho-ch''eng,Ho-cheng-hsien,Ho-ch’eng,Khechzhen,Ning-ho,Ning-ho-pao,Ninghochwang,Ninkhe,he zheng cheng guan zhen,he zheng xian,和政县,和政城关镇', 35.4299900, 103.3572500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17904, 'Hezhang', 'Hezhang', 'Hei-chang,Hezhang,Hezhang Xian Chengguanzhen,Ho-chang,Ho-chang-hsien,he zhang,he zhang xian cheng guan zhen,赫章,赫章县城关镇', 27.1222200, 104.7238900, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17905, 'Heze', 'Heze', 'Caozhou,Che-ce,Ha Trach,Ha-tek-chhi,He-tse,Heze,Ho-dek,Ho-tse,Ho-tse-shih,Hotseh,Hotseh-hsien,Hà Trạch,Hâ-te̍k-chhī,Hê-tse,Hò̤-dĕk,Khece,Khehczeh,Ko-tse,Ko-tse-hsien,Ts''ao-chou,Ts''aochow,Tsaochowfu,Ts’ao-chou,Ts’aochow,he ze,he ze shi,heojjeo si,hzh,ka ze shi,Хеце,Хэцзэ,هزه,ہازا,カ沢市,菏泽,菏泽市,菏澤,허쩌 시', 35.2392900, 115.4735800, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17906, 'Heyin', 'Heyin', 'Guide,Guide Xian,Heyin,Heyin Zhen,Ho-yin,Ho-yin-chen,Kuei-te,Kuei-te-hsien,Kui-to,Kui-tö,Kweiteh,Kweitehting,Kweithting,gui de,gui de xian,he yin,he yin zhen,河阴,河阴镇,贵德,贵德县', 36.0440800, 101.4287400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17907, 'Hechuan', 'Hechuan', 'Hechuan,Heyang,Ho-ch''uan,Ho-ch''uan-hsien,Ho-ch''uan-shih,Ho-chou,Ho-ch’uan,Ho-ch’uan-hsien,Ho-ch’uan-shih,Hochow,Hochwan,Hochwan-hsien,he chuan,合川', 29.9922800, 106.2646100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17908, 'Hexing', 'Hexing', 'Hexing,Hexing Xiang,he xing,he xing xiang,和兴,和兴乡', 33.2229200, 113.9793300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17909, 'Hexiangqiao', 'Hexiangqiao', 'Hexiangqiao,Hexiangqiao Zhen,Ho-hsiang-ch''iao,Ho-hsiang-ch’iao,he xiang qiao,he xiang qiao zhen,荷香桥,荷香桥镇', 27.2202800, 110.9633300, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17910, 'Hexia', 'Hexia', 'Hexia,Hexia Zhen,Ho-hsia,he xia,he xia zhen,河下,河下镇', 27.7928900, 114.8485000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17911, 'Hexi', 'Hexi', 'Hexi,Ho-hsi,Ho-hsi-fang,he xi,河西', 34.9453700, 107.7955300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17912, 'Hexi', 'Hexi', 'Hexi,Hexi Zhen,Ho-hsi,he xi,he xi zhen,河溪,河溪镇', 28.2232700, 109.8119600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17913, 'Hexi', 'Hexi', 'Ching-ning,Hexi,Hexi Zhen,Ho-hsi,he xi,he xi zhen,鹤溪,鹤溪镇', 27.9744400, 119.6308300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17914, 'Hexi', 'Hexi', 'Hexi,Hexi Xiang,Xinan,he xi,he xi xiang,xi nan,合溪,合溪乡,溪南', 24.8798200, 116.7238800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17915, 'Hetoudian', 'Hetoudian', 'Hetoudian,Hetoudian Zhen,Ho-t''ou-tien,Ho-t’ou-tien,he tou dian,he tou dian zhen,河头店,河头店镇', 37.0183700, 120.5737200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17916, 'Hetou', 'Hetou', 'Hetou,Hetou Xiang,Ho-t''ou,Ho-t’ou,he tou,he tou xiang,河头,河头乡', 39.7417500, 113.2736200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17917, 'Hetou', 'Hetou', 'Hetou,Hetou Zhen,Ho-t''ou,Ho-t''ou-chen,Ho-t’ou,Ho-t’ou-chen,he tou,he tou zhen,河头,河头镇', 28.9958500, 121.0949400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17918, 'Hetou', 'Hetou', 'Hetou,Hetou Zhen,Ho-t''ou,Ho-t''ou-hsu,Ho-t’ou,Ho-t’ou-hsü,he tou,he tou zhen,河头,河头镇', 21.0576900, 109.8506200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17919, 'Hetian', 'Hetian', 'Hetian,Hetian Zhen,Ho-t''ien,Ho-t''ien-hsun,Ho-t’ien,Ho-t’ien-hsün,Hotein,he tian,he tian zhen,河田,河田镇', 25.6670000, 116.4154300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17920, 'Hetian', 'Hetian', 'Hetian,Hetian Zhen,Ho-t''ien,Ho-t''ien-hsu,Ho-t’ien,Ho-t’ien-hsü,Hotin,he tian,he tian zhen,河田,河田镇', 23.3014300, 115.6569900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17921, 'Hetang', 'Hetang', 'Hetang,Hetang Zhen,Ho-tang,he tang,he tang zhen,鹤塘,鹤塘镇', 26.6627600, 119.1106200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17922, 'Hetan', 'Hetan', 'Hetan,Hetan Zhen,Hetanbu,Ho-t''an,Ho-t''an-fou,Ho-t’an,Ho-t’an-fou,he tan,he tan zhen,河潭,河潭镇', 28.3681800, 117.2960700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17923, 'Yixing', 'Yixing', 'Heshun,Heshun Xian,Ho-shun,Ho-shun-hsien,Kheshun,Yixing,Yixing Zhen,he shun xian,yi xing,yi xing zhen,义兴,义兴镇,和顺县', 37.3376000, 113.5392600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17924, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,Ho-shui,he shui,he shui zhen,合水,合水镇', 28.0508600, 108.5498300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17925, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,Ho-shui,he shui,he shui zhen,合水,合水镇', 27.9808300, 109.9286100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17926, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,he shui,he shui zhen,合水,合水镇', 24.3950100, 114.9346200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17927, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,Ho-shui,he shui,he shui zhen,合水,合水镇', 22.3686500, 111.4097300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17928, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,Ho-shui,Ho-shui-hsu,Ho-shui-hsü,Hopshuihu,Hopshuihü,he shui,he shui zhen,合水,合水镇', 22.3024800, 111.8651400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17929, 'Heshi', 'Heshi', 'Heshi,Heshi Zhen,Ho-shih,he shi,he shi zhen,何市,何市镇', 28.8394300, 114.6100500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17930, 'Heshi', 'Heshi', 'Heshi,Heshi Zhen,he shi,he shi zhen,合市,合市镇', 28.0200200, 116.6503900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17931, 'Heshi', 'Heshi', 'Hao-shih,Hao-shu-xia,Heshi,Heshi Zhen,Ho-shih,Hokschua,he shi,he shi zhen,鹤市,鹤市镇', 24.0085100, 115.3590000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17932, 'Heshengbao', 'Heshengbao', 'Heshengbao,Heshengbao Xiang,Heshengbu,Ho-sheng-pao,he sheng bao,he sheng bao xiang,合盛堡,合盛堡乡', 39.5752600, 112.9058400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17933, 'Hesheng', 'Hesheng', 'Hao-sheng-ts''un,Hao-sheng-ts’un,Hesheng,Hesheng Xiang,Ho-sheng,he sheng,he sheng xiang,鹤盛,鹤盛乡', 28.3754300, 120.8347900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17934, 'Heshe', 'Heshe', 'Heshe,Heshe Zhen,he she,he she zhen,和舍,和舍镇', 19.5973400, 109.7207500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17935, 'Heshang', 'Heshang', 'Heshang,Heshang Zhen,Ho-chen,Ho-shang-chen,Ho-shang-tien,he shang,he shang zhen,河上,河上镇', 29.9434100, 120.1606800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17936, 'Jianshe', 'Jianshe', 'Ch''ang-ko,Ch''ang-ko-hsien,Changge,Ch’ang-ko,Ch’ang-ko-hsien,Heshangqiao,Ho-shang-ch''iao,Ho-shang-ch’iao,Jianshe,jian she,建设', 34.2175000, 113.7688900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17937, 'Heshang', 'Heshang', 'Hao-shang,Heshang,Heshang Zhen,he shang,he shang zhen,鹤上,鹤上镇', 25.9502900, 119.5483600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17938, 'Yiyang', 'Yiyang', 'Heshan,I-yang,I-yang-ch''eng,I-yang-ch’eng,I-yang-hsien,I-yang-shih,I-yeng,Ijan,Yiyang,Yiyang-hsien,Иян', 28.5891700, 112.3283300, 'CN', '2015-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17939, 'Heshan', 'Heshan', 'Heshan,Heshan Zhen,Ho-shan,Ho-shan-hsu,Ho-shan-hsü,Hopshan,he shan,he shan zhen,合山,合山镇', 21.9651800, 112.1280000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17940, 'Herong', 'Herong', 'Herong,Herong Zhen,Ho-jung,Ho-jung-chen,Ho-yong-chen,he rong,he rong zhen,河溶,河溶镇', 30.7069300, 111.9726600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17941, 'Wenbi', 'Wenbi', 'Chiu-ho-ch''u,Chiu-ho-ch’ü,Hequ,Hequ Xian,Ho-ch''u,Ho-ch''u-ch''eng,Ho-ch''u-hsien,Ho-ch’ü,Ho-ch’ü-ch’eng,Ho-ch’ü-hsien,Hoku,Hokuhsien,Hokü,Hokühsien,Wenbi,Wenbi Zhen,he qu xian,wen bi,wen bi zhen,文笔,文笔镇,河曲县', 39.3874000, 111.1911500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17942, 'Heqiao', 'Heqiao', 'Heqiao,Heqiao Zhen,Ho-ch''iao,Ho-ch''iao-chen,Ho-ch’iao,Ho-ch’iao-chen,he qiao,he qiao zhen,和桥,和桥镇', 31.4847500, 119.8845700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17943, 'Heqiao', 'Heqiao', 'Heqiao,Ho-ch''iao,Ho-ch''iao-chen,Ho-ch’iao,Ho-ch’iao-chen,he qiao,河桥', 30.1036100, 119.2302800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17944, 'Hepu', 'Hepu', 'Hepu,Hepu Zhen,Ho-p''u,Ho-p’u,he pu,he pu zhen,河铺,河铺镇', 30.9938300, 115.3825700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17945, 'Hepu', 'Hepu', 'Hepu,Hepu Zhen,Ho-p''u,Ho-p’u,he pu,he pu zhen,鹤浦,鹤浦镇', 29.1530800, 121.9030900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17946, 'Hepo', 'Hepo', 'Chieh-hsi,Hepo,Ho-p''o,Ho-p''o-hsu,Ho-p’o,Ho-p’o-hsü,Jiexi,Khehpo,he po,Хэпо,河婆', 23.4307700, 115.8299100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17947, 'Heping', 'Heping', 'Heping,Ho-p''ing,Ho-p''ing-chen,Ho-p’ing,Ho-p’ing-chen,he ping,和平', 30.8311100, 119.8983300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17948, 'Hepingyizu', 'Hepingyizu', 'Chin-k''ou-ho,Chin-k’ou-ho,Heping,Hepingyizu,Jinkouhe,Kinkowho,he ping yi zu,和平彝族', 29.2469300, 103.0824900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17949, 'Heping', 'Heping', 'Heping,Heping Zhen,Yanhe,Yanhe Tujiazu Zizhixian,Yen-ho,Yen-ho-hsien,Yenhosze,he ping,he ping zhen,yan he tu jia zu zi zhi xian,和平,和平镇,沿河土家族自治县', 28.5579000, 108.4900000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17950, 'Heping', 'Heping', 'Heping,Heping Zhen,Ho-p''ing,Ho-p’ing,he ping,he ping zhen,和平,和平镇', 25.3416500, 117.4221000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17951, 'Heping', 'Heping', 'Heping,Heping Zhen,Ho-p''ing,Ho-p’ing,he ping,he ping zhen,和平,和平镇', 23.2536000, 116.4769200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17952, 'Hengzhou', 'Hengzhou', 'Heng,Heng-chou-chen,Heng-hsien,Hengchou,Hengchow,Hengxian,Hengzhou,Hengzhou Zhen,heng zhou,heng zhou zhen,横州,横州镇', 22.6886200, 109.2658900, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17953, 'Hengyang', 'Hengyang', 'Cheng-jang,Fen-yong-su,Fên-yòng-sṳ,HNY,Hanh Duong,Henan,Henchow,Heng-chou,Heng-iong,Heng-iong-chhi,Heng-nan,Heng-nan-hsien,Heng-yang-ch''eng,Heng-yang-ch’eng,Heng-yang-shih,Hengchow,Hengchowfu,Hengjang,Hengjangas,Hengyang,Hengyang-hsien,Hành Dương,Hèng-iòng,Hêng-iông-chhī,Khehnujan,Khengjang,Khunjan,Xengyang shehiri,Xéngyang shehiri,heng yang,heng yang shi,heong-yang si,hngyang,Хенгјанг,Хънян,Хэнъян,Հենան,هنگیانگ,ہینگیانگ,衡阳市,衡陽,衡陽市,헝양 시', 26.8894600, 112.6188800, 'CN', '2014-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17954, 'Hengxianhe', 'Hengxianhe', 'Heng-hsien-ho,Hengxianhe,Hengxianhe Zhen,Hui-ch''ien-ho,Hui-ch’ien-ho,Hui-hsien-ho,heng xian he,heng xian he zhen,横现河,横现河镇', 33.3395100, 106.0818800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17955, 'Hengxi', 'Hengxi', 'Heng-ch''i,Heng-ch''i-ch''iao,Heng-ch’i,Heng-ch’i-ch’iao,Heng-hsi,Hengxi,Hengxi Zhen,heng xi,heng xi zhen,横溪,横溪镇', 31.7166700, 118.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17956, 'Hengxizhen', 'Hengxizhen', 'Heng-hsi,Heng-hsi-chen,Hengxi,Hengxi Zhen,Hengxizhen,heng xi,heng xi zhen,横溪,横溪镇', 29.7254900, 121.5904300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17957, 'Hengxi', 'Hengxi', 'Heng-ch''i,Heng-ch’i,Heng-hsi,Hengxi,Hengxi Zhen,heng xi,heng xi zhen,横溪,横溪镇', 28.7350800, 120.4716300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17958, 'Hengtang', 'Hengtang', 'Hengtang,Hengtang Zhen,Huang-t''ang-p''u,Huang-t’ang-p’u,heng tang,heng tang zhen,横塘,横塘镇', 29.3465800, 115.8869100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17959, 'Hengshui', 'Hengshui', 'Cheng-suej,Cheng-šuej,Hanh Thuy,Heng-chui-chhi,Heng-cui,Heng-shui-ch''eng-kuan,Heng-shui-ch’eng-kuan,Heng-shui-hsien,Hengshui,Hành Thủy,Hèng-cūi,Hêng-chúi-chhī,Khehnshuj,Khengshuej,Khenshuy,heng shui,heng shui shi,heongsu-i si,hngshwy,Хенгшуеј,Хэншуй,هنگشوی,ہینگشوئی,衡水,衡水市,헝수이 시', 37.7322200, 115.7011100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17960, 'Hengshui', 'Hengshui', 'Heng-shui-chen,Hengshui,Hengshui Zhen,heng shui,heng shui zhen,横水,横水镇', 34.4688100, 107.5241900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17961, 'Hengshui', 'Hengshui', 'Ch''ung-i,Ch''ung-i-hsien,Chongyi,Chongyi Xian,Ch’ung-i,Ch’ung-i-hsien,Hengshui,Tsungi,Tsungyi-hsien,chong yi xian,heng shui,崇义县,横水', 25.7000000, 114.3166700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17962, 'Hengshanqiao', 'Hengshanqiao', 'Heng-shan-ch''iao,Heng-shan-ch’iao,Hengshanqiao,Hengshanqiao Zhen,heng shan qiao,heng shan qiao zhen,横山桥,横山桥镇', 31.7637300, 120.1115000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17963, 'Kaiyun', 'Kaiyun', 'Heng-shan-ch''eng,Heng-shan-ch’eng,Heng-shan-hsien,Hengshan,Kaiyun,kai yun,开云', 27.2135100, 112.8559900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17964, 'Hengshan', 'Hengshan', 'Heng-shan-hsu,Heng-shan-hsü,Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横山,横山镇', 23.5310500, 112.3724900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17965, 'Hengshan', 'Hengshan', 'Hang-shan-hsu,Heng-shan-hsu,Heng-shan-hsü,Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横山,横山镇', 21.4748000, 110.0642200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17966, 'Hengqu', 'Hengqu', 'Heng-ch''u,Heng-ch''u-chen,Heng-ch’ü,Heng-ch’ü-chen,Hengqu,Hengqu Zhen,Khentsyuy,heng qu,heng qu zhen,横渠,横渠镇', 34.1962700, 107.9598500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17967, 'Hengqiao', 'Hengqiao', 'Heng-ch''iao,Heng-ch’iao,Hengqiao,Hengqiao Xiang,Hsi-heng-ch''iao,Hsi-heng-ch’iao,Tung-heng-ch''iao,Tung-heng-ch’iao,heng qiao,heng qiao xiang,横桥,横桥乡', 35.5775700, 111.2237100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17968, 'Hengpi', 'Hengpi', 'Hengpi,Hengpi Zhen,heng bei,heng bei zhen,横陂,横陂镇', 22.0380700, 112.3181600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17969, 'Henglu', 'Henglu', 'Henglu,Henglutou,heng lu,横路', 30.3097200, 119.3141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17970, 'Henglu', 'Henglu', 'Heng-lu-p''u,Heng-lu-p’u,Henglu,Henglu Xiang,heng lu,heng lu xiang,横路,横路乡', 29.4150000, 115.1094400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17971, 'Henglin', 'Henglin', 'Heng-lin-chen,Henglin,Henglin Zhen,Wanglin,heng lin,heng lin zhen,横林,横林镇', 31.6984600, 120.0955400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17972, 'Hengliang', 'Hengliang', 'Heng-liang-tien,Hengliang,Hengliang Zhen,Hengliangdian,heng liang,heng liang zhen,横梁,横梁镇', 32.3261500, 118.9307000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17973, 'Hengli', 'Hengli', 'Heng-li-hsu,Heng-li-hsü,Hengli,Hengli Zhen,Wanglik,heng li,heng li zhen,横沥,横沥镇', 23.1714100, 114.6199200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17974, 'Hengli', 'Hengli', 'Heng-li-hsu,Heng-li-hsü,Hengli,Hengli Zhen,Wanglikhu,Wanglikhü,heng li,heng li zhen,横沥,横沥镇', 23.0288700, 113.9534000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17975, 'Henglan', 'Henglan', 'Henglan,Henglan Zhen,heng lan,heng lan zhen,横栏,横栏镇', 22.5337200, 113.2484600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17976, 'Hengjing', 'Hengjing', 'Hengjing,Hengjing Zhen,heng jing,heng jing zhen,横泾,横泾镇', 32.9169000, 119.6921300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17977, 'Hengjie', 'Hengjie', 'Heng-chieh,Hengjie,Hengjie Zhen,heng jie,heng jie zhen,横街,横街镇', 28.7043900, 118.1431000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17978, 'Hengjiang', 'Hengjiang', 'Heng-chiang,Hengjiang,Hengjiang Zhen,Huang-chiang,heng jiang,heng jiang zhen,横江,横江镇', 26.1434500, 116.3488000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17979, 'Hengjian', 'Hengjian', 'Heng-chien,Hengjian,Hengjian Xiang,Hung-chien-ts''un,Hung-chien-ts’un,heng jian,heng jian xiang,横涧,横涧乡', 39.2729600, 113.8802200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17980, 'Henghe', 'Henghe', 'Heng-ho,Heng-ho-shih,Henghe,Henghe Zhen,heng he,heng he zhen,横河,横河镇', 30.1293200, 121.2371000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17981, 'Henghe', 'Henghe', 'Heng-ho,Henghe,Henghe Zhen,heng he,横河', 23.3437600, 114.1171000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17982, 'Henggouqiao', 'Henggouqiao', 'Heng-kou-ch''iao,Heng-kou-ch’iao,Henggouqiao,Henggouqiao Zhen,heng gou qiao,heng gou qiao zhen,横沟桥,横沟桥镇', 29.9322000, 114.3562900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17983, 'Henggang', 'Henggang', 'Heng-kang,Henggang,Henggang Zhen,heng gang,heng gang zhen,横港,横港镇', 29.5566000, 115.4877600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17984, 'Henggang', 'Henggang', 'Heng-kang,Heng-kang-hsu,Heng-kang-hsü,Henggang,Henggang Jiedao,Wangkong,heng gang,heng gang jie dao,横岗,横岗街道', 22.6489000, 114.1961200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17985, 'Hengfan', 'Hengfan', 'Heng-fan-chen,Hengfan,Hengpan,Hueng-pan,heng fan,横畈', 30.3307400, 119.7512300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17986, 'Hengdong Chengguanzhen', 'Hengdong Chengguanzhen', 'Heng-tung,Hengdong,Hengdong Chengguanzhen,Wu-chi,heng dong cheng guan zhen,衡东城关镇', 27.0833300, 112.9500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17987, 'Hengdian', 'Hengdian', 'Heng-tien,Hengdian,Hengdian Jiedao,heng dian,heng dian jie dao,横店,横店街道', 30.8053200, 114.2917200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17988, 'Hengdian', 'Hengdian', 'Hengdian,Hengdian Zhen,heng dian,heng dian zhen,横店,横店镇', 29.1569800, 120.3147800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17989, 'Hengbanqiao', 'Hengbanqiao', 'Heng-pan-ch''iao,Heng-pan-ch’iao,Hengbanqiao,Hengbanqiao Zhen,heng ban qiao,heng ban qiao zhen,横板桥,横板桥镇', 27.1716700, 110.8652800, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17990, 'Hema', 'Hema', 'Hema,Hema Zhen,he ma,he ma zhen,合马,合马镇', 28.0386100, 106.3280600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17991, 'Helong', 'Helong', 'Helong,Helong Xiang,he long,he long xiang,合龙,合龙乡', 25.9445000, 116.1341400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17992, 'Helixi', 'Helixi', 'Helixi,Helixi Zhen,Ho-li-ch''i,Ho-li-ch''i-chen,Ho-li-chu,Ho-li-chü,Ho-li-ch’i,Ho-li-ch’i-chen,Ho-li-hsi,Ho-li-hsi-chen,Holiki,Ning-kuo,Ning-kuo-hsien,Ningguo,Ningguo Shi,Ningkwo,Ningkwohsien,he li xi,he li xi zhen,ning guo,ning guo shi,宁国,宁国市,河沥溪,河沥溪镇', 30.6284100, 118.9812400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17993, 'Helin', 'Helin', 'Helin,Helin Zhen,Ho-lin-chen,Majiachang,he lin,he lin zhen,ma jia chang,和林,和林镇,马家场', 30.5812300, 107.6806400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17994, 'Helie', 'Helie', 'Binhu Qu,Helie,Helie Jiedao,bin hu qu,he lie,he lie jie dao,河埒,河埒街道,滨湖区', 31.5214000, 120.2896100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17995, 'Hele', 'Hele', 'Hele,Hele Zhen,Ho-le,Ho-lo-shih,he le,he le zhen,和乐,和乐镇', 18.9018100, 110.4726300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17996, 'Helang', 'Helang', 'Helang,Helang Zhen,he lang,he lang zhen,河塱,河塱镇', 22.5569400, 111.8577200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17997, 'Heku', 'Heku', 'Heku,Heku Zhen,he ku,he ku zhen,禾库,禾库镇', 28.1871500, 109.4726100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17998, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,Ho-k''ou,Ho-k''ou-chien,Ho-k’ou,Ho-k’ou-chien,Kou-k''ou,Kou-k’ou,he kou,he kou zhen,河口,河口镇', 33.9590300, 106.8149000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(17999, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,Ho-k''ou,Ho-k''ou-chen,Ho-k’ou,Ho-k’ou-chen,Hokow,he kou,he kou zhen,河口,河口镇', 31.3175700, 114.4322800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18000, 'Hekou', 'Hekou', 'Hekou,Hekou Xiang,Hua-li-kang,he kou,he kou xiang,河口,河口乡', 31.2705300, 111.6374200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18001, 'Hekou', 'Hekou', 'Guandupu,Hekou,Hekou Zhen,Ho-k''ou,Ho-k’ou,Hohkow,Hokow,guan du pu,he kou,he kou zhen,合口,合口镇,管渡铺', 29.6288600, 111.5796100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18002, 'Pailou', 'Pailou', 'Hekou,Hekou Xiang,Ho-k''ou,Ho-k’ou,Pailou,he kou,he kou xiang,pai lou,河口,河口乡,牌楼', 29.5498700, 109.8570700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18003, 'Hekou', 'Hekou', 'Ch''ien-shan,Ch’ien-shan,Hekou,Hekou Zhen,Ho-k''ou,Ho-k''ou-chen,Ho-k’ou,Ho-k’ou-chen,Hokow,Hokowchen,Qianshan Xian,Yanshan,Yen-shan,he kou,he kou zhen,qian shan xian,河口,河口镇,铅山县', 28.3158500, 117.7084300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18004, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,Ho-k''ou,Ho-k''ou-hsu,Ho-k’ou,Ho-k’ou-hsü,he kou,he kou zhen,河口,河口镇', 23.1796300, 115.6067700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18005, 'Hekou', 'Hekou', 'Hekou,Hekou Jiedao,he kou,he kou jie dao,河口,河口街道', 22.9638200, 112.1106700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18006, 'Hekou', 'Hekou', 'Hekou,Ho-k''ou,Ho-k''ou-hsien,Ho-k''ou-shih,Ho-k''ou-yao-tsu-miao-tsu-tzu-chih-hsien,Ho-k''ou-yao-tsu-tzu-chih-hsien,Ho-k’ou,Ho-k’ou-hsien,Ho-k’ou-shih,Ho-k’ou-yao-tsu-miao-tsu-tzu-chih-hsien,Ho-k’ou-yao-tsu-tzu-chih-hsien,Hokow,Hokow-hsien,he kou,河口', 22.5385100, 104.0110900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18007, 'Hekou', 'Hekou', 'Chien-shui-hsu,Chien-shui-hsü,Hekou,Hekou Zhen,Ho-k''ou,Ho-k''ou-hsu,Ho-k’ou,Ho-k’ou-hsü,he kou,he kou zhen,河口,河口镇', 21.9666700, 111.6833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18008, 'Hejiayan', 'Hejiayan', 'Hejiayan,Hejiayan Zhen,Ho-chia-ya,Ho-chia-yai,Ho-chia-yen,he jia yan,he jia yan zhen,何家岩,何家岩镇', 33.2589700, 106.3258300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18009, 'Hewan', 'Hewan', 'Hejiawan,Hewan,Hewan Zhen,Ho-chia-wan,Ho-wan,he wan,he wan zhen,何湾,何湾镇', 30.8163200, 118.0809900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18010, 'Hejiaping', 'Hejiaping', 'Hejiaping,Hejiaping Zhen,Ho-chia-p''ing,Ho-chia-p’ing,he jia ping,he jia ping zhen,贺家坪,贺家坪镇', 30.6075200, 110.8263300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18011, 'Hejiang', 'Hejiang', 'Hejiang,Ho-chiang,Ho-chiang-hsien,Hokiang,Hokianghsien,he jiang,合江', 28.8116100, 105.8335900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18012, 'Hejiang', 'Hejiang', 'Hejiang,Hejiang Zhen,Ho-chiang,Ho-chiang-hsu,Ho-chiang-hsü,Ho-ching-hsu,Ho-ching-hsü,he jiang,he jiang zhen,合江,合江镇', 21.9352300, 110.5581300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18013, 'Hejiabao', 'Hejiabao', 'Hejiabao,Hejiabao Xiang,Hejiabu,Ho-chia-pao,he jia bao,he jia bao xiang,何家堡,何家堡乡', 39.8136400, 113.0490600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18014, 'Hejia', 'Hejia', 'Hejia,Hejia Zhen,he jia,he jia zhen,河夹,河夹镇', 32.9242500, 110.5373300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18015, 'Hejia', 'Hejia', 'Hejia,Hetian,he jia,he tian,何家,何田', 29.3297600, 118.3146400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18016, 'Heishui', 'Heishui', 'Heishui,Heishui Zhen,Heshuiba,hei shui,hei shui zhen,黑水,黑水镇', 29.0555100, 108.7963600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18017, 'Heilongkou', 'Heilongkou', 'Hei-lung-k''ou,Hei-lung-k’ou,Heilongkou,Heilongkou Zhen,hei long kou,黑龙口', 34.0095900, 109.7306000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18018, 'Heilangkou', 'Heilangkou', 'Hei-lang-k''ou-chen,Hei-lang-k’ou-chen,Heilangkou', 39.6127800, 117.4016700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18019, 'Heicheng', 'Heicheng', 'Hei-ch''eng-chen,Hei-ch’eng-chen,Heicheng,Heicheng Zhen,hei cheng,hei cheng zhen,黑城,黑城镇', 36.3701900, 106.0862300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18020, 'Hehu', 'Hehu', 'Hehu,Hehu Xiang,he hu,he hu xiang,荷湖,荷湖乡', 27.9287200, 115.7236400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18021, 'Hefu', 'Hefu', 'Hefu,Hefu Zhen,Ho-fu,he fu,he fu zhen,河洑,河洑镇', 29.0384300, 111.5972300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18022, 'Hefei', 'Hefei', 'Che-fej,Chefei,HFE,Hak-bui,Hap-pui-chhi,Ha̍p-pûi-chhī,Hefei,Hefei Shi,Hefejo,Hefejus,Hefėjus,Heyfey,Ho-fei,Ho-fei-hsien,Ho-fei-shih,Hofej,Hop Phi,Hozfeiz,Hăk-bùi,Hợp Phì,Khefej,Khehfehj,Khufej,Lu-chou,Luchow,Luchowfu,Lunchow,haphai,he fei,he fei shi,hefe''i,heopei si,hexfey,hfyy,khfy,Χεφέι,Хефей,Хефеј,Хъфей,Хэфэй,Хөфэй,Հեյֆեյ,خفي,خېفېي شەھىر,هفئی,ہیفئی,ہیفیئی,हफै,हेफ़ेई,เหอเฝย์,合肥,合肥市,허페이 시', 31.8638900, 117.2808300, 'CN', '2015-11-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18023, 'Hedian', 'Hedian', 'Hedian,Hedian Zhen,Ho-chia-tien,he dian,he dian zhen,何店,何店镇', 31.5935600, 113.3214300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18024, 'Hedi', 'Hedi', 'Hedi,Hedi Zhen,Ho-ti,he di,he di zhen,河底,河底镇', 35.3337100, 111.3569200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18025, 'Hedi', 'Hedi', 'Hedi,Hedi Zhen,Ho-ti,he de,he de zhen,荷地,菏地镇', 27.5773300, 119.2795000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18026, 'Hede', 'Hede', 'Hede,Ho-te,Ho-te-chen,Ho-te-kung-ssu,Hsia-ssu-chiang,Khede,Sheyang,he de,she yang,Хеде,合德,射阳', 33.7722000, 120.2617600, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18027, 'Hecun', 'Hecun', 'Hecun,Ho-ts''un,Ho-ts''un-ch''ien,Ho-ts''un-chen,Ho-ts’un,Ho-ts’un-chen,Ho-ts’un-ch’ien', 36.5333300, 114.1111100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18028, 'Hecun', 'Hecun', 'Hecun,he cun,合村', 29.9389100, 119.3071700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18029, 'Hecun', 'Hecun', 'Hecun,Hecun Zhen,Ho-ts''un,Ho-ts''un-shih,Ho-ts’un,Ho-ts’un-shih,he cun,he cun zhen,贺村,贺村镇', 28.6702700, 118.5287000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18030, 'Hechun', 'Hechun', 'Hechun,Hechun Zhen,Ho-ch''un,Ho-ch’un,he chun,he chun zhen,河唇,河唇镇', 21.6981000, 110.3004000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18031, 'Hechuan', 'Hechuan', 'Hechuan,Yongxin,Yongxin Xian,Yun-sin,Yung-hsin,Yung-hsin-hsien,Yungsin-hsien,he chuan,yong xin xian,永新县,禾川', 26.9361300, 114.2277800, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18032, 'Hecheng', 'Hecheng', 'Ch''ing-t''ien,Ch''ing-t''ien-hsien,Ch''ing-t''ien-hsien-ch''eng,Ch’ing-t’ien,Ch’ing-t’ien-hsien,Ch’ing-t’ien-hsien-ch’eng,Hecheng,Hecheng Zhen,Qingtian Xian,Tsing-tien,Tsingtienhsien,he cheng,he cheng zhen,qing tian xian,青田县,鹤城,鹤城镇', 28.1393900, 120.2879900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18033, 'Hecheng', 'Hecheng', 'Hecheng,Hecheng Zhen,Ho-ch''eng,Ho-ch’eng,he cheng,he cheng zhen,鹤城,鹤城镇', 22.6398600, 112.8152400, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18034, 'Hebu', 'Hebu', 'Hebu,Hebu Xiang,Ho-pu,he pu,he pu xiang,荷浦,荷浦乡', 27.8364000, 115.3904200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18035, 'Hebian', 'Hebian', 'Hebian,Hebian Zhen,Ho-pien,he bian,he bian zhen,河边,河边镇', 29.6566300, 106.1967300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18036, 'Hebi', 'Hebi', 'Che-pi,Hac Bich,Hao-pi,Hao-pi-chen,Hao-pi-chi,Hao-pi-shih,Hebi,Ho-pi,Ho-pi-shih,Hok-biah,Hok-piah-chhi,Hopitsi,Ho̍k-piah-chhī,Hŏk-biáh,Hạc Bích,Khebi,Khehbi,he bi,he bi shi,heobi si,Хеби,Хэби,ہئبی,鶴壁,鶴壁市,鹤壁市,허비 시', 35.8991700, 114.1925000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18037, 'Hebeitun', 'Hebeitun', 'Hebeitun,Ho-pei-t''un,Ho-pei-t’un,Ho-po-t''un,Ho-po-t’un', 39.5747200, 117.1133300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18038, 'Hebei', 'Hebei', 'Hebei,Hebei Zhen,Ho-pei,Ho-pei-chen,Ho-pei-ts''un,Ho-pei-ts’un,Khehbehj,he bei,he bei zhen,Хэбэй,河北,河北镇', 39.8152100, 115.9306800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18039, 'Heba', 'Heba', 'Heba,he ba,何坝', 33.9362400, 105.2162500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18040, 'Haokou', 'Haokou', 'Hao-tzu-k''ou,Hao-tzu-k’ou,Haokou,Haokou Zhen,Haozikou,hao kou,hao kou zhen,浩口,浩口镇', 30.3812800, 112.6399300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18041, 'Haozigang', 'Haozigang', 'Haozigang,Haozigang Zhen,hao zi gang,hao zi gang zhen,蒿子港,蒿子港镇', 29.2716900, 112.0567300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18042, 'Haozhai', 'Haozhai', 'Haozhai,Haozhai Zhen,Ho-chai,hao zhai,hao zhai zhen,郝寨,郝寨镇', 33.0095900, 113.0345600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18043, 'Haoyi', 'Haoyi', 'Haoyi,Haoyi Zhen,hao yi,hao yi zhen,好义,好义镇', 23.3704600, 114.7547400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18044, 'Haoxue', 'Haoxue', 'Hao-hsueh,Hao-hsüeh,Haoxue,Ho-hsueh,Ho-hsüeh,hao xue,郝穴', 30.0476100, 112.4675900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18045, 'Haodian', 'Haodian', 'Hao-chia-tien,Haodian,Haodian Zhen,Haojiadian,Ho-chia-tien,hao dian,hao dian zhen,郝店,郝店镇', 31.7930400, 113.7454600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18046, 'Haocun', 'Haocun', 'Haocun,Haocun Xiang,hao cun,hao cun xiang,濠村,濠村乡', 27.5915200, 118.4681700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18047, 'Hanzhong', 'Hanzhong', 'Chan-cung,Chan-čung,HZG,Han Trung,Han-chung,Han-chung-fu,Han-chung-shih,Han-tiong-chhi,Hang-dung,Hantai,Hantai Qu,Hanzhong,Hanzhong Shi,Hàn-tiong-chhī,Hán Trung,Háng-dṳ̆ng,Khan''chzhun,Khan’chzhun,Nan''chzhen,Nan-cheng,Nan-cheng-hsien,Nan’chzhen,han tai,han tai qu,han zhong,han zhong shi,hanjung si,Ханьчжун,ہانژونگ,汉中,汉中市,汉台,汉台区,漢中,漢中市,한중 시', 33.0750700, 107.0221400, 'CN', '2017-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18048, 'Hanyuan', 'Hanyuan', 'Hanyuan,Hsi-ho,Hsi-ho-hsien,Si-ho-hien,Si-ho-hién,Siho,Sikhe,Xihe,Xihe Xian,han yuan,xi he,xi he xian,汉源,西和,西和县', 34.0108300, 105.2919400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18049, 'Hanyin Chengguanzhen', 'Hanyin Chengguanzhen', 'Han-yang,Han-yin-hsien,Han-yin-hsien-ch''eng,Han-yin-hsien-ch’eng,Hanyin,Hanyin Chengguanzhen,Hanyin Xian,Hanyintang,han yin cheng guan zhen,han yin xian,汉阴县,汉阴城关镇', 32.8913900, 108.5047200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18050, 'Chengyang', 'Chengyang', 'Chengyang,Chengyang Xiang,Fu''an,Fu''an Shi,Fu-an-hsien,Fuanja,Fu’an,Fu’an Shi,Hanyang,cheng yang,cheng yang xiang,fu an,fu an shi,Фуаня,城阳,城阳乡,福安,福安市', 27.0891700, 119.6452800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18051, 'Hanting', 'Hanting', 'Han-t''ing-chen,Han-t’ing-chen,Hanting,Hanting Qu,Hantingchieh,Wei Xian,Wei-hsien,han ting,han ting qu,wei xian,寒亭,寒亭区,潍县', 36.7708300, 119.2108300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18052, 'Hanting', 'Hanting', 'Han-t''ing-chen,Han-t’ing-chen,Hanting,Hanting Zhen,Hung-chia-tsui,han ting,han ting zhen,寒亭,寒亭镇', 30.9186800, 118.5484800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18053, 'Hantang', 'Hantang', 'Hantang,Hantang Zhen,Nantang,han tang,han tang zhen,翰堂,翰堂镇', 28.1528300, 114.7894000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18054, 'Hantai', 'Hantai', 'Han-t''ai-chen,Han-t’ai-chen,Hantai,Hantai Zhen,Khan''tay,Khan’tay,han tai,han tai zhen,邯邰,邯邰镇', 38.3164400, 114.8352100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18055, 'Hanshou', 'Hanshou', 'Han-shou-ch''eng,Han-shou-ch’eng,Han-shou-hsien,Hanshou,Hanshou Xian,Hanshow-hsien,Longyang,Longyang Zhen,han shou xian,long yang,long yang zhen,汉寿县,龙阳,龙阳镇', 28.9058300, 111.9561100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18056, 'Hanjiashu', 'Hanjiashu', 'Han-chia-shu,Hanjiashu,Hanliushu,han jia shu,韩家墅', 39.1875000, 117.0730600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18057, 'Hanjia', 'Hanjia', 'Han-chia,Hanjia,han jia,韩家', 34.9286000, 107.8680200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18058, 'Hanjia', 'Hanjia', 'Han-chia-chen,Hanjia,Hanjia Zhen,P''eng-shui-hsien,Pengshui Miaozu Tujiazu Zizhixian,P’eng-shui-hsien,han jia,han jia zhen,peng shui miao zu tu jia zu zi zhi xian,彭水苗族土家族自治县,汉葭,汉葭镇', 29.2952400, 108.1613200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18059, 'Hanji', 'Hanji', 'Han-chia-chi,Han-kia-tsi,Hang-chang-ch''ih,Hang-chang-ch’ih,Hanji,Hanji Zhen,Hanjiaji,Lin-hsia,Lin-hsia-hsien,Linxia Xian,Ta-chia-li-shan,han ji,han ji zhen,lin xia xian,临夏县,韩集,韩集镇', 35.4954400, 102.9926000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18060, 'Hangzhou', 'Hangzhou', 'Chan''nktsoou,Chang-cou,Chang-čou,Gorad Khanchzhou,HGH,Hancheum,Hanchow-fu,Hanczou,Handzou,Handžou,Hang,Hang Chau,Hang-chiu-chhi,Hang-chou,Hang-chou-shih,Hang-hsien,Hangchow,Hangcsou,Hangdzou,Hangdžou,Hanggouo,Hangtsjou,Hangzcouh,Hangzhou,Hangzhou Shi,Hangĝoŭo,Hančžou,Hong-chu-su,Hong-ciu,Hàng Châu,Hâng-chiu-chhī,Hòng-chû-sṳ,Hòng-ciŭ,Khanchzhou,Khandzhou,Khangdzou,Khanzhou,Xanchjou,hang cow,hang zhou,hang zhou shi,hangacau,hangajho''u,hanghtshw,hangjeou,hangjeou si,hangju,hangzhw,hanjha,hannaco,hʼnggwʼw,kancu,Χανγκτσόου,Горад Ханчжоу,Хангџоу,Ханджоу,Ханжоу,Ханчжоу,האנגגואו,خاڭجۇ شەھىر,هانغتشو,هانگژو,ہانگژو,हांगचौ,हांगझोऊ,ਹਾਂਙਚੋ,காங்சூ,ഹാങ്ഝൗ,หางโจว,ཧང་ཀྲོའུ།,杭州,杭州市,항저우,항저우 시,항주', 30.2936500, 120.1614200, 'CN', '2017-06-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18061, 'Hangu', 'Hangu', 'Han-ku,Han-ku-shih,Hangu,Khanga,Ханга', 39.2488900, 117.7891700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18062, 'Hangou', 'Hangou', 'Han-kou,Han-kou-chen,Hangou,han gou,汉沟', 39.2908300, 117.0900000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18063, 'Hangongdu', 'Hangongdu', 'Hangongdu,Hangongdu Zhen,han gong du,han gong du zhen,韩公渡,韩公渡镇', 29.0888200, 111.9189000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18064, 'Hangchuan', 'Hangchuan', 'Guangze,Hangchuan,Kuang-te,Kuang-tse,Kuang-tse-hsien,Kwangtseh,Kwangtseh-hsien,Kwangtsen,hang chuan,杭川', 27.5194700, 117.3349100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18065, 'Hangbu', 'Hangbu', 'Hangbu,Hangbu Zhen,hang bu,hang bu zhen,航埠,航埠镇', 28.9365700, 118.7758600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18066, 'Hanfeng', 'Hanfeng', 'Hanfeng,Hanfeng Jiedao,K''ai,K''ai-hsien,Kai Xian,K’ai,K’ai-hsien,han feng,han feng jie dao,kai xian,开县,汉丰,汉丰街道', 31.1694600, 108.4031000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18067, 'Hanfang', 'Hanfang', 'Hanfang,Hanfang Xiang,han fang,han fang xiang,韩坊,韩坊乡', 25.4887700, 115.0930000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18068, 'Changzhi', 'Changzhi', 'CIH,Cangdzi,Cangi,Cchang-c,Ch''ang-chih,Ch''ang-chih-hsien,Ch''ang-chih-shih,Chanchzhi,Chandzhu,Chang-chi,Changdzi,Changzhi,Changzhi Shi,Ch’ang-chih,Ch’ang-chih-hsien,Ch’ang-chih-shih,Diong-de,Diòng-dê,Handian,Lu''an,Lu''anfu,Lu’an,Lu’anfu,Tiong-ti-chhi,Tiông-tī-chhī,Truong Tri,Trường Trị,changjeu si,changjy,changzhy,lu an,lu an fu,zhang zhi,zhang zhi shi,Ĉanĝi,Čangdži,Čchang-č,Чангџи,Чанджъ,Чанчжи,چانگجی,چانگژی,潞安,潞安府,長治,長治市,长治,长治市,창즈 시', 36.1838900, 113.1052800, 'CN', '2015-06-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18069, 'Handian', 'Handian', 'Ch''ang-chih-hsien,Changzhi,Changzhi Xian,Ch’ang-chih-hsien,Han-tien,Han-tien-chen,Handian,Handian Zhen,han dian,han dian zhen,zhang zhi xian,长治县,韩店,韩店镇', 36.0458300, 113.0441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18070, 'Handan', 'Handan', 'Chan-tan,HDG,Ham GJan,Han-tan,Han-tan-chhi,Han-tan-hsien,Han-tan-shih,Handan,Handan Shi,Handanas,Handano,Hang-dang,Hàm Đan,Hàng-dăng,Hân-tan-chhī,Khan''dan'',Khandan,han dan,han dan shi,handan,handan si,Хандан,Ханьдань,האנדאן,خەندەن شەھىرى,هاندان,ہاندان,邯郸市,邯鄲,邯鄲市,한단 시', 36.6005600, 114.4677800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18071, 'Hanchuan', 'Hanchuan', 'Han-ch''uan-hsien,Han-ch’uan-hsien,Hanchuan,Hanchwan,Hanchwanhsien', 30.6500000, 113.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18072, 'Hancheng', 'Hancheng', 'Han-ch''eng-hsien,Han-ch’eng-hsien,Hancheng,Khanchen', 35.4602800, 110.4291700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18073, 'Haizhou', 'Haizhou', 'Chiu-tung-hai,Hai-chou,Haichow,Haizhou,Tung-hai,Tung-hai-ch''eng,Tung-hai-ch’eng,Tung-hai-hsien,hai zhou,海州', 34.5816700, 119.1288900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18074, 'Sanhe', 'Sanhe', 'Hai-yuan-hsien,Hai-yüan-hsien,Haicheng,Haicheng Zhen,Haiyuan,Haiyuan Xian,Khaychen,Khayyuan'',Khayyuan’,Sanhe,hai cheng,hai cheng zhen,hai yuan xian,san he,三河,海原县,海城,海城镇', 36.5641000, 105.6390000, 'CN', '2015-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18075, 'Haiyou', 'Haiyou', 'Hai-yu,Hai-yu-chen,Haiyou,Haiyou Zhen,Haiyouzhen,Sanmen,hai you,hai you zhen,san men,三门,海游,海游镇', 29.1235800, 121.3734400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18076, 'Haiyangsuo', 'Haiyangsuo', 'Hai-yang-so,Haiyangsuo,Haiyangsuo Zhen,hai yang suo,hai yang suo zhen,海阳所,海阳所镇', 36.8064000, 121.6164700, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18077, 'Haiyang', 'Haiyang', 'Hai-yang-chen,Haiyang,Haiyang Zhen,Hsiu-ning,Hsiu-ning-hsien,Siuning,Siuning-hsien,Xiuning,hai yang,hai yang zhen,xiu ning,休宁,海阳,海阳镇', 29.7861200, 118.1769800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18078, 'Haiyan', 'Haiyan', 'Hai-yen,Hai-yen-chieh,Haiyan,Haiyan Zhen,Haiyanzhong,Hoingan,hai yan,hai yan zhen,海宴,海宴镇', 21.8289900, 112.5433600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18079, 'Haitou', 'Haitou', 'Hai-t''ou-chen,Hai-t’ou-chen,Haitou,Haitou Zhen,hai tou,hai tou zhen,海头,海头镇', 34.9336100, 119.1697200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18080, 'Haitou', 'Haitou', 'Hai-t''ou-chiang,Hai-t''ou-shih,Hai-t’ou-chiang,Hai-t’ou-shih,Haitou,Haitou Zhen,Hoita,Hoitou,Hoitow,hai tou,hai tou zhen,海头,海头镇', 19.5056300, 108.9505400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18081, 'Haishiwan', 'Haishiwan', 'Hai-shih-wan,Haishiwan,Haishiwan Zhen,hai shi wan,hai shi wan zhen,海石湾,海石湾镇', 36.3462800, 102.8579900, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18082, 'Hairag', 'Hairag', 'Ch''ia-erh-ch''i,Chargi,Ch’ia-erh-ch’i,Ha''ergaixiang,Ha-erh-kai,Ha-erh-kai-hsiang,Hairag,Ha’ergaixiang,K''a-erh,K''a-erh-ch''i,Kharg,Khargi,K’a-erh,K’a-erh-ch’i,ha er gai,哈尔盖', 37.2231700, 100.4161700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18083, 'Jiaojiang', 'Jiaojiang', 'Hai-men-chen,Haimen,Jiaojiang', 28.6802800, 121.4427800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18084, 'Haimen', 'Haimen', 'Hai-men-so,Haimen,Haimen Zhen,Haimun,Haimung,Hoimoon,hai men,hai men zhen,海门,海门镇', 23.1934600, 116.6121900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18085, 'Haikou', 'Haikou', 'Hai-k''ou-shih,Hai-k’ou-shih,Haikou,Haikou Zhen,hai kou,hai kou zhen,海口,海口镇', 29.1068200, 117.8073600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18086, 'Haikou', 'Haikou', 'Hai-k''ou-chen,Hai-k''ou-shih,Hai-k’ou-chen,Hai-k’ou-shih,Haikou,Haikou Zhen,hai kou,hai kou zhen,海口,海口镇', 28.3258300, 120.0829900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18087, 'Haikou', 'Haikou', 'Hai-kow,Haikou,Haikou Zhen,hai kou,hai kou zhen,海口,海口镇', 25.6937000, 119.4594100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18088, 'Haikou', 'Haikou', 'Haikou,Haikou Zhen,hai kou,hai kou zhen,海口,海口镇', 24.7798500, 102.5754800, 'CN', '2012-01-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18089, 'Haikou', 'Haikou', 'Chaj-kchou,Gorad Khajkou,HAK,Ha k''uo-shih,Ha k’uo-shih,Hai Khau,Hai-k''ou-shih,Hai-k''ou-so-ch''eng,Hai-kau,Hai-khau-chhi,Hai-k’ou-shih,Hai-k’ou-so-ch’eng,Haijgouj,Haik-how,Haikou,Haikou Shi,Haikow,Hajkou,Hajkouo,Hajkoŭo,Heihow,Hoi Hao,Hoihau,Hoihow,Hái-kháu-chhī,Hāi-kāu,Hải Khẩu,Khajkou,Xeyko shehir,ha''iko''u,hai kou,hai kou shi,haikeou si,haykw,Горад Хайкоу,Хайкоу,Хајкоу,هايكو,هایکو,ہائکو,ہائیکؤ,हाइकोऊ,ཧའེ་ཁོའུ་གྲོང་ཁྱེར།,ဟိုင်းခိုမြို့,海口,海口市,하이커우 시', 20.0458300, 110.3416700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18090, 'Haihui', 'Haihui', 'Haihui,Haihui Zhen,hai hui,hai hui zhen,海会,海会镇', 29.5433300, 116.0533600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18091, 'Haifu', 'Haifu', 'Hai-fu-chen,Haifu,Haifu Zhen,Haifuzhen,hai fu,hai fu zhen,海复,海复镇', 31.9866700, 121.6875000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18092, 'Haicheng', 'Haicheng', 'Hai-ch''eng-chen,Hai-ch’eng-chen,Hai-feng-hsien,Haicheng,Haifeng,Hoifung,Hoifung-hsien,hai cheng,海城', 22.9753300, 115.3317900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18093, 'Haidian', 'Haidian', 'Hai-tien,Hai-tien-ch''u,Hai-tien-ch’ü,Haidian,Haidian Qu,Haidian Xiang,hai dian,hai dian qu,hai dian xiang,海淀,海淀乡,海淀区', 39.9906400, 116.2886800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18094, 'Haibeitou', 'Haibeitou', 'Hai-pei-t''ou,Hai-pei-t’ou,Haibeitou,Haibeitou Xiang,hai bei tou,hai bei tou xiang,海北头,海北头乡', 39.8038200, 113.1850100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18095, 'Hai’an', 'Hai''an', 'Hai''an,Hai''an Xian,Hai''an Zhen,Hai-an-chen,Hai’an,Hai’an Xian,Hai’an Zhen,hai an,hai an xian,hai an zhen,海安,海安县,海安镇', 32.5436100, 120.4500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18096, 'Hai’an', 'Hai''an', 'Hai''an,Hai''an Zhen,Hai-an-so,Hai’an,Hai’an Zhen,Hoian,Hoingan,hai an,hai an zhen,海安,海安镇', 20.2801300, 110.2291200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18097, 'Gyimkar', 'Gyimkar', 'Gyimkar,Jika,Jika Xiang,Jiyao Dangwuda,ji ka,ji ka xiang,ji yao dang wu da,吉卡,吉卡乡,吉要当吾达', 32.8180900, 100.2803800, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18098, 'Gyangqai', 'Gyangqai', 'Gyangqai,Jiangqian,Jiangqian Xiang,Xiniangtang,jiang qian,jiang qian xiang,xi niang tang,江千,江千乡,西娘塘', 34.1666700, 100.4000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18099, 'Maji', 'Maji', 'Guzhu,K''u-chu,K’u-chu,Maji,Maji Zhen,gu zhu,ma ji,ma ji zhen,古竹,马吉,马吉镇', 31.4394500, 120.1022900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18100, 'Guzhu', 'Guzhu', 'Guzhu,Guzhu Zhen,Ku-chu,Ku-chu-hsu,Ku-chu-hsü,gu zhu,gu zhu zhen,古竹,古竹镇', 23.5157200, 114.7056900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18101, 'Guzhen Chengguanzhen', 'Guzhen Chengguanzhen', 'Guzhen,Guzhen Chengguanzhen,Ku-chen,gu zhen cheng guan zhen,固镇城关镇', 33.3105600, 117.3105600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18102, 'Guzhen', 'Guzhen', 'Guzhen,Guzhen Zhen,Ku-chen,Ku-chen-hsu,Ku-chen-hsü,gu zhen,gu zhen zhen,古镇,古镇镇', 22.6152200, 113.1749800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18103, 'Guyong', 'Guyong', 'Chiang-le,Chiang-lo,Chiang-lo-hsien,Guyong,Jiangle,Tsianglo,Tsianglohsien,gu yong,古镛', 26.7308300, 117.4683300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18104, 'Guyi', 'Guyi', 'Guyi,Ku-i,Ku-i-chen,Kuyi,San-chiang,San-chiang-hsien,San-chiang-t''ung-tsu-tzu-chih-hsien,San-chiang-t’ung-tsu-tzu-chih-hsien,San-kiang,Sanjiang,gu yi,古宜', 25.7777800, 109.6002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18105, 'Guye', 'Guye', 'Guye,Ku-yeh,gu ye,古冶', 39.7305400, 118.4408500, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18106, 'Guyang', 'Guyang', 'Guyang,Guzhang,Guzhang Xian,Ku-chang,Ku-chang-hsien,Ku-chang-p''ing,Ku-chang-p’ing,gu yang,gu zhang xian,古丈县,古阳', 28.6138500, 109.9325300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18107, 'Guxiang', 'Guxiang', 'Gugang,Guxiang,Guxiang Zhen,Ku-chiang-chan,Ku-hsiang,gu xiang,gu xiang zhen,古巷,古巷镇', 23.6537700, 116.5723000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18108, 'Guxian', 'Guxian', 'Guxian,Guxian Jiedao,Ku-hsien,Ku-hsien-ts''un,Ku-hsien-ts’un,Ku-yen-ts''un,Ku-yen-ts’un,gu xian,gu xian jie dao,古现,古现街道', 37.5720800, 121.1223800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18109, 'Guxian', 'Guxian', 'Guxian,Guxian Zhen,Ku-hsien,gu xian,gu xian zhen,古县,古县镇', 27.1535700, 115.5154400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18110, 'Guxi', 'Guxi', 'Guxi,Guxi Zhen,Ku-ch''i,Ku-ch''i-chen,Ku-ch’i,Ku-ch’i-chen,Ku-hsi,gu xi,gu xi zhen,古溪,古溪镇', 32.3459600, 120.3346700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18111, 'Guxi', 'Guxi', 'Guxi,Guxi Zhen,Ku-hsi,gu xi,gu xi zhen,古溪,古溪镇', 30.3302600, 105.8720800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18112, 'Gutian', 'Gutian', 'Gutian,Gutian Zhen,Ku-t''ien,Ku-t’ien,gu tian,gu tian zhen,姑田,姑田镇', 25.6956300, 116.9657100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18113, 'Gutian', 'Gutian', 'Gutian,Gutian Zhen,Ku-t''ien,Ku-t’ien,gu tian,gu tian zhen,古田,古田镇', 25.2277800, 116.8181000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18114, 'Gutang', 'Gutang', 'Gutang,Gutang Zhen,gu tang,gu tang zhen,姑塘,姑塘镇', 29.6218500, 116.1180700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18115, 'Gutan', 'Gutan', 'Gutan,Gutan Xiang,Ku-t''an,Ku-t’an,gu tan,gu tan xiang,古坦,古坦乡', 29.4533100, 117.6802200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18116, 'Gushui', 'Gushui', 'Gushui,Gushui Zhen,Ku-shui,gu shui,gu shui zhen,古水,古水镇', 23.6868400, 112.3008000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18117, 'Gushi', 'Gushi', 'Gushi,Gushi Zhen,Ku-shih,Ku-shih-chen,gu shi,故市', 34.6425000, 109.5842600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18118, 'Gushi Chengguanzhen', 'Gushi Chengguanzhen', 'Gushi,Gushi Chengguanzhen,Ku-shih,Ku-shih-hsien,gu shi cheng guan zhen,固始城关镇', 32.1620800, 115.6698900, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18119, 'Gushi', 'Gushi', 'Gushi,Gushi Zhen,Ku-shih,gu shi,gu shi zhen,古市,古市镇', 29.0612700, 114.1479700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18120, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,Ku-shan,Ku-shan-chen,gu shan,gu shan zhen,孤山,孤山镇', 32.0666700, 120.3000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18121, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,Ku-shan,gu shan,gu shan zhen,古山,古山镇', 28.9833400, 120.1637300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18122, 'Xiagulei', 'Xiagulei', 'Daowei Cangzu Xiang,Guru,Gurü,Xiagulei,dao wei cang zu xiang,gu lei,xia gu lei,下古雷,古雷,道帏藏族乡', 35.6531800, 102.6458300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18123, 'Guozhuang', 'Guozhuang', 'Guozhuang,Guozhuang Zhen,Kuo-chuang,Kuo-chuang-chen,guo zhuang,guo zhuang zhen,郭庄,郭庄镇', 38.2114600, 114.8646100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18124, 'Guozhen', 'Guozhen', 'Baoji,Chencang Qu,Gochzhen,Guo Zhen,Guo zhen,Guozhen,Guozhen zhen,Ko-chen,Kuo-chen,Pao-chi,Pao-chi-hsien,chen cang qu,guo zhen,guo zhen zhen,虢镇,虢镇镇,陈仓区', 34.3659100, 107.3590400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18125, 'Guozhen', 'Guozhen', 'Guozhen,Kuo-chen,Kuo-chia-pa,guo zhen,郭镇', 33.3280600, 105.8248500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18126, 'Guoyang Chengguanzhen', 'Guoyang Chengguanzhen', 'Guoyang,Guoyang Chengguanzhen,Ke-yang,Ko-yang,Ko-yang-hsien,Kuo-yang,Kwoyang,Kwoyang-hsien,wo yang cheng guan zhen,涡阳城关镇', 33.5055000, 116.2308000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18127, 'Lingbao Chengguanzhen', 'Lingbao Chengguanzhen', 'Guolue,Guoluezhen,Guolüe,Kuo-lueh-chen,Kuo-lüeh-chen,Kwoliochen,Ling-pao,Ling-pao-hsien,Lingbao,Lingbao Chengguanzhen,ling bao cheng guan zhen,灵宝城关镇', 34.5197200, 110.8644400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18128, 'Guojiazhuang', 'Guojiazhuang', 'Guojiazhuang,Guojiazhuang Zhen,Kuo-chia-chuang,guo jia zhuang,guo jia zhuang zhen,郭家庄,郭家庄镇', 35.3044900, 111.1625300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18129, 'Guoyuan', 'Guoyuan', 'Guojiayuan,Guoyuan,Guoyuan Zhen,Kuo-chia-yuan,Kuo-chia-yüan,guo yuan,guo yuan zhen,郭园,郭园镇', 32.1670200, 120.5946800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18130, 'Guojiadian', 'Guojiadian', 'Guojiadian,Guojiadian Zhen,Kuo-chia-tien,guo jia dian,guo jia dian zhen,郭家店,郭家店镇', 37.0824300, 120.1570700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18131, 'Guojiaba', 'Guojiaba', 'Guojiaba,Guojiaba Zhen,guo jia ba,guo jia ba zhen,郭家坝,郭家坝镇', 30.9220700, 110.7285500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18132, 'Guoji', 'Guoji', 'Guoji,Kuo-chi,guo ji,郭集', 32.9781200, 113.1221700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18133, 'Guohua', 'Guohua', 'Guohua,Guohua Zhen,guo hua,guo hua zhen,国华,国华镇', 32.4797400, 106.2922900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18134, 'Guofuchang', 'Guofuchang', 'Guofu,Guofuchang,Kuo-fu', 28.8500000, 106.6013900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18135, 'Guodu', 'Guodu', 'Guodu,Guodu Jieban,Kuo-tu,Kuo-tu-chen,guo du,guo du jie ban,郭杜,郭杜街办', 34.1553700, 108.8643100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18136, 'Guocun', 'Guocun', 'Guocun,Guocun Zhen,guo cun,guo cun zhen,郭村,郭村镇', 32.5366400, 119.7862200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18137, 'Guocun', 'Guocun', 'Guocun,guo cun,郭村', 29.5572700, 118.6329700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18138, 'Guochuan', 'Guochuan', 'Daijiayanxing,Guochuan,Guochuan Zhen,Guochuangang,dai jia yan xing,guo chuan,guo chuan zhen,戴家烟行,过船,过船镇', 32.1487900, 119.9265300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18139, 'Gunan', 'Gunan', 'Ch''i-chiang,Ch''i-chiang-hsien,Chi-kiang,Ch’i-chiang,Ch’i-chiang-hsien,Gunan,Gunan Zhen,Kikiang,Kikianghsien,Qijiang,Qijiang Xian,gu nan,gu nan zhen,qi jiang xian,古南,古南镇,綦江县', 29.0231000, 106.6480000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18140, 'Gulou', 'Gulou', 'Gulou,Gulou Xiang,Ku-lou,gu lou,gu lou xiang,古楼,古楼乡', 28.1666700, 111.1000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18141, 'Gulonggang', 'Gulonggang', 'Gulonggang,Gulonggang Zhen,Ku-lung-kang,gu long gang,gu long gang zhen,古龙冈,古龙冈镇', 26.4477800, 115.6969700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18142, 'Guling', 'Guling', 'Gaoping,Guling,Guling Zhen,Ku-lin-t''o,Ku-lin-t’o,Ku-ling-chen,gao ping,gu ling,gu ling zhen,故陵,故陵镇,高坪', 30.9409900, 109.0802200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18143, 'Guling', 'Guling', 'Guling,Guling Zhen,gu ling,gu ling zhen,牯岭,牯岭镇', 29.5690200, 115.9761000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18144, 'Gulin', 'Gulin', 'Gulin,Ku-lin,Ku-lin-hsien,gu lin,古蔺', 28.0422300, 105.8103800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18145, 'Guli', 'Guli', 'Guli,Guli Zhen,Ku-li,gu li,gu li zhen,谷里,谷里镇', 31.8833300, 118.6833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18146, 'Guli', 'Guli', 'Guli,Guli Zhen,Ku-li,Ku-li-ts''un,Ku-li-ts’un,gu li,gu li zhen,古里,古里镇', 31.6321900, 120.8349900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18147, 'Guli', 'Guli', 'Guli,Yongkang,Yung-k''ang,Yung-k''ang-hsien,Yung-k’ang,Yung-k’ang-hsien,Гули', 28.8816200, 120.0330800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18148, 'Gulaobei', 'Gulaobei', 'Gulaobei,Gulaobei Jiedao,Ku-lao-pei,gu lao bei,gu lao bei jie dao,古老背,古老背街道', 30.5194100, 111.4266400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18149, 'Gulao', 'Gulao', 'Gulao,Gulao Zhen,Ku-lao,Ku-lao-hsu,Ku-lao-hsü,Kulo,gu lao,gu lao zhen,古劳,古劳镇', 22.8351500, 112.9336100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18150, 'Gulang', 'Gulang', 'Gulan,Gulang,Gulang Xian,Ku-lang,Ku-lang-hsien,gu lang,gu lang xian,古浪,古浪县', 37.4665700, 102.8942800, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18151, 'Gulai', 'Gulai', 'Gulai,Gulai Zhen,K''o-lai,Ku-lai,Ku-lai-ts''un,Ku-lai-ts’un,K’o-lai,gu lai,gu lai zhen,谷来,谷来镇', 29.6909300, 120.6427000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18152, 'Gujing', 'Gujing', 'Gujing,Gujing Zhen,Ku-ching,Ku-ching-hsu,Ku-ching-hsü,Kutsing,gu jing,gu jing zhen,古井,古井镇', 22.3549800, 113.1086000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18153, 'Shangyuan', 'Shangyuan', 'Chung-ku-chiao,Gujiao Zhen,Ku-chiao,Nan-ku-chiao,Pei-ku-chiao,Shangyuan,gu jiao zhen,shang yuan,上院,古交镇', 35.6150600, 111.1323700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18154, 'Gujiang', 'Gujiang', 'Gujiang,Gujiang Zhen,Ku-chiang,gu jiang,gu jiang zhen,固江,固江镇', 27.1880900, 114.7880000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18155, 'Guizi', 'Guizi', 'Guizi,Guizi Zhen,Kuii-tzu,gui zi,gui zi zhen,贵子,贵子镇', 22.6362800, 111.1131100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18156, 'Guiyu', 'Guiyu', 'Guiyu,Guiyu Zhen,gui yu,贵屿', 23.3221300, 116.3429500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18157, 'Guiyang', 'Guiyang', 'Goi-iong,Guejang,Guejjan,Guijangas,Guijango,Guiyang,Guiyang Shi,Gujjan,Guyan,Guyyan,Gveiyangz,Gói-iòng,Gŭijango,KWE,Kuei-chu,Kuei-yang,Kuei-yang-shih,Kuej-jang,Kui-iong-chhi,Kweichu,Kweiyang,Kweiyangfu,Kùi-iông-chhī,Queiyanga,Quy Duong,Quý Dương,ghwyyangh,gu''iyanga,gu-iyang si,gui yang,gui yang shi,gwyyang,kuy hyang,Гуейян,Гуејанг,Гуйян,Ґуйян,Գույան,غوييانغ,گوئیانگ,گۇيياڭ شەھىرى,गुइयांग,ਗੁਈਯਾਂਗ,กุ้ยหยาง,ကွေ့ယန်မြို့,貴陽,貴陽市,贵阳,贵阳市,구이양 시', 26.5833300, 106.7166700, 'CN', '2016-06-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18158, 'Guiyang Chengguanzhen', 'Guiyang Chengguanzhen', 'Guiyang,Guiyang Chengguanzhen,Kuei-yang,Kuei-yang-ch''eng,Kuei-yang-ch’eng,Kuei-yang-hsien,Kweiyang,Kweiyang-hsien,Kweiyangchow,gui yang cheng guan zhen,桂阳城关镇', 25.7333300, 112.7458900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18159, 'Guixi', 'Guixi', 'Dianjiang Xian,Dyan''tszyan,Dyan’tszyan,Guixi,Guixi Zhen,Tien-ch''iang,Tien-chiang-hsien,Tien-chiang-hsien-ch''eng,Tien-chiang-hsien-ch’eng,Tien-ch’iang,Tienkiang,Tienkiang-hsien,dian jiang xian,gui xi,gui xi zhen,垫江县,桂溪,桂溪镇', 30.3335500, 107.3454500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18160, 'Guitou', 'Guitou', 'Guitou,Guitou Zhen,Kuei-t''ou,Kuei-t''ou-hsu,Kuei-t’ou,Kuei-t’ou-hsü,gui tou,gui tou zhen,桂头,桂头镇', 24.9333300, 113.4166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18161, 'Guishan', 'Guishan', 'Guishan,Guishan Xiang,gui shan,gui shan xiang,龟山,龟山乡', 31.0756600, 115.1818400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18162, 'Guishan', 'Guishan', 'Guishan,Guishan Xiang,gui shan,gui shan xiang,皈山,皈山乡', 30.6500000, 119.5500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18163, 'Guishan', 'Guishan', 'Guishan,Hsin-p''ing,Hsin-p''ing-hsien,Hsin-p’ing,Hsin-p’ing-hsien,Sinping-hsien,Xinping,gui shan,桂山', 24.0502700, 102.0001800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18164, 'Guiren', 'Guiren', 'Guiren,Kuei-jen,Kuei-jen-chi', 33.6697200, 118.1888900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18165, 'Guiping', 'Guiping', 'Guiping,Guiping Zhen,Hsun-chou,Hsün-chou,Kuei-p''ing,Kuei-p''ing-hsien,Kuei-p’ing,Kuei-p’ing-hsien,Kweiping,Kweiping-hsien,Sun-chow-fu,Sunchow,Sunshow,Sün-chow-fu,Sünchow,gui ping,gui ping zhen,桂平,桂平镇', 23.3933600, 110.0743700, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18166, 'Guilin', 'Guilin', 'Guilin,Guilin Zhen,Kuei-lin,Kuei-lin-chen,gui lin,gui lin zhen,桂林,桂林镇', 29.9220000, 118.4680200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18167, 'Guilin', 'Guilin', 'Garadskaja akruga Gujlin'',Guejlin,Guilin,Guilin Shi,Gujlin,Gujlin'',Gveilinz,KWL,Kuei-lin,Kuei-lin-shih,Kuej-lin,Kui-lim-su,Kui-lìm-sṳ,Kweilin,Kweilin-hsien,Lin-kuei,Lin-kuei-hsien,Lin-kwei,Ling-ch''uan,Ling-ch’uan,Que Lam,Quế Lâm,gu''ilina,gu-ilin si,gui lin,gui lin shi,kuy hlin,Гарадская акруга Гуйлінь,Гуейлин,Гуејлин,Гуйлинь,گۇيلىن شەھىرى,गुइलिन,กุ้ยหลิน,桂林,桂林市,구이린 시', 25.2819400, 110.2863900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18168, 'Guigang', 'Guigang', 'Guigang,Guigang Zhen,gui gang,gui gang zhen,圭岗,圭岗镇', 22.3572400, 111.7314100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18169, 'Guidong Chengguanzhen', 'Guidong Chengguanzhen', 'Guidong,Guidong Chengguanzhen,Guidong Xian,Kuei-tung,Kuei-tung-hsien,Kweitung,Kweitung-hsien,gui dong cheng guan zhen,gui dong xian,桂东县,桂东城关镇', 26.0790300, 113.9406200, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18170, 'Guigang', 'Guigang', 'Goi-geng,Guicheng,Guigang,Guixian,Gujgan,Gveigangj,Gói-gē̤ng,Kuei,Kuei-hsien,Kuej-kang,Kui-kang-chhi,Kui-kong-su,Kui-kóng-sṳ,Kweihsien,Kùi-káng-chhī,Quy Cang,Quý Cảng,gu-igang si,gui gang,gui gang shi,gwygang,gwyygang,Гуйган,گوئگانگ,گوئیگانگ,گویگانگ,貴港,貴港市,贵港市,구이강 시', 23.0963900, 109.6091700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18171, 'Guhuai', 'Guhuai', 'Guhuai,Guhuai Zhen,Ku-hsien,Ku-huai,gu huai,gu huai zhen,古槐,古槐镇', 25.8838700, 119.5378100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18172, 'Gugao', 'Gugao', 'Gugao,Gugao Zhen,Gugaozhuang,Ku-kao,Ku-kao-chuang,gu gao,gu gao zhen,gu gao zhuang,顾高,顾高庄,顾高镇', 32.3646000, 120.1633600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18173, 'Gufeng', 'Gufeng', 'Gufeng,Ku-fen,Ku-fen-chen,Ku-feng-chen,Ku-hsia,Pingnan,gu feng,古峰', 26.9083300, 118.9819400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18174, 'Gudian', 'Gudian', 'Gudian,Gudian Xiang,Ku-tien,Pan-ku-tien,gu dian,gu dian xiang,古店,古店乡', 32.8833300, 116.5333300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18175, 'Gucun', 'Gucun', 'Gucun,Gucun Zhen,Ku-ts''un,Ku-ts’un,gu cun,gu cun zhen,固村,固村镇', 26.2416300, 116.1480500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18176, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,Ku-ch''eng,Ku-ch''eng-chen,Ku-ch’eng,Ku-ch’eng-chen,gu cheng,gu cheng zhen,古城,古城镇', 35.9115200, 111.3192400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18177, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,Ku-ch''eng,Ku-ch’eng,gu cheng,gu cheng zhen,古城,古城镇', 35.8569400, 106.4580600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18178, 'Gucheng Chengguanzhen', 'Gucheng Chengguanzhen', 'Gucheng,Gucheng Chengguanzhen,Ku-ch''eng,Ku-ch''eng-hsien,Ku-ch’eng,Ku-ch’eng-hsien,gu cheng cheng guan zhen,古城城关镇', 32.2660400, 111.6347600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18179, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,Ku-ch''eng,Ku-ch''eng-chen,Ku-ch’eng,Ku-ch’eng-chen,gu cheng,gu cheng zhen,固城,固城镇', 31.3054100, 118.9665100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18180, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,Ku-ch''eng,Ku-ch’eng,gu cheng,gu cheng zhen,古城,古城镇', 25.8645000, 116.1679900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18181, 'Gubu', 'Gubu', 'Gubu,Gubu Zhen,Ku-pu,gu bu,gu bu zhen,古埠,古埠镇', 28.7173200, 116.8015200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18182, 'Gubei', 'Gubei', 'Gubei,Gubei Zhen,gu bei,gu bei zhen,古陂,古陂镇', 25.3345800, 115.0988900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18183, 'Guazhou', 'Guazhou', 'Guazhou,Guazhou Zhen,Kua-chou,Kua-chou-chen,Kwa-chow,Kwachow,gua zhou,gua zhou zhen,瓜洲,瓜洲镇', 32.2534000, 119.3831100, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18184, 'Guapo', 'Guapo', 'Guapo,Guapo Zhen,Kua-p''o,Kua-p''o-chen,Kua-p’o,Kua-p’o-chen,gua po,瓜坡', 34.4772800, 109.7060200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18185, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Guanzhuang Zhen,Kuan-chuang,guan zhuang,guan zhuang zhen,关庄,关庄镇', 34.9572600, 108.8664800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18186, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Guanzhuang Zhen,Hsi-kuan-chuang,Kuan-chuang,guan zhuang,guan zhuang zhen,官庄,官庄镇', 34.8991700, 108.4113900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18187, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Kuan-chuang,guan zhuang,官庄', 32.8865400, 113.2954900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18188, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Guanzhuang Zhen,Kuan-chuang,guan zhuang,guan zhuang zhen,官庄,官庄镇', 28.5333300, 110.9000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18189, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Guanzhuang Shezu Xiang,Kuan-chuang,Kuan-chuang-hsu,Kuan-chuang-hsü,guan zhuang,guan zhuang she zu xiang,官庄,官庄畲族乡', 25.3094400, 116.3447200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18190, 'Guanzhu', 'Guanzhu', 'Guanzhu,Guanzhu Zhen,guan zhu,guan zhu zhen,观珠,观珠镇', 21.6905200, 111.1733000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18191, 'Guanzhou', 'Guanzhou', 'Guanzhou,Guanzhou Zhen,Guanzhouchang,Kuan-chou,guan zhou,guan zhou chang,guan zhou zhen,官舟,官舟场,官舟镇', 28.5550000, 108.3422800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18192, 'Guanyuan', 'Guanyuan', 'Guanyuan,Guanyuan Matou,Guanyuan Xiang,guan yuan,guan yuan ma tou,guan yuan xiang,官垸,官垸乡,官垸码头', 29.5587300, 112.0099100, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18193, 'Guanyinsi', 'Guanyinsi', 'Guanyinsi,Kuan-yin-ssu,guan yin si,观音寺', 33.3666700, 106.4547600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18194, 'Guanyinge', 'Guanyinge', 'Guanyinge,Guanyinge Zhen,Kuan-yin-ko,guan yin ge,guan yin ge zhen,观音阁,观音阁镇', 27.9991700, 110.6172200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18195, 'Guanyinge', 'Guanyinge', 'Guanyinge,Guanyinge Zhen,guan yin ge,guan yin ge zhen,观音阁,观音阁镇', 23.3981000, 114.5776400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18196, 'Guanyin', 'Guanyin', 'Guanyin,Guanyin Zhen,guan yin,guan yin zhen,观音,观音镇', 32.9005100, 110.3678500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18197, 'Guanyang', 'Guanyang', 'Guanyang,Guanyang Zhen,Yaozhanzi,guan yang,guan yang zhen,yao zhan zi,官阳,官阳镇,腰栈子', 31.3421900, 109.9052300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18198, 'Guanxu', 'Guanxu', 'Guanxu,Guanyu Zhen,Kuan-hsu,Kuan-hsü,guan wei,guan wei zhen,官圩,官圩镇', 23.2564800, 111.7939600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18199, 'Guancheng', 'Guancheng', 'Guancheng,Guancheng Zhen,Guanxian,Kuan,Kuan-hsien,Kuan-hsien-ch''eng,Kuan-hsien-ch’eng,Kwanhsien,guan cheng,guan cheng zhen,guan xian,冠县,冠城,冠城镇', 36.4803100, 115.4351000, 'CN', '2016-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18200, 'Guantou', 'Guantou', 'Guantou,Guantou Zhen,Kuan-t''ou,Kuan-t''ou-chen,Kuan-t’ou,Kuan-t’ou-chen,guan tou,guan tou zhen,关头,关头镇', 34.6572700, 108.0744800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18201, 'Guantou', 'Guantou', 'Guantou,Guantou Zhen,Kuan-t''ou,Kuan-t’ou,Kwantow,guan tou,guan tou zhen,琯头,琯头镇', 26.1351500, 119.5571800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18202, 'Guanting', 'Guanting', 'Guanting,Guanting Xiang,Kuan-t''ing,Kuan-t’ing,guan ting,guan ting xiang,官厅,官厅乡', 36.1631400, 106.4146900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18203, 'Guanting', 'Guanting', 'Guanting,Guanting Zhen,Kuan-t''ing,Kuan-t’ing,guan ting,guan ting zhen,官亭,官亭镇', 35.8754400, 102.7996200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18204, 'Guanting', 'Guanting', 'Guanting,Guanting Zhen,Kuan-t''ing,Kuan-t’ing,guan ting,guan ting zhen,官亭,官亭镇', 33.8165200, 104.5322700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18205, 'Guantian', 'Guantian', 'Guantian,Guantian Xiang,Kuan-t''ien,Kuan-t’ien,guan tian,guan tian xiang,官田,官田乡', 27.0645400, 114.6665600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18206, 'Guantian', 'Guantian', 'Guantian,Guantian Xiang,guan tian,guan tian xiang,官田,官田乡', 25.0520200, 117.4826200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18207, 'Guantangyi', 'Guantangyi', 'Guantangyi,Guantangyi Zhen,Kuan-t''ang-i,Kuan-t’ang-i,guan tang yi,guan tang yi zhen,官塘驿,官塘驿镇', 29.7756400, 114.0859500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18208, 'Guanshui', 'Guanshui', 'Guanshui,Guanshui Zhen,Tung-ts''un,Tung-ts’un,guan shui,guan shui zhen,观水,观水镇', 37.2164300, 121.2635400, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18209, 'Guanshan', 'Guanshan', 'Guanshan,Guanshan Zhen,Kuan-shan,Kuan-shan-chen,guan shan,关山', 34.6927700, 109.3758300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18210, 'Guanshan', 'Guanshan', 'Guanshan,Guanshan Xiang,Kuan-shan,guan shan,guan shan xiang,冠山,冠山乡', 27.0996800, 115.4461800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18211, 'Guanqiao', 'Guanqiao', 'Guanqiao,Guanqiao Zhen,Kuan-ch''iao,Kuan-ch''iao-hsu,Kuan-ch’iao,Kuan-ch’iao-hsü,guan qiao,guan qiao zhen,官桥,官桥镇', 25.0227800, 118.0872200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18212, 'Guanqiao', 'Guanqiao', 'Guanqiao,Guanqiao Zhen,guan qiao,guan qiao zhen,官桥,官桥镇', 21.7346800, 110.4952600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18213, 'Guanqian', 'Guanqian', 'Guanqian,Guanqian Zhen,Kuan-ch''ien-hsu,Kuan-chien,Kuan-ch’ien-hsü,guan qian,guan qian zhen,管前,管前镇', 26.1796900, 117.9613300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18214, 'Guanqian', 'Guanqian', 'Guanqian,Guanqian Zhen,guan qian,guan qian zhen,馆前,馆前镇', 25.9370200, 116.5430500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18215, 'Guanlu', 'Guanlu', 'Guanlu,Guanlu Zhen,Kuan-lu,Kuan-lu-chen,guan lu,官路', 34.7377900, 109.7218400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18216, 'Guanlu', 'Guanlu', 'Guanlu,Guanlu Zhen,Kuan-lu,Kuan-lu-ch''iao,Kuan-lu-ch’iao,Shijing,guan lu,guan lu zhen,shi jing,官路,官路镇,石井', 28.8332300, 120.6590600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18217, 'Guanlin', 'Guanlin', 'Guanlin,Guanlin Zhen,Kuan-lin,Kuan-lin-chen,Kuan-ts''un,Kuan-ts''un-chen,Kuan-ts’un,Kuan-ts’un-chen,guan lin,guan lin zhen,官林,官林镇', 31.5040400, 119.7116400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18218, 'Guanli', 'Guanli', 'Guanli,Guanli Zhen,Kuan-li,Kuan-li-chi,guan li,guan li zhen,观里,观里镇', 37.1850100, 120.6920000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18219, 'Guanlan', 'Guanlan', 'Guanlan,Guanlan Jiedao,Kuan-lan,Kuan-lan-hsu,Kuan-lan-hsü,guan lan,guan lan jie dao,观澜,观澜街道', 22.7211000, 114.0524400, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18220, 'Guankou', 'Guankou', 'Guankou,Guankou Zhen,Kuan-k''ou,Kuan-k’ou,guan kou,guan kou zhen,关口,关口镇', 30.5500000, 115.3333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18221, 'Guankou', 'Guankou', 'Guankou,Guankou Zhen,Kuan-k''ou,Kuan-k''ou-chen,Kuan-k''ou-hsun-ssu,Kuan-k’ou,Kuan-k’ou-chen,Kuan-k’ou-hsün-ssu,Kwan-kou,Kwankow,guan kou,guan kou zhen,灌口,灌口镇', 24.6123500, 117.9911200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18222, 'Guangzhou', 'Guangzhou', 'CAN,Cantao,Canton,Cantão,Cantón,Fan-yu,Fan-yü,Guanchjou,Guanchzhou,Guanczou,Guand''ou,Guandzhou,Guandzou,Guandžou,Guangdzou,Guangdzov,Guangdžou,Guangdžov,Guangjow,Guangzhou,Guangzhou Shi,Guanzhou,Guančžou,Guaңҗu,Guong-ciu,Guōng-ciŭ,Gvangjcouh,Kanton,Kantono,Kng-chiu-chhi,Kong-chu-su,Kouan''nktsoou,Kouang-chou,Kuang-chou,Kuang-chou-shih,Kwang-chowfu,Kwangchow,Kwangtsjou,Kóng-chû-sṳ,Kńg-chiu-chhī,P''an-yu,Puyun,Puyün,P’an-yü,Quancheum,Quancjou,Quang Chau,Quançjou,Quảng Châu,Shengcheng,ghwanzw,gu''angazu,guang zhou,guang zhou shi,guanjou,gvangajho''u,gvanjea,gwangjeou,gwangjeou si,gwangzhw,gwʼnggwʼw,kantwn,kuvanco,kvangacau,kwang cow,shynyang,Κουανγκτσόου,Гуангџоу,Гуанджоу,Гуандьоу,Гуанжоу,Гуанчжоу,Гуанчжоў,Гуаңҗу,Кантон,Գուանչժոու,גואנגגואו,شینیانگ,غوانزو,کانتون,گوانگژو,گوانگ‌ژو,گۇاڭجۇ شەھىرى,क्वांगचौ,ग्वांगझोउ,ਗੁਆਂਗਜ਼ੂ,குவாங்சோ,ഗ്വാങ്ജോ,กว่างโจว,ກວ່າງໂຈວ,ཀོང་ཀྲོའུ་གྲོང་ཁྱེར།,ကွမ်ကျိုးမြို့,გუანჯოუ,广州,广州市,広州,広州市,廣州,廣州市,광저우,광저우 시', 23.1166700, 113.2500000, 'CN', '2017-06-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18223, 'Guangyubao', 'Guangyubao', 'Guangyubao,Guangyubao Xiang,Kuang-yu-pao,Kuang-yü-pao,Pao-tzu-shang,guang yu bao,guang yu bao xiang,光裕堡,光裕堡乡', 39.1892300, 113.4113500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18224, 'Guanyang', 'Guanyang', 'Guanyang,Kuan-yang,Kuan-yang-chen,Kuan-yang-hsien,Kwangyang-hsien,Kwanyanghsien,guan yang,灌阳', 25.4952300, 111.1348700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18225, 'Guangshun', 'Guangshun', 'Guangshun,Guangshun Jiedao,Guangshunchang,Kuang-shun-ch''ang,Kuang-shun-ch’ang,guang shun,guang shun jie dao,广顺,广顺街道', 29.3748300, 105.5265300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18226, 'Guangshui', 'Guangshui', 'Guangshui,Guangshui Jiedao,Kuang-shui,Kuang-shui-chen,Kuang-shui-shih,Kwangshia,Kwangshui,guang shui,guang shui jie dao,广水,广水街道', 31.6199000, 113.9978000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18227, 'Zishui', 'Zishui', 'Guangshan,Guangshan Chengguanzhen,Guangshan Xian,Kuang-shan,Kuang-shan-hsien,Kwangshan,Zishui,guang shan cheng guan zhen,guang shan xian,zi shui,光山县,光山城关镇,紫水', 32.0077300, 114.9010800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18228, 'Guangrao', 'Guangrao', 'Guangrao,Kuang-jao,Kuang-jao-hsien,Kuang-tao,Kwangjao,Lo-an,Loanhsien,guang rao,广饶', 37.0528600, 118.3991000, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18229, 'Guangping', 'Guangping', 'Guangping,Guangping Zhen,Kuang-p''ing,Kuang-p’ing,guang ping,guang ping zhen,广平,广平镇', 26.0911600, 117.8190400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18230, 'Guangming', 'Guangming', 'Ganxiangying,Guangming,Hsi-te,Kan-hsiang-ying,Kan-shan-ying,Xide,guang ming,光明', 28.3102000, 102.4118900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18231, 'Guangming', 'Guangming', 'Guangming,Guangming Xiang,guang ming,guang ming xiang,光明,光明乡', 26.7947800, 117.3899300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18232, 'Huquan', 'Huquan', 'Guangling,Guangling Xian,Huquan,Huquan Zhen,Kuang-ling,Kuang-ling-hsien,Kwang-ling,guang ling xian,hu quan,hu quan zhen,壶泉,壶泉镇,广灵县', 39.7953800, 114.1830300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18233, 'Guangling', 'Guangling', 'Guangling,Guangling Zhen,Guanglingzhen,Kuang-ling,Kuang-ling-chen,guang ling,guang ling zhen,广陵,广陵镇', 32.1044100, 120.2362700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18234, 'Guangli', 'Guangli', 'Guangli,Guangli Jiedao,Kuang-li,Kuang-li-hsu,Kuang-li-hsü,Kwongli,guang li,guang li jie dao,广利,广利街道', 23.1875500, 112.6108500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18235, 'Guangji', 'Guangji', 'Chi-chen,Guangji,Guangji Zhen,Kuang-chi,guang ji,guang ji zhen,广济,广济镇', 34.1182000, 108.1477600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18236, 'Guanghai', 'Guanghai', 'Guanghai,Guanghai Zhen,Kuang-hai,Kuang-hai-ch''eng,Kuang-hai-chai,Kuang-hai-ch’eng,Kuanghay,Kueng-hai,Kueng-shi,Kwonghoi,guang hai,guang hai zhen,广海,广海镇', 21.9616400, 112.7930700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18237, 'Guangfuqiao', 'Guangfuqiao', 'Guangfuqiao,Guangfuqiao Zhen,guang fu qiao,guang fu qiao zhen,广福桥,广福桥镇', 29.4769900, 111.2981900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18238, 'Guangfu', 'Guangfu', 'Guangfu,Guangfu Zhen,Kuang-fu,Kuang-fu-chen,guang fu,guang fu zhen,光福,光福镇', 31.2878600, 120.3890200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18239, 'Guangcun', 'Guangcun', 'Guangcun,Guangcun Zhen,guang cun,guang cun zhen,光村,光村镇', 19.8176600, 109.4768600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18240, 'Guangchen', 'Guangchen', 'Guangchen,Guangchen Zhen,Kuang-ch''en-chen,Kuang-ch’en-chen,guang chen,guang chen zhen,广陈,广陈镇', 30.7521500, 121.1260300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18241, 'Guang’ao', 'Guang''ao', 'Guang''ao,Guang''ao Jiedao,Guang’ao,Guang’ao Jiedao,guang ao,广澳', 23.2308300, 116.7760400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18242, 'Guangang', 'Guangang', 'Guangang,Guangang Zhen,Kuan-chiang,Kuan-kang,guan gang,guan gang zhen,官港,官港镇', 29.9115900, 116.9285700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18243, 'Guan’er', 'Guan''er', 'Guan''er,Guan''er Xiang,Guan’er,Guan’er Xiang,Kuan-erh,Kuan-erh-shang,guan r,guan r xiang,官儿,官儿乡', 39.5158200, 113.6351900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18244, 'Guandukou', 'Guandukou', 'Guandukou,Guandukou Zhen,Kuan-tu-k''ou,Kuan-tu-k’ou,guan du kou,guan du kou zhen,官渡口,官渡口镇', 31.0392100, 110.3090100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18245, 'Guandu', 'Guandu', 'Guandu,Guandu Zhen,Kuan-tu,guan du,guan du zhen,官渡,官渡镇', 31.9982600, 110.0792800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18246, 'Guandu', 'Guandu', 'Guandu,Guandu Zhen,Kuan-tu,guan du,guan du zhen,官渡,官渡镇', 30.9558900, 109.8469700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18247, 'Guandu', 'Guandu', 'Guandu,Guandu Zhen,Kuan-tu,guan du,guan du zhen,官渡,官渡镇', 30.0810100, 106.4289700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18248, 'Guandu', 'Guandu', 'Chiu-hsi-shui,Guandu,Guandu Zhen,Hsi-shui,Hsi-shui-hsien,Kuan-tu,Kuan-tu-ch''ang,Kuan-tu-ch’ang,Sishui,Sishui-hsien,guan du,guan du zhen,官渡,官渡镇', 28.5683300, 106.1025500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18249, 'Guandu', 'Guandu', 'Guandu,Guandu Zhen,Kuan-tu,Kuan-tu-hsu,Kuan-tu-hsü,guan du,guan du zhen,官渡,官渡镇', 24.2833300, 113.8833300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18250, 'Guandiping', 'Guandiping', 'Guandiping,Guandiping Zhen,Kuan-ti-p''ing,Kuan-ti-p’ing,guan de ping,guan de ping zhen,官地坪,官地坪镇', 29.5923200, 110.4362100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18251, 'Guandian', 'Guandian', 'Guandian,Guandian Zhen,Kuan-tien,guan dian,guan dian zhen,官店,官店镇', 28.2938900, 106.6108300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18252, 'Guandi', 'Guandi', 'Guandi,Guandi Zhen,Kuan-ti,Kuan-ti-chen,guan di,官底', 34.7128100, 109.4428900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18253, 'Guandao', 'Guandao', 'Guandao,Kuan-t''ou-chen,Kuan-tao,Kuan-t’ou-chen,guan dao,官道', 34.6300700, 109.4832800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18254, 'Guanchi', 'Guanchi', 'Guanchi,Guanchi Zhen,Kuan-ch''ih,Kuan-ch’ih,Kuan-yu-ch''ih,Kuan-yü-ch’ih,guan chi,官池', 34.7030600, 109.9403600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18255, 'Guanhaiwei', 'Guanhaiwei', 'Guancheng,Guanchengzhen,Guanhaiwei,Guanhaiwei Zhen,Kuan-ch''eng,Kuan-ch''eng-chen,Kuan-ch’eng,Kuan-ch’eng-chen,Kuan-hai-wei,Kuan-hai-wei-ch''eng,Kuan-hai-wei-ch’eng,guan hai wei,guan hai wei zhen,观海卫,观海卫镇', 30.1703300, 121.4018000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18256, 'Guanchao', 'Guanchao', 'Guanchao,Guanchao Zhen,guan chao,guan chao zhen,观巢,观巢镇', 27.8857000, 114.8642000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18257, 'Guancang', 'Guancang', 'Guancang,Guancang Zhen,guan cang,guan cang zhen,官仓,官仓镇', 28.0361100, 106.7141700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18258, 'Guanbuqiao', 'Guanbuqiao', 'Guanbuqiao,Guanbuqiao Zhen,Kuan-pu-ch''iao,Kuan-pu-ch’iao,guan bu qiao,guan bu qiao zhen,官埠桥,官埠桥镇', 29.9007200, 114.3187700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18259, 'Guanbu', 'Guanbu', 'Guanbu,Guanbu Zhen,guan bu,guan bu zhen,关埠,关埠镇', 23.4336100, 116.4636100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18260, 'Guanban', 'Guanban', 'Guanban,Guanban Zhen,guan ban,guan ban zhen,官坂,官坂镇', 26.3120400, 119.6697500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18261, 'Guanba', 'Guanba', 'Ganbachang,Guanba,Guanba Zhen,guan ba,guan ba zhen,官坝,官坝镇', 30.4886100, 107.8820100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18262, 'Guali', 'Guali', 'Guali,Guali Zhen,Kua-li,Kua-li-shih,gua li,gua li zhen,瓜沥,瓜沥镇', 30.1866100, 120.4535900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18263, 'Guabu', 'Guabu', 'Guabu,Guabu Zhen,Kua-fou,Kua-fou-chen,Kua-pu,gua bu,gua bu zhen,瓜埠,瓜埠镇', 32.2489800, 118.8840800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18264, 'Goujie', 'Goujie', 'Goujie,Goujie Zhen,Kou-chieh,Kou-chieh-tzu,Kowkaitze,gou jie,gou jie zhen,狗街,狗街镇', 24.7891700, 103.1419400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18265, 'Gongyi', 'Gongyi', 'Gongyi,Gongyibu,Gongyizhen,gong yi,gong yi zhen,公易,公易镇', 35.6906500, 105.7217000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18266, 'Gongxi', 'Gongxi', 'Gongxi,Gongxi Zhen,Kung-ch''i,Kung-ch’i,Kung-hsi,Kung-p''o,Kung-p''o-hsu,Kung-pei,Kung-pei-hsu,Kung-pei-hsü,Kung-p’o,Kung-p’o-hsü,gong xi,gong xi zhen,公溪,公溪镇', 27.6610100, 115.9042100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18267, 'Gongtan', 'Gongtan', 'Gongtan,Gongtan Zhen,Kiangtan,Kung-t''an,Kung-t''an-hsun,Kung-t’an,Kung-t’an-hsün,gong tan,gong tan zhen,龚滩,龚滩镇', 28.9077200, 108.3485600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18268, 'Gongqiao', 'Gongqiao', 'Gongqiao,Gongqiao Zhen,Gongshengqiao,Kung-ch''eng-ch''iao,Kung-ch’eng-ch’iao,Kung-sheng-ch''iao,Kung-sheng-ch’iao,gong qiao,gong qiao zhen,功桥,功桥镇', 31.5712800, 118.1838100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18269, 'Gongqiao', 'Gongqiao', 'Gongqiao,Gongqiao Zhen,gong qiao,gong qiao zhen,拱桥,拱桥镇', 25.2500000, 117.3202800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18270, 'Gongping', 'Gongping', 'Chuanzhugong,Gongping,Gongping Zhen,chuan zhu gong,gong ping,gong ping zhen,公平,公平镇,川主宫', 31.1269500, 109.1972200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18271, 'Gongping', 'Gongping', 'Gongping,Gongping Zhen,Kongpeng,Kung-p''ing,Kung-p’ing,gong ping,gong ping zhen,公平,公平镇', 23.0609800, 115.3937700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18272, 'Gongming', 'Gongming', 'Gongming,Gongming Jiedao,Kung-ming,gong ming,gong ming jie dao,公明,公明街道', 22.7874300, 113.8824600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18273, 'Gongjing', 'Gongjing', 'Gongjing,KUNGTSING,Kung-ching,gong jing,贡井', 29.3474800, 104.7115700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18274, 'Gongjiang', 'Gongjiang', 'Gongjiang,Gongjiang Zhen,Yu-tu,Yu-tu-hsien,Yudu,Yudu Xian,Yü-tu,Yü-tu-hsien,gong jiang,gong jiang zhen,yu dou xian,于都县,贡江,贡江镇', 25.9573500, 115.4100200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18275, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Tujiazu Xiang,gong he,gong he tu jia zu xiang,共和,共和土家族乡', 28.1999500, 108.2149600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18276, 'Gonghe', 'Gonghe', 'Gonghe,Mou-ting,Mou-ting-ch''eng,Mou-ting-ch’eng,Mou-ting-hsien,Mouding,Mowting-hsien,Ting-yuan,Ting-yüan,gong he,共和', 25.2557500, 101.5185700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18277, 'Gongguan', 'Gongguan', 'Gongguan,Gongguan Zhen,Kung-kuan,Kung-kuan-hsu,Kung-kuan-hsü,Kungkun,Mao-ming-shih,gong guan,gong guan zhen,公馆,公馆镇', 21.6832300, 110.8373200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18278, 'Gongfang', 'Gongfang', 'Gongfang,Gongfang Zhen,Kung-fang,Kung-fang-hsu,Kung-fang-hsü,gong fang,gong fang zhen,龚坊,龚坊镇', 27.5923000, 115.7534300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18279, 'Gongdian', 'Gongdian', 'Gongdian,gong dian,龚店', 33.6625500, 113.4352100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18280, 'Gongdao', 'Gongdao', 'Gongdao,Gongdao Zhen,Gongdaoqiao,gong dao,gong dao zhen,公道,公道镇', 32.5888900, 119.3477800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18281, 'Gongchuan', 'Gongchuan', 'Gongchuan,Gongchuan Zhen,Kung-ch''uan,Kung-ch’uan,gong chuan,gong chuan zhen,贡川,贡川镇', 26.0919300, 117.4374700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18282, 'Gongchenqiao', 'Gongchenqiao', 'Gongchenqiao,Gongchenqiao Jiedao,Kung-ch''en-ch''iao,Kung-ch’en-ch’iao,gong chen qiao,gong chen qiao jie dao,拱宸桥,拱宸桥街道', 30.3174500, 120.1324300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18283, 'Gongcheng', 'Gongcheng', 'Gongcheng,Kung-ch''eng,Kung-ch''eng-chen,Kung-ch''eng-hsien,Kung-ch’eng,Kung-ch’eng-chen,Kung-ch’eng-hsien,gong cheng,恭城', 24.8333300, 110.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18284, 'Gongchang', 'Gongchang', 'Gongchang,Gongchang Zhen,gong chang,gong chang zhen,龚场,龚场镇', 30.0546800, 113.0956200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18285, 'Gongba', 'Gongba', 'Gongba,gong ba,拱坝', 33.4845900, 104.5286100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18286, 'Guomaying', 'Guomaying', 'Gomangxung,Guomang,Guomaying,Guomaying Zhen,Kuo-ma-ying,guo ma ying,guo ma ying zhen,guo mang,过芒,过马营,过马营镇', 35.8111200, 101.1107900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18287, 'Gomang', 'Gomang', 'Gomang,Gumang,Gumang Xiang,gu mang,gu mang xiang,谷芒,谷芒乡', 35.1816800, 100.4946100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18288, 'Geyuan', 'Geyuan', 'Geyuan,Geyuan Zhen,Ko-yuan,Ko-yüan,ge yuan,ge yuan zhen,葛源,葛源镇', 28.6026400, 117.6718400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18289, 'Getang', 'Getang', 'Getang,Getang Jiedao,Ko-t''ang,Ko-t''ang-chi,Ko-t’ang,Ko-t’ang-chi,ge tang,ge tang jie dao,葛塘,葛塘街道', 32.2442600, 118.7369800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18290, 'Geshan', 'Geshan', 'Geshan,Geshan Zhen,Ko-shan,Ko-shan-ts''un,Ko-shan-ts’un,ge shan,ge shan zhen,歌山,歌山镇', 29.2877200, 120.4374900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18291, 'Geping', 'Geping', 'Geping,Geping Xiang,ge ping,ge ping xiang,戈坪,戈坪乡', 27.6537700, 115.1206000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18292, 'Gensi', 'Gensi', 'Gensi,Gensi Xiang,gen si,gen si xiang,根思,根思乡', 32.2513000, 120.0098100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18293, 'Gengzhen', 'Gengzhen', 'Gengzhen,Keng-chen,Keng-chia-chi-chen,geng zhen,耿镇', 34.4386200, 109.0998400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18294, 'Gengwan', 'Gengwan', 'Gengjiawan,Gengwan,Gengwan Xiang,Keng-chia-wan,geng jia,geng jia wan,geng jia xiang,耿家,耿家乡,耿家湾', 36.8813500, 107.2578300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18295, 'Geling', 'Geling', 'Geling,Geling Zhen,Ko-ling,ge ling,ge ling zhen,葛岭,葛岭镇', 25.8830200, 119.0739700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18296, 'Gelin', 'Gelin', 'Gelin,Gelin Zhen,Ko-lin,ge lin,ge lin zhen,格林,格林镇', 28.5496400, 107.5180900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18297, 'Geleshan', 'Geleshan', 'Geleshan,Geleshan Zhen,Ko-le-shan,ge le shan,ge le shan zhen,歌乐山,歌乐山镇', 29.5779100, 106.4125800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18298, 'Gelan', 'Gelan', 'Gelan,Gelan Zhen,ge lan,ge lan zhen,葛兰,葛兰镇', 30.0358900, 107.1161200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18299, 'Gekeng', 'Gekeng', 'Gekeng,Gekeng Xiang,Gekeng Zhen,Ko-k''eng,Ko-k’eng,ge keng,ge keng xiang,ge keng zhen,葛坑,葛坑乡,葛坑镇', 25.8471300, 118.2012400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18300, 'Gejiu', 'Gejiu', 'Gejiu,Ko-chiu,Ko-chiu-hsien,Ko-chiu-shih,Kokiu,Kokiu-hsien,Kokiuchang,Ku-chiu,ge jiu shi,xi cheng,个旧市,锡城', 23.3608500, 103.1537200, 'CN', '2012-12-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18301, 'Gejia', 'Gejia', 'Gejia,Gejia Zhen,ge jia,ge jia zhen,葛家,葛家镇', 37.1530100, 121.8510900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18302, 'Gegu', 'Gegu', 'Gegu,Gegu Zhen,Kehku,Ko-ku,Ko-ku-chen,ge gu,ge gu zhen,葛沽,葛沽镇', 38.9903600, 117.5091100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18303, 'Gedong', 'Gedong', 'Fangshan,Fangshan Xian,Gedong,Gedong Zhen,Ko-tung,Ko-tung-chen,fang shan xian,ge dong,ge dong zhen,圪洞,圪洞镇,方山县', 37.8931100, 111.2554400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18304, 'Gedian', 'Gedian', 'Gedian,Gedian Zhen,Ko-tien,ge dian,ge dian zhen,葛店,葛店镇', 30.5333300, 114.6166700, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18305, 'Gecheng', 'Gecheng', 'Ch''eng-k''ou-hsien,Chengkou Xian,Chengkow-hsien,Chenkow,Ch’eng-k’ou-hsien,Fu-hsing-chen,Fuxingzhen,Gecheng,Gecheng Zhen,Xinchengzhen,cheng kou xian,ge cheng,ge cheng zhen,城口县,葛城,葛城镇', 31.9485600, 108.6607300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18306, 'Ganzi', 'Ganzi', 'Ganzi,Ganzi Zhen,Garze,Garzê,Kan-tze-hsien,Kan-tzu,Kantse,Kantsi,Kantze,gan zi,gan zi zhen,甘孜,甘孜镇', 31.6274400, 99.9941300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18307, 'Garang', 'Garang', 'Garang,Garang Xiang,Ka-jang,ga rang,ga rang xiang,尕让,尕让乡', 36.2269700, 101.5620600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18308, 'Gaozi', 'Gaozi', 'Gaozi,Gaozi Zhen,Kao-tzu,Kao-tzu-chen,Kaotze,gao zi,gao zi zhen,高资,高资镇', 32.1694600, 119.3019300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18309, 'Gaozhuang', 'Gaozhuang', '', 39.2691700, 117.9755600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18310, 'Gaozhuang', 'Gaozhuang', 'Gaozhuang,Gaozhuang Zhen,Kao-chuang,gao zhuang,gao zhuang zhen,高庄,高庄镇', 34.4644300, 108.9272800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18311, 'Gaozhou', 'Gaozhou', 'Gaozhou,Kao-chou,Kaochow,Kochow,Kochowfu,Mao-ming,Mao-ming-hsien,Mowming,gao zhou,高州', 21.9392400, 110.8460700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18312, 'Gaozeng', 'Gaozeng', 'Gaozeng,Kao-tseng', 25.8016700, 108.9375000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18313, 'Gaoyu', 'Gaoyu', 'Gaoyu,Gaoyu Xiang,gao yu,gao yu xiang,高禹,高禹乡', 30.8211900, 119.6079500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18314, 'Gaoyou', 'Gaoyou', 'Gaoyou,Gaoyou Shi,Gaoyou Zhen,Kao-yu,Kao-yu-ch''eng,Kao-yu-ch’eng,Kao-yu-hsien,Kaoyuchow,gao you,gao you shi,gao you zhen,高邮,高邮市,高邮镇', 32.7893300, 119.4418200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18315, 'Gaoyi', 'Gaoyi', 'Gaoyi,Kao-i,gao yi,高邑', 32.7435600, 113.4564700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18316, 'Gaoya', 'Gaoya', 'Gaoya,Gaoya Zhen,Kao-ya,Kao-ya-chen,Kao-yai-chen,Kao-yen,Kao-yen-chen,gao ya,gao ya zhen,高崖,高崖镇', 34.8967600, 107.3142300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18317, 'Gaoxing', 'Gaoxing', 'Gaoxing,Gaoxing Zhen,Gaoxingxu,Kao-hsing,Kao-hsing-hsu,Kao-hsing-hsü,gao xing,gao xing zhen,高兴,高兴镇', 26.4330600, 115.2825000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18318, 'Gaoxian', 'Gaoxian', 'Gaoxian,Gaoxian Zhen,Kao-hsien,Kao-hsien-chen,gao xian,gao xian zhen,高显,高显镇', 35.7190700, 111.4204000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18319, 'Gaotuan', 'Gaotuan', 'Gaotuan,Gaotuan Zhen,Kao-t''uan,Kao-t’uan,gao tuan,gao tuan zhen,高疃,高疃镇', 37.4658300, 121.1431300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18320, 'Gaotangling', 'Gaotangling', 'Gaotangling,Kao-t''ang-ling,Kao-t’ang-ling,Wangcheng,Wangcheng Xian,gao tang ling,wang cheng xian,望城县,高塘岭', 28.3666700, 112.8166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18321, 'Gaotang', 'Gaotang', 'Gaotang,Gaotang Zhen,Kao-t''ang,Kao-t''ang-chen,Kao-t''ang-chieh,Kao-t’ang,Kao-t’ang-chen,Kao-t’ang-chieh,gao tang,高塘', 34.4065800, 109.6520300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18322, 'Gaotang', 'Gaotang', 'Gaotang,Gaotang Zhen,Kao-t''ang,Kao-t’ang,gao tang,gao tang zhen,高唐,高唐镇', 26.8033300, 117.5870200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18323, 'Gaotan', 'Gaotan', 'Gaotan,Gaotan Zhen,gao tan,gao tan zhen,高潭,高潭镇', 23.1836400, 115.3040000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18324, 'Gaoshan', 'Gaoshan', 'Gaoshan,Gaoshan Tujiazu Xiang,gao shan,gao shan tu jia zu xiang,高山,高山土家族乡', 28.5000000, 108.1666700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18325, 'Gaoshan', 'Gaoshan', 'Gaoshan,Gaoshan Zhen,Kao-shan,Kao-shan-shih,Kaomanshih,Kuoshanshih,gao shan,gao shan zhen,高山,高山镇', 25.4714700, 119.5572800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18326, 'Gaosha', 'Gaosha', 'Gaosha,Gaosha Zhen,Kao-sha,gao sha,gao sha zhen,高砂,高砂镇', 26.4278500, 117.9056900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18327, 'Gaoqiu', 'Gaoqiu', 'Gaoqiu,Gaoqiu Zhen,gao qiu,gao qiu zhen,高丘,高丘镇', 33.1588300, 112.0759600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18328, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,gao qiao,高桥', 34.0952500, 105.9488300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18329, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,Kao-ch''iao,Kao-ch''iao-chen,Kao-ch’iao,Kao-ch’iao-chen,gao qiao,gao qiao zhen,高桥,高桥镇', 32.2290700, 119.6492000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18330, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Xiang,gao qiao,gao qiao xiang,高桥,高桥乡', 31.2285200, 110.5436300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18331, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,Kao-ch''iao-chen,Kao-ch’iao-chen,gao qiao,gao qiao zhen,高桥,高桥镇', 30.5248600, 120.5436800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18332, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Kao-ch''iao,Kao-ch''iao-chen,Kao-ch’iao,Kao-ch’iao-chen,gao qiao,高桥', 30.1020400, 119.9369000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18333, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,Kao-ch''iao,Kao-ch’iao,gao qiao,gao qiao zhen,高桥,高桥镇', 29.9081000, 121.4541800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18334, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,gao qiao,gao qiao zhen,高桥,高桥镇', 29.8564600, 114.5128300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18335, 'Gaoyi', 'Gaoyi', 'Gaoqiao,Gaoyi,Gaoyi Xiang,Kao-i', 26.9594400, 110.0155600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18336, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,Kao-ch''iao,Kao-ch’iao,gao qiao,gao qiao zhen,高桥,高桥镇', 26.5603500, 117.7749700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18337, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Kao-ch''iao,Kao-ch’iao', 26.6336100, 110.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18338, 'Gaoping', 'Gaoping', 'Gaoping,Nan-ch''ung,Nan-ch’ung,Nanchong,gao ping,高坪', 30.7757600, 106.1029400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18339, 'Gaoping', 'Gaoping', 'Gaoping,Gaoping Zhen,gao ping,gao ping zhen,高坪,高坪镇', 30.6636400, 110.0796000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18340, 'Gaoping', 'Gaoping', 'Daqiaobian,Gaoping,Gaoping Zhen,da qiao bian,gao ping,gao ping zhen,大桥边,高坪,高坪镇', 27.4800000, 111.1425000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18341, 'Gaopai', 'Gaopai', 'Gaopai,Gaopai Xiang,Kao-p''ai,Kao-p''ai-hsu,Kao-p’ai,Kao-p’ai-hsü,gao pai,gao pai xiang,高排,高排乡', 25.4895900, 115.6082500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18342, 'Gaoniang', 'Gaoniang', 'Gaoniang,Kao-niang,Kao-niang-chen', 26.8425000, 109.1788900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18343, 'Gaomi', 'Gaomi', 'Gaomi,Kao-mi,Kao-mi-hsien', 36.3833300, 119.7527800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18344, 'Gaoluo', 'Gaoluo', 'Gaoluo,Gaoluo Xiang,Kao-lo,gao luo,gao luo xiang,高罗,高罗乡', 29.7322100, 109.4913500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18345, 'Gaolong', 'Gaolong', 'Gaolong,Gaolong Zhen,Kao-lung,gao long,gao long zhen,高陇,高陇镇', 26.9503400, 113.7868200, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18346, 'Gaoling', 'Gaoling', 'Gaoling,Gaoling Zhen,Kao-ling,gao ling,gao ling zhen,高陵,高陵镇', 37.2938600, 121.5221600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18347, 'Gaoliang', 'Gaoliang', 'Gaoliang,Gaoliang Zhen,Kao-liang,Kao-liang-hsu,Kao-liang-hsü,gao liang,gao liang zhen,高良,高良镇', 23.2830600, 111.9416700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18348, 'Gaoleshan', 'Gaoleshan', 'Chengfeng Xian,Gaoleshan,Gaoleshan Zhen,Hsien-feng,Hsien-feng-hsien,Sienfenghsien,Xianfeng,cheng feng xian,gao le shan,gao le shan zhen,成丰县,高乐山,高乐山镇', 29.6782500, 109.1445300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18349, 'Gaolan', 'Gaolan', 'Gaolan,Gaolan Xiang,Kao-feng,Kao-lan,gao lan,gao lan xiang,高岚,高岚乡', 28.0246000, 114.7061000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18350, 'Gaojingzhuang', 'Gaojingzhuang', 'Gaojingzhuang,Kao-ching-chuang', 39.4161100, 117.6300000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18351, 'Gaojia', 'Gaojia', 'Gaojia,Gaojia Zhen,Gaojiazhen,Kao-chia-chen,Minzhu,gao jia,gao jia zhen,min zhu,民主,高家,高家镇', 31.8261100, 121.5838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18352, 'Gaojia', 'Gaojia', 'Gaojia,Gaojia Zhen,Gaotszyachzhen'',Gaotszyachzhen’,Kao-chia,Kao-chia-chen,Kaokaichen,Kaokiachen,Kiokiachen,gao jia,gao jia zhen,高家,高家镇', 30.0203500, 107.8600000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18353, 'Gaojiayan', 'Gaojiayan', 'Gaojiayan,Gaojiayan Zhen,Kao-chia-yen,gao jia yan,gao jia yan zhen,高家堰,高家堰镇', 30.6088100, 111.0557300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18354, 'Gaojialing', 'Gaojialing', 'Gaojialing,Gaojialing Zhen,gao jia ling,gao jia ling zhen,高家岭,高家岭镇', 29.1675400, 116.7823000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18355, 'Gaojiacun', 'Gaojiacun', 'Dongshan,Dongshan Zhen,Gaojiacun,dong shan,dong shan zhen,gao jia cun,东山,东山镇,高家村', 25.2586100, 104.0633800, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18356, 'Gaojiabu', 'Gaojiabu', 'Gaojiabu,Gaojiabu Xiang,Kao-chia-pao,Kao-chia-pao-ts''un,Kao-chia-pao-ts’un,gao jia bao,gao jia bao xiang,高家堡,高家堡乡', 39.7924900, 112.4461100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18357, 'Gaohu', 'Gaohu', 'Gaohu,Gaohu Zhen,Kao-hu,gao hu,gao hu zhen,高湖,高湖镇', 28.9261100, 115.2363600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18358, 'Gaohe', 'Gaohe', 'Ao-ho-fou,Gaohe,Gaohebu,Huaining Xian,Kao-ho,Kao-ho-fou,Kao-ho-pu,Kaohofow,gao he,huai ning xian,怀宁县,高河', 30.7417300, 116.8425900, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18359, 'Gaoguan', 'Gaoguan', 'Gaoguan,Gaoguan Zhen,Gaoguansi,Gaohuansi,gao guan,gao guan zhen,高观,高观镇', 31.8490500, 108.8908100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18360, 'Gaogu', 'Gaogu', 'Gaogu,Gaogu Zhen,Gaoguqiao,gao gu,gao gu qiao,gao gu zhen,高谷,高谷桥,高谷镇', 29.3955700, 108.0657900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18361, 'Gaogou', 'Gaogou', 'Gaogou,Gaogou Zhen,Kao-chia-kou,Kao-kou,Kao-kou-chen,gao gou,gao gou zhen,高沟,高沟镇', 34.0175000, 119.1886100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18362, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Xiang,gao feng,gao feng xiang,高峰,高峰乡', 28.6666700, 110.1833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18363, 'Gaocun', 'Gaocun', 'Gaocun,Gaocun Zhen,Kao-ts''un,Kao-ts’un,gao cun,gao cun zhen,高村,高村镇', 37.0844000, 122.1933300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18364, 'Gaocun', 'Gaocun', 'Gaocun,Gaocun Zhen,Kao-ts''un,Kao-ts''un-shih,Kao-ts’un,Kao-ts’un-shih,gao cun,gao cun zhen,高村,高村镇', 28.3421600, 114.4344000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18365, 'Gaocun', 'Gaocun', 'Gaocun,Kao-ts''un,Kao-ts''un-chen,Kao-ts’un,Kao-ts’un-chen,Ma-yang-hsien,Mayang,gao cun,高村', 27.8773100, 109.7847600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18366, 'Gaocheng', 'Gaocheng', 'Gaocheng,Gaocheng Zhen,Kao-ch''eng,Kao-ch’eng,gao cheng,gao cheng zhen,高城,高城镇', 31.9470200, 113.4421800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18367, 'Gaocheng', 'Gaocheng', 'Gaocheng,Gaocheng Zhen,Kao-ch''eng,Kao-ch''eng-chen,Kao-ch’eng,Kao-ch’eng-chen,gao cheng,gao cheng zhen,高塍,高塍镇', 31.4566500, 119.8063000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18368, 'Gaocheng', 'Gaocheng', 'Gaocheng,Gaocheng Zhen,Li-ch''ang,Li-ch’ang,Li-hua,Li-hua-hsien,Li-t''ang-hsien,Li-t’ang-hsien,Lichan,Lihwa,Likhua,Litang,Lithang,gao cheng,gao cheng zhen,li tang,理塘,高城,高城镇', 29.9881400, 100.2694000, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18369, 'Gaocheng', 'Gaocheng', 'Gaocheng,Gaocheng Xiang,Kao-ch''eng,Kao-ch’eng,gao cheng,gao cheng xiang,高城,高城乡', 28.1018600, 114.3495100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18370, 'Gaobu', 'Gaobu', 'Gaobu,Gaobu Zhen,Kao-pu,gao bu,gao bu zhen,皋埠,皋埠镇', 30.0092000, 120.6642100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18371, 'Gaobei', 'Gaobei', 'Gaobei,Gaobei Zhen,Mulin,gao bei,gao bei zhen,mu lin,睦邻,高陂,高陂镇', 24.9784300, 116.8709000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18372, 'Gao’an', 'Gao''an', 'Gao''an,Gao''an Zhen,Gao’an,Gao’an Zhen,Kao-an,gao an,gao an zhen,高安,高安镇', 30.2901900, 107.4619700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18373, 'Ganziping', 'Ganziping', 'Ganziping,Ganziping Xiang,gan zi ping,gan zi ping xiang,竿子坪,竿子坪乡', 28.1974400, 109.6533500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18374, 'Ganzhou', 'Ganzhou', 'Ganzhou,Ganzhou Zhen,Kan-chou,Kan-chou-chieh,gan zhou,gan zhou zhen,干洲,干洲镇', 28.8184200, 115.4327300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18375, 'Ganzhou', 'Ganzhou', 'Cam Chau,Cám Châu,Gan''chzhou,Gandzou,Gang-ciu,Gantsjou,Ganzhou,Ganzhou Shi,Gànzhōu,Gáng-ciŭ,KOW,Kam-chu-su,Kan,Kan-chou,Kan-chou-shih,Kan-cou,Kan-hsien,Kan-čou,Kanchow,Kong-chiu-chhi,Kàm-chû-sṳ,Kòng-chiu-chhī,gan zhou,gan zhou shi,ganjeou si,ganzhww,gong zhou,gʼngwʼw,kan zhou,kan zhou shi,Ганьчжоу,Ганџоу,Գանչժոու,גאנגואו,گانژوو,カン州,カン州市,贛州,赣州,赣州市,간저우 시', 25.8466400, 114.9326000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18376, 'Ganyi', 'Ganyi', 'Ganyi,Ganyi Zhen,gan yi,gan yi zhen,干驿,干驿镇', 30.5437800, 113.3802300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18377, 'Ganyao', 'Ganyao', 'Ganyao,Ganyao Zhen,Kan-yao-chen,gan yao,gan yao zhen,干窑,干窑镇', 30.8887600, 120.8853200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18378, 'Ganyan', 'Ganyan', 'Ganyan,Ganyan Tujiazu Xiang,gan yan,gan yan tu jia zu xiang,甘堰,甘堰土家族乡', 29.2786100, 110.7791700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18379, 'Ganxitan', 'Ganxitan', 'Ganxitan,Ganxitan Zhen,Kan-hsi-t''an,Kan-hsi-t’an,gan xi tan,gan xi tan zhen,甘溪滩,甘溪滩镇', 29.8676100, 111.3757900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18380, 'Ganxi', 'Ganxi', 'Ganxi,Ganxi Xiang,Ganxichang,Kan-hsi,gan xi,gan xi chang,gan xi xiang,甘溪,甘溪乡,甘溪场', 28.3900200, 108.4207800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18381, 'Gantang', 'Gantang', 'Gantang,Gantang Zhen,Kan-t''ang,Kan-t''ang-chen,Kan-t''ang-ts''un,Kan-t’ang,Kan-t’ang-chen,Kan-t’ang-ts’un,Taiping,gan tang,gan tang zhen,甘棠,甘棠镇', 30.2969400, 118.1305600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18382, 'Gantang', 'Gantang', 'Gantang,Kan-t''ang,Kan-t''ang-pao,Kan-t’ang,Kan-t’ang-pao', 26.9200000, 119.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18383, 'Gantang', 'Gantang', 'Gantang,Kan-t''ang,Kan-t’ang', 26.7983300, 118.9361100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18384, 'Lingchuan', 'Lingchuan', 'Gantang,Kan-t''ang,Kan-t''ang-hsiang,Kan-t''ang-hsu,Kan-t''ang-tu,Kan-t’ang,Kan-t’ang-hsiang,Kan-t’ang-hsü,Kan-t’ang-tu,Lingchuan,ling chuan,灵川', 25.4095100, 110.3227800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18385, 'Ganshui', 'Ganshui', 'Ganshui,Ganshui Zhen,Kan-shui,Kan-shui-ch''ang,Kan-shui-ch’ang,gan shui,gan shui zhen,赶水,赶水镇', 28.7422200, 106.7111100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18386, 'Ganquan', 'Ganquan', 'Ganquan,Ganquan Zhen,Ganquanshan,Kan-ch''uan-shan,Kan-ch''uan-shan-chen,Kan-ch’üan-shan,Kan-ch’üan-shan-chen,gan quan,gan quan zhen,甘泉,甘泉镇', 32.4806900, 119.3426300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18387, 'Ganpu', 'Ganpu', 'Ganpu,Ganpu Zhen,Kan-p''u,Kan-p''u-ch''eng,Kan-p''u-chen,Kan-p’u,Kan-p’u-chen,Kan-p’u-ch’eng,gan pu,gan pu zhen,澉浦,澉浦镇', 30.3935000, 120.8897200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18388, 'Ganlong', 'Ganlong', 'Ganlong,Ganlong Zhen,gan long,gan long zhen,甘龙,甘龙镇', 28.3293100, 108.7030300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18389, 'Ganlin', 'Ganlin', 'Ganlin,Ganlin Zhen,Kan-lin,gan lin,gan lin zhen,甘霖,甘霖镇', 29.5205600, 120.7141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18390, 'Ganlan', 'Ganlan', 'Ganlan,Ganlan Zhen,Kan-lan,gan lan,gan lan zhen,干览,干览镇', 30.1026800, 122.1369800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18391, 'Ganjun', 'Ganjun', 'Ganjun,Ganjun Zhen,Ganjunpu,gan jun,gan jun zhen,甘浚,甘浚镇', 38.9658300, 100.1697200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18392, 'Ganjing', 'Ganjing', 'Ganjing,Ganjing Zhen,Kan-ching,Nan-kan-ching,gan jing,gan jing zhen,甘井,甘井镇', 34.7205600, 108.0641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18393, 'Ganjiachang', 'Ganjiachang', 'Ganjiachang,Ganjiachang Xiang,gan jia chang,gan jia chang xiang,甘家厂,甘家厂乡', 29.7500000, 112.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18394, 'Ganjia', 'Ganjia', 'Ganjia,Ganjia Xiang,gan jia,gan jia xiang,甘加,甘加乡', 35.4012400, 102.5164000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18395, 'Ganhe', 'Ganhe', 'Ganhe,Ganhe Zhen,Kan-ho,gan he,gan he zhen,甘河,甘河镇', 34.1577800, 108.5144400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18396, 'Gangwei', 'Gangwei', 'Gangwei,Gangwei Zhen,Kang-wei,gang wei,gang wei zhen,港尾,港尾镇', 24.3171500, 118.0072900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18397, 'Gangu Chengguanzhen', 'Gangu Chengguanzhen', 'Fu-ch''iang,Fu-ch’iang,Fu-k''iang-hien,Fu-k’iang-hién,Futsyan,Gangu,Gangu Chengguanzhen,Gangu Xian,Kan-ku,Kan-ku-hsien,gan gu cheng guan zhen,gan gu xian,甘古城关镇,甘谷县', 34.7356400, 105.3263200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18398, 'Gangtou', 'Gangtou', 'Chiang-t''ou,Chiang-t’ou,Gangtou,Gangtou Zhen,Kang-t''ou,Kang-t’ou,gang tou,gang tou zhen,港头,港头镇', 25.5530800, 119.4812200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18399, 'Gangshangji', 'Gangshangji', 'Gangshangji,Gangshangji Zhen,Kang-shang-chi,gang shang ji,gang shang ji zhen,岗上积,岗上积镇', 28.1155700, 116.5197100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18400, 'Gangouyi', 'Gangouyi', 'Gangouyi,Kan-kou-i,gan gou yi,甘沟驿', 35.9563200, 105.0187800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18401, 'Gangou', 'Gangou', 'Gangou,Nagu,Nagu Zhen,gan gou,na gu,na gu zhen,娜姑,娜姑镇,甘沟', 26.5150300, 103.1476800, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18402, 'Gangnan', 'Gangnan', 'Gangnan,Gangnan Zhen,Kang-nan,gang nan,gang nan zhen,岗南,岗南镇', 38.3215000, 114.0215300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18403, 'Gangmei', 'Gangmei', 'Gangmei,Gangmei Zhen,Kang-mei-hsu,Kang-mei-hsü,Kang-wei-hsu,Kang-wei-hsü,Kangmei,Kongmi,gang mei,gang mei zhen,岗美,岗美镇', 22.0438900, 111.7511400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18404, 'Gangkou', 'Gangkou', 'Chiang-k''ou,Chiang-k’ou,Gangkou,Gangkou Zhen,Kang-k''ou,Kang-k’ou,gang kou,gang kou zhen,港口,港口镇', 30.7327800, 118.9111100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18405, 'Gangkoujie', 'Gangkoujie', 'Gangkou,Gangkoujie,Gangkoujie Zhen,Kang-k''ou,Kang-k’ou,gang kou jie,gang kou jie zhen,港口街,港口街镇', 29.7250400, 115.7818900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18406, 'Gangkou', 'Gangkou', 'Gangkou,Gangkou Zhen,gang kou,gang kou zhen,港口,港口镇', 29.2573700, 114.3325500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18407, 'Gangkou', 'Gangkou', 'Gangkou,Gangkou Xiang,gang kou,gang kou xiang,港口,港口乡', 28.7355600, 114.2891800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18408, 'Gangkou', 'Gangkou', 'Gangkou,Gangkou Zhen,Kang-k''ou,Kang-k’ou,gang kou,gang kou zhen,港口,港口镇', 28.1901400, 117.3393000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18409, 'Gangkou', 'Gangkou', 'Gangkou,Gangkou Zhen,Kang-k''ou,Kang-k’ou,gang kou,港口', 22.5747800, 114.8975300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18410, 'Gangkou', 'Gangkou', 'Chiang-k''ou,Chiang-k’ou,Gangkou,Gangkou Zhen,Kang-k''ou,Kang-k’ou,gang kou,gang kou zhen,港口,港口镇', 22.5897200, 113.3747200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18411, 'Ganfang', 'Ganfang', 'Ganfang,Ganfang Xiang,Kan-fang,gan fang,gan fang xiang,甘坊,甘坊乡', 28.6429500, 114.8660500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18412, 'Yaluhu', 'Yaluhu', 'Gan''dutan,Gando,Gandu,Gandu Zhen,Ganducheng,Gan’dutan,Kan-tou-t''ang,Kan-tou-t’ang,Kan-tu,Kan-tu-ssu,Kan-tu-t''ang,Kan-tu-t’ang,Yaluhu,gan dou zhen,ya lu hu,牙路乎,甘都镇', 35.8909600, 102.3289800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18413, 'Gande', 'Gande', 'Gande,Gande Zhen,Hongyou,gan de,gan de zhen,hong you,感德,感德镇,洪佑', 25.2988200, 117.8482200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18414, 'Gancheng', 'Gancheng', 'Gancheng,Gancheng Xiang,Ganchengzi,gan cheng,gan cheng xiang,甘城,甘城乡', 36.5915300, 106.3394300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18415, 'Gancheng', 'Gancheng', 'Chiu-kan-en,Gancheng,Gancheng Zhen,Kamyan,Kan-ch''eng,Kan-ch’eng,Kan-en,Kan-en-hsien,Kan-ngen,Kanem,Kenen,Kumyan,gan cheng,gan cheng zhen,感城,感城镇', 18.8515700, 108.6403700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18416, 'Ganchang', 'Ganchang', 'Ganchang,Ganchang Zhen,Ganchangxi,Kan-ch''ang,Kan-ch''ang-ch''i,Kan-ch’ang,Kan-ch’ang-ch’i,gan chang,gan chang zhen,赶场,赶场镇', 32.4051800, 106.9249400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18417, 'Gaiyang', 'Gaiyang', 'Gaiyang,Gaiyang Zhen,Kai-yang,gai yang,gai yang zhen,盖洋,盖洋镇', 26.4387800, 117.0611400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18418, 'Gaiyang', 'Gaiyang', 'Dunqian,Gaiyang,Gaiyang Xiang,gai yang,gai yang xiang,盖洋,盖洋乡', 25.8414000, 118.4837000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18419, 'Gabasumdo', 'Gabasumdo', 'Gabasongduo,Gabasongduo Zhen,Gabasumdo,Ka-pa-sung-tu,Lo-pa-sung-tu,T''ung-te,Tongde,Tongde Xian,T’ung-te,Ya-pa-sung-tu,ga ba song duo,ga ba song duo zhen,tong de,tong de xian,同德,同德县,尕巴松多,尕巴松多镇', 35.2589000, 100.5499400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18420, 'Fuzhuang', 'Fuzhuang', '', 39.2661100, 117.9344400, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18421, 'Fuzhou', 'Fuzhou', 'FOC,Focheum,Foochow,Foutsoou,Fouzhou,Fu-chou,Fu-chou-shih,Fu-cou,Fu-čou,Fuchau,Fucheu,Fuchzhou,Fucsou,Fudzhou,Fudzou,Fudžou,Fugouo,Fuk-chu-su,Fuk-chû-sṳ,Futsjou,Fuzcouh,Fuzhou,Fuĝoŭo,Hok-chiu-chhi,Hok-chiu-chhī,Hok-ciu,Hók-ciŭ,Lin-sen,Lin-sen-hsien,Min Hsien,Min-hou,Min-hou-hsien,Min-hou-hsien-ch''eng,Min-hou-hsien-ch’eng,Minhow,Minhow-hsien,Phuc Chau,Phúc Châu,fu zhou,fu zhou shi,fuco,fujho''u,fwjw,fwzhw,phucau,pujeou si,Φουτσόου,Фуджоу,Фучжоу,Фуџоу,فوجو,فوزهو,فوژو,فۇجو شەھىرى,फ़ूझोउ,फूचौ,ਫ਼ੂਚੋ,ဖူကျိုးမြို့,福州,福州市,푸저우 시', 26.0613900, 119.3061100, 'CN', '2016-07-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18422, 'Fujia', 'Fujia', 'Fujia,Fujia Zhen,Fuzhen,fu jia,fu jia zhen,伏家,伏家镇', 33.8188900, 105.9536100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18423, 'Fuyong', 'Fuyong', 'Fu-yung,Fukwing,Fuyong,Fuyong Jiedao,fu yong,fu yong jie dao,福永,福永街道', 22.6721400, 113.8151900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18424, 'Fuyang', 'Fuyang', 'FUG,Fou-yang,Fou-yang-hsien,Fowyang,Fowyang-hsien,Fu-jang,Fu-yang-shih,Fujan,Fuyan,Fuyang,Hu-iong-chhi,Hū-iông-chhī,Inchzhou,Paiu-iong,Phu Duong,Phụ Dương,Puyanghsien,Pâiu-iòng,Ying-chou,Yingchow,Yingchow-fu,fu yang,fu yang shi,fwyang,puyang si,Фуян,Ֆույան,فویانگ,阜阳市,阜陽,阜陽市,푸양 시', 32.9000000, 115.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18425, 'Fuyang', 'Fuyang', 'Fu-yang-hsien,Fujan'',Fuyang,Fuyang Shi,Puyang,fu yang,fu yang shi,Фуянь,富阳,富阳市', 30.0533300, 119.9519400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18426, 'Fuyang', 'Fuyang', 'Fuyang,Fuyang Zhen,fu yang,fu yang zhen,涪洋,涪洋镇', 28.5325800, 107.7425200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18427, 'Fuyang', 'Fuyang', 'Chiu-fu-ch''uan,Chiu-fu-ch’uan,Fu-ch''uan-hsien,Fu-ch’uan-hsien,Fu-yang-chen,Fuchuan,Fuchwan,Fuchwan-hsien,Fuyang,fu yang,富阳', 24.8344100, 111.2580200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18428, 'Fuyang', 'Fuyang', 'Fuyang,Fuyang Zhen,fu yang,fu yang zhen,浮洋,浮洋镇', 23.5752000, 116.5853300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18429, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Zhen,Fuxingchang,fu xing,fu xing zhen,复兴,复兴镇', 28.6369400, 109.5640800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18430, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Zhen,Fuxingchang,fu xing,fu xing zhen,复兴,复兴镇', 27.9963400, 107.6110900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18431, 'Fuxing', 'Fuxing', 'Fu-hsing,Fu-hsing-chen,Fuxing,Fuxing Zhen,fu xing,fu xing zhen,复兴,复兴镇', 29.9056000, 116.4142200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18432, 'Wofo', 'Wofo', 'Fu-hsing,Fuxing,Fuxingchang,Wofo,Wofo Zhen,fu xing chang,wo fu,wo fu zhen,卧佛,卧佛镇,复兴场', 29.9082500, 105.7870600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18433, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Tujiazu Miaozu Xiang,Qixingchang,fu xing,fu xing tu jia zu miao zu xiang,qi xing chang,七星场,复兴,复兴土家族苗族乡', 28.0931500, 107.8874300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18434, 'Fuxi', 'Fuxi', 'Fu-ch''i,Fu-ch’i,Fu-hsi,Fuxi,Fuxi Zhen,fu xi,fu xi zhen,富溪,富溪镇', 27.1897200, 119.8244400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18435, 'Fuxi', 'Fuxi', 'Fuxi,Fuxi Zhen,fu xi,fu xi zhen,扶溪,扶溪镇', 25.2177000, 113.8575900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18436, 'Futianhe', 'Futianhe', 'Fu-t''ien-ho,Fu-t’ien-ho,Futianhe,Futianhe Zhen,fu tian he,fu tian he zhen,福田河,福田河镇', 31.4774800, 115.0936100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18437, 'Futian', 'Futian', 'Futian,Futian Zhen,fu tian,fu tian zhen,阜田,阜田镇', 27.4289700, 114.9271000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18438, 'Futian', 'Futian', 'Fu-t''ien,Fu-t''ien-chen,Fu-t’ien,Fu-t’ien-chen,Futian,Futian Jie,fu tian,fu tian jie,富田,富田街', 26.8224700, 115.2494700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18439, 'Futian', 'Futian', 'Fu-t''ien,Fu-t''ien-hsu,Fu-t’ien,Fu-t’ien-hsü,Fuktin,Futian,Futian Zhen,fu tian,fu tian zhen,福田,福田镇', 23.2173900, 113.9555500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18440, 'Futang', 'Futang', 'Futang,Futang Zhen,fu tang,fu tang zhen,福堂,福堂镇', 24.3999000, 112.0967600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18441, 'Fushui', 'Fushui', 'Fu-shui-kang,Fushui,Fushui Zhen,Fushuigang,fu shui,fu shui zhen,洑水,洑水镇', 31.3360400, 113.6920100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18442, 'Fushui', 'Fushui', 'Fu-shui-chen,Fushui,Fushui Zhen,fu shui,敷水', 34.5468300, 109.9538200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18443, 'Fushi', 'Fushi', 'Fu-shih,Fushi,Fushi Zhen,Sheqian,fu shi,fu shi zhen,she qian,抚市,抚市镇,社前', 24.8367700, 116.9186700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18444, 'Fushanzhuang', 'Fushanzhuang', 'Fu-shan-chuang,Fushanzhuang,Fushanzhuang Xiang,fu shan zhuang,fu shan zhuang xiang,福善庄,福善庄乡', 39.2469400, 112.6255600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18445, 'Qingyang', 'Qingyang', 'Fu-shan-hsien,Fushan,Fushan Qu,Qingyang,Qingyang Jiedao,fu shan,fu shan qu,qing yang,qing yang jie dao,清洋,清洋街道,福山,福山区', 37.4958300, 121.2580600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18446, 'Tiantan', 'Tiantan', 'Fou-shan,Fou-shan-hsien,Fushan,Fushan Xian,Tiantan,Tiantan Zhen,fu shan xian,tian tan,tian tan zhen,天坛,天坛镇,浮山县', 35.9661100, 111.8416700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18447, 'Fushan', 'Fushan', 'Fushan,Fushan Xiang,fu shan,fu shan xiang,富山,富山乡', 28.5154700, 115.8531400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18448, 'Fushan', 'Fushan', 'Fushan,Fushan Zhen,fu shan,fu shan zhen,浮山,浮山镇', 23.8539700, 116.8846000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18449, 'Fushan', 'Fushan', 'Fu-shan-shih,Fushan,Fushan Zhen,fu shan,fu shan zhen,福山,福山镇', 19.8361100, 109.9262500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18450, 'Furong', 'Furong', 'Fu-jung,Furong,Furong Zhen,fu rong,fu rong zhen,芙蓉,芙蓉镇', 28.2987800, 121.0317100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18451, 'Furong', 'Furong', 'Furong,Wan''an,Wan''an Xian,Wan-an-hsien,Wan-an-hsien-ch''eng,Wan-an-hsien-ch’eng,Wan’an,Wan’an Xian,fu rong,wan an xian,万安县,芙蓉', 26.4500000, 114.7666700, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18452, 'Fuqiao', 'Fuqiao', 'Fou-ch''iao,Fou-ch''iao-chen,Fou-ch’iao,Fou-ch’iao-chen,Fu-ch''iao,Fu-ch’iao,Fuqiao,Fuqiao Zhen,fu qiao,fu qiao zhen,浮桥,浮桥镇', 31.6038200, 121.2065200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18453, 'Fulu', 'Fulu', 'Fulu,Fulu Zhen,fu lu,fu lu zhen,福禄,福禄镇', 30.6542200, 107.9683200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18454, 'Fuling', 'Fuling', 'Fu-ling-hsia,Fu-ling-hsia-chen,Fuling,Fuling Zhen,Fulingxia,fu ling,fu ling zhen,伏岭,伏岭镇', 30.1386100, 118.7277800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18455, 'Fuling', 'Fuling', 'Fou-chou,Fou-ling,Fou-ling-hsien,Fowchou,Fowchow,Fowling,Fowlinghsien,Fuchou,Fulin,Fuling,Pei-ling,fu ling,Фулин,涪陵', 29.7060000, 107.3957500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18456, 'Fuling', 'Fuling', 'Fu-ling-chen,Fuling,Fuling Zhen,fu ling,fu ling zhen,富岭,富岭镇', 27.8947200, 118.6413900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18457, 'Fuliangpengjie', 'Fuliangpengjie', 'Fuliangpeng,Fuliangpengjie,fu liang peng,fu liang peng jie,富良棚,富良棚街', 24.3149500, 102.0888900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18458, 'Fuliang', 'Fuliang', 'Chiu-fou-liang,Fuliang,Fuliang Xian,Fuliang Zhen,fu liang,fu liang xian,fu liang zhen,浮梁,浮梁县,浮梁镇', 29.3763900, 117.2466700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18459, 'Fukou', 'Fukou', 'Fukou,Fukou Zhen,fu kou,fu kou zhen,富口,富口镇', 26.4490100, 117.6902700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18460, 'Fukou', 'Fukou', 'Fukou,Fukou Xiang,fu kou,fu kou xiang,洑口,洑口乡', 25.7625900, 118.4678800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18461, 'Fujiayan', 'Fujiayan', 'Fujiayan,Fujiayan Xiang,fu jia yan,fu jia yan xiang,傅家堰,傅家堰乡', 30.3095500, 110.4785500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18462, 'Fushi', 'Fushi', 'Fu-shun-hsien,Fujiang,Fushi,Fushun,fu shi,富世', 29.1838200, 105.0011400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18463, 'Fuji', 'Fuji', 'Fu-chi,Fuji,fu ji,福集', 29.1481900, 105.3739100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18464, 'Fugou Chengguanzhen', 'Fugou Chengguanzhen', 'Fu-kou,Fu-kou-hsien,Fugou,Fugou Chengguanzhen,fu gou cheng guan zhen,扶沟城关镇', 34.0666700, 114.3833300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18465, 'Fufeng', 'Fufeng', 'Fu-feng-hsien,Fu-feng-hsien-ch''eng,Fu-feng-hsien-ch’eng,Fufeng,Fufeng Xian,Fufyn,fu feng,fu feng xian,扶风,扶风县', 34.3605100, 107.8734800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18466, 'Fufang', 'Fufang', 'Fu-chia,Fu-fang-hsu,Fu-fang-hsü,Fufang,Fufang Xiang,fu fang,fu fang xiang,傅坊,傅坊乡', 26.9727700, 116.5941400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18467, 'Fu’e', 'Fu''e', 'Fu''e,Fu''e Zhen,Fu-ho,Fu-o,Fu’e,Fu’e Zhen,fu ye,fu ye zhen,富堨,富堨镇', 29.9074700, 118.3736700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18468, 'Fudian', 'Fudian', 'Fu-tien,Fudian,Fudian Zhen,fu dian,fu dian zhen,付店,付店镇', 33.9318700, 112.3564100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18469, 'Fuchunjiang', 'Fuchunjiang', 'Fu-ch''un-chiang,Fu-ch’un-chiang,Fuchunjiang,Fuchunjiang Zhen,fu chun jiang,fu chun jiang zhen,富春江,富春江镇', 29.7126800, 119.6457900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18470, 'Fuchun', 'Fuchun', 'Fuchun,Fuchun Zhen,fu chun,fu chun zhen,赋春,赋春镇', 29.3241200, 117.5434700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18471, 'Fuchuan', 'Fuchuan', 'Fou-ch''uan-chi,Fou-ch’uan-chi,Fu-ch''uan-chi,Fu-ch’uan-chi,Fuchuan,Fuchuan Zhen,fu chuan,fu chuan zhen,阜川,阜川镇', 33.0023800, 106.6897400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18472, 'Fucheng', 'Fucheng', 'Fou-ch''eng,Fou-ch''eng-ch''eng-kuan,Fou-ch''eng-hsien,Fou-ch’eng,Fou-ch’eng-ch’eng-kuan,Fou-ch’eng-hsien,Fouchen,Fowcheng,Fucheng,fu cheng,阜城', 37.8691300, 116.1505800, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18473, 'Fucheng', 'Fucheng', 'Fucheng,Fucheng Xiang,fu cheng,fu cheng xiang,富城,富城乡', 25.5363100, 115.8871300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18474, 'Fuchang', 'Fuchang', 'Fuchang,Fuchang Zhen,fu chang,fu chang zhen,府场,府场镇', 30.1008200, 113.1534700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18475, 'Fubao', 'Fubao', 'Fo-pao-ch''ang,Fo-pao-ch’ang,Fu-pao,Fubao,Fubaochang,fu bao,福宝', 28.7690500, 106.0766700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18476, 'Fu’an', 'Fu''an', 'Fu''an,Fu''an Zhen,Fu-an-chen,Fu’an,Fu’an Zhen,fu an,fu an zhen,富安,富安镇', 32.6779800, 120.4742300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18477, 'Foshan', 'Foshan', 'FUO,Fachan,Fatshan,Fo-san,Fo-shan-chen,Fo-shan-shih,Fo-šan,Fosan,Fosanas,Foshan,Foshan'',Fosjan,Foŝan,Fošanas,Fu-shan-chen,Fut-san-su,Fu̍t-sân-sṳ,Huk-sang,Hut-san-chhi,Hu̍t-san-chhī,Hŭk-săng,Namhoi,Nan-hai,Nanhai-hsien,Nanhoi,Nom Hoy,Phat Son,Phật Sơn,fo shan shi,fu shan,fu shan shi,fwshan,pocan,posan si,Φοσάν,Фошан,Фошань,فوشان,فۇشەن شەھىر,பொசன்,仏山市,佛山,佛山市,포산 시', 23.0267700, 113.1314800, 'CN', '2014-08-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18478, 'Foluo', 'Foluo', 'Fo-lo,Foluo,Foluo Zhen,fu luo,fu luo zhen,佛罗,佛罗镇', 18.5810600, 108.7286100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18479, 'Fenyi', 'Fenyi', 'Chieh-ch''iao,Chieh-ch''iao-chen,Chieh-ch’iao,Chieh-ch’iao-chen,Fen-i,Fen-i-chen,Fenyi,Fenyi Xian,Fenyi Zhen,I-chieh-ch''iao,I-chieh-ch’iao,fen yi,fen yi xian,fen yi zhen,分宜,分宜县,分宜镇', 27.8111700, 114.6680500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18480, 'Fenyan', 'Fenyan', 'Fenyan,Fenyan Zhen,fen yan,fen yan zhen,分盐,分盐镇', 29.9835200, 113.0506500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18481, 'Fenxiang', 'Fenxiang', 'Fen-hsiang-ch''ang,Fen-hsiang-ch’ang,Fenxiang,Fenxiang Zhen,Fenxiangchang,fen xiang,fen xiang zhen,分乡,分乡镇', 30.9120500, 111.4187700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18482, 'Yong’an', 'Yong''an', 'Fen-hsi,Fen-hsi-hsien,Fen-hsi-hsien-ch''eng,Fen-hsi-hsien-ch’eng,Fensi,Fenxi,Fenxi Xian,Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,fen xi xian,yong an,yong an zhen,永安,永安镇,汾西县', 36.6576200, 111.5664300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18483, 'Xiantai', 'Xiantai', 'Fentai,Xiantai,Xiantai Zhen,xian tai,仙台', 33.5301000, 113.4509400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18484, 'Fenshui', 'Fenshui', 'Fen-shui-ling,Fenshui,Fenshui Zhen,Fenshuichang,fen shui,fen shui zhen,分水,分水镇', 30.7197000, 108.0833300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18485, 'Fenshui', 'Fenshui', 'Fenshui,fen shui,分水', 29.9304700, 119.4307000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18486, 'Fenlu', 'Fenlu', 'Fenlu,Fenlu Zhen,fen lu,fen lu zhen,分路,分路镇', 29.7886200, 115.9024400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18487, 'Yangqitan', 'Yangqitan', 'Fenkou,Fenkou Zhen,Yangqitan,fen kou,fen kou zhen,yang qi tan,杨旗坦,汾口,汾口镇', 29.4350300, 118.5442100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18488, 'Fenjie', 'Fenjie', 'Fen-chieh,Fen-chieh-chen,Fenjie,Fenjie Zhen,fen jie,fen jie zhen,分界,分界镇', 32.2778800, 120.3300100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18489, 'Fenjie', 'Fenjie', 'Fenjie,Fenjie Zhen,fen jie,fen jie zhen,分界,分界镇', 21.7723600, 110.9628700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18490, 'Fengzhou', 'Fengzhou', 'Chiu-feng-hsien,Feng,Feng-chou,Feng-chou-chen,Feng-hsien,Fengzhou,Fengzhou Zhen,feng zhou,feng zhou zhen,凤州,凤州镇', 33.9769000, 106.6519300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18491, 'Fengzhou', 'Fengzhou', 'Feng-chou,Fengzhou,feng zhou,丰州', 24.9576200, 118.5336500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18492, 'Fengyuan', 'Fengyuan', 'Feng-yuan-chen,Feng-yüan-chen,Fengyuan,Fengyuan Zhen,feng yuan,丰原', 34.4456600, 109.5636000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18493, 'Fengyu', 'Fengyu', 'Feng-yu-ts''un,Feng-yü-ts’un,Fengyu,Fengyu Xiang,feng yu,feng yu xiang,峰峪,峰峪乡', 39.9251000, 113.6053500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18494, 'Fengyi', 'Fengyi', 'Chiu-mao-hsien,Feng-i,Fengyi,Fengyizhen,Mao,Mao Xian,Mao-hsien,Mao-wen-ch''iang-tsu-tzu-chih-hsien,Mao-wen-ch’iang-tsu-tzu-chih-hsien,Maowen,Mowchow,Mowhsien,feng yi,mao xian,凤仪,茂县', 31.6841200, 103.8538200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18495, 'Fengyi', 'Fengyi', 'Cheng-an,Cheng-an Chou,Cheng-an-hsien,Chenganchow,Feng-i,Fengyi,Fengyi Zhen,Zheng''an,Zheng''an Xian,Zheng’an,Zheng’an Xian,feng yi,feng yi zhen,zheng an xian,凤仪,凤仪镇,正安县', 28.5537000, 107.4390000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18496, 'Fengyang Fuchengzhen', 'Fengyang Fuchengzhen', 'Chiu-feng-yang,Chiu-feng-yang-fu-ch''eng,Chiu-feng-yang-fu-ch’eng,Feng-yang-hsien,Fengyang,Fengyang Fuchengzhen,feng yang fu cheng zhen,凤阳府城镇', 32.8796900, 117.5446500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18497, 'Fengyang', 'Fengyang', 'Fengyang,Fengyang Xiang,feng yang,feng yang xiang,凤阳,凤阳乡', 27.8605800, 114.6415800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18498, 'Fengyang', 'Fengyang', 'Fengyang,Fengyang Xiang,feng yang,feng yang xiang,凤阳乡,风阳', 27.2258300, 119.4672200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18499, 'Fengyang', 'Fengyang', 'Fengyang,Fengyang Zhen,feng yang,feng yang zhen,丰阳,丰阳镇', 25.0497200, 112.2733300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18500, 'Fengxian', 'Fengxian', 'Feng,Feng-hsien,Fengxian', 34.7038800, 116.5871700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18501, 'Fengxi', 'Fengxi', 'Fengxi,Fengxi Zhen,feng xi,feng xi zhen,丰溪,丰溪镇', 31.8752700, 109.7022200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18502, 'Fengxi', 'Fengxi', 'Feng-hsi,Fengxi,Fengxi Xiang,feng xi,feng xi xiang,枫溪,枫溪乡', 26.5112100, 116.8511200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18503, 'Fengxi', 'Fengxi', 'Feng-ch''i,Feng-ch’i,Feng-hsi,Fengxi,Fengxi Zhen,feng xi,feng xi zhen,枫溪,枫溪镇', 23.6636100, 116.6027900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18504, 'Fengting', 'Fengting', 'Fengting,Fengting Zhen,feng ting,feng ting zhen,枫亭,枫亭镇', 25.2448500, 118.8497600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18505, 'Fengtian', 'Fengtian', 'Feng-t''ien,Feng-t''ien-chieh,Feng-t’ien,Feng-t’ien-chieh,Fengtian,Fengtian Zhen,feng tian,feng tian zhen,枫田,枫田镇', 27.3707200, 114.6956600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18506, 'Fengtai', 'Fengtai', 'Fengtai,Fengtaizhen', 39.5580600, 117.7491700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18507, 'Fengtai', 'Fengtai', 'Feng-t''ai-ch''u,Feng-t’ai-ch’ü,Fengtai,Fengtai Jiedao,Fengtai Qu,feng tai,feng tai jie dao,feng tai qu,丰台,丰台区,丰台街道', 39.8475700, 116.2722700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18508, 'Fengtai Chengguanzhen', 'Fengtai Chengguanzhen', 'Feng-t''ai-hsien,Feng-t’ai-hsien,Fengtai,Fengtai Chengguanzhen,feng tai cheng guan zhen,凤台城关镇', 32.7082500, 116.7295600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18509, 'Fengshi', 'Fengshi', 'Feng-shih,Fengshi,Fengshi Zhen,feng shi,feng shi zhen,峰市,峰市镇', 24.6774400, 116.6226000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18510, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Zhen,feng shan,feng shan zhen,丰山,丰山镇', 31.1121800, 114.1630900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18511, 'Fengshan', 'Fengshan', 'Fengshan,Lo-t''ien,Lo-t''ien-hsien,Lo-t’ien,Lo-t’ien-hsien,Luotian,feng shan,凤山', 30.8871200, 115.4209100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18512, 'Fengshan', 'Fengshan', 'Fengshan,Lo-yuan,Lo-yuan-hsien,Lo-yüan,Lo-yüan-hsien,Luoyuan,Luyuanhsien,feng shan,凤山', 26.4855600, 119.5491700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18513, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Xiang,feng shan,feng shan xiang,丰山,丰山乡', 26.4269500, 116.4403400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18514, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Xiang,feng shan,feng shan xiang,凤山,凤山乡', 25.5757000, 118.5567800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18515, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Xiang,feng shan,feng shan xiang,凤山,凤山乡', 25.0525200, 115.3801500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18516, 'Fengcheng', 'Fengcheng', 'Feng-ch''eng-chen,Feng-ch''eng-hsiang,Feng-ch’eng-chen,Feng-ch’eng-hsiang,Feng-shan-hsien,Feng-shan-hsien-ch''eng,Feng-shan-hsien-ch’eng,Fengcheng,Fengshan,feng cheng,凤城', 24.5711700, 107.0424300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18517, 'Fengrun', 'Fengrun', 'Chiu-feng-jun,Feng-jun,Feng-jun-ch''eng-kuan,Feng-jun-ch’eng-kuan,Feng-jun-hsien,Fengrun', 39.8333300, 118.1166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18518, 'Rentian', 'Rentian', 'Feng-jen,Feng-jen-shih,Fengren,Rentian,Rentian Zhen,Zhenqi Dushang,ren tian,ren tian zhen,zhen qi du shang,稔田,稔田镇,镇岐渡上', 24.8532500, 116.5992100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18519, 'Fengqiu Chengguanzhen', 'Fengqiu Chengguanzhen', 'Feng-ch''iu,Feng-ch''iu-hsien,Feng-ch’iu,Feng-ch’iu-hsien,Fengkiushien,Fengqiu,Fengqiu Chengguanzhen,feng qiu cheng guan zhen,封丘城关镇', 35.0291700, 114.4130600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18520, 'Fengqiao', 'Fengqiao', 'Fengqiao,Fengqiao Zhen,feng qiao,feng qiao zhen,凤桥,凤桥镇', 30.6610800, 120.8544900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18521, 'Fengqiao', 'Fengqiao', 'Feng-ch''iao,Feng-ch''iao-chen,Feng-ch’iao,Feng-ch’iao-chen,Fengkiao,Fengqiao,Fengqiao Zhen,feng qiao,feng qiao zhen,枫桥,枫桥镇', 29.7903800, 120.4151900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18522, 'Fengpu', 'Fengpu', 'Fengpu,Fengpu Xiang,Fong-pu,feng bu,feng bu xiang,凤埔,凤埔乡', 26.6827600, 118.7600600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18523, 'Fengmu', 'Fengmu', 'Fengmu,Fengmu Zhen,feng mu,feng mu zhen,枫木,枫木镇', 19.2093300, 110.0082900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18524, 'Fengming', 'Fengming', 'Ch''i-shan,Ch''i-shan-hsien,Ch''i-shan-hsien-ch''eng,Ch’i-shan,Ch’i-shan-hsien,Ch’i-shan-hsien-ch’eng,Fengming,Fengming Zhen,Qishan,Tsishan'',Tsishan’,feng ming,feng ming zhen,qi shan,岐山,风鸣,风鸣镇', 34.4413900, 107.6177800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18525, 'Fenglu', 'Fenglu', 'Ch''eng-chiang,Ch''eng-chiang-hsien,Chengjiang,Chengjiang Xian,Chengkiang,Chengkiang-hsien,Ch’eng-chiang,Ch’eng-chiang-hsien,Fenglu,Fenglu Zhen,Ho-yang,cheng jiang,cheng jiang xian,feng lu,feng lu zhen,凤麓,凤麓镇,澄江,澄江县', 24.6765200, 102.9112900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18526, 'Fenglingtou', 'Fenglingtou', 'Fen-ling-t''ou,Fen-ling-t’ou,Fenglingtou,Fenglingtou Zhen,feng ling tou,feng ling tou zhen,枫岭头,枫岭头镇', 28.4631500, 117.8453700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18527, 'Fenglin', 'Fenglin', 'Fenglin,Fenglin Jiedao,feng lin,feng lin jie dao,凤林,凤林街道', 37.4125300, 122.1704600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18528, 'Fenglin', 'Fenglin', 'Fenglin,Fenglin Zhen,feng lin,feng lin zhen,枫林,枫林镇', 29.7613400, 115.3963300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18529, 'Fenglin', 'Fenglin', 'Feng-lin-chen,Fenglin,Fenglin Zhen,feng lin,feng lin zhen,枫林,枫林镇', 28.3220200, 120.7633900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18530, 'Fengliang', 'Fengliang', 'Chiu-feng-shun,Feng-shun,Feng-shun-hsien,Fengliang,Fengliang Zhen,Fungshun,Fungshun-hsien,Pungshan hsien,feng liang,feng liang zhen,丰良,丰良镇', 23.9524600, 116.2020400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18531, 'Fengli', 'Fengli', 'Feng-li-ch''ang,Feng-li-chen,Feng-li-ch’ang,Fengli,Fengli Zhen,Fenglizhen,feng li,feng li zhen,丰利,丰利镇', 32.4479300, 121.0435300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18532, 'Fengle', 'Fengle', 'Fengle,Fengle Zhen,feng le,feng le zhen,丰乐,丰乐镇', 31.4662100, 112.4730000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18533, 'Fengle', 'Fengle', 'Fengle,Fengle Zhen,feng le,feng le zhen,丰乐,丰乐镇', 28.3497200, 107.8533300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18534, 'Fenglang', 'Fenglang', 'Fenglang,Fenglang Zhen,feng lang,feng lang zhen,枫朗,枫朗镇', 24.2610000, 116.8017000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18535, 'Fengkou', 'Fengkou', 'Fengkou,Fengkou Zhen,Fengkow,feng kou,feng kou zhen,峰口,峰口镇', 30.0826800, 113.3334600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18536, 'Fengjing', 'Fengjing', 'Feng-ching,Feng-ching-chen,Fengjing,Fengjingzhen,Fengking,feng jing,枫泾', 30.8901900, 121.0119500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18537, 'Fengjiang', 'Fengjiang', 'Feng-chiang,Fengjiang,Fengjiang Zhen,feng jiang,feng jiang zhen,枫江,枫江镇', 27.4004300, 115.0009900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18538, 'Fengjia', 'Fengjia', 'Feng-chia,Fengjia,Fengjia Zhen,feng jia,feng jia zhen,冯家,冯家镇', 37.0346000, 121.6718200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18539, 'Fengjia', 'Fengjia', 'Fengjia,Fengjia Jiedao,Fengjiaba,feng jia,feng jia jie dao,冯家,冯家街道', 29.3931300, 108.7845900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18540, 'Fenghuo', 'Fenghuo', 'Fenghuo,Fenghuo Zhen,feng huo,feng huo zhen,烽火,烽火镇', 34.5533300, 108.6283300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18541, 'Fenghui', 'Fenghui', 'Feng-hui-chen,Fenghui,Fenghui Zhen,Hui-feng-chen,Shang-yu,Shang-yu-hsien,Shang-yü,Shang-yü-hsien,feng hui,feng hui zhen,丰惠,丰惠镇', 29.9492400, 120.9765600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18542, 'Fenghuang', 'Fenghuang', 'Fenghuang,Fenghuang Zhen,feng huang,feng huang zhen,凤凰,凤凰镇', 23.9084400, 116.6997200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18543, 'Fenggao', 'Fenggao', 'Feng-kao-p''u,Feng-kao-p’u,Fenggao,Fenggao Zhen,Fenggaopu,feng gao,feng gao zhen,峰高,峰高镇', 29.4268500, 105.6750600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18544, 'Fenggang', 'Fenggang', 'Feng-chiang,Fenggang,Fenggang Xiang,feng gang,feng gang xiang,枫港,枫港乡', 28.5939000, 116.5867200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18545, 'Fenggang', 'Fenggang', 'Chiu-i-huang,Fenggang,Fenggang Zhen,I-huang,I-huang-hsien,I-huang-hsien-ch''eng,I-huang-hsien-ch’eng,Ihwang,Ihwang-hsien,Yihuang,Yihuang Xian,feng gang,feng gang zhen,yi huang xian,宜黄县,风冈,风冈镇', 27.5456600, 116.2145600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18546, 'Fenggang', 'Fenggang', 'Fenggang,Fenggang Zhen,feng gang,feng gang zhen,凤岗,凤岗镇', 23.9842700, 112.3477300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18547, 'Shuangzhu', 'Shuangzhu', 'Feng-pu,Feng-tu,Fengdu,Shuangzhu,shuang zhu,双珠', 26.6311400, 118.6457000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18548, 'Fengdie', 'Fengdie', 'Fengdie,feng die,峰迭', 33.8104900, 104.2450700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18549, 'Fengchuan', 'Fengchuan', 'Fen-hsin,Feng-hsin,Feng-hsin-hsien,Feng-hsin-hsien-ch''eng,Feng-hsin-hsien-ch’eng,Fengchuan,Fengchuan Zhen,Fengsin,Fengsin-hsien,Fengxin Xian,feng chuan,feng chuan zhen,feng xin xian,冯川,冯川镇,奉新县', 28.7000000, 115.3833300, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18550, 'Fengcheng', 'Fengcheng', 'Chiu-feng-hsien,Chiu-hsien,Feng-hsien,Feng-hsien-ch''eng,Feng-hsien-ch’eng,Feng-hsien-ku-chih,Fengcheng,Fengcheng Zhen,feng cheng,feng cheng zhen,奉城,奉城镇', 30.9157800, 121.6404000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18551, 'Fengcheng', 'Fengcheng', 'Fengcheng,Lianjiang,Lien-chiang,Lien-chiang-hsien,Lien-chiang-hsien-ch''eng,Lien-chiang-hsien-ch’eng,Lienkang,Lienkong,Lienkong-hsien,feng cheng,凤城', 26.1972200, 119.5391700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18552, 'Fengcheng', 'Fengcheng', 'An-ch''i,An-ch''i-hsien,An-ch’i,An-ch’i-hsien,An-hsi,Anki,Ankihsien,Anxi Xian,Fengcheng,Fengcheng Zhen,an xi xian,feng cheng,feng cheng zhen,凤城,凤城镇,安溪县', 25.0569700, 118.1829000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18553, 'Fengcheng', 'Fengcheng', 'Fengcheng,Fengcheng Zhen,Yongding,Yongding Xian,Yung-ting,Yung-ting-hsien,feng cheng,feng cheng zhen,yong ding,yong ding xian,凤城,凤城镇,永定,永定县', 24.7236500, 116.7242900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18554, 'Fengcheng', 'Fengcheng', 'Ch''ang-ning,Changninghsien,Chongning,Ch’ang-ning,Fengcheng,Fengcheng Jiedao,Fengcheng Zhen,Hsin-feng,Hsin-feng-hsien,Hsin-feng-hsien-ch''eng,Hsin-feng-hsien-ch’eng,Sinfenghsien,Sinfung,Sun-feng-hsien,Sunfung,Xinfeng Xian,feng cheng,feng cheng jie dao,xin feng xian,xin feng zhen,丰城,丰城街道,新丰县,新丰镇', 24.0547900, 114.2134600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18555, 'Fencheng', 'Fencheng', 'Feichenghsien,Fen''chen,Fen-ch''eng-chen,Fen-ch''eng-hsien,Fen-ch’eng-chen,Fen-ch’eng-hsien,Fencheng,Fencheng Zhen,Feng-ch''eng,Feng-ch’eng,Fen’chen,T''ai-p''ing,Taipinghsien,Taupin,T’ai-p’ing,fen cheng,fen cheng zhen,汾城,汾城镇', 35.8176500, 111.2742500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18556, 'Feizhu', 'Feizhu', 'Feizhu,Feizhu Zhen,fei zhu,fei zhu zhen,飞竹,飞竹镇', 26.4590700, 119.3399000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18557, 'Feicheng', 'Feicheng', 'Chiu-fei-hsien,Fei,Fei-hsien,Fei-hsien-ch''eng,Fei-hsien-ch’eng,Feicheng,Feixian,Pi-hsien', 35.2605600, 117.9675000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18558, 'Feiluan', 'Feiluan', 'Feloon', 26.5625000, 119.5975000, 'CN', '2017-05-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18559, 'Fasi', 'Fasi', 'Fasi,Fasi Zhen,fa si,fa si zhen,法泗,法泗镇', 30.1564000, 114.1564000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18560, 'Fanshi', 'Fanshi', 'Chiu-fan-chih,Fan-chih,Fan-chih-ch''eng,Fan-chih-ch’eng,Fan-chih-hsien,Fan-shih,Fancheng,Fancheng Zhen,Fansze,Fantzehsien,Fanzhi Xian,fan cheng,fan cheng zhen,fan shi xian,繁城,繁城镇,繁峙县', 39.1899200, 113.2640100, 'CN', '2015-11-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18561, 'Yangjia', 'Yangjia', 'Fan-shih,Fanshi,Fanshi Zhen,Fanshizhen,Yangjia,fan shi,fan shi zhen,yang jia,杨家,范市,范市镇', 30.1044300, 121.4673200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18562, 'Fankou', 'Fankou', 'Fan-k''ou-chieh,Fan-k’ou-chieh,Fankou,Fankou Jiedao,fan kou,fan kou jie dao,樊口,樊口街道', 30.4166700, 114.8333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18563, 'Fanzhuang', 'Fanzhuang', 'Fan-chia-chuang,Fanchia,Fanjiazhuang,Fanzhuang,Fanzhuangzi,fan zhuang,范庄', 39.1936100, 117.3350000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18564, 'Fanjiazhai', 'Fanjiazhai', 'Fan-chia,Fan-chia-chai,Fanjiazhai,fan jia zhai,范家寨', 34.5983600, 107.3988000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18565, 'Fanzhen', 'Fanzhen', 'Fan-chia-p''u,Fan-chia-p’u,Fanjiapu,Fanzhen,Fanzhen Zhen,fan zhen,fan zhen zhen,范镇,范镇镇', 29.5829400, 115.5641900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18566, 'Fanjiachuan', 'Fanjiachuan', 'Fanjiachuan,Fanjiachuan Xiang,fan jia chuan,fan jia chuan xiang,樊家川,樊家川乡', 36.5800200, 107.4607100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18567, 'Fangxian', 'Fangxian', 'Fang-hsien-ch''iao,Fang-hsien-chen,Fang-hsien-ch’iao,Fangxian,Fangxian Zhen,fang xian,fang xian zhen,访仙,访仙镇', 32.0010400, 119.7340900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18568, 'Fangxian Chengguanzhen', 'Fangxian Chengguanzhen', 'Fang,Fang-hsien,Fangxian,Fangxian Chengguanzhen,fang xian cheng guan zhen,房县城关镇', 32.0550000, 110.7341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18569, 'Fangxi', 'Fangxi', 'Fang-hsi,Fangxi,Fangxi Zhen,fang xi,fang xi zhen,芳溪,芳溪镇', 28.3452100, 114.6386400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18570, 'Fangting', 'Fangting', 'Fangting,Shifang,Shih-fang,Shih-fang-hsien', 31.1276600, 104.1664900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18571, 'Fangtian', 'Fangtian', 'Fangtian,fang tian,方田', 26.1846800, 116.5402300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18572, 'Fangshan', 'Fangshan', 'Chou-k''ou-tien-ch''u,Chou-k’ou-tien-ch’ü,Fang-shan-hsien,Fangshan,Ta-fang-shan,fang shan,房山', 39.6869900, 115.9965800, 'CN', '2014-12-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18573, 'Fangqiao', 'Fangqiao', 'Fang-ch''iao,Fang-ch''iao-chen,Fang-ch’iao,Fang-ch’iao-chen,Fangqiao,Fangqiao Zhen,fang qiao,fang qiao zhen,芳桥,芳桥镇', 31.4152400, 119.9352000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18574, 'Fangqiang', 'Fangqiang', 'Fangqiang,Fangqiang Zhen,fang qiang,fang qiang zhen,方强,方强镇', 33.3795600, 120.4258600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18575, 'Fangqian', 'Fangqian', 'Fang-ch''ien,Fang-ch''ien-chen,Fang-ch’ien,Fang-ch’ien-chen,Fangqian,Fangqian Jiedao,fang qian,fang qian jie dao,坊前,坊前街道', 31.5574400, 120.3801600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18576, 'Fangli', 'Fangli', 'Fang-li-chen,Fangli,Fangli Zhen,Wan-li-chen,fang li,fang li zhen,方里,方里镇', 34.8230600, 108.7369400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18577, 'Fangjiazhuang', 'Fangjiazhuang', 'Fang-chia-chuang,Fang-chuang-chen,Fangjiazhuang', 39.7297200, 117.4205600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18578, 'Fangxiang', 'Fangxiang', 'Fang-chia-hsiang,Fangjiaxiang,Fangxiang,Fangxiang Zhen,fang xiang,fang xiang zhen,方巷,方巷镇', 32.5052100, 119.3857400, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18579, 'Fanggaoping', 'Fanggaoping', 'Fang-kao-p''ing,Fang-kao-p’ing,Fanggaoping,Fanggaoping Zhen,fang gao ping,fang gao ping zhen,方高坪,方高坪镇', 30.6855200, 114.9269600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18580, 'Fangfan', 'Fangfan', 'Fangfan,Fangfan Zhen,fang fan,fang fan zhen,芳畈,芳畈镇', 31.3898000, 114.1042600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18581, 'Fangcun', 'Fangcun', 'Changhong,Fang-ts''un,Fang-ts’un,Fangcun,fang cun,zhang hong,芳村,长虹', 29.2419400, 118.2386100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18582, 'Fangcun', 'Fangcun', 'Fang-ts''un,Fang-ts''un-chen,Fang-ts’un,Fang-ts’un-chen,Fangcun,Fangcun Zhen,fang cun,fang cun zhen,方村,芳村,芳村镇', 29.0549800, 118.6133000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18583, 'Fangcheng Chengguanzhen', 'Fangcheng Chengguanzhen', 'Fang-ch''eng-hsien,Fang-ch’eng-hsien,Fangcheng,Fangcheng Chengguanzhen,Yu-chou,Yuchow,Yü-chou,Yüchow,fang cheng cheng guan zhen,方城城关镇', 33.2532200, 113.0012000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18584, 'Fanchuan', 'Fanchuan', 'Fan-ch''uan-chen,Fan-ch’uan-chen,Fanchuan,Fanchuan Zhen,Fanchwanchen,fan chuan,fan chuan zhen,樊川,樊川镇', 32.6655400, 119.6833800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18585, 'Fanyang', 'Fanyang', 'Fan-ch''ang-hsien,Fan-ch’ang-hsien,Fanchang,Fanyang,Fanyang Zhen,fan yang,fan yang zhen,繁阳,繁阳镇', 31.0847100, 118.1942500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18586, 'Famen', 'Famen', 'Ch''ung-cheng-chen,Chunchzhenchzhen'',Chunchzhenchzhen’,Ch’ung-cheng-chen,Fa-men-ssu,Famen,Famen Zhen,Famensi,fa men,fa men si,fa men zhen,法门,法门寺,法门镇', 34.4369600, 107.8986600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18587, 'Ezhou', 'Ezhou', 'Echeng,Echeng-hsien,Ezhou,O-ch''eng,O-ch''eng-hsien,O-ch’eng,O-ch’eng-hsien,Shou-ch''ang,Shou-ch’ang,Wuchanghsien', 30.4000000, 114.8333300, 'CN', '2011-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18588, 'Erwangzhuang', 'Erwangzhuang', 'Erh-chuang,Erh-chuang-chen,Erh-chuang-tzu,Erh-hsin-chuang,Erhchuangtze,Erwangzhuang', 39.3916700, 117.3538900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18589, 'Ershilipu', 'Ershilipu', 'Erh-shih-li-p''u,Erh-shih-li-p’u,Ershilipu,Ershilipu Zhen,er shi li pu,er shi li pu zhen,二十里铺,二十里铺镇', 38.0329500, 114.5741600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18590, 'Ershilipu', 'Ershilipu', 'Erh-shih-li-p''u,Erh-shih-li-p’u,Ershilipu,Ershilipu Zhen,er shi li pu,er shi li pu zhen,二十里铺,二十里铺镇', 36.7086600, 101.7538000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18591, 'Erqu', 'Erqu', 'Chou-chih,Chou-chih-hsien,Chowchih,Chowchihhsien,Chzhouchzhi,Erqu,Erqu Zhen,Zhouzhi Xian,er qu,er qu zhen,zhou zhi xian,二曲,二曲镇,周至县', 34.1527800, 108.2063900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18592, 'Erlong', 'Erlong', 'Erlong,er long,二龙', 33.2195700, 112.1847000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18593, 'Erling', 'Erling', 'Erh-ling,Erh-ling-chen,Erling,Erling Zhen,er ling,er ling zhen,珥陵,珥陵镇', 31.8797400, 119.5955800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18594, 'Erlang', 'Erlang', 'Erlang,Erlangmiao,er lang,二郎', 33.8394600, 105.5883100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18595, 'Dawu Chengguanzhen', 'Dawu Chengguanzhen', 'Dawu,Dawu Chengguanzhen,Dawu Xian,Erh-lang-fan,Erh-lang-tien,Erlangdian,Ta-wu,da wu cheng guan zhen,大悟城关镇', 31.6096500, 114.1180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18596, 'Erkou', 'Erkou', 'Erh-k''ou,Erh-k’ou,Erkou,Erkou Xiang,er kou,er kou xiang,耳口,耳口乡', 27.9579300, 117.1458100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18597, 'Erjia', 'Erjia', 'Erh-chia,Erh-chia-chen,Erhkia,Erjia,Erjia Zhen,Erjiazhen,er jia,er jia zhen,二甲,二甲镇', 32.0228700, 121.1855700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18598, 'Erdu', 'Erdu', 'Erdu,Erdu Zhen,Erh-tu,er dou,er dou zhen,二都,二都镇', 27.4563200, 116.1720600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18599, 'Erba', 'Erba', 'Erba,Erba Zhen,Erh-pa,er ba,er ba zhen,二坝,二坝镇', 31.3445400, 118.3308200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18600, 'Eqiao', 'Eqiao', 'Eqiao,Erqiao Zhen,O-ch''iao,O-ch''iao-chen,O-ch’iao,O-ch’iao-chen,e qiao,e qiao zhen,峨桥,峨桥镇', 31.1759300, 118.2834900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18601, 'Enshi', 'Enshi', 'ENH,Ehn''shi,En-shih,En-shih-hsien,Enshi,Shih-nan,Shihnanfu,en shi,Ēnshī,Эньши,恩施', 30.3000000, 109.4833300, 'CN', '2016-06-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18602, 'Enle', 'Enle', 'Enle,en le,恩乐', 23.9604900, 101.0826500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18603, 'Enjiang', 'Enjiang', 'Enjiang,Enjiang Zhen,Yongfeng Xian,Yung-feng,Yung-feng-hsien,Yung-feng-hsien-ch''eng,Yung-feng-hsien-ch’eng,en jiang,en jiang zhen,yong feng xian,恩江,恩江镇,永丰县', 27.3217700, 115.4292500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18604, 'Encheng', 'Encheng', 'Ehn''pin,En-p''ing-chen,En-p''ing-hsien,En-p’ing-chen,En-p’ing-hsien,Encheng,Encheng Jiedao,Enping,Yan-ping-hsien,Yanping,Yin Ping,en cheng jie dao,en ping,si cheng,Эньпин,思城,恩城街道,恩平', 22.1865900, 112.3042400, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18605, 'Eman', 'Eman', 'Eman,Eman Zhen,e man,e man zhen,峨蔓,峨蔓镇', 19.8572300, 109.2627100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18606, 'Eling', 'Eling', 'Eling,Eling Zhen,O-ling,O-ling-chen,e ling,e ling zhen,峨岭,峨岭镇', 30.8451000, 118.3017000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18607, 'Ekou', 'Ekou', 'Ekou,Ekou Zhen,Hao-chia-chieh,Haojiajie,O-k''ou,O-k''ou-chen,O-k’ou,O-k’ou-chen,e kou,e kou zhen,峨口,峨口镇', 39.1312500, 113.1911900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18608, 'Ehu', 'Ehu', 'Ehu,Ehu Zhen,O-hu,O-hu-t''an,O-hu-t’an,e hu,e hu zhen,鹅湖,鹅湖镇', 29.4761400, 117.4484000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18609, 'Ehen Hudag', 'Ehen Hudag', 'A-la-shan-yu-ch''i,A-la-shan-yu-ch’i,Alashanyou Qi,Alxa Youqi,Ehen Hudag,Ekenhu Duge Zhen,O-k''en-hu-tu-ko,O-k’en-hu-tu-ko,a la shan you qi,e ken hu dou ge,e ken hu dou ge zhen,阿拉善右旗,额肯呼都格,额肯呼都格镇', 39.2107400, 101.6689800, 'CN', '2013-09-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18610, 'Duzhuang', 'Duzhuang', 'Duzhuang,Duzhuang Zhen,Tu-chia-chuang,Tu-chuang,du zhuang,du zhuang zhen,杜庄,杜庄镇', 39.9350000, 113.4672200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18611, 'Duzhou', 'Duzhou', 'Duzhou,Duzhou Zhen,Tu-chou,du zhou,du zhou zhen,渡舟,渡舟镇', 29.8784800, 107.0784000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18612, 'Duze', 'Duze', 'Duze,Duze Zhen,She-tse,Tu-tse,Tu-tse-chen,du ze,du ze zhen,杜泽,杜泽镇', 29.1244300, 118.9455900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18613, 'Duyun', 'Duyun', 'Dujun,Duyun,Dūyún,OCD,Pingchowhsien,Tu-yun,Tu-yun-ch''eng,Tu-yun-hsien,Tu-yun-shih,Tu-yün,Tu-yün-ch’eng,Tu-yün-hsien,Tu-yün-shih,dou yun,Дуюн,都勻,都匀', 26.2666700, 107.5166700, 'CN', '2016-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18614, 'Zhengyang', 'Zhengyang', 'Duxun Zhen,Tu-hsun,Tu-hsün,Zhengyang,du xun zhen,zheng yang,杜浔镇,正阳', 23.9446000, 117.6020000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18615, 'Duqiao', 'Duqiao', 'Duqiao,Duqiao Zhen,Duxiaqiao,T''u-hsia-ch''iao-chen,T''u-hsia-chi''ao,T’u-hsia-chi’ao,T’u-hsia-ch’iao-chen,du qiao,du qiao zhen,杜桥,杜桥镇', 28.7687600, 121.4917400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18616, 'Duwei', 'Duwei', 'Duwei,Duwei Zhen,Tu-wei,du wei,du wei zhen,度尾,度尾镇', 25.4163400, 118.5766400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18617, 'Dushu', 'Dushu', 'Dushu,Dushu Zhen,Tu-shu,Tu-shu-chen,du shu,du shu zhen,独树,独树镇', 33.3254300, 113.1596900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18618, 'Dushi', 'Dushi', 'Dushi,Dushi Zhen,Tu-shih-ch''ang,Tu-shih-ch’ang,du shi,du shi zhen,杜市,杜市镇', 29.1500200, 106.5328300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18619, 'Dushan', 'Dushan', 'Dushan,Dushan Zhen,du shan,du shan zhen,独山,独山镇', 30.0745000, 116.0400900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18620, 'Duruan', 'Duruan', 'Duruan,Duruan Zhen,Tu-juan,du ruan,du ruan zhen,杜阮,杜阮镇', 22.6055200, 113.0095000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18621, 'Duru', 'Duru', 'Duru,Duru Zhen,Tu-ju,Wu-ch''uan-hsien,Wu-ch’uan-hsien,Wuchuan,Wuchuan Gelaozu Miaozu Zizhixian,Wuchwan,Wuchwan-hsien,dou ru,dou ru zhen,wu chuan ge lao zu miao zu zi zhi xian,务川仡佬族苗族自治县,都濡,都濡镇', 28.5255000, 107.8870000, 'CN', '2014-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18622, 'Duqu', 'Duqu', 'Duqu,Duqu Zhen,Tu-ch''u,Tu-ch''u-chen,Tu-ch’ü,Tu-ch’ü-chen,du qu,杜曲', 34.1100200, 109.0016500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18623, 'Duozhu', 'Duozhu', 'Duozhu,Duozhu Zhen,San-t''o-chu,San-to,San-to-chu-hsu,San-to-chu-hsü,San-t’o-chu,To-chu,duo zhu,duo zhu zhen,多祝,多祝镇', 23.0295400, 114.9466100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18624, 'Duowen', 'Duowen', 'Duowen,Duowen Zhen,To-wen,To-wen-shih,duo wen,duo wen zhen,多文,多文镇', 19.7762300, 109.7658300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18625, 'Duodaoshi', 'Duodaoshi', 'Duodao,Duodaoshi,Duodaoshi Jiedao,To-tao,To-tao-shih,duo dao shi,duo dao shi jie dao,掇刀石,掇刀石街道', 30.9617400, 112.1847600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18626, 'Duobao', 'Duobao', 'Duobao,Duobao Zhen,Duobaowan,To-pao-wan,Topaowan,Topaowanchen,duo bao,duo bao zhen,多宝,多宝镇', 30.6700000, 112.6895200, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18627, 'Duntou', 'Duntou', 'Duntou,Duntou Zhen,dun tou,dun tou zhen,墩头,墩头镇', 32.6465800, 120.3479100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18628, 'Duntou', 'Duntou', 'Duntou,Duntou Zhen,dun tou,dun tou zhen,墩头,墩头镇', 29.3504700, 119.7539200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18629, 'Liufeng', 'Liufeng', 'Duntou,Liufeng,Liufeng Xiang,Tun-t''ou,Tun-t’ou,dun tou,liu feng,liu feng xiang,墩头,柳峰,柳峰乡', 27.3915100, 119.9944900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18630, 'Dunshang', 'Dunshang', 'Dunshang,Dunshang Zhen,Tun-shang,dun shang,dun shang zhen,墩尚,墩尚镇', 34.7087100, 119.0389900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18631, 'Dunhou', 'Dunhou', 'Dunhou,Dunhou Zhen,Ji''an,Ji''an Xian,Ji’an,Ji’an Xian,Tun-hou,dui hou,dui hou zhen,ji an xian,吉安县,敦厚,敦厚镇', 27.0500000, 114.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18632, 'Duliu', 'Duliu', 'Duliu,Duliu Zhen,Tu-liu,Tu-liu-chan,Tu-liu-chen,du liu,du liu zhen,独流,独流镇', 39.0286800, 116.9074000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18633, 'Dukou', 'Dukou', 'Dukou,Dukou Zhen,du kou,du kou zhen,渡口,渡口镇', 29.3292400, 111.9352100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18634, 'Dujing', 'Dujing', 'Dujing,Tu-ching,Tu-ching-shih,Zitong,Zitong Zhen,du jing,zi tong,zi tong zhen,杜井,梓桐,梓桐镇', 29.6014700, 118.7550000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18635, 'Dushi', 'Dushi', 'Dujiawei,Dushi,Dushi Zhen,du shi,du shi zhen,杜市,杜市镇', 28.0521600, 115.9804900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18636, 'Dujiang', 'Dujiang', 'Dujiang,Dujiang Zhen,du jiang,du jiang zhen,渡江,渡江镇', 24.8666700, 114.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18637, 'Duhu', 'Duhu', 'Duhu,Duhu Zhen,Tohuk,Tu-hu,dou hu,dou hu zhen,都斛,都斛镇', 22.0693800, 112.9414800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18638, 'Doucun', 'Doucun', 'Doucun,Ducun,Fu-p''ing-hsien,Fu-p''ing-hsien-ch''eng,Fu-p’ing-hsien,Fu-p’ing-hsien-ch’eng,Fupin,Fuping,dou cun,窦村', 34.7480900, 109.1796800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18639, 'Ducheng', 'Ducheng', 'Dosing,Ducheng,Ducheng Zhen,Tu-ch''eng,Tu-ch''eng-hsu,Tu-ch’eng,Tu-ch’eng-hsü,Yunan,dou cheng,dou cheng zhen,都城,都城镇', 23.2421200, 111.5284000, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18640, 'Duchang', 'Duchang', 'Duchang,Duchang Xian,Duchang Zhen,Tu-ch''ang,Tu-ch''ang-hsien,Tu-ch''ang-hsien-ch''eng,Tu-ch’ang,Tu-ch’ang-hsien,Tu-ch’ang-hsien-ch’eng,dou chang,dou chang xian,dou chang zhen,都昌,都昌县,都昌镇', 29.2660000, 116.1863100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18641, 'Dubu', 'Dubu', 'Dubu,Dubu Zhen,du bu,du bu zhen,杜步,杜步镇', 24.3333300, 112.6666700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18642, 'Duanlongshan', 'Duanlongshan', 'Duanlongshan,Duanlongshan Zhen,duan long shan,duan long shan zhen,断龙山,断龙山镇', 28.6832900, 109.8105400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18643, 'Duanjia', 'Duanjia', 'Duanjia,Tuan-chia,Tuan-chia-chai,duan jia,段家', 34.8725600, 109.8184400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18644, 'Duanfen', 'Duanfen', 'Duanfen,Duanfen Zhen,Tuan-fen,duan fen,duan fen zhen,端芬,端芬镇', 22.0585200, 112.7542100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18645, 'Duancun', 'Duancun', 'Duancun,Duancun Zhen,Tuan-ts''un,Tuan-ts''un-chen,Tuan-ts’un,Tuan-ts’un-chen,duan cun,duan cun zhen,段村,段村镇', 38.2590600, 116.0016700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18646, 'Duoba', 'Duoba', 'Dowa,Duoba,Duoba Zhen,To-pa,duo ba,duo ba zhen,多巴,多巴镇', 36.6579500, 101.5337400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18647, 'Qukuhu', 'Qukuhu', 'Dowa,Duowa,Qukuhu,Qukuhu Xiang,duo wa,qu ku hu,qu ku hu xiang,多哇,曲库乎,曲库乎乡', 35.4080400, 101.9621900, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18648, 'Doushan', 'Doushan', 'Doushan,Doushan Zhen,Tou-shan,Towshan,dou shan,dou shan zhen,斗山,斗山镇', 22.0634900, 112.8321900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18649, 'Doumuhu', 'Doumuhu', 'Doumuhu,Doumuhu Zhen,Tou-mu-hu,dou mu hu,dou mu hu zhen,斗姆湖,斗姆湖镇', 28.9489400, 111.6285800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18650, 'Doumen', 'Doumen', 'Doumen,Doumen Jieban,Doumenzhen,Tou-men,Tou-men-chen,dou men,dou men jie ban,斗门,斗门街办', 34.2174200, 108.7525900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18651, 'Doumen', 'Doumen', 'Baishenglou,Doumen,Doumen Zhen,Tou-men,Tou-men-chen,dou men,dou men zhen,斗门,斗门镇', 30.0976100, 120.5925000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18652, 'Doumen', 'Doumen', 'Doumen,Tou-men,dou men,斗门', 22.2341700, 113.1910000, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18653, 'Doujia', 'Doujia', 'Doujia,Doujia Zhen,Tou-chia,dou jia,dou jia zhen,窦家,窦家镇', 34.7972200, 108.3002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18654, 'Douhudi', 'Douhudi', 'Douhudi,Doushi,Gong''an,Gong’an,Kung-an,Tou-hu-ti,Tou-shih,Towhuti,Tung-ting Hao,Tungting Hsu,Tungting Tao,dou hu di,斗湖堤', 30.0605600, 112.2241700, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18655, 'Dougou', 'Dougou', 'Dougou,Dougou Xiang,dou gou,dou gou xiang,陡沟,陡沟乡', 34.2833300, 119.1166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18656, 'Dougou', 'Dougou', 'Dougou,Dougou Zhen,Tou-kou,Tou-kou-pa,dou gou,dou gou zhen,陡沟,陡沟镇', 31.3583300, 118.0139900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18657, 'Douba', 'Douba', 'Douba,dou ba,豆坝', 33.2571100, 105.4681200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18658, 'Dongzhu', 'Dongzhu', 'Dongzhu,Dongzhu Zhen,Tung-chu,Tung-chu-chen,dong zhu,dong zhu zhen,东渚,东渚镇', 31.3345100, 120.4011000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18659, 'Nanjie', 'Nanjie', 'Dongzhen Zhen,Nanjie,Tung-chen,dong zhen zhen,nan jie,东镇镇,南街', 35.4272300, 111.3084800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18660, 'Xinyi', 'Xinyi', 'Dongzhen,Hsin-i,Tung-chen,Tung-chen-chen,Tung-chen-hsu,Tung-chen-hsü,Xinyi,xin yi,信宜', 22.3730300, 110.9474600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18661, 'Dongzhaogezhuang', 'Dongzhaogezhuang', '', 39.9488900, 117.3700000, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18662, 'Dongzhao', 'Dongzhao', 'Dongzhao,Dongzhao Xiang,Tung-chao,Tung-chao-ts''un,Tung-chao-ts’un,dong zhao,dong zhao xiang,东赵,东赵乡', 37.6941700, 112.8480600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18663, 'Dongzhang', 'Dongzhang', 'Dongzhang,Dongzhang Zhen,dong zhang,dong zhang zhen,东张,东张镇', 25.7124900, 119.2459000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18664, 'Dongzhai', 'Dongzhai', 'Dongzhai,Dongzhai Zhen,Tung-chai,Tung-chai-chen,dong zhai,dong zhai zhen,东寨,东寨镇', 38.8085300, 112.0978900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18665, 'Dongzha', 'Dongzha', 'Chia-hsing,Dongzha,Dongzha Jiedao,Dongzha Xiang,Tung-cha,Tung-cha-chen,Tung-cha-k''ou-chen,Tung-cha-k’ou-chen,dong shan,dong shan jie dao,dong shan xiang,东栅,东栅乡,东栅街道', 30.7611300, 120.7859400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18666, 'Dongyueguan', 'Dongyueguan', 'Dongyueguan,Dongyueguan Zhen,Tung-yueh-kuan,Tung-yüeh-kuan,dong yue guan,dong yue guan zhen,东岳观,东岳观镇', 29.5599900, 111.0355500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18667, 'Dongyuan', 'Dongyuan', 'Dongyuan,Tung-yuan,Tung-yüan,dong yuan,东园', 24.9173800, 118.7523600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18668, 'Donglan', 'Donglan', 'Donglan,Dongyuan,Tung-lan,Tung-lan-chen,Tung-lan-hsien,Tung-lan-hsien-ch''eng,Tung-lan-hsien-ch’eng,Tunlangchow,dong lan,东兰', 24.5501800, 107.3828900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18669, 'Dongyuan', 'Dongyuan', 'Dongyuan,Dongyuan Zhen,Tung-yuan,Tung-yüan,dong yuan,dong yuan zhen,东园,东园镇', 23.5116000, 116.1303000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18670, 'Dongyou', 'Dongyou', 'Dongyou,Dongyou Zhen,Tung-yu,dong you,dong you zhen,东游,东游镇', 27.1627800, 118.6313900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18671, 'Shengli', 'Shengli', 'DOY,Dongying,Dun''in,Dungjing,Dunuin,GJong Dinh,Shengli,Shengli Jiedao,Tung-jing,Tung-ying,dong ying,dong ying shi,dung-ing si,sheng li,sheng li jie dao,Đông Dinh,Дунгјинг,Дунъин,Дуньин,东营市,東営市,東營,胜利,胜利街道,둥잉 시', 37.4627100, 118.4916500, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18672, 'Dongxing', 'Dongxing', 'Cheng-tung-yu-chen,Cheng-tung-yü-chen,Dongxing,Dongxing Zhen,Dongxingzhen,Tung-hsing-chen,Tung-hsing-wei,dong xing,dong xing zhen,东兴,东兴镇', 31.9817600, 120.1606000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18673, 'Dongxiao', 'Dongxiao', 'Dongxiao,Dongxiao Jiedao,dong xiao,dong xiao jie dao,东肖,东肖街道', 25.0285800, 117.0080000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18674, 'Dongxia', 'Dongxia', 'Dongxia,Dongxia Zhen,Tung-hsia,Tung-hsia-chen,dong xia,dong xia zhen,东夏,东夏镇', 31.1680400, 119.0898400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18675, 'Dongxi', 'Dongxi', 'Dongxi,Dongxichang,Dongxizhen,Tung-hsi-chen,dong xi,dong xi zhen,东溪,东溪镇', 32.0657700, 106.2484300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18676, 'Dongxi', 'Dongxi', 'Dongxi,Dongxi Xiang,dong xi,dong xi xiang,洞溪,洞溪乡', 29.1422500, 110.8250600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18677, 'Dongxi', 'Dongxi', 'Dongxi,Tung-hsi', 28.7613900, 106.6611100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18678, 'Dongwu', 'Dongwu', 'Dongwu,Tung-wu,dong wu,东坞', 34.7991700, 108.5286100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18679, 'Dongting', 'Dongting', 'Dongting,Dongting Jiedao,Tung-t''ing,Tung-t''ing-chen,Tung-t’ing,Tung-t’ing-chen,Xishan Qu,dong ting,dong ting jie dao,xi shan qu,东亭,东亭街道,锡山区', 31.5849300, 120.3668100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18680, 'Dongshan', 'Dongshan', 'Ch''ien-shan,Ch''ien-shan-chen,Chen-tse,Ch’ien-shan,Ch’ien-shan-chen,Dongshan,Dongshan Zhen,Dongting,Tung-shan,Tung-shan-chen,dong shan,dong shan zhen,东山,东山镇', 31.0826400, 120.4027800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18681, 'Dongting', 'Dongting', 'Dongting,Tung-hu-t''ing,Tung-hu-t’ing,Tung-t''ing,Tung-t''ing-hu,Tung-t''ing-hu-chen,Tung-t’ing,Tung-t’ing-hu,Tung-t’ing-hu-chen,dong ting,东亭', 30.8722200, 119.5196600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18682, 'Dongtang', 'Dongtang', 'Dongtang,Dongtang Zhen,dong tang,dong tang zhen,董塘,董塘镇', 25.0808000, 113.6305800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18683, 'Dongtai', 'Dongtai', 'Dongtai,Dongtai Shi,Dongtai Zhen,Tung-t''ai,Tung-t''ai-chen,Tung-t''ai-hsien,Tung-t’ai,Tung-t’ai-chen,Tung-t’ai-hsien,dong tai,dong tai shi,dong tai zhen,东台,东台市,东台镇', 32.8523100, 120.3094700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18684, 'Dongtazhuang', 'Dongtazhuang', 'Dongta,Dongtazhuang', 39.8938900, 117.3372200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18685, 'Dongshui', 'Dongshui', 'Dongshui,Dongshui Zhen,Tung-shui,Tung-shui-hsu,Tung-shui-hsü,dong shui,dong shui zhen,东水,东水镇', 24.2562400, 115.1732200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18686, 'Dongshi', 'Dongshi', 'Dongshi,Dongshi Zhen,Tung-shih,Tung-tse,dong shi,dong shi zhen,董市,董市镇', 30.4090800, 111.7037900, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18687, 'Dongshi', 'Dongshi', 'Dongshi,Dongshi Xiang,dong shi,dong shi xiang,洞市,洞市乡', 29.8091900, 111.3753800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18688, 'Dongshi', 'Dongshi', 'Dongshi,Dongshi Zhen,dong shi,dong shi zhen,东石,东石镇', 24.6786900, 115.9479700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18689, 'Dongshi', 'Dongshi', 'Dongshi,Dongshi Zhen,Tangchioh,Tung-shih,dong shi,dong shi zhen,东石,东石镇', 24.6651300, 118.4561600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18690, 'Dongsheng', 'Dongsheng', 'DSN,Dongsheng,Dongsheng Qu,Dunshen,Tung-sheng,Tung-sheng-hsien,dong sheng,dong sheng qu,东胜,东胜区', 39.8160900, 109.9776300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18691, 'Dongshe', 'Dongshe', 'Dongshe,Dongshe Zhen,Tung-she,Tung-she-chen,dong she,dong she zhen,东社,东社镇', 32.0967800, 121.1811400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18692, 'Dongshanba', 'Dongshanba', 'Dongshanba,Dongshanba Zhen,dong shan ba,dong shan ba zhen,东山坝,东山坝镇', 26.7405700, 116.0604600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18693, 'Dongshan', 'Dongshan', 'Chiang-ning,Chiang-ning-hsien,Chiu-t''u-shan-chen,Chiu-t’u-shan-chen,Dongshan,Dongshan Jiedao,Jiangning Qu,Kiangning-hsien,T''u-shan-chen,Tung-shan,Tung-shan-chen,T’u-shan-chen,dong shan,dong shan jie dao,jiang ning qu,东山,东山街道,江宁区', 31.9556800, 118.8326900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18694, 'Dongshan Dongzuxiang', 'Dongshan Dongzuxiang', 'Dongshan,Dongshan Dongzuxiang,Dunshan'',Dunshan’,Tung-shan', 26.5950000, 109.8966700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18695, 'Dongshan', 'Dongshan', 'Dongshan,Shang-yu,Shang-yu-chiang,Shang-yu-hsien,Shangyiu,Shangyiu-hsien,Shangyou,Shangyou Xian,Shanyu,dong shan,shang you xian,上犹县,东山', 25.7938900, 114.5425600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18696, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Zhen,Lei-tung,Tung-shan,dong shan,dong shan zhen,东山,东山镇', 21.0350600, 110.3923600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18697, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Zhen,dong shan,dong shan zhen,东山,东山镇', 19.7515000, 110.2325200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18698, 'Dongsha', 'Dongsha', 'Dongsha,Dongsha Zhen,Dongshajiao,Tung-sha-chiao,dong sha,dong sha zhen,东沙,东沙镇', 30.3141700, 122.1412300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18699, 'Dongqiao', 'Dongqiao', 'Dongqiao,Dongqiao Zhen,Tung-ch''iao,Tung-ch’iao,dong qiao,dong qiao zhen,东桥,东桥镇', 31.1932200, 112.8311800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18700, 'Dongqiao', 'Dongqiao', 'Dongqiao,Dongqiao Zhen,dong qiao,dong qiao zhen,东桥,东桥镇', 26.3709200, 118.8905800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18701, 'Dongpu', 'Dongpu', 'Dongpu,Dongpu Zhen,Tung-p''u,Tung-p''u-shih,Tung-p’u,Tung-p’u-shih,dong pu,dong pu zhen,东浦,东浦镇', 30.0558300, 120.5313300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18702, 'Dongping', 'Dongping', 'An-hua-hsien,Anhua,Anhua Xian,Dongping,Tung-p''ing,Tung-p''ing-chen,Tung-p’ing,Tung-p’ing-chen,an hua xian,dong ping,东坪,安化县', 28.3801700, 111.2058600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18703, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,Tung-p''ing,Tung-p’ing,dong ping,dong ping zhen,东平,东平镇', 27.4286100, 118.6383300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18704, 'Dongping', 'Dongping', 'Dongping,Dongping Xiang,dong ping,dong ping xiang,东坪,东坪乡', 27.3098200, 116.6827900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18705, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,Tung-p''ing,Tung-p’ing,dong ping,dong ping zhen,东平,东平镇', 21.7392600, 112.2171800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18706, 'Dongnigu', 'Dongnigu', 'Dongnigu,Tung-ni-chan,Tung-ni-ku,dong ni gu,东泥沽', 39.0165500, 117.4439600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18707, 'Dongming Chengguanzhen', 'Dongming Chengguanzhen', 'Dongming,Dongming Chengguanzhen,Dunlin,Tung-ming,Tung-ming-hsien,dong ming,dong ming cheng guan zhen,东明,东明城关镇', 35.2914500, 115.0901900, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18708, 'Dongmen', 'Dongmen', 'Dongmen,Lo-ch''eng,Lo-ch''eng-hsien,Lo-ch’eng,Lo-ch’eng-hsien,Loshing-hsien,dong men,东门', 24.7919800, 108.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18709, 'Dongmafang', 'Dongmafang', 'Dongmafang,Dongmafang Xiang,Tung-ma-fang,dong ma fang,dong ma fang xiang,东马坊,东马坊乡', 38.6808500, 112.3240700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18710, 'Lianhua', 'Lianhua', 'Donglong,Lianhua,Lianhua Zhen,Tang-leng,Tung-lung,lian hua,莲华', 23.5759400, 116.8006000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18711, 'Dongli', 'Dongli', 'Dongli,Dongli Zhen,dong li,dong li zhen,东里,东里镇', 23.5613400, 116.8124900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18712, 'Dongliu', 'Dongliu', 'Dongliu,Dongliu Xiang,dong liu,dong liu xiang,东留,东留乡', 25.1440200, 115.9890700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18713, 'Dongling', 'Dongling', 'Dongling,Donlin,dong ling,Донлин,东岭', 24.9827100, 118.8979000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18714, 'Dongli', 'Dongli', 'Dongli,Dongli Zhen,Tung-li,dong li,dong li zhen,东里,东里镇', 20.7920100, 110.3611000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18715, 'Dongle', 'Dongle', 'Dongle,Dongle Xiang,Tung-le,dong le,dong le xiang,东乐,东乐乡', 38.8272200, 100.7980600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18716, 'Dongkou', 'Dongkou', 'Dongkou,Dunkou,Tung-k''ou,Tung-k''ou-chen,Tung-k’ou,Tung-k’ou-chen,Tungkow,dong kou,洞口', 27.0527200, 110.5361000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18717, 'Dongkengkou', 'Dongkengkou', 'Dongkengkou,Tung-k''eng-k''ou,Tung-k’eng-k’ou,Yanglin,Yanglin Zhen,dong keng kou,yang lin,yang lin zhen,东坑口,杨林,杨林镇', 29.0563500, 118.1431800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18718, 'Dongkeng', 'Dongkeng', 'Dongkeng,Dongkeng Zhen,Tung-k''eng,Tung-k’eng,dong keng,dong keng zhen,东坑,东坑镇', 27.7961100, 119.7108300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18719, 'Dongkan', 'Dongkan', 'Binhai,Dongkan,Pin-hai,Tung-k''an,Tung-k''an-chen,Tung-k’an,Tung-k’an-chen', 33.9997200, 119.8308300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18720, 'Dongjituo', 'Dongjituo', 'Dongjituo,Tung-chi-t''o,Tung-chi-t’o,Tungchituo', 39.4219400, 117.5741700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18721, 'Dongjin', 'Dongjin', 'Dongjin,Dongjin Zhen,Dongjinwan,Tung-chin-wan,Tung-ching-wan,dong jin,dong jin zhen,东津,东津镇', 32.0252600, 112.2249600, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18722, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Zhen,dong jiao,dong jiao zhen,东郊,东郊镇', 19.5769600, 110.8562000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18723, 'Dongjian', 'Dongjian', 'Dongjian,Dongjian Zhen,dong jian,dong jian zhen,东简,东简镇', 21.0365800, 110.4954200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18724, 'Dongjia', 'Dongjia', 'Dongjia,Dongjia Zhen,Tung-chia,dong jia,dong jia zhen,董家,董家镇', 28.2744700, 115.5104400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18725, 'Donghuishe', 'Donghuishe', 'Donghuishe,Donghuishe Zhen,Hui-she,Hui-she-chen,dong hui she,dong hui she zhen,东回舍,东回舍镇', 38.2532600, 114.0887100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18726, 'Donghuang', 'Donghuang', 'Donghuang,Hsi-shui,Tung-huang-ch''ang,Tung-huang-chen,Tung-huang-ch’ang,Tung-huang-tien,Xishui,Xishui Xian,dong huang,xi shui xian,东皇,习水县', 28.3329700, 106.2155700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18727, 'Donghua', 'Donghua', 'Donghua,Huating,Huating Xian,Hwatinghsien,Khuatin,dong hua,hua ting xian,东华,华亭县', 35.2152000, 106.6530000, 'CN', '2015-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18728, 'Donghu', 'Donghu', 'Donghu,Donghu Xiang,Tung-hu,Tung-hu-ts''un,Tung-hu-ts’un,dong hu,dong hu xiang,东湖,东湖乡', 39.0938700, 112.1129200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18729, 'Donghu', 'Donghu', 'Chengdongxiang,Donghu,Donghuzhen,cheng dong xiang,dong hu,dong hu zhen,东湖,东湖镇,城东乡', 30.0257200, 120.6079900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18730, 'Xian’an', 'Xian''an', 'Donghong,Xian''an,Xian''an Zhen,Xian’an,Xian’an Zhen,xian an,xian an zhen,仙庵,仙庵镇', 23.0748700, 116.5166000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18731, 'Donghenan', 'Donghenan', 'Donghenan,Donghenan Zhen,Ho-nan,Ho-nan-chen,Tung-ho-nan,Tung-ho-nan-chen,dong he nan,dong he nan zhen,东河南,东河南镇', 39.3819400, 114.0441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18732, 'Donghai', 'Donghai', 'Donghai,Donghai Jiedao,Lu-feng-hsien,Lu-feng-hsien-ch''eng,Lu-feng-hsien-ch’eng,Lufeng,Lufung,Lukfung,dong hai,lu feng,东海,陆丰', 22.9459300, 115.6420400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18733, 'Dongguan', 'Dongguan', 'Dongguan,Dongguan Jiedao,Dongguan Zhen,Tung-kuan,Tung-kuan-chen,dong guan,dong guan jie dao,dong guan zhen,东关,东关街道,东关镇', 30.0116600, 120.8140700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18734, 'Dongguang', 'Dongguang', 'Dongguang,Dunguan,Tung-kuang,Tung-kuang-ch''eng-kuan,Tung-kuang-ch’eng-kuan,Tung-kuang-hsien,Tungkwang,Tungkwanghsien,dong guang,东光', 37.8850900, 116.5328300, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18735, 'Dongguan', 'Dongguan', 'Baode,Baode Xian,Dongguan,Dongguan Zhen,Pao-te,Pao-te-hsien,Pao-teh,Paotehchow,bao de xian,dong guan,dong guan zhen,东关,东关镇,保德县', 39.0173200, 111.1267400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18736, 'Dongguan', 'Dongguan', 'Dongguan,Dongguan Zhen,Tung-kuan,dong guan,dong guan zhen,东馆,东馆镇', 27.8272000, 116.4603200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18737, 'Dongguan', 'Dongguan', 'Deng-uang,Dongguan,Dongguan City,Dongwen shehiri,Dunguan,Dunguan'',Dĕ̤ng-uāng,GJong Hoan,Ntonkouan,Tong-koan-chhi,Tong-kóan-chhī,Tung-kon-su,Tung-kuan,Tungkuan,Tungkun,Tûng-kón-sṳ,XHO,dong guan,dong guan shi,dong wan shi,donggu''ana,dung-gwan si,dwnghqwan,dwngwan,tonkuvan,Đông Hoản,Ντογκουάν,Донггуан,Дунгуан,Дунгуань,Дунґуань,דונגגוואן,دونغقوان,دونگوان,ڈwngwan,ڈونگ گوآن,ڈونگوان,डोंग्गूआन,டொங்குவான்,东莞,东莞市,東莞,東莞市,둥관 시', 23.0179700, 113.7486600, 'CN', '2017-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18738, 'Donggu', 'Donggu', 'Donggu,Donggu Zhen,Gonglue,Gonglüe,Tung-ku,Tung-yin,dong gu,dong gu zhen,东固,东固镇', 26.7250100, 115.3910400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18739, 'Donggou', 'Donggou', 'Donggou,Donggou Zhen,Tung-kou,Tung-kou-chen,dong gou,dong gou zhen,东沟,东沟镇', 32.2719400, 118.9895500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18740, 'Donggong', 'Donggong', 'Donggong,Donggong Zhen,Tung-kung,dong gong,dong gong zhen,东巩,东巩镇', 31.3258000, 111.8314700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18741, 'Donggang', 'Donggang', 'Donggang,Donggang Xiang,dong gang,dong gang xiang,东港,东港乡', 28.9365200, 114.2259300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18742, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Zhen,Tung-feng,Tung-feng-t''ang,Tung-feng-t''un,Tung-feng-t’ang,Tung-feng-t’un,dong feng,dong feng zhen,东峰,东峰镇', 27.1023300, 118.4956800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18743, 'Dong’erying', 'Dong''erying', '', 39.9575000, 117.2791700, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18744, 'Dongdu', 'Dongdu', 'Dongdu,Tung-tu', 35.8500000, 117.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18745, 'Dongditou', 'Dongditou', 'Dongditou,dong di tou,东堤头', 39.2664100, 117.3727300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18746, 'Dongdai', 'Dongdai', 'Dongdai,Dongdai Zhen,Tung-tai,dong dai,dong dai zhen,东岱,东岱镇', 26.2436600, 119.6156600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18747, 'Dongcun', 'Dongcun', 'Dongcun,Dongcun Zhen,Lan Xian,Lan-hsien,Lanxian,Tung-ts''un,Tung-ts''un-chen,Tung-ts’un,Tung-ts’un-chen,dong cun,dong cun zhen,lan xian,东村,东村镇,岚县', 38.2944200, 111.7035200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18748, 'Dongcun', 'Dongcun', 'Dongcun,Haiyang,Tung-ts''un,Tung-ts''un-chi,Tung-ts’un,Tung-ts’un-chi', 36.7766700, 121.1597200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18749, 'Dongcun', 'Dongcun', 'Dongcun,Dongcun Xiang,dong cun,dong cun xiang,东村,东村乡', 26.3631000, 115.5522800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18750, 'Dongchuan', 'Dongchuan', 'Dongchuan,Dongchuan Zhen,dong chuan,dong chuan zhen,东川,东川镇', 37.3679700, 101.8356500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18751, 'Dongchuan', 'Dongchuan', 'Chien-ch''uan-chen,Chien-ch’uan-chen,Dongchuan,Yao''an,Yao-chou,Yaochow,Yao’an,dong chuan,栋川', 25.4765500, 101.2846800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18752, 'Dongchong', 'Dongchong', 'Dongchong,Tangchung,Tung-ch''ung,Tung-ch''ung-k''ou,Tung-ch’ung,Tung-ch’ung-k’ou,dong chong,东冲', 26.5400100, 119.8325700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18753, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Zhen,Tung-ch''eng,Tung-ch''eng-chen,Tung-ch’eng,Tung-ch’eng-chen,dong cheng,dong cheng zhen,东塍,东塍镇', 28.9291500, 121.2703000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18754, 'Dongchen', 'Dongchen', 'Dongchen,Dongchen Zhen,Tung-ch''en,Tung-ch''en-chen,Tung-ch’en,Tung-ch’en-chen,dong chen,dong chen zhen,东陈,东陈镇', 32.4015500, 120.6404800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18755, 'Dongbeitang', 'Dongbeitang', 'Dongbeitang,Dongbeitang Zhen,Tung-pei-t''ang,Tung-pei-t’ang,dong bei tang,dong bei tang zhen,东北塘,东北塘镇', 31.6335100, 120.3537100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18756, 'Dongbei', 'Dongbei', 'Dongbei,Dongbei Zhen,Tung-p''o,Tung-pei,Tung-p’o,dong bei,dong bei zhen,东陂,东陂镇', 27.2096900, 116.1311800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18757, 'Dongbei', 'Dongbei', 'Dongbei,Dongbei Zhen,Tung-p''o,Tung-p''o-hsu,Tung-p''u,Tung-pei,Tung-pei-hsu,Tung-pei-hsü,Tung-p’o,Tung-p’o-hsü,Tung-p’u,dong bei,dong bei zhen,东陂,东陂镇', 24.9916700, 112.2958300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18758, 'Dongbang', 'Dongbang', 'Dongbang,Dongbang Zhen,Tung-pang-shih,Tung-peng-shih,dong bang,dong bang zhen,董浜,董浜镇', 31.6483700, 120.9260700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18759, 'Dongba', 'Dongba', 'Dongba,Dongba Xiang,Tung-pa,Tung-pa-chen,dong ba,dong ba xiang,东坝,东坝乡', 39.9625000, 116.5527500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18760, 'Dongba', 'Dongba', 'Dongba,Dongba Zhen,Tung-pa,Tung-pa-chen,dong ba,dong ba zhen,东坝,东坝镇', 31.2976800, 119.0536500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18761, 'Dong’ao', 'Dong''ao', 'Dong''ao,Dong''ao Zhen,Dong’ao,Dong’ao Zhen,dong ao,dong ao zhen,东澳,东澳镇', 18.7155400, 110.3955500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18762, 'Dong’an', 'Dong''an', 'Dong''an,Dong''an Zhen,Dong’an,Dong’an Zhen,dong an,dong an zhen,东岸,东岸镇', 22.1297700, 110.9510400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18763, 'Dogarmo', 'Dogarmo', 'Dogarmo,Duohemao,Duohemao Xiang,duo he mao,duo he mao xiang,多禾茂,多禾茂乡', 35.0666100, 101.8125600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18764, 'Dizhang', 'Dizhang', 'Chang-ti,Chang-ti-wan,Dizhang,Dizhang Zhen,Ti-chang,Ti-chang-wan,di zhang,di zhang zhen,底张,底张镇', 34.4263900, 108.7736100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18765, 'Dizhai', 'Dizhai', 'Dizhai,Dizhai Zhen,Ti-chai,Ti-chai-chen,di zhai,狄寨', 34.2103000, 109.1150700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18766, 'Dingzhou', 'Dingzhou', 'Dingxian,Dingzhou,Dinsyan,T''ang-hsien,Ting,Ting-hsien,Ting-hsien-ch''eng-kuan,Ting-hsien-ch’eng-kuan,Tingchow,T’ang-hsien', 38.5130600, 114.9955600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18767, 'Dingzhai', 'Dingzhai', 'Dingzhai,Dingzhai Xiang,Ting-chai,ding zhai,ding zhai xiang,丁寨,丁寨乡', 29.6000000, 109.0500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18768, 'Dingying', 'Dingying', 'Dingying,Ting-ying,ding ying,丁营', 33.7545600, 113.6031100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18769, 'Dingyan', 'Dingyan', 'Dingyan,Dingyan Zhen,Ting-yen,Ting-yen-chen,ding yan,ding yan zhen,丁堰,丁堰镇', 32.3635700, 120.7100300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18770, 'Dingyan', 'Dingyan', 'Dingyan,Dingyan Zhen,ding yan,ding yan zhen,丁堰,丁堰镇', 31.7455900, 120.0112000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18771, 'Jinchang', 'Jinchang', 'Dingxiang,Dingxiang Xian,Dinsyan'',Dinsyan’,Jinchang,Jinchang Zhen,Ting-hsiang,Ting-hsiang-hsien,Ting-hsiang-hsien-ch''eng,Ting-hsiang-hsien-ch’eng,Tingsiang,ding xiang xian,jin chang,jin chang zhen,定襄县,晋昌,晋昌镇', 38.4980800, 112.9236000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18772, 'Dingxi', 'Dingxi', 'An''din,An-ting,An’din,Dingxi,Dingxi Shi,Dinsi,Ting-an,Ting-hsi,Ting-hsi-hsien,ding xi,ding xi shi,定西,定西市', 35.5708800, 104.6230300, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18773, 'Dingtao', 'Dingtao', 'Dingtao,Ting-t''ao,Ting-t''ao-hsien,Ting-t’ao,Ting-t’ao-hsien,ding tao,定陶', 35.0743600, 115.5658200, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18774, 'Dingtang', 'Dingtang', 'Dingtang,Dingtang Zhen,Ting-shan,Ting-t''ang,Ting-t’ang,ding tang,ding tang zhen,定塘,定塘镇', 29.2303300, 121.8421700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18775, 'Dingshu', 'Dingshu', 'Dingshu,Dingshu Zhen,Shu-shan,Shu-shan-chen,Su-shan,Ting-shan,Ting-shan-chen,Ting-shu-chen,ding shu,ding shu zhen,丁蜀,丁蜀镇', 31.2573000, 119.8488100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18776, 'Dingshi', 'Dingshi', 'Dingshi,Dingshi Zhen,ding shi,ding shi zhen,丁市,丁市镇', 28.7754900, 108.5464600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18777, 'Dingqiao', 'Dingqiao', 'Dingqiao,Dingqiao Zhen,Ting-ch''iao,Ting-ch''iao-chen,Ting-ch’iao,Ting-ch’iao-chen,ding qiao,ding qiao zhen,丁桥,丁桥镇', 30.4231000, 120.6391300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18778, 'Dingping', 'Dingping', 'Dingping,Lin''shuy,Lin-shui-hsien,Ling-shui,Linshui,Lin’shuy,ding ping,鼎屏', 30.3386200, 106.9270000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18779, 'Dingjiayao', 'Dingjiayao', 'Dingjiayao,Dingjiayao Xiang,Ting-chia-yao,ding jia yao,ding jia yao xiang,丁家窑,丁家窑乡', 39.9933400, 112.2096200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18780, 'Dingjiang', 'Dingjiang', 'Dingjiang,Dingjiang Zhen,Ting-chiang,ding jiang,ding jiang zhen,丁江,丁江镇', 27.1696500, 115.3016700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18781, 'Dingjia', 'Dingjia', 'Dingjia,Dingjia Zhen,Dingjia''ao,Dingjia’ao,Ting-chia,ding jia,ding jia zhen,丁家,丁家镇', 29.4090000, 106.1422800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18782, 'Dinghai', 'Dinghai', 'Dinghai,Ting-tiai,ding hai,定海', 26.2802200, 119.7896400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18783, 'Dinggou', 'Dinggou', 'Dinggou,Dinggou Zhen,Ting-kou,Ting-kou-chen,ding gou,ding gou zhen,丁沟,丁沟镇', 32.5642300, 119.6625500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18784, 'Dingcheng', 'Dingcheng', 'Dingcheng,Dingyuan,Ting-ch''eng-chen,Ting-ch’eng-chen,Ting-yuan,Ting-yuan-hsien,Ting-yüan,Ting-yüan-hsien,Yuan-t''ing,Yüan-t’ing,ding cheng,定城', 32.5160900, 117.6595200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18785, 'Dingbu', 'Dingbu', 'Dingbu,Dingbu Zhen,Ting-fou,Ting-fou-chen,Ting-pu,ding bu,ding bu zhen,定埠,定埠镇', 31.2936200, 119.1610100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18786, 'Dingbian', 'Dingbian', 'Dingbian,Dingbian Xian,Dingbyan'',Dingbyan’,Ting-pien,Ting-pien-hsien,ding bian,ding bian xian,定边,定边县', 37.5926600, 107.5942800, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18787, 'Dingcheng', 'Dingcheng', 'Ding''an,Ding''an Xian,Dingcheng,Dingcheng Zhen,Ding’an,Ding’an Xian,Hsien-kou-shih,Ting-an,Ting-an-chen,Ting-an-hsien,Ting-ch''eng,Ting-ch’eng,Xiangou,ding an xian,ding cheng,ding cheng zhen,xian gou,仙沟,定城,定城镇,定安县', 19.6791400, 110.3623100, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18788, 'Dimda', 'Dimda', 'Dengta,Dengta Xiang,Dimda,Qingmuda,deng ta,deng ta xiang,qing mu da,灯塔,灯塔乡,青木达', 32.6874900, 100.9336400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18789, 'Dikou', 'Dikou', 'Dikou,Dikou Zhen,Ti-k''ou,Ti-k’ou,di kou,di kou zhen,迪口,迪口镇', 26.7500200, 118.4650100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18790, 'Digang', 'Digang', 'Digang,Digang Zhen,Teih Kiang,Ti Kiang,Ti-chiang,Ti-chiang-chen,Ti-kang,Tikangchen,di gang,di gang zhen,荻港,荻港镇', 31.1287100, 118.0057900, 'CN', '2014-11-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18791, 'Dietaisi', 'Dietaisi', 'Dietaisi,Dietaisi Xiang,Tieh-t''ai-ssu,Tieh-t’ai-ssu,die tai si,die tai si xiang,迭台寺,迭台寺乡', 38.8057600, 112.2033200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18792, 'Diduo', 'Diduo', 'Diduo,Diduo Zhen,Ti-to,Ti-to-chen,di duo,di duo zhen,荻垛,荻垛镇', 32.8560100, 120.0774600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18793, 'Didou', 'Didou', 'Didou,Didou Zhen,Ti-tou,de dou,de dou zhen,地豆,地豆镇', 23.5648700, 112.7057200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18794, 'Didian', 'Didian', 'Didian,Ti-tien,di dian,底店', 34.9848800, 109.2180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18795, 'Didian', 'Didian', 'Didian,Ti-tien,di dian,底店', 34.9271600, 107.9535500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18796, 'Diaoyumiao', 'Diaoyumiao', 'Diaoyu,Diaoyu Zhen,Diaoyumiao,diao yu,diao yu miao,diao yu zhen,钓鱼,钓鱼庙,钓鱼镇', 33.0859500, 119.9734300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18797, 'Diaopu', 'Diaopu', 'Diaopu,Diaopu Jiedao,Tiao-chia-p''u,Tiao-chia-p’u,Tiao-p''u,Tiao-p’u,diao pu,diao pu jie dao,刁铺,刁铺街道', 32.3472400, 119.8757100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18798, 'Diaojingyan', 'Diaojingyan', 'Diaojing,Diaojing Xiang,Diaojingyan,diao jing,diao jing xiang,diao jing yan,吊井,吊井乡,吊井岩', 29.0670900, 109.9281700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18799, 'Diaofeng', 'Diaofeng', 'Diaofeng,Diaofeng Xiang,diao feng,diao feng xiang,钓峰,钓峰乡', 26.7233300, 115.9267500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18800, 'Dianzhong', 'Dianzhong', 'Dianzhong,Dianzhong Zhen,Tien-chung,dian zhong,dian zhong zhen,甸中,甸中镇', 24.4050000, 102.2247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18801, 'Dianya', 'Dianya', 'Dianya,Dianya Zhen,Tien-ya,dian ya,dian ya zhen,店垭,店垭镇', 31.3987500, 111.3336700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18802, 'Dianweijie', 'Dianweijie', 'Dianwei,Dianweijie,Tien-wei,Zhuanlong,Zhuanlong Zhen,dian wei jie,zhuan long,zhuan long zhen,甸尾街,转龙,转龙镇', 25.9075000, 102.8544400, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18803, 'Dianfang', 'Dianfang', 'Dianfang,Dianfang Xiang,dian fang,dian fang xiang,靛房,靛房乡', 28.9767200, 109.5687000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18804, 'Diancheng', 'Diancheng', 'Chiu-tien-pai,Diancheng,Diancheng Zhen,Tien-ch''eng,Tien-ch’eng,Tien-pai,Tien-pai-hsien,Tienpak,Tinpak,Tinpakhsien,dian cheng,dian cheng zhen,电城,电城镇', 21.5166700, 111.3000000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18805, 'Dianbu', 'Dianbu', 'Dianbu,Fei-tung,Feidong,Feidong Xian,Tien-fou,Tien-fou-chen,Tien-pu,Tienfow,dian bu,fei dong xian,店埠,肥东县', 31.8730800, 117.4580300, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18806, 'Dezhou', 'Dezhou', 'Daik-ciu,Dedzou,Degou,Dehchzhou,Detsjou,Dezhou,Deĝoŭ,Dáik-ciŭ,GJuc Chau,Te,Te-chou,Te-chou-shih,Te-cou,Te-hsien,Te-čou,Techow,Teh-hsien,Tehchow,Tehetsouen,Tek-chiu-chhi,Tek-chiu-chhī,de zhou,de zhou shi,deojeou si,dyzhww,dzhw,Đức Châu,Деџоу,Дэчжоу,دژو,دیژوو,徳州市,德州,德州市,더저우 시', 37.4512700, 116.3104600, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18807, 'Dezhou', 'Dezhou', 'Dechang,Dezhou,Te-ch''ang,Te-ch''ang-hsien,Te-ch’ang,Te-ch’ang-hsien,Tehchang,de zhou,德州', 27.4080900, 102.1800100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18808, 'Deyang', 'Deyang', 'DEY,Daik-iong,Dehjan,Deyan,Deyang,Dáik-iòng,GJuc Duong,Te-jang,Te-yang,Te-yang-hsien,Tehyang,Tehyang-hsien,Tek-iong-chhi,Tek-iông-chhī,de yang,de yang shi,deoyang si,dyyang,Đức Dương,Дэян,Դեյան,دییانگ,徳陽市,德阳市,德陽,더양 시', 31.1301900, 104.3819800, 'CN', '2015-08-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18809, 'Deshan', 'Deshan', 'Dejiao,Deshan,Deshan Zhen,Te-shan,de shan,de shan zhen,德山,德山镇', 28.9282800, 111.7123900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18810, 'Dêrnang', 'Dernang', 'De''ang,De''ang Xiang,Dernang,De’ang,De’ang Xiang,Dêrnang,Qulazhi,de ang,de ang xiang,qu la zhi,德昂,德昂乡,曲拉直', 33.4333300, 100.1666700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18811, 'Deqing', 'Deqing', 'Deqing,Deqing Xian,Te-ch''ing,Te-ch''ing-hsien,Te-ch''ing-hsien-ch''eng,Te-ch’ing,Te-ch’ing-hsien,Te-ch’ing-hsien-ch’eng,Tehtsing,de qing,de qing xian,德清,德清县', 30.5448500, 119.9599000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18812, 'Decheng', 'Decheng', 'Ch''ing-ch''eng,Ch’ing-ch’eng,Decheng,Decheng Jiedao,Deqing,Tak Hing,Takhing,Taking,Te-ch''ing,Te-ch''ing-chen,Te-ch''ing-hsien,Te-ch’ing,Te-ch’ing-chen,Te-ch’ing-hsien,Te-feng,de cheng,de cheng jie dao,德城,德城街道', 23.1426300, 111.7773700, 'CN', '2015-11-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18813, 'Dengzhuang', 'Dengzhuang', 'Dengzhuang,Dengzhuang Zhen,Teng-chuang,Teng-chuang-chen,deng zhuang,deng zhuang zhen,邓庄,邓庄镇', 35.9644600, 111.5224600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18814, 'Dengzhou', 'Dengzhou', 'Dengzhou,Dengzhou Jiedao,P''eng-lai-hsien,Pehnlaj,Penglai,Penglai Shi,P’eng-lai-hsien,Teng-Chow-Fu,Teng-chou,Tengchow,Tengchowfu,deng zhou,deng zhou jie dao,peng lai,peng lai shi,Пэнлай,登州,登州街道,蓬莱,蓬莱市', 37.8082200, 120.7590800, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18815, 'Huazhou', 'Huazhou', 'Dengxian,Dengzhou,Huazhou,Teng,Teng-hsien,hua zhou,花洲', 32.6822200, 112.0819400, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18816, 'Dengta', 'Dengta', 'Dengta,Dengta Zhen,Teng-t''a,Teng-t''a-hsu,Teng-t’a,Teng-t’a-hsü,deng ta,deng ta zhen,灯塔,灯塔镇', 24.0109400, 114.7872000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18817, 'Dengmingsi', 'Dengmingsi', 'Dengmingsi,Dengmingsi Zhen,Teng-ming-ssu,deng ming si,deng ming si zhen,灯明寺,灯明寺镇', 37.9011100, 116.7411100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18818, 'Dengjiapu', 'Dengjiapu', 'Dengjiapu,Teng-chia-p''u,Teng-chia-p’u', 26.9044400, 110.9200000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18819, 'Songyang', 'Songyang', 'Dengfeng,Songyang,Teng-feng,Teng-feng-hsien,song yang,嵩阳', 34.4552800, 113.0280600, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18820, 'Dehenglong', 'Dehenglong', 'Dehenglong,Dehenglong Xiang,de heng long,de heng long xiang,德恒隆,德恒隆乡', 35.9747200, 102.1439500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18821, 'Degan', 'Degan', 'Degan,Degan Jiedao,Deganba,Te-kan-pa,de gan,de gan jie dao,德感,德感街道', 29.2784600, 106.2315700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18822, 'Debao Chengguanzhen', 'Debao Chengguanzhen', 'Chenan,Chenanfu,Debao,Debao Chengguanzhen,T''ien-pao,T''ien-pao-hsien,T''ien-pao-hsien-ch''eng,Te-pao,T’ien-pao,T’ien-pao-hsien,T’ien-pao-hsien-ch’eng,de bao cheng guan zhen,德保城关镇', 23.3847100, 106.5735200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18823, 'Dazuo', 'Dazuo', 'Dazuo,Ta-tso,da zuo,大岞', 24.8861600, 118.9643300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18824, 'Dazhou', 'Dazhou', 'Dazhou,Dazhou Zhen,da zhou,da zhou zhen,大周,大周镇', 30.8788700, 108.4984100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18825, 'Dazhongzhuang', 'Dazhongzhuang', 'Dazhongzhuang,Ta-chung-chuang', 39.6808300, 117.5641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18826, 'Dazhong', 'Dazhong', 'Dafeng,Dazhong,Dazhong Zhen,Dazhongji,Ta-chung-chen,Ta-chung-chi,Ta-feng,da zhong,da zhong zhen,大中,大中镇', 33.1997300, 120.4578000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18827, 'Dazhipo', 'Dazhipo', 'Dazhipo,Dazhipo Zhen,Ta-chih-p''o,Ta-chih-p''o-shih,Ta-chih-p’o,Ta-chih-p’o-shih,da zhi po,da zhi po zhen,大致坡,大致坡镇', 19.8031600, 110.6819100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18828, 'Dazhe', 'Dazhe', 'Dazhe,Dazhe Zhen,P''ing-ch''eng-chen,Pingyuan,Pingyuan Xian,P’ing-ch’eng-chen,Ta-che,Ta-che-hsu,Ta-che-hsü,Ta-chih-chen,da zhe,da zhe zhen,ping yuan,ping yuan xian,大柘,大柘镇,平远,平远县', 24.5755600, 115.8918400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18829, 'Dazhangzhuang', 'Dazhangzhuang', 'Dazhangzhuang,Dazhangzhuang Zhen,Ta-chang-chuang,da zhang zhuang,da zhang zhuang zhen,大张庄,大张庄镇', 39.2859400, 117.2257600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18830, 'Dazhan', 'Dazhan', 'Dazhan,Dazhan Zhen,da zhan,da zhan zhen,大站,大站镇', 24.1519900, 113.3980100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18831, 'Daze', 'Daze', 'Daze,Ta-tse,da ze,大泽', 22.5202900, 112.9336100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18832, 'Dayukou', 'Dayukou', 'Dayukou,Dayukou Zhen,da yu kou,da yu kou zhen,大玉口,大玉口镇', 23.6849100, 111.7357200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18833, 'Dayuan', 'Dayuan', 'Dayuan,Dayuan Zhen,T''ai-yuan-chen,Ta-yuan,Ta-yuan-chen,Ta-yüan,Ta-yüan-chen,T’ai-yüan-chen,da yuan,da yuan zhen,大源,大源镇', 30.0061100, 119.9955600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18834, 'Dayuan', 'Dayuan', 'Dayuan,Dayuan Zhen,Ta-yuan,Ta-yüan,Zhangyuan,da yuan,da yuan zhen,大源,大源镇', 28.6103500, 120.3189200, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18835, 'Dayuan', 'Dayuan', 'Dayuan,Dayuan Xiang,da yuan,da yuan xiang,大源,大源乡', 26.9402000, 117.3737200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18836, 'Dayuan', 'Dayuan', 'Dayuan,Dayuan Zhen,da yuan,da yuan zhen,大源,大源镇', 25.2744400, 113.2866700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18837, 'Dayou', 'Dayou', 'Dayou,Dayou Zhen,Dayu,Li Yu,Li Yü,Ta-yu,da you,da you zhen,大有,大有镇', 34.2205600, 119.8811100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18838, 'Dayou', 'Dayou', 'Dayou,Dayou Zhen,da you,da you zhen,大有,大有镇', 28.9895000, 107.3300600, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18839, 'Dayou', 'Dayou', 'Dayou,Dayou Xiang,Ta-yu,Ta-yu-p''ing,Ta-yu-p’ing,da you,da you xiang,大由,大由乡', 26.1450400, 116.1820500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18840, 'Zhangjiajie', 'Zhangjiajie', 'Cang-tia-tie,Chong-ka-kie-su,Chzhanczjacze,Chông-kâ-kie-sṳ,DYG,Dayong,Diong-ga-gai,Diŏng-gă-gái,Ta-yung,Ta-yung-hsien,Tiuⁿ-ka-kè-chhī,Truong Gia Gioi,Trương Gia Giới,Yongding,Yongding Qu,Yung-ting,Yung-ting-chen,Zhangjiajie,Zhangjiajie Shi,jangjaje si,yong ding,yong ding qu,zanghjyajy,zhang jia jie,zhang jia jie shi,Čang-ťia-ťie,Чжанцзяцзе,זאנגגיאגיה,زانغجياجي,ژانگجیانیے,ကျန်းကျားကျဲသဘာဝဥယျာဉ်,张家界,张家界市,張家界,張家界市,永定,永定区,장자제 시', 29.1294400, 110.4783300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18841, 'Dayong', 'Dayong', 'Dayong,Ta-yung,Ta-yung-hsu,Ta-yung-hsü,da yong,大涌', 22.4706100, 113.2848800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18842, 'Daying', 'Daying', 'Daying,Daying Zhen,Dayingji,Ta-ying,Ta-ying-chi,da ying,da ying zhen,大英,大英镇', 32.3026800, 118.6012100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18843, 'Daying', 'Daying', 'Daying,Daying Zhen,Ta-ying,Ta-ying-chen,da ying,da ying zhen,大营,大营镇', 39.2901900, 113.7575800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18844, 'Daying', 'Daying', 'Daying,Ta-ying,da ying,大营', 34.7217700, 111.1029500, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18845, 'Daying', 'Daying', 'Daying,Daying Zhen,Ta-ying,da ying,da ying zhen,大营,大营镇', 33.9374800, 112.8829600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18846, 'Dayin', 'Dayin', 'Dayin,Dayin Zhen,Ta-yin,da yin,da yin zhen,大隐,大隐镇', 29.9400500, 121.3710700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18847, 'Dayi', 'Dayi', 'Dayi,Dayi Zhen,Dayiji,Ta-i,Ta-i-chi,Tayiji,da yi,da yi zhen,大仪,大仪镇', 32.5426600, 119.2380800, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18848, 'Daye', 'Daye', 'Daye,Ta-ye-li,Ta-yeh,Ta-yeh-ch''eng,Ta-yeh-ch’eng,Ta-yeh-hsien', 30.0833300, 114.9500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18849, 'Dayao', 'Dayao', 'Dayao,Dayao Zhen,da yao,da yao zhen,大窑,大窑镇', 37.3893800, 121.6569600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18850, 'Dayanggezhuang', 'Dayanggezhuang', '', 39.8188900, 117.4236100, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18851, 'Dayang', 'Dayang', 'Dayang,Dayang Zhen,da yang,da yang zhen,大洋,大洋镇', 29.4425000, 119.5088400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18852, 'Dayang', 'Dayang', 'Dayang,Dayang Xiang,da yang,da yang xiang,大洋,大洋乡', 25.7208800, 119.0774800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18853, 'Dayandang', 'Dayandang', 'Dayandang,Dayandang Zhen,Ta-yen-tang,da yan dang,da yan dang zhen,大堰垱,大堰垱镇', 29.7500000, 111.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18854, 'Daohe', 'Daohe', 'Daohe,Daohe Xiang,Dayanchang,da yan chang,dao he,dao he xiang,大岩场,道河,道河乡', 29.5455300, 111.7280900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18855, 'Dayanbei', 'Dayanbei', 'Dayanbei,Dayanbei Xiang,Ta-yen-pei,Ta-yen-pei-chen,da yan bei,da yan bei xiang,大严备,大严备乡', 39.1555300, 112.0219100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18856, 'Dayan', 'Dayan', 'Dayan,Dayan Xiang,Ta-yen,da yan,da yan xiang,大堰,大堰乡', 30.3393200, 111.0840900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18857, 'Dayan', 'Dayan', 'Dayan,Dayan Zhen,Ta-yen,Ta-yen-shih,da yan,da yan zhen,大堰,大堰镇', 29.5076700, 121.2995300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18858, 'Lijiang', 'Lijiang', 'Cidade Antiga de Lijiang,LJG,La-gong,Le Giang,Le-kang-chhi,Li-chiang,Li-tiang,Li-ťiang,Liczjan,Liczjan shaary,Lidziangas,Lijiang,Likiang-hsien,Liszyan,Lâ̤-gŏng,Lìjiāng,Lē-kang-chhī,Lệ Giang,Ta-yen-chen,li ceiyng,li jiang,li jiang shi,lidziani,lijang si,liji''anga,liji''anga  yunnana,lyjyang,lyjyang shەھyry,lyjyanj,Лицзян,Лицзян шаары,Лиђанг,ליגיאנג,لىجياڭ شەھىرى,ليجيانج,لیجیانگ,लिजिआंग,लिजिआंग  युन्नान,ลี่เจียง,ლიძიანი,丽江市,麗江,麗江市,리장 시', 26.8687900, 100.2207200, 'CN', '2014-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18859, 'Daxu', 'Daxu', 'Daxu,Daxu Zhen,Ta-hsu,Ta-hsu-chieh-shih,Ta-hsü,Ta-hsü-chieh-shih,da xu,da xu zhen,大徐,大徐镇', 29.5316700, 121.8797200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18860, 'Daxin', 'Daxin', 'Daxin,Daxin Zhen,da xin,da xin zhen,大新,大新镇', 31.9716300, 120.5430700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18861, 'Daxinzhuang', 'Daxinzhuang', 'Daxingzhuang,Daxinzhuang,Daxinzhuang Zhen,Ta-hsin-chuang,Ta-hsing-chuang,da xin zhuang,da xin zhuang zhen,大辛庄,大辛庄镇', 36.2333300, 113.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18862, 'Daxing', 'Daxing', 'Daxing,Daxing Xiang,Daxing Zhen,Ta-hsing,Ta-hsing-chen,Ta-hsing-ts''un,Ta-hsing-ts’un,da xing,da xing zhen,大兴,大兴镇', 31.7561500, 121.6760700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18863, 'Daxing', 'Daxing', 'Daxing,Lang-ch''u,Lang-ch’ü,Langku,Langkü,Ning-lang-hsien,Ning-lang-i-tsu-tzu-chih-hsien,Ning-lang-she-chih-chu,Ning-lang-she-chih-chü,Ninglang,da xing,大兴', 27.2636900, 100.8638700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18864, 'Daxindian', 'Daxindian', 'Daxindian,Daxindian Zhen,Ta-hsin-tien,Tasintien,da xin dian,da xin dian zhen,大辛店,大辛店镇', 37.6212600, 120.8522500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18865, 'Xindian', 'Xindian', 'Daxindian,Ta-hsin-tien,Xindian,Xindian Zhen,xin dian,xin dian zhen,新店,新店镇', 33.6184900, 113.8504600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18866, 'Daxin', 'Daxin', 'Daxin,Daxin Zhen,Daxindian,Ta-hsin-tien,da xin zhen,大新镇', 31.7211700, 114.1536000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18867, 'Daxie', 'Daxie', 'Daxie,Daxie Xiang,da xie,da xie xiang,大歇,大歇乡', 30.0729200, 108.1102700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18868, 'Daxi', 'Daxi', 'Daxi,Daxi Xiang,Daxidu,Ta-hsi-tu,da xi,da xi xiang,大溪,大溪乡', 28.5881900, 116.6982700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18869, 'Dongshan', 'Dongshan', 'Daxibian,Dongshan,da xi bian,dong shan,东山,大溪边', 29.3027800, 118.5433300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18870, 'Dazhou', 'Dazhou', 'DAX,Dachzhou,Dak-ciu,Dasyan'',Dasyan’,Daxian,Dazhou,Dăk-ciŭ,GJat Chau,Sui-ting,Sui-ting-fu,Suting,Suydin,Ta,Ta-cou,Ta-hsien,Ta-čou,Tat-chiu-chhi,Ta̍t-chiu-chhī,That-chu-su,Tha̍t-chû-sṳ,da zhou,da zhou shi,dajeou si,dazhw,dazhww  sychwan,Đạt Châu,Дачжоу,داژو,داژوو، سیچوان,达州,达州市,達州,達州市,다저우 시', 31.2159200, 107.5009200, 'CN', '2016-11-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18871, 'Daxi', 'Daxi', 'Daxi,Daxi Xiang,da xi,da xi xiang,大溪,大溪乡', 30.9993800, 109.6380500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18872, 'Daxi', 'Daxi', 'Daxi,Daxi Zhen,Ta-hsi,Ta-hsi-chen,da xi,da xi zhen,大溪,大溪镇', 28.4664100, 121.2500500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18873, 'Dawukou', 'Dawukou', 'Dawukou,Shih-tsui-shan,Shizuishan,Ta-wei-k''ou,Ta-wei-k’ou,Ta-wu-k''ou,Ta-wu-k’ou', 39.0419400, 106.3958300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18874, 'Dawu', 'Dawu', 'Dawo,Dawu,Dawu Zhen,Ma-ch''in,Ma-ch’in,Maqen,Maqin,Maqin Xian,Maqên,Ta-wu,da wu,da wu zhen,ma qin,ma qin xian,大武,大武镇,玛沁,玛沁县', 34.4662300, 100.2299300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18875, 'Dawangtai', 'Dawangtai', 'Dawangtai,Ta-wang-t''ai,Ta-wang-t’ai,Wang-chia-t''ai,Wang-chia-t’ai,Wang-t''ai-tzu,Wang-t’ai-tzu,da wang tai,大王台', 39.2750400, 117.4850200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18876, 'Wangcun', 'Wangcun', 'Dawang,Ta-wang,Ta-wang-ts''un,Ta-wang-ts’un,Wangcun,Wangcun Zhen,wang cun,wang cun zhen,王村,王村镇', 34.3763900, 108.1816700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18877, 'Dawang', 'Dawang', 'Dawang,Ta-wang,Ta-wang-chia,da wang,大王', 34.3028700, 109.4746400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18878, 'Dawang', 'Dawang', 'Dawang,Dawang Zhen,Ta-wang,Ta-wang-chen,da wang,da wang zhen,大王,大王镇', 34.2030300, 108.6513900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18879, 'Dawan', 'Dawan', 'Dawan,Dawan Zhen,Ta-wan,da wan,da wan zhen,大湾,大湾镇', 24.3413900, 112.9372200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18880, 'Dawan', 'Dawan', 'Dawan,Dawan Zhen,Ta-wan-hsu,Ta-wan-hsü,Taiwan,da wan,da wan zhen,大湾,大湾镇', 22.8210700, 111.6299300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18881, 'Datuo', 'Datuo', 'Datuo,Datuo Zhen,Datuopu,Ta-t''o,Ta-t''o-p''u,Ta-t’o,Ta-t’o-p’u,da tuo,da tuo zhen,大托,大托镇', 28.0592900, 112.9489000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18882, 'Datuan', 'Datuan', 'Datuan,Datuan Zhen,da tuan,da tuan zhen,大疃,大疃镇', 37.1173300, 122.3081200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18883, 'Datuan', 'Datuan', 'Datuan,Ta-t''uan,Ta-t''uan-chen,Ta-t’uan,Ta-t’uan-chen,da tuan,大团', 30.9738100, 121.7335600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18884, 'Datong', 'Datong', 'Datong,Datong Zhen,Datongjie,Datun,Ta-t''ung,Ta-t''ung-chen,Ta-t’ung,Ta-t’ung-chen,da tong,da tong zhen,Датун,大通,大通镇', 32.8280800, 118.8444300, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18885, 'Datong', 'Datong', 'Datong,Datun,Ta-t''ung,Ta-t’ung,Датун', 32.6208200, 117.0631900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18886, 'Datong', 'Datong', 'Datong,Datong Zhen,Datun,Ta-t''ung,Ta-t''ung-chen,Ta-t’ung,Ta-t’ung-chen,da tong,da tong zhen,Датун,大同,大同镇', 29.3109200, 119.1069800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18887, 'Datong', 'Datong', 'Datong,Datong Zhen,da tong,da tong zhen,大同,大同镇', 28.5013900, 105.6769400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18888, 'Datong', 'Datong', 'Datong,Datong Jiedao,Datun,T''ung-an,T''ung-an-hsien,T''ung-an-hsien-ch''eng,Tong''an,Tong’an,T’ung-an,T’ung-an-hsien,T’ung-an-hsien-ch’eng,da tong,da tong jie dao,Датун,大同,大同街道', 24.7348300, 118.1430300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18889, 'Datianzhuang', 'Datianzhuang', '', 39.2725000, 117.7536100, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18890, 'Datian', 'Datian', 'Datian,Datian Jiedao,Ta-t''ien,Ta-t’ien,da tian,da tian jie dao,大田,大田街道', 28.9076300, 121.1976300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18891, 'Datian', 'Datian', 'Datian,Datian Xiang,da tian,da tian xiang,大田,大田乡', 26.9286400, 116.9998900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18892, 'Datian', 'Datian', 'Datian,Datian Xiang,Ta-t''ien,Ta-t''ien-shih,Ta-t’ien,Ta-t’ien-shih,da tian,da tian xiang,大田,大田乡', 25.8559200, 115.1278800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18893, 'Datian', 'Datian', 'Datian,Datian Zhen,Ta-t''ien,Ta-t’ien,da tian,da tian zhen,大田,大田镇', 22.2638200, 112.2237100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18894, 'Datangzhuang', 'Datangzhuang', 'Datangzhuang,Ta-t''ang-chuang,Ta-t’ang-chuang', 39.3994400, 117.4341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18895, 'Datangping', 'Datangping', 'Datang,Datangping,Datangping Xiang,da tang ping,da tang ping xiang,大塘坪,大塘坪乡', 28.9942200, 115.9022600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18896, 'Datang', 'Datang', 'Datang,Datang Zhen,da tang,da tang zhen,大塘,大塘镇', 24.7744700, 113.6930200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18897, 'Datang', 'Datang', 'Datang,Datang Zhen,Ta-t''ang,Ta-t''ang-hsu,Ta-t’ang,Ta-t’ang-hsü,da tang,da tang zhen,大塘,大塘镇', 23.4425000, 112.8938700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18898, 'Dasi', 'Dasi', 'Dasi,Dasi Zhen,Dasizhuang,Ta-ssu,Ta-ssu-chuang,da si,da si zhen,da si zhuang,大泗,大泗庄,大泗镇', 32.3583900, 119.9693000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18899, 'Dasi', 'Dasi', 'Dasi,Dasi Zhen,da si,da si zhen,大寺,大寺镇', 39.0182100, 117.2376800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18900, 'Dashuipo', 'Dashuipo', 'Dashuipo,Dashuipo Zhen,Ta-shui-po,da shui po,da shui po zhen,大水泊,大水泊镇', 37.1849800, 122.2471200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18901, 'Shiqiao', 'Shiqiao', 'Dashiqiao,Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 33.9206400, 113.1559100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18902, 'Dashiju', 'Dashiju', 'Dashiju,Dashiju Zhen,Ta-shih-chu,Ta-shih-chü,da shi ju,da shi ju zhen,大市聚,大市聚镇', 29.4447200, 121.0341700, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18903, 'Dashentang', 'Dashentang', '', 39.2172200, 117.9525000, 'CN', '2001-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18904, 'Dasheng', 'Dasheng', 'Dasheng,Dasheng Zhen,Dashengqiao,Ta-sheng-ch''iao,Ta-sheng-ch’iao,da sheng,da sheng qiao,da sheng zhen,大生,大生桥,大生镇', 32.1414000, 119.9827000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18905, 'Shaping', 'Shaping', 'Dashaping,Shaping,Shaping Zhen,Ta-sha-p''ing,Ta-sha-p’ing,sha ping,sha ping zhen,沙坪,沙坪镇', 29.3762400, 113.8708300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18906, 'Dasha', 'Dasha', 'Dasha,Dasha Zhen,Ta-sha,da sha,da sha zhen,大沙,大沙镇', 23.2481000, 112.7433600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18907, 'Dasha', 'Dasha', 'Dasha,Dasha Zhen,Ta-sha,da sha,da sha zhen,大沙,大沙镇', 22.5203200, 112.3445700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18908, 'Darong', 'Darong', 'Darong,Ta-jung-tung,da rong,大融', 25.7850000, 108.8640000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18909, 'Darenzhuang', 'Darenzhuang', 'Darenzhuang,Darenzhuang Xiang,Ta-jen-chuang,da ren zhuang,da ren zhuang xiang,大仁庄,大仁庄乡', 39.6841100, 113.8900100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18910, 'Darenzhuang', 'Darenzhuang', 'Darenzhuang,da ren zhuang,大任庄', 39.0388900, 117.2519400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18911, 'Daqi', 'Daqi', 'Daqi,Daqi Zhen,Daqitou,Ta-ch''i,Ta-ch''i-chen,Ta-ch''i-t''ou,Ta-ch’i,Ta-ch’i-chen,Ta-ch’i-t’ou,da qi,da qi zhen,大碶,大碶镇', 29.8921000, 121.7959800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18912, 'Qiaobian', 'Qiaobian', 'Daqiaobian,Qiaobian,Qiaobian Zhen,Ta-ch''iao-pien,Ta-ch’iao-pien,qiao bian,qiao bian zhen,桥边,桥边镇', 30.6823000, 111.1866400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18913, 'Daqiao', 'Daqiao', 'Daqiao,da qiao,大桥', 33.7463100, 105.2786600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18914, 'Daqiao', 'Daqiao', 'Ch''iao-k''ou,Ch’iao-k’ou,Daqiao,Daqiao Zhen,Ta-ch''iao,Ta-ch''iao-k''ou,Ta-ch’iao,Ta-ch’iao-k’ou,da qiao,da qiao zhen,大桥,大桥镇', 32.9933100, 120.6359600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18915, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,Ho-chia-ch''iao,Ho-chia-ch’iao,Huojiaqiao,Ta-ch''iao,Ta-ch''iao-chen,Ta-ch’iao,Ta-ch’iao-chen,da qiao,da qiao zhen,大桥,大桥镇', 32.3697700, 119.7060700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18916, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Jiedao,Ta-ch''iao,Ta-ch''iao-chen,Ta-ch’iao,Ta-ch’iao-chen,da qiao,da qiao jie dao,大桥,大桥街道', 31.4653900, 118.4085400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18917, 'Fenghua', 'Fenghua', 'Chung-cheng,Daqiao,Daqiaozhen,Feng-hua-hsien,Fenghua,Fenghua Shi,Fenghwa,Fenghwahsien,Ta-ch''iao,Ta-ch’iao,feng hua,feng hua shi,奉化,奉化市', 29.6562800, 121.4064000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18918, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,Ta-ch''iao,Ta-ch’iao,da qiao,da qiao zhen,大桥,大桥镇', 28.7430500, 118.4061800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18919, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,Ta-ch''iao,Ta-ch’iao,da qiao,da qiao zhen,大桥,大桥镇', 26.6150000, 118.9063900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18920, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,da qiao,da qiao zhen,大桥,大桥镇', 25.3521600, 115.1479500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18921, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,Ta-ch''iao,Ta-ch’iao,da qiao,da qiao zhen,大桥,大桥镇', 24.9833300, 113.1333300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18922, 'Daqiang', 'Daqiang', 'Daqiang,Ta-ch''iang,Ta-ch’iang,da qiang,大墙', 34.4502800, 108.3383300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18923, 'Daqian', 'Daqian', 'Daqian,Daqian Zhen,da qian,da qian zhen,大阡,大阡镇', 28.9760000, 107.4473000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18924, 'Daqi', 'Daqi', 'Daqi,Daqi Xiang,da qi,da qi xiang,大崎,大崎乡', 30.8532500, 115.1911300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18925, 'Dabaozi', 'Dabaozi', 'Dabaozi,Dabaozi Xiang,Dabuzi,Dapuzi,Ta-p''u-tzu,Ta-pao-tzu,Ta-p’u-tzu', 26.6955600, 109.4477800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18926, 'Dapo', 'Dapo', 'Dapo,Dapo Zhen,da po,da po zhen,大坡,大坡镇', 22.0808000, 111.2447100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18927, 'Taipingying', 'Taipingying', 'Dapingying,Ta-p''ing-ying,Ta-p’ing-ying,Taipingying,Taipingying Xiang,tai ping ying,tai ping ying xiang,太平营,太平营乡', 28.0982100, 109.1636900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18928, 'Daping', 'Daping', 'Daping,Daping Zhen,Ta-p''ing,Ta-p’ing,da ping,da ping zhen,大坪,大坪镇', 29.0129700, 110.4926000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18929, 'Daping', 'Daping', 'Daping,Daping Zhen,da ping,da ping zhen,大坪,大坪镇', 28.5829700, 107.9342000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18930, 'Dapingchang', 'Dapingchang', 'Daping,Dapingchang,Dapingchang Zhen,da ping chang,da ping chang zhen,大坪场,大坪场镇', 28.1099200, 109.1071900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18931, 'Daping', 'Daping', 'Daping,Daping Zhen,da ping,da ping zhen,大坪,大坪镇', 24.3720800, 115.9605300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18932, 'Daping', 'Daping', 'Daping,Daping Zhen,da ping,da ping zhen,大坪,大坪镇', 23.1787700, 115.8479900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18933, 'Dapeng', 'Dapeng', 'Dapeng,Dapeng Jiedao,Ta-peng-so-ch''eng,Ta-peng-so-ch’eng,Taipang,Taipung,Taipungshosheng,da peng,da peng jie dao,大鹏,大鹏街道', 22.6008500, 114.4731300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18934, 'Xuetian', 'Xuetian', 'Dapan,Dapan Zhen,Xuetian,da pan zhen,xue tian,大盘镇,学田', 29.0045300, 120.5620000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18935, 'Daoxian', 'Daoxian', 'Daoxian,Daoxian Zhen,Tao-hsien,Tao-hsien-chen,Tao-yen-chen,dao xian,到贤', 34.8600700, 109.3157600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18936, 'Daotanghe', 'Daotanghe', 'Daotanghe,Daotanghe Zhen,Tao-t''ang-ho,Tao-t’ang-ho,dao tang he,dao tang he zhen,倒淌河,倒淌河镇', 36.3988900, 100.9652800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18937, 'Dashu', 'Dashu', 'Daoshu Zhen,Daoshuqiao,Dashu,Tao-shu-ch''iao,Tao-shu-ch''iao-chen,Tao-shu-ch’iao,Tao-shu-ch’iao-chen,dao shu,dao shu zhen,导墅,导墅镇', 31.8381000, 119.6869800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18938, 'Daoshi', 'Daoshi', 'Daoshi,Daoshi Zhen,Daoshiwu,Niao-shih-wu,Tao-shih-wu,dao shi,岛石', 30.2922200, 118.9483300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18939, 'Daokou', 'Daokou', 'Daokou,Hua-hsien,Huaxian,Tao-k''ou,Tao-k''ou-chen,Tao-k’ou,Tao-k’ou-chen,Taokow,dao kou,道口', 35.5638900, 114.5058300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18940, 'Daojiao', 'Daojiao', 'Daojiao,Daojiao Zhen,dao jiao,dao jiao zhen,道滘,道窖镇', 23.0011200, 113.6586000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18941, 'Daojiang', 'Daojiang', 'Daojiang,Daojiangzhen,Daoxian,Tao,Tao-chiang,Tao-chiang-chen,Tao-chou,Tao-hsien,dao jiang,道江', 25.4960300, 111.5514600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18942, 'Qushan', 'Qushan', 'Daodou,Daodou''ao,Daodouzhen,Daodou’ao,Qushan,Qushan Zhen,Ta-ch''u,Ta-ch’ü,Tao-tou-ao,dao dou,dao dou zhen,qu shan,qu shan zhen,岛斗,岛斗镇,衢山,衢山镇', 30.4500500, 122.2842700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18943, 'Danzao', 'Danzao', 'Danzao,Tan-tsao,dan zao,丹灶', 23.0425000, 112.9138900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18944, 'Danyun', 'Danyun', 'Danyun,Danyun Xiang,Tan-yang,dan yun,dan yun xiang,丹云,丹云乡', 25.9940500, 119.0217600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18945, 'Danyang', 'Danyang', 'Danyang,Danyang Zhen,Tan-yang,dan yang,dan yang zhen,丹阳,丹阳镇', 26.3510200, 119.4803000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18946, 'Danshui', 'Danshui', 'Dan''shuem,Danshui,Danshui Jiedao,Huiyang Qu,Huiyangshi,Tamshui,Tamshuihu,Tamshuihü,Tan-shui,Tanshuihu,dan shui,hui yang qu,Даньшуем,惠阳区,淡水', 22.7984000, 114.4671600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18947, 'Danjiangkou', 'Danjiangkou', 'Chun-hsien,Chün-hsien,Dan''czjankou,Danjiangkou,Junxian,Junxian Danjiang,Sha-t''o-ying,Sha-t’o-ying,Shatoin,Tan-chiang,Tan-chiang-k''ou,Tan-chiang-k’ou,Даньцзянкоу', 32.5427800, 111.5086100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18948, 'Ningchang', 'Ningchang', 'Daningchang,Hengjiadong,Ningchang,Ningchang Zhen,Ta-ning-ch''ang,Ta-ning-ch’ang,heng jia dong,ning chang,ning chang zhen,宁厂,宁厂镇,衡家洞', 31.4820800, 109.6402900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18949, 'Xinshui', 'Xinshui', 'Danin,Daning,Daning Xian,Hsi-ning Hsien,Ta-ning,Ta-ning-hsien,Ta-ning-hsien-ch''eng,Ta-ning-hsien-ch’eng,Xinshui,Xinshui Zhen,da ning xian,xin shui,xin shui zhen,大宁县,昕水,昕水镇', 36.4783900, 110.7552200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18950, 'Gushu', 'Gushu', 'Dangtu,Gushu,Tai Ping,Taiping,Taiping-fu,Tang-t''u,Tang-t''u-hsien,Tang-t’u,Tang-t’u-hsien,gu shu,姑熟', 31.5605500, 118.4814700, 'CN', '2014-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18951, 'Dangcheng', 'Dangcheng', 'Dangcheng,Dangshan,Dongshan,Tang-shan,Tang-shan-hsien,dang cheng,砀城', 34.4278700, 116.3765700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18952, 'Dangmu', 'Dangmu', 'Dangmu,Dangmu Zhen,Tang-mu,Tang-mu-chen,dang mu,党睦', 34.8141800, 109.6210100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18953, 'Dangliuzhuang', 'Dangliuzhuang', 'Dangliuzhuang,Dangliuzhuang Zhen,Tang-liu-chuang,dang liu zhuang,dang liu zhuang zhen,党留庄,党留庄镇', 39.9889700, 113.4222000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18954, 'Dangjiaxian', 'Dangjiaxian', 'Dangjiaxian,dang jia xian,党家岘', 35.5299200, 105.3017000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18955, 'Dangcheng', 'Dangcheng', 'Danchenchzhen,Dangcheng,Dangcheng Xiang,Tang-ch''eng,Tang-ch''eng-chen,Tang-ch’eng,Tang-ch’eng-chen,dang cheng,dang cheng xiang,党城,党城乡', 38.7365400, 114.5715700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18956, 'Dangchang Chengguanzhen', 'Dangchang Chengguanzhen', 'Chengguan Zhen,Danchanchzhen'',Danchanchzhen’,Dangchang,Dangchang Chengguanzhen,Dangchang Xian,Tanchang,Tang-ch''ang,Tang-ch''ang-chen,Tang-ch''ang-pao,Tang-ch’ang,Tang-ch’ang-chen,Tang-ch’ang-pao,Tang-tsch''ang-tschon,Tang-tsch’ang-tschön,Yen-ch''ang-chen,Yen-ch’ang-chen,cheng guan zhen,dang chang,dang chang cheng guan zhen,dang chang xian,城关镇,宕昌,宕昌县,宕昌城关镇', 34.0446200, 104.3946400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18957, 'Danfeng', 'Danfeng', 'Danfeng,Shih-tsung,Shih-tsung-ch''eng,Shih-tsung-ch’eng,Shih-tsung-hsien,Shizong,dan feng,丹凤', 24.8305400, 104.0082000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18958, 'Dandian', 'Dandian', 'Dadian Zhen,Dandian,T''au-tien,T’au-tien,dan dian,dan dian zhen,但店,但店镇', 30.7678700, 115.1777600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18959, 'Dancun', 'Dancun', 'Dancun,Dancun Zhen,Tan-ts''un,Tan-ts''un-chen,Tan-ts’un,Tan-ts’un-chen,dan cun,淡村', 34.7194700, 109.0535200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18960, 'Xincheng', 'Xincheng', 'Dancheng,Tan-ch''eng,Tan-ch''eng-chi,Tan-ch’eng,Tan-ch’eng-chi,Xincheng,xin cheng,新城', 33.6333300, 115.1833300, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18961, 'Danxi', 'Danxi', 'Dancheng,Danxi,Danxi Jiedao,Hsiang-shan,Hsiang-shan-hsien,Siangshan,Siangshanhsien,Tan-ch''eng,Tan-ch''eng-chen,Tan-ch’eng,Tan-ch’eng-chen,Xiangshan,dan xi,dan xi jie dao,xiang shan,丹西,丹西街道,象山', 29.4747200, 121.8655600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18962, 'Danchang', 'Danchang', 'Danchang,Danchang Zhen,dan chang,dan chang zhen,旦场,旦场镇', 21.5127700, 111.1009800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18963, 'Daming', 'Daming', 'Damin,Daming,Ta-ming,Ta-ming-ch''eng-kuan,Ta-ming-ch’eng-kuan,Ta-ming-hsien,Tamingfu,da ming,大名', 36.2860800, 115.1435600, 'CN', '2014-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18964, 'Damiao', 'Damiao', 'Damiao,Damiao Xiang,Ta-miao,da miao,da miao xiang,大庙,大庙乡', 28.0765100, 114.8841300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18965, 'Daman', 'Daman', 'Daman,Daman Zhen,Damanbu,da man,da man zhen,大满,大满镇', 38.8247200, 100.4155600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18966, 'Damai', 'Damai', 'Damai,Damai Xiang,da mai,da mai xiang,达麦,达麦乡', 35.2000700, 102.6641400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18967, 'Dama', 'Dama', 'Dama,Dama Zhen,Ta-ma,da ma,da ma zhen,大麻,大麻镇', 30.5023300, 120.3411100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18968, 'Dama', 'Dama', 'Dama,Damazhen,da ma,da ma zhen,大麻,大麻镇', 24.3438900, 116.5293100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18969, 'Daluo', 'Daluo', 'Daluo,Daluo Zhen,da luo,da luo zhen,大洛,大洛镇', 26.2509900, 117.7893900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18970, 'Dalun', 'Dalun', 'Dalun,Dalun Zhen,Dalunzhuang,Ta-lun,Ta-lun-chuang,da lun,da lun zhen,大埨,大埨镇', 32.4437600, 120.2419200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18971, 'Dalucao', 'Dalucao', 'Dalucao,Dalucao Xiang,da lu cao,da lu cao xiang,大路槽,大路槽乡', 28.0166700, 107.3000000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18972, 'Dalubian', 'Dalubian', 'Dalubian,Dalubian Zhen,da lu bian,da lu bian zhen,大路边,大路边镇', 25.0279000, 112.6199000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18973, 'Dalu', 'Dalu', 'Dalu,Dalu Zhen,Ta-lu,Ta-lu-chen,da lu,da lu zhen,大路,大路镇', 32.2152600, 119.7323000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18974, 'Dalu', 'Dalu', 'Dalu,Dalu Zhen,Ta-lu,da lu,da lu zhen,大路,大路镇', 29.7298400, 106.2177000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18975, 'Dalu', 'Dalu', 'Dalu,Dalu Zhen,da lu,da lu zhen,大路,大路镇', 19.3895000, 110.4652700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18976, 'Dalongzhan', 'Dalongzhan', 'Dalongzhan,Dalongzhan Zhen,da long zhan,da long zhan zhen,大龙站,大龙站镇', 29.2047200, 111.7529800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18977, 'Dalong', 'Dalong', 'Dalong,Dalong Xiang,Dalongkou,Ta-lung,Ta-lung-k''ou,Ta-lung-k’ou,da long,da long xiang,大陇,大陇乡', 31.4335800, 118.7133800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18978, 'Daliuhang', 'Daliuhang', 'Daliuhang,Daliuhang Zhen,Ta-liu-hang,da liu xing,da liu xing zhen,大柳行,大柳行镇', 37.6084300, 121.0475800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18979, 'Daliu', 'Daliu', 'Daliu,Daliu Xiang,Daliudian,Ta-liu-tien,da liu,da liu xiang,大刘,大刘乡', 33.5036400, 113.9029500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18980, 'Dalinhe', 'Dalinhe', 'Dalinhe,Dalinhe Xiang,Lin-ho-ts''un,Lin-ho-ts’un,Ta-lin-ho,da lin he,da lin he xiang,大临河,大临河乡', 39.5555600, 113.3611100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18981, 'Dalikou', 'Dalikou', 'Dali Zhen,Dalikou,Ta-li,Ta-li-k''ou,Ta-li-k’ou,da li kou,da li zhen,大历口,大历镇', 26.8894300, 118.0024600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18982, 'Daliang', 'Daliang', 'Daliang,Daljan,Ta-hang-chen,Ta-liang,Ta-liang-chen,Далян', 39.5394400, 117.0950000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18983, 'Daliang', 'Daliang', 'Daliang,Daliang Jiedao,Daljan,P''an-shun,P’an-shun,Schuntak,Shun-te,Shun-te-hsien,Shunde,Shuntak,Ta-liang,Ta-liang-chen,da liang,da liang jie dao,shun de qu,Далян,大良,大良街道,顺德区', 22.8406700, 113.2503000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18984, 'Dalian', 'Dalian', 'DLC,Dairen,Dal''niy,Dalian,Dalian Shi,Daljan'',Dalny,Dal’niy,Lu-ta,Lu-ta-shih,Luda,Lü-ta,Lü-ta-shih,Lüda,Ntalian,Ta-lien,Ta-lien-shih,da lian,da lian shi,daelyeon,dalyan,dalyen si,dʼlyyn,ta heliyn,Νταλιάν,Далянь,דאליין,داليان,دالیان,ต้าเหลียน,大连,大连市,大連,大連市,다롄 시,대련', 38.9122200, 121.6022200, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18985, 'Dali', 'Dali', 'Dali,T''ung-chou,Ta-li,Ta-li-hsien,Tunchzhou,Tungchow,Tungchowfu,T’ung-chou,da li,大荔', 34.7958600, 109.9389500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18986, 'Dali', 'Dali', 'Chung-ho-chen,DLU,Dali,Ta-ho,Ta-li,Talifu,da li,da li shi,Дали,大理,大理市', 25.5847400, 100.2122900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18987, 'Dalang', 'Dalang', 'Dalang,Dalang Zhen,da lang,da lang zhen,大崀,大崀镇', 24.4497200, 112.4865300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18988, 'Dalang', 'Dalang', 'Dalang,Dalang Zhen,Ta-lang,Ta-lang-hsu,Ta-lang-hsü,da lang,da lang zhen,大朗,大朗镇', 22.9481000, 113.9276400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18989, 'Dalan', 'Dalan', 'Dalan,Dalan Zhen,Ta-lan,da lan,大岚', 23.2817400, 114.7156700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18990, 'Dakoutun', 'Dakoutun', 'Dakoutun,Ta-k''ou-t''un,Ta-k’ou-t’un', 39.5833300, 117.2288900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18991, 'Dajishan', 'Dajishan', 'Dajishan,Dajishan Zhen,Ta-chi-shan,da ji shan,da ji shan zhen,大吉山,大吉山镇', 24.6052100, 114.3614000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18992, 'Dajin', 'Dajin', 'Dajin,Dajin Zhen,Dajinpu,Ta-chin,Ta-chin-p''u,Ta-chin-p’u,da jin,da jin zhen,大金,大金镇', 29.9978500, 115.6121000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18993, 'Dajing', 'Dajing', 'Dajing,Dajing Zhen,Ta-ching,Ta-ching-chen,da jing,大荆', 34.0583300, 109.8642500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18994, 'Dajing', 'Dajing', 'Dajing,Dajing Zhen,Ta-ching,Ta-ching-chen,da jing,da jing zhen,大荆,大荆镇', 28.4093900, 121.1536300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18995, 'Dajing', 'Dajing', 'Dajing,Dajing Zhen,Ta-ching,Ta-ching-hsu,Ta-ching-hsü,da jing,da jing zhen,大井,大井镇', 22.0839600, 110.8711800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18996, 'Dajin', 'Dajin', 'Dajin,Dajin Zhen,Dajinchang,da jin,da jin zhen,大进,大进镇', 31.5095500, 108.4457900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18997, 'Dajijia', 'Dajijia', 'Dajijia,Dajijia Zhen,da ji jia,da ji jia zhen,大季家,大季家镇', 37.6664100, 121.0529900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18998, 'Dajie', 'Dajie', 'Chiang-ch''uan,Chiang-ch’uan,Dajie,Dajie Zhen,Jiangchuan,Jiangchuan Xian,Ta-chieh-chen,Ta-chieh-tzu,da jie,da jie zhen,jiang chuan,jiang chuan xian,大街,大街镇,江川,江川县', 24.2962300, 102.7506400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(18999, 'Dajiang', 'Dajiang', 'Dajiang,Dajiang Zhen,Ta-chiang,da jiang,da jiang zhen,大江,大江镇', 22.3770900, 112.8000700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19000, 'Dajianchang', 'Dajianchang', '', 39.4777800, 117.0830600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19001, 'Dajia', 'Dajia', 'Dajia,Dajia Xiang,da jia,da jia xiang,大甲,大甲乡', 26.6390900, 119.2754100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19002, 'Daji', 'Daji', 'Daji,Daji Jiedao,da ji,da ji jie dao,大集,大集街道', 30.5088700, 114.0428100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19003, 'Daji', 'Daji', 'Daji,Daji Xiang,Ta-chi,Xi''andi,Xi’andi,da ji,da ji xiang,大漈,大漈乡', 27.8140900, 119.5857400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19004, 'Daiyue', 'Daiyue', 'Daiyue,Daiyue Zhen,Dayyuechzhen,Shan-yin-hsien,Shanyin,Shanyin Xian,Tai-yo,Tai-yueh,Tai-yueh-chen,Tai-yüeh,Tai-yüeh-chen,Taiyoh,dai yue,dai yue zhen,shan yin xian,山阴县,岱岳,岱岳镇', 39.5203800, 112.8168400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19005, 'Shangguan', 'Shangguan', 'Dai Xian,Daixian,Daysyan'',Daysyan’,Shangguan,Shangguan Zhen,Tai,Tai-ch''eng,Tai-ch’eng,Tai-hsien,Tai-hsien-ch''eng,Tai-hsien-ch’eng,Taichow,dai xian,shang guan,shang guan zhen,上馆,上馆镇,代县', 39.0690100, 112.9291300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19006, 'Daixi', 'Daixi', 'Daixi,Daixi Zhen,Tai-ch''i,Tai-ch’i,Tai-hsi,dai xi,dai xi zhen,埭溪,埭溪镇', 30.6629000, 120.0099900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19007, 'Daixi', 'Daixi', 'Daixi,Tai-hsi,Yang-k''ou,Yang-k’ou', 26.8125000, 119.1141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19008, 'Daitou', 'Daitou', 'Daitou,Daitou Zhen,Tai-t''ou,Tai-t’ou,dai tou,dai tou zhen,埭头,埭头镇', 31.4957300, 119.5174200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19009, 'Daitou', 'Daitou', 'Daitou,Daitou Zhen,Tai-t''ou,Tai-t’ou,dai tou,dai tou zhen,埭头,埭头镇', 25.2580300, 119.2258400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19010, 'Daishan', 'Daishan', 'Daishan,Gaoting,Gaoting Zhen,dai shan,gao ting,gao ting zhen,岱山,高亭,高亭镇', 30.2458900, 122.1989500, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19011, 'Dainan', 'Dainan', 'Dainan,Dainan Zhen,Tai-chia-tse,Tai-nan,dai nan,dai nan zhen,戴南,戴南镇', 32.7170300, 120.1290600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19012, 'Daijiaba', 'Daijiaba', 'Daijiaba,Daijiaba Zhen,Tai-chia-pa,dai jia ba,dai jia ba zhen,代家坝,代家坝镇', 33.0097000, 106.1835200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19013, 'Daifang', 'Daifang', 'Daifang,Daifang Zhen,Tai-fang,Tai-fang-hsu,Tai-fang-hsü,Tai-fang-ts''un,Tai-fang-ts’un,dai fang,dai fang zhen,戴坊,戴坊镇', 27.5514600, 115.7060400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19014, 'Duifang', 'Duifang', 'Daifang,Duifang,Duifang Xiang,dui fang,dui fang xiang,对坊,对坊乡', 26.2126100, 115.9786400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19015, 'Daibu', 'Daibu', 'Daibu,Daibu Zhen,Tai-fou,Tai-fou-chen,Tai-pu,dai bu,dai bu zhen,戴埠,戴埠镇', 31.3110400, 119.4972400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19016, 'Dahuangwei', 'Dahuangwei', 'Dahuangwei,Dahuangwei Xiang,Huang-wei-ts''un,Huang-wei-ts’un,Ta-huang-wei,da huang wei,da huang wei xiang,大黄巍,大黄巍乡', 39.5312600, 113.0718600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19017, 'Dahuangpu', 'Dahuangpu', 'Dahuangbu,Dahuangpu,Ta-huang-Pao,Ta-huang-p''u,Ta-huang-p’u', 39.4411100, 117.2777800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19018, 'Dahuang', 'Dahuang', 'Dahuang,Dahuang Xiang,da huang,da huang xiang,大黄,大黄乡', 28.7833300, 116.9333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19019, 'Dahuai', 'Dahuai', 'Dahuai,Dahuai Zhen,Ta-huai,da huai,da huai zhen,大槐,大槐镇', 22.0977000, 112.2291400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19020, 'Dahua', 'Dahua', 'Dahua,Ta-hua,Ta-hua-hsiang,Ta-hua-hsu,Ta-hua-hsü,da hua,大化', 23.7679800, 107.9841000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19021, 'Dahu', 'Dahu', 'Dahu,Dahu Xiang,da hu,da hu xiang,大湖,大湖乡', 26.3655500, 119.0911100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19022, 'Dahu', 'Dahu', 'Dahu,Dahu Zhen,Ta-hu,da hu,da hu zhen,大湖,大湖镇', 26.0497100, 117.3235800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19023, 'Dahu', 'Dahu', 'Dahu,Dahu Zhen,da hu,da hu zhen,大湖,大湖镇', 24.2395700, 114.8322400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19024, 'Dahongmen', 'Dahongmen', 'Dahongmen,Dahongmen Jiedao,Ta-hung-men,da hong men,da hong men jie dao,大红门,大红门街道', 39.8357400, 116.3994200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19025, 'Daheng', 'Daheng', 'Daheng,Daheng Zhen,Ta-heng,da heng,da heng zhen,大横,大横镇', 26.7667800, 118.2577300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19026, 'Dahe', 'Dahe', 'Dahe,Dahe Zhen,Dahekou,Ta-ho-k''ou,Ta-ho-k’ou,da he,da he zhen,大河,大河镇', 32.1957100, 106.9323700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19027, 'Dahejia', 'Dahejia', 'Dahejia,Dahejia Zhen,Dakhztszya,Ta-ho-chia,Ta-hz-chia,da he jia,da he jia zhen,大河家,大河家镇', 35.8341700, 102.7575600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19028, 'Dahe', 'Dahe', 'Dahe,Dahe Zhen,Daheba,Ta-ho-pa,da he,da he zhen,大河,大河镇', 28.3238900, 106.8363900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19029, 'Dahe’an', 'Dahe''an', 'Dahe''an,Dahe''an Zhen,Dahe’an,Dahe’an Zhen,da he an,da he an zhen,大河岸,大河岸镇', 30.8400200, 115.4770200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19030, 'Dahe', 'Dahe', 'Dahe,Dahe Xiang,Ta-ho,Ta-ho-ts''un,Ta-ho-ts’un,da he,da he xiang,大河,大河乡', 38.1377500, 114.3766700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19031, 'Ziyuan', 'Ziyuan', 'Dahe,Ta-fou-t''ou,Ta-fou-t’ou,Tzu-yuan,Tzu-yüan,Ziyuan,zi yuan,资源', 26.0366700, 110.6405600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19032, 'Dahe', 'Dahe', 'Dahe,Dahe Xiang,Ta-ho,da he,da he xiang,大禾,大禾乡', 25.4006300, 116.1013700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19033, 'Dahao', 'Dahao', 'Dahao,Dahao Jiedao,da hao,da hao jie dao,达濠,达濠街道', 23.2888000, 116.7176100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19034, 'Daguo', 'Daguo', 'Daguo,Daguo Xiang,da guo,da guo xiang,大郭,大郭乡', 33.7907700, 113.7958000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19035, 'Dagou', 'Dagou', 'Dagou,da gou,大沟', 35.9798600, 105.2325300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19036, 'Dagou', 'Dagou', 'Dagou,Dagou Zhen,da gou,da gou zhen,大沟,大沟镇', 21.8349800, 112.1565400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19037, 'Dagkar', 'Dagkar', 'Dagkar,Daka,Daka Xiang,Duola''ang Songduo,Duola’ang Songduo,da ka,da ka xiang,duo la ang song duo,多拉昂松多,达卡,达卡乡', 32.9949100, 100.0670700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19038, 'Dazhasi', 'Dazhasi', 'Dagcagoin,Dazhasi,Jo-erh-kai,Ta-cha-ssu,Ta-cha-szu,Ta-ko-cha-ssu,Zoige,Zoigê,da zha si,达扎寺', 33.5779500, 102.9641200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19039, 'Dagang', 'Dagang', 'Dagang,Dagang Jiedao,Ta-chiang,Ta-kang,da gang,da gang jie dao,大港,大港街道', 32.1926000, 119.6554500, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19040, 'Dagang', 'Dagang', 'Dagang,Dagang Zhen,Ta-kang,Ta-kang-hsu,Ta-kang-hsü,da gang,da gang zhen,大岗,大岗镇', 28.1546400, 116.1728300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19041, 'Dagang', 'Dagang', 'Dagang,Dagang Zhen,Ta-kang,da gang,da gang zhen,大岗,大岗镇', 22.8056000, 113.4036000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19042, 'Dagan', 'Dagan', 'Dagan,Dagan Zhen,Ta-kan,da gan,da gan zhen,大干,大干镇', 26.9316000, 117.7328100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19043, 'Dafengdui', 'Dafengdui', 'Dafengdui,Dafengdui Zhen,da feng dui,da feng dui zhen,大丰堆,大丰堆镇', 38.8928600, 117.0036200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19044, 'Dafeng', 'Dafeng', 'Dafeng,Dafeng Zhen,Shang-lin-hsien,Shang-liu,Shanglin,Shangling,da feng,da feng zhen,大丰,大丰镇', 23.4342200, 108.5982500, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19045, 'Dafang', 'Dafang', 'Dafang,Dafang Zhen,da fang,da fang zhen,大方,大方镇', 22.9710800, 111.5798800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19046, 'Dafan', 'Dafan', 'Dafan,Dafan Zhen,Ta-fan,Ta-fan-chen,da fan,da fan zhen,大畈,大畈镇', 29.6588300, 114.6643700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19047, 'Daduo', 'Daduo', 'Daduo,Daduo Zhen,Ta-to,Ta-to-chen,da duo,da duo zhen,大垛,大垛镇', 32.8970600, 120.0340700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19048, 'Dadunqiu', 'Dadunqiu', 'Dadunqiu,Ta-tun-ch''iu,Ta-tun-ch’iu', 39.4061100, 117.0330600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19049, 'Xinshancun', 'Xinshancun', 'Dadukou,Dadukou Qu,Ta-tu-k''ou,Ta-tu-k’ou,Xinshancun,da du kou qu,xin shan cun,大渡口区,新山村', 29.4860000, 106.4786100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19050, 'Daduan', 'Daduan', 'Daduan,Daduan Zhen,Tu-tuan,da duan,da duan zhen,大塅,大塅镇', 28.6583400, 114.5542700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19051, 'Xinxing', 'Xinxing', 'An-tung-hsien,Dadong,Dadungou,Donggang,Donggang Shi,Donggou,Ta-tung,Ta-tung-chen,Ta-tung-kou,Ta-tung-kou-chen,Tatungkow,Tung-kou,Xinxing,dong gang shi,xin xing,东港市,新兴', 39.8669400, 124.1230400, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19052, 'Dadong', 'Dadong', 'Dadong,Dadong Xiang,da dong,da dong xiang,大洞,大洞乡', 29.4882700, 114.9496000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19053, 'Dadian', 'Dadian', 'Dadian,Ta-tien,da dian,大店', 34.7750000, 108.6094400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19054, 'Dadeng', 'Dadeng', 'Dadeng,da deng,大嶝', 24.5438600, 118.3275300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19055, 'Daciyao', 'Daciyao', 'Daciyao,Daciyao Zhen,Ta-tz''u-yao,Ta-tz’u-yao,da ci yao,da ci yao zhen,大磁窑,大磁窑镇', 39.6378400, 113.7291100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19056, 'Dachuan', 'Dachuan', 'Dachuan,Dachuan Zhen,da chuan,da chuan zhen,大川,大川镇', 32.5442800, 110.7025100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19057, 'Yajin', 'Yajin', 'Dachi,Dachi Zhen,Ta-ch''ih,Ta-ch’ih,Yajin,da chi,da chi zhen,ya jin,大池,大池镇,雅金', 25.1260100, 116.7943300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19058, 'Dacheng', 'Dacheng', 'Dacheng,Dacheng Zhen,T''ien-ch''eng-chen,Ta-ch''eng,Ta-ch''eng-chen,Ta-ch’eng,Ta-ch’eng-chen,T’ien-ch’eng-chen,da cheng,大程', 34.6609400, 109.1342000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19059, 'Dacheng', 'Dacheng', 'Dacheng,Dacheng Zhen,Ta-ch''eng,Ta-ch’eng,da cheng,da cheng zhen,大城,大城镇', 28.5382300, 115.5188400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19060, 'Dachen', 'Dachen', 'Dachen,Dachen Zhen,Ta-ch''en,Ta-ch''en-shih,Ta-ch’en,Ta-ch’en-shih,da chen,da chen zhen,大陈,大陈镇', 29.4521000, 120.1252700, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19061, 'Dachang', 'Dachang', 'Dachang,Dachang Zhen,Ta-ch''ang,Ta-ch''ang-chen,Ta-ch’ang,Ta-ch’ang-chen,da chang,da chang zhen,大昌,大昌镇', 31.2686100, 109.8021000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19062, 'Dabu', 'Dabu', 'Dabu,Dabu Xiang,Ta-pu,da bu,da bu xiang,大埠,大埠乡', 25.6929400, 115.0695900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19063, 'Dabu', 'Dabu', 'Dabu,Dabu Zhen,Ta-pu,Ta-pu-chen,Yuanqian,da bu,da bu zhen,yuan qian,达埔,达埔镇,院前', 25.3113900, 118.1633300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19064, 'Dabu', 'Dabu', 'Dabu,Dapu,Liucheng,Ta-p''u-chen,Ta-pu,Ta-p’u-chen,da bu,大埔', 24.6673900, 109.2354700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19065, 'Dabu', 'Dabu', 'Dabu,Dabu Zhen,Ta-pu-hsu,Ta-pu-hsü,Ta-pu-tung,da bu,da bu zhen,大布,大布镇', 24.5333300, 113.1453300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19066, 'Dabizhuang', 'Dabizhuang', 'Dabizhuang,Dabizhuang Zhen,Ta-pi-chuang,Tapi,da bi zhuang,da bi zhuang zhen,大毕庄,大毕庄镇', 39.1930600, 117.2558300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19067, 'Dabao’anzhen', 'Dabao''anzhen', 'Dabao''an,Dabao''anzhen,Dabao’an,Dabao’anzhen,Ta-an-chuang', 39.8994400, 117.4763900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19068, 'Dabaizhuang', 'Dabaizhuang', 'Dabaizhuang,Ta-pai-chuang', 39.4447200, 117.3802800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19069, 'Shuren', 'Shuren', 'Dabaishu,Shuren,Shuren Zhen,Ta-pai-shu,da bai shu,shu ren,shu ren zhen,大柏树,树人,树人镇', 29.9866100, 107.7392300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19070, 'Dabaidi', 'Dabaidi', 'Dabaidi,Dabaidi Xiang,Ta-pai-ti,da bai de,da bai de xiang,大柏地,大柏地乡', 26.1019900, 116.0415600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19071, 'Dabachang', 'Dabachang', 'Dabachang,Ta-pa-ch''ang,Ta-pa-ch’ang', 27.7425000, 108.3433300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19072, 'Daba', 'Daba', 'Daba,Daba Xiang,Ta-pa,da ba,da ba xiang,大坝,大坝乡', 28.9333300, 109.8000000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19073, 'Daba', 'Daba', 'Daba,Daba Zhen,Ta-pa,Ta-sha-pa,da ba,da ba zhen,大坝,大坝镇', 28.0160500, 106.4278800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19074, 'Xiazhi', 'Xiazhi', 'Da''ao,Da’ao,Ta-ao,Xiazhi,Xiazhi Zhen,xia shi,xia shi zhen,虾峙,虾峙镇', 29.7562100, 122.2357200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19075, 'Da’anshan', 'Da''anshan', 'Da''anshan,Da''anshan Xiang,Da’anshan,Da’anshan Xiang,Ta-an-shan,da an shan,da an shan xiang,大安山,大安山乡', 39.8860300, 115.7785600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19076, 'Da’anping', 'Da''anping', 'Da''an Xiang,Da''anping,Da’an Xiang,Da’anping,Ta-an-p''ing,Ta-an-p’ing,da an ping,da an xiang,大安乡,大安坪', 29.5359900, 109.6713900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19077, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Daan''i,Daan’i,Da’an,Da’an Zhen,Ta-an,Ta-an-i,Taanchen,Taanyi,da an,da an zhen,大安,大安镇', 33.0558300, 106.2958300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19078, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Da''anchang,Da’an,Da’an Zhen,Da’anchang,Ta-an,da an,da an zhen,大安,大安镇', 29.3831000, 106.0147600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19079, 'Da’an', 'Da''an', 'Buwei,Da''an,Da''an Xiang,Da’an,Da’an Xiang,Ta-an,Ta-an-ts''un,Ta-an-ts’un,bu wei,da an,da an xiang,埠尾,大安,大安乡', 27.4541700, 119.8816700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19080, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Da’an,Da’an Zhen,Ta-an,Ta-an-hsu,Ta-an-hsü,Taion,da an,da an zhen,大安,大安镇', 23.0682800, 115.6375600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19081, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Da’an,Da’an Zhen,da an,da an zhen,打安,打安镇', 19.2853500, 109.3685400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19082, 'Cuntou', 'Cuntou', 'Cuntou,Cuntou Zhen,Ts''un-t''ou,Ts''un-t''ou-shih,Ts’un-t’ou,Ts’un-t’ou-shih,cun tou,cun tou zhen,村头,村头镇', 29.2650400, 118.4680400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19083, 'Cuntan', 'Cuntan', 'Cuntan,Jiangbei Qu,Ts''un-t''an,Ts’un-t’an,cun tan,jiang bei qu,寸滩,江北区', 29.6024800, 106.5705500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19084, 'Cunqian', 'Cunqian', 'Cunqian,Cunqian Xiang,Ts''un-ch''ien,Ts''un-ch''ien-chieh,Ts’un-ch’ien,Ts’un-ch’ien-chieh,cun qian,cun qian xiang,村前,村前乡', 28.4696800, 115.1318000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19085, 'Cunliji', 'Cunliji', 'Cunliji,Cunliji Zhen,Shih-men-k''ou,Shih-men-k’ou,cun li ji,cun li ji zhen,村里集,村里集镇', 37.5378500, 120.7774200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19086, 'Cuimu', 'Cuimu', 'Cuimu,Cuimu Zhen,Ts''ui-mu,Ts''ui-mu-chen,Tsuymuchzhen'',Tsuymuchzhen’,Ts’ui-mu,Ts’ui-mu-chen,cui mu,cui mu zhen,崔木,崔木镇', 34.8113600, 107.8597400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19087, 'Cuijiaqiao', 'Cuijiaqiao', 'Cuijiaqiao,Cuijiaqiao Zhen,cui jia qiao,cui jia qiao zhen,崔家桥,崔家桥镇', 28.7000000, 112.0000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19088, 'Cuijiang', 'Cuijiang', 'Ch''ing-ning,Ch’ing-ning,Cuijiang,Cuijiang Zhen,Ning-hua-ch''eng-kuan,Ning-hua-ch’eng-kuan,Ning-hua-hsien,Ning-hua-hsien-ch''eng,Ning-hua-hsien-ch’eng,Ninghua,Ninghua Xian,Ninghwa,Ninghwa-hsien,cui jiang,cui jiang zhen,ning hua xian,宁化县,翠江,翠江镇', 26.2632100, 116.6499100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19089, 'Cuijiamatou', 'Cuijiamatou', '', 39.0747200, 117.3005600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19090, 'Cuijiaba', 'Cuijiaba', 'Cuijiaba,Cuijiaba Zhen,Ts''ui-chia-pa,Ts’ui-chia-pa,cui jia ba,cui jia ba zhen,崔家坝,崔家坝镇', 30.5070300, 109.8492600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19091, 'Cuihuangkou', 'Cuihuangkou', 'Cuihuangkou,Ts''ui-huang-chuang,Ts''ui-huang-k''ou,Ts’ui-huang-chuang,Ts’ui-huang-k’ou', 39.5258300, 117.1805600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19092, 'Cuihua', 'Cuihua', 'Cuihua,Daguan,Ta-kuan,Ta-kuan-hsien,Takwan-hsien,cui hua,翠华', 27.7376600, 103.8573800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19093, 'Cizhu', 'Cizhu', 'Cizhu,Cizhu Zhen,Tz''u-chu,Tz’u-chu,ci zhu,ci zhu zhen,茨竹,茨竹镇', 29.9854000, 106.7398200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19094, 'Cizao', 'Cizao', 'Cizao,Cizao Zhen,Tz''u-tsao,Tz’u-tsao,ci zao,ci zao zhen,磁灶,磁灶镇', 24.8203300, 118.4880900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19095, 'Ciyu', 'Ciyu', 'Ciyu,Ciyu Zhen,Tsoyuychzhen,Tsöyuychzhen,Tz''u-yu,Tz''u-yu-chen,Tz’u-yü,Tz’u-yü-chen,ci yu,ci yu zhen,慈峪,慈峪镇', 38.4492200, 114.3132300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19096, 'Ciyantang', 'Ciyantang', 'Ciyantang,Ciyantang Zhen,ci yan tang,ci yan tang zhen,茨岩塘,茨岩塘镇', 29.4147300, 109.5954000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19097, 'Cishangang', 'Cishangang', 'Cishangang,Tz''u-shan-kang,Tz’u-shan-kang,ci shan gang,祠山岗', 30.9098300, 119.5095000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19098, 'Cili', 'Cili', 'Cili,Cili Xian,Lingyang,Lingyang Zhen,Tsu-li,Tz''u-li,Tz''u-li-hsien,Tzeli,Tzeli-hsien,Tz’u-li,Tz’u-li-hsien,ci li,ci li xian,ling yang,ling yang zhen,慈利,慈利县,零阳,零阳镇', 29.4244400, 111.1201300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19099, 'Cikou', 'Cikou', 'Cikou,Cikou Xiang,Tz''u-k''ou,Tz’u-k’ou,ci kou,ci kou xiang,慈口,慈口乡', 29.6889600, 114.7947600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19100, 'Cihukou', 'Cihukou', 'Cihukou,Cihukou Zhen,Tz''u-hu,Tz''u-hu-k''ou,Tz’u-hu,Tz’u-hu-k’ou,ci hu kou,ci hu kou zhen,茈湖口,茈湖口镇', 28.7327800, 112.5505600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19101, 'Cihua', 'Cihua', 'Cihua,Cihua Zhen,Tz''u-hua,Tz’u-hua,ci hua,ci hua zhen,慈化,慈化镇', 28.0122800, 114.0273500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19102, 'Cihu', 'Cihu', 'Cihu,Cihu Xiang,Tz''u-hu,Tz''u-hu-chen,Tzehu,Tz’u-hu,Tz’u-hu-chen,ci hu,ci hu xiang,慈湖,慈湖乡', 31.7412300, 118.5045400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19103, 'Cihe', 'Cihe', 'Cihe,Cihe Zhen,Tz''u-ho,Tz’u-ho,ci he,ci he zhen,茨河,茨河镇', 32.0488400, 111.8376700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19104, 'Cigou', 'Cigou', 'Cigou,Tz''u-kou,Tz’u-kou,ci gou,茨沟', 33.8330500, 113.5827400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19105, 'Cicheng', 'Cicheng', 'Cicheng,Cicheng Zhen,Tsekihsien,Tz''u-ch''eng,Tz''u-ch''eng-chen,Tz''u-ch''i,Tz''u-ch''i-hsien,Tzeki,Tz’u-ch’eng,Tz’u-ch’eng-chen,Tz’u-ch’i,Tz’u-ch’i-hsien,ci cheng,ci cheng zhen,慈城,慈城镇', 29.9823200, 121.4401800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19106, 'Ciba', 'Ciba', 'Ciba,ci ba,茨芭', 34.0788700, 113.0538100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19107, 'Chuzhou', 'Chuzhou', 'Cchu-cou,Ch''u,Ch''u-ch''uan,Ch''u-hsien,Chuchow,Chuchzhou,Chudzhou,Chudzou,Chuju shehiri,Chutsjou,Chuxian,Chuzhou,Ch’u,Ch’u-ch’üan,Ch’u-hsien,Du-ciu,Dṳ̀-ciŭ,Tru Chau,Trừ Châu,Tu-chiu-chhi,Tû-chiu-chhī,chajwa,chu zhou,chu zhou shi,chujeou si,chwzhww,jo zhou shi,Čchu-čou,Чуджоу,Чучжоу,Чуџоу,Չուչժոու,چاجوا,چوژوؤ,چوژوو,ジョ州市,滁州,滁州市,추저우 시', 32.3219400, 118.2977800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19108, 'Chushan', 'Chushan', 'Ch''u-shan-chai,Chushan,Chushan Zhen,Ch’u-shan-chai,chu shan,chu shan zhen,出山,出山镇', 33.2954800, 113.6528000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19109, 'Chunxi', 'Chunxi', 'Ch''un-hsi,Chunxi,Chunxi Zhen,Ch’un-hsi,Gaochun Xian,Kao-ch''un,Kao-ch’un,Kao-shun,Kao-shun-hsien,chun xi,chun xi zhen,gao chun xian,淳溪,淳溪镇,高淳县', 31.3276900, 118.8748900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19110, 'Chunwan', 'Chunwan', 'Ch''un-wan-hsu,Chunwan,Chunwan Zhen,Ch’un-wan-hsü,chun wan,chun wan zhen,春湾,春湾镇', 22.4391400, 111.9308500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19111, 'Chunshui', 'Chunshui', 'Ch''un-shui-chen,Chun''shuy,Chunshui,Chunshui Zhen,Chun’shuy,Ch’un-shui-chen,chun shui,春水', 33.0326400, 113.4579600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19112, 'Chunhua', 'Chunhua', 'Chengguan Zhen,Chunhua,Chunhwa,Chunhwa-hsien,Shun-hua,Shun-hua-hsien,Shun-hua-hsien-ch''eng,Shun-hua-hsien-ch’eng,Shunhwahsien,cheng guan zhen,chun hua,城关镇,淳化', 34.7988900, 108.5750000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19113, 'Chunhu', 'Chunhu', 'Chunhu,Chunhu Zhen,Tsun-hu-chen,chun hu,chun hu zhen,莼湖,莼湖镇', 29.5786100, 121.5155600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19114, 'Chunchi', 'Chunchi', 'Ch''un-ch''ih,Chunchi,Chunchi Zhen,Ch’un-ch’ih,chun chi,chun chi zhen,纯池,纯池镇', 27.2439900, 119.3131600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19115, 'Yangchun', 'Yangchun', 'Ch''un-ch''eng-chen,Chuncheng,Ch’un-ch’eng-chen,Yang-ch''un-hsien,Yang-ch’un-hsien,Yangchun,Yeungchun,yang chun,阳春', 22.1666700, 111.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19116, 'Chumi', 'Chumi', 'Ch''u-mi-p''u,Chumi,Chumi Zhen,Ch’u-mi-p’u,chu mi,chu mi zhen,楚米,楚米镇', 28.2336100, 106.8327800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19117, 'Chumen', 'Chumen', 'Ch''u-men-chen,Chumen,Chumen Zhen,Ch’u-men-chen,chu men,chu men zhen,楚门,楚门镇', 28.2196400, 121.2934300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19118, 'Chuimatan', 'Chuimatan', 'Chuimatan,Chuimatan Zhen,Jishishan Bonanzu Dongxiangzu,chui ma tan,chui ma tan zhen,ji shi shan bao an zu dong xiang zu,吹麻滩,吹麻滩镇,积石山保安族东乡族', 35.7181000, 102.8740700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19119, 'Zhiqing Songduo', 'Zhiqing Songduo', 'Chih-ch''ing-sung-to,Chih-ch’ing-sung-to,Chiu-chih,Chugqensumdo,Chugqênsumdo,Jigzhi,Jiuzhi,Jiuzhi Xian,Zhiqing Songduo,Zhiqing Songduo Zhen,jiu zhi,jiu zhi xian,zhi qing song duo,zhi qing song duo zhen,久治,久治县,智青松多,智青松多镇', 33.4333300, 101.4333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19120, 'Chuandian', 'Chuandian', 'Ch''uan-hsin-tien,Chuandian,Chuandian Zhen,Chuanxindian,Ch’uan-hsin-tien,chuan dian,chuan dian zhen,川店,川店镇', 30.5905100, 112.0735900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19121, 'Chuantang', 'Chuantang', 'Chuantang,Chuantang Zhen,chuan tang,chuan tang zhen,船塘,船塘镇', 24.1590800, 114.9398900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19122, 'Chuantan', 'Chuantan', 'Chuantan,Chuantan Zhen,chuan tan,chuan tan zhen,船滩,船滩镇', 29.2395800, 114.6715600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19123, 'Chuanshan', 'Chuanshan', 'Chuanshan,Chuanshan Xiang', 25.0666700, 108.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19124, 'Chuanliao', 'Chuanliao', 'Ch''uan-liao-shih,Chuanliao,Chuanliao Zhen,Ch’uan-liao-shih,chuan liao,chuan liao zhen,船寮,船寮镇', 28.2582200, 120.2118400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19125, 'Dengzishan', 'Dengzishan', 'Chuanjie,Dengzishan,chuan jie,川街', 24.8985800, 102.0451800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19126, 'Chuangang', 'Chuangang', 'Ch''uan-chiang,Ch''uan-chiang-chen,Ch''uan-kang,Chuangang,Chuangang Zhen,Ch’uan-chiang,Ch’uan-chiang-chen,Ch’uan-kang,chuan gang,chuan gang zhen,川港,川港镇', 31.9278800, 121.0636600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19127, 'Chuanbu', 'Chuanbu', 'Ch''uan-pu,Ch''uan-pu-hsu,Chuanbu,Chuanbu Zhen,Ch’uan-pu,Ch’uan-pu-hsü,Shunpo,Shünpo,chuan bu,chuan bu zhen,船步,船步镇', 22.5915700, 111.6220500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19128, 'Yiwu', 'Yiwu', 'Choucheng,I-wu,I-wu-hsien,Iu,YIW,Yiwu,Yiwuhsien,yi wu,yi wu xian,Иу,义乌,義烏縣', 29.3150600, 120.0767600, 'CN', '2017-04-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19129, 'Chongxing', 'Chongxing', 'Chongxing,Chongxing Zhen,Chung-hsing,Chung-hsing-shih,zhong xing,zhong xing zhen,重兴,重兴镇', 19.4131700, 110.5955600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19130, 'Chongxian', 'Chongxian', 'Ch''ung-hsien,Ch''ung-hsien-hsu,Chongxian,Chongxian Xiang,Ch’ung-hsien,Ch’ung-hsien-hsü,chong xian,chong xian xiang,崇贤,崇贤乡', 26.5488900, 115.3438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19131, 'Chongru', 'Chongru', 'Ch''ung-ju,Chongru,Ch’ung-ju', 26.9511100, 119.9252800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19132, 'Chongren', 'Chongren', 'Ch''ung-jen,Ch''ung-jen-chen,Chongren,Chongren Zhen,Ch’ung-jen,Ch’ung-jen-chen,chong ren,chong ren zhen,崇仁,崇仁镇', 29.6093300, 120.7052400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19133, 'Chongqing', 'Chongqing', 'CKG,Cchung-cching,Ch''ung-ch''ing,Ch''ung-ch''ing-shih,Chongqing,Chongqing - zhong qing,Chongqing - 重庆,Chongqing Shi,Chuncin,Chungking,Ch’ung-ch’ing,Ch’ung-ch’ing-shih,Congcing,Congcingas,Congcingo,Csungking,Cuncjina,Pa,Pa-hsien,Trung Khanh,Trùng Khánh,Tshung-khin,Tshùng-khin,Tsjoengking,Yu-chou,Yuzhou,Yü-chou,caungakiga,ceancin,chng ching,chungching si,chwng kyng,chwngchng,congachinga,congkinga,conkin,tshwnghtshyngh,z''wngz''yng,zhong qing,zhong qing shi,Çongçing,Ĉongĉingo,Čchung-čching,Čongčingas,Čuncjina,Чунгкинг,Чунцин,Чунцін,צ''ונגצ''ינג,تشونغتشينغ,چونگ کینگ,چونگچنگ,چونگ‌کینگ,چۇڭچىڭ شەھىرى,चोंगछिंग,चोंग्किंग,ਚੌਂਗਕਿੰਗ,சோங்கிங்,ചോങ്ചിങ്,ฉงชิ่ง,ཁྲུང་ཆིན་གྲོང་ཁྱེར།,重庆,重庆市,重慶,重慶市,충칭 시', 29.5627800, 106.5527800, 'CN', '2014-07-31', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19134, 'Chongning', 'Chongning', 'Ch''ung-ning,Ch''ung-ning-chen,Chongning,Chongning Zhen,Ch’ung-ning,Ch’ung-ning-chen,chong ning,崇凝', 34.3822600, 109.5862300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19135, 'Chonglou', 'Chonglou', 'Ch''ung-lou,Ch''ung-lou-hsu,Ch''ung-wei-hsu,Cheung-kok,Chonglou,Chonglou Zhen,Chunglaw,Chunglow,Chunglu,Chunglü,Ch’ung-lou,Ch’ung-lou-hsü,Ch’ung-wei-hsü,chong lou,chong lou zhen,冲蒌,冲蒌镇', 22.1294800, 112.8074700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19136, 'Chonglong', 'Chonglong', 'Chonglong,Tzechow,Tzechung,Tzechung-hsien,Tzu-chou,Tzu-chung,Tzu-chung-hsien,Zizhong,zhong long,重龙', 29.7806200, 104.8522400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19137, 'Chongkan', 'Chongkan', 'Chongkan,Chongkan Zhen,Guanghui,chong kan,chong kan zhen,guang hui,光辉,崇龛,崇龛镇', 30.1555900, 105.6122200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19138, 'Chonggu', 'Chonggu', 'Ch''ung-ku-chen,Chonggu,Chonggu Zhen,Chung-ku,Ch’ung-ku-chen,zhong gu,zhong gu zhen,重固,重固镇', 31.2036100, 121.1705600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19139, 'Chongfu', 'Chongfu', 'Ch''ung-fu-chen,Ch''ung-te,Ch''ung-te-chen,Ch''ung-te-hsien,Ch''ung-te-hsien-ch''eng,Chongde,Chongfu,Chongfu Zhen,Ch’ung-fu-chen,Ch’ung-te,Ch’ung-te-chen,Ch’ung-te-hsien,Ch’ung-te-hsien-ch’eng,Shih-men,Tsungteh,chong fu,chong fu zhen,崇福,崇福镇', 30.5311300, 120.4309000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19140, 'Chizhou', 'Chizhou', 'Ch''ih-chou,Ch''ih-chou-chen,Chichau,Chih-chow-fu,Chihchow,Chizhou,Chizhou Shi,Ch’ih-chou,Ch’ih-chou-chen,Guichi,JUH,Kuei-ch''ih,Kuei-ch''ih-hsien,Kuei-ch’ih,Kuei-ch’ih-hsien,Kweichih,Kweichih-hsien,Kweighih,Tche Tcheou,chi zhou,chi zhou shi,池州,池州市', 30.6613400, 117.4778300, 'CN', '2014-11-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19141, 'Chiyuan', 'Chiyuan', 'Ch''ih-yuan,Ch''ih-yuan-chieh,Chiyuan,Chiyuan Zhen,Ch’ih-yüan,Ch’ih-yüan-chieh,chi yuan,chi yuan zhen,池园,池园镇', 26.0979600, 118.6782900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19142, 'Chixi', 'Chixi', 'Ch''ih-hsi,Chixi,Chixi Xiang,Ch’ih-hsi,chi xi,chi xi xiang,池溪,池溪乡', 28.3970800, 116.4197800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19143, 'Chixi', 'Chixi', 'Ch''ih-ch''i,Chixi,Ch’ih-ch’i', 26.9111100, 119.4830600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19144, 'Chixi', 'Chixi', 'Ch''ih-hsi,Chixi,Chixi Xiang,Ch’ih-hsi,chi xi,chi xi xiang,赤锡,赤锡乡', 25.7810100, 118.8553500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19145, 'Chiwei', 'Chiwei', 'Ch''ih-wei,Chiwei,Chiwei Jiedao,Ch’ih-wei,chi wei,chi wei jie dao,池尾,池尾街道', 23.2993700, 116.1365900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19146, 'Chishui', 'Chishui', 'Ch''ih-shui,Ch''ih-shui-chen,Chishui,Chishui Zhen,Ch’ih-shui,Ch’ih-shui-chen,chi shui,赤水', 34.5072300, 109.6424400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19147, 'Chishui', 'Chishui', 'Ch''ih-shui,Chishui,Chishui Zhen,Ch’ih-shui,chi shui,chi shui zhen,赤水,赤水镇', 26.7012600, 116.3629000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19148, 'Chishui', 'Chishui', 'Ch''ih-shui,Chishui,Chishui Zhen,Ch’ih-shui,chi shui,chi shui zhen,赤水,赤水镇', 25.6452600, 118.1275900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19149, 'Chishui', 'Chishui', 'Chishui,Chishui Zhen,chi shui,chi shui zhen,赤水,赤水镇', 25.5991700, 117.2894400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19150, 'Chishui', 'Chishui', 'Ch''ih-shui,Ch''ih-shui-hsu,Chikshui,Chishui,Ch’ih-shui,Ch’ih-shui-hsü,chi shui,赤水', 22.1406300, 112.5874500, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19151, 'Chishi', 'Chishi', 'Chishi,Chishi Zhen,chi shi,chi shi zhen,赤石,赤石镇', 22.8724600, 115.0773100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19152, 'Chishan', 'Chishan', 'Ch''ih-shan-chi,Chishan,Chishan Zhen,Chishanji,Ch’ih-shan-chi,chi shan,chi shan zhen,斥山,斥山镇', 36.9333300, 122.3877800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19153, 'Chini', 'Chini', 'Ch''ih-ni,Chini,Chini Zhen,Ch’ih-ni,chi ni,chi ni zhen,赤坭,赤坭镇', 23.4001400, 112.9988800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19154, 'Chikeng', 'Chikeng', 'Chikeng,Chikeng Zhen,chi keng,chi keng zhen,赤坑,赤坑镇', 22.8533500, 115.4591700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19155, 'Chikan', 'Chikan', 'Ch''ih-k''an,Chikan,Chikan Zhen,Ch’ih-k’an,chi kan,chi kan zhen,赤坎,赤坎镇', 22.3229000, 112.5815600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19156, 'Chikan', 'Chikan', 'Ch''ih-k''an,Chekam,Chekan,Chekham,Chikan,Chikan Qu,Chikhom,Ch’ih-k’an,Tche Kam,Tchia-k''am,Tchia-k’am,chi kan,chi kan qu,赤坎,赤坎区', 21.2711600, 110.3590600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19157, 'Chitu', 'Chitu', 'Ch''ih-chien-t''an,Ch''ih-hsien-t''an,Chijiantan,Chitu,Ch’ih-chien-t’an,Ch’ih-hsien-t’an,chi tu,赤土', 39.2033300, 117.4027800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19158, 'Chiguang', 'Chiguang', 'Chiguang,Chiguang Zhen,chi guang,chi guang zhen,赤光,赤光镇', 24.3858300, 115.4306800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19159, 'Chigan', 'Chigan', 'Ch''ih-kan,Ch''ih-kan-chen,Chigan,Chigan Zhen,Ch’ih-kan,Ch’ih-kan-chen,chi gan,chi gan zhen,叱干,叱干镇', 34.7077800, 108.4325000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19160, 'Zoumaling', 'Zoumaling', 'Chidong,Chidong Zhen,Zoumaling,chi dong,chi dong zhen,zou ma ling,赤东,赤东镇,走马岭', 30.2123500, 115.4268400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19161, 'Chidong', 'Chidong', 'Ch''ih-tung,Ch''ih-tung-hsu,Chidong,Chidong Zhen,Ch’ih-tung,Ch’ih-tung-hsü,chi dong,chi dong zhen,池垌,池洞镇', 22.4276000, 110.9470200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19162, 'Chicheng', 'Chicheng', 'Chicheng,Feng-chi,Fontsi,Fyntsi,P''eng-ch''i,P''eng-ch''i-hsien,P''eng-hsi,Pengki,Pengki-hsien,Pengxi,P’eng-ch’i,P’eng-ch’i-hsien,P’eng-hsi,chi cheng,赤城', 30.7793600, 105.7121400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19163, 'Chibi', 'Chibi', 'Ch''ih-pi,Chibi,Chibi Zhen,Ch’ih-pi,chi bi,chi bi zhen,赤壁,赤壁镇', 29.8783200, 113.6250600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19164, 'Chiba', 'Chiba', 'Chiba,chi ba,池坝', 33.6465700, 104.7822400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19165, 'Chi’an', 'Chi''an', 'Ch''ih-an,Ch''ih-an-shih,Chi''an,Chi''an Zhen,Chi’an,Chi’an Zhen,Ch’ih-an,Ch’ih-an-shih,chi an,chi an zhen,赤岸,赤岸镇', 29.1450100, 120.0303600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19166, 'Chexi', 'Chexi', 'Chexi,Chexi Xiang,Chexihe,che xi,che xi he,che xi xiang,车溪,车溪乡,车溪河', 29.7168900, 111.6908100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19167, 'Chetou', 'Chetou', 'Chetou,Chetou Xiang,che tou,che tou xiang,车头,车头乡', 25.1939400, 115.3322100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19168, 'Chetian', 'Chetian', 'Chetian,Chetiean Xiang,che tian,che tian xiang,车田,车田乡', 29.1418300, 109.0460900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19169, 'Chetian', 'Chetian', 'Ch''e-t''ien-hsu,Chetian,Chetian Zhen,Ch’e-t’ien-hsü,che tian,che tian zhen,车田,车田镇', 24.4336000, 115.2863400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19170, 'Chenzui', 'Chenzui', 'Chenzui,Chenzui Zhen,chen ju,chen ju zhen,陈咀,陈咀镇', 39.2853000, 116.9857400, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19171, 'Chenzhuang', 'Chenzhuang', 'Ch''en-chuang,Ch''en-chuang-chen,Chenzhuang,Chenzhuang Zhen,Ch’en-chuang,Ch’en-chuang-chen,chen zhuang,chen zhuang zhen,陈庄,陈庄镇', 38.5694000, 114.0986400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19172, 'Chenzhuang', 'Chenzhuang', 'Chenzhuang,Chenzhuang Zhen,chen zhuang,陈庄', 34.8722400, 109.6038400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19173, 'Chenzhuang', 'Chenzhuang', 'Chenzhuang,chen zhuang,陈庄', 32.6564500, 113.2976500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19174, 'Chenzhou', 'Chenzhou', 'Ch''en,Ch''en-chou-shih,Ch''en-hsien,Chehn''chzhou,Chenchow,Chenzhou,Ch’en,Ch’en-chou-shih,Ch’en-hsien,LQP,chen zhou,Чэньчжоу,郴州', 25.8000000, 113.0333300, 'CN', '2014-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19175, 'Chenying', 'Chenying', 'Ch''en-ying-chen,Ch''en-ying-chieh,Chenying,Chenying Zhen,Ch’en-ying-chen,Ch’en-ying-chieh,Wan-nien,Wannian,Wannian Xian,chen ying,chen ying zhen,wan nian xian,万年县,陈营,陈营镇', 28.6929000, 117.0673200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19176, 'Chenyang', 'Chenyang', 'Ch''en-ch''i,Ch''en-ch''i-hsien,Ch''en-hsi,Chenki,Chenki-hsien,Chenxi,Chenxi Xian,Chenyang,Ch’en-ch’i,Ch’en-ch’i-hsien,Ch’en-hsi,chen xi xian,chen yang,辰溪县,辰阳', 28.0158100, 110.1729800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19177, 'Chenxiang', 'Chenxiang', 'Ch''en-chia-hsiang,Chenxiang,Chenxiang Zhen,Ch’en-chia-hsiang,chen xiang,chen xiang zhen,陈巷,陈巷镇', 31.4798100, 113.7674400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19178, 'Chenjin', 'Chenjin', 'Chenjin,Chenjin Xiang,chen jin,chen jin xiang,陈靳,陈靳乡', 35.5666700, 106.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19179, 'Chenjiatan', 'Chenjiatan', 'Chenjiatan,Chenjiatan Xiang,chen jia tan,chen jia tan xiang,陈家滩,陈家滩乡', 28.6833300, 110.7500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19180, 'Chenjiang', 'Chenjiang', 'Ch''en-chiang,Chenjiang,Chenjiang Jiedao,Ch’en-chiang,chen jiang,chen jiang jie dao,陈江,陈江街道', 23.0292100, 114.3049200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19181, 'Chenjiahe', 'Chenjiahe', 'Chenjiahe,Chenjiahe Zhen,chen jia he,chen jia he zhen,陈家河,陈家河镇', 29.4860700, 109.9767200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19182, 'Chenjiagang', 'Chenjiagang', 'Ch''en-chia-chiang,Ch''en-chia-kang,Chenjiagang,Chenjiagang Zhen,Chenkiakiang,Ch’en-chia-chiang,Ch’en-chia-kang,chen jia gang,chen jia gang zhen,陈家港,陈家港镇', 34.3786100, 119.8030600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19183, 'Chendian', 'Chendian', 'Ch''en-chia-tien,Chendian,Chendian Xiang,Chenjiadian,Ch’en-chia-tien,chen dian,chen dian xiang,陈店,陈店乡', 31.2683400, 113.8179600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19184, 'Chendian', 'Chendian', 'Ch''en-chia-tien,Chendian,Chendian Zhen,Chenjiadian,Ch’en-chia-tien,chen dian,chen dian zhen,陈店,陈店镇', 30.2671900, 111.6414900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19185, 'Chenji', 'Chenji', 'Ch''en-chi,Chenji,Chenji Zhen,Ch’en-chi,chen ji,chen ji zhen,陈集,陈集镇', 34.1833300, 119.3833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19186, 'Chenji', 'Chenji', 'Ch''en-chi,Ch''en-chia-chi,Chenji,Chenji Zhen,Ch’en-chi,Ch’en-chia-chi,chen ji,chen ji zhen,陈集,陈集镇', 32.4854700, 119.1850000, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19187, 'Chengzi', 'Chengzi', 'Ch''eng-tzu,Chengzi,Chengzi Jiedao,Ch’eng-tzu,cheng zi,cheng zi jie dao,城子,城子街道', 39.9510900, 116.0891000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19188, 'Chengzhong', 'Chengzhong', 'Chengzhong,Ning-ming-hsien,Ningming,cheng zhong,城中', 22.1682400, 107.0073000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19189, 'Chengyue', 'Chengyue', 'Ch''eng-yueh,Ch''eng-yueh-shih,Chengyue,Chengyue Zhen,Ch’eng-yüeh,Ch’eng-yüeh-shih,Shinguet,Shingyueh,Shingyuet,cheng yue,cheng yue zhen,城月,城月镇', 21.1667900, 110.0721400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19190, 'Chengyuan', 'Chengyuan', 'Chengyuan,Chengyuan Xiang,cheng yuan,cheng yuan xiang,澄源,澄源乡', 27.3205600, 119.1550000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19191, 'Chengyang', 'Chengyang', 'Chengyang,Chengyang Jiedao,cheng yang,cheng yang jie dao,城阳,城阳街道', 36.3116700, 120.3758300, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19192, 'Chengyang', 'Chengyang', 'Chengyang,Chengyang Xiang,cheng yang,cheng yang xiang,城阳,城阳乡', 35.8166700, 106.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19193, 'Chengyang', 'Chengyang', 'Chengyang,Chu,Chu-hsien,Chuchow,Chü,Chü-hsien,Chüchow,Juxian', 35.5794400, 118.8327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19194, 'Chengxian Chengguanzhen', 'Chengxian Chengguanzhen', 'Ch''eng,Ch''eng-hsien,Chengguan Zhen,Chengxian,Chengxian Chengguanzhen,Chensyan'',Chensyan’,Ch’eng,Ch’eng-hsien,cheng guan zhen,cheng xian,cheng xian cheng guan zhen,城关镇,成县,成县城关镇', 33.7411100, 105.7205600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19195, 'Chengxi', 'Chengxi', 'Ch''eng-hsi,Chengxi,Chengxi Zhen,Ch’eng-hsi,cheng xi,cheng xi zhen,澄溪,澄溪镇', 30.2092100, 107.2589000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19196, 'Chengwu', 'Chengwu', 'Ch''eng-wu-hsien,Chengwu,Ch’eng-wu-hsien,cheng wu,成武', 34.9540700, 115.8841900, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19197, 'Chengui', 'Chengui', 'Chengui,Chengui Zhen,chen gui,chen gui zhen,陈贵,陈贵镇', 30.0500000, 114.8000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19198, 'Chenguantun', 'Chenguantun', 'Ch''en-kuan-t''un,Chenguantun,Chenguantun Zhen,Ch’en-kuan-t’un,chen guan tun,chen guan tun zhen,陈官屯,陈官屯镇', 38.8196300, 116.9057000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19199, 'Chenguang', 'Chenguang', 'Chenguang,Chenguang Zhen,chen guang,chen guang zhen,晨光,晨光镇', 24.8075900, 115.4773400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19200, 'Chengtougu', 'Chengtougu', 'Ch''eng-t''ou-ku,Chengtougu,Ch’eng-t’ou-ku', 39.1400000, 117.7788900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19201, 'Chengtang', 'Chengtang', 'Chengtang,Chengtang Zhen,cheng tang,cheng tang zhen,澄塘,澄塘镇', 28.4231200, 114.9143700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19202, 'Chengtan', 'Chengtan', 'Chengtan,Chengtan Zhen,cheng tan,cheng tan zhen,澄潭,澄潭镇', 29.4487700, 120.7901200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19203, 'Langchi', 'Langchi', 'Chengshou,Inshan'',Inshan’,Langchi,Ying-shan-hsien,Yingshan,lang chi,朗池', 31.0795200, 106.5651400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19204, 'Chengshang', 'Chengshang', 'Chengshang,Chengshang Xiang,cheng shang,cheng shang xiang,城上,城上乡', 27.6792800, 115.6464800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19205, 'Chengfeng', 'Chengfeng', 'Chengfeng,Chengfeng Xiang,Chengshan,cheng feng,cheng feng xiang,城丰,城丰乡', 28.9385900, 115.7087600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19206, 'Chengnanzhuang', 'Chengnanzhuang', 'Ch''en-nan-chuang,Ch''eng-nan-chuang,Chengnanzhuang,Chengnanzhuang Zhen,Ch’en-nan-chuang,Ch’eng-nan-chuang,cheng nan zhuang,cheng nan zhuang zhen,城南庄,城南庄镇', 38.7343100, 114.1665900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19207, 'Chengmagang', 'Chengmagang', 'Ch''eng-ma-kang,Chengmagang,Chengmagang Zhen,Ch’eng-ma-kang,cheng ma gang,cheng ma gang zhen,乘马岗,乘马岗镇', 31.3527300, 114.9800700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19208, 'Chenglong', 'Chenglong', 'Chenglong,Chenlong Zhen,cheng long,cheng long zhen,程龙,程龙镇', 24.8335300, 114.6771500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19209, 'Chengkou', 'Chengkou', 'Chengkou,Chengkou Zhen,cheng kou,cheng kou zhen,城口,城口镇', 25.3217300, 113.7396500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19210, 'Chengjia', 'Chengjia', 'Ch''en-chia-shih,Ch''eng-chia-shih,Chengjia,Chengjia Shi,Chengjiashi,Ch’en-chia-shih,Ch’eng-chia-shih,Guangping,Kuang-p''ing,Kuang-p’ing,cheng jia,cheng jia shi,程家,程家市', 31.9114800, 118.0826200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19211, 'Chengqiao', 'Chengqiao', 'Ch''eng-chia-ch''iao,Chengjiaqiao,Chengqiao,Chengqiao Zhen,Ch’eng-chia-ch’iao,cheng qiao,cheng qiao zhen,程桥,程桥镇', 32.3861900, 118.7235700, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19212, 'Chengjiang', 'Chengjiang', 'Ch''eng-chiang-chen,Chengjiang,Chengjiang Zhen,Ch’eng-chiang-chen,cheng jiang,cheng jiang zhen,澄江,澄江镇', 29.8719400, 106.3846700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19213, 'Jiangyin', 'Jiangyin', 'Chengjiang,Chengjiang Jiedao,Chiang-yin,Chiang-yin-ch''eng,Chiang-yin-ch’eng,Chiang-yin-hsien,Jiangyin,Jiangyin Shi,Kiang Ying,Kiangyin,cheng jiang,cheng jiang jie dao,jiang yin shi,江阴市,澄江,澄江街道', 31.9110200, 120.2630200, 'CN', '2014-11-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19214, 'Chengjiang', 'Chengjiang', 'Chengjiang,T''ai-ho,T''ai-ho-hsien,T''ai-ho-hsien-ch''eng,Taihe,Taihe Xian,T’ai-ho,T’ai-ho-hsien,T’ai-ho-hsien-ch’eng,cheng jiang,tai he xian,泰和县,澄江', 26.8017100, 114.8997800, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19215, 'Chengjiang', 'Chengjiang', 'Ch''eng-chiang,Ch''eng-chiang-ch''iao,Ch''eng-chiang-hsu,Ch''eng-wang,Chengjiang,Chengjiang Zhen,Ch’eng-chiang,Ch’eng-chiang-ch’iao,Ch’eng-chiang-hsü,Ch’eng-wang,cheng jiang,cheng jiang zhen,澄江,澄江镇', 25.0612000, 115.7201900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19216, 'Chengjiang', 'Chengjiang', 'Ch''eng-chiang,Ch''eng-chiang-hsu,Chengjiang,Chengjiang Zhen,Ch’eng-chiang,Ch’eng-chiang-hsü,cheng jiang,cheng jiang zhen,澄江,澄江镇', 24.9179300, 114.3356300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19217, 'Chengjia', 'Chengjia', 'Ch''eng-chia,Ch''eng-chia-hsu,Chengjia,Chengjia Yaozhuxiang,Chengjiayaozuxiang,Ch’eng-chia,Ch’eng-chia-hsü,cheng jia,cheng jia yao zu xiang,秤架,秤架瑶族乡', 24.7699400, 112.7989700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19218, 'Chenghe', 'Chenghe', 'Ch''eng-chia-ho,Chenghe,Chenghe Zhen,Ch’eng-chia-ho,cheng he,cheng he zhen,程河,程河镇', 32.2935100, 112.4314900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19219, 'Chengguo', 'Chengguo', 'Chengguo,Chengguo Zhen,Chengguozhuang,cheng guo,cheng guo zhen,城郭,城郭镇', 37.2223900, 119.9907700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19220, 'Chenggang', 'Chenggang', 'Ch''eng-kang,Chenggang,Chenggang Xiang,Ch’eng-kang,cheng gang,cheng gang xiang,城冈,城冈乡', 26.5090200, 115.4875600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19221, 'Chengfangqiao', 'Chengfangqiao', 'Chengfangqiao,Panjiang,Panjiang Xiang,cheng fang qiao,pan jiang,pan jiang xiang,城方桥,盘江,盘江乡', 25.7572500, 103.8310400, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19222, 'Chengdu', 'Chengdu', 'CTU,Ccheng-tu,Cendu,Cengdu,Cengduo,Ch''eng-tu,Ch''eng-tu-hsien,Ch''eng-tu-shih,Chehndu,Chendu,Chengdu,Chengdu Shi,Chengdú,Chundu,Chөndү,Ch’eng-tu,Ch’eng-tu-hsien,Ch’eng-tu-shih,Csengtu,Cwngzduh,Hua-yang,Sang-tu-su,Seng-to-chhi,Sing-du,Sàng-tû-sṳ,Sêng-to͘-chhī,Sìng-dŭ,Thanh Do,Thành Đô,Tsen''nkntou,Txengdu,cengadu,centu,chantu,cheing tu,cheng dou,cheng dou shi,cheongdu si,chngdw,chyngdw,chېngdۇ shەھyr,tshnghdw,zngdw,Çengdu,Ĉengduo,Čcheng-tu,Čendu,Čengdu,Τσενγκντού,Ченгду,Ченду,Чънду,Чыңду,Чэнду,Чөндү,Չենդու,צנגדו,تشنغدو,چنگدو,چینگدو,چېڭدۇ شەھىر,चेंगदू,छंतू,ਚੇਂਗਦੂ,செங்டூ,เฉิงตู,ချင်းဒူမြို့,成都,成都市,청두 시', 30.6666700, 104.0666700, 'CN', '2014-07-31', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19223, 'Chengcunjiang', 'Chengcunjiang', 'Ch''eng-ts''un-chiang,Chengcunjiang,Chengcunjiang Xiang,Ch’eng-ts’un-chiang,cheng cun jiang,cheng cun jiang xiang,呈村降,呈村降乡', 29.8895700, 118.5376700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19224, 'Chengcun', 'Chengcun', 'Ch''eng-ts''un,Ch''eng-ts''un-hsu,Chengcun,Chengcun Zhen,Ch’eng-ts’un,Ch’eng-ts’un-hsü,cheng cun,cheng cun zhen,程村,程村镇', 21.8037900, 111.7052900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19225, 'Chenghua', 'Chenghua', 'Ch''eng-hai-hsien,Chengcheng,Chenghai,Chenghua,Ching hai,Ch’eng-hai-hsien,Tenghai,Tenghai-hsien,Tsai-ch''eng-chen,Tsai-ch’eng-chen,cheng hai,cheng hua,澄华,澄海', 23.4613200, 116.7700700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19226, 'Chenfang', 'Chenfang', 'Ch''en-k''eng,Chenfang,Chenfang Xiang,Ch’en-k’eng,Tung-fang,chen fang,chen fang xiang,陈坊,陈坊乡', 28.0522500, 117.5402900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19227, 'Chen’er', 'Chen''er', 'Ch''en-erh-p''u,Chen''er,Chen''er Xiang,Chen''erpu,Chen’er,Chen’er Xiang,Chen’erpu,Ch’en-erh-p’u,chen er,chen er pu,chen er xiang,陈二,陈二乡,陈二铺', 29.3437200, 111.6186300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19228, 'Chendong', 'Chendong', 'Ch''en-tung,Chendong,Chendong Xiang,Ch’en-tung,chen dong,chen dong xiang,陈东,陈东乡', 24.7201400, 116.9104900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19229, 'Chendai', 'Chendai', 'Ch''en-tai,Chendai,Chendai Zhen,Ch’en-tai,chen dai,陈岱', 23.7946500, 117.4013300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19230, 'Chencun', 'Chencun', 'Ch''en-ts''un,Ch''en-ts''un-chiu-hsu,Ch''en-ts''un-hsu,Chanchuen,Chencun,Chencun Zhen,Ch’en-ts’un,Ch’en-ts’un-chiu-hsü,Ch’en-ts’un-hsü,chen cun,chen cun zhen,陈村,陈村镇', 22.9643300, 113.2196700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19231, 'Chencheng', 'Chencheng', 'Chencheng,Chencheng Zhen,chen cheng,陈城', 23.5948600, 117.3828300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19232, 'Chencai', 'Chencai', 'Ch''en-ts''ai,Ch''en-ts''ai-shih,Chencai,Chencai Zhen,Ch’en-ts’ai,Ch’en-ts’ai-shih,chen cai,chen cai zhen,陈蔡,陈蔡镇', 29.5844500, 120.3773800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19233, 'Cheluo', 'Cheluo', 'Ch''e-lo,Ch''e-lo-chen,Ch''e-lo-pa,Cheluo,Cheluo Zhen,Ch’e-lo,Ch’e-lo-chen,Ch’e-lo-pa,che luo,che luo zhen,车逻,车逻镇', 32.7157600, 119.4501900, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19234, 'Chegang', 'Chegang', 'Ch''e-kang,Ch''e-kang-hsu,Chegang,Chegang Zhen,Ch’e-kang,Ch’e-kang-hsü,che gang,che gang zhen,车岗,车岗镇', 22.7771000, 112.2360400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19235, 'Chedun', 'Chedun', 'Ch''e-tun,Ch''e-tun-chen,Chedun,Chedun Zhen,Ch’e-tun,Ch’e-tun-chen,che dun,che dun zhen,车墩,车墩镇', 31.0186600, 121.3077500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19236, 'Checun', 'Checun', 'Ch''e-ts''un,Checun,Checun Zhen,Ch’e-ts’un,che cun,che cun zhen,车村,车村镇', 33.7963100, 112.1166600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19237, 'Chebu', 'Chebu', 'Chebu,Chebu Zhen,che bu,che bu zhen,车埠,车埠镇', 29.7687800, 113.7606300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19238, 'Chayuan', 'Chayuan', 'Ch''a-yuan-kang,Chayuan,Chayuan Xiang,Ch’a-yüan-kang,cha yuan,cha yuan xiang,茶园,茶园乡', 26.4774600, 115.1605900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19239, 'Chayang', 'Chayang', 'Chayang,Chayang Zhen,cha yang,cha yang zhen,茶阳,茶阳镇', 24.5191200, 116.6769200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19240, 'Chatian', 'Chatian', 'Ch''a-t''ien,Ch''a-t''ien-shih,Chatian,Chatian Zhen,Ch’a-t’ien,Ch’a-t’ien-shih,cha tian,cha tian zhen,查田,查田镇', 27.8786100, 118.9875000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19241, 'Chatian', 'Chatian', '', 27.8022200, 109.3736100, 'CN', '2002-04-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19242, 'Chashan', 'Chashan', 'Chashan,Chashan Zhen,cha shan,茶山', 23.0695600, 113.8690000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19243, 'Chaping', 'Chaping', 'Chaping,Chaping Xiang,cha ping,cha ping xiang,茶平,茶平乡', 27.4786100, 118.8152800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19244, 'Chaozhou', 'Chaozhou', 'Caodzou,Caogou,Cchao-cou,Ch''ao-an-hsien,Ch''ao-chou,Ch''ao-chou-chen,Ch''ao-chou-shih,Chao''an,Chaochow,Chaochowfu,Chaochzhou,Chaodzou,Chaotsjou,Chaozhou,Chao’an,Chau chu fu,Chauchow,Chheu-chu-su,Chhèu-chû-sṳ,Ch’ao-an-hsien,Ch’ao-chou,Ch’ao-chou-chen,Ch’ao-chou-shih,Dieu-ciu,Dièu-ciŭ,SWA,Tio-chiu-chhi,Tiô-chiu-chhī,Trieu Chau,Triều Châu,chao zhou,chao zhou shi,chaojeou si,chawzhw,chawzhww,tæciw,Ĉaoĝou,Čaodžou,Čchao-čou,Чаочжоу,Чаоџоу,چاؤژوؤ,چاوژو,چاوژوو,แต้จิ๋ว,潮州,潮州市,차오저우 시', 23.6539600, 116.6226200, 'CN', '2014-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19245, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Zhen,chao yang,chao yang zhen,朝阳,朝阳镇', 34.6818400, 119.2979700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19246, 'Chaotian', 'Chaotian', 'Ch''ao-t''ien,Ch''ao-t''ien-i,Ch''ao-t''ien-kuan,Chaotian,Chaotianyi,Chzhaotyan'',Chzhaotyan’,Ch’ao-t’ien,Ch’ao-t’ien-i,Ch’ao-t’ien-kuan,chao tian,朝天', 32.6446200, 105.8850100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19247, 'Chaoshui', 'Chaoshui', 'Ch''ao-shui-chi,Chaoshui,Chaoshui Zhen,Ch’ao-shui-chi,chao shui,chao shui zhen,潮水,潮水镇', 37.6924800, 120.9714800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19248, 'Chaohu', 'Chaohu', 'Ch''ao,Ch''ao-hsien,Chaohu,Chaoxian,Ch’ao,Ch’ao-hsien,Ts''ao-chen,Ts’ao-chen,chao hu shi,巢湖市', 31.6000000, 117.8666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19249, 'Chaodi', 'Chaodi', 'Ch''ao-ti,Chaodi,Chaodi Zhen,Ch’ao-ti,Qinglongzui,chao di,chao di zhen,qing long ju,潮砥,潮砥镇,青龙咀', 28.1019200, 108.2324200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19250, 'Chaobei', 'Chaobei', 'Ch''ao-p''o,Ch''ao-pei,Chaobei,Chaobei Zhen,Ch’ao-pei,Ch’ao-p’o,chao bei,chao bei zhen,晁陂,晁陂镇', 33.0405600, 112.1037000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19251, 'Changzhou', 'Changzhou', 'CZX,Cangdzou,Canggouo,Cchang-cou,Ch''ang-chou,Ch''ang-chou-shih,Chanchzhou,Chandzhou,Chang-chow-fu,Changchow,Changdzou,Changtsjou,Changzhou,Chanzhou khot,Ch’ang-chou,Ch’ang-chou-shih,Csangcsou,Siong-chiu-chhi,Siong-ciu,Siòng-ciŭ,Siông-chiu-chhī,Thuong Chau,Thường Châu,Wu-chin,Wu-chin-hsien,Wujin,Wutsin,chang zhou,chang zhou shi,changjeou si,changzhw,Ĉangĝoŭo,Čangdžou,Čchang-čou,Чангџоу,Чанджоу,Чанжоу хот,Чанчжоу,چانگژو,چاڭجو شەھىر,常州,常州市,창저우 시', 31.7735900, 119.9540100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19252, 'Changzhou', 'Changzhou', 'Changzhou,zhang zhou,长洲', 23.0816900, 113.4223100, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19253, 'Changzhi', 'Changzhi', 'Ch''ang-chih,Chanchzhi,Changzhi,Ch’ang-chih,Shih-t''ou-ko-t''a,Shih-t’ou-ko-t’a,Shitougeta,Чанчжи', 35.2088900, 111.7386100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19254, 'Changzhen', 'Changzhen', 'Ch''ang-chen,Ch''ang-chen-ts''un,Changzhen,Changzhen Xiang,Ch’ang-chen,Ch’ang-chen-ts’un,zhang zhen,zhang zhen xiang,长畛,长畛乡', 39.2536900, 111.8244100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19255, 'Puxi', 'Puxi', 'Ch''ang-yuan-hsien,Changyuan,Ch’ang-yüan-hsien,Puxi,pu xi,蒲西', 35.1958300, 114.6850000, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19256, 'Changyuan', 'Changyuan', 'Changyuan,Changyuan Jiedao,Jung-ch''ang,Jung-ch''ang-hsien,Jung-ch’ang,Jung-ch’ang-hsien,Rongchang Xian,Yung-ch''ang,Yung-ch’ang,chang yuan,chang yuan jie dao,rong chang xian,昌元,昌元街道,荣昌县', 29.4049900, 105.5882700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19257, 'Kuiju', 'Kuiju', 'Ch''ang-i,Ch''ang-i-hsien,Changyi,Ch’ang-i,Ch’ang-i-hsien,Kuiju,chang yi,kui ju,奎聚,昌邑', 36.8536100, 119.3908300, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19258, 'Changxuanling', 'Changxuanling', 'Ch''ang-hsien-ling,Ch''ang-hsuan-ling,Changxuanling,Changxuanling Zhen,Ch’ang-hsien-ling,Ch’ang-hsüan-ling,zhang xuan ling,zhang xuan ling zhen,长轩岭,长轩岭镇', 31.0960900, 114.3448900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19259, 'Changxing', 'Changxing', 'Ch''ang-hsing,Ch''ang-hsing-chen,Changxing,Changxing Zhen,Ch’ang-hsing,Ch’ang-hsing-chen,chang xing,chang xing zhen,常兴,常兴镇', 34.2707600, 107.8357400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19260, 'Changxingbao', 'Changxingbao', 'Changxing,Changxingbao,Changxingbao Zhen,zhang xing bao,zhang xing bao zhen,长兴堡,长兴堡镇', 28.3174100, 109.1923900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19261, 'Xiaoxi', 'Xiaoxi', 'Ch''ang-hsiao,Changxiao Zhen,Ch’ang-hsiao,Xiaoxi,xiao xi,zhang xiao zhen,校溪,长校镇', 25.9506100, 116.7128500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19262, 'Changxi', 'Changxi', 'Ch''ang-ch''i,Ch''ang-hsi,Changxi,Changxi Xiang,Ch’ang-ch’i,Ch’ang-hsi,chang xi,chang xi xiang,昌溪,昌溪乡', 29.9125700, 118.6438700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19263, 'Changtun', 'Changtun', '', 39.4433300, 117.0705600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19264, 'Changtu', 'Changtu', 'Changtu,Changtuzhen,Wojingtan,wo jing tan,zhang tu,zhang tu zhen,倭井谭,长涂,长涂镇', 30.2540500, 122.3033400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19265, 'Changtang', 'Changtang', 'Changtang,Changtang Zhen,zhang tang,zhang tang zhen,长塘,长塘镇', 28.3574300, 111.7727800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19266, 'Changtang', 'Changtang', 'Changtang,Changtang Zhen,zhang tang,zhang tang zhen,长塘,长塘镇', 27.1918800, 114.9681100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19267, 'Changtan', 'Changtan', 'Changtan,Changtan Zhen,zhang tan,zhang tan zhen,长滩,长滩镇', 31.0021400, 112.7328900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19268, 'Wu’an', 'Wu''an', 'Ch''ang-t''ai-hsien,Changtai,Ch’ang-t’ai-hsien,Wu''an,Wu''anzhen,Wu’an,Wu’anzhen,wu an,武安', 24.6038700, 117.7453900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19269, 'Changshou', 'Changshou', 'Ch''ang-shou-tien,Changshou,Changshou Zhen,Changshoudian,Changshowtien,Chanshoudyan,Ch’ang-shou-tien,zhang shou,zhang shou zhen,长寿,长寿镇', 31.4170000, 112.6133600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19270, 'Changshengqiao', 'Changshengqiao', 'Ch''ang-sheng-ch''iao,Changshengqiao,Changshengqiao Zhen,Ch’ang-sheng-ch’iao,zhang sheng qiao,zhang sheng qiao zhen,长生桥,长生桥镇', 29.5088900, 106.6608300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19271, 'Changsheng', 'Changsheng', 'Ch''ang-sheng-fang,Ch''ang-sheng-hsu,Changsheng,Changsheng Zhen,Ch’ang-sheng-fang,Ch’ang-sheng-hsü,zhang sheng,zhang sheng zhen,长胜,长胜镇', 26.2851800, 116.0127000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19272, 'Changsha', 'Changsha', 'Ch''ang-sha,Ch''ang-sha-chen,Changsha,Changsha Zhen,Changshazhen,Ch’ang-sha,Ch’ang-sha-chen,zhang sha,zhang sha zhen,长沙,长沙镇', 32.4096000, 121.2879900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19273, 'Changshanyan', 'Changshanyan', 'Changshanyan,Changshanyan Xiang,zhang shan yan,zhang shan yan xiang,长山晏,长山晏乡', 28.2409000, 116.2227000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19274, 'Changshan', 'Changshan', 'Ch''ang-shan-hsu,Changshan,Changshan Zhen,Ch’ang-shan-hsü,zhang shan,zhang shan zhen,长山,长山镇', 21.7962100, 110.0051400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19275, 'Changsha', 'Changsha', 'Ch''ang-sha-ch''ang,Changsha,Changsha Zhen,Chansha,Ch’ang-sha-ch’ang,zhang sha,zhang sha zhen,Чанша,长沙,长沙镇', 28.6877800, 105.9897200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19276, 'Changsha', 'Changsha', 'CSX,Cangsa,Cangzsah,Cansa,Cchang-sa,Ch''ang-sha-hsien,Ch''ang-sha-shih,Changsha,Changsja,Chansha,Chhong-sa-su,Chhòng-sâ-sṳ,Ch’ang-sha-hsien,Ch’ang-sha-shih,Csangsa,Diong-sa,Diòng-să,Tng-soa-chhi,Tn̂g-soa-chhī,Truong Sa,Trường Sa,Tsan''nksa,cangasa,chang cha,changsa,changsa si,changsha,changsha shەھyr,channasa,tshanghsha,zhang sha,zhang sha shi,Ĉangŝa,Čangša,Čanša,Čchang-ša,Τσανγκσά,Чангша,Чанша,Չանշա,تشانغشا,چانگشا,چاڭشا شەھىر,चांगशा,छांग्षा,ਛਾਂਙਸ਼ਾ,ฉางชา,ချနဆားမြ,ချန်ဆားမြို့,長沙,長沙市,长沙,长沙市,창사 시', 28.1987400, 112.9708700, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19277, 'Changsha', 'Changsha', 'Changsha,Changsha Zhen,zhang sha,zhang sha zhen,长沙,长沙镇', 24.2157500, 116.1212600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19278, 'Changsa', 'Changsa', 'Changsa,Changsa Zhen,chang sa,chang sa zhen,昌洒,昌洒镇', 19.7628000, 110.8983000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19279, 'Changqing', 'Changqing', 'Ch''ang-ch''ing,Ch''ang-ch''ing-hsien,Chancin,Changqing,Changtsing,Ch’ang-ch’ing,Ch’ang-ch’ing-hsien,Чанцин', 36.5575000, 116.7272200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19280, 'Changqing', 'Changqing', 'Ch''ang-ch''ing,Changqing,Changqing Zhen,Ch’ang-ch’ing,zhang qing,zhang qing zhen,长庆,长庆镇', 25.8844400, 118.5799900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19281, 'Changqiao', 'Changqiao', 'Ch''ang-ch''iao,Changqiao,Changqiao Xiang,Ch’ang-ch’iao,zhang qiao,zhang qiao xiang,长桥,长桥乡', 26.8296100, 116.4090200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19282, 'Changqiao', 'Changqiao', 'Ch''ang-ch''iao,Changqiao,Ch’ang-ch’iao,P''ing-nan,P’ing-nan', 26.8213900, 118.8436100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19283, 'Changqi', 'Changqi', 'Ch''ang-ch''i,Ch''ang-ch''i-ts''un,Changqi,Changqi Zhen,Ch’ang-ch’i,Ch’ang-ch’i-ts’un,zhang qi,zhang qi zhen,长岐,长岐镇', 21.5337900, 110.7232200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19284, 'Changpu', 'Changpu', 'Ch''ang-p''u-chen,Ch''ang-p''u-tzu,Changpu,Changputze,Changpuzhen,Chanpu,Ch’ang-p’u-chen,Ch’ang-p’u-tzu,Suinin,Suining,zhang pu,长铺', 26.5758400, 110.1078500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19285, 'Changpo', 'Changpo', 'Changpo,Changpo Zhen,zhang po,zhang po zhen,长坡,长坡镇', 22.0643800, 111.0166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19286, 'Changpo', 'Changpo', 'Ch''ang-po-shih,Changpo,Changpo Zhen,Ch’ang-po-shih,zhang po,zhang po zhen,长坡,长坡镇', 19.3429200, 110.6077300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19287, 'Changping', 'Changping', 'Changping,Changping Zhen,zhang ping,zhang ping zhen,长坪,长坪镇', 31.7906500, 111.5535700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19288, 'Changping', 'Changping', 'Ch''ang-p''ing-hsu,Changping,Changping Zhen,Ch’ang-p’ing-hsü,Shang-p''ing,Shang-p''ing-hsu,Shang-p’ing,Shang-p’ing-hsü,Sheungp''ing,Sheungp’ing,chang ping,chang ping zhen,changping,常平,常平镇', 22.9769200, 113.9902400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19289, 'Changning', 'Changning', 'Changning,zhang ning,长宁', 31.2173900, 121.4210500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19290, 'Changning', 'Changning', 'Ch''ang-ning-chen,Ch''ang-ning-cheng,Changning,Changning Zhen,Ch’ang-ning-chen,Ch’ang-ning-cheng,Yu-tz''u,Yu-tz''u-hsien,Yü-tz’u,Yü-tz’u-hsien,zhang ning,zhang ning zhen,长凝,长凝镇', 37.6534900, 112.8474100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19291, 'Changning', 'Changning', 'Ch''ang-i-chen,Ch''ang-ning-chen,Changning,Changning Zhen,Ch’ang-i-chen,Ch’ang-ning-chen,Tung-fu-feng,chang ning,chang ning zhen,常宁,常宁镇', 34.8305600, 108.2497200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19292, 'Changning', 'Changning', 'An-ning,An-ning-chen,An-ning-chiao,An-ning-p''u,An-ning-p’u,Ch''ang-ning-hsien,Changning,Ch’ang-ning-hsien,zhang ning,长宁', 28.5777300, 104.9208700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19293, 'Yiyang', 'Yiyang', 'Ch''ang-ning-hsien,Changning,Ch’ang-ning-hsien,Tschang-ning,Yiyang,yi yang,宜阳', 26.3889300, 112.3792500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19294, 'Changning', 'Changning', 'Changning,Changning Zhen,Changninghsien,Hsun-wu,Hsun-wu-hsien,Hsün-wu,Hsün-wu-hsien,Sunwu,Sunwu-hsien,Sünwu,Sünwu-hsien,Xunwu,Xunwu Xian,xun wu,xun wu xian,zhang ning,zhang ning zhen,寻乌,寻乌县,长宁,长宁镇', 24.9556800, 115.6423600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19295, 'Changning', 'Changning', 'Ch''ang-ning-hsin-hsu,Changning,Changning Zhen,Ch’ang-ning-hsin-hsü,zhang ning,zhang ning zhen,长宁,长宁镇', 23.2238500, 114.0380800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19296, 'Changluo', 'Changluo', 'Ch''ang-lo,Changluo,Changluo Xiang,Ch’ang-lo,zhang luo,zhang luo xiang,长洛,长洛乡', 25.8038600, 115.1822500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19297, 'Changlong', 'Changlong', 'Ch''ang-lung,Changlong,Changlong Zhen,Ch’ang-lung,zhang long,zhang long zhen,长龙,长龙镇', 26.3194100, 119.5690400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19298, 'Changling', 'Changling', 'Ch''ang-ling-kang,Changling,Changling Zhen,Changlinggang,Ch’ang-ling-kang,zhang ling,zhang ling zhen,长岭,长岭镇', 31.5181000, 113.5816800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19299, 'Changlin', 'Changlin', 'Ch''ang-lin-chen,Changlin,Changlin Zhen,Chanlin''chzhen'',Chanlin’chzhen’,Ch’ang-lin-chen,zhang lin,zhang lin zhen,长林,长林镇', 33.1434000, 106.9053100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19300, 'Changli', 'Changli', 'Ch''ang-li-ch''eng-kuan,Ch''ang-li-hsien,Changli,Chanli,Ch’ang-li-ch’eng-kuan,Ch’ang-li-hsien,Чанли', 39.7041700, 119.1505600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19301, 'Changle', 'Changle', 'Ch''ang-le-chen,Ch''ang-lo,Ch''ang-lo-chen,Changle,Changle Zhen,Changlezhen,Ch’ang-le-chen,Ch’ang-lo,Ch’ang-lo-chen,chang le,chang le zhen,常乐,常乐镇', 31.9342400, 121.2475400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19302, 'Changleping', 'Changleping', 'Changleping,Changleping Zhen,zhang le ping,zhang le ping zhen,长乐坪,长乐坪镇', 30.1754900, 110.8680400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19303, 'Changleng', 'Changleng', 'Ch''ang-ling-chen,Ch''ang-t''ou-ling,Changleng,Ch’ang-ling-chen,Ch’ang-t’ou-ling,Hsin-chien,Xinjian', 28.7000000, 115.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19304, 'Changle', 'Changle', 'Changle,Changle Zhen,zhang le,zhang le zhen,长乐,长乐镇', 29.4565000, 120.6104900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19305, 'Changle', 'Changle', 'Ch''ang-lo,Changle,Changle Xiang,Ch’ang-lo,zhang le,zhang le xiang,长乐,长乐乡', 24.2948200, 116.9365100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19306, 'Changkou', 'Changkou', 'Ch''ang-k''ou-chen,Changkou,Changkou Zhen,Ch’ang-k’ou-chen,chang kou,chang kou zhen,场口,场口镇', 29.9130600, 119.8774200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19307, 'Changkeng', 'Changkeng', 'Changkeng,Changkeng Xiang,zhang keng,zhang keng xiang,长坑,长坑乡', 25.1963700, 117.8674100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19308, 'Changjie', 'Changjie', 'Ch''ang-chieh,Ch''ang-chieh-chen,Changjie,Changjie Zhen,Changjiezhen,Ch’ang-chieh,Ch’ang-chieh-chen,zhang jie,zhang jie zhen,长街,长街镇', 29.2500000, 121.7050000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19309, 'Changjiang', 'Changjiang', 'Changjiang,Changjiang Zhen,zhang jiang,zhang jiang zhen,长江,长江镇', 32.1039900, 120.5581300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19310, 'Changjiang', 'Changjiang', 'Ch''ang-chiang,Ch''ang-chiang-hsu,Changjiang,Changjiang Zhen,Ch’ang-chiang,Ch’ang-chiang-hsü,zhang jiang,zhang jiang zhen,长江,长江镇', 25.3267800, 113.9270100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19311, 'Changhua', 'Changhua', 'Ch''ang-hua-hsien,Ch''ang-hua-hsien-chih,Changhua,Changhwa,Changhwahsien,Ch’ang-hua-hsien,Ch’ang-hua-hsien-chih,Wu-lung-chen,chang hua,昌化', 30.1683300, 119.2175000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19312, 'Changhua', 'Changhua', 'Changhua,Changhua Zhen,chang hua,chang hua zhen,昌化,昌化镇', 19.3308700, 108.6763600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19313, 'Changhe', 'Changhe', 'Ch''ang-ho-shih,Changhe,Changhe Zhen,Changheshi,Ch’ang-ho-shih,Erh-t''ang-t''ou,Erh-t’ang-t’ou,zhang he,zhang he zhen,长河,长河镇', 30.2200900, 121.1833100, 'CN', '2017-06-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19314, 'Changhe', 'Changhe', 'Ch''ang-ho,Ch''ang-ho-chen,Changhe,Changhe Jiedao,Changhe Zhen,Ch’ang-ho,Ch’ang-ho-chen,zhang he,zhang he jie dao,zhang he zhen,长河,长河街道,长河镇', 30.1725400, 120.1866700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19315, 'Changgouhe', 'Changgouhe', 'Ch''ang-kou-ho,Changgouhe,Ch’ang-kou-ho,zhang gou he,长沟河', 33.2569500, 106.6307700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19316, 'Changgou', 'Changgou', 'Ch''ang-kou-chen,Chang-kou,Changgou,Changgou Zhen,Ch’ang-kou-chen,zhang gou,zhang gou zhen,长沟,长沟镇', 39.5738400, 115.8957100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19317, 'Changgang', 'Changgang', 'Ch''ang-kang-tien,Changgang,Changgang Zhen,Ch’ang-kang-tien,zhang gang,zhang gang zhen,长岗,长岗镇', 31.5510900, 112.9743300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19318, 'Changgang', 'Changgang', 'Ch''ang-kang,Changgang,Changgang Xiang,Ch’ang-kang,zhang gang,zhang gang xiang,长冈,长冈乡', 26.3657100, 115.3660700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19319, 'Changgang', 'Changgang', 'Ch''ang-kang,Ch''ang-kang-hsu,Changgang,Changgang Zhen,Changkong,Ch’ang-kang,Ch’ang-kang-hsü,zhang gang,zhang gang zhen,长岗,长岗镇', 23.2774600, 111.5788600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19320, 'Changfeng', 'Changfeng', 'Ch''ang-pan,Changfeng,Ch’ang-pan,chang feng,常丰', 34.7347300, 107.9689700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19321, 'Changfeng', 'Changfeng', 'Changfeng,Changfeng Tujiazu Xiang,zhang feng,zhang feng tu jia zu xiang,长丰,长丰土家族乡', 28.4216400, 108.0832800, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19322, 'Changcun', 'Changcun', 'Ch''ang-ts''un,Changcun,Ch’ang-ts’un,chang cun,常村', 33.5329800, 113.1221200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19323, 'Changchun', 'Changchun', 'Changchun,Changchun Zhen,zhang chun,zhang chun zhen,长春,长春镇', 26.7285700, 120.0401400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19324, 'Changchi', 'Changchi', 'Ch''ang-ch''ih,Ch''ang-ch''ih-ch''ang,Changchi,Changchizhen,Ch’ang-ch’ih,Ch’ang-ch’ih-ch’ang,zhang chi,zhang chi zhen,长赤,长赤镇', 32.1637700, 106.6581400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19325, 'Changbu', 'Changbu', 'Changbu,Changbu Zhen,zhang bu,zhang bu zhen,长埠,长埠镇', 28.7951700, 115.6241300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19326, 'Changbu', 'Changbu', 'Ch''ang-pu,Changbu,Changbu Zhen,Ch’ang-pu,zhang bu,zhang bu zhen,长布,长布镇', 23.7934800, 115.4373700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19327, 'Changba', 'Changba', 'Ch''ang-pa,Changba,Changba Zhen,Ch’ang-pa,zhang ba,zhang ba zhen,长坝,长坝镇', 29.3346600, 107.4749600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19328, 'Chang’an', 'Chang''an', 'Ch''ang-an-chen,Chang''an,Chang''an Zhen,Chang’an,Chang’an Zhen,Chungnan,Ch’ang-an-chen,zhang an,zhang an zhen,长安,长安镇', 30.4556100, 120.4437600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19329, 'Rong’an', 'Rong''an', 'Ch''ang-an-chen,Chang''an,Chang’an,Chongon,Ch’ang-an-chen,Jung-an,Jung-shui,Rong''an,Rong’an,zhang an,长安', 25.2333300, 109.3833300, 'CN', '2011-09-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19330, 'Chang’an', 'Chang''an', 'Ch''ang-an-hsu,Chang''an,Chang''an Zhen,Chang’an,Chang’an Zhen,Ch’ang-an-hsü,zhang an,zhang an zhen,长安,长安镇', 23.8820700, 111.8936800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19331, 'Chande', 'Chande', 'Chande,Chande Xiang,chan de,chan de xiang,产德,产德乡', 38.6458700, 114.5850300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19332, 'Chalu', 'Chalu', 'Ch''a-lu-chieh,Chalu,Chalu Zhen,Ch’a-lu-chieh,cha lu,cha lu zhen,岔路,岔路镇', 29.2033300, 121.3152800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19333, 'Chaling Chengguanzhen', 'Chaling Chengguanzhen', 'Ch''a-ling-hsien,Ch''a-ling-hsien-ch''eng,Ch''o-ling,Cha-ling-chow,Chaling Chengguanzhen,Ch’a-ling-hsien,Ch’a-ling-hsien-ch’eng,Ch’o-ling,Tscha-ling,cha ling cheng guan zhen,茶陵城关镇', 26.7909700, 113.5397500, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19334, 'Chakou', 'Chakou', 'Ch''a-k''ou-chen,Chakou,Chakou Zhen,Ch’a-k’ou-chen,cha kou,cha kou zhen,岔口,岔口镇', 29.8887800, 118.7055000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19335, 'Chajian', 'Chajian', 'Ch''a-chien,Ch''a-chien-chen,Chajian,Chajian Zhen,Ch’a-chien,Ch’a-chien-chen,cha jian,cha jian zhen,汊涧,汊涧镇', 32.6769400, 118.7694200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19336, 'Chaiwan', 'Chaiwan', 'Ch''ai-wan-chen,Chaiwan,Chaiwan Zhen,Ch’ai-wan-chen,chai wan,chai wan zhen,柴湾,柴湾镇', 32.4582400, 120.5405100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19337, 'Chaiqiao', 'Chaiqiao', 'Ch''ai-ch''iao,Ch''ai-ch''iao-chen,Ch''ai-ch''iao-shih,Chaiqiao,Chaiqiao Zhen,Ch’ai-ch’iao,Ch’ai-ch’iao-chen,Ch’ai-ch’iao-shih,chai qiao,chai qiao zhen,柴桥,柴桥镇', 29.8691700, 121.9144400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19338, 'Chaihu', 'Chaihu', 'Chaihu,Chaihu Zhen,chai hu,chai hu zhen,柴湖,柴湖镇', 30.9917600, 112.5903300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19339, 'Chaicun', 'Chaicun', 'Ch''ai-ts''un,Chaicun,Chaicun Jiedao,Ch’ai-ts’un,Jiancaoping Qu,chai cun,chai cun jie dao,jian cao ping qu,尖草坪区,柴村,柴村街道', 37.9327800, 112.4763900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19340, 'Chahe', 'Chahe', 'Ch''a-ho,Ch''a-ho-chi,Chahe,Chahe Zhen,Chaheji,Ch’a-ho,Ch’a-ho-chi,cha he,cha he zhen,汊河,汊河镇', 32.2057900, 118.5869100, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19341, 'Chahe', 'Chahe', 'Ch''a-ho,Ch''a-ho-chen,Chahe,Chahe Zhen,Ch’a-ho,Ch’a-ho-chen,cha he,cha he zhen,岔河,岔河镇', 32.3516700, 120.9205600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19342, 'Chahe', 'Chahe', 'Ch''a-ho,Chahe,Chahe Zhen,Ch’a-ho,cha he,cha he zhen,叉河,叉河镇', 19.2324900, 108.9387300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19343, 'Chagugang', 'Chagugang', 'Ch''a-ku-chiang,Chagugang,Chagugang Zhen,Ch’a-ku-chiang,I-ku-chiang,cha gu gang,cha gu gang zhen,汊沽港,汊沽港镇', 39.2461100, 116.9413900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19344, 'Chadong', 'Chadong', 'Ch''a-tung,Chadong,Chadong Zhen,Ch’a-tung,cha dong,cha dong zhen,茶洞,茶洞镇', 28.5175000, 109.2948200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19345, 'Chadian', 'Chadian', 'Ch''a-t''ien-tzu,Ch''a-tien,Chadian,Chadian Zhen,Chadianzi,Chadyan''tszo,Chadyan’tszö,Ch’a-tien,Ch’a-t’ien-tzu,cha dian,cha dian zhen,茶店,茶店镇', 33.1883300, 106.4606600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19346, 'Chadianzi', 'Chadianzi', 'Ch''a-tien-tzu,Chadianzi,Chadianzi Zhen,Ch’a-tien-tzu,cha dian zi,cha dian zi zhen,茶店子,茶店子镇', 30.9275600, 110.3271100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19347, 'Chadian', 'Chadian', 'Ch''a-t''en,Ch''a-tien,Cha-ting,Chadian,Ch’a-tien,Ch’a-t’en', 39.2247200, 117.7488900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19348, 'Chadian', 'Chadian', 'Ch''a-tien,Chadian,Chadian Zhen,Ch’a-tien,cha dian,cha dian zhen,茶店,茶店镇', 32.7426000, 110.8357200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19349, 'Longxing', 'Longxing', 'Ch''a-tien,Chadianzi,Ch’a-tien,Longxing,Longxing Zhen,cha dian zi,long xing,long xing zhen,茶店子,龙形,龙形镇', 30.2507900, 105.9085300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19350, 'Chadian', 'Chadian', 'Ch''a-tien-ch''ang,Chadian,Ch’a-tien-ch’ang', 27.5819400, 109.1327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19351, 'Chadi', 'Chadi', 'Ch''a-ti,Chadi,Chadi Xiang,Ch’a-ti,Dianqian,cha de,cha de xiang,茶地,茶地乡', 25.0246600, 116.5801400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19352, 'Chabaihu', 'Chabaihu', '', 39.4655600, 117.1483300, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19353, 'Cha’anpu', 'Cha''anpu', 'Cha''anpu,Cha''anpu Zhen,Cha’anpu,Cha’anpu Zhen,cha an pu,cha an pu zhen,茶庵铺,茶庵铺镇', 28.6344400, 111.1566700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19354, 'Cewu', 'Cewu', 'Cewu,Cewu Xiang,ce wu,ce wu xiang,策武,策武乡', 25.7284300, 116.3479200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19355, 'Cairima', 'Cairima', 'Cairima,Cairima Xiang,Ceruma,Cêruma,cai ri ma,cai ri ma xiang,采日玛,采日玛乡', 33.3398200, 102.1580300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19356, 'Cenhe', 'Cenhe', 'Cenhe,Cenhe Zhen,Ts''en-ho,Ts’en-ho,cen he,cen he zhen,岑河,岑河镇', 30.2710900, 112.3704900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19357, 'Cengang', 'Cengang', 'Cengang,Cengang Zhen,Ling-chiang,Ts''en-kang,Ts''en-kang-chen,Ts’en-kang,Ts’en-kang-chen,cen gang,cen gang zhen,岑港,岑港镇', 30.0775100, 121.9957200, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19358, 'Caoyuan', 'Caoyuan', 'Caoyuan,Caoyuan Zhen,cao yuan,cao yuan zhen,曹远,曹远镇', 26.0326800, 117.3330400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19359, 'Caoxi', 'Caoxi', 'Caoxi,Caoxi Zhen,Ts''ao-hsi,Ts’ao-hsi,cao xi,曹溪', 28.7024200, 117.3441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19360, 'Caotan', 'Caotan', 'Caotan,Caotan Jieban,Ts''ao-t''an,Ts''ao-t''an-chen,Ts’ao-t’an,Ts’ao-t’an-chen,cao tan,cao tan jie ban,草滩,草滩街办', 34.3960000, 108.9707100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19361, 'Caotan', 'Caotan', 'Caotan,Caotan Zhen,cao tan,cao tan zhen,草潭,草潭镇', 21.2649700, 109.7808900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19362, 'Caota', 'Caota', 'Caota,Caota Zhen,Ts''ao-t''a,Ts''ao-t''a-shih,Ts’ao-t’a,Ts’ao-t’a-shih,cao ta,cao ta zhen,草塔,草塔镇', 29.6833300, 120.1333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19363, 'Caopie', 'Caopie', 'Caopie,Caopie Zhen,Ts''ao-ch''ang-p''ieh,Ts''ao-p''ieh,Ts’ao-ch’ang-p’ieh,Ts’ao-p’ieh,cao pie,cao pie zhen,曹丿,曹丿镇', 32.8601200, 120.6696600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19364, 'Caodipan', 'Caodipan', 'Caodipan,Caodipan Zhen,Caopandi,Ts''ao-p''an-ti,Ts’ao-p’an-ti,cao de pan,cao de pan zhen,草地盘,草地盘镇', 31.0048200, 115.8990300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19365, 'Caoyan', 'Caoyan', 'Caoyan,Caoyan Zhen,Ts''ao-nien,Ts''ao-tien,Ts''ao-tien-chen,Ts''ao-yen,Ts''ao-yen-chen,Ts’ao-nien,Ts’ao-tien,Ts’ao-tien-chen,Ts’ao-yen,Ts’ao-yen-chen,cao yan,cao yan zhen,草堰,草堰镇', 32.9477700, 120.2946800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19366, 'Caomiaozi', 'Caomiaozi', 'Caomiao,Caomiaozi,Caomiaozi Zhen,cao miao zi,cao miao zi zhen,草庙子,草庙子镇', 37.3081700, 122.1163300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19367, 'Caomiao', 'Caomiao', 'Caomiao,Caomiao Xiang,Ts''ao-miao,Ts’ao-miao,cao miao,cao miao xiang,草庙,草庙乡', 36.0295200, 106.6996700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19368, 'Caomiao', 'Caomiao', 'Caomiao,Caomiao Zhen,Ts''ao-ch''a-t''ou,Ts’ao-ch’a-t’ou,cao miao,cao miao zhen,草庙,草庙镇', 33.0493700, 120.6684900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19369, 'Caojia', 'Caojia', 'Caojia,Caojia Zhen,Ts''ao-an-ts''un,Ts''ao-chia,Ts''ao-chia-ts''un,Ts''ao-ts''un,Ts’ao-an-ts’un,Ts’ao-chia,Ts’ao-chia-ts’un,Ts’ao-ts’un,cao jia,cao jia zhen,曹家,曹家镇', 34.2443600, 107.6068400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19370, 'Caojia', 'Caojia', 'Caojia,Caojia Zhen,Caojiazhen,Hezuo,Hezuo Zhen,Ts''ao-chia,Ts''ao-chia-chen,Ts’ao-chia,Ts’ao-chia-chen,cao jia,cao jia zhen,he zuo,he zuo zhen,合作,合作镇,曹家,曹家镇', 31.9238900, 121.6347200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19371, 'Caohe', 'Caohe', 'Caohe,Caohe Zhen,Caojiahe,Ch''i-ch''un,Ch’i-ch’un,Qichun,Ts''ao-chia-ho,Ts''ao-ho,Ts''ao-ho-chen,Ts''ao-ho-cheng,Ts''ao-ho-chien,Ts’ao-chia-ho,Ts’ao-ho,Ts’ao-ho-chen,Ts’ao-ho-cheng,Ts’ao-ho-chien,cao he,cao he zhen,漕河,漕河镇', 30.2297000, 115.4334600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19372, 'Weining', 'Weining', 'Caohai,Vehjnin,Wei-ning-hsien,Wei-ning-hsien-i-tsu-hui-tsu-miao-tsu- tzu-chih-ch''u,Wei-ning-hsien-i-tsu-hui-tsu-miao-tsu- tzu-chih-ch’ü,Wei-ning-i-tsu-hui-ysu-miao-tsu-tzu-chih-hsien,Weining,Вэйнин', 26.8500000, 104.2333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19373, 'Caofang', 'Caofang', 'Caofang,Ts''ao-fang,Ts’ao-fang,cao fang,曹坊', 26.0632900, 116.6170800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19374, 'Caodian', 'Caodian', 'Caodian,Caodian Zhen,cao dian,cao dian zhen,草店,草店镇', 32.1936200, 113.6674600, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19375, 'Caocun', 'Caocun', 'Caocun,Caocun Zhen,Ts''ao-ts''un,Ts’ao-ts’un,cao cun,曹村', 34.9001300, 109.2008900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19376, 'Caochang', 'Caochang', 'Caochang,Caochang Xiang,Ts''ao-chang-hsu,Ts’ao-chang-hsü,cao chang,cao chang xiang,操场,操场乡', 28.0710100, 114.6726500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19377, 'Caobi', 'Caobi', 'Caobi,Caobi Zhen,Ts''ao-pi,Ts''ao-pi-chen,Tsaobichzhen'',Tsaobichzhen’,Ts’ao-pi,Ts’ao-pi-chen,cao bi,cao bi zhen,草碧,草碧镇', 34.7584300, 107.0292500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19378, 'Canzhuang', 'Canzhuang', 'Canzhuang,Canzhuang Zhen,Ts''an-chuang,Ts’an-chuang,can zhuang,can zhuang zhen,蚕庄,蚕庄镇', 37.3980600, 120.2130600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19379, 'Cangzhou', 'Cangzhou', 'Canchzhou,Candzhou,Cangdzou,Cangou,Cangzhou,Cangzou,Canĝou,Cchang-cou,Cchang-čou,Changhsien,Chhong-chiu-chhi,Chhong-chiu-chhī,Chong-ciu,Chŏng-ciŭ,T''sang-chou-shih,Thuong Chau,Thương Châu,Ts''ang-chen,Ts''ang-chou,Ts''ang-hsien,Tsan''syan'',Tsang,Tsangchow,Tsan’syan’,Ts’ang-chen,Ts’ang-chou,Ts’ang-hsien,T’sang-chou-shih,cang zhou,cang zhou shi,changjeou si,kangdhww,kangjw,sangjw shەھyry,Цангџоу,Цанджоу,Цанчжоу,ساڭجو شەھىرى,کانگجو,کانگذوو,沧州市,滄州,滄州市,창저우 시', 38.3166700, 116.8666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19380, 'Cangshuipu', 'Cangshuipu', 'Cangshuipu,Cangshuipu Zhen,Ts''ang-shui-p''u,Ts’ang-shui-p’u,cang shui pu,cang shui pu zhen,沧水铺,沧水铺镇', 28.4400000, 112.4361100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19381, 'Cangqian', 'Cangqian', 'Cangqian,Ts''ang-ch''ien,Ts''ang-ch''ien-chen,Ts’ang-ch’ien,Ts’ang-ch’ien-chen,cang qian,仓前', 30.2909300, 119.9909300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19382, 'Cangling', 'Cangling', 'Cangling,Cangling Zhen,cang ling,cang ling zhen,苍岭,苍岭镇', 29.0015900, 108.5995700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19383, 'Canggang', 'Canggang', 'Canggang,Canggang Zhen,Ts''ang-kang,Ts’ang-kang,cang gang,cang gang zhen,沧港,沧港镇', 28.9099500, 111.8871500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19384, 'Cangcheng', 'Cangcheng', 'Cangcheng,Cangcheng Zhen,Chiu-k''ai-p''ing,Chiu-k’ai-p’ing,Hoiping,Hoiping-hsien,K''ai-p''ing,K''ai-p''ing-hsien,K’ai-p’ing,K’ai-p’ing-hsien,Ts''ang-ch''eng,Ts’ang-ch’eng,cang cheng,cang cheng zhen,苍城,苍城镇', 22.4780500, 112.5481000, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19385, 'Cangchang', 'Cangchang', 'Cangchang,Cangchang Xiang,cang chang,cang chang xiang,苍场,苍场乡', 28.3722200, 110.9272200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19386, 'Cangbu', 'Cangbu', 'Cangbu,Cangbu Jiedao,Ts''ang-pu,Ts’ang-pu,cang bu,cang bu jie dao,仓埠,仓埠街道', 30.8341400, 114.5929300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19387, 'Caiyuan', 'Caiyuan', 'Caiyuan,Caiyuanzhen,Ch''eng-ssu,Ch’eng-ssu,Sheng-ssu,Sheng-szu,Shengsi,Shengsze,Ts''ai-yuan-chen,Ts''ai-yuan-ts''un,Ts''ai-yuao-ts''un,Ts’ai-yuan-ts’un,Ts’ai-yüan-chen,Ts’ai-yüao-ts’un,cai yuan,sheng si,嵊泗,菜园', 30.7236100, 122.4513900, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19388, 'Caiyu', 'Caiyu', 'Caiyu,Caiyu Zhen,Ts''ai-yu,Ts''ai-yu-chen,Ts’ai-yü,Ts’ai-yü-chen,cai yu,cai yu zhen,采育,采育镇', 39.6513200, 116.6171900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19389, 'Shangcai Zhongxing', 'Shangcai Zhongxing', 'Caixi,Caixi Zhen,Shangcai Zhongxing,Ts''ai-hsi,Ts’ai-hsi,cai xi,cai xi zhen,shang cai zhong xing,上才中兴,才溪,才溪镇', 25.2639800, 116.4162100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19390, 'Caishi', 'Caishi', 'Caishi,Caishi Jiedao,Ts''ai-shih,Ts''ai-shih-chen,Tsai Shih,Ts’ai-shih,Ts’ai-shih-chen,cai shi,cai shi jie dao,采石,采石街道', 31.6484200, 118.4618900, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19391, 'Caijiapu', 'Caijiapu', '', 39.1730600, 117.8105600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19392, 'Caijiapo', 'Caijiapo', 'Caijiapo,Caijiapo Zhen,Ts''ai-chia-p''o,Ts''ai-p''o,Ts''ai-p''o-chen,Ts’ai-chia-p’o,Ts’ai-p’o,Ts’ai-p’o-chen,cai jia po,cai jia po zhen,蔡家坡,蔡家坡镇', 34.3274200, 107.5963800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19393, 'Caijiang', 'Caijiang', 'Caijiang,Caijiang Xiang,Ts''ai-chiang,Ts’ai-chiang,cai jiang,cai jiang xiang,蔡江,蔡江乡', 26.6137800, 115.8134200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19394, 'Caijiamiao', 'Caijiamiao', 'Caijiamiao,Caijiamiao Xiang,cai jia miao,cai jia miao xiang,蔡家庙,蔡家庙乡', 36.0540300, 107.7185000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19395, 'Caihe', 'Caihe', 'Caihe,Caihe Zhen,Caijiahe,Ts''ai-chia-ho,Ts’ai-chia-ho,cai he,cai he zhen,蔡河,蔡河镇', 30.5644200, 115.4067900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19396, 'Caijia', 'Caijia', 'Caijia,Caijia Zhen,Caijiachang,Ts''ai-chia-ch''ang,Ts''ai-chia-kang,Ts’ai-chia-ch’ang,Ts’ai-chia-kang,cai jia,cai jia zhen,蔡家,蔡家镇', 28.9088900, 106.3404000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19397, 'Caihua', 'Caihua', 'Caihua,Ts''ai-hua,Ts’ai-hua,cai hua,采花', 30.2148000, 110.4488000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19398, 'Caihe', 'Caihe', 'Caihe,Caihe Zhen,Ts''ai-chia-ho,Ts''ai-ho,Ts’ai-chia-ho,Ts’ai-ho,cai he,cai he zhen,蔡河,蔡河镇', 31.7254600, 113.8130000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19399, 'Caigongzhuang', 'Caigongzhuang', 'Caigongzhuang,Caigongzhuang Zhen,Ts''ai-kung-chuang,Ts’ai-kung-chuang,cai gong zhuang,cai gong zhuang zhen,蔡公庄,蔡公庄镇', 38.7897200, 117.0758300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19400, 'Caidian', 'Caidian', 'Caidian,Caidian Xiang,Ts''ai-tien,Ts’ai-tien,cai dian,cai dian xiang,蔡店,蔡店乡', 31.2931000, 114.2917900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19401, 'Caidian', 'Caidian', 'Caidian,Caidian Jiedao,Caidian Qu,Han-yang-hsien,Hanyang,Ts''ai-tien,Ts''ai-tien-chen,Tsaitien,Ts’ai-tien,Ts’ai-tien-chen,cai dian,cai dian jie dao,cai dian qu,蔡甸,蔡甸区,蔡甸街道', 30.5833300, 114.0333300, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19402, 'Caicun', 'Caicun', 'Caicun,Caicun Zhen,Caicunba,Ma-yuan-k''ou,Ma-yüan-k’ou,Ts''ai-ts''un,Ts''ai-ts''un-pa,Ts’ai-ts’un,Ts’ai-ts’un-pa,cai cun,cai cun zhen,蔡村,蔡村镇', 30.7172000, 118.5503900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19403, 'Caicun', 'Caicun', 'Caicun,Caicun Zhen,Ts''ai-ts''un,Ts’ai-ts’un,cai cun,cai cun zhen,蔡村,蔡村镇', 39.7439100, 113.6489400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19404, 'Bulu', 'Bulu', 'Bulu,Bulu Xiang,P''u-lo,Pu-lu,P’u-lo,bu lu,bu lu xiang,步路,步路乡', 28.8001200, 120.7121400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19405, 'Buliu', 'Buliu', 'Buliu,Buliu Zhen,Buliucun,Pu-liu-ts''un,Pu-liu-ts’un,bu liu,bu liu zhen,埠柳,埠柳镇', 37.3368900, 122.4306900, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19406, 'Buji', 'Buji', 'Buji,Buji Jiedao,Pu-chi,Pu-chi-ts''un,Pu-chi-ts’un,Pukak,bu ji,布吉', 22.6029800, 114.1007300, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19407, 'Buhe', 'Buhe', 'Buhe,Buhe Zhen,Bukheh,Pu-ho,bu he,bu he zhen,Бухэ,埠河,埠河镇', 30.2875700, 112.2297900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19408, 'Bozhou', 'Bozhou', 'Bac Chau,Bochzhou,Bok-ciu,Boxian,Bozhou,Bŏk-ciŭ,Bạc Châu,Po,Po-cou,Po-hsien,Po-čou,Pochow,Pok-chiu-chhi,Po̍k-chiu-chhī,bo zhou,bo zhou shi,bojeou si,bwjwa,bwzhw,bwzhww,Бочжоу,Բոչժոու,بوجوا,بوژؤ,بوژوو,亳州,亳州市,보저우 시', 33.8772200, 115.7702800, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19409, 'Bozhou', 'Bozhou', 'Bochzhou,Bozhou,Po-chou,Бочжоу', 27.3788900, 109.2777800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19410, 'Bozhi', 'Bozhi', 'Bozhi,Bozhi Zhen,Po-chih-hsu,Po-chih-hsü,bo zhi,bo zhi zhen,播植,播植镇', 23.2751400, 112.1597400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19411, 'Boyang', 'Boyang', 'Boyang,Po-yang', 26.2116700, 109.5205600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19412, 'Boyang', 'Boyang', 'Boyang,Boyang Zhen,bo yang,bo yang zhen,播扬,播扬镇', 22.1094800, 110.5962100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19413, 'Bowang', 'Bowang', 'Bowang,Bowang Zhen,Po-wang,Po-wang-i,bo wang,博望', 33.1739200, 112.7452800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19414, 'Bowang', 'Bowang', 'Bowang,Bowang Zhen,Po-wang,Po-wang-chen,bo wang,bo wang zhen,博望,博望镇', 31.5634600, 118.8377600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19415, 'Botou', 'Botou', 'Bota,Botou,Botuchzhen'',Botuchzhen’,Bozhen,Chiao-ho,Nan-p''i,Nan-p’i,Po-chen,Po-t''ou,Po-t''ou-chen,Po-t’ou,Po-t’ou-chen,Potowchen,Бота', 38.0666700, 116.5666000, 'CN', '2016-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19416, 'Boshi', 'Boshi', 'Boshi,Po-shih,Po-shih-chen,bo shi,伯士', 34.7701800, 110.0507800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19417, 'Boshan', 'Boshan', 'Boshan,Po-shan,Tzu-po,Tzu-po-shih', 36.4833300, 117.8333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19418, 'Baise City', 'Baise City', 'AEB,Baicheng Jiedao,Baise,Baise City,Baise Zhen,Baksaek,Bose,Bose Zhen,Boze,Bósè,Bǎisè,Pai-se,Pai-se-chen,Pai-se-hsien,Po-se,Poseh,Poseh-hsien,bai cheng,bai cheng jie dao,bai se,bai se zhen,Бозе,百城,百城街道,百色,百色镇', 23.8997200, 106.6133300, 'CN', '2013-03-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19419, 'Bomei', 'Bomei', 'Bomei,Bomei Zhen,Po-mei,Po-mei-hsu,Po-mei-hsü,bo mei,bo mei zhen,博美,博美镇', 22.9492100, 115.7873100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19420, 'Bolian', 'Bolian', 'Bolian,Bolian Zhen,bo lian,bo lian zhen,波莲,波莲镇', 19.8686500, 109.6427300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19421, 'Bohe', 'Bohe', 'Bohe,Bohe Zhen,Po-he,bo he,bo he zhen,博贺,博贺镇', 21.4895700, 111.2188500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19422, 'Bobai', 'Bobai', 'Bobai,Bobai Zhen,Po-pai,Po-pai-chen,Po-pai-hsien,Pokpak,Pokpak-hsien,bo bai,bo bai zhen,博白,博白镇', 22.2708500, 109.9743300, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19423, 'Bo''ao', 'Bo''ao', 'BPO,Bo''ao,Bo''ao Zhen,Bo’ao Zhen,Bó''áo,Po-ao,bo ao,bo ao zhen,boao jin,博鰲,博鰲鎮,博鳌,보아오 진', 19.1599300, 110.5812800, 'CN', '2014-11-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19424, 'Biyong', 'Biyong', 'Biyong,Biyun,Pi-yung', 27.1872200, 109.5100000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19425, 'Bishui', 'Bishui', 'Bishui,Biyang,Miyang-hsien,Pi-yang,Pi-yang-hsien,mi shui,泌水', 32.7178600, 113.3116700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19426, 'Biyang', 'Biyang', 'Biyang,Biyang Zhen,I,I-hsien,Xiangyang,Yi Xian,bi yang,bi yang zhen,yi xian,碧阳,碧阳镇,黟县', 29.9288500, 117.9463800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19427, 'Bicheng', 'Bicheng', 'Bicheng,Bicheng Jiedao,Bicheng Zhen,Bishan Xian,Pi-shan,Pi-shan-hsien,Pi-shan-hsien-ch''eng,Pi-shan-hsien-ch’eng,bi cheng,bi cheng jie dao,bi shan xian,璧城,璧城街道,璧山县', 29.5949100, 106.2247600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19428, 'Biqiao', 'Biqiao', 'Biqiao,Biqiao Zhen,Pi-ch''iao,Pi-chia-ch''iao,Pi-chia-ch’iao,Pi-ch’iao,bi qiao,bi qiao zhen,毕桥,毕桥镇', 31.0146900, 119.0226400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19429, 'Bipu', 'Bipu', 'Bipu,Bipu Xiang,Pi-p''u,Pi-p''u-chen,Pi-p’u,Pi-p’u-chen,bi pu,bi pu xiang,毕浦,毕浦乡', 29.9221600, 119.5248800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19430, 'Binzhou', 'Binzhou', 'Beizhen,Bin''chzhou,Bindzhou,Bing-ciu,Bintsjou,Binzhou,Bĭng-ciŭ,Gorad Bin''chzhou,Hui-min,Pei-chen,Pin-chiu-chhi,Pin-chiu-chhī,Pin-cou,Pin-hsien,Pin-čou,Tan Chau,Tân Châu,bang zhou shi,bin zhou,bin zhou shi,binjeou si,bnzhww,bynzhw,Бинджоу,Биньчжоу,Горад Біньчжоу,بنژوو,بینژو,浜州市,滨州市,濱州,빈저우 시', 37.3666700, 118.0166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19431, 'Luxu', 'Luxu', 'Binyang,Binzhou,Lu-hsu,Lu-hsu-chen,Lu-hsü,Lu-hsü-chen,Luxu,Pin-yang,Pin-yang-hsien,lu wei,芦圩', 23.2237800, 108.8021700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19432, 'Binjiang', 'Binjiang', 'Binjiang,Binjiang Zhen,Pin-chiang,bin jiang,bin jiang zhen,彬江,彬江镇', 27.7839600, 114.5521200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19433, 'Bingying', 'Bingying', 'Bingying,Bingying Xiang,bing ying,bing ying xiang,兵营,兵营乡', 32.1097900, 109.9414900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19434, 'Bingfang', 'Bingfang', 'Bingfang,Bingfang Zhen,Ping-fang,bing fang,bing fang zhen,兵房,兵房镇', 32.2694300, 121.2954300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19435, 'Bingcun', 'Bingcun', 'Bingcun,Bingcun Zhen,Ping-ts''un,Ping-ts''un-hsu,Ping-ts’un,Ping-ts’un-hsü,bing cun,bing cun zhen,丙村,丙村镇', 24.3670100, 116.2739700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19436, 'Bilian', 'Bilian', 'Bilian,Bilian Zhen,Pi-lien,Pi-lien-shih,bi lian,bi lian zhen,碧莲,碧莲镇', 28.3139400, 120.5560800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19437, 'Gaoyao', 'Gaoyao', 'Biji,Biji Zhen,Bijiguan,Gaoyao,Pei-chi Kuan,Pi-chi Kuan,bi ji,bi ji zhen,gao yao,碧鸡,碧鸡镇,高峣', 24.9858300, 102.6225000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19438, 'Bijie', 'Bijie', 'BFJ,Bek-ciek,Bicze,Bijie,Bék-ciék,Bìjíe,Pi-tie,Pi-ťie,Pit-chiat-chhi,Pit-chiat-chhī,Prefecture de Bijie,Préfecture de Bijie,Tat Tiet,Tất Tiết,bi jie,bi jie shi,bije si,byjay,byjyy,Бицзе,بیجئی,بیجای,毕节,毕节市,畢節,畢節市,비제 시', 27.3019300, 105.2862700, 'CN', '2016-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19439, 'Bihu', 'Bihu', 'Bihu,Bihu Zhen,Pi-hu,bi hu,bi hu zhen,碧湖,碧湖镇', 28.3404500, 119.7873900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19440, 'Biguo', 'Biguo', 'Biguo,Biguo Zhen,Pi-kou,Pi-kuo-chi,bi guo,bi guo zhen,毕郭,毕郭镇', 37.2194900, 120.5539200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19441, 'Bi’er', 'Bi''er', 'Bi''er,Bi''er Zhen,Bi’er,Bi’er Zhen,Pi-erh,bi er,bi er zhen,比耳,比耳镇', 28.8047300, 109.3806700, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19442, 'Bieqiao', 'Bieqiao', 'Bieqiao,Bieqiao Zhen,bie qiao,bie qiao zhen,别桥,别桥镇', 31.5580900, 119.4602600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19443, 'Bibei', 'Bibei', 'Bibei,Bibei Zhen,bi bei,bi bei zhen,必背,必背镇', 25.0094300, 113.2801000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19444, 'Biaokou', 'Biaokou', 'Biaokou,Biaokou Xiang,Piao-k''ou,Piao-k’ou,biao kou,biao kou xiang,俵口,俵口乡', 39.3252700, 117.5537800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19445, 'Biaojiao', 'Biaojiao', 'Biaojiao,Biaojiao Zhen,Hu-chiao-chen,Piao-chiao,Piao-chiao-chen,biao jiao,biao jiao zhen,彪角,彪角镇', 34.4349700, 107.4969900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19446, 'Bianzhuang', 'Bianzhuang', 'Bianzhuang,Cangshan,Hsia-chuang,Pien-chuang,Ts''ang-shan,Ts’ang-shan', 34.8486100, 118.0447200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19447, 'Bianhe', 'Bianhe', 'Bianhe,Bianhe Zhen,bian he,bian he zhen,汴河,汴河镇', 29.8164400, 113.0825100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19448, 'Benniu', 'Benniu', 'Benniu,Benniu Zhen,Pen-niu,Pen-niu-chen,ben niu,ben niu zhen,奔牛,奔牛镇', 31.8619200, 119.8102300, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19449, 'Bengbu', 'Bengbu', 'BFU,Bang Phu,Bangbu,Behnbu,Benbu,Bengbu,Bunbu,Bạng Phụ,Pang-fou,Pang-fou-shih,Pang-po-chhi,Pang-pu,Paung-buo,Peng-pu,Pâung-buô,Pāng-pō-chhī,bang bu,bang bu shi,beongbu si,bngbw,byngbw,bېngbۇ shەھەry,Бенгбу,Бънбу,Бэнбу,Բենբու,بنگبو,بینگبو,بېڭبۇ شەھەرى,蚌埠,蚌埠市,벙부 시', 32.9408300, 117.3608300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19450, 'Benchu', 'Benchu', 'Benchu,Benchu Zhen,P''en-ch''u,P’en-ch’u', 26.7711100, 109.2905600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19451, 'Bencheng', 'Bencheng', 'Bencheng,Luannan,Pen-ch''eng,Pen-ch''eng-chen,Pen-ch’eng,Pen-ch’eng-chen,Pengcheng,ben cheng,倴城', 39.5000000, 118.7000000, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19452, 'Bingcha', 'Bingcha', 'Bencha,Bencha Zhen,Bingcha,Bingcha Zhen,Ping-ch''a,Ping-ch''a-chen,Ping-ch’a,Ping-ch’a-chen,ben cha,ben cha zhen,栟茶,栟茶镇', 32.5228400, 120.8913700, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19453, 'Beizi', 'Beizi', 'Beizi,Beizijie,Pei-tzu-chieh,bei zi,背孜', 33.9634800, 112.6035600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19454, 'Beizhouzhuang', 'Beizhouzhuang', 'Beizhouzhuang,Beizhouzhuang Zhen,Pei-chou-chuang,bei zhou zhuang,bei zhou zhuang zhen,北周庄,北周庄镇', 39.5980400, 112.8228400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19455, 'Beizhang', 'Beizhang', 'Beizhang,Beizhang Zhen,Pei-chang,Pei-chang-chuang,bei zhang,bei zhang zhen,北张,北张镇', 35.7024500, 111.1031000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19456, 'Beizhang', 'Beizhang', 'Beizhang,Beizhang Zhen,Pei-chang,bei zhang,bei zhang zhen,北漳,北漳镇', 29.5913900, 121.0400000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19457, 'Beizhakou', 'Beizhakou', 'Beizhakou,Beizhakou Zhen,bei zha kou,bei zha kou zhen,北闸口,北闸口镇', 38.9555600, 117.3947200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19458, 'Beizang', 'Beizang', 'Beizang,Beizang Zhen,Beizangcun,Beizangcun Xiang,bei zang,bei zang zhen,北臧,北臧镇', 39.6739500, 116.2844900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19459, 'Beixin', 'Beixin', 'Beixin,Beixin Zhen,Beixinzhen,Pei-hsin-chen,bei xin,bei xin zhen,北新,北新镇', 31.8250900, 121.5088100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19460, 'Beiwudu', 'Beiwudu', 'Beiwudu,Beiwudu Zhen,Pei-wu-tu,bei wu du,北舞渡', 33.6212100, 113.6918000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19461, 'Beiwenquan', 'Beiwenquan', 'Beibei Qu,Beiwenquan,Beiwenquan Jiedao,Pei-wen-ch''uan,Pei-wen-ch’üan,bei bei qu,bei wen quan,bei wen quan jie dao,北温泉,北温泉街道,北碚区', 29.8336600, 106.4193500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19462, 'Beituan', 'Beituan', 'Beituan,Beituan Zhen,bei tuan,bei tuan zhen,北团,北团镇', 25.8000500, 116.7166100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19463, 'Beitou', 'Beitou', 'Beitou,Beitou Zhen,bei tou,bei tou zhen,陂头,陂头镇', 25.0000000, 114.5833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19464, 'Beitou', 'Beitou', 'Beitou,Beitou Zhen,bei tou,bei tou zhen,陂头,陂头镇', 24.3865100, 114.2767800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19465, 'Beitan', 'Beitan', '', 39.7580600, 117.4455600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19466, 'Beisu', 'Beisu', 'Beisu,Beisu Zhen,Pei-su,Pei-su-chen,bei su,bei su zhen,北苏,北苏镇', 38.1547900, 114.8068900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19467, 'Beishidian', 'Beishidian', 'Beishidian,Beishidian Zhen,Pei-shih-tien,bei shi dian,bei shi dian zhen,北石店,北石店镇', 35.5477800, 112.8936100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19468, 'Beishi', 'Beishi', 'Beishi,Beishi Zhen,Pei-shih,bei shi,bei shi zhen,北市,北市镇', 23.8394700, 112.5712500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19469, 'Beishan', 'Beishan', 'Beihsan Zhen,Beishan,Haotang''ao,Haotang’ao,bei shan,bei shan zhen,北山,北山镇', 28.4016900, 112.9949200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19470, 'Beipo', 'Beipo', 'Beipo,Beipo Zhen,Pei-p''o,Pei-p''o-hsu,Pei-p’o,Pei-p’o-hsü,bei po,bei po zhen,北坡,北坡镇', 21.2189600, 109.8937800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19471, 'Beima', 'Beima', 'Beima,Beima Zhen,Hou-lu-chia,Hou-lü-chia,Pai-ma,Pei-ma,bei ma,bei ma zhen,北马,北马镇', 37.6094700, 120.3808700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19472, 'Beiluo', 'Beiluo', 'Beiluo,Beiluo Zhen,Chao-pei-lo,Pei-lo,bei luo,bei luo zhen,北罗,北罗镇', 38.7068300, 114.8593300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19473, 'Beilun', 'Beilun', 'Beilun,Beilun Qu,Beilungang,Xinqi,Xinqi Zhen,bei lun,bei lun qu,xin qi,xin qi zhen,北仑,北仑区,新碶,新碶镇', 29.9191700, 121.8377800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19474, 'Beilizigu', 'Beilizigu', 'Beilizigu,Pei-li-tzu-ku', 39.4913900, 117.4650000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19475, 'Beiling', 'Beiling', 'Beiling,Beiling Zhen,Pei-ling,Pei-ling-hsu,Pei-ling-hsü,Puiling,bei ling,bei ling zhen,贝岭,贝岭镇', 24.5961400, 115.3384200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19476, 'Beijing', 'Beijing', 'BJS,Bac Kinh,Baek-ging,Baekging,Behehzhin,Beijing,Beijing Shi,Beising,Beixin,Beixín,Bejdzing,Bejdżing,Bejing,Beyjing,Beȝcinȝ,Báe̤k-gĭng,Béising,Bắc Kinh,Gorad Pekin,Pechin,Pechino,Pechinu,Pechinum,Pecinum,Pei-ching,Pei-ching-shih,Pei-p''ing,Pei-p''ing-shih,Peken,Pekin,Pekin'',Pekina,Pekinas,Peking,Pekini,Pekino,Pekín,Pekîn,Peping,Pequim,Pequin,Pequín,Pet-kin,Pet-kîn,Peycing,Pikkin,Pèquin,Pékin,Péqùin,Péycing,be''ijim,be''ijina,be''ijinga,bei jing,bei jing shi,beidjin,beijing,bijiga,bijing,bijinga,bkyn,buggyeong,byjng,bykyn,byyg''yng,byyzsyng,pakking,peyjin,pkn,Πεκίνο,Бейжің,Бээжин,Бәәҗң балһсн,Горад Пекін,Пекин,Пекинг,Пекін,Пекінґ,Պեկին,בייג''ינג,בייזשינג,بكين,بيكين,بیجنگ,بېجینګ,بېيجىڭ,بېيجىڭ شەھىرى,پکن,پێکەن,ބީޖިންގ,बीजिंग,बेइजिङ,বেইজিং,ਬੀਜਿੰਗ,બેઇજિંગ,பெய்ஜிங்,బీజింగ్,ಬೀಜಿಂಗ್,ബെയ്‌ജിങ്ങ്‌,බෙයිජිං,ปักกิ่ง,པེ་ཅིང་གྲོང་ཁྱེར།,ပေကျင်းမြို့,პეკინი,ቤዪጂንግ,ប៉េកាំង,北京,北京市,베이징,북경', 39.9075000, 116.3972300, 'CN', '2017-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19477, 'Beijie', 'Beijie', 'Beijie,Pakkai,Pei-chieh,bei jie,北街', 22.6094400, 113.1011800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19478, 'Beijiao', 'Beijiao', 'Beijiao,Beijiao Zhen,Pei-chiao,bei jiao,bei jiao zhen,北滘,北窖,北窖镇', 22.9270500, 113.1981600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19479, 'Beihuaidian', 'Beihuaidian', 'Beihuaidian,Beihuaidian Xiang,Pei-huai-tien,Pei-huai-yu-tien,Pei-huai-yü-tien,bei huai dian,bei huai dian xiang,北淮淀,北淮淀乡', 39.2585400, 117.5637800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19480, 'Beihai', 'Beihai', 'BHY,Bac Hai,Baek-hai,Baekhaij,Behjkhaj,Beihai,Beihai i Guangxi,Beihajus,Bejkhaj,Beyhay,Báe̤k-hāi,Bắc Hải,Pak-hai-chhi,Pak-hái-chhī,Pakhoi,Pei-hai,Pei-hai-shih,Pej-chaj,Pet-hoi-su,Pet-hói-sṳ,bei hai,bei hai shi,beihai si,byhay,Бейхай,Бејхај,Бэйхай,Բեյհայ,بیئہائی,بیئیہائی,بیهای,بېيخەي شەھىرى,北海,北海市,베이하이 시', 21.4833300, 109.1000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19481, 'Beigou', 'Beigou', 'Beigou,Beigou Zhen,Pei-kou,bei gou,bei gou zhen,北沟,北沟镇', 37.7380600, 120.6146200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19482, 'Beigang', 'Beigang', 'Beigang,Beigang Zhen,Pei-kang,bei gang,bei gang zhen,北港,北港镇', 29.2992400, 113.6495700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19483, 'Beidu', 'Beidu', 'Beidu,Beidu Zhen,Pei-tu,Pei-tu-chen,Pei-tu-ts''un,Pei-tu-ts’un,bei du,bei du zhen,北杜,北杜镇', 34.4625000, 108.7344400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19484, 'Beidu', 'Beidu', 'Beidu,Beidu Zhen,Pei-tu,Pei-tu-chieh,bei du,北渡', 33.7073500, 113.2871300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19485, 'Beidou', 'Beidou', 'Beidou,Beidou Zhen,bei dou,bei dou zhen,北斗,北斗镇', 23.8224700, 116.1317300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19486, 'Beidou', 'Beidou', 'Beidou,Beidou Zhen,bei dou,bei dou zhen,北陡,北陡镇', 21.8771000, 112.3890200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19487, 'Beidong', 'Beidong', 'Beidong,Beidong Xiang,Pei-tung,Pei-tung-ts''un,Pei-tung-ts’un,bei dong,bei dong xiang,北董,北董乡', 35.6160000, 111.5426500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19488, 'Beidiantou', 'Beidiantou', 'Beidiantou,Beidiantou Xiang,Pei-tien-t''ou,Pei-tien-t’ou,bei dian tou,bei dian tou xiang,北店头,北店头乡', 38.7969400, 114.8930300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19489, 'Beidao', 'Beidao', 'Beidao,Beidao jiedao,Beidaobu,Maji Qu,Pei-tao-pu,T''ien-shui,Tianshui,T’ien-shui,bei dao,bei dao jie dao,mai ji qu,北道,北道街道,麦积区', 34.5686100, 105.8933300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19490, 'Beidaihehaibin', 'Beidaihehaibin', 'Beidaihehaibin,Bejdajkheh,Pehtaiho,Pehtaiho Beach,Pei-tai-ho Hai-pin,Бейдайхэ', 39.8222200, 119.5180600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19491, 'Beicuo', 'Beicuo', 'Beicuo,Beicuo Zhen,Pei-ts''o,Pei-ts’o,bei cuo,bei cuo zhen,北厝,北厝镇', 25.4796700, 119.7367000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19492, 'Beicheng', 'Beicheng', 'Beicheng,Beicheng Zhen,Pei-ch''eng,Pei-ch''eng-chieh,Pei-ch’eng,Pei-ch’eng-chieh,bei cheng,bei cheng zhen,北城,北城镇', 24.4272200, 102.5483300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19493, 'Beicaoshan', 'Beicaoshan', 'Beicaoshan,Pei-ts''ao-shan,Pei-ts’ao-shan,bei cao shan,北曹山', 39.4663900, 113.1975000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19494, 'Beicang', 'Beicang', 'Beicang,Beicang Zhen,Pei-ts''ang,Pei-ts’ang,bei cang,bei cang zhen,北仓,北仓镇', 39.2357000, 117.1226200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19495, 'Beicaicun', 'Beicaicun', '', 39.4872200, 117.0255600, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19496, 'Beibei', 'Beibei', 'Behj,Beibei,Paipei,Pehpei,Pei-p''ei-ch''ang,Pei-p''ei-kuan-li-chu,Pei-p''ei-shih,Pei-p’ei-ch’ang,Pei-p’ei-kuan-li-chü,Pei-p’ei-shih,bei bei,Бэй,北碚', 29.8273900, 106.4364500, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19497, 'Bazishao', 'Bazishao', 'Bazishao,Bazishao Zhen,Bazizhao,ba zi shao,ba zi shao zhen,八字哨,八字哨镇', 28.6205600, 112.5655600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19498, 'Bazi', 'Bazi', 'Bazai,Bazi,Bazi Zhen,Pa Tzu Ping,Pa-tsai,Pa-tzu-hsu,Pa-tzu-hsü,ba zi,ba zi zhen,坝仔,坝仔镇', 24.5166700, 114.1166700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19499, 'Bazhou', 'Bazhou', 'Bachzhou,Bachzhun,Bazhong,Bazhou,Pa-chou,Pa-chung,Pa-chung-hsien,Pachow,ba zhou,巴州', 31.8557000, 106.7720000, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19500, 'Bayan Hot', 'Bayan Hot', 'A-la-shan-ch''i,A-la-shan-ch’i,A-la-shan-tso-ch''i,A-la-shan-tso-ch’i,Alashanzuo Qi,Alxa Zuoqi,Bayan Hot,Bayanhaote Zhen,Bayenhot,Bayinhot,Pa-yen-hao-t''e,Pa-yen-hao-t''e-chen,Pa-yen-hao-t''e-shih,Pa-yen-hao-t’e,Pa-yen-hao-t’e-chen,Pa-yen-hao-t’e-shih,Pa-yin-hao-t''e,Pa-yin-hao-t’e,Ting-yuan-ying,Ting-yüan-ying,Tszokhushechzhitszyuy,Tszökhushechzhitszyuy,Tzu-hu,Tzu-hu-she-chih-chu,Tzu-hu-she-chih-chü,a la shan zuo qi,ba yan hao te,ba yan hao te zhen,巴彦浩特,巴彦浩特镇,阿拉善左旗', 38.8386100, 105.6686100, 'CN', '2014-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19501, 'Bayang', 'Bayang', 'Bayang,Bayang Zhen,bai yang,bai yang zhen,白羊,白羊镇', 30.8164000, 108.6109800, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19502, 'Bayan', 'Bayan', 'Bayan,Bayan Xiang,Pa-yen,ba yan,ba yan xiang,巴燕,巴燕乡', 36.7661100, 101.1319400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19503, 'Shuanglong', 'Shuanglong', 'Bawuhe,Pa-wu-ho,Shuanglong,Shuanglong Zhen,ba wu he,shuang long,shuang long zhen,双龙,双龙镇,巴雾河', 31.1949400, 109.8805400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19504, 'Batou', 'Batou', 'Batou,Batou Zhen,Batouzhen,Desheng,Desheng Zhen,Pa-t''ou-chen,Pa-t’ou-chen,T''ou-pa,T’ou-pa,ba tou,ba tou zhen,de sheng,de sheng zhen,坝头,坝头镇,德胜,德胜镇', 31.9575400, 121.1657100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19505, 'Batang', 'Batang', 'Batang,Batang Zhen,Pa-t''ang,Pa-t’ang,ba tang,ba tang zhen,八塘,八塘镇', 29.8353700, 106.2927100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19506, 'Batan', 'Batan', 'Batan,Batan Zhen,Pa-t''an,Pa-t’an,ba tan,ba tan zhen,八滩,八滩镇', 34.1425000, 120.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19507, 'Basuo', 'Basuo', 'Basuo,Basuo Zhen,Dongfang Shi,Pa-so,Pa-so-chen,Pasuo,Tung-fang,ba suo,ba suo zhen,dong fang shi,东方市,八所,八所镇', 19.0939000, 108.6545600, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19508, 'Bashan', 'Bashan', 'Bashan,Bashan Zhen,Bashan''so,Bashan''sy,Bashansi,Bashan’sy,Bashan’sö,Pa-shan-ssu,ba shan,ba shan zhen,拔山,拔山镇', 30.3147400, 107.7324900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19509, 'Bashan', 'Bashan', 'Baqiu,Bashan,Bashan Zhen,Ch''ung-jen,Ch''ung-jen-hsien,Ch''ung-jen-hsien-ch''eng,Chongren Xian,Ch’ung-jen,Ch’ung-jen-hsien,Ch’ung-jen-hsien-ch’eng,Hung-ch''i-chen,Hung-ch’i-chen,Ts''un-jen,Tsungjen,Ts’un-jen,ba shan,ba shan zhen,chong ren xian,崇仁县,巴山,巴山镇', 27.7682300, 116.0501700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19510, 'Basar', 'Basar', 'Basar,Wasai,Wasai Xiang,wa sai,wa sai xiang,哇赛,哇赛乡', 33.7333300, 100.6000000, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19511, 'Barkam', 'Barkam', 'Ma-erh-k''ang,Maerkang,Ssu-t''u', 31.9005900, 102.2209200, 'CN', '2006-10-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19512, 'Baqiu', 'Baqiu', 'Baqiu,Baqiu Zhen,Hsia-chiang,Hsia-chiang-hsien,Siakiang,Siakiang-hsien,Xiajiang,ba qiu,ba qiu zhen,巴邱,巴邱镇', 27.5526000, 115.1516300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19513, 'Baqiao', 'Baqiao', 'Baqiao,Baqiao Zhen,Pa-ch''iao-chen,Pa-ch’iao-chen,Pa-tzu-ch''iao,Pa-tzu-ch’iao,ba qiao,ba qiao zhen,八桥,八桥镇', 32.1091400, 119.8743200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19514, 'Baqiao', 'Baqiao', 'Baqiao,Baqiao Zhen,Pa-ch''iao,Pa-ch''iao-chen,Pa-ch''iao-pao,Pa-ch’iao,Pa-ch’iao-chen,Pa-ch’iao-pao,ba qiao,灞桥', 34.3182900, 109.0818600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19515, 'Baqiao', 'Baqiao', 'Baqiao,Baqiao Zhen,Pa-ch''iao-chen,Pa-ch’iao-chen,Pa-tzu-ch''iao,Pa-tzu-ch’iao,ba qiao,ba qiao zhen,八桥,八桥镇', 32.6797600, 119.5824400, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19516, 'Baoyou', 'Baoyou', 'Baoyou,Baoyou Zhen,Le-tung,Ledong,Ledong Lizu Zizhixian,Lo-an,Lo-an-ch''eng,Lo-an-ch’eng,Lo-tung,Lo-tung-hsien,Lok Ang,Pao-yu,Pao-yu-shih,bao you,bao you zhen,le dong li zu zi zhi xian,乐东黎族自治县,抱由,抱由镇', 18.7493200, 109.1717200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19517, 'Baoying', 'Baoying', 'Baoying,Pao-ying,Pao-ying-ch''eng,Pao-ying-ch’eng,Pao-ying-hsien', 33.2291700, 119.3091700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19518, 'Baoxu', 'Baoxu', 'Baoxu,Baoyu Zhen,Pao-hsu,Pao-hsü,bao wei,bao wei zhen,宝圩,宝圩镇', 22.1486500, 110.6780500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19519, 'Muping', 'Muping', 'Baosin,Baoxing,Baoxing Xian,Mu-p''ing,Mu-p’ing,Mupin,Muping,Pao-hsing,Pao-hsing-hsien,Pao-shing,bao xing xian,mu ping,宝兴县,穆坪', 30.3704500, 102.8122300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19520, 'Baoxia', 'Baoxia', 'Baoxia,Baoxia Zhen,Pao-hsia,bao xia,bao xia zhen,鲍峡,鲍峡镇', 32.7074600, 110.3303400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19521, 'Baocheng', 'Baocheng', 'Baocheng,Baoting,Baoting Lizu Miaozu Zizhixian,Pao-ch''eng,Pao-ch''eng-chen,Pao-ch’eng,Pao-ch’eng-chen,Pao-t''ing,Pao-t''ing-hsien,Pao-t''ing-shih,Pao-t''ing-ying,Pao-t’ing,Pao-t’ing-hsien,Pao-t’ing-shih,Pao-t’ing-ying,Po Deng,bao cheng,bao ting li zu miao zu zi zhi xian,保亭黎族苗族自治县,保城', 18.6402800, 109.6994400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19522, 'Baoshui', 'Baoshui', 'Baoshui,Baoshui Xiang,bao shui,bao shui xiang,雹水,雹水乡', 38.7217800, 114.8275400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19523, 'Baoshan', 'Baoshan', 'Baoshan,Pao-shan,Pao-shan-ch''eng,Pao-shan-ch’eng,Pao-shan-hsien,bao shan,宝山', 31.4084500, 121.4895600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19524, 'Langzhong', 'Langzhong', 'Baoning,Lang-chung,Lang-chung-hsien,Langzhong,Pao-ning-fu,Paoning,lang zhong,阆中', 31.5503700, 105.9938100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19525, 'Baoyan', 'Baoyan', 'Baonian,Baoyan,Baoyan Zhen,Pao-nien,Pao-yen,Pao-yen-chen,bao yan,bao yan zhen,宝堰,宝堰镇', 31.9204000, 119.3590500, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19526, 'Baoluan', 'Baoluan', 'Baoluan,Baoluan Zhen,Pao-luan,bao luan,bao luan zhen,包鸾,包鸾镇', 29.7641600, 107.6783400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19527, 'Baokang Chengguanzhen', 'Baokang Chengguanzhen', 'Baokang,Baokang Chengguanzhen,Pao-k''ang,Pao-k''ang-hsien,Pao-k’ang,Pao-k’ang-hsien,bao kang cheng guan zhen,保康城关镇', 31.8780600, 111.2563900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19528, 'Baojia', 'Baojia', 'Baojia,Baojia Zhen,Pao-chia-lou,Paochialo,bao jia,bao jia zhen,保家,保家镇', 29.4386900, 108.3132400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19529, 'Baohe', 'Baohe', 'Baohe,Baohezhai,bao he,保和', 33.4578000, 113.5234100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19530, 'Baofeng Chengguanzhen', 'Baofeng Chengguanzhen', 'Baofeng,Baofeng Chengguanzhen,Chiu-pao-feng,Pao-feng,Pao-feng-hsien,bao feng cheng guan zhen,宝丰城关镇', 33.8702800, 113.0652800, 'CN', '2015-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19531, 'Baofeng', 'Baofeng', 'Baofeng,Baofeng Zhen,Pao-feng,bao feng,bao feng zhen,保丰,保丰镇', 32.3020900, 110.0033900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19532, 'Baoding', 'Baoding', 'BVN,Bao GJinh,Baodin,Baodina,Baoding,Baodingas,Bawding shehiri,Bo-deng,Báoding,Bō̤-dêng,Bảo Định,Ch''ing-yuan-hsien,Ching-yuang,Ch’ing-yüan-hsien,Pao-ting,Pao-ting-shih,Po-teng-chhi,Prefettura di Baoding,Pó-tēng-chhī,Tsingyuan,Tsingyuan-hsien,Tsingyüan-hsien,bao ding,bao ding shi,baoding si,baywdyng,pea ting,Баодин,Баодинг,Բաոդին,באודינג,بائودینگ,باوڈنگ,เป่าติ้ง,保定,保定市,바오딩 시', 38.8511100, 115.4902800, 'CN', '2013-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19533, 'Baocun', 'Baocun', 'Baocun,Baohe Xiang,bao cun,bao he xiang,包合乡,包村', 30.5528300, 118.1256400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19534, 'Baochang', 'Baochang', 'Baochang,Baochang Zhen,Pao-ch''ang,Pao-ch''ang-chen,Pao-ch’ang,Pao-ch’ang-chen,bao chang,bao chang zhen,包场,包场镇', 32.0580600, 121.4166100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19535, 'Bao’an', 'Bao''an', 'Bao''an,Bao’an,Chih-tan,Pao-an,Paoanhsien,Zhidan,Zhidan Xian,bao an,zhi dan xian,保安,志丹县', 36.8289900, 108.7581400, 'CN', '2013-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19536, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Zhen,Bao’an,Bao’an Zhen,Pao-an,bao an,bao an zhen,保安,保安镇', 35.6180000, 102.0692400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19537, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Zhen,Bao’an,Bao’an Zhen,Pao-an,Pao-an-chen,bao an,保安', 34.1550100, 109.9542300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19538, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Zhen,Bao’an,Bao’an Zhen,Pao-an,Pao-an-chen,Pao-an-i,bao an,保安', 33.3830400, 113.2345400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19539, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Zhen,Bao’an,Bao’an Zhen,Pao-an,bao an,bao an zhen,保安,保安镇', 30.1729100, 114.7359600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19540, 'Banzhudang', 'Banzhudang', 'Banzhudang,Banzhudang Zhen,Pan-chu-tang,ban zhu dang,ban zhu dang zhen,班竹垱,班竹垱镇', 30.0527800, 112.0075000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19541, 'Banyue', 'Banyue', 'Banyue,Banyue Zhen,Pan-yueh,Pan-yüeh,ban yue,ban yue zhen,半月,半月镇', 30.6166600, 111.8282300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19542, 'Banxi', 'Banxi', 'Banxi,Banxi Zhen,Pan-hsi,ban xi,ban xi zhen,板溪,板溪镇', 28.0726800, 108.4689900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19543, 'Banshu', 'Banshu', 'Banshu,Banshu Xiang,Pan-shu,ban shu,ban shu xiang,版书,版书乡', 30.2294900, 118.5038500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19544, 'Banshi', 'Banshi', 'Banshi,Banshi Zhen,Pan-shih,ban shi,ban shi zhen,版石,版石镇', 25.3066600, 115.3554300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19545, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Xiang,Pan-ch''iao,Pan-ch’iao,ban qiao,ban qiao xiang,板桥,板桥乡', 39.2948700, 100.3150100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19546, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Zhen,Pan-ch''iao,Pan-ch’iao,ban qiao,板桥', 32.9976100, 113.6212400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19547, 'Banqiaodian', 'Banqiaodian', 'Banqiao,Banqiaodian,Banqiaodian Zhen,Pan-ch''iao,Pan-ch’iao,ban qiao dian,ban qiao dian zhen,板桥店,板桥店镇', 31.7496700, 112.5120500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19548, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Zhen,Pan-ch''iao,Pan-ch’iao,ban qiao,ban qiao zhen,板桥,板桥镇', 31.5298000, 111.5862400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19549, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Zhen,Pan-ch''iao,Pan-ch’iao,ban qiao,ban qiao zhen,板桥,板桥镇', 30.5904000, 109.2739900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19550, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Zhen,Banqiaochang,Pan-ch''iao,Pan-ch’iao,ban qiao,ban qiao zhen,板桥,板桥镇', 29.5130200, 105.9534100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19551, 'Majie', 'Majie', 'Banqiao Xiang,Majie,Pan-ch''iao-chieh,Pan-ch’iao-chieh,ban qiao xiang,ma jie,板桥乡,马街', 24.6863000, 103.2586100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19552, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Zhen,Pan-ch''iao-shih,Pan-ch’iao-shih,ban qiao,ban qiao zhen,板桥,板桥镇', 18.8005100, 108.6842400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19553, 'Banpu', 'Banpu', 'Banpu,Banpu Zhen,Kuan-yun,Kuan-yun-hsien,Kuan-yün,Kuan-yün-hsien,Kwanyun,Pan-p''u,Pan-p''u-chen,Pan-p’u,Pan-p’u-chen,ban pu,ban pu zhen,板浦,板浦镇', 34.4755600, 119.2447200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19554, 'Banmian', 'Banmian', 'Banmian,Banmian Xiang,Pan-mien,ban mian,ban mian xiang,坂面,坂面乡', 26.0344200, 118.1200900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19555, 'Banjing', 'Banjing', 'Banjing,Banjing Zhen,Pan-chin,Pan-ching,Pan-ching-chen,ban jing,ban jing zhen,搬经,搬经镇', 32.3093200, 120.4069100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19556, 'Bangtou', 'Bangtou', 'Bangtou,Bangtou Zhen,P''ang-t''ou,P''ang-t''ou-chen,P’ang-t’ou,P’ang-t’ou-chen,bang tou,bang tou zhen,榜头,榜头镇', 25.4270900, 118.7474800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19557, 'Bangjun', 'Bangjun', 'Bangjun,Pang-chun,Pang-chun-chen,Pang-chün,Pang-chün-chen', 39.9911100, 117.2627800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19558, 'Bangdong', 'Bangdong', 'Bangdong,Pang-tung-chen', 26.9755600, 109.1858300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19559, 'Bandong', 'Bandong', 'Bandong,Bandong Zhen,Fan-chung,Pan-tung,ban dong,ban dong zhen,坂东,坂东镇', 26.1123300, 118.7676500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19560, 'Banchang', 'Banchang', 'Banchang,Banchang Xiang,Banchangba,ban chang,ban chang ba,ban chang xiang,板场,板场乡,板场坝', 28.4310300, 108.3690200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19561, 'Bamencheng', 'Bamencheng', 'Bamencheng,Pa-men-ch''eng,Pa-men-cheng-chen,Pa-men-ch’eng', 39.5777800, 117.6052800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19562, 'Bama', 'Bama', 'Bama,Chiu-wan-kang,Pa-ma,Pa-ma-hsiang,Pa-ma-yao-tsu-tzu-chih-hsien,Wan-kang,Wan-kang-hsien,ba ma,巴马', 24.1705400, 107.2489200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19563, 'Balitai', 'Balitai', 'Balitai,Balitai Zhen,Hsiao-chan,Pa-li-t''ai,Pa-li-t’ai,ba li tai,ba li tai zhen,八里台,八里台镇', 38.9428400, 117.2888000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19564, 'Baju', 'Baju', 'Baju,Baju Zhen,Pa-chu,Pa-chü,ba ju,ba ju zhen,八巨,八巨镇', 34.1166700, 119.9833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19565, 'Bajing', 'Bajing', 'Bajing,Bajing Zhen,Pa-ching,ba jing,ba jing zhen,八景,八景镇', 28.1771900, 115.4832500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19566, 'Bajie', 'Bajie', 'Bajie,Bajie Zhen,Pa-chieh,ba jie,ba jie zhen,八街,八街镇', 24.6691700, 102.3608300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19567, 'Bajiao', 'Bajiao', 'Bajiao,Bajiao Xiang,Bajiaoba,Pa-chiao-pa,ba jiao,ba jiao xiang,芭蕉,芭蕉乡', 28.7329500, 107.1954100, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19568, 'Bajiao', 'Bajiao', 'Bajiao,Bajiao Zhen,Pa-chiao,Pa-chiao-pao,ba jiao,ba jiao zhen,八角,八角镇', 39.2147100, 111.8905700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19569, 'Bajia', 'Bajia', 'Bajia,Bajia Zhen,Pa-chia,ba jia,ba jia zhen,八甲,八甲镇', 21.9448400, 111.4217200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19570, 'Baizi', 'Baizi', 'Baizi,Baizi Zhen,Pai-tzu,bai zi,bai zi zhen,白梓,白梓镇', 30.0940300, 105.7129700, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19571, 'Baizhong', 'Baizhong', 'Baizhong,Baizhong Zhen,bai zhong,bai zhong zhen,白中,白中镇', 26.1360500, 118.7377300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19572, 'Baizhi', 'Baizhi', 'Baizhi,Baizhi Xiang,Baizhitai,Pai-chih-t''ai,Pai-chih-t’ai,bai zhi,bai zhi tai,bai zhi xiang,柏枝,柏枝乡,柏枝台', 29.3761500, 111.7600300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19573, 'Baizhang', 'Baizhang', 'Baizhang,Baizhang Zhen,Baizhangkou,Pai-chang-k''ou,Pai-chang-k''ou-shih,Pai-chang-k’ou,Pai-chang-k’ou-shih,bai zhang,bai zhang kou,bai zhang zhen,百丈,百丈口,百丈镇', 27.6550000, 119.8502800, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19574, 'Baizhang', 'Baizhang', 'Baizhang,Baizhang Zhen,Pai-chang,Shui-ch''iao-t''ou,Shui-ch’iao-t’ou,bai zhang,bai zhang zhen,百丈,百丈镇', 30.5280600, 119.7247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19575, 'Baizhang', 'Baizhang', 'Baizhang,Baizhang Zhen,bai zhang,bai zhang zhen,白樟,白樟镇', 26.1816700, 118.8065900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19576, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Xiang,Baiyunqiao,bai yun,bai yun qiao,bai yun xiang,白云,白云乡,白云桥', 29.6343400, 111.1781400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19577, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Xiang,Pai-yun,Pai-yün,bai yun,bai yun xiang,白云,白云乡', 26.0364800, 118.9062200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19578, 'Baiyu', 'Baiyu', 'Baiyu,Baiyu Xiang,Baiyugoinba,Baiyusi,Baiyügoinba,Pai-yu-ssu,Pai-yü-ssu,bai yu,bai yu si,bai yu xiang,白玉,白玉乡,白玉寺', 33.2701700, 100.6657600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19579, 'Baiyin', 'Baiyin', 'Aho Chia Chuan,Bach Ngan,Bah-ngung,Baiyin,Baiyin Shi,Bajin'',Bayin,Băh-ngṳ̀ng,Bạch Ngân,Hao-chia-ch''uan,Hao-chia-ch’uan,Ho-chia-ch''uan,Ho-chia-ch’uan,Pai-yin,Pai-yin-ch''ang,Pai-yin-ch’ang,Pai-yin-shih,Paj-jin,Peh-gin-chhi,Pe̍h-gîn-chhī,bai yin,bai yin shi,baiin si,bayy yn,bayyyn,Байинь,Բային,بائی ین,بائیین,白銀,白銀市,白银,白银市,바이인 시', 36.5469600, 104.1702300, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19580, 'Baiyi', 'Baiyi', 'Baiyi,Baiyi Zhen,Baiyi''an,Baiyi’an,bai yi,bai yi an,bai yi zhen,白衣,白衣庵,白衣镇', 29.4561000, 111.8734800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19581, 'Baiyashi', 'Baiyashi', 'Baiyashi,Dong''an,Dong’an,Pai-ya,Pai-ya-shih,Tung-an,Tung-an-hsien,bai ya shi,白牙市', 26.3888300, 111.2621300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19582, 'Baiyangping', 'Baiyangping', 'Baiyangping,Pai-yang-p''ing,Pai-yang-p’ing,bai yang ping,白杨坪', 30.4959900, 109.6381200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19583, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Zhen,Pai-yang,Pih-Yang,bai yang,bai yang zhen,白洋,白洋镇', 30.4227700, 111.5087400, 'CN', '2015-09-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19584, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Xiang,Pai-yang,Pei-yang,bai yang,bai yang xiang,柏洋,柏洋乡', 27.0538100, 119.8621100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19585, 'Baiyan', 'Baiyan', 'Baiyan,Baiyan Xiang,bai yan,bai yan xiang,白岩,白岩乡', 28.3610100, 109.9743300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19586, 'Baixian', 'Baixian', 'Baixian,Baixian Xiang,Fangxian,Pai-hsien,Pai-hsien-chen,bai xian,bai xian xiang,fang xian,白岘,白岘乡,访贤', 31.1172700, 119.6855500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19587, 'Baixi', 'Baixi', 'Baixi,Baixi Xiang,Pai-hsi,bai xi,bai xi xiang,柏溪,柏溪乡', 29.9004100, 117.7966900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19588, 'Baixi', 'Baixi', 'Baixi,Baixi Zhen,I-pin,I-pin-hsien,Pai-ch''i-chen,Pai-ch’i-chen,Pai-hsi-chen,Pai-shu-ch''ang,Pai-shu-ch''i,Pai-shu-ch’ang,Pai-shu-ch’i,Yibin,Yibin Xian,bai xi,bai xi zhen,yi bin xian,宜宾县,柏溪,柏溪镇', 28.6997000, 104.5491700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19589, 'Baixi', 'Baixi', 'Baixi,Baixi Zhen,bai xi,bai xi zhen,白溪,白溪镇', 28.0125000, 111.3088900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19590, 'Baitu', 'Baitu', 'Baitu,Baitu Zhen,bai tu,bai tu zhen,白土,白土镇', 30.5972200, 108.8114000, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19591, 'Baitu', 'Baitu', 'Baitu,Baitu Zhen,Pai-t''u,Pai-t''u-chen,Pai-t’u,Pai-t’u-chen,bai tu,bai tu zhen,白兔,白兔镇', 31.9783200, 119.3566100, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19592, 'Baitu', 'Baitu', 'Baitu,Baitu Zhen,Pai-t''u,Pai-t''u-hsu,Pai-t’u,Pai-t’u-hsü,bai tu,bai tu zhen,白土,白土镇', 28.2078800, 115.9836900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19593, 'Baitu', 'Baitu', 'Baitu,Baitu Zhen,Pai-t''u,Pai-t''u-hsu,Pai-t’u,Pai-t’u-hsü,bai tu,bai tu zhen,白土,白土镇', 24.6829600, 113.5146500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19594, 'Baitu', 'Baitu', 'Baitu,Baitu Zhen,Pai-t''u,Pai-t’u,bai tu,bai tu zhen,白土,白土镇', 22.9867000, 112.5981100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19595, 'Baitao', 'Baitao', 'Baitao,Baitao Zhen,Pai-t''ao-chen,Pai-t’ao-chen,bai tao,bai tao zhen,白涛,白涛镇', 29.5508300, 107.4868800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19596, 'Baitang', 'Baitang', 'Baitang,Baitang Xiang,Pai-t''ang,Pai-t''ang-tzu,Pai-t''ang-wa,Pai-t’ang,Pai-t’ang-tzu,Pai-t’ang-wa,bai tang,bai tang xiang,白堂,白堂乡', 39.4461500, 112.3262600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19597, 'Baitang', 'Baitang', 'Baitang,Baitang Zhen,Botang Zhen,Pai-t''ang,Pai-t''ang-hsu,Pai-t’ang,Pai-t’ang-hsü,bai tang,bai tang zhen,柏塘,柏塘镇', 23.3947100, 114.3604300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19598, 'Baita', 'Baita', 'Baita,Baita Zhen,Pai-t''a,Pai-t’a,bai ta,bai ta zhen,白塔,白塔镇', 28.7560200, 120.5883600, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19599, 'Baita', 'Baita', 'Baita,Baita Zhen,bai ta,bai ta zhen,白塔,白塔镇', 23.5608600, 116.2026900, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19600, 'Baishun', 'Baishun', 'Baishun,Baishun Zhen,Pai-shun-hsu,Pai-shun-hsü,bai shun,bai shun zhen,百顺,百顺镇', 25.1906900, 114.0270100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19601, 'Baishuiyang', 'Baishuiyang', 'Baishuiyang,Baishuiyang Zhen,Pai-shu-yang-chen,Pai-shui-yang,Pai-shui-yang-chen,Pai-yang-shui,bai shui yang,bai shui yang zhen,白水洋,白水洋镇', 28.8969700, 120.8937900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19602, 'Baishuijiang', 'Baishuijiang', 'Baishuijiang,Baishuijiang Zhen,Bayshuytszyan,Pai-shui-chiang,bai shui jiang,bai shui jiang zhen,白水江,白水江镇', 33.5764300, 106.0939300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19603, 'Shazhou', 'Shazhou', 'Baishui,Pai-shui,Shazhou,Shazhou Zhen,sha zhou,sha zhou zhen,沙州,沙州镇', 32.6696300, 105.4832800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19604, 'Baishui', 'Baishui', 'Baishui,Baishui Zhen,Pai-shui,bai shui,bai shui zhen,白水,白水镇', 32.2581500, 106.0163100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19605, 'Baishui', 'Baishui', 'Baishui,Baishui Zhen,Pai-shui,bai shui,bai shui zhen,白水,白水镇', 28.6586100, 113.0591700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19606, 'Baishui', 'Baishui', 'Baishui,Baishui Xiang,Pai-shui,bai shui,bai shui xiang,白水,白水乡', 28.1897100, 114.1413800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19607, 'Baishui', 'Baishui', 'Baishui,Baishui Zhen,Pai-shui,Pai-shui-chieh,bai shui,bai shui zhen,白水,白水镇', 27.0782500, 115.3652900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19608, 'Baishiyi', 'Baishiyi', 'Baishiyi,Baishiyi Zhen,Pai-shih-i,Paishihyi,bai shi yi,bai shi yi zhen,白市驿,白市驿镇', 29.4922200, 106.3808300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19609, 'Baishigou', 'Baishigou', 'Baishigou,Pai-shih-kou,bai shi gou,白石沟', 33.3751700, 106.1937700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19610, 'Baishi', 'Baishi', 'Baish Zhen,Baishi,Madao,Pa-shih-chien,Pai-shih,bai shi,bai shi zhen,ma dao,白石,白石镇,码道', 28.0991200, 120.8603700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19611, 'Baishi', 'Baishi', 'Baishi,Pai-yen-t''ang,Pai-yen-t’ang', 26.9736100, 109.4433300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19612, 'Baishi', 'Baishi', 'Baishi,Baishi Zhen,Pai-shih,Pai-shih-hsu,bai shi,bai shi zhen,白石,白石镇', 22.8208600, 111.7951200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19613, 'Baishi', 'Baishi', 'Baishi,Baishi Zhen,Fu-lung-pai-shih,Pai-shih,Pai-shih-hsu,Pai-shih-hsü,Pai-shih-pao,bai shi,bai shi zhen,白石,白石镇', 22.3578200, 111.0936800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19614, 'Baishe', 'Baishe', 'Baishe,Baishe Zhen,Pai-she,Pai-she-shih,Paishechen,bai she,bai she zhen,白舍,白舍镇', 27.0404200, 116.4368200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19615, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Baishazhen,Pai-sha,Pai-sha-chen,bai sha,bai sha zhen,白沙,白沙镇', 26.2092800, 119.0690700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19616, 'Baishatan', 'Baishatan', 'Baishatan,Baishatan Zhen,Pai-sha-t''an,Pai-sha-t’an,bai sha tan,bai sha tan zhen,白沙滩,白沙滩镇', 36.8330200, 121.6956600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19617, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha-p''u,Pai-sha-p’u,bai sha,bai sha zhen,白沙,白沙镇', 29.9597000, 115.0642700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19618, 'Baishanzu', 'Baishanzu', 'Baishanzu,Baishanzu Xiang,Chegen,Pai-shan-tsu,bai shan zu,bai shan zu xiang,che gen,百山祖,百山祖乡,车根', 27.7363900, 119.1786100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19619, 'Baishan', 'Baishan', 'Baishan,Baishan Zhen,Lung-sha,Lung-shan,Lung-shan-hsien,Mashan,bai shan,bai shan zhen,白山,白山镇', 23.7135300, 108.1709300, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19620, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha-p''u,Pai-sha-p’u,bai sha,bai sha zhen,白沙,白沙镇', 31.1357200, 113.8943500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19621, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,bai sha,bai sha zhen,白沙,白沙镇', 29.0622600, 106.1189000, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19622, 'Baisha', 'Baisha', 'Baisha,Baisha Xiang,Pai-sha,bai sha,bai sha xiang,白沙,白沙乡', 28.4725600, 114.0837300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19623, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,bai sha,bai sha zhen,白沙,白沙镇', 26.9553800, 115.4345900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19624, 'Baisha', 'Baisha', 'Baisha,Pai-sha', 26.5222200, 110.9311100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19625, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,bai sha,bai sha zhen,白沙,白沙镇', 25.5950300, 119.0101100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19626, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,bai sha,bai sha zhen,白沙,白沙镇', 25.3936100, 117.2236100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19627, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,bai sha,bai sha zhen,白砂,白砂镇', 25.1293000, 116.5992500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19628, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-ha-hsu,Pai-ha-hsü,Pai-sha,bai sha,bai sha zhen,白沙,白沙镇', 24.0904600, 113.7565500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19629, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Pai-sha,Pai-sha-chiu-hsu,Pai-sha-chiu-hsü,Pai-sha-hsu,Pai-sha-hsü,Paksha,bai sha,bai sha zhen,白沙,白沙镇', 22.2500000, 112.5937700, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19630, 'Bairuopu', 'Bairuopu', 'Bairuopu,Bairuopu Zhen,Pai-jo-p''u,Pai-jo-p’u,bai ruo pu,bai ruo pu zhen,白箬铺,白箬铺镇', 28.2000000, 112.8000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19631, 'Baiquesi', 'Baiquesi', 'Baiquesi,Botsioso,Botsiosö,Pai-ch''iao-ssu,Pai-ch’iao-ssu,Po-ch''ueh-ssu,Po-ch’üeh-ssu,bai que si,白雀寺', 33.2220700, 106.0785500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19632, 'Baiquan', 'Baiquan', 'Baiquan,Baiquan Zhen,Baiquanzhen,Pai-ch''uan,Pai-ch''uan-chuang,Pai-ch’üan,Pai-ch’üan-chuang,Tianshewang,bai quan,bai quan zhen,tian she wang,田舍王,白泉,白泉镇', 30.0711100, 122.1508300, 'CN', '2012-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19633, 'Baipu', 'Baipu', 'Baipu,Baipu Zhen,Pai-p''u,Pai-p''u-chen,Pai-p’u,Pai-p’u-chen,bai pu,bai pu zhen,白蒲,白蒲镇', 32.2435000, 120.7550300, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19634, 'Baipu', 'Baipu', 'Baipu,Baipu Zhen,Pai-pu,Po-yung,Po-yung-hsu,Po-yung-hsü,bai bu,bai bu zhen,柏埔,柏埔镇', 23.7096300, 114.8515300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19635, 'Baini', 'Baini', 'Baini,Baini Zhen,Pai-ni,bai ni,bai ni zhen,白坭,白坭镇', 23.0624200, 112.8339100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19636, 'Baimiaohe', 'Baimiaohe', 'Baimiaohe,Baimiaohe Xiang,bai miao he,bai miao he xiang,白庙河,白庙河乡', 31.0013700, 115.6018200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19637, 'Baimi', 'Baimi', 'Baimi,Baimi Zhen,Pai-mi,Pai-mi-chen,Ta-pai-mi,Ta-pai-mi-chen,bai mi,bai mi zhen,白米,白米镇', 32.5066100, 120.2518400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19638, 'Baima', 'Baima', 'Baima,Baimashi,Pai-ma-shih,bai ma,白马', 29.2426400, 118.7161100, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19639, 'Baimajing', 'Baimajing', 'Baimajing,Baimajing Zhen,Pai-ma-ching,Pai-ma-ching-shih,Pak Ma Chow,Pak Ma Kong,Po-mao-chiang,bai ma jing,bai ma jing zhen,白马井,白马井镇', 19.7119500, 109.2180100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19640, 'Baima', 'Baima', 'Baima,Baima Xiang,bai ma,bai ma xiang,白马,白马乡', 36.5951700, 107.7256800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19641, 'Baima', 'Baima', 'Baima,Baima Zhen,Baimaqiao,Pai-ma,Pai-ma-ch''iao,Pai-ma-ch’iao,bai ma,bai ma zhen,白马,白马镇', 31.5826100, 119.1721900, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19642, 'Baimasi', 'Baimasi', 'Baima,Baimasi,Baimasi Zhen,Pai-ma-shih,bai ma si,bai ma si zhen,白马寺,白马寺镇', 30.1020800, 112.5234300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19643, 'Baima', 'Baima', 'Baima,Baima Zhen,Pai-ma,bai ma,bai ma zhen,白马,白马镇', 29.4034600, 107.5349800, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19644, 'Bailuo', 'Bailuo', 'Bailuo,Bailuo Zhen,Bailuoji,Pai-lo-chi,Pai-lo-shih,Pehloshih,bai luo,bai luo zhen,白螺,白螺镇', 29.5511400, 113.2037200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19645, 'Bailu', 'Bailu', 'Bailu,Bailu Zhen,Bailugou,Pai-lu-kou,bai lu,bai lu zhen,百禄,百禄镇', 34.0536100, 119.5222200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19646, 'Bailu', 'Bailu', 'Bailu,Bailu Zhen,bai lu,bai lu zhen,白鹿,白鹿镇', 31.6129500, 109.6739700, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19647, 'Bailu', 'Bailu', 'Bailu,Bailu Xiang,Pai-lu,Pai-lu-hsu,Pai-lu-hsü,bai lu,bai lu xiang,白鹭,白鹭乡', 26.2433300, 115.1475000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19648, 'Wujia', 'Wujia', 'Bailongmiao,Pai-lung-miao,Wujia,Wujia Zhen,bai long miao,wu jia,wu jia zhen,五甲,五甲镇,白龙庙', 32.1456700, 121.1990200, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19649, 'Bailizhou', 'Bailizhou', 'Bailizhou,Bailizhou Zhen,bai li zhou,bai li zhou zhen,百里洲,百里洲镇', 30.4052200, 111.8004100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19650, 'Bailin', 'Bailin', 'Bai Linchang,Bailin,Bailin Zhen,Pai-lin,bai lin,bai lin zhen,柏林,柏林镇', 28.7359900, 106.4604300, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19651, 'Bailianhe', 'Bailianhe', 'Bailianhe,Bailianhe Xiang,bai lian he,bai lian he xiang,白莲河,白莲河乡', 30.5985600, 115.4357900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19652, 'Bailian', 'Bailian', 'Bailian,Bailian Zhen,Pai-lien,bai lian,bai lian zhen,白莲,白莲镇', 26.5162100, 117.3778000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19653, 'Baiju', 'Baiju', 'Baiju,Baiju Zhen,Pai-chu,Pai-chu-ch''ang,Pai-chu-chen,Pai-chü,Pai-chü-chen,Pai-chü-ch’ang,Paiku,bai ju,bai ju zhen,白驹,白驹镇', 33.0669500, 120.3080900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19654, 'Baijiazhuang', 'Baijiazhuang', 'Baijiazhuang,Baijiazhuang Xiang,Pai-chia-chuang,bai jia zhuang,bai jia zhuang xiang,柏家庄,柏家庄乡', 39.3641400, 113.6663700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19655, 'Baijiang', 'Baijiang', 'Baijiang,Baijiang Zhen,Pai-chiang,Pai-chiang-chen,bai jiang,bai jiang zhen,百江,百江镇', 29.8501200, 119.3546400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19656, 'Baijian', 'Baijian', '', 39.9941700, 117.2086100, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19657, 'Baihua', 'Baihua', 'Baihua,Baihua Zhen,bai hua,bai hua zhen,白花,白花镇', 22.9550000, 114.6485100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19658, 'Baihou', 'Baihou', 'Baihou,Baihou Zhen,Pai-hou,Pai-hou-hsu,Pai-hou-hsü,Pakhow,bai hou,bai hou zhen,百侯,百侯镇', 24.3023200, 116.7661500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19659, 'Baihe', 'Baihe', 'Baihe,Baihe Zhen,Pai-ho,bai he,bai he zhen,白合,白合镇', 38.8522300, 114.8328300, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19660, 'Baihedian', 'Baihedian', 'Baihe,Baihe Zhen,Baihedian,Pai-ho,bai he dian,bai he zhen,白鹤殿,白鹤镇', 29.2348600, 120.9351500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19661, 'Baihe', 'Baihe', 'Baihe,bai he,百合', 22.1343000, 107.2320000, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19662, 'Baiguo', 'Baiguo', 'Baiguo,Baiguo Zhen,Pai-kuo,bai guo,bai guo zhen,白果,白果镇', 31.0411200, 115.0144400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19663, 'Shangyu', 'Shangyu', 'Baiguan,Pai-kuan,Pai-kuan-chen,Pekwan,Pokwan,Shangyu', 30.0155600, 120.8711100, 'CN', '2010-08-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19664, 'Baifusi', 'Baifusi', 'Baifusi,Baifusi Zhen,Pai-fu-ssu,bai fu si,bai fu si zhen,百福司,百福司镇', 29.2040500, 109.2194500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19665, 'Bai’e', 'Bai''e', 'Bai''e,Bai''e Xiang,Bai’e,Bai’e Xiang,Pai-o,Pai-o-hsu,Pai-o-hsü,bai e,bai e xiang,白鹅,白鹅乡', 25.8186300, 115.6097300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19666, 'Baidu', 'Baidu', 'Baidu,Baidu Zhen,Pai-tu,bai du,bai du zhen,白渡,白渡镇', 24.4941300, 116.1926100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19667, 'Baidian', 'Baidian', 'Baidian,Baidian Zhen,Pai-tien,bai dian,bai dian zhen,柏垫,柏垫镇', 30.7766700, 119.2441700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19668, 'Baidi', 'Baidi', 'Baidi,Baidi Zhen,Pai-ti,bai de,bai de zhen,白地,白地镇', 30.2075000, 118.3738900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19669, 'Baicun', 'Baicun', 'Baicun,Baicun Zhen,bai cun,bai cun zhen,柏村,柏村镇', 28.6880300, 107.9319000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19670, 'Baicha', 'Baicha', 'Baicha,Baicha Zhen,Pai-ch''a,Pai-cha-chieh,Pai-chia-chieh,Pai-ch’a,bai cha,bai cha zhen,白槎,白槎镇', 29.1840900, 115.5986300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19671, 'Baibu', 'Baibu', 'Baibu,Baibu Zhen,Baibuting,Pai-pu-t''ing,Pai-pu-t’ing,bai bu,bai bu zhen,百步,百步镇', 30.5420000, 120.7775100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19672, 'Baibei', 'Baibei', 'Baibei,Baibei Xiang,Pai-p''o,Pai-pei,Pai-p’o,bai bei,bai bei xiang,白陂,白陂乡', 27.8039800, 115.9074000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19673, 'Bahuang', 'Bahuang', 'Bahuang,Bahuangchang,Pa-huang-ch''ang,Pa-huang-ch’ang,Pa-wang', 27.7180600, 109.0188900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19674, 'Yuquan', 'Yuquan', 'Baguanhe,Yuquan,Yuquan Jiedao,ba guan he,yu quan,yu quan jie dao,巴关河,玉泉,玉泉街道', 26.6052000, 101.6001300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19675, 'Bagou', 'Bagou', 'Bagou,Bagou Xiang,Xiaba,ba gou,ba gou xiang,xia ba,下巴,巴沟,巴沟乡', 35.2733000, 100.3976500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19676, 'Badu', 'Badu', 'Badu,Badu Zhen,Ch''ien-yang,Ch’ien-yang,Pa-tu,Pa-tu-chen,ba dou,ba dou zhen,八都,八都镇', 27.9806100, 118.9319400, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19677, 'Badu', 'Badu', 'Badu,Badu Zhen,Pa-tu,Pa-tu-hsu,Pa-tu-hsü,ba dou,ba dou zhen,八都,八都镇', 27.4527100, 115.2597400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19678, 'Badu', 'Badu', 'Badu,Pa-tu', 26.8102800, 119.5641700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19679, 'Badaogu', 'Badaogu', '', 39.4733300, 117.3297200, 'CN', '2000-11-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19680, 'Bada', 'Bada', 'Bada,Hsi-lin,Pa-ta,Pa-ta-chen,Pa-ta-chou,Pa-ta-hsiang,Xilin,ba da,八达', 24.5929700, 105.0932400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19681, 'Bachuan', 'Bachuan', 'Bachuan,Bachuan Jiedao,T''ung-liang,T''ung-liang-hsien,Tongliang Xian,T’ung-liang,T’ung-liang-hsien,ba chuan,ba chuan jie dao,tong liang xian,巴川,巴川街道,铜梁县', 29.8486300, 106.0504600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19682, 'Bachi', 'Bachi', 'Bachi,Bachi Zhen,Pa-ch''ih,Pa-ch’ih,ba chi,ba chi zhen,八尺,八尺镇', 24.7411900, 115.8044500, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19683, 'Bacheng', 'Bacheng', 'Bacheng,Bacheng Zhen,Pa-ch''eng,Pa-ch''eng-chen,Pa-ch’eng,Pa-ch’eng-chen,ba cheng,ba cheng zhen,巴城,巴城镇', 31.4578600, 120.8727800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19684, 'Babu', 'Babu', 'Babu,Hexian,Ho,Ho-hsien,Pa-pu,Pa-pu-chen,Patpo,Бабу', 24.4166700, 111.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19685, 'Babao', 'Babao', 'Babao,Bayuy,Ch''i-lien,Ch''i-lien-she-chih-chu,Ch’i-lien,Ch’i-lien-she-chih-chü,Pa-pao,Pa-pao-ssu,Qilian,Qilian Xian,ba bao,qi lian xian,八宝,祁连县', 38.1805600, 100.2402800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19686, 'Babaiqiao', 'Babaiqiao', 'Babailiqiao,Babaiqiao,Babaiqiao Zhen,Pa-pai-ch''iao,Pa-pai-ch''iao-chen,Pa-pai-ch’iao,Pa-pai-ch’iao-chen,Pa-pai-li-ch''iao,Pa-pai-li-ch’iao,ba bai qiao,ba bai qiao zhen,八百桥,八百桥镇', 32.4205300, 118.9280200, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19687, 'Aozai', 'Aozai', 'Ao-tsai,Aozai,Aozai Zhen,ao zi,ao zi zhen,坳仔,坳仔镇', 23.7926800, 112.3049600, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19688, 'Aoyang', 'Aoyang', 'Aoyang,Aoyang Jiedao,Aoyang Zhen,Shang-kao,Shang-kao-hsien,Shang-kao-hsien-ch''eng,Shang-kao-hsien-ch’eng,Shanggao Xian,ao yang,ao yang jie dao,ao yang zhen,shang gao xian,上高县,敖阳,敖阳街道,敖阳镇', 28.2389600, 114.9208100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19689, 'Aoyang', 'Aoyang', 'Aoyang,Aoyang Zhen,Shou-ning-hsien,Shouning,Showning,Showninghsien,ao yang,ao yang zhen,shou ning,寿宁,鳌阳,鳌阳镇', 27.4588900, 119.5013900, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19690, 'Aoxi', 'Aoxi', 'Aoxi,Aoxi Zhen,Le''an Xian,Le’an Xian,Lo-an,Lo-an-hsien,Lo-an-hsien-ch''eng,Lo-an-hsien-ch’eng,ao xi,ao xi zhen,le an xian,乐安县,鳌溪,鳌溪镇', 27.4258900, 115.8364300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19691, 'Aotou', 'Aotou', 'Ao-t''ou-hsu,Ao-t’ou-hsü,Aotou,Aotou Zhen,ao tou,鳌头', 23.6205100, 113.4154100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19692, 'Aotou', 'Aotou', 'Ao-t''ou-chiang,Ao-t’ou-chiang,Aotou,Aotou Jiedao,Otow,Outaokong,Outau,ao tou,ao tou jie dao,澳头,澳头街道', 22.7256000, 114.5355200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19693, 'Aoshi', 'Aoshi', 'Ao-shih,Ao-shih-ts''un,Ao-shih-ts’un,Aoshi,Aoshi Xiang,ao shi,ao shi xiang,鳌石,鳌石乡', 39.9667500, 113.9658700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19694, 'Aoshi', 'Aoshi', 'Ao-shih,Ao-yu-tsui,Ao-yü-tsui,Aoshi,Aoshi Zhen', 26.4016700, 109.0711100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19695, 'Aoqian', 'Aoqian', 'Aoqian,Aoqian Zhen,Kuan-yin-ao,ao qian,ao qian zhen,澳前,澳前镇', 25.4651900, 119.8438800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19696, 'Anzhen', 'Anzhen', 'An-chen,Anzhen,Anzhen Zhen,an zhen,an zhen zhen,安镇,安镇镇', 31.6101200, 120.4698800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19697, 'Qingyang', 'Qingyang', 'An-chen,Anzhenba,Qingyang,Qingyang Zhen,an zhen ba,qing yang,qing yang zhen,安镇坝,青羊,青羊镇', 29.5274300, 107.2007100, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19698, 'Fucheng', 'Fucheng', 'An-tse,Anze,Anze Fucheng Zhen,Anze Xian,Fu-ch''eng,Fu-ch''eng-chen,Fu-ch''eng-tien,Fu-ch’eng,Fu-ch’eng-chen,Fu-ch’eng-tien,Fucheng,Fucheng Zhen,an ze fu cheng zhen,an ze xian,fu cheng,fu cheng zhen,安泽县,安泽府城镇,府城,府城镇', 36.1468400, 112.2335100, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19699, 'Anyuan', 'Anyuan', 'An-yuan-hsun,An-yüan-hsün,Anyuan,an yuan,安远', 26.5769000, 116.6758600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19700, 'Anyi', 'Anyi', 'An-i,An-i Old City,An-i-ch''eng,An-i-chen,An-i-chiu-ch''eng,An-i-chiu-chih,An-i-chiu-ch’eng,An-i-ch’eng,An-i-hsien,Anyi,Anyi Jiedao,Lu-ts''un,Lu-ts’un,an yi,an yi jie dao,安邑,安邑街道', 35.0561100, 111.0336100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19701, 'Anyang', 'Anyang', 'An-yang-chen,An-yang-k''ou,An-yang-k’ou,Anyang,Anyang Zhen,an yang,an yang zhen,安阳,安阳镇', 32.8458000, 111.0107200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19702, 'Anyang', 'Anyang', 'Anyang,Anyang Zhen,Du''an,Du’an,Tu-an,Tu-an-hsien,Tu-an-yao-tsu-tzu-chih-hsien,an yang,an yang zhen,安阳,安阳镇', 23.9379600, 108.0976500, 'CN', '2013-10-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19703, 'Anxiang', 'Anxiang', 'An-hsiang,An-hsiang-hsien,Ansiang,Ansiang-hsien,Anxiang,Anxiang Chengguanzhen,an xiang,an xiang cheng guan zhen,安乡,安乡城关镇', 29.4000000, 112.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19704, 'Anxi', 'Anxi', 'An-hsi,An-hsi-hsu,An-hsi-hsü,Anxi,Anxi Zhen,an xi,an xi zhen,安西,安西镇', 25.2022900, 115.0753800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19705, 'Anwen', 'Anwen', 'An-wen-chen,Anwen,Anwen Zhen,P''an-an,P’an-an,an wen,an wen zhen,安文,安文镇', 29.0595100, 120.4376800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19706, 'Anting', 'Anting', 'An-t''ing-chen,An-t’ing-chen,Anting,Anting Zhen,an ting,an ting zhen,安亭,安亭镇', 31.2989000, 121.1576000, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19707, 'Anshun', 'Anshun', 'AVA,An Thuan,An Thuận,An''shun'',An-shun-hsien,An-shun-hsien-ch''eng,An-shun-hsien-ch’eng,An-shun-shih,An-sun,An-sun-chhi,An-sūn-chhī,An-šun,Ang-song,Anshun,Anshunfu,Ansunas,Anšunas,P''u-ting,P’u-ting,an shun,an shun shi,anshwn,ansun si,Ăng-sông,Аншун,Аньшунь,انشون,安順,安順市,安顺市,안순 시', 26.2500000, 105.9333300, 'CN', '2013-03-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19708, 'Ansha', 'Ansha', 'Ansha,Ansha Zhen,an sha,an sha zhen,安砂,安砂镇', 26.0314300, 117.1241100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19709, 'Anrong', 'Anrong', 'An-jung,An-ying-ts''un,An-ying-ts’un,Anrong,Anrong Xiang,an rong,an rong xiang,安荣,安荣乡', 39.4700000, 112.8147200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19710, 'Anren', 'Anren', 'Anren,an ren,安仁', 26.9693100, 117.4316600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19711, 'Anren Chengguanzhen', 'Anren Chengguanzhen', 'An-jen,An-jen-hsien,Anren,Anren Chengguanzhen,Anren Xian,an ren cheng guan zhen,an ren xian,安仁县,安仁城关镇', 26.7141300, 113.2672600, 'CN', '2013-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19712, 'Anqiu', 'Anqiu', 'An-ch''iu,An-ch''iu-hsien,An-ch’iu,An-ch’iu-hsien,An-kiu,Ankiuhsien,Anqiu', 36.4341700, 119.1925000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19713, 'Anqing', 'Anqing', 'AQG,An Khanh,An Khánh,An''cin,An-cching,An-ch''ing,An-ch''ing-ch''eng,An-ch''ing-shih,An-ch’ing,An-ch’ing-ch’eng,An-ch’ing-shih,An-čching,Ancin,Ancing,Ancingas,Anking,Anqing,Anqing Shi,Ančingas,Ganking,Huai-ning,Huai-ning-hsien,Hwaining,Hwaining-hsien,Nganking,an qing,an qing shi,anching si,ankng,Анцин,Аньцин,Аньцін,Анћинг,ئەنچىڭ شەھىرى,انکنگ,安庆,安庆市,安慶,安慶市,안칭 시', 30.5136500, 117.0472300, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19714, 'Anpu', 'Anpu', 'An-p''u-shih,An-p’u-shih,Anpo,Anpu,Anpu Zhen,Onpo,an bu zhen,an pu,安埔镇,安铺', 21.4547400, 110.0261500, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19715, 'Anping', 'Anping', 'Anping,Anping Xiang,an ping,an ping xiang,安坪,安坪乡', 30.9638400, 109.3450400, 'CN', '2012-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19716, 'Mabai', 'Mabai', 'Anping,Ma-kuan,Ma-kuan-hsien,Ma-pai-kuan,Mabai,Maguan,Makwan,Makwan-hsien,Mapai,ma bai,马白', 23.0127900, 104.4508100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19717, 'Anmenkou', 'Anmenkou', 'An-men-chen,An-men-k''ou-chen,An-men-k’ou-chen,Anmenkou,Anmenkou Zhen,K''ang,K''ang-hsien,K’ang,K’ang-hsien,an men kou,an men kou zhen,岸门口,岸门口镇', 33.2778300, 105.6269000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19718, 'Anlu', 'Anlu', 'An-lu-hsien,Anlu,Te-an,Tean-fu,Teian,Teianfu,an lu,安陆', 31.2575000, 113.6783300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19719, 'Anliu', 'Anliu', 'An-liu-hsu,An-liu-hsü,Anliu,Anliu Zhen,Heng-liu-tu,Wongliutu,an liu,an liu zhen,安流,安流镇', 23.6982400, 115.6795300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19720, 'Anliang', 'Anliang', 'Anliang,Anliang Zhen,an liang,安良', 34.0448800, 113.2625600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19721, 'Anle', 'Anle', 'An-le-ts''un,An-le-ts’un,Anle,Anle Zhen,an le,安乐', 34.5967600, 109.0177700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19722, 'Anle', 'Anle', 'An-le-chai,An-lo-chai,Anle,Anle Zhen,an le,an le zhen,安乐,安乐镇', 34.2214300, 107.6614900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19723, 'Xinggongxia', 'Xinggongxia', 'Anle,Xinggongxia,an le,xing gong xia,安乐,行宫下', 26.1123200, 116.7338500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19724, 'Ankou', 'Ankou', 'Ankou,Ankou Zhen,Ankouzhen,an kou,an kou zhen,安口,安口镇', 35.2219400, 106.7927800, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19725, 'Anju', 'Anju', 'An-chu,An-chu-chen,An-chü,An-chü-chen,Anchushui,Anju,Anju Zhen,Ankuchen,an ju,an ju zhen,安居,安居镇', 31.7450200, 113.2004000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19726, 'Anju', 'Anju', 'An-chu,An-chü,Anju,Anjuba,an ju,安居', 30.3495600, 105.4559400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19727, 'Anju', 'Anju', 'An-chu-chen,An-chü-chen,Anju,Anju Zhen,an ju,an ju zhen,安居,安居镇', 29.9906600, 106.0318600, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19728, 'Anjiang', 'Anjiang', 'An-chiang,An-chiang-chen,Anjiang,Ankiang,Ch''ien-yang,Ch''ien-yang-hsien,Ch’ien-yang,Ch’ien-yang-hsien,Qianyang', 27.3194400, 110.1030600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19729, 'Anjia', 'Anjia', 'Anjia,Anjia Xiang,an jia,an jia xiang,安家,安家乡', 33.0104000, 110.5075500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19730, 'Anhua', 'Anhua', 'Anhua,Anhua Zhen,an hua,an hua zhen,安化,安化镇', 33.5052800, 105.0478200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19731, 'Anhua', 'Anhua', 'An-hua-chen,An-hua-shih,Anhua,Anhua Zhen,an hua,an hua zhen,安华,安华镇', 29.5584400, 120.1141300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19732, 'Anhai', 'Anhai', 'Anhai,Anhai Zhen,an hai,an hai zhen,安海,安海镇', 24.7195800, 118.4707900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19733, 'Angdong', 'Angdong', 'Ang-tung,Angdong,Angdong Xiang,ang dong,ang dong xiang,昂洞,昂洞乡', 28.7687300, 109.5817200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19734, 'Angao', 'Angao', 'An-kao,Angao,Angao Zhen,an gao,an gao zhen,安皋,安皋镇', 33.1160200, 112.3836700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19735, 'Anfu', 'Anfu', 'An-fu-chen,Anbei,Anfu,Anfu Zhen,an bei,an fu,an fu zhen,安北,安富,安富镇', 29.3593700, 105.4674200, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19736, 'Anfusi', 'Anfusi', 'An-fu,An-fu-shih,An-fu-ssu,Anfusi,Anfusi Zhen,Antushih,an fu si,an fu si zhen,安福寺,安福寺镇', 30.5250500, 111.5854900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19737, 'Naxi', 'Naxi', 'Anfu,Na-ch''i,Na-ch''i-hsien,Na-ch’i,Na-ch’i-hsien,Na-hsi,Naxi,na xi,纳溪', 28.7742200, 105.3648800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19738, 'Anfu', 'Anfu', 'An-fu-hsu,An-fu-hsü,Anfu,Anfu Xiang,an fu,an fu xiang,安福,安福乡', 26.6274100, 115.9693500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19739, 'Anfeng', 'Anfeng', 'An-feng-chen,Anfeng,Anfeng Zhen,Pei-an,Pei-an-feng,Pei-an-feng-chen,an feng,an feng zhen,安丰,安丰镇', 33.0894000, 120.0964800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19740, 'Anfeng', 'Anfeng', 'An-feng-chen,Anfeng,Anfeng Zhen,an feng,an feng zhen,安丰,安丰镇', 32.7328100, 120.3984400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19741, 'Andun', 'Andun', 'An-tun,Andun,Andun Zhen,an dun,an dun zhen,安墩,安墩镇', 23.1833300, 115.0051400, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19742, 'Andongwei', 'Andongwei', 'An-tung-chieh,An-tung-wei,Andongwei,Andongwei Jiedao,Lanshan Qu,an dong wei,an dong wei jie dao,lan shan qu,安东卫,安东卫街道,岚山区', 35.1294000, 119.2760000, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19743, 'Andong', 'Andong', 'An-tung,An-tung-shih,Andong,Andong Zhen,Andongzhen,an dong,an dong zhen,庵东,庵东镇', 30.2682300, 121.2158200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19744, 'Anding', 'Anding', 'An-ting,An-ting-ts''un,An-ting-ts’un,Anding,Anding Zhan,Anding Zhen,an ding,an ding zhen,安定,安定镇', 39.6176500, 116.4894900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19745, 'Anchang', 'Anchang', 'An-ch''ang-shih,An-ch’ang-shih,Anchang,Anchang Zhen,an chang,an chang zhen,安昌,安昌镇', 30.1407200, 120.4851100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19746, 'Anchang', 'Anchang', 'An-ch''ang-chen,An-ch’ang-chen,Anchang,Anchang Zhen,an chang,an chang zhen,安场,安场镇,安常', 28.6502300, 107.4257300, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19747, 'Anbu', 'Anbu', 'An-pu,Anbu,Anbu Zhen,an bu,庵埠', 23.4489500, 116.6809200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19748, 'Gangbei', 'Gangbei', 'Anbei,Gangbei,Gangbei Zhen,gang bei,gang bei zhen,岗背,岗背镇', 24.3398800, 115.6970600, 'CN', '2012-08-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19749, 'Altan Xiret', 'Altan Xiret', 'A-t''eng-hsi-lien,A-t’eng-hsi-lien,Altan Xiret,Atengxilian,Atengxilian Zhen,Ejin Horo Qi,I-chin-huo-lo-ch''i,I-chin-huo-lo-ch’i,Yijinhuoluo Qi,a teng xi lian,a teng xi lian zhen,yi jin huo luo qi,伊金霍洛旗,阿腾席连,阿腾席连镇', 39.5772200, 109.7527800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19750, 'Aizhai', 'Aizhai', 'Ai-chai,Aizhai,Aizhai Zhen,ai zhai,ai zhai zhen,矮寨,矮寨镇', 28.3262300, 109.5945200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19751, 'Aitianba', 'Aitianba', 'Aitian,Aitian Xiang,Aitianba,ai tian ba,ai tian xiang,艾田乡,艾田坝', 28.1666700, 104.1666700, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19752, 'Ailibugai', 'Ailibugai', 'Ailibugai,Eribugai,Eribugai Sumu,e ri bu gai,e ri bu gai su mu,额日布盖,额日布盖苏木', 38.8666700, 101.5666700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19753, 'Aicheng', 'Aicheng', 'Aicheng,Aicheng Zhen,Chien-ch''ang,Chien-ch’ang,Kienchang,Kienchanghsien,Yung-hsiu,Yung-hsiu-hsien,Yunghu,Yungsiu,ai cheng,ai cheng zhen,艾城,艾城镇', 29.0881600, 115.7616800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19754, 'Aba', 'Aba', 'A-pa,Aba,Aba Xian,Aba Zhen,Chung-a-pa,Mai-sang,Ngawa,a ba,a ba xian,a ba zhen,阿坝,阿坝县,阿坝镇', 32.9059400, 101.7062500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19755, 'Yangshan', 'Yangshan', 'Lu-ch''u-ch''iao,Lu-ch’ü-ch’iao,Luqu,Luqu Xiang,Luquqiao,Yangshan,Yangshan Zhen,lu qu,yang shan,yang shan zhen,阳山,阳山镇,陆区', 31.5791000, 120.0876200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19756, 'Qiantong', 'Qiantong', 'Ch''ien-t''ung,Ch’ien-t’ung,Qiantong,Qiantong Zhen,qian tong,qian tong zhen,前童,前童镇', 29.2246100, 121.3525500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19757, 'Tianyuan', 'Tianyuan', 'T''ien-yuan-shih,Tianyuan,Tianyuan Zhen,T’ien-yüan-shih,tian yuan,tian yuan zhen,天元,天元镇', 30.1997000, 121.1815500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19758, 'Langxia', 'Langxia', 'Lang-hsia-chen,Langxia,Langxia Jiedao,Langxia Zhen,lang xia,lang xia jie dao,lang xia zhen,朗霞,朗霞街道,朗霞镇', 30.1677800, 121.0750000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19759, 'Ma’ao', 'Ma''ao', 'Loumenkou,Ma''ao,Ma''ao Zhen,Ma''aozhen,Ma-ao (2),Ma’ao,Ma’ao Zhen,Ma’aozhen,lou men kou,ma ao,ma ao zhen,楼门口,马岙,马岙镇', 30.1137700, 122.0867000, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19760, 'Xiaosha', 'Xiaosha', 'Hsiao-sha-chuang,Xiaosha,Xiaosha Zhen,xiao sha,xiao sha zhen,小沙,小沙镇', 30.1077900, 122.0577900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19761, 'Yanguan', 'Yanguan', 'Guodian,Guodian Zhen,Kuo-tien-chen,Yanguan,Yanguan Zhen,guo dian,guo dian zhen,yan guan,yan guan zhen,盐官,盐官镇,郭店,郭店镇', 30.4560700, 120.5467300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19762, 'Maqiao', 'Maqiao', 'Ma-ch''iao-chen,Ma-ch’iao-chen,Maqiao,Maqiao Jiedao,Maqiao Zhen,ma qiao,ma qiao jie dao,ma qiao zhen,马桥,马桥街道,马桥镇', 30.4644900, 120.6979200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19763, 'Nankai', 'Nankai', 'Lieh-pao,Nankai,Nankai Xiang,nan kai,nan kai xiang,南开,南开乡', 19.0800000, 109.4086000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19764, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,Ta-ts''un,Ta-ts’un,bai sha,bai sha zhen,白沙,白沙镇', 19.1914200, 109.4478700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19765, 'Xinwan', 'Xinwan', 'Hsin-wan-ti,Xinwan,Xinwan Zhen,xin wan,xin wan zhen,新湾,新湾镇', 30.2788900, 120.5385700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19766, 'Dangshan', 'Dangshan', 'Dangshan,Dangshan Zhen,Tang-shan-shih,dang shan,dang shan zhen,党山,党山镇', 30.1644300, 120.5190000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19767, 'Linjiang', 'Linjiang', 'Houzhi,Linjiang,Linjiang Zhen,hou zhi,lin jiang,lin jiang zhen,临江,临江镇,后支', 28.1333400, 120.4872700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19768, 'Shuangchao', 'Shuangchao', 'Dong''ao,Dong’ao,Shuangchao,Shuangchao Xiang,dong ao,shuang chao,shuang chao xiang,东岙,双朝,双朝乡', 28.1404100, 120.4442400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19769, 'Fangshan', 'Fangshan', 'Fangshan,Fangshan Xiang,Hsu-ch''ien,Hsü-ch’ien,Shiqian,fang shan,fang shan xiang,方山,方山乡', 28.0236000, 120.3135000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19770, 'Gui’ao', 'Gui''ao', 'Gui''ao,Gui''ao Xiang,Gui’ao,Gui’ao Xiang,Kuei-ao,gui ao,gui ao xiang,贵岙,贵岙乡', 28.1736400, 120.3530400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19771, 'Xiaozhoushan', 'Xiaozhoushan', 'Hsiao-tsou-shan,Xiaozhoushan,Xiaozhoushan Xiang,xiao zhou shan,xiao zhou shan xiang,小舟山,小舟山乡', 28.2065100, 120.3841500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19772, 'Wukeng', 'Wukeng', 'Wukeng,Wukeng Xiang,Yu-k''eng,Yü-k’eng,wu keng,wu keng xiang,吴坑,吴坑乡', 28.2419300, 120.4020100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19773, 'Qiaotou', 'Qiaotou', 'Ch''iao-t''ou-ts''un,Ch’iao-t’ou-ts’un,Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 28.1703200, 120.4737200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19774, 'Shiran', 'Shiran', 'Shih-jan-ts''un,Shih-jan-ts’un,Shiran,Shiran Xiang,shi ran,shi ran xiang,石染,石染乡', 28.3505800, 120.4084000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19775, 'Yingkeng', 'Yingkeng', 'Yingkeng,Yingkeng Xiang,ying keng,ying keng xiang,应坑,应坑乡', 28.3940600, 120.5016800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19776, 'Wanshan', 'Wanshan', 'Sunku,Wanshan,Wanshan Xiang,sun ku,wan shan,wan shan xiang,万山,万山乡,孙窟', 28.3356500, 120.3082000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19777, 'Muli', 'Muli', 'Muli,Muli Xiang,mu li,mu li xiang,木栗,木栗乡', 28.4491800, 120.3409800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19778, 'Nanxi', 'Nanxi', 'Nan-ch''i,Nan-ch’i,Nanxi,Nanxi Xiang,nan xi,nan xi xiang,南溪,南溪乡', 28.4955300, 120.3088300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19779, 'Sanxi', 'Sanxi', 'Houwu,Sanxi,Sanxi Xiang,hou wu,san xi,san xi xiang,三溪,三溪乡,后吴', 28.7027100, 120.2776000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19780, 'Qianlu', 'Qianlu', 'Ch''ien-lu,Ch’ien-lu,Qianlu,Qianlu Xiang,qian lu,qian lu xiang,前路,前路乡', 28.7677700, 120.2606300, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19781, 'Yanling', 'Yanling', 'Yanling,Yanling Xiang,Yanmen,Zuoku,yan ling,yan ling xiang,zuo ku,左库,雁岭,雁岭乡', 28.8330700, 120.2883000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19782, 'Lengshui', 'Lengshui', 'Lengshui,Lengshui Zhen,leng shui,leng shui zhen,冷水,冷水镇', 28.8999400, 120.3461500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19783, 'Baizhu', 'Baizhu', 'Baizhu,Baizhu Xiang,bai zhu,bai zhu xiang,白竹,白竹乡', 28.9096900, 120.2844900, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19784, 'Shuangfeng', 'Shuangfeng', 'Damin,Shuangfeng,Shuangfeng Xiang,Ta-min,da min,shuang feng,shuang feng xiang,双峰,双峰乡,大皿', 28.9250000, 120.4575800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19785, 'Lingdi', 'Lingdi', 'Lingdi,Lingdi Xiang,Nanchong,ling di,ling di xiang,nan chong,南充,岭底,岭底乡', 28.2859100, 120.9483000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19786, 'Donggao', 'Donggao', 'Donggao,Donggao Xiang,Tung-kao,dong gao,dong gao xiang,东皋,东皋乡', 28.3813100, 120.8046200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19787, 'Huangyang', 'Huangyang', 'Huangyang,Huangyang Xiang,Shipingchuan,huang yang,huang yang xiang,shi ping chuan,石平川,黄垟,黄垟乡', 28.2963000, 120.3514700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19788, 'Lixi', 'Lixi', 'Li-ch''i,Li-ch’i,Lixi,Lixi Xiang,li xi,li xi xiang,鲤溪,鲤溪乡', 28.4105000, 120.7729800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19789, 'Xiyuan', 'Xiyuan', 'Hsi-k''eng-ts''un,Hsi-k’eng-ts’un,Xiyuan,Xiyuan Xiang,xi yuan,xi yuan xiang,西源,西源乡', 28.4149100, 120.8383600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19790, 'Shuangyu', 'Shuangyu', 'Lu-t''ou-ts''un,Lu-t’ou-ts’un,Shuangyu,Shuangyu Zhen,shuang yu,shuang yu zhen,双屿,双屿镇', 28.0188400, 120.6065200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19791, 'Xialiao', 'Xialiao', 'Hsia-liao-ts''un,Hsia-liao-ts’un,Xialiao,Xialiao Xiang,xia liao,xia liao xiang,下寮,下寮乡', 28.2176600, 120.6883600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19792, 'Xu’ao', 'Xu''ao', 'Xu''ao,Xu''ao Xiang,Xu’ao,Xu’ao Xiang,Yu-ch''e-ts''un,Yu-ch’e-ts’un,xu ao,xu ao xiang,徐岙,徐岙乡', 28.1994200, 120.5685400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19793, 'Lingtou', 'Lingtou', 'Ling-t''ou-ts''un,Ling-t’ou-ts’un,Lingtou,Lingtou Xiang,ling tou,ling tou xiang,岭头,岭头乡', 28.4351400, 120.9141800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19794, 'Fushan', 'Fushan', 'Banshan,Fushan,Fushan Xiang,Pan-shan,fu shan,fu shan xiang,富山,富山乡', 28.5315500, 120.8856000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19795, 'Shangyang', 'Shangyang', 'Shangyang,Shangyang Xiang,shang yang,shang yang xiang,上垟,上垟乡', 28.5199800, 121.0017700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19796, 'Shangzheng', 'Shangzheng', 'Hsia-cheng,Shangzheng,Shangzheng Zhen,shang zheng,shang zheng zhen,上郑,上郑镇', 28.5983300, 120.9242300, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19797, 'Zhuxi', 'Zhuxi', 'Chu-ch''i,Chu-ch’i,Zhuxi,Zhuxi Zhen,zhu xi,zhu xi zhen,朱溪,朱溪镇', 28.7259000, 120.8335700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19798, 'Shuangmiao', 'Shuangmiao', 'Shuang-miao-shih,Shuangmiao,Shuangmiao Xiang,shuang miao,shuang miao xiang,双庙,双庙乡', 28.7949400, 120.8475000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19799, 'Dazhan', 'Dazhan', 'Dazhan,Dazhan Zhen,da zhan,da zhan zhen,大战,大战镇', 28.8218700, 120.8141100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19800, 'Xiangyang', 'Xiangyang', 'Hesheng,P''an-yang,P’an-yang,Xiangyang,Xiangyang Zhen,he sheng,xiang yang,xiang yang zhen,荷盛,象阳,象阳镇', 28.0343000, 120.9291500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19801, 'Doumen', 'Doumen', 'Doumen,Doumen Xiang,dou men,dou men xiang,陡门,陡门乡', 28.2009100, 120.8318500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19802, 'Huatan', 'Huatan', 'Huatan,Huatan Xiang,hua tan,hua tan xiang,花坦,花坦乡', 28.2630000, 120.8163100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19803, 'Oubei', 'Oubei', 'Ch''ing-shui-fou,Ch’ing-shui-fou,Oubei,Oubei Zhen,Qingshuibu,Qingshuibuzhen,ou bei,ou bei zhen,qing shui bu,清水埠,瓯北,瓯北镇', 28.0468700, 120.6531300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19804, 'Tiaolou', 'Tiaolou', 'Tiaolou,Tiaolou Zhen,diao lou,diao lou zhen,调楼,调楼镇', 19.9387700, 109.5350300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19805, 'Changliu', 'Changliu', 'Changliu,Changliu Zhen,Na-liu-shih,zhang liu,zhang liu zhen,长流,长流镇', 20.0132700, 110.2008700, 'CN', '2012-05-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19806, 'Zhonghe', 'Zhonghe', 'Chiu-tan-hsien,Zhonghe,Zhonghe Zhen,zhong he,zhong he zhen,中和,中和镇', 19.7427600, 109.3449200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19807, 'Tayang', 'Tayang', 'Tayang,Tayang Zhen,ta yang,ta yang zhen,塔洋,塔洋镇', 19.2913500, 110.5047000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19808, 'Haifeng', 'Haifeng', 'Haifeng,Haifeng Zhen,hai feng,hai feng zhen,海丰,海丰镇', 32.1648600, 121.3825300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19809, 'Zhengyu', 'Zhengyu', 'Zhengyu,Zhengyu Zhen,zheng yu,zheng yu zhen,正余,正余镇', 32.0648200, 121.3619400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19810, 'Huolong', 'Huolong', 'Huo-lung-chen,Huolong,Huolong Zhen,Huolongzhen,huo long,huo long zhen,货隆,货隆镇', 32.0563200, 121.2707600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19811, 'Antou', 'Antou', 'An-t''ou-chen,An-t’ou-chen,Antou,Antou Zhen,Antouzhen,Wanghao,Wanghao Zhen,an tou,an tou zhen,wang hao,wang hao zhen,岸头,岸头镇,王浩,王浩镇', 32.0613900, 121.3168600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19812, 'Xingdong', 'Xingdong', 'Xingdong,Xingdong Zhen,Yangshiqiao,xing dong,xing dong zhen,yang shi qiao,兴东,兴东镇,杨世桥', 32.0826500, 120.9682800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19813, 'Jiangyou', 'Jiangyou', '', 31.7666700, 104.7166700, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19814, 'Xincao', 'Xincao', 'Xincao,Xincao Zhen,xin cao,xin cao zhen,新曹,新曹镇', 32.8842500, 120.7616400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19815, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 32.6795300, 120.7734200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19816, 'Xianfeng', 'Xianfeng', 'Sanxutou,Xianfeng,Xianfeng Zhen,san wei tou,xian feng,xian feng zhen,三圩头,先锋,先锋镇', 32.0103800, 120.9794000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19817, 'Pingdong', 'Pingdong', 'Pingdong,Pingdong Zhen,ping dong,ping dong zhen,平东,平东镇', 32.1227100, 120.7787600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19818, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,he kou,he kou zhen,河口,河口镇', 32.4925900, 120.8231300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19819, 'Wanying', 'Wanying', 'Wanying,Wanying Zhen,wan ying,wan ying zhen,万盈,万盈镇', 33.0486700, 120.5708900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19820, 'Suzhou', 'Suzhou', 'SZV,So-chiu-chhi,Soutsoou,So͘-chiu-chhī,Su-chou,Su-chu-su,Su-ciu,Su-cou,Su-čou,Suchjou,Suchzhou,Sudzhou,Sudzou,Sudžou,Sugouo,Sutsjou,Suzhou,Suzhou Shi,Suzhou i Jiangsu,Suĝoŭo,Szucsou,Sû-chû-sṳ,Sŭ-ciŭ,To Chau,Tô Châu,Wu-hsien,cuco,ssujeou si,su cow,su zhou,su zhou shi,sujho''u,suzu,swgwʼw,swjw,swzhw,swzhww,Σουτσόου,Суджоу,Сучжоу,Сучжоў,Суџоу,Сүжоу,Սուչժոու,סוגואו,سوجو,سوژو,سوژوو,سۇجۇ شەھىرى,सूझोऊ,ਸੂਜ਼ੂ,சுசோ,ซูโจว,苏州,苏州市,蘇州,蘇州市,쑤저우 시', 31.3040800, 120.5953800, 'CN', '2015-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19821, 'Zhoushan', 'Zhoushan', 'Chzhoushan'',Dinghai Qu,HSN,Zhoushan,Zhoushan Shi,ding hai,ding hai qu,zhou shan,zhou shan shi,Чжоушань,定海,定海区,舟山,舟山市', 29.9886900, 122.2048800, 'CN', '2014-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19822, 'Huaihelu', 'Huaihelu', 'Huaihelu,huai he lu,淮河路', 34.7163800, 113.6413800, 'CN', '2015-06-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19823, 'Goushan', 'Goushan', 'Goushan,Goushan Jiedao,Goushanzhen,Kou-shan,gou shan,gou shan jie dao,gou shan zhen,勾山,勾山街道,勾山镇', 29.9778600, 122.2655700, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19824, 'Fuming', 'Fuming', 'Fuming,Fuming Jiedao,fu ming,fu ming jie dao,福明,福明街道', 29.8731600, 121.6018600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19825, 'Shiqi', 'Shiqi', 'Shih-ch''i,Shih-ch’i,Shiqi,Shiqi Zhen,shi qi,shi qi zhen,石碶,石碶镇', 29.8225000, 121.5044400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19826, 'Zhonggongmiao', 'Zhonggongmiao', 'Zhonggongmiao,Zhonggongmiao Zhen,zhong gong miao,zhong gong miao zhen,钟公庙,钟公庙镇', 29.8261100, 121.5375000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19827, 'Xiaying', 'Xiaying', 'Hsia-ying-chen,Xiaying,Xiaying Zhen,xia ying,xia ying zhen,下应,下应镇', 29.8047200, 121.5913900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19828, 'Yunlong', 'Yunlong', 'Yun-lung-ch''i-chen,Yunlong,Yunlong Zhen,Yün-lung-ch’i-chen,yun long,yun long zhen,云龙,云龙镇', 29.7744000, 121.5918400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19829, 'Dongwu', 'Dongwu', 'Dongwu,Dongwu Zhen,Tung-wu-chen,dong wu,dong wu zhen,东吴,东吴镇', 29.8088900, 121.7225000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19830, 'Jinhai', 'Jinhai', 'Jinhai,jin hai,近海', 31.9175000, 121.7788500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19831, 'Huiping', 'Huiping', 'Huiping,Huiping Zhen,hui ping,hui ping zhen,惠萍,惠萍镇', 31.7640800, 121.7779100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19832, 'Donghai', 'Donghai', 'Donghai,Donghai Zhen,dong hai,dong hai zhen,东海,东海镇', 31.7684100, 121.8705100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19833, 'Hehe', 'Hehe', 'Hehe,Hehe Zhen,Ho-ho Chen,he he,he he zhen,和合,和合镇', 31.7383600, 121.8034100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19834, 'Dajiahe', 'Dajiahe', 'Dajiahe,Dajiahe Zhen,Ta-chu-ho,Ta-chü-ho,da jia he,da jia he zhen,大佳何,大佳何镇', 29.4288900, 121.5505600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19835, 'Fenghuang', 'Fenghuang', 'Fenghuang,Fenghuang Zhen,Fenghuangcun,feng huang,feng huang zhen,凤凰,风凰镇', 18.3010000, 109.4475400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19836, 'Sizhoutou', 'Sizhoutou', 'Sizhoutou,Sizhoutou Zhen,Ssu-chou-t''ou,Ssu-chou-t’ou,si zhou tou,si zhou tou zhen,泗洲头,泗洲头镇', 29.3727800, 121.7675000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19837, 'Xinqiao', 'Xinqiao', 'Hsin-ch''iao-chen,Hsin-ch’iao-chen,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 29.3177800, 121.8616700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19838, 'Tuci', 'Tuci', 'T''u-tz''u-chen,Tuci,Tuci Zhen,T’u-tz’u-chen,tu ci,tu ci zhen,涂茨,涂茨镇', 29.5572200, 121.9336100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19839, 'Xianxiang', 'Xianxiang', 'Hsien-yang,Xianxiang,Xianxiang Zhen,xian xiang,xian xiang zhen,贤庠,贤庠镇', 29.5877800, 121.8427800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19840, 'Baifeng', 'Baifeng', 'Baifeng,Baifeng Zhen,Pai-feng-ts''un,Pai-feng-ts’un,bai feng,bai feng zhen,白峰,白峰镇', 29.8777800, 121.9919400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19841, 'Xiapu', 'Xiapu', 'Hsia-p''u-chen,Hsia-p’u-chen,Xiapu,Xiapu Zhen,xia pu,xia pu zhen,霞浦,霞浦镇', 29.8890200, 121.8803000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19842, 'Li’ao', 'Li''ao', 'Li''ao,Li-ao,Li’ao,Meishan,li ao,mei shan,梅山,里岙', 29.7983300, 121.9888900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19843, 'Tianfen', 'Tianfen', 'Tianfen,Tianfen Zhen,tian fen,tian fen zhen,天汾,天汾镇', 32.0630800, 121.5415800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19844, 'Caobu', 'Caobu', 'Caobu,Caobu Zhen,Ts''ao-chia-fou,Ts’ao-chia-fou,cao bu,cao bu zhen,曹埠,曹埠镇', 32.2494800, 121.0883900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19845, 'Zhangjiayuan', 'Zhangjiayuan', 'Chang-chia-yuan,Chang-chia-yüan,Huangang,Huangang Zhen,Zhangjiayuan,huan gang,huan gang zhen,zhang jia yuan,张家园,环港,环港镇', 32.4539800, 121.0920100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19846, 'Wujie', 'Wujie', 'Wu-chieh-ch''iao,Wu-chieh-ch’iao,Wujie,Wujie Zhen,wu jie,wu jie zhen,五接,五接镇', 32.0865100, 120.6809600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19847, 'Wuyao', 'Wuyao', 'Wu-chia-yao-tu,Wuyao,Wuyao Zhen,wu yao,wu yao zhen,吴窑,吴窑镇', 32.2046700, 120.5444700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19848, 'Lupu', 'Lupu', 'Jingtou,Lu-ao,Lupu,Lupu Zhen,jing tou,lu pu,lu pu zhen,井头,芦浦,芦浦镇', 28.1921000, 121.2364200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19849, 'Lincheng', 'Lincheng', 'Lincheng,Lincheng Jiedao,Linchengzhen,lin cheng,lin cheng jie dao,lin cheng zhen,临城,临城街道,临城镇', 29.9964600, 122.2004100, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19850, 'Haishan', 'Haishan', 'Haishan,Haishan Xiang,hai shan,hai shan xiang,海山,海山乡', 28.2254100, 121.1654800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19851, 'Nanyue', 'Nanyue', 'Nanyue,Nanyue Zhen,nan yue,nan yue zhen,南岳,南岳镇', 28.1862000, 121.0798200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19852, 'Tiancheng', 'Tiancheng', 'Tiancheng,Tiancheng Xiang,tian cheng,tian cheng xiang,天成,天成乡', 28.1714300, 121.0310400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19853, 'Jiguan', 'Jiguan', 'Chi-kuan-chiao-ts''un,Chi-kuan-chiao-ts’un,Dengbu,Dengbu Xiang,Jiguan,deng bu,deng bu xiang,ji guan,登步,登步乡,鸡冠', 29.8798000, 122.2963000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19854, 'Gongqian', 'Gongqian', 'Gongqian,Kuan-chien-ts''un,Kuan-chien-ts’un,Taohua,Taohua Zhen,gong qian,tao hua,tao hua zhen,公前,桃花,桃花镇', 29.8327900, 122.2765000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19855, 'Shifan', 'Shifan', 'Hsi-p''o-hu,Hsi-p’o-hu,Pohu,Shifan,Shifan Zhen,Xipohu,pu hu,shi fan,shi fan zhen,朴湖,石帆,石帆镇', 28.1934600, 121.0215100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19856, 'Huwu', 'Huwu', 'Hu-wu-chieh,Huwu,Huwu Zhen,hu wu,hu wu zhen,湖雾,湖雾镇', 28.3976600, 121.2043700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19857, 'Yandang', 'Yandang', 'Mao-yang,Songyang,Yandang,Yandang Zhen,song yang,yan dang,yan dang zhen,松垟,雁荡,雁荡镇', 28.3543600, 121.1400200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19858, 'Longxi', 'Longxi', 'Longxi,Longxi Xiang,long xi,long xi xiang,龙西,龙西乡', 28.3955100, 121.0433800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19859, 'Shuangfeng', 'Shuangfeng', 'Shuangfeng,Shuangfeng Xiang,shuang feng,shuang feng xiang,双峰,双峰乡', 28.4195800, 121.1270900, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19860, 'Zhen’an', 'Zhen''an', 'Shih-t''an-chien,Shih-t’an-chien,Shitan,Zhen''an,Zhen''an Xiang,Zhen’an,Zhen’an Xiang,shi tan,zhen an,zhen an xiang,石坦,镇安,镇安乡', 28.4668900, 121.1620500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19861, 'Shahe', 'Shahe', 'Sha-ho,Shahe,Shahe Zhen,sha he,sha he zhen,沙河,沙河镇', 23.9941700, 112.8791700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19862, 'Timian', 'Timian', 'Timian,Timian Zhen,ti mian,ti mian zhen,梯面,梯面镇', 23.5493900, 113.2876900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19863, 'Fengcun', 'Fengcun', 'Feng-ts''un,Feng-ts’un,Fengcun,Fengcun Zhen,feng cun,feng cun zhen,凤村,凤村镇', 23.2326400, 112.0934800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19864, 'Qidu', 'Qidu', 'Ch''i-tu-t''u,Ch’i-tu-t’u,Laotu,Qidu,Qidu Zhen,Qidutou,lao tu,qi dou,qi dou zhen,七都,七都镇,老涂', 28.0079100, 120.7637400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19865, 'Lishui', 'Lishui', 'Lishui,Lishui Zhen,li shui,li shui zhen,里水,里水镇', 23.2011100, 113.1600000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19866, 'Wangniudun', 'Wangniudun', 'Wang-niu-tun,Wangniudun,Wangniudun Zhen,Wanniudun Zhen,wang niu dun,wang niu dun zhen,望牛墩,望牛墩镇', 23.0525000, 113.6472200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19867, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Zhen,cheng bei,cheng bei zhen,城北,城北镇', 28.1640000, 120.9067600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19868, 'Lianzhou', 'Lianzhou', 'Lianzhou,Lianzhou Zhen,lian zhou,lian zhou zhen,连州,连州镇', 22.6359100, 111.4339800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19869, 'Baizhu', 'Baizhu', 'Baizhu,Baizhu Zhen,Pai-chu-wai,bai zhu,bai zhu zhen,白诸,白诸镇', 22.9516900, 112.3452300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19870, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Zhen,Tung-ch''eng-hsu,Tung-ch’eng-hsü,dong cheng,dong cheng zhen,东成,东成镇', 22.6862300, 112.3189400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19871, 'Shuitai', 'Shuitai', 'Shuitai,Shuitai Zhen,shui tai,shui tai zhen,水台,水台镇', 22.6193500, 112.4678300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19872, 'Longkou', 'Longkou', 'Longkou,Longkou Zhen,Lung-k''ou,Lung-k’ou,long kou,long kou zhen,龙口,龙口镇', 22.7742600, 112.9070800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19873, 'Lile', 'Lile', 'Lile,Lile Jiedao,Liyue,li le,li le jie dao,礼乐,礼乐街道', 22.5364500, 113.0829500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19874, 'Dacheng', 'Dacheng', 'Dacheng,Dacheng Zhen,Ta-ch''eng-hsu,Ta-ch’eng-hsü,da cheng,da cheng zhen,大成,大成镇', 22.2977600, 111.1055200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19875, 'Daba', 'Daba', 'Daba,Daba Zhen,Ta-pa-hsu,Ta-pa-hsü,da ba,da ba zhen,大八,大八镇', 22.0733800, 111.9603400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19876, 'Nalong', 'Nalong', 'Na-lung,Nalong,Nalong Zhen,Nalongxu,na long,na long zhen,那龙,那龙镇', 22.0369700, 112.2088600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19877, 'Niujiang', 'Niujiang', 'Niu-chiang-tu-hsu,Niu-chiang-tu-hsü,Niujiang,Niujiang Zhen,niu jiang,niu jiang zhen,牛江,牛江镇', 22.3761600, 112.3795000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19878, 'Aotou', 'Aotou', 'Aotou,Aotou Zhen,ao tou,ao tou zhen,鳌头,鼇头镇', 21.5533300, 110.8575300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19879, 'Yangjiao', 'Yangjiao', 'Yang-chiao-hsu,Yang-chiao-hsü,Yangjiao,Yangjiao Zhen,yang jiao,yang jiao zhen,羊角,羊角镇', 21.6777200, 110.9838700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19880, 'Mata', 'Mata', 'Ma-t''a-hsu,Ma-t’a-hsü,Mata,Mata Zhen,ma ta,ma ta zhen,马踏,马踏镇', 21.6070500, 111.3467500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19881, 'Yashao', 'Yashao', 'Yashao,Yashao Zhen,ya shao,ya shao zhen,雅韶,雅韶镇', 21.8219000, 112.0489300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19882, 'Dacheng', 'Dacheng', 'Dacheng,Dacheng Zhen,Ta-ch''eng,Ta-ch’eng,da cheng,da cheng zhen,大成,大成镇', 19.5092700, 109.3927500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19883, 'Laocheng', 'Laocheng', 'Chiu-ch''eng-mai,Chiu-ch’eng-mai,Laocheng,Laocheng Zhen,lao cheng,lao cheng zhen,老城,老城镇', 19.9642200, 110.1193300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19884, 'Shishan', 'Shishan', 'Shih-shan-shih,Shishan,Shishan Zhen,shi shan,shi shan zhen,石山,石山镇', 19.9354600, 110.2043200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19885, 'Longtang', 'Longtang', 'Longtang,Longtang Zhen,Lung-t''ang,Lung-t’ang,long tang,long tang zhen,龙塘,龙塘镇', 19.8843000, 110.4110100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19886, 'Xinpo', 'Xinpo', 'Hsin-p''o,Hsin-p’o,Xinpo,Xinpo Zhen,xin po,xin po zhen,新坡,新坡镇', 19.7716500, 110.3654600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19887, 'Jiazi', 'Jiazi', 'Chia-tzu-shih,Jiazi,Jiazi Zhen,jia zi,jia zi zhen,甲子,甲子镇', 19.6093100, 110.4942600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19888, 'Leiming', 'Leiming', 'Lei-ming-shih,Leiming,Leiming Zhen,lei ming,lei ming zhen,雷鸣,雷鸣镇', 19.5571800, 110.3199100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19889, 'Gongpo', 'Gongpo', 'Gongpo,Gongpo Zhen,K''ung-p''o-shih,K’ung-p’o-shih,gong po,gong po zhen,公坡,公坡镇', 19.7921600, 110.8036800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19890, 'Baoluo', 'Baoluo', 'Baoluo,Baoluo Zhen,P''o-lo,P’o-lo,bao luo,bao luo zhen,抱罗,抱罗镇', 19.8412300, 110.7445300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19891, 'Sigeng', 'Sigeng', 'Sigeng,Sigeng Zhen,Ssu-keng,si geng,si geng zhen,四更,四更镇', 19.2281000, 108.6735600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19892, 'Wupo', 'Wupo', 'Wupo,Wupo Zhen,wu po,wu po zhen,乌坡,乌坡镇', 19.1842900, 110.0672200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19893, 'Lingkou', 'Lingkou', 'Ling-k''ou-shih,Ling-k’ou-shih,Lingkou,Lingkou Zhen,ling kou,ling kou zhen,岭口,岭口镇', 19.3439700, 110.3039200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19894, 'Yangjiang', 'Yangjiang', 'Yang-chiang,Yangjiang,Yangjiang Zhen,yang jiang,yang jiang zhen,阳江,阳江镇', 19.1008900, 110.3431300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19895, 'Benhao', 'Benhao', 'Benhao,Benhao Zhen,Penhao,ben hao,ben hao zhen,本号,本号镇', 18.6151300, 109.9307500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19896, 'Sidu', 'Sidu', 'Meixi,Sidu,Sidu Xiang,mei xi,si dou,si dou xiang,四都,四都乡,梅溪', 28.2162300, 120.9541800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19897, 'Leluo', 'Leluo', 'Leluo,Leluo Zhen,Lo-lo-shih,le luo,le luo zhen,乐罗,乐罗镇', 18.4480800, 108.8824500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19898, 'Putuoshan', 'Putuoshan', 'Putuoshan,Putuoshan Zhen,pu tuo shan,pu tuo shan zhen,普陀山,普陀山镇', 29.9865700, 122.3804700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19899, 'Dadong’ao', 'Dadong''ao', 'Dadong''ao,Dadong’ao,Zhujiajian,Zhujiajian Zhen,da dong ao,zhu jia jian,zhu jia jian zhen,大洞岙,朱家尖,朱家尖镇', 29.9222800, 122.3888100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19900, 'Zhongzhan', 'Zhongzhan', 'Li-feng,Zhongzhan,zhong zhan,中站', 35.2413900, 113.1602800, 'CN', '2015-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19901, 'Jiujianfang', 'Jiujianfang', 'Jiujianfang,Mu-chia-yen,jiu jian fang,九间房', 34.1858000, 109.5151300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19902, 'Zhangguanying', 'Zhangguanying', 'Chang-kuan-ying,Zhangguanying,Zhangguanying Zhen,zhang guan ying,zhang guan ying zhen,张官营,张官营镇', 33.6540800, 113.1745500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19903, 'Zhangpan', 'Zhangpan', 'Chang-p''an-chen,Chang-p’an-chen,Zhangpan,Zhangpan Zhen,zhang pan,zhang pan zhen,张潘,张潘镇', 33.9925600, 113.9903900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19904, 'Duqu', 'Duqu', 'Duqu,Duqu Zhen,Tu-chieh,du qu,du qu zhen,杜曲,杜曲镇', 33.8130700, 113.8632900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19905, 'Liuquan', 'Liuquan', 'Liu-ch''uan-p''u,Liu-ch’üan-p’u,Liuquan,Liuquanpu,liu quan,liu quan pu,柳泉,柳泉铺', 33.0475800, 112.3351000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19906, 'Huiwan', 'Huiwan', 'Huiwan,Huiwan Xiang,Xiaohekou,hui wan,hui wan xiang,汇湾,汇湾乡', 32.1409100, 109.8159500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19907, 'Guyi', 'Guyi', 'Guyi,Guyi Zhen,Yeh-wa,gu yi,gu yi zhen,古驿,古驿镇', 32.2619900, 112.2299400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19908, 'Zhangjiaji', 'Zhangjiaji', 'Chang-chia-chi,Zhangjiaji,Zhangjiaji Zhen,zhang jia ji,zhang jia ji zhen,张家集,张家集镇', 32.1042400, 112.4366200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19909, 'Xiaolin', 'Xiaolin', 'Hsiao-lin-tien,Xiaolin,Xiaolin Zhen,Xiaolindian,xiao lin,xiao lin zhen,小林,小林镇', 32.3146200, 113.7220100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19910, 'Shaochang', 'Shaochang', 'Shaochang,Shaochang Zhen,shao chang,shao chang zhen,邵厂,邵厂镇', 30.9083000, 121.7534500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19911, 'Quantang', 'Quantang', 'Quantang,Quantangzhen,quan tang,quan tang zhen,全塘,全塘镇', 30.6820800, 121.2238900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19912, 'Xiaozhi', 'Xiaozhi', 'Hsiao-chih-shih,Xiaozhi,Xiaozhi Zhen,xiao zhi,xiao zhi zhen,小芝,小芝镇', 28.8536900, 121.4527400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19913, 'Jishan', 'Jishan', 'Beibianshan,Chi-kuan-shan,Jishan,Jishan Xiang,bei bian shan,ji shan,ji shan xiang,北边山,鸡山,鸡山乡', 28.1077500, 121.3660700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19914, 'Ganjiang', 'Ganjiang', 'Ganjiang,Ganjiang Zhen,Xia''angong,Xia’angong,gan jiang,gan jiang zhen,xia an gong,下岸宫,干江,干江镇', 28.1606300, 121.3509000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19915, 'Longxi', 'Longxi', 'Hua-yen-p''u,Hua-yen-p’u,Huayanpu,Longxi,Longxi Xiang,hua yan pu,long xi,long xi xiang,花岩浦,龙溪,龙溪乡', 28.1980900, 121.3040200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19916, 'Hengjie', 'Hengjie', 'Heng-chieh-chen,Hengjie,Hengjie Zhen,heng jie,heng jie zhen,横街,横街镇', 28.5326400, 121.4362500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19917, 'Maoshan', 'Maoshan', 'Mao-shan-ts''un,Mao-shan-ts’un,Maoshan,Maoshan Zhen,mao shan,mao shan zhen,茅山,茅山镇', 29.7457200, 121.4958600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19918, 'Pengjie', 'Pengjie', 'Pengjie,Pengjie Zhen,peng jie,peng jie zhen,蓬街,蓬街镇', 28.5554400, 121.4805200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19919, 'Fengjiang', 'Fengjiang', 'Fengjiang,Fengjiang Jiedao,feng jiang,feng jiang jie dao,峰江,峰江街道', 28.5402900, 121.3738100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19920, 'Xiachen', 'Xiachen', 'Hsia-ch''en-shih,Hsia-ch’en-shih,Xiachen,Xiachen Jiedao,xia chen,xia chen jie dao,下陈,下陈街道', 28.5893100, 121.4498400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19921, 'Tongyu', 'Tongyu', 'T''ung-yu,Tongyu,Tongyu Jiedao,T’ung-yu,tong yu,tong yu jie dao,桐屿,桐屿街道', 28.5920700, 121.3305600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19922, 'Jiangkou', 'Jiangkou', 'Chiang-pian-chin,Jiangkou,Jiangkou Jiedao,jiang kou,jiang kou jie dao,江口,江口街道', 28.6769400, 121.3180600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19923, 'Jiazhi', 'Jiazhi', 'Jiazhi,Jiazhi Jiedao,Tuan-chih-chen,jia zhi,jia zhi jie dao,葭沚,葭沚街道', 28.6736800, 121.3778100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19924, 'Zhang’an', 'Zhang''an', 'Chang-an,Zhang''an,Zhang''an Jiedao,Zhang’an,Zhang’an Jiedao,zhang an,zhang an jie dao,章安,章安街道', 28.7149400, 121.4102900, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19925, 'Shiqiaotou', 'Shiqiaotou', 'Shih-ch''iao-t''ou-shih,Shih-ch’iao-t’ou-shih,Shiqiaotou,Shiqiaotou Zhen,shi qiao tou,shi qiao tou zhen,石桥头,石桥头镇', 28.3560600, 121.4511700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19926, 'Wugen', 'Wugen', 'Wu-ken-shih,Wugen,Wugen Zhen,wu gen,wu gen zhen,坞根,坞根镇', 28.3245800, 121.2683000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19927, 'Hengfeng', 'Hengfeng', 'Heng-feng-ch''iao-shih,Heng-feng-ch’iao-shih,Hengfeng,Hengfeng Jiedao,heng feng,heng feng jie dao,横峰,横峰街道', 28.4340600, 121.3401700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19928, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,Ku-shan-chen,gu shan,gu shan zhen,顾山,顾山镇', 31.7327800, 120.5487700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19929, 'Tangzi', 'Tangzi', 'T''ang-tzu-chen,Tangzi,Tangzizhen,T’ang-tzu-chen,tang zi,tang zi zhen,唐子,唐子镇', 32.9363900, 120.0819400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19930, 'Xinba', 'Xinba', 'Xinba,Xinba Zhen,xin ba,xin ba zhen,新坝,新坝镇', 32.2792100, 119.6070100, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19931, 'Yangjian', 'Yangjian', 'Yang-chien,Yang-chien-ling,Yangjian,Yangjian Zhen,yang jian,yang jian zhen,羊尖,羊尖镇', 31.6287600, 120.5545400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19932, 'Xinzhuang', 'Xinzhuang', 'Hsin-chuang-chen,Xinzhuang,Xinzhuang Zhen,xin zhuang,xin zhuang zhen,辛庄,辛庄镇', 31.5373600, 120.6886900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19933, 'Beiqiao', 'Beiqiao', 'Beiqiao,Beiqiao Jiedao,Pei-ch''iao-chen,Pei-ch’iao-chen,bei qiao,bei qiao jie dao,北桥,北桥街道', 31.5087400, 120.5950300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19934, 'Huangdai', 'Huangdai', 'Huang-tai-chen,Huangdai,Huangdai Zhen,huang dai,huang dai zhen,黄埭,黄埭镇', 31.4362400, 120.5560100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19935, 'Weitang', 'Weitang', 'Wei-ching-t''ang-chen,Wei-ching-t’ang-chen,Weitang,Weitang Zhen,wei tang,wei tang zhen,渭塘,渭塘镇', 31.4648600, 120.6451500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19936, 'Taiping', 'Taiping', 'T''ai-p''ing-ch''iao-chen,Taiping,Taiping Jiedao,T’ai-p’ing-ch’iao-chen,tai ping,tai ping jie dao,太平,太平街道', 31.4351500, 120.6975500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19937, 'Fengqiao', 'Fengqiao', 'Feng-ch''iao-chen,Feng-ch’iao-chen,Fengqiao,Fengqiao Jiedao,feng qiao,feng qiao jie dao,枫桥,枫桥街道', 31.3134000, 120.5480100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19938, 'Mudu', 'Mudu', 'Mu-tu,Mu-tu-chen,Mudu,Mudu Zhen,mu du,mu du zhen,Муду,木渎,木渎镇', 31.2559700, 120.5185700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19939, 'Guoxiang', 'Guoxiang', 'Guogang,Guoxiang,Guoxiang Jiedao,Kuo-hsiang-chen,guo xiang,guo xiang jie dao,郭巷,郭巷街道', 31.2544500, 120.6715800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19940, 'Xinqiao', 'Xinqiao', 'Nan-hsin-ch''iao,Nan-hsin-ch’iao,Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 31.8025100, 120.5047800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19941, 'Tongli', 'Tongli', 'T''ung-li,T''ung-li-chen,Tongli,Tongli Zhen,T’ung-li,T’ung-li-chen,tong li,tong li zhen,同里,同里镇', 31.1609700, 120.7117700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19942, 'Songling', 'Songling', 'Songling,Songlingzhen,Sunlin,Wu-chiang,Wukiang,song ling,Сунлин,松陵', 31.1933000, 120.7175800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19943, 'Hengshan', 'Hengshan', 'Heng-shan-chen,Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横扇,横扇镇', 31.0185100, 120.5356200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19944, 'Hengjing', 'Hengjing', 'Heng-ching-chen,Hengjing,Hengjing Jiedao,heng jing,heng jing jie dao,横泾,横泾街道', 31.1722700, 120.5307500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19945, 'Shadili', 'Shadili', 'Changbai,Shadili,sha de li,zhang bai,沙地里,长白', 30.1752300, 122.0390900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19946, 'Xiushan', 'Xiushan', 'Xiushan,Yuandun,xiu shan,yuan dun,圆墩,秀山', 30.1894400, 122.1688900, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19947, 'Beichan', 'Beichan', 'Beichan,bei chan,北蝉', 30.0672200, 122.2194400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19948, 'Yancang', 'Yancang', 'Yancang,Yancang Jiedao,yan cang,yan cang jie dao,盐仓,盐仓街道', 30.0329000, 122.0569400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19949, 'Daixi', 'Daixi', 'Daixi,Daixi Zhen,dai xi,dai xi zhen,岱西,岱西镇', 30.2934500, 122.1226400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19950, 'Nizhi', 'Nizhi', 'Fujia,Ni-chih-chuang,Nizhi,Nizhi Zhen,fu jia,ni shi,ni shi zhen,傅家,泥峙,泥峙镇', 30.3041700, 122.1755600, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19951, 'Daidaon', 'Daidaon', 'Caojia,Daidaon,Daidong Zhen,Daidongzhen,Ts''ao-chia,Ts’ao-chia,cao jia,dai dong,dai dong zhen,岱东,岱东镇,曹家', 30.2952600, 122.1979400, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19952, 'Zhanmao', 'Zhanmao', 'Dazhan,Zhanmao,Zhanmao Zhen,da zhan,zhan mao,zhan mao zhen,大展,展茅,展茅镇', 30.0269800, 122.2829000, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19953, 'Huaniao', 'Huaniao', 'Huaniao,hua niao,花鸟', 30.8502800, 122.6913900, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19954, 'Wulong', 'Wulong', 'Wulong,wu long,五龙', 30.7072200, 122.5177800, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19955, 'Liutangting', 'Liutangting', 'Chongshou,Chongshou Zhen,Liutangting,chong shou,chong shou zhen,liu tang ting,六塘亭,崇寿,崇寿镇', 30.2758800, 121.2648900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19956, 'Qiaotou', 'Qiaotou', 'Qiaotou,qiao tou,桥头', 30.1609600, 121.3568800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19957, 'Haiyanmiao', 'Haiyanmiao', 'Fuhai Zhen,Hai-yen-miao,Haiyan,Haiyanmiao,fu hai zhen,hai yan,hai yan miao,海晏,海晏庙,附海镇', 30.2274700, 121.3993000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19958, 'Shengshan', 'Shengshan', 'Sheng-shan-chen,Shengshan,Shengshan Zhen,sheng shan,sheng shan zhen,胜山,胜山镇', 30.2329000, 121.3225400, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19959, 'Kandun', 'Kandun', 'K''an-tun-chen,Kandong,Kandun,Kandun Jiedao,Kandun Zhen,K’an-tun-chen,kan dun,kan dun jie dao,kan dun zhen,坎墩,坎墩街道,坎墩镇', 30.2253800, 121.2595100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19960, 'Zhangqi', 'Zhangqi', 'Zhangqi,Zhangqizhen,zhang qi,zhang qi zhen,掌起,掌起镇', 30.1158100, 121.4508900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19961, 'Sanqishi', 'Sanqishi', 'San-ch''i-shih,San-ch’i-shih,Sanqishi,Sanqishi Zhen,san qi shi,san qi shi zhen,三七市,三七市镇', 30.0336000, 121.3385600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19962, 'Shuangling', 'Shuangling', 'Shuangling,shuang ling,双岭', 28.0247500, 120.6021000, 'CN', '2014-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19963, 'Baizhifang', 'Baizhifang', 'Baizhifang,Baizhifang Jiedao,Xuanwu Qu,bai zhi fang,bai zhi fang jie dao,xuan wu qu,宣武区,白纸坊,白纸坊街道', 39.8828700, 116.3517400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19964, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Xiang,dong feng,dong feng xiang,东风,东风乡', 39.9365000, 116.4993100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19965, 'Daguo', 'Daguo', 'Daguo,Daguo Zhen,da guo,da guo zhen,大郭,大郭镇', 38.0738800, 114.4103000, 'CN', '2013-07-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19966, 'Fulilu', 'Fulilu', 'Fulilu,Hsi-ku-ch''eng,Hsi-ku-ch’eng,Xigu,Xigu Qu,Xigu Xiang,fu li lu,xi gu,xi gu qu,xi gu xiang,福利路,西固,西固乡,西固区', 36.1016800, 103.6157300, 'CN', '2013-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19967, 'Laojunpo', 'Laojunpo', 'Laojun,Laojunpo,lao jun po,老君坡', 35.7471600, 105.4211800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19968, 'Qingjiangyi', 'Qingjiangyi', 'Qingjiang,Qingjiangyi,qing jiang yi,青江驿', 35.6773900, 105.4391800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19969, 'Shixiang', 'Shixiang', 'Ching-shui-kung,Qingshui,Qingshui Xiang,Shixiang,qing shui xiang,shi xiang,清水乡,石巷', 35.8330900, 102.5402600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19970, 'Baizhuangji', 'Baizhuangji', 'Baizhuang,Baizhuang Xiang,Baizhuangji,bai zhuang,bai zhuang ji,bai zhuang xiang,白庄,白庄乡,白庄集', 35.7206200, 102.5739300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19971, 'Houjiachuan', 'Houjiachuan', 'Houchuan,Houjiachuan,hou jia chuan,侯家川', 35.4928300, 105.2201100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19972, 'Xindian', 'Xindian', 'Xindian,Xindian Xiang,xin dian,xin dian xiang,新店,新店乡', 35.3522200, 105.5180700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19973, 'Shaozhai', 'Shaozhai', 'Shaozhai,Shaozhai Zhen,shao zhai,shao zhai zhen,邵寨,邵寨镇', 34.9914500, 107.8038500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19974, 'Taijing', 'Taijing', 'Taijing,Taijing Zhen,tai jing,tai jing zhen,太京,太京镇', 34.5633300, 105.5488900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19975, 'Weixin', 'Weixin', 'Weixin,wei xin,维新', 34.6670300, 103.8685200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19976, 'Sancha', 'Sancha', 'Sancha,san cha,三岔', 34.5875000, 103.7613900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19977, 'Taibai', 'Taibai', 'Taibai,tai bai,太白', 34.0579100, 106.1623200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19978, 'Xipo', 'Xipo', 'Xipo,xi po,西坡', 33.8477200, 106.4303900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19979, 'Dahedian', 'Dahedian', 'Dahedian,da he dian,大河店', 33.6533300, 106.0497200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19980, 'Huama', 'Huama', 'Huama,hua ma,化马', 33.7367100, 104.5397500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19981, 'Shimen', 'Shimen', 'Shimen,shi men,石门', 33.4859700, 104.7382400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19982, 'Yangtian', 'Yangtian', 'Yangtian,yang tian,秧田', 33.1839600, 105.6645300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19983, 'Baiyang', 'Baiyang', 'Baiyang,bai yang,白杨', 33.1728800, 105.7818400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19984, 'Zhuandou', 'Zhuandou', 'Chuan-tou-p''u,Chuan-tou-p’u,Zhuandou,Zhuandou Xiang,Zhuandoupu,zhuan dou,zhuan dou xiang,转斗,转斗乡', 32.7091800, 106.0736000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19985, 'Tielou', 'Tielou', 'Tielou,Tielou Zangzuxiang,tie lou,tie lou cang zu xiang,铁楼,铁楼藏族乡', 32.9066500, 104.4644500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19986, 'Liangshui', 'Liangshui', 'Liangshui,Liangshui Zhen,liang shui,liang shui zhen,凉水,凉水镇', 32.3833300, 105.2183300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19987, 'Chixi', 'Chixi', 'Ch''ih-ch''i-ch''ang,Chixi,Chixi Xiang,Chixichang,Ch’ih-ch’i-ch’ang,chi xi,chi xi xiang,赤溪,赤溪乡', 32.1544400, 106.7643100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19988, 'Bashan', 'Bashan', 'Bashan,Bashan Zhen,Ranjiaba,ba shan,ba shan zhen,ran jia ba,冉家坝,巴山,巴山镇', 32.1116200, 108.4673200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19989, 'Xiliguantun', 'Xiliguantun', 'Li-kuan-t''un,Li-kuan-t’un,Xiliguantun', 37.0783300, 115.9413900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19990, 'Qiangezhai', 'Qiangezhai', 'Guxian,Guxian Xiang,Qiangezhai,Ta-ko-chai,gu xian,gu xian xiang,qian ge zhai,前葛寨,固献,固献乡', 36.9637000, 115.3782300, 'CN', '2014-07-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19991, 'Xiaojiezi', 'Xiaojiezi', 'Luju,Luju Zhen,Xiaojiezi,lu ju,lu ju zhen,xiao jie zi,小街子,路居,路居镇', 24.3447600, 102.8638000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19992, 'Sijie', 'Sijie', 'Sijie,Sijie Zhen,si jie,si jie zhen,四街,四街镇', 24.1666700, 102.7052800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19993, 'Huai’an', 'Huai''an', 'Huai''an,Huai''an Xiang,Huai’an,Huai’an Xiang,huai an,huai an xiang,怀安,怀安乡', 36.5835400, 107.8184300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19994, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,shui kou zhen,水口,水口镇', 29.9301300, 106.1126800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19995, 'Lüfeng', 'Lufeng', 'Lufeng,Lufeng Zhen,Lufengchang,Lüfeng,Lüfeng Zhen,Lüfengchang,lu feng,lu feng zhen,侣俸,侣俸镇', 29.8583400, 105.9730600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19996, 'Shouqiao', 'Shouqiao', 'Ranfangba,Shouqiao,Shouqiao Zhen,ran fang ba,shou qiao,shou qiao zhen,寿桥,寿桥镇,染坊坝', 29.8995500, 105.8941900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19997, 'Xinsheng', 'Xinsheng', 'Xinsheng,Xinsheng Zhen,xin sheng,xin sheng zhen,新生,新生镇', 29.9567300, 105.7509200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19998, 'Shuangshan', 'Shuangshan', 'Shuanghechang,Shuangshan,Shuangshan Xiang,shuang he chang,shuang shan,shuang shan xiang,双山,双山乡,双河场', 29.8212000, 105.8287800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(19999, 'Xiaolin', 'Xiaolin', 'Tuanshanbao,Xiaolin,Xiaolin Xiang,tuan shan bao,xiao lin,xiao lin xiang,团山堡,小林,小林乡', 29.7877000, 105.8519500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20000, 'Guoliang', 'Guoliang', 'Guoliang,Guoliang Zhen,Yunluchang,guo liang,guo liang zhen,yun lu chang,云路场,国梁,国梁镇', 29.7656900, 105.9220500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20001, 'Tuqiao', 'Tuqiao', 'Tuqiao,Tuqiao Zhen,tu qiao,tu qiao zhen,土桥,土桥镇', 29.7698200, 106.0131200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20002, 'Yongxi', 'Yongxi', 'Yongxi,Yongxi Zhen,Youfangpo,yong xi,yong xi zhen,you fang po,油坊坡,雍溪,雍溪镇', 29.7385300, 105.9794100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20003, 'Shiyu', 'Shiyu', 'Shiyu,Shiyu Zhen,shi yu,shi yu zhen,石鱼,石鱼镇', 29.7716100, 106.0934200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20004, 'Pulü', 'Pulu', 'Pulu,Pulu Zhen,Puluchang,Pulü,Pulü Zhen,Pulüchang,pu lu,pu lu chang,pu lu zhen,蒲吕,蒲吕场,蒲吕镇', 29.8179600, 106.1592700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20005, 'Caijiagang', 'Caijiagang', 'Caijiachang,Caijiagang,Caijiagang Zhen,cai jia chang,cai jia gang,cai jia gang zhen,蔡家场,蔡家岗,蔡家岗镇', 29.7424800, 106.4750800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20006, 'Huilongba', 'Huilongba', 'Huilongba,Huilongba Zhen,Xinglong,hui long ba,hui long ba zhen,回龙坝,回龙坝镇', 29.7050000, 106.3755600, 'CN', '2013-07-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20007, 'Jinshan', 'Jinshan', 'Dabao,Dabaochang,Jinshan,Jinshan Zhen,da bao chang,jin shan,jin shan zhen,大堡场,金山,金山镇', 29.6657500, 105.8820600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20008, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 29.7285900, 105.8628900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20009, 'Gaosheng', 'Gaosheng', 'Gaosheng,Gaosheng Zhen,gao sheng,gao sheng zhen,高升,高升镇', 29.7178000, 105.5783300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20010, 'Tieshan', 'Tieshan', 'Shuanghechang,Tieshan,Tieshan Zhen,shuang he chang,tie shan,tie shan zhen,双河场,铁山,铁山镇', 29.6894700, 105.5010000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20011, 'Yuanjue', 'Yuanjue', 'Ruanjiao,Yanjiaosi,Yuanjue,Yuanjue Xiang,Yuanjue Zhen,yan jiao si,yuan jue,yuan jue zhen,演教寺,远觉,远觉镇', 29.5584600, 105.3171900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20012, 'Tonggu', 'Tonggu', 'Tonggu,Tonggu Zhen,Wanfuqiao,tong gu,tong gu zhen,wan fu qiao,万福桥,铜鼓,铜鼓镇', 29.6060900, 105.4669400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20013, 'Guansheng', 'Guansheng', 'Guansheng,Guansheng Zhen,guan sheng,guan sheng zhen,观胜,观胜镇', 29.5777900, 105.4375400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20014, 'Hebao', 'Hebao', 'Hebao,Hebao Zhen,he bao,he bao zhen,河包,河包镇', 29.5661700, 105.5433800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20015, 'Baoxing', 'Baoxing', 'Baoxing,Baoxing Zhen,bao xing,bao xing zhen,宝兴,宝兴镇', 29.6217300, 105.6926500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20016, 'Damiao', 'Damiao', 'Damiao,Damiao Xiang,Damiao Zhen,da miao,da miao zhen,大庙,大庙镇', 29.6443000, 106.0695600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20017, 'Fulu', 'Fulu', 'Fulu,Fulu Zhen,fu lu,fu lu zhen,福禄,福禄镇', 29.6083100, 106.1345400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20018, 'Huaxing', 'Huaxing', 'Fuxingchang,Huaxing,Huaxing Zhen,fu xing chang,hua xing,hua xing zhen,华兴,华兴镇,复兴场', 29.5997700, 106.0696300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20019, 'Anxi', 'Anxi', 'Anxi,Anxi Zhen,an xi,an xi zhen,安溪,安溪镇', 29.5640700, 106.0419900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20020, 'Daxing', 'Daxing', 'Daxing,Daxing Zhen,Xinglongchang,da xing,da xing zhen,xing long chang,兴隆场,大兴,大兴镇', 29.5560500, 106.1600200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20021, 'Zengjia', 'Zengjia', 'Zengjia,Zengjia Zhen,ceng jia,ceng jia zhen,曾家,曾家镇', 29.5508300, 106.2977800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20022, 'Jinlong', 'Jinlong', 'Jinlong,Jinlong Zhen,Jiulongchang,jin long,jin long zhen,jiu long chang,九龙场,金龙,金龙镇', 29.5136000, 106.0606200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20023, 'Sanjiao', 'Sanjiao', 'Sanjiao,Sanjiao Zhen,Sanjiaochang,san jiao,san jiao zhen,三教,三教镇', 29.4880100, 105.8676500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20024, 'Shiban', 'Shiban', 'Shiban,Shiban Zhen,shi ban,shi ban zhen,石板,石板镇', 29.4252000, 106.3523500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20025, 'Tiaodeng', 'Tiaodeng', 'Tiaodeng,Tiaodeng Zhen,tiao deng,tiao deng zhen,跳蹬,跳蹬镇', 29.4055600, 106.4266700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20026, 'Taojia', 'Taojia', 'Taojia,Taojia Zhen,tao jia,tao jia zhen,陶家,陶家镇', 29.3732500, 106.3215200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20027, 'Guangpu', 'Guangpu', 'Guangpu,Guangpu Zhen,guang pu,guang pu zhen,广普,广普镇', 29.3356700, 106.1452100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20028, 'Chenshi', 'Chenshi', 'Chenshi,Chenshi Zhen,Chenshichang,chen shi,chen shi zhen,陈食,陈食镇', 29.3144600, 105.9926500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20029, 'Qingfeng', 'Qingfeng', 'Qingfeng,Qingfeng Zhen,qing feng,qing feng zhen,青锋,青锋镇', 29.3393800, 105.8267600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20030, 'Zhisheng', 'Zhisheng', 'Zhisheng,Zhisheng Zhen,zhi sheng,zhi sheng zhen,直升,直升镇', 29.3735200, 105.6533500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20031, 'Baofeng', 'Baofeng', 'Baofeng,Baofeng Zhen,bao feng,bao feng zhen,宝峰,宝峰镇', 29.2806500, 105.7056800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20032, 'Shuangzhu', 'Shuangzhu', 'Shuangfengchang,Shuangzhu,Shuangzhu Zhen,shuang feng chang,shuang zhu,shuang zhu zhen,双凤场,双竹,双竹镇', 29.2574300, 105.9031000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20033, 'Wutan', 'Wutan', 'Wutan,Wutan Zhen,Wutanchang,wu tan,wu tan zhen,吴滩,吴滩镇', 29.2569600, 106.0629000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20034, 'Wujian', 'Wujian', 'Wujian,Wujian Zhen,wu jian,wu jian zhen,五间,五间镇', 29.1820900, 105.8343600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20035, 'Hegeng', 'Hegeng', 'Hegeng,Hegeng Zhen,Hegengchang,he geng,he geng zhen,何埂,何埂镇', 29.1369600, 105.8698800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20036, 'Xianlong', 'Xianlong', 'Xianlong,Xianlong Zhen,Xianlongchang,xian long,xian long zhen,仙龙,仙龙镇', 29.1510700, 105.7840300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20037, 'Ji’an', 'Ji''an', 'Ji''an,Ji''an Zhen,Ji’an,Ji’an Zhen,ji an,ji an zhen,吉安,吉安镇', 29.1589700, 105.7470300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20038, 'Zhangcun', 'Zhangcun', 'Zhangcun,zhang cun,章村', 30.4647000, 119.3750000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20039, 'Panbanqiao', 'Panbanqiao', 'P''an-pan-ch''iao,Panbanqiao,P’an-pan-ch’iao,pan ban qiao,潘板桥', 30.3847200, 119.8713900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20040, 'Shuangxi', 'Shuangxi', 'Shuang-ch''i-chen,Shuang-ch’i-chen,Shuangxi,shuang xi,双溪', 30.4055100, 119.8256500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20041, 'Leping', 'Leping', 'Leping,Leping Xiang,Lo-p''ing-ts''un,Lo-p’ing-ts’un,le ping,乐平', 30.0103300, 119.3969400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20042, 'Zangwan', 'Zangwan', 'Tsang-wan-shih,Zangwan,Zangwan Xiang,zang wan,zang wan xiang,臧湾,臧湾乡', 29.4695400, 117.3940900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20043, 'Yujia', 'Yujia', 'Hsu-chia,Hsü-chia,Yujia,Yujia Xiang,yu jia,yu jia xiang,余家,余家乡', 29.4630100, 118.4729200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20044, 'Zhukou', 'Zhukou', 'Chu-k''ou-chen,Chu-k’ou-chen,Zhukou,Zhukou Zhen,zhu kou,zhu kou zhen,竹口,竹口镇', 27.6972200, 118.9144400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20045, 'Runsong', 'Runsong', 'Jun-song,Runsong,Runsonglaozhai,run song,润松', 26.8700000, 109.0970000, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20046, 'Dundong', 'Dundong', 'Dundong,Tun-tung,dun dong,顿洞', 26.0119000, 109.1410000, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20047, 'Gaowu', 'Gaowu', 'Gaowu,Kao-wu,gao wu,高武', 25.5625000, 108.9080000, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20048, 'Pingjiang', 'Pingjiang', 'P''ing-chiang,Pingjiang,Pingjiangkou,P’ing-chiang,ping jiang,ping jiang kou,平江,平江口', 25.8114000, 108.6620000, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20049, 'Tiantang', 'Tiantang', 'Tiantang,Tiantang Zhen,tian tang,tian tang zhen,天堂,天堂镇', 28.1525000, 108.5599000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20050, 'Mashan', 'Mashan', 'Mashan,Mashan Zhen,ma shan,ma shan zhen,马山,马山镇', 28.0524900, 107.5794300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20051, 'Huangyang', 'Huangyang', 'Huangcunba,Huangyang,Huangyang Zhen,Kuankuo,huang cun ba,huang yang,huang yang zhen,黄村坝,黄杨,黄杨镇', 28.2966900, 107.0747400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20052, 'Songxia', 'Songxia', 'Shou-chih,Shouzhi,Songxia,Songxia Zhen,song xia,song xia zhen,松下,松下镇', 25.7641500, 119.5938200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20053, 'Chengtou', 'Chengtou', 'Chengtou,Chengtou Zhen,cheng tou,cheng tou zhen,城头,城头镇', 25.7006900, 119.5146200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20054, 'Donghan', 'Donghan', 'Donghan,Donghan Zhen,Tung-han,dong han,dong han zhen,东瀚,东瀚镇', 25.4315500, 119.6056800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20055, 'Beigao', 'Beigao', 'Beigao,Beigao Zhen,Pei-kao-chen,bei gao,bei gao zhen,北高,北高镇', 25.3403100, 119.1364000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20056, 'Baiyatai', 'Baiyatai', 'Baiyatai,Baiyatai Xiang,bai ya tai,bai ya tai xiang,白崖台,白崖台乡', 39.3280600, 113.9736100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20057, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Da’an,Da’an Zhen,da an,da an zhen,大安,大安镇', 18.6956500, 109.2098300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20058, 'Wanchong', 'Wanchong', 'Wanchong,Wanchong Zhen,wan chong,wan chong zhen,万冲,万冲镇', 18.8486400, 109.3170800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20059, 'Nansheng', 'Nansheng', 'Nansheng,Nansheng Zhen,nan sheng,nan sheng zhen,南圣,南圣镇', 18.7277100, 109.5968200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20060, 'Shiling', 'Shiling', 'Shiling,Shiling Zhen,shen ling,shen ling zhen,什玲,什玲镇', 18.6643200, 109.7788100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20061, 'Haodi', 'Haodi', 'Haodi,hao de,好地', 35.0009600, 105.7588700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20062, 'Jiangkou', 'Jiangkou', 'Jiangkou,jiang kou,江口', 34.0584600, 105.0999600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20063, 'Leiwang', 'Leiwang', 'Leiwang,lei wang,雷王', 34.0508400, 105.1441800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20064, 'Liuping', 'Liuping', 'Liuping,liu ping,刘坪', 34.8913900, 105.7191700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20065, 'Suhe', 'Suhe', 'Suhe,su he,苏合', 34.0625000, 105.2221000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20066, 'Wangyin', 'Wangyin', 'Wangyin,wang yin,王尹', 34.8338900, 105.7616700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20067, 'Wulong', 'Wulong', 'Wulong,Wulong Xiang,wu long,wu long xiang,五龙,五龙乡', 34.7516700, 105.5216700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20068, 'Xinglong', 'Xinglong', 'Xinglong,xing long,兴隆', 34.0382100, 105.3442200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20069, 'Yanhe', 'Yanhe', 'Chaxihe,Yanhe,Yanhe Xiang,cha xi he,yan he,yan he xiang,岔溪河,沿河,沿河乡', 32.0590400, 108.3958300, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20070, 'Fujia', 'Fujia', 'Fujia,Fujia Xiang,Fujiahe,fu jia,fu jia xiang,傅家,傅家乡', 32.1171800, 106.6899700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20071, 'Dingbao', 'Dingbao', 'Dingbao,Dingbao Zhen,ding bao,ding bao zhen,丁堡,丁堡镇', 22.3017500, 110.9742500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20072, 'Beijie', 'Beijie', 'Beijie,Beijie Zhen,bei jie,bei jie zhen,北界,北界镇', 22.3191100, 110.7989500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20073, 'Daliu', 'Daliu', 'Daliu,Daliu Xiang,da liu,da liu xiang,大柳,大柳乡', 33.0160800, 110.7364300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20074, 'Junxian', 'Junxian', 'Junxian,Junxian Zhen,jun xian,jun xian zhen,均县,均县镇', 32.6676200, 111.1397300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20075, 'Wudangshan', 'Wudangshan', 'Wudangshan,Wudangshan Zhen,wu dang shan,wu dang shan zhen,武当山,武当山镇', 32.5140900, 111.0771800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20076, 'Tuguanya', 'Tuguanya', 'Tuguanya,Tuguanya Zhen,tu guan ya,tu guan ya zhen,土关垭,土关垭镇', 32.4206500, 111.3640800, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20077, 'Nanhe', 'Nanhe', 'Nanhe,Nanhe Zhen,nan he,nan he zhen,南河,南河镇', 32.1734200, 111.5089400, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20078, 'Yuanchong', 'Yuanchong', 'Yuanchong,Yuanchong Xiang,yuan chong,yuan chong xiang,袁冲,袁冲乡', 32.5266200, 111.7339600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20079, 'Shigu', 'Shigu', 'Shigu,Shigu Zhen,shi gu,shi gu zhen,石鼓,石鼓镇', 32.7529100, 111.3559200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20080, 'Dahekan', 'Dahekan', 'Dahekan,Dahekan Zhen,Dahekanzhen,da he kan,da he kan zhen,大河坎,大河坎镇', 33.0411100, 107.0363900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20081, 'Yangying', 'Yangying', 'Yangying,Yanying Zhen,yang ying,yang ying zhen,杨营,杨营镇', 33.0023000, 112.1670200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20082, 'Dafengying', 'Dafengying', 'Dafengying,da feng ying,大冯营', 33.0067200, 112.8417000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20083, 'Qutun', 'Qutun', 'Qutun,Qutun Zhen,qu tun,qu tun zhen,曲屯,曲屯镇', 33.0404100, 112.0254000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20084, 'Wanggang', 'Wanggang', 'Wanggang,wang gang,王岗', 33.1009100, 112.0866400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20085, 'Luyi', 'Luyi', 'Luyi,Luyi Zhen,Luyijie,lu yi,lu yi zhen,卢医,卢医镇', 33.1006200, 112.0471900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20086, 'Xiezhuang', 'Xiezhuang', 'Xiezhuang,xie zhuang,谢庄', 33.1495400, 112.4356200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20087, 'Xuanqiao', 'Xuanqiao', 'Xuanqiao,quan qiao,券桥', 33.1526500, 112.9619500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20088, 'Guangyang', 'Guangyang', 'Guangyang,Guangyangzhen,guang yang,guang yang zhen,广阳,广阳镇', 33.2843900, 112.7015000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20089, 'Yuandianhui', 'Yuandianhui', 'Yuandianhui,Yuandianhuizuxiang,yuan dian hui,袁店回', 33.2723400, 112.8440800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20090, 'Jizhong', 'Jizhong', 'Jizhong,ji zhong,鸡冢', 33.6362400, 112.6784300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20091, 'Xiongbei', 'Xiongbei', 'Xiongbei,xiong bei,熊背', 33.6624800, 112.8118000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20092, 'Sikeshu', 'Sikeshu', 'Sikeshu,si ke shu,四棵树', 33.6660400, 112.5850900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20093, 'Zhangdian', 'Zhangdian', 'Zhangdian,zhang dian,张店', 33.7724900, 112.8831400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20094, 'Zhangbaqiao', 'Zhangbaqiao', 'Zhangbaqiao,Zhangbaqiaozhen,zhang ba qiao,zhang ba qiao zhen,张八桥,张八桥镇', 33.8700000, 112.9597800, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20095, 'Guanyinsi', 'Guanyinsi', 'Guanyinsi,guan yin si,观音寺', 33.8674300, 112.7281600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20096, 'Jiulong', 'Jiulong', 'Jiulong,Jiulong Zhen,jiu long,jiu long zhen,九龙,九龙镇', 32.4868100, 119.8433500, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20097, 'Jiangqiao', 'Jiangqiao', 'Jiangqiao,Jiangqiao Zhen,jiang qiao,jiang qiao zhen,蒋桥,蒋桥镇', 32.1586600, 119.4597300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20098, 'Shima', 'Shima', 'Shima,Shima Zhen,shi ma,shi ma zhen,石蟆,石蟆镇', 28.9877300, 105.9244100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20099, 'Majiadu', 'Majiadu', 'Majiadu,Majiadu Zhen,ma jia du,ma jia du zhen,麻家渡,麻家渡镇', 32.2959900, 110.0328100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20100, 'Yeda', 'Yeda', 'Yeda,Yeda Xiang,ye da,ye da xiang,叶大,叶大乡', 32.5420900, 110.4531600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20101, 'Yuanyang', 'Yuanyang', 'Yuanyang,Yuanyang Jiedao,yuan yang,yuan yang jie dao,鸳鸯,鸳鸯街道', 32.5952300, 110.8802200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20102, 'Fangtan', 'Fangtan', 'Fangtan,Fangtan Xiang,fang tan,fang tan xiang,方滩,方滩乡', 32.7383700, 110.6116000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20103, 'Wufeng', 'Wufeng', 'Wufeng,Wufeng Xiang,wu feng,wu feng xiang,五峰,五峰乡', 32.8273700, 110.3693000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20104, 'Jianchi', 'Jianchi', 'Jianchi,Jianchi Xiang,jian chi,jian chi xiang,涧池,涧池乡', 32.8701100, 110.3311300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20105, 'Shipu', 'Shipu', 'Shipu,Shipu Jiedao,shi pu,shi pu jie dao,柿铺,柿铺街道', 32.0506200, 112.0742300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20106, 'Huopai', 'Huopai', 'Huopai,Huopai Zhen,huo pai,huo pai zhen,伙牌,伙牌镇', 32.1626300, 112.1269900, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20107, 'Mizhuang', 'Mizhuang', 'Mizhuang,Mizhuang Zhen,mi zhuang,mi zhuang zhen,米庄,米庄镇', 32.1353800, 112.1552300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20108, 'Liusheng', 'Liusheng', 'Liusheng,Liusheng Zhen,liu sheng,liu sheng zhen,刘升,刘升镇', 32.1514100, 112.9599600, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20109, 'Liuge', 'Liuge', 'Liuge,Liuge Xiang,liu ge,liu ge xiang,刘阁,刘阁乡', 32.9841700, 113.9722200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20110, 'Gaodian', 'Gaodian', 'Gaodian,gao dian,高店', 32.6393400, 113.2353700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20111, 'Shuangmiaojie', 'Shuangmiaojie', 'Shuangmiaojie,shuang miao jie,双庙街', 32.8038400, 113.2588600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20112, 'Yangjiaji', 'Yangjiaji', 'Yangjiaji,yang jia ji,杨家集', 32.8294800, 113.3384500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20113, 'Fuzhuang', 'Fuzhuang', 'Fuzhuang,fu zhuang,付庄', 32.9586800, 113.4789200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20114, 'Laohe', 'Laohe', 'Laohe,lao he,老河', 32.9194800, 113.7144900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20115, 'Sizhou', 'Sizhou', 'Sizhou,Sizhou Zhen,si zhou,si zhou zhen,泗洲,泗洲镇', 29.0463300, 117.7099400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20116, 'Xiangtun', 'Xiangtun', 'Xiangtun,Xiangtun Zhen,xiang tun,xiang tun zhen,香屯,香屯镇', 29.0080600, 117.5402800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20117, 'Xiaofayi', 'Xiaofayi', 'Xiaofayi,xiao fa yi,小法仪', 34.1698400, 107.8211800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20118, 'Wuzhangyuan', 'Wuzhangyuan', 'Wuzhangyuan,Wuzhangyuan Zhen,wu zhang yuan,wu zhang yuan zhen,五丈原,五丈原镇', 34.2840600, 107.6128100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20119, 'Majia', 'Majia', 'Majia,Majia Zhen,ma jia,ma jia zhen,马家,马家镇', 34.3105300, 107.7074200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20120, 'Zhaogong', 'Zhaogong', 'Shaogong,Zhaogong,Zhaogong Zhen,zhao gong,zhao gong zhen,召公,召公镇', 34.4381700, 107.9890700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20121, 'Jingdang', 'Jingdang', 'Jingdang,jing dang,京当', 34.4904500, 107.8232000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20122, 'Meiganqiao', 'Meiganqiao', 'Meiganqiao,Meiganqiao Zhen,mei gan qiao,mei gan qiao zhen,糜杆桥,糜杆桥镇', 34.5422200, 107.4511000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20123, 'Hanfeng', 'Hanfeng', 'Hanfeng,han feng,汉封', 34.6193100, 107.2974300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20124, 'Cuijiatou', 'Cuijiatou', 'Cuijiatou,Cuijiatou Zhen,cui jia tou,cui jia tou zhen,崔家头,崔家头镇', 34.6364500, 107.2317700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20125, 'Zhangjiayuan', 'Zhangjiayuan', 'Zhangjiayuan,Zhangjiayuan Zhen,zhang jia yuan,zhang jia yuan zhen,张家塬,张家塬镇', 34.6995800, 107.1021600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20126, 'Pingyao', 'Pingyao', 'Pingyao,ping yao,平遥', 34.8277900, 107.9747200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20127, 'Longzhouwan', 'Longzhouwan', 'Banan,Banan Qu,Longzhouwan,ba nan qu,long zhou wan,巴南区,龙洲湾', 29.3786100, 106.5400000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20128, 'Nanping', 'Nanping', 'Nan''an,Nan''an Qu,Nanping,Nan’an,Nan’an Qu,nan an qu,nan ping,南坪,南岸区', 29.5411100, 106.5877800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20129, 'Li’an', 'Li''an', 'Li''an,Li''an Zhen,Li-an,Li’an,Li’an Zhen,li an,li an zhen,黎安,黎安镇', 18.4332400, 110.0669200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20130, 'Guangpo', 'Guangpo', 'Chiang-p''o,Chiang-p’o,Gangpo,Guangpo,Guangpo Zhen,guang po,guang po zhen,光坡,光坡镇', 18.5508900, 110.0515000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20131, 'Liji', 'Liji', 'Li-ch''I,Li-ch’I,Liji,Liji Zhen,li ji,li ji zhen,礼纪,礼纪镇', 18.7518400, 110.3150600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20132, 'Hou’an', 'Hou''an', 'Hou''an,Hou''an Zhen,Hou-an-shih,Hou’an,Hou’an Zhen,hou an,hou an zhen,后安,后安镇', 18.8671400, 110.4465400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20133, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Zhen,hong shan,hong shan zhen,洪山,洪山镇', 26.0784900, 119.2706200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20134, 'Guling', 'Guling', 'Guling,Guling Xiang,gu ling,gu ling xiang,鼓岭,鼓岭乡', 26.0924300, 119.3914900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20135, 'Huanxi', 'Huanxi', 'Huanxi,Huanxi Zhen,huan xi,huan xi zhen,宦溪,宦溪镇', 26.1739900, 119.3538500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20136, 'Xiagong', 'Xiagong', 'Xiagong,Xiagong Xiang,xia gong,xia gong xiang,下宫,下宫乡', 26.3835700, 119.7950200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20137, 'Jiangjiayan', 'Jiangjiayan', 'Jiangjiayan,Jiangjiayan Zhen,jiang jia yan,jiang jia yan zhen,蒋家堰,蒋家堰镇', 32.3259400, 109.5829900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20138, 'Xiabeisi', 'Xiabeisi', 'Xiabeisi,xia bei si,下碑寺', 33.0276300, 113.5666900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20139, 'Huangshankou', 'Huangshankou', 'Huangshan,Huangshankou,huang shan kou,黄山口', 33.0409300, 113.3170100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20140, 'Yangfeng', 'Yangfeng', 'Yangfeng,Yangfeng Xiang,yang feng,yang feng xiang,阳丰,阳丰乡', 33.1344000, 113.8531600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20141, 'Shenzhai', 'Shenzhai', 'Shenzhai,Shenzhai Xiang,chen zhai,chen zhai xiang,沈寨,沈寨乡', 33.2353900, 113.8673700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20142, 'Huaishu', 'Huaishu', 'Huaishu,Huaishu Xiang,huai shu,huai shu xiang,槐树,槐树乡', 33.2511000, 113.7252400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20143, 'Jiudian', 'Jiudian', 'Jiudian,Jiudian Xiang,jiu dian,jiu dian xiang,酒店,酒店乡', 33.2595800, 113.6610300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20144, 'Yangzhuang', 'Yangzhuang', 'Yangzhuang,Zhuzhuang,yang zhuang,杨庄', 33.2685200, 113.4810500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20145, 'Lumiao', 'Lumiao', 'Lumiao,Lumiao Xiang,lu miao,lu miao xiang,芦庙,芦庙乡', 33.3203000, 113.7153900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20146, 'Yangzhuang', 'Yangzhuang', 'Yangzhuang,Yangzhuang Xiang,yang zhuang,yang zhuang xiang,杨庄,杨庄乡', 33.3371300, 113.8374300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20147, 'Zhuantan', 'Zhuantan', 'Zhuantan,Zhuantan Xiang,zhuan tan,zhuan tan xiang,专探,专探乡', 33.3365900, 113.9033400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20148, 'Miaojie', 'Miaojie', 'Miaojie,miao jie,庙街', 33.3574500, 113.4637800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20149, 'Tandian', 'Tandian', 'Tandian,Tandian Xiang,tan dian,tan dian xiang,谭店,谭店乡', 33.3759000, 113.9256500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20150, 'Shiling', 'Shiling', 'Shiling,Shiling Zhen,shi ling,shi ling zhen,师灵,师灵镇', 33.3967700, 113.8191800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20151, 'Wenfeng', 'Wenfeng', 'Wenfeng,wen feng,文峰', 33.4465900, 113.5754800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20152, 'Xin’an', 'Xin''an', 'Qin''an,Qin’an,Xin''an,Xin''an Zhen,Xin’an,Xin’an Zhen,xin an,辛安', 33.4458800, 113.6785900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20153, 'Songji', 'Songji', 'Songji,Songji Xiang,song ji,song ji xiang,宋集,宋集乡', 33.4635700, 113.9732100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20154, 'Longquan', 'Longquan', 'Longquan,long quan,龙泉', 33.4882600, 113.4250400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20155, 'Jiangdian', 'Jiangdian', 'Jiangdian,jiang dian,姜店', 33.5283300, 113.6615400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20156, 'Macun', 'Macun', 'Macun,ma cun,马村', 33.5668000, 113.6455400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20157, 'Mazhuang', 'Mazhuang', 'Mazhuang,Mazhuang Huizuxiang,ma zhuang,ma zhuang hui zu xiang,马庄,马庄回族乡', 33.5906700, 113.3435600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20158, 'Shuizhai', 'Shuizhai', 'Shuizhai,shui zhai,水寨', 33.6218400, 113.5431700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20159, 'Taiwei', 'Taiwei', 'Taiwei,Taiwei Zhen,tai wei,太尉', 33.6297300, 113.7576900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20160, 'Rendian', 'Rendian', 'Rendian,Rendian Zhen,ren dian,ren dian zhen,任店,任店镇', 33.6267200, 113.2271200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20161, 'Houji', 'Houji', 'Houji,hou ji,侯集', 33.6700300, 113.7048200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20162, 'Gunziying', 'Gunziying', 'Gunziying,Gunziying Xiang,gun zi ying,gun zi ying xiang,磙子营,磙子营乡', 33.6700100, 113.1032300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20163, 'Dengli', 'Dengli', 'Dengli,deng li,邓李', 33.6717800, 113.5024100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20164, 'Zhanghua', 'Zhanghua', 'Zhanghua,zhang hua,章化', 33.6685100, 113.6227000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20165, 'Zunhuadian', 'Zunhuadian', 'Zunhuadian,Zunhuadian Zhen,zun hua dian,遵化店', 33.7059600, 113.4007500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20166, 'Caozhen', 'Caozhen', 'Caozhen,cao zhen,曹镇', 33.7044300, 113.2140000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20167, 'Hongzhuangyang', 'Hongzhuangyang', 'Hongzhuangyang,hong zhuang yang,洪庄杨', 33.7306200, 113.5167200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20168, 'Donggaohuang', 'Donggaohuang', 'Donggaohuang,dong gao huang,东高皇', 33.7575800, 113.3638300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20169, 'Jiaodian', 'Jiaodian', 'Jiaodian,Jiaodian Zhen,jiao dian,焦店', 33.7672200, 113.2229400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20170, 'Huangdimiao', 'Huangdimiao', 'Huangdimiao,Huangdimiao Xiang,huang di miao,huang di miao xiang,皇帝庙,皇帝庙乡', 33.7675700, 113.9856700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20171, 'Taichen', 'Taichen', 'Taichen,Taichen Zhen,tai chen,tai chen zhen,台陈,台陈镇', 33.7692600, 113.9219000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20172, 'Lizhuang', 'Lizhuang', 'Lizhuang,Lizhuang Xiang,li zhuang,li zhuang xiang,李庄,李庄乡', 33.8412100, 113.2657700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20173, 'Yangzhuang', 'Yangzhuang', 'Yangzhuang,Yangzhuang Zhen,yang zhuang,yang zhuang zhen,杨庄,杨庄镇', 33.8357600, 113.0350300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20174, 'Fanhu', 'Fanhu', 'Fanhu,fan hu,范湖', 33.8452900, 113.6813500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20175, 'Juling', 'Juling', 'Juling,Juling Zhen,ju ling,ju ling zhen,巨陵,巨陵镇', 33.8622000, 113.9600400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20176, 'Zhouzhuang', 'Zhouzhuang', 'Zhouzhuang,Zhouzhuang Zhen,zhou zhuang,zhou zhuang zhen,周庄,周庄镇', 33.8605500, 113.1159800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20177, 'Guxiang', 'Guxiang', 'Guxiang,Guxiang Xiang,gu xiang,gu xiang xiang,固厢,固厢乡', 33.8732100, 113.9198100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20178, 'Shilipu', 'Shilipu', 'Shilipu,shi li pu,十里铺', 33.8817300, 113.4305400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20179, 'Yaozhuang', 'Yaozhuang', 'Yaozhuang,Yaozhuang Huizuxiang,yao zhuang,yao zhuang hui zu xiang,姚庄,姚庄回族乡', 33.8757500, 113.2709400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20180, 'Kuzhuang', 'Kuzhuang', 'Kuzhuang,Xiku,ku zhuang,库庄', 33.9028000, 113.5589400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20181, 'Xiaoqi', 'Xiaoqi', 'Xiaoqi,Xiaoqi Xiang,xiao qi,xiao qi xiang,肖旗,肖旗乡', 33.9163600, 113.0605600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20182, 'Jiangliji', 'Jiangliji', 'Jiangliji,Jiangliji Zhen,jiang li ji,jiang li ji zhen,蒋李集,蒋李集镇', 33.9401900, 113.8348400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20183, 'Yingyang', 'Yingyang', 'Yingyang,ying yang,颍阳', 33.9512400, 113.6117800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20184, 'Guangkuotiandi', 'Guangkuotiandi', 'Guangkuotiandi,guang kuo tian de,广阔天地', 33.9665400, 113.1655500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20185, 'Caotang', 'Caotang', 'Caotang,Caotang Zhen,cao tang,cao tang zhen,草堂,草堂镇', 34.0438900, 108.7108300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20186, 'Luanzhen', 'Luanzhen', 'Luanzhen,Luanzhen Jieban,luan zhen,luan zhen jie ban,滦镇,滦镇街办', 34.0584300, 108.8116500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20187, 'Jiangcun', 'Jiangcun', 'Jiangcun,Jiangcun Zhen,jiang cun,jiang cun zhen,蒋村,蒋村镇', 34.0829300, 108.4735200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20188, 'Huangliang', 'Huangliang', 'Huangliang,huang liang,黄良', 34.0934600, 108.8945300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20189, 'Xiliu', 'Xiliu', 'Xiliu,Xiliu Zhen,xi liu,xi liu zhen,细柳,细柳镇', 34.1502800, 108.7911100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20190, 'Tangfang', 'Tangfang', 'Tangfang,tang fang,汤坊', 34.2372200, 108.3625000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20191, 'Yuhuazhai', 'Yuhuazhai', 'Yuhuazhai,Yuhuazhai Jieban,yu hua zhai,yu hua zhai jie ban,鱼化寨,鱼化寨街办', 34.2269400, 108.8555600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20192, 'Dazhuang', 'Dazhuang', 'Dazhuang,Dazhuang Zhen,da zhuang,da zhuang zhen,大庄,大庄镇', 34.2533600, 108.1623900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20193, 'Chenyangzhai', 'Chenyangzhai', 'Chenyangzhai,Chenyangzhai Jieban,chen yang zhai,chen yang zhai jie ban,陈杨寨,陈杨寨街办', 34.3201500, 108.7062200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20194, 'Liucunbao', 'Liucunbao', 'Liucunbao,Liucunbao Jieban,liu cun bao,liu cun bao jie ban,六村堡,六村堡街办', 34.3336100, 108.8476400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20195, 'Nanshi', 'Nanshi', 'Nanshi,Nanshi Zhen,nan shi,nan shi zhen,南市,南市镇', 34.3604000, 108.4623800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20196, 'Nanwei', 'Nanwei', 'Nanwei,Nanwei Zhen,nan wei,nan wei zhen,南位,南位镇', 34.3575000, 108.5422200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20197, 'Jiangcun', 'Jiangcun', 'Jiangcun,Jiangcun Zhen,jiang cun,jiang cun zhen,姜村,姜村镇', 34.3927800, 108.2525000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20198, 'Xizhangbao', 'Xizhangbao', 'Xizhangbao,Xizhangbao Zhen,Xizhangbaocun,xi zhang bao,xi zhang bao zhen,西张堡,西张堡镇', 34.5052800, 108.5655600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20199, 'Lingyuan', 'Lingyuan', 'Lingyuan,Lingyuan Zhen,ling yuan,ling yuan zhen,灵源,灵源镇', 34.5022200, 108.3492700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20200, 'Sanqu', 'Sanqu', 'Sanqu,Sanqu Zhen,Sanqukou,Sanquzhen,san qu,san qu zhen,三渠,三渠镇', 34.5744400, 108.8925000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20201, 'Qiaodi', 'Qiaodi', 'Qiaodi,Qiaodi Zhen,qiao di,qiao di zhen,桥底,桥底镇', 34.6063900, 108.7161100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20202, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 34.6480600, 108.6927800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20203, 'Mafang', 'Mafang', 'Mafang,Mafang Zhen,ma fang,ma fang zhen,马坊,马坊镇', 34.7857600, 108.1625200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20204, 'Guxian', 'Guxian', 'Guxian,gu xian,固贤', 34.8386100, 108.7569400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20205, 'Potou', 'Potou', 'Potou,Potou Zhen,Potoucun,Potouzhen,po tou,po tou zhen,坡头,坡头镇', 34.8527800, 108.8947200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20206, 'Majia', 'Majia', 'Majia,Majia Zhen,ma jia,ma jia zhen,马家,马家镇', 34.8583300, 108.4583300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20207, 'Sigou', 'Sigou', 'Sigou,Sigou Zhen,si gou,si gou zhen,寺沟,寺沟镇', 34.9383300, 108.9316700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20208, 'Hujiamiao', 'Hujiamiao', 'Hujiamiao,Hujiazhuang,hu jia miao,胡家庙', 34.9579400, 108.4190000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20209, 'Dongjiahe', 'Dongjiahe', 'Dongjiahe,Dongjiahe Zhen,dong jia he,dong jia he zhen,董家河,董家河镇', 34.9625000, 108.9969400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20210, 'Sunyuan', 'Sunyuan', 'Sunjiayuan,Sunyuan,Sunyuan Zhen,sun yuan,孙塬', 34.9444400, 109.0250600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20211, 'Duli', 'Duli', 'Duli,Duli Zhen,du li,独李', 34.6340500, 109.0804500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20212, 'Baimiao', 'Baimiao', 'Baimiao,bai miao,白庙', 34.9379600, 109.1436400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20213, 'Xinshi', 'Xinshi', 'Xinshi,xin shi,新市', 34.5383400, 109.1800500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20214, 'Weizhai', 'Weizhai', 'Weizhai,wei zhai,魏寨', 34.1077300, 109.1716600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20215, 'Qianwei', 'Qianwei', 'Qianwei,Qianwei Zhen,qian wei,前卫', 34.1263600, 109.2235400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20216, 'Tangyu', 'Tangyu', 'Tangyu,Tangyu Zhen,tang yu,汤峪', 34.0183200, 109.2143500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20217, 'Qinling Jieban', 'Qinling Jieban', 'Qinling,Qinling Jieban,qin ling jie ban,秦陵街办', 34.3867800, 109.2492800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20218, 'Ancun', 'Ancun', 'Ancun,an cun,安村', 34.1213400, 109.2686100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20219, 'Sanli', 'Sanli', 'Dasanlitou,Sanli,Sanli Zhen,san li,三里', 34.1691300, 109.3075700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20220, 'Daiwang', 'Daiwang', 'Daiwang,Daiwang Jieban,dai wang,代王', 34.3968600, 109.2942700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20221, 'Hezhai', 'Hezhai', 'Hejunzhai,Hezhai,Hezhai Zhen,he zhai,何寨', 34.5172300, 109.3177900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20222, 'Zhangqiao', 'Zhangqiao', 'Zhangqiao,Zhangqiao Zhen,zhang qiao,张桥', 34.7560000, 109.3815600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20223, 'Sufang', 'Sufang', 'Sufang,Sufang Zhen,su fang,苏坊', 34.8958700, 109.3712000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20224, 'Youhuai', 'Youhuai', 'Youfangjie,Youhuai,Youhuai Zhen,you huai,油槐', 34.5584900, 109.3855300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20225, 'Potou', 'Potou', 'Potou,Potou Zhen,po tou,坡头', 34.9710300, 109.4459400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20226, 'Sanhe', 'Sanhe', 'Sanhe,san he,三合', 34.9708500, 109.5149600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20227, 'Longchi', 'Longchi', 'Longchi,long chi,龙池', 34.8065300, 109.6769100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20228, 'Chunlin', 'Chunlin', 'Chunlin,chun lin,椿林', 34.9599800, 109.6773800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20229, 'Zhangjia', 'Zhangjia', 'Zhangjia,zhang jia,张家', 34.6169700, 109.7358300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20230, 'Dongchen', 'Dongchen', 'Dongchen,dong chen,东陈', 35.0008600, 109.8068200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20231, 'Xijing', 'Xijing', 'Xijing,xi jing,西荆', 34.0485700, 109.8181600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20232, 'Fengcun', 'Fengcun', 'Fengcun,Fengcun Zhen,feng cun,冯村', 34.8525700, 109.8271000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20233, 'Liuzhi', 'Liuzhi', 'Liuzhi,Liuzhi Zhen,liu zhi,柳枝', 34.5393600, 109.8568100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20234, 'Aijia', 'Aijia', 'Aijia,Aijia Zhen,ai jia,ai jia zhen,艾家,艾家镇', 30.6235900, 111.3461400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20235, 'Babao', 'Babao', 'Babao,Babao Zhen,ba bao,ba bao zhen,八宝,八宝镇', 30.1822900, 111.8702300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20236, 'Dianjun', 'Dianjun', 'Dianjun,Dianjun Jiedao,Dianjun Xiang,dian jun,dian jun dao jie,dian jun xiang,点军,点军乡,点军道街', 30.7015400, 111.2599100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20237, 'Gujiadian', 'Gujiadian', 'Gujiadian,Gujiadian Zhen,gu jia dian,gu jia dian zhen,顾家店,顾家店镇', 30.3305300, 111.5768500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20238, 'Sijiachang', 'Sijiachang', 'Sijiachang,Sijiachang Zhen,si jia chang,si jia chang zhen,斯家场,斯家场镇', 30.0859700, 111.6212600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20239, 'Wuyanquan', 'Wuyanquan', 'Wuyanquan,Wuyanquan Xiang,wu yan quan,wu yan quan xiang,五眼泉,五眼泉乡', 30.3549200, 111.3220800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20240, 'Xiejiaping', 'Xiejiaping', 'Xiejiaping,Xiejiaping Tujiazuxiang,xie jia ping,xie jia ping tu jia zu xiang,卸甲坪,卸甲坪土家族乡', 30.0404400, 111.3664800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20241, 'Yunchi', 'Yunchi', 'Yunchi,Yunchi Jiedao,yun chi,yun chi jie dao,云池,云池街道', 30.5223500, 111.4404600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20242, 'Shenbai', 'Shenbai', 'Shenbai,Shenbai Xiang,shen bai,shen bai xiang,神柏,神柏乡', 35.3666800, 111.1480800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20243, 'Donggaocun', 'Donggaocun', 'Donggaocun,Gaocun Xiang,dong gao cun,gao cun xiang,东高村,高村乡', 35.6021300, 111.2921400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20244, 'Houcun', 'Houcun', 'Houcun,Houcun Xiang,hou cun,hou cun xiang,侯村,侯村乡', 35.4166100, 111.3510600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20245, 'Fengcheng', 'Fengcheng', 'Fengcheng,Fengcheng Xiang,feng cheng,feng cheng xiang,凤城,凤城乡', 35.6332300, 111.4360500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20246, 'Dadeng', 'Dadeng', 'Dadeng,Dadeng Xiang,da deng,da deng xiang,大邓,大邓乡', 35.9214800, 111.5338800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20247, 'Zhongyuanlu', 'Zhongyuanlu', 'Hualong Qu,Zhongyuanlu,Zhongyuanyoutian,hua long qu,zhong yuan lu,中原路,华龙区', 35.7684700, 115.0613300, 'CN', '2014-07-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20248, 'Yangying', 'Yangying', 'Yangying,Yangying Zhen,yang ying,yang ying zhen,杨营,杨营镇', 35.8180500, 115.9480700, 'CN', '2014-10-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20249, 'Xiangyang', 'Xiangyang', 'Xiangyang,Xiangyang Jiedao,xiang yang,xiang yang jie dao,向阳,向阳街道', 39.7423000, 115.9565100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20250, 'Zhangziying', 'Zhangziying', 'Zhangziying,Zhangziying Zhen,zhang zi ying,zhang zi ying zhen,张子营,张子营镇', 39.6828400, 116.5926100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20251, 'Yinghai', 'Yinghai', 'Yinghai,Yinghai Zhen,ying hai,ying hai zhen,瀛海,瀛海镇', 39.7593500, 116.4341000, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20252, 'Jiugong', 'Jiugong', 'Jiugong,Jiugong Zhen,jiu gong,jiu gong zhen,旧宫,旧宫镇', 39.8027000, 116.4510400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20253, 'Gantang', 'Gantang', 'Gantang,Gantang Zhen,gan tang,gan tang zhen,甘棠,甘棠镇', 39.8558500, 116.8083500, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20254, 'Liyuan', 'Liyuan', 'Liyuan,Liyuan Zhen,li yuan,li yuan zhen,梨园,梨园镇', 39.8722400, 116.6562700, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20255, 'Yushan', 'Yushan', 'Mazhu,Yushan,Yushan Zhen,yu shan,yu shan zhen,嵛山,嵛山镇', 26.9574800, 120.3227700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20256, 'Daqiuzhuang', 'Daqiuzhuang', 'Daqiuzhuang,Daqiuzhuang Zhen,da qiu zhuang,da qiu zhuang zhen,大邱庄,大邱庄镇', 38.8353900, 117.0530100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20257, 'Yangchengzhuang', 'Yangchengzhuang', 'Yangchengzhuang,Yangchengzhuang Zhen,yang cheng zhuang,yang cheng zhuang zhen,杨成庄,杨成庄镇', 38.9416700, 117.0491700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20258, 'Shuangqiaohe', 'Shuangqiaohe', 'Shuangqiaohe,Shuangqiaohe Zhen,shuang qiao he,shuang qiao he zhen,双桥河,双桥河镇', 38.9888700, 117.4207600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20259, 'Gaozhai', 'Gaozhai', 'Gaozhai,Gaozhai Zhen,gao zhai,gao zhai zhen,高寨,高寨镇', 36.5438400, 101.9860200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20260, 'Shangxinzhuang', 'Shangxinzhuang', 'Shangxinzhuang,Shangxinzhuang Zhen,shang xin zhuang,shang xin zhuang zhen,上新庄,上新庄镇', 36.4122800, 101.5696800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20261, 'Shenzhong', 'Shenzhong', 'Shenzhong,Shenzhong Xiang,shen zhong,shen zhong xiang,申中,申中乡', 36.7244400, 101.1866700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20262, 'Dayang', 'Dayang', 'Dayang,Dayang Xiang,da yang,da yang xiang,大洋,大洋乡', 38.7708000, 114.7944300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20263, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Zhen,feng shan,feng shan zhen,凤山,凤山镇', 38.0473700, 114.0484700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20264, 'Langjiazhuang', 'Langjiazhuang', 'Langjiazhuang,Langjiazhuang Xiang,lang jia zhuang,lang jia zhuang xiang,郎家庄,郎家庄乡', 38.8627700, 114.6368800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20265, 'Lichengdao', 'Lichengdao', 'Lichengdao,Lichengdao Xiang,li cheng dao,li cheng dao xiang,里城道,里城道乡', 38.2354900, 114.9244000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20266, 'Mucun', 'Mucun', 'Mucun,Mucun Xiang,mu cun,mu cun xiang,穆村,穆村乡', 38.4096100, 114.6832000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20267, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Xiang,yong feng,yong feng xiang,永丰,永丰乡', 26.3061300, 115.2090100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20268, 'Qingtang', 'Qingtang', 'Qingtang,Qingtang Zhen,qing tang,qing tang zhen,青塘,青塘镇', 26.4408200, 115.8629700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20269, 'Fangtai', 'Fangtai', 'Fangtai,Fangtai Xiang,fang tai,fang tai xiang,方太,方太乡', 26.5108300, 115.3850000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20270, 'Futan', 'Futan', 'Futan,Futan Zhen,fu tan,fu tan zhen,富滩,富滩镇', 26.9912500, 115.1503300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20271, 'Yayao', 'Yayao', 'Yayao,Yayao Zhen,ya yao,ya yao zhen,雅瑶,雅瑶镇', 22.7112300, 113.0060200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20272, 'Da’ao', 'Da''ao', 'Da''ao,Da''ao Zhen,Da’ao,Da’ao Zhen,da ao,da ao zhen,大敖,大敖镇,大鳌', 22.4857000, 113.2063700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20273, 'Dongfeng', 'Dongfeng', 'Dongfeng,dong feng,东凤', 22.6899900, 113.2452900, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20274, 'Nantou', 'Nantou', 'Nantou,Nantou Zhen,nan tou,nan tou zhen,南头,南头镇', 22.7217100, 113.2926100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20275, 'Zhongcun', 'Zhongcun', 'Zhongcun,Zhongcun Jiedao,zhong cun,zhong cun jie dao,钟村,钟村街道', 22.9761100, 113.3130600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20276, 'Banfu', 'Banfu', 'Banfu,ban fu,板芙', 22.4097200, 113.3182500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20277, 'Lanhe', 'Lanhe', 'Lanhe,Lanhe Zhen,lan he,lan he zhen,榄核,榄核镇', 22.8422800, 113.3382000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20278, 'Shatou', 'Shatou', 'Shatou,Shatou Jiedao,sha tou,sha tou jie dao,沙头,沙头街道', 22.9551300, 113.3361100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20279, 'Fusha', 'Fusha', 'Fusha,Fusha Zhen,fu sha,fu sha zhen,阜沙,阜沙镇', 22.6623000, 113.3450900, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20280, 'Sanjiao', 'Sanjiao', 'Sanjiao,Sanjiao Zhen,san jiao,san jiao zhen,三角,三角镇', 22.6850000, 113.4275000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20281, 'Shiqi', 'Shiqi', 'Shiji Zhen,Shiqi,shi qi,shi qi zhen,石碁,石碁镇', 22.9564200, 113.4334200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20282, 'Tanzhou', 'Tanzhou', 'Tanzhou,Tanzhou Zhen,tan zhou,tan zhou zhen,坦洲,坦洲镇', 22.2550300, 113.4669200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20283, 'Dongyong', 'Dongyong', 'Dongchong,Dongyong,dong yong,东涌', 22.8865600, 113.4557700, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20284, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,沙田,沙田镇', 22.9236100, 113.6116700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20285, 'Xinwan', 'Xinwan', 'Xinwan,Xinwan Zhen,xin wan,新湾', 22.7866200, 113.6680000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20286, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Zhen,Chang’an,Chang’an Zhen,zhang an,长安', 22.8064800, 113.8027800, 'CN', '2012-09-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20287, 'Dongkeng', 'Dongkeng', 'Dongkeng,Dongkeng Zhen,dong keng,dong keng zhen,东坑,东坑镇', 22.9888900, 113.9413900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20288, 'Shahe', 'Shahe', 'Shahe,Shahe Jiedao,Shahezhan,sha he,sha he jie dao,沙河,沙河街道', 22.5522600, 113.9791200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20289, 'Huangjiang', 'Huangjiang', 'Huangjiang,Huangjiang Zhen,huang jiang,huang jiang zhen,黄江,黄江镇', 22.9205700, 113.9965000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20290, 'Wendengying', 'Wendengying', 'Wendengying,Wendengying Zhen,wen deng ying,wen deng ying zhen,文登营,文登营镇', 37.2127000, 122.1000200, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20291, 'Xiazhuang', 'Xiazhuang', 'Xiazhuang,Xiazhuang Zhen,xia zhuang,xia zhuang zhen,夏庄,夏庄镇', 37.2323100, 122.4526100, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20292, 'Yaxi', 'Yaxi', 'Yaxi,Yaxi Zhen,ya xi,ya xi zhen,崖西,崖西镇', 37.2519500, 122.3658900, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20293, 'Heshan', 'Heshan', 'Heshan,Heshan Zhen,Qingshan,he shan,he shan zhen,荷山,荷山镇', 37.2843200, 122.0667000, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20294, 'Chengshan', 'Chengshan', 'Chengshan,Chengshan Zhen,Chengshanwei,cheng shan,cheng shan zhen,成山,成山镇', 37.3671600, 122.5519800, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20295, 'Gangxi', 'Gangxi', 'Gangxi,Gangxi Zhen,gang xi,gang xi zhen,港西,港西镇', 37.3820200, 122.4299200, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20296, 'Boyu', 'Boyu', 'Boyu,Boyu Zhen,Boyujia,po yu,po yu zhen,泊于,泊于镇', 37.3777500, 122.3488500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20297, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,gu shan,gu shan zhen,崮山,崮山镇', 37.4082100, 122.2391300, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20298, 'Zhangcun', 'Zhangcun', 'Zhangcun,Zhangcun Zhen,zhang cun,zhang cun zhen,张村,张村镇', 37.4846400, 122.0313400, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20299, 'Sunjiatuan', 'Sunjiatuan', 'Sunjiatuan,Sunjiatuan Zhen,sun jia tuan,sun jia tuan zhen,孙家疃,孙家疃镇', 37.5381000, 122.1119500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20300, 'Xiaomiaozi', 'Xiaomiaozi', 'Xiaomiaozi,xiao miao zi,小庙子', 39.9177800, 111.6544400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20301, 'Shunhua', 'Shunhua', 'Shunhua,Shunhua Xiang,shun hua,shun hua xiang,顺化,顺化乡', 38.4686100, 100.7141700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20302, 'Nanhai', 'Nanhai', 'Nanhai,Nanhai Jeidao,nan hai,nan hai jie dao,南海,南海街道', 21.4725100, 111.0268400, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20303, 'Shuzi', 'Shuzi', 'Shuzai Zhen,Shuzi,shu zi,shu zi zhen,树仔,树仔镇', 21.5446700, 111.2233100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20304, 'Lingmen', 'Lingmen', 'Lingmen,Lingmen Zhen,ling men,ling men zhen,岭门,岭门镇', 21.5702800, 111.3872200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20305, 'Xiachuan', 'Xiachuan', 'Xiachuan,Xiachuan Zhen,xia chuan,xia chuan zhen,下川,下川镇', 21.6508600, 112.5812900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20306, 'Xinxu', 'Xinxu', 'Xinxu,Xinyu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 21.7047100, 111.4472800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20307, 'Shangchuan', 'Shangchuan', 'Shangchuan,Shangchuan Zhen,shang chuan,shang chuan zhen,上川,上川镇', 21.7262100, 112.7712900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20308, 'Zhize', 'Zhize', 'Zhize,Zhize Zhen,zhi ze,zhi ze zhen,织箦,织箦镇', 21.7554000, 111.6143300, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20309, 'Buchang', 'Buchang', 'Buchang,Buchang Zhen,bu chang,bu chang zhen,埠场,埠场镇', 21.7785500, 111.9223100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20310, 'Genzi', 'Genzi', 'Genzi,Genzi Zhen,gen zi,gen zi zhen,根子,根子镇', 21.7990500, 111.0399800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20311, 'Luokeng', 'Luokeng', 'Luokeng,Luokeng Zhen,luo keng,luo keng zhen,罗坑,罗坑镇', 21.8215500, 111.2390100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20312, 'Huangling', 'Huangling', 'Huangling,Huangling Zhen,huang ling,huang ling zhen,黄岭,黄岭镇', 21.8344400, 111.1544400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20313, 'Baisha', 'Baisha', 'Baisha,Baisha Jiedao,bai sha,bai sha jie dao,白沙,白沙街道', 21.8727500, 111.8740900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20314, 'Yuntan', 'Yuntan', 'Yuntan,Yuntan Zhen,yun tan,yun tan zhen,云潭,云潭镇', 21.8841500, 111.1643000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20315, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Zhen,Yangdong Xian,dong cheng,dong cheng zhen,yang dong xian,东城,东城镇,阳东县', 21.8820000, 112.0102200, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20316, 'Xindong', 'Xindong', 'Xindong,Xintong Zhen,xin dong,xin dong zhen,新垌,新垌镇', 21.9081700, 111.0630200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20317, 'Beiguan', 'Beiguan', 'Beiguan,Beiguan Zhen,bei guan,bei guan zhen,北惯,北惯镇', 21.9324800, 112.0667600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20318, 'Pingshan', 'Pingshan', 'Pingshan,Pingshan Zhen,ping shan,ping shan zhen,平山,平山镇', 22.0948200, 111.0884300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20319, 'Guding', 'Guding', 'Guding,Guding Zhen,gu ding,gu ding zhen,古丁,古丁镇', 22.1520900, 111.1964800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20320, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Zhen,san he,san he zhen,三合,三合镇', 22.1904300, 112.7176600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20321, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Zhen,dong cheng,dong cheng zhen,东成,东成镇', 22.2461000, 112.3813800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20322, 'Xiangang', 'Xiangang', 'Xiangang,Xiangang Zhen,Yangang,xian gang,xian gang zhen,蚬冈,蚬冈镇', 22.2840600, 112.5332000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20323, 'Sanba', 'Sanba', 'Sanba,Sanba Zhen,san ba,san ba zhen,三八,三八镇', 22.3017600, 112.6814600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20324, 'Juntang', 'Juntang', 'Juntang,Juntang Zhen,jun tang,jun tang zhen,君堂,君堂镇', 22.3194900, 112.4249400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20325, 'Liangxi', 'Liangxi', 'Liangxi,Liangxi Zhen,liang xi,liang xi zhen,良西,良西镇', 22.3211900, 112.3365800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20326, 'Pimian', 'Pimian', 'Pimian,Pimian Zhen,bei mian,bei mian zhen,陂面,陂面镇', 22.3441700, 111.8475000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20327, 'Tangkou', 'Tangkou', 'Tangkou,Tangkou Zhen,tang kou,tang kou zhen,塘口,塘口镇', 22.3677700, 112.6172500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20328, 'Xinbao', 'Xinbao', 'Xinbao,Xinbao Zhen,xin bao,xin bao zhen,新宝,新宝镇', 22.3812700, 111.4619900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20329, 'Shatang', 'Shatang', 'Shatang,Shatang Zhen,sha tang,sha tang zhen,沙塘,沙塘镇', 22.4582300, 112.5868300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20330, 'Sihe', 'Sihe', 'Sihe,Sihe Zhen,si he,si he zhen,思贺,思贺镇', 22.4735800, 111.5852000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20331, 'Hongguan', 'Hongguan', 'Hongguan,Hongguan Zhen,hong guan,hong guan zhen,洪冠,洪冠镇', 22.4520600, 111.1454200, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20332, 'Songbai', 'Songbai', 'Songbai,Songbo Zhen,song bai,song bai zhen,松柏,松柏镇', 22.4811100, 111.8808300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20333, 'Luokeng', 'Luokeng', 'Luokeng,Luokeng Zhen,luo keng,luo keng zhen,罗坑,罗坑镇', 22.4626500, 112.9197700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20334, 'Magang', 'Magang', 'Magang,Magang Zhen,ma gang,ma gang zhen,马冈,马冈镇', 22.4777900, 112.4931000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20335, 'Dajiang', 'Dajiang', 'Dajiang,Dajiang Zhen,da jiang,da jiang zhen,大江,大江镇', 22.4801400, 112.1186200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20336, 'Yueshan', 'Yueshan', 'Yueshan,Yueshan Zhen,yue shan,yue shan zhen,月山,月山镇', 22.4781700, 112.7278500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20337, 'Shiwang', 'Shiwang', 'Shiwang,Shiwang Zhen,shi wang,shi wang zhen,石望,石望镇', 22.5270900, 111.9283300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20338, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 22.5196600, 111.4975000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20339, 'Fenjie', 'Fenjie', 'Fenjie,Fenjie Zhen,fen jie,fen jie zhen,分界,分界镇', 22.5544700, 111.3457800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20340, 'Chashan', 'Chashan', 'Chashan,Chashan Zhen,cha shan,cha shan zhen,茶山,茶山镇', 22.5577800, 111.1397200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20341, 'Hetou', 'Hetou', 'Hetou,Hetou Zhen,he tou,he tou zhen,河头,河头镇', 22.5847400, 112.0431600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20342, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Zhen,gong he,gong he zhen,共和,共和镇', 22.5813800, 112.8773700, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20343, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 22.6416100, 112.2376100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20344, 'Fulin', 'Fulin', 'Fulin,Fulinzhen,fu lin,fu lin zhen,富林,富林镇', 22.6621600, 111.8961100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20345, 'Jinji', 'Jinji', 'Jinji,Jinji Zhen,jin ji,jin ji zhen,金鸡,金鸡镇', 22.7136100, 111.8213900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20346, 'Jiayi', 'Jiayi', 'Jiayi,Jiayi Zhen,jia yi,jia yi zhen,加益,加益镇', 22.7070000, 111.1502300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20347, 'Shengjiang', 'Shengjiang', 'Shengjiang,Shengjiang Zhen,sheng jiang,sheng jiang zhen,生江,生江镇', 22.7075200, 111.5094400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20348, 'Pingtang', 'Pingtang', 'Pingtang,Pingtang Zhen,ping tang,ping tang zhen,苹塘,苹塘镇', 22.7568800, 111.7540700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20349, 'Huashi', 'Huashi', 'Huashi,Huashi Zhen,hua shi,hua shi zhen,华石,华石镇', 22.7660000, 111.6853000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20350, 'Mingcheng', 'Mingcheng', 'Mingcheng,Mingcheng Zhen,Mingchenggongyuan,ming cheng,ming cheng zhen,明城,明城镇', 22.8580600, 112.6923600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20351, 'Nansheng', 'Nansheng', 'Nansheng,Nanshengzhen,nan sheng,nan sheng zhen,南盛,南盛镇', 22.8280000, 112.0619600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20352, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,he kou,he kou zhen,河口,河口镇', 22.8705400, 111.7186800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20353, 'Huodao', 'Huodao', 'Huodao,Huodao Zhen,huo dao,huo dao zhen,活道,活道镇', 22.8655400, 112.4102600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20354, 'Songgui', 'Songgui', 'Songgui,Songgui Zhen,song gui,song gui zhen,宋桂,宋桂镇', 22.9030600, 111.7636000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20355, 'Antang', 'Antang', 'Antang,Antang Jiedao,Antangjieban,an tang,an tang jie dao,安塘,安塘街道', 22.9292700, 112.2025600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20356, 'Jiaotang', 'Jiaotang', 'Jiaotang,Jiaotang Zhen,jiao tang,jiao tang zhen,蛟塘,蛟塘镇', 22.9109400, 112.5886500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20357, 'Dongba', 'Dongba', 'Dongba,Dongba Zhen,dong ba,dong ba zhen,东坝,东坝镇', 22.9402100, 111.7516400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20358, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 22.9289000, 112.6286800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20359, 'Gaocun', 'Gaocun', 'Gaocun,Gaocunzhen,gao cun,gao cun zhen,高村,高村镇', 22.9441700, 111.8883300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20360, 'Silao', 'Silao', 'Silao,Silao Zhen,si lao,si lao zhen,思劳,思劳镇', 22.9295300, 112.2255800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20361, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Jiedao,Gaofengjieban,gao feng,gao feng jie dao,高峰,高峰街道', 22.9593100, 112.0417200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20362, 'Lidong', 'Lidong', 'Lidong,Lidong Zhen,li dong,li dong zhen,历洞,历洞镇', 22.9754000, 111.6620200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20363, 'Tongmen', 'Tongmen', 'Tongmen,Tongmen Zhen,tong men,tong men zhen,通门,通门镇', 23.0000000, 111.4688900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20364, 'Dongying', 'Dongying', 'Dongying,Dongying Zhen,dong ying,dong ying zhen,东营,东营镇', 20.0527800, 110.4134700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20365, 'Mei’an', 'Mei''an', 'Mei''an,Mei''an Zhen,Mei’an,Mei’an Zhen,mei an,mei an zhen,美安,美安镇', 19.8782600, 110.1858200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20366, 'Yongfa', 'Yongfa', 'Yongfa,Yongfa Zhen,yong fa,yong fa zhen,永发,永发镇', 19.7483400, 110.1948400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20367, 'Xinzhu', 'Xinzhu', 'Xinzhu,Xinzhu Zhen,xin zhu,xin zhu zhen,新竹,新竹镇', 19.6215800, 110.2065000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20368, 'Xinwu', 'Xinwu', 'Xinwu,Xinwu Zhen,xin wu,xin wu zhen,新吴,新吴镇', 19.6493600, 110.1874300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20369, 'Zuntan', 'Zuntan', 'Zuntan,Zuntan Zhen,zun tan,zun tan zhen,遵谭,遵谭镇', 19.8144300, 110.2991100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20370, 'Longqiao', 'Longqiao', 'Longqiao,Longqiao Zhen,long qiao,long qiao zhen,龙桥,龙桥镇', 19.9139100, 110.3557600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20371, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,hong qi,hong qi zhen,红旗,红旗镇', 19.8203600, 110.5063800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20372, 'Dapo', 'Dapo', 'Dapo,Dapo Zhen,da po,da po zhen,大坡,大坡镇', 19.6160900, 110.5715800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20373, 'Donglu', 'Donglu', 'Donglu,Donglu Zhen,dong lu,dong lu zhen,东路,东路镇', 19.7386900, 110.6779700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20374, 'Fengpo', 'Fengpo', 'Fengpo,Fengpo Zhen,feng po,feng po zhen,冯坡,冯坡镇', 19.9679600, 110.7765700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20375, 'Yanfeng', 'Yanfeng', 'Yanfeng,Yanfeng Zhen,yan feng,yan feng zhen,演丰,演丰镇', 19.9562100, 110.5463600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20376, 'Longlou', 'Longlou', 'Longlou,Longlou Zhen,long lou,long lou zhen,龙楼,龙楼镇', 19.6563200, 110.9645900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20377, 'Dongge', 'Dongge', 'Dongge,Dongge Zhen,dong ge,dong ge zhen,东阁,东阁镇', 19.6600400, 110.8451600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20378, 'Dayuanhuizu', 'Dayuanhuizu', 'Dayuanhuizu,Dayuanhuizu Xiang,Dayuanli,da yuan hui zu,da yuan hui zu xiang,大院回族,大院回族乡', 32.4230500, 105.2344500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20379, 'Fengxiang', 'Fengxiang', 'Fengxiang,Fengxiangyuan,feng xiang,枫相', 32.9019400, 105.3113000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20380, 'Xiasi', 'Xiasi', 'Xiasi,Xiasi Zhen,xia si,xia si zhen,下寺,下寺镇', 32.2899800, 105.5132600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20381, 'Yangba', 'Yangba', 'Yangba,Yangba Zhen,yang ba,yang ba zhen,阳坝,阳坝镇', 33.0102700, 105.7664300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20382, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Jiedao,tao yuan,tao yuan jie dao,桃园,桃园街道', 36.9328400, 122.4440100, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20383, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Jiedao,dong shan,dong shan jie dao,东山,东山街道', 36.9633300, 122.4397200, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20384, 'Wanglian', 'Wanglian', 'Wanglian,Wanglian Jiedao,wang lian,wang lian jie dao,王连,王连街道', 36.9858100, 122.3639700, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20385, 'Conglin', 'Conglin', 'Conglin,Conglin Zhen,cong lin,cong lin zhen,丛林,丛林镇', 29.0302800, 106.9702800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20386, 'Ciyun', 'Ciyun', 'Ciyun,Ciyun Zhen,ci yun,ci yun zhen,慈云,慈云镇', 29.0754100, 106.2056000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20387, 'Xiaba', 'Xiaba', 'Xiaba,Xiaba Zhen,xia ba,xia ba zhen,夏坝,夏坝镇', 29.1168400, 106.5100600, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20388, 'Shentong', 'Shentong', 'Shentong,Shentong Zhen,shen tong,shen tong zhen,神童,神童镇', 29.1786100, 106.9308300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20389, 'Shitan', 'Shitan', 'Shitan,Shitan Zhen,shi tan,shi tan zhen,石滩,石滩镇', 29.1761100, 106.8852800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20390, 'Shilong', 'Shilong', 'Shilong,Shilong Zhen,shi long,shi long zhen,石龙,石龙镇', 29.2822200, 106.8980600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20391, 'Xipeng', 'Xipeng', 'Xipeng,Xipeng Zhen,xi peng,xi peng zhen,西彭,西彭镇', 29.2941800, 106.3212400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20392, 'Huimin', 'Huimin', 'Huimin,Huimin Zhen,Huiming,hui min,hui min zhen,惠民,惠民镇', 29.4619400, 106.7047200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20393, 'Zouma', 'Zouma', 'Zouma,Zouma Zhen,zou ma,zou ma zhen,走马,走马镇', 29.4711100, 106.2947200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20394, 'Fengsheng', 'Fengsheng', 'Fengsheng,Fengsheng Zhen,feng sheng,feng sheng zhen,丰盛,丰盛镇', 29.5313900, 106.9325000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20395, 'Guangyang', 'Guangyang', 'Guangyang,Guangyang Zhen,guang yang,guang yang zhen,广阳,广阳镇', 29.5836100, 106.7525000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20396, 'Tuzhu', 'Tuzhu', 'Tuzhu,Tuzhu Zhen,tu zhu,tu zhu zhen,土主,土主镇', 29.6441200, 106.3671700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20397, 'Yufengshan', 'Yufengshan', 'Shiping,Yufengshan,Yufengshan Zhen,shi ping,yu feng shan,yu feng shan zhen,玉峰山,玉峰山镇,石坪', 29.6635200, 106.6659100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20398, 'Tongjiaxi', 'Tongjiaxi', 'Tongjiaxi,Tongjiaxi Zhen,Tongxingchang,tong jia xi,tong jia xi zhen,tong xing chang,同兴场,童家溪,童家溪镇', 29.6849700, 106.4444200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20399, 'Fuguo', 'Fuguo', 'Fuguo,Fuguo Zhen,fu guo,fu guo zhen,福果,福果镇', 29.6994700, 106.0472100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20400, 'Dasheng', 'Dasheng', 'Dasheng,Dasheng Zhen,da sheng,da sheng zhen,大盛,大盛镇', 29.8902900, 106.8972700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20401, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 29.9036100, 106.0387500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20402, 'Tuchang', 'Tuchang', 'Tuchang,Tuchang Zhen,Tuzhuchang,tu chang,tu chang zhen,tu zhu chang,土主场,土场,土场镇', 29.9253000, 106.4907000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20403, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Zhen,bai yang,bai yang zhen,白羊,白羊镇', 29.9611000, 106.0823400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20404, 'Honghu', 'Honghu', 'Honghu,Honghu Zhen,hong hu,hong hu zhen,洪湖,洪湖镇', 30.0004300, 106.9520400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20405, 'Jiatou', 'Jiatou', 'Jiatou,Jiatou Xiang,jia tou,jia tou xiang,佳头,佳头乡', 26.0369200, 118.6079400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20406, 'Houjia', 'Houjia', 'Houjia,Houjia Xiang,hou jia,hou jia xiang,后佳,后佳乡', 26.0368100, 118.5487200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20407, 'Sanxi', 'Sanxi', 'Sanxi,Sanxi Xiang,san xi,san xi xiang,三溪,三溪乡', 26.1138100, 118.8131000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20408, 'Yunlong', 'Yunlong', 'Yunlong,Yunlong Xiang,yun long,yun long xiang,云龙,云龙乡', 26.1708800, 118.8299500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20409, 'Meixi', 'Meixi', 'Meixi,Meixi Zhen,mei xi,mei xi zhen,梅溪,梅溪镇', 26.2091200, 118.8787000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20410, 'Zhenghu', 'Zhenghu', 'Zhenghu,Zhenghu Xiang,zheng hu,zheng hu xiang,郑湖,郑湖乡', 26.3614400, 118.0217500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20411, 'Luxia', 'Luxia', 'Luxia,Luxia Zhen,lu xia,lu xia zhen,炉下,炉下镇', 26.4900400, 118.2961100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20412, 'Chimen', 'Chimen', 'Chimen,Chimen Xiang,chi men,chi men xiang,赤门,赤门乡', 26.5454900, 118.4477600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20413, 'Songji', 'Songji', 'Songji,Songji Xiang,song ji,song ji xiang,松吉,松吉乡', 26.5766200, 118.7403500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20414, 'Yedun', 'Yedun', 'Gaoyang Xiang,Yedun,gao yang xiang,ye dun,叶墩,高阳乡', 26.9098500, 118.1416200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20415, 'Wenlang', 'Wenlang', 'Wenlang,Wenlang Zhen,wen lang,wen lang zhen,汶朗,汶朗镇', 23.9840800, 112.2816100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20416, 'Gansa', 'Gansa', 'Gansa,Gansa Zhen,gan sa,gan sa zhen,甘洒,甘灑镇', 23.9667300, 112.3136100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20417, 'Heyun', 'Heyun', 'Heyun,Heyun Zhen,he yun,he yun zhen,禾云,禾云镇', 23.9302800, 112.9188900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20418, 'Dagang', 'Dagang', 'Dagang,Dagang Zhen,da gang,da gang zhen,大岗,大岗镇', 23.8831200, 112.0363900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20419, 'Longjing', 'Longjing', 'Longjing,Longjing Zhen,long jing,long jing zhen,龙颈,龙颈镇', 23.8695700, 112.8371300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20420, 'Chikeng', 'Chikeng', 'Chikeng,Chikeng Zhen,chi keng,chi keng zhen,赤坑,赤坑镇', 23.8509700, 112.4769200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20421, 'Zhagang', 'Zhagang', 'Zhagang,Zhagang Zhen,zha gang,zha gang zhen,闸岗,闸岗镇', 23.8323500, 112.1003500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20422, 'Kengkou', 'Kengkou', 'Kengkou,Kengkou Zhen,keng kou,keng kou zhen,坑口,坑口镇', 23.7879900, 112.4000800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20423, 'Lianhe', 'Lianhe', 'Lianhe,Lianhe Zhen,lian he,lian he zhen,联和,联和镇', 23.7305300, 112.6537700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20424, 'Tanbu', 'Tanbu', 'Tanbu,Tanbu Zhen,tan bu,tan bu zhen,潭布,潭布镇', 23.6230600, 112.5597900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20425, 'Shizui', 'Shizui', 'Shizui,Shizui Zhen,shi ju,shi ju zhen,石咀,石咀镇', 23.6177200, 112.1585500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20426, 'Zhouzai', 'Zhouzai', 'Zhouzai,Zhouzai Zhen,zhou zi,zhou zi zhen,洲仔,洲仔镇', 23.6204300, 112.2865500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20427, 'Luoyuan', 'Luoyuan', 'Luoyuan,Luoyuan Zhen,luo yuan,luo yuan zhen,罗源,罗源镇', 23.5789100, 112.7513300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20428, 'Paisha', 'Paisha', 'Paisha,Paisha Zhen,pai sha,pai sha zhen,排沙,排沙镇', 23.5370100, 112.5284600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20429, 'Wuhe', 'Wuhe', 'Wuhe,Wuhe Zhen,wu he,wu he zhen,五和,五和镇', 23.4477300, 112.3447100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20430, 'Xiamao', 'Xiamao', 'Xiamao,Xiamao Zhen,xia mao,xia mao zhen,下茆,下茆镇', 23.4191100, 112.6597900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20431, 'Longfu', 'Longfu', 'Longfu,Longfu Zhen,long fu,long fu zhen,龙甫,龙甫镇', 23.3574300, 112.7086200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20432, 'Hetai', 'Hetai', 'Hetai,Hetai Zhen,he tai,he tai zhen,河台,河台镇', 23.3496200, 112.2740900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20433, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Zhen,yong feng,yong feng zhen,永丰,永丰镇', 23.3400000, 112.1202800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20434, 'Wulong', 'Wulong', 'Wulong,Wulong Zhen,wu long,wu long zhen,武垄,武垄镇', 23.3231100, 112.1876200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20435, 'Shuinan', 'Shuinan', 'Shuinan,Shuinan Zhen,shui nan,shui nan zhen,水南,水南镇', 23.3018300, 112.3691300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20436, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,Liantang,lian hua,lian hua zhen,莲花,莲花镇', 23.2625600, 112.6869400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20437, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 23.1791700, 112.6885400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20438, 'Xiaoxiang', 'Xiaoxiang', 'Xiaoxiang,Xiaoxiang Zhen,xiao xiang,xiao xiang zhen,小湘,小湘镇', 23.1356500, 112.3869100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20439, 'Mugang', 'Mugang', 'Mugang,mu gang,睦岗', 23.0677300, 112.4153700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20440, 'Duyang', 'Duyang', 'Douyang Zhen,Duqi,Duyang,dou yang,dou yang zhen,都杨,都杨镇', 23.0171200, 112.1503700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20441, 'Hongmao', 'Hongmao', 'Hongmao,Hongmao Zhen,hong mao,hong mao zhen,红毛,红毛镇', 19.0255900, 109.6654900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20442, 'Zhongping', 'Zhongping', 'Zhongping,Zhongping Zhen,zhong ping,zhong ping zhen,中平,中平镇', 19.0030100, 110.0549200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20443, 'Huishan', 'Huishan', 'Huishan,Huishan Zhen,hui shan,hui shan zhen,会山,会山镇', 19.0694000, 110.2610300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20444, 'Yuanmen', 'Yuanmen', 'Yuanmen,yuan men,元门', 19.1582300, 109.4826500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20445, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Zhen,long jiang,long jiang zhen,龙江,龙江镇', 19.1477100, 110.3200500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20446, 'Xishui', 'Xishui', 'Xishui,Xishui Xiang,xi shui,xi shui xiang,细水,细水乡', 19.2112900, 109.5596800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20447, 'Wanquan', 'Wanquan', 'Wanquan,Wanquan Zhen,wan quan,wan quan zhen,万泉,万泉镇', 19.2441500, 110.4039600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20448, 'Limushan', 'Limushan', 'Limushan,Limushan Zhen,li mu shan,li mu shan zhen,黎母山,黎母山镇', 19.2675200, 109.7829800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20449, 'Poxin', 'Poxin', 'Poxin,Poxin Zhen,po xin,po xin zhen,坡心,坡心镇', 19.3020200, 110.0837400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20450, 'Lanyang', 'Lanyang', 'Lanyang,Lanyang Zhen,lan yang,lan yang zhen,兰洋,兰洋镇', 19.4614100, 109.6604000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20451, 'Sandu', 'Sandu', 'Sandu,Sandu Zhen,san dou,san dou zhen,三都,三都镇', 19.7894000, 109.2150000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20452, 'Mutang', 'Mutang', 'Mutang,Mutang Zhen,mu tang,mu tang zhen,木棠,木棠镇', 19.8075500, 109.3453900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20453, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Zhen,dong cheng,dong cheng zhen,东成,东成镇', 19.7086800, 109.4561000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20454, 'Heqing', 'Heqing', 'Heqing,Heqing Zhen,he qing,he qing zhen,和庆,和庆镇', 19.5283100, 109.6327900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20455, 'Bohou', 'Bohou', 'Bohou,Bohou Zhen,bo hou,bo hou zhen,博厚,博厚镇', 19.8812500, 109.7405900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20456, 'Huangtong', 'Huangtong', 'Huangtong,Huangtong Zhen,huang tong,huang tong zhen,皇桐,皇桐镇', 19.8350300, 109.8439100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20457, 'Longbo', 'Longbo', 'Longbo,Longbo Zhen,long bo,long bo zhen,龙波,龙波镇', 19.7610100, 109.8518700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20458, 'Dongyin', 'Dongyin', 'Dongyin,Dongyin Zhen,dong ying,dong ying zhen,东英,东英镇', 19.9605400, 109.6427300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20459, 'Tandou', 'Tandou', 'Tandou,Tandou Zhen,qin dou zhen,tan dou,潭斗,覃斗镇', 20.5268600, 109.8955600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20460, 'Xinliao', 'Xinliao', 'Xinliao,Xinliao Zhen,xin liao,xin liao zhen,新寮,新寮镇', 20.6204900, 110.4631000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20461, 'Leigao', 'Leigao', 'Leigao,Leigao Zhen,lei gao,lei gao zhen,雷高,雷高镇', 20.8093100, 110.1936400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20462, 'Songzhu', 'Songzhu', 'Songzhu,Songzhu Zhen,song zhu,song zhu zhen,松竹,松竹镇', 20.8561600, 110.0578300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20463, 'Yangjia', 'Yangjia', 'Yangjia,Yangjia Zhen,yang jia,yang jia zhen,杨家,杨家镇', 20.8980200, 109.9603100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20464, 'Baisha', 'Baisha', 'Baisha,Baisha Zhen,bai sha,bai sha zhen,白沙,白沙镇', 20.8908300, 110.0888800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20465, 'Shentang', 'Shentang', 'Shentang,Shentang Zhen,chen tang,chen tang zhen,沈塘,沈塘镇', 20.9998900, 110.1206700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20466, 'Min’an', 'Min''an', 'Min''an,Min''an Zhen,Min’an,Min’an Zhen,min an,min an zhen,民安,民安镇', 21.0139000, 110.3199500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20467, 'Jianxin', 'Jianxin', 'Jianxin,Jianxin Zhen,jian xin,jian xin zhen,建新,建新镇', 21.1160300, 110.2021000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20468, 'Lemin', 'Lemin', 'Lemin,Lemin Zhen,le min,le min zhen,乐民,乐民镇', 21.1340600, 109.7567000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20469, 'Nansan', 'Nansan', 'Nansan,Nansan Zhen,nan san,nan san zhen,南三,南三镇', 21.1517300, 110.5506100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20470, 'Gangmen', 'Gangmen', 'Gangmen,Gangmen Zhen,gang men,gang men zhen,港门,港门镇', 21.2146900, 109.7998700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20471, 'Qiantang', 'Qiantang', 'Qiantang,Qiantang Zhen,gan tang,gan tang zhen,乾塘,乾塘镇', 21.2315800, 110.6118800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20472, 'Wutang', 'Wutang', 'Wutang,Wutang Zhen,wu tang,wu tang zhen,乌塘,乌塘镇', 21.2626000, 110.0014600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20473, 'Lingbei', 'Lingbei', 'Lingbei,Lingbei Zhen,ling bei,ling bei zhen,岭北,岭北镇', 21.2635500, 110.1641600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20474, 'Zhongshan', 'Zhongshan', 'Zhongshan,zhong shan,zhong shan shi,中山,中山市', 21.3199200, 110.5723000, 'CN', '2014-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20475, 'Yanggan', 'Yanggan', 'Yanggan,Yanggan Zhen,yang gan,yang gan zhen,杨柑,杨柑镇', 21.3218900, 109.9184500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20476, 'Guandu', 'Guandu', 'Guandu,Guandu Zhen,guan du,guan du zhen,官渡,官渡镇', 21.3845000, 110.4375400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20477, 'Tangwei', 'Tangwei', 'Tangwei,Tangwei Jiedao,tang wei,tang wei jie dao,塘尾,塘尾街道', 21.3954500, 110.7283200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20478, 'Jiepao', 'Jiepao', 'Jiepao,Jiepao Zhen,jie pao,jie pao zhen,界炮,界炮镇', 21.3968400, 109.9601900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20479, 'Zhenwen', 'Zhenwen', 'Zhenwen,Zhenwen Zhen,zhen wen,zhen wen zhen,振文,振文镇', 21.4072600, 110.6845300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20480, 'Tanba', 'Tanba', 'Tanba,Tanba Zhen,qin ba,qin ba zhen,覃巴,覃巴镇', 21.4457600, 110.8548500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20481, 'Zhangpu', 'Zhangpu', 'Zhangpu,Zhangpu Zhen,zhang pu,zhang pu zhen,樟铺,樟铺镇', 21.4513900, 110.6952800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20482, 'Xiaoliang', 'Xiaoliang', 'Xiaoliang,Xiaoliang Zhen,xiao liang,xiao liang zhen,小良,小良镇', 21.4931000, 110.8906500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20483, 'Shayuan', 'Shayuan', 'Shayuan,Shayuan Zhen,sha yuan,sha yuan zhen,沙院,沙院镇', 21.4474000, 110.9817900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20484, 'Lanshi', 'Lanshi', 'Lanshi,Lanshi Zhen,lan shi,lan shi zhen,兰石,兰石镇', 21.5163900, 110.8265300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20485, 'Cheban', 'Cheban', 'Cheban,Cheban Zhen,che ban,che ban zhen,车板,车板镇', 21.5172700, 109.8306100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20486, 'Yangmei', 'Yangmei', 'Yangmei,Yangmei Zhen,yang mei,yang mei zhen,杨梅,杨梅镇', 21.5438200, 110.6094700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20487, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,da qiao,da qiao zhen,笪桥,笪桥镇', 21.5732300, 110.4974700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20488, 'Qianshui', 'Qianshui', 'Qianshui,Qianshui Zhen,qian shui,qian shui zhen,浅水,浅水镇', 21.5855600, 110.7522500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20489, 'Zhencheng', 'Zhencheng', 'Zhencheng,Zhencheng Zhen,zhen sheng,zhen sheng zhen,镇盛,镇盛镇', 21.6100300, 110.8485600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20490, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,gao qiao,gao qiao zhen,高桥,高桥镇', 21.6090600, 109.7637200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20491, 'Poxin', 'Poxin', 'Poxin,Poxin Zhen,po xin,po xin zhen,坡心,坡心镇', 21.6419400, 111.0045000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20492, 'Gaoshan', 'Gaoshan', 'Gaoshan,Gaoshan Zhen,gao shan,gao shan zhen,高山,高山镇', 21.6544000, 110.8982900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20493, 'Xinpo', 'Xinpo', 'Xinpo,Xinpo Zhen,xin po,xin po zhen,新坡,新坡镇', 21.6618400, 110.8929600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20494, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Jiedao,dong shan,dong shan jie dao,东山,东山街道', 21.6667600, 110.6450800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20495, 'Jishui', 'Jishui', 'Jishui,Jishui Zhen,ji shui,ji shui zhen,吉水,吉水镇', 21.6730400, 110.2449600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20496, 'Shange', 'Shange', 'Shange,Shange Zhen,shan ge,shan ge zhen,山阁,山阁镇', 21.7283300, 110.9288900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20497, 'Ligang', 'Ligang', 'Ligang,Ligang Zhen,li gang,li gang zhen,丽岗,丽岗镇', 21.7503000, 110.6217300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20498, 'Heliao', 'Heliao', 'Heliao,Heliao Zhen,he liao,he liao zhen,和寮,和寮镇', 21.8569000, 110.1903800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20499, 'Sishui', 'Sishui', 'Sishui,Sishui Zhen,si shui,si shui zhen,泗水,泗水镇', 21.8577800, 110.9619400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20500, 'Zhenjiang', 'Zhenjiang', 'Zhenjiang,Zhenjiang Zhen,zhen jiang,zhen jiang zhen,镇江,镇江镇', 21.8680600, 110.7055600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20501, 'Jianghu', 'Jianghu', 'Jianghu,Jianghu Zhen,jiang hu,jiang hu zhen,江湖,江湖镇', 21.8708300, 110.6047200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20502, 'Shijiao', 'Shijiao', 'Shijiao,Shijiao Zhen,shi jiao,shi jiao zhen,石角,石角镇', 21.8792900, 110.3101100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20503, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,沙田,沙田镇', 21.9052800, 110.7200000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20504, 'Caojiang', 'Caojiang', 'Caojiang,Caojiang Zhen,cao jiang,cao jiang zhen,曹江,曹江镇', 21.9850100, 110.9448100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20505, 'Shiban', 'Shiban', 'Shiban,Shiban Zhen,shi ban,shi ban zhen,石板,石板镇', 22.1533800, 110.7147400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20506, 'Tantou', 'Tantou', 'Tantou,Tantou Zhen,tan tou,tan tou zhen,潭头,潭头镇', 22.1842600, 110.8569200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20507, 'Zhenlong', 'Zhenlong', 'Zhenlong,Zhenlong Zhen,zhen long,zhen long zhen,镇隆,镇隆镇', 22.2113900, 110.8741700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20508, 'Hehua', 'Hehua', 'Hehua,Hehua Zhen,he hua,he hua zhen,荷花,荷花镇', 22.2414400, 110.7010600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20509, 'Zhangshui', 'Zhangshui', 'Zhangshui,Zhangshui Zhen,zhang shui,zhang shui zhen,章水,章水镇', 29.8203600, 121.2993500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20510, 'Xiaren', 'Xiaren', 'Jinting,Jinting Zhen,Xiaren,jin ting zhen,xia ren,下任,金庭镇', 29.5704000, 121.0267600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20511, 'Hemudu', 'Hemudu', 'Hemudu,Hemudu Zhen,he mu du,he mu du zhen,河姆渡,河姆渡镇', 29.9871000, 121.3113800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20512, 'Ruanzhuang', 'Ruanzhuang', 'Lingnan,Ruanzhuang,ling nan,ruan zhuang,岭南,阮庄', 29.7801100, 121.0281300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20513, 'Chenxikou', 'Chenxikou', 'Chenxi,Chenxikou,chen xi,chen xi kou,陈溪,陈溪口', 29.8180500, 121.0522000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20514, 'Huangwu', 'Huangwu', 'Huangwu,Sanhe,Sanhe Zhen,huang wu,san he zhen,三合镇,黄务', 29.0845400, 121.1661000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20515, 'Feikeng', 'Feikeng', 'Feifeng,Feikeng,Shuangfeng,fei feng,fei keng,榧坑,榧峰', 29.2870200, 121.2355600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20516, 'Shiliang', 'Shiliang', 'Shiliang,Shiliang Zhen,shi liang,shi liang zhen,石梁,石梁镇', 29.2409700, 121.0432200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20517, 'Hengjie', 'Hengjie', 'Hengjie,Hengjie Zhen,heng jie,heng jie zhen,横街,横街镇', 29.8591700, 121.3969400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20518, 'Gulin', 'Gulin', 'Gulin,Gulin Zhen,gu lin,gu lin zhen,古林,古林镇', 29.8325000, 121.4302800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20519, 'Jishigang', 'Jishigang', 'Jishigang,Jishigang Zhen,ji shi gang,ji shi gang zhen,集士港,集士港镇', 29.8702800, 121.4311100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20520, 'Fulong', 'Fulong', 'Fulong,Fulong Xiang,fu long,fu long xiang,阜龙,阜龙乡', 19.3238700, 109.4553400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20521, 'Jinbo', 'Jinbo', 'Jinbo,Jinbo Xiang,jin bo,jin bo xiang,金波,金波乡', 19.2409200, 109.1699700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20522, 'Qifang', 'Qifang', 'Qifang,Qifang Zhen,qi fang,qi fang zhen,七坊,七坊镇', 19.2999200, 109.2357400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20523, 'Bangxi', 'Bangxi', 'Bangxi,Bangxi Zhen,bang xi,bang xi zhen,邦溪,邦溪镇', 19.3706400, 109.0978600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20524, 'Rongbang', 'Rongbang', 'Rongbang,Rongbang Xiang,rong bang,rong bang xiang,荣邦,荣邦乡', 19.4463700, 109.1339200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20525, 'Shiyuetian', 'Shiyuetian', 'Shiyuetian,Shiyuetian Zhen,shi yue tian,shi yue tian zhen,十月田,十月田镇', 19.3286700, 108.9489500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20526, 'Wulie', 'Wulie', 'Wulie,Wulie Zhen,wu lie,wu lie zhen,乌烈,乌烈镇', 19.2861400, 108.7839400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20527, 'Sanjia', 'Sanjia', 'Sanjia,Sanjia Zhen,san jia,san jia zhen,三家,三家镇', 19.2429900, 108.7559000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20528, 'Qicha', 'Qicha', 'Qicha,Qicha Xiang,qi cha,qi cha xiang,七差,七差乡', 19.1149400, 109.0665500, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20529, 'Changhao', 'Changhao', 'Changhao,Changhao Xiang,chang hao,chang hao xiang,畅好,畅好乡', 18.7377900, 109.4778300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20530, 'Chongshan', 'Chongshan', 'Chongshan,Chongshan Zhen,Wuzhishan Shi,chong shan,chong shan zhen,wu zhi shan shi,五指山市,冲山,冲山镇', 18.7822900, 109.5013000, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20531, 'Maodao', 'Maodao', 'Maodao,Maodao Xiang,mao dao,mao dao xiang,毛道,毛道乡', 18.8193500, 109.3982300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20532, 'Fanyang', 'Fanyang', 'Fanyang,Fanyang Zhen,fan yang,fan yang zhen,番阳,番阳镇', 18.8767500, 109.3931100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20533, 'Wuguishan', 'Wuguishan', 'Wuguishan,Wuguishan Jiedao,wu gui shan,wu gui shan jie dao,五桂山,五桂山街道', 22.4048500, 113.4293300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20534, 'Nanshan', 'Nanshan', 'Nanshan,Nanshan Jiedao,Nanshanqu,nan shan,nan shan jie dao,南山,南山街道', 22.5380000, 113.9388900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20535, 'Nan’ao', 'Nan''ao', 'Nan''ao,Nan''ao Jiedao,Nan’ao,Nan’ao Jiedao,nan ao,nan ao jie dao,南澳,南澳街道', 22.5407700, 114.4898200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20536, 'Liantang', 'Liantang', 'Liantang,Liantang Jiedao,lian tang,lian tang jie dao,莲塘,莲塘街道', 22.5667000, 114.1685900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20537, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Zhen,Jilong,dong sheng,dong sheng zhen,东升,东升镇', 22.6224500, 113.2887000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20538, 'Chaolian', 'Chaolian', 'Chaolian,Chaolian Jiedao,chao lian,chao lian jie dao,潮连,潮连街道', 22.6328500, 113.1101600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20539, 'Hetang', 'Hetang', 'Hetang,Hetang Zhen,he tang,he tang zhen,荷塘,荷塘镇', 22.6556200, 113.1280200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20540, 'Tieyong', 'Tieyong', 'Tieyong,Tieyong Zhen,tie yong,tie yong zhen,铁涌,铁涌镇', 22.7289600, 114.8422300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20541, 'Hengli', 'Hengli', 'Hengli,Hengli Zhen,heng li,heng li zhen,横沥,横沥镇', 22.7341000, 113.4830200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20542, 'Kengzi', 'Kengzi', 'Kengzi,Kengzi Jiedao,keng zi,keng zi jie dao,坑梓,坑梓街道', 22.7520300, 114.3703400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20543, 'Huangbu', 'Huangbu', 'Huangbu,huang bu,黄埠', 22.7540000, 114.9566400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20544, 'Guangming', 'Guangming', 'Guangming,Guangming Jiedao,Guangminghuaqiao Xumuchang,guang ming,guang ming jie dao,光明,光明街道', 22.7722800, 113.9299800, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20545, 'Pingdi', 'Pingdi', 'Pingdi,Pingdi Jiedao,ping de,ping de jie dao,坪地,坪地街道', 22.7707200, 114.3022600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20546, 'Fenggang', 'Fenggang', 'Fenggang,Fenggang Zhen,feng gang,风岗', 22.7567500, 114.1487900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20547, 'Dongyong', 'Dongyong', 'Dongyong,Dongyong Zhen,dong yong,dong yong zhen,东涌,东涌镇', 22.7957700, 115.4263500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20548, 'Qiuchang', 'Qiuchang', 'Qiuchang,Qiuchang Jiedao,qiu zhang,qiu zhang jie dao,秋长,秋长街道', 22.8206300, 114.4232200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20549, 'Ebu', 'Ebu', 'Ebu,Ebu Zhen,e bu,e bu zhen,鹅埠,鹅埠镇', 22.8319700, 114.9943000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20550, 'Dahu', 'Dahu', 'Dahu,Dahu Zhen,da hu,da hu zhen,大湖,大湖镇', 22.8377200, 115.5683900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20551, 'Hongcao', 'Hongcao', 'Hongcao,Hongcao Zhen,hong cao,hong cao zhen,红草,红草镇', 22.8270200, 115.3792700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20552, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,沙田,沙田镇', 22.8768700, 114.5518700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20553, 'Jinxiang', 'Jinxiang', 'Jinxiang,Jinxiang Zhen,jin xiang,jin xiang zhen,金厢,金厢镇', 22.8622100, 115.7282600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20554, 'Jiadong', 'Jiadong', 'Jiadong,Jiadong Zhen,jia dong,jia dong zhen,甲东,甲东镇', 22.8753000, 116.1172200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20555, 'Shangying', 'Shangying', 'Shangying,Shangying Zhen,shang ying,shang ying zhen,上英,上英镇', 22.8842700, 115.5642300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20556, 'Taohe', 'Taohe', 'Taohe,Taohe Zhen,tao he,tao he zhen,陶河,陶河镇', 22.8954000, 115.4105900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20557, 'Lian’an', 'Lian''an', 'Lian''an,Lian''an Zhen,Lian’an,Lian’an Zhen,lian an,lian an zhen,联安,联安镇', 22.9126500, 115.2952700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20558, 'Qishi', 'Qishi', 'Qishi,Qishi Zhen,qi shi,歧石', 22.9157200, 116.1360900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20559, 'Qiaochong', 'Qiaochong', 'Qiaochong,Qiaochong Zhen,qiao chong,qiao chong zhen,桥冲,桥冲镇', 22.9205100, 115.7976600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20560, 'Yonghu', 'Yonghu', 'Yonghu,Yonghu Zhen,yong hu,yong hu zhen,永湖,永湖镇', 22.9503800, 114.4875100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20561, 'Ketang', 'Ketang', 'Ketang,Ketang Zhen,ke tang,ke tang zhen,可塘,可塘镇', 22.9367600, 115.4622300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20562, 'Dalong', 'Dalong', 'Dalong,Mulong,da long,大龙', 22.9578200, 113.4271800, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20563, 'Lecong', 'Lecong', 'Lecong,Lecong Zhen,le cong,le cong zhen,乐从,乐从镇', 22.9586600, 113.0761600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20564, 'Aojiang', 'Aojiang', 'Aojiang,Aojiang Zhen,Biejiang,ao jiang,ao jiang zhen,鳌江,鳌江镇', 22.9383100, 116.0482900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20565, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 22.9523700, 115.6670900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20566, 'Qianzhan', 'Qianzhan', 'Qianzhan,Qianzhan Zhen,qian zhan,qian zhan zhen,前詹,前詹镇', 22.9449600, 116.4341600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20567, 'Hexi', 'Hexi', 'Hexi,Hexi Jiedao,he xi,he xi jie dao,河西,河西街道', 22.9723500, 115.5909400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20568, 'Nanzhuang', 'Nanzhuang', 'Nanzhuang,Nanzhuang Zhen,nan zhuang,nan zhuang zhen,南庄,南庄镇', 22.9877400, 113.0028800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20569, 'Donggang', 'Donggang', 'Donggang,Donggang Zhen,dong gang,dong gang zhen,东港,东港镇', 22.9872200, 115.9344400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20570, 'Lilin', 'Lilin', 'Lilin,Lilin Zhen,li lin,li lin zhen,沥林,沥林镇', 22.9938900, 114.2152800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20571, 'Hongmei', 'Hongmei', 'Hongmei,Hongmei Zhen,hong mei,hong mei zhen,洪梅,洪梅镇', 22.9937800, 113.6037100, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20572, 'Sandong', 'Sandong', 'Sandong,Sandong Zhen,san dong,san dong zhen,三栋,三栋镇', 22.9960400, 114.4478200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20573, 'Liangjing', 'Liangjing', 'Liangjing,Liangjing Zhen,liang jing,liang jing zhen,良井,良井镇', 23.0032500, 114.5671400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20574, 'Xixi', 'Xixi', 'Xixi,Xixi Zhen,xi xi,xi xi zhen,溪西,溪西镇', 22.9768300, 116.1751000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20575, 'Maodian', 'Maodian', 'Maodian,Maodian Zhen,mao dian,mao dian zhen,毛店,毛店镇', 29.1009200, 119.9939300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20576, 'Lingxia', 'Lingxia', 'Lingxia,Lingxia Zhen,ling xia,ling xia zhen,岭下,岭下镇', 29.0552300, 119.7612100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20577, 'Jiangdong', 'Jiangdong', 'Jiangdong,Jiangdong Zhen,jiang dong,jiang dong zhen,江东,江东镇', 29.0485500, 119.7385600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20578, 'Duohu', 'Duohu', 'Duohu,Duohu Jiedao,Jindong Qu,duo hu,duo hu jie dao,jin dong qu,多湖,多湖街道,金东区', 29.0937000, 119.6851100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20579, 'Fucun', 'Fucun', 'Fucun,Fucun Zhen,fu cun,fu cun zhen,傅村,傅村镇', 29.2403200, 119.8932000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20580, 'Caozhai', 'Caozhai', 'Caozhai,Caozhai Zhen,cao zhai,cao zhai zhen,曹宅,曹宅镇', 29.2044700, 119.7505700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20581, 'Huangzhai', 'Huangzhai', 'Huangzhai,Huangzhai Zhen,huang zhai,huang zhai zhen,黄宅,黄宅镇', 29.4486400, 119.9957100, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20582, 'Yantou', 'Yantou', 'Yantou,Yantou Zhen,Yantouchen,yan tou,yan tou chen,yan tou zhen,岩头,岩头镇,岩头陈', 29.4904200, 119.9552300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20583, 'Yuzhai', 'Yuzhai', 'Yuzhai,Yuzhai Xiang,yu zhai,yu zhai xiang,虞宅,虞宅乡', 29.5668000, 119.8681000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20584, 'Tanxi', 'Tanxi', 'Tanxi,Tanxi Zhen,tan xi,tan xi zhen,檀溪,檀溪镇', 29.6278600, 119.9431400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20585, 'Huyuan', 'Huyuan', 'Huyuan,Huyuan Xiang,Xiaozhang,hu yuan,hu yuan xiang,xiao zhang,小章,湖源,湖源乡', 29.8135300, 119.9442900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20586, 'Longmen', 'Longmen', 'Longmen,Longmen Zhen,long men,long men zhen,龙门,龙门镇', 29.9030300, 119.9474200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20587, 'Huanshan', 'Huanshan', 'Huanshan,Huanshan Xiang,huan shan,huan shan xiang,环山,环山乡', 29.9314300, 119.9246200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20588, 'Shen’ao', 'Shen''ao', 'Shen''ao,Shen''ao Zhen,Shen’ao,Shen’ao Zhen,shen ao,shen ao zhen,深澳,深澳镇', 29.8537000, 119.8349800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20589, 'Fengchuan', 'Fengchuan', 'Fengchuan,Fengchuan Zhen,feng chuan,feng chuan zhen,风川,风川镇', 29.8108000, 119.7746600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20590, 'Gaoxiang', 'Gaoxiang', 'Gaoxiang,gao xiang,高翔', 29.9283700, 119.5907000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20591, 'Yaolin', 'Yaolin', 'Yaolin,Yaolin Zhen,yao lin,yao lin zhen,瑶琳,瑶琳镇', 29.8987000, 119.5392800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20592, 'Qintang', 'Qintang', 'Qintang,Qintang Xiang,qin tang,qin tang xiang,钦堂,钦堂乡', 29.7148300, 119.5638500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20593, 'Qiantan', 'Qiantan', 'Qiantan,Qiantan Zhen,gan tan,gan tan zhen,乾潭,乾潭镇', 29.6198700, 119.5390300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20594, 'Xiachen', 'Xiachen', 'Xiachen,Xiachen Zhen,xia chen,xia chen zhen,下陈,下陈镇', 29.4101700, 119.6900400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20595, 'Baisha', 'Baisha', 'Baisha,Baisha Xiang,bai sha,bai sha xiang,白沙,白沙乡', 29.3066800, 119.7274700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20596, 'Mamu', 'Mamu', 'Mamu,Mamu Xiang,ma mu,ma mu xiang,马目,马目乡', 29.5006300, 119.3897900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20597, 'Houren', 'Houren', 'Houren,Houren Zhen,hou ren,hou ren zhen,厚仁,厚仁镇', 29.2687800, 119.3916400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20598, 'Xianqiao', 'Xianqiao', 'Xianqiao,Xianqiao Zhen,xian qiao,xian qiao zhen,仙桥,仙桥镇', 29.1500700, 119.6944100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20599, 'Bailongqiao', 'Bailongqiao', 'Bailongqiao,Bailongqiao Zhen,bai long qiao,bai long qiao zhen,白龙桥,白龙桥镇', 29.0776900, 119.5481800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20600, 'Changshan', 'Changshan', 'Changshan,Changshan Xiang,zhang shan,zhang shan xiang,长山,长山乡', 29.0208800, 119.5477500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20601, 'Yangbu', 'Yangbu', 'Yangbu,Yangbu Zhen,yang bu,yang bu zhen,洋埠,洋埠镇', 29.0954800, 119.3301700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20602, 'Shuiting', 'Shuiting', 'Shuiting,Shuiting Shezuxiang,shui ting,shui ting she zu xiang,水亭,水亭畲族乡', 29.1793500, 119.2726700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20603, 'Zhitang', 'Zhitang', 'Zhitang,Zhitang Zhen,zhi tang,zhi tang zhen,志棠,志棠镇', 29.2475000, 119.2421900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20604, 'Shifo', 'Shifo', 'Shifo,Shifo Xiang,shi fu,shi fu xiang,石佛,石佛乡', 29.1685600, 119.1050900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20605, 'Gaojia', 'Gaojia', 'Gaojia,Gaojia Zhen,gao jia,gao jia zhen,高家,高家镇', 29.0039600, 119.0292700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20606, 'Zhanjia', 'Zhanjia', 'Pushan,Zhanjia,Zhanjia Zhen,pu shan,zhan jia,zhan jia zhen,浦山,詹家,詹家镇', 29.0223900, 119.1276000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20607, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,lian hua,lian hua zhen,莲花,莲花镇', 29.0729400, 119.0080600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20608, 'Shangma', 'Shangma', 'Shangma,Shangma Xiang,shang ma,shang ma xiang,上马,上马乡', 29.2627500, 119.0380700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20609, 'Lijia', 'Lijia', 'Lijia,Lijia Zhen,li jia,li jia zhen,李家,李家镇', 29.3295000, 119.0332400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20610, 'Fangbu', 'Fangbu', 'Fangbu,Fangbu Zhen,fang bu,fang bu zhen,方埠,方埠镇', 29.8579500, 119.6095900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20611, 'Shifu', 'Shifu', 'Shifu,Shifu Zhen,shi fu,shi fu zhen,石阜,石阜镇', 29.8429800, 119.7831800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20612, 'Donghui', 'Donghui', 'Donghui,Donghui Xiang,dong hui,dong hui xiang,东辉,东辉乡', 29.8497800, 119.2783800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20613, 'Dashe', 'Dashe', 'Dashe,Yanjia,da she,yan jia,严家,大社', 29.9079000, 118.9074000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20614, 'Wangfu', 'Wangfu', 'Wangfu,Zhengzhong,wang fu,zheng zhong,王阜,郑中', 29.8418200, 118.9118100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20615, 'Weiping', 'Weiping', 'Weiping,Weiping Zhen,wei ping,wei ping zhen,威坪,威坪镇', 29.7269900, 118.7844200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20616, 'Tangban', 'Tangban', 'Jinfeng,Tangban,jin feng,tang fan,塘畈,金峰', 29.6838900, 118.9144400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20617, 'Yaojia', 'Yaojia', 'Jieshou,Yaojia,jie shou,yao jia,姚家,界首', 29.5526000, 118.7836200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20618, 'Langchuan', 'Langchuan', 'Langchuan,Langchuan Xiang,lang chuan,lang chuan xiang,浪川,浪川乡', 29.4991000, 118.5929300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20619, 'Liyang', 'Liyang', 'Lishang,Liyang,li shang,li yang,里商,里阳', 29.4828400, 118.9927000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20620, 'Shuangqiao', 'Shuangqiao', 'Shuangqiao,shuang qiao,双桥', 29.1339100, 118.8839300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20621, 'Datou', 'Datou', 'Datou,Qili,da tou,qi li,七里,大头', 29.1530600, 118.7577800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20622, 'Xiacaoqiao', 'Xiacaoqiao', 'Taizhen,Xiacaoqiao,tai zhen,xia cao qiao,下槽桥,太真', 29.1839200, 118.8387900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20623, 'Shisanli', 'Shisanli', 'Fushi,Shisanli,fu shi,shi san li,十三里,浮石', 29.0050500, 118.9075200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20624, 'Huipinggeng', 'Huipinggeng', 'Huipinggeng,Laochagen,hui ping geng,lao cha geng,灰坪埂,老茶埂', 29.2497500, 118.8542800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20625, 'Anyang', 'Anyang', 'Anyang,an yang,安阳', 29.4193200, 118.8283700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20626, 'Fengshuling', 'Fengshuling', 'Fengshuling,Fengshuling Zhen,feng shu ling,feng shu ling zhen,枫树岭,枫树岭镇', 29.3678200, 118.7045400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20627, 'Furong', 'Furong', 'Furong,Furong Xiang,fu rong,fu rong xiang,芙蓉,芙蓉乡', 29.1224100, 118.6374900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20628, 'Shangyuan', 'Shangyuan', 'Jinyuan,Shangyuan,jin yuan,shang yuan,上源,金源', 29.0475900, 118.6558600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20629, 'Xinchang', 'Xinchang', 'Xinchang,xin chang,新昌', 29.0743600, 118.5907300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20630, 'Donglu', 'Donglu', 'Donglu,dong lu,东鲁', 29.0249500, 118.5344800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20631, 'Lujiawu', 'Lujiawu', 'Lujiawu,Tongcun,Tongcun Zhen,lu jia wu,tong cun,tong cun zhen,桐村,桐村镇,鲁家坞', 29.0075300, 118.2492000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20632, 'Youxikou', 'Youxikou', 'Youxikou,Zhangwan,you xi kou,zhang wan,张湾,油溪口', 29.1241800, 118.1974000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20633, 'Wenshan', 'Wenshan', 'Wenshan,Wenshan Xiang,wen shan,wen shan xiang,汶山,汶山乡', 29.1306100, 118.3492500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20634, 'Zhangcun', 'Zhangcun', 'Zhangcun,Zhongcun,zhang cun,zhong cun,中村,张村', 29.2190300, 118.3353700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20635, 'Xiashan', 'Xiashan', 'Xiashan,xia shan,霞山', 29.3319800, 118.4059600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20636, 'Zhongzhou', 'Zhongzhou', 'Zhongzhou,Zhongzhou Zhen,zhong zhou,zhong zhou zhen,中洲,中洲镇', 29.4414900, 118.4841000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20637, 'Yecun', 'Yecun', 'Yecun,Yecun Xiang,ye cun,ye cun xiang,叶村,叶村乡', 29.3960500, 118.4589000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20638, 'Longyuan', 'Longyuan', 'Longyuan,Longyuan Xiang,long yuan,long yuan xiang,龙源,龙源乡', 29.4020600, 118.5868700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20639, 'Tangwu', 'Tangwu', 'Tangwu,Tangwu Xiang,Tangwukou,tang wu,tang wu kou,tang wu xiang,塘坞,塘坞乡,塘坞口', 29.3462200, 118.4802600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20640, 'Dongwu', 'Dongwu', 'Changpu,Dongwu,chang pu,dong wu,东坞,菖蒲', 29.2343900, 118.5476900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20641, 'Qingshandi', 'Qingshandi', 'Qingshandi,Qingshandi Xiang,qing shan di,qing shan di xiang,青山底,青山底乡', 29.0840500, 118.3939200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20642, 'Hengshan', 'Hengshan', 'Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横山,横山镇', 29.1793500, 119.2064300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20643, 'Xukou', 'Xukou', 'Xukou,xu kou,胥口', 29.9839100, 119.6668300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20644, 'Daling', 'Daling', 'Daling,Daling Zhen,da ling,da ling zhen,大岭,大岭镇', 23.0158300, 114.6955600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20645, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Zhen,Ma’an,Ma’an Zhen,ma an,ma an zhen,马安,马安镇', 23.0462700, 114.5029900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20646, 'Shipai', 'Shipai', 'Shipai,Shipai Zhen,shi pai,shi pai zhen,石排,石排镇', 23.0878000, 113.9474800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20647, 'Gaobu', 'Gaobu', 'Gaobu,Gaobu Zhen,gao bu,gao bu zhen,高埗,高埗镇', 23.0843500, 113.7178500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20648, 'Shijie', 'Shijie', 'Shijie,Shijie Zhen,shi jie,shi jie zhen,石碣,石碣镇', 23.0954600, 113.7919500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20649, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Jiedao,dong jiao,dong jiao jie dao,东漖,东漖街道', 23.0820100, 113.2182400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20650, 'Lianghua', 'Lianghua', 'Lianghua,Lianghua Zhen,liang hua,liang hua zhen,梁化,梁化镇', 23.1173400, 114.6782800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20651, 'Dali', 'Dali', 'Dali,Dalijieban,da li,大沥', 23.1197400, 113.1167300, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20652, 'Shiwan', 'Shiwan', 'Shiwan,Shiwan Zhen,shi wan,shi wan zhen,石湾,石湾镇', 23.1398700, 113.8530300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20653, 'Xiaojinkou', 'Xiaojinkou', 'Xiaojinkou,Xiaojinkou Jiedao,Xiaojinkou Zhen,xiao jin kou,xiao jin kou jie dao,小金口,小金口街道', 23.2019400, 114.3918500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20654, 'Luogang', 'Luogang', 'Luogang,Luogang Jiedao,luo gang,luo gang jie dao,萝岗,萝岗街道', 23.1778900, 113.5010400, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20655, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Jiedao,Yonghe Zhen,yong he,yong he jie dao,永和,永和街道', 23.1815900, 113.5847200, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20656, 'Xinshi', 'Xinshi', 'Xinshi,Xinshi Jiedao,xin shi,xin shi jie dao,新市,新市街道', 23.2014700, 113.2529800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20657, 'Shijing', 'Shijing', 'Shijing,Shijing Jiedao,shi jing,shi jing jie dao,石井,石井街道', 23.2073500, 113.2310800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20658, 'Tonghe', 'Tonghe', 'Tonghe,Tonghe Jiedao,tong he,tong he jie dao,同和,同和街道', 23.2022600, 113.3166000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20659, 'Ningxi', 'Ningxi', 'Ningxi,Ningxi Zhen,ning xi,宁西', 23.2172200, 113.6548900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20660, 'Aipi', 'Aipi', 'Aipi,Aipi Zhen,ai bei,矮陂', 23.2282000, 114.6384400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20661, 'Feng’an', 'Feng''an', 'Feng''an,Feng''an Zhen,Feng’an,Feng’an Zhen,feng an,feng an zhen,凤安,凤安镇', 23.4112700, 114.8456300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20662, 'Huadong', 'Huadong', 'Huadong,Huadong Zhen,hua dong,hua dong zhen,花东,花东镇', 23.4363100, 113.3228900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20663, 'Huashan', 'Huashan', 'Huashan,Huashan Zhen,hua shan,hua shan zhen,花山,花山镇', 23.4499900, 113.2675200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20664, 'Shiling', 'Shiling', 'Shiling,Shiling Zhen,shi ling,shi ling zhen,狮岭,狮岭镇', 23.4563900, 113.1519300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20665, 'Qingxi', 'Qingxi', 'Qingxi,Qingxi Zhen,qing xi,qing xi zhen,青溪,青溪镇', 23.5375500, 114.9540200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20666, 'Gongzhuang', 'Gongzhuang', 'Gongzhuang,Gongzhuang Zhen,gong zhuang,gong zhuang zhen,公庄,公庄镇', 23.5322200, 114.3796800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20667, 'Luxi', 'Luxi', 'Luxi,Luxi Zhen,lu xi,路溪', 23.5626800, 114.2744000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20668, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Zhen,long jiang,long jiang zhen,龙江,龙江镇', 23.6034700, 114.2983800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20669, 'Wangping', 'Wangping', 'Wangping,Wangping Zhen,wang ping,王坪', 23.7347700, 114.2483100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20670, 'Xinhuilong', 'Xinhuilong', 'Xinhuilong,Xinhuilong Zhen,xin hui long,xin hui long zhen,新回龙,新回龙镇', 23.7568400, 114.3832500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20671, 'Jiushe', 'Jiushe', 'Jiushe,Jiushe Zhen,jiu she,jiu she zhen,久社,久社镇', 23.7789400, 114.9589700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20672, 'Xingang', 'Xingang', 'Xingang,Xingang Zhen,xin gang,xin gang zhen,新港,新港镇', 23.7819100, 114.6385000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20673, 'Gaotian', 'Gaotian', 'Gaotian,Gaotian Zhen,gao tian,gao tian zhen,高田,高田镇', 23.8170100, 113.1805100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20674, 'Yihe', 'Yihe', 'Yihe,Yihe Zhen,yi he,yi he zhen,义合,义合镇', 23.8400200, 114.8738000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20675, 'Shuitou', 'Shuitou', 'Shuitou,Shuitou Zhen,shui tou,shui tou zhen,水头,水头镇', 23.8860100, 113.6519800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20676, 'Xichang', 'Xichang', 'Xichang,Xichang Zhen,xi chang,xi chang zhen,锡场,锡场镇', 23.9271900, 114.4527600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20677, 'Shuangjiang', 'Shuangjiang', 'Shuangjiang,Shuangjiang Zhen,shuang jiang,shuang jiang zhen,双江,双江镇', 23.9505500, 114.7125600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20678, 'Yaotian', 'Yaotian', 'Yaotian,Yaotian Zhen,yao tian,yao tian zhen,遥田,遥田镇', 23.9830600, 113.8261100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20679, 'Xiaozhen', 'Xiaozhen', 'Xiaozhen,Xiaozhen Zhen,xiao zheng,xiao zheng zhen,小正,小正镇', 23.9854200, 114.0259800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20680, 'Shijiao', 'Shijiao', 'Shijiao,Shijiao Zhen,shi jiao,shi jiao zhen,石角,石角镇', 24.0053400, 114.3531500, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20681, 'Dadong', 'Dadong', 'Dadong,Dadong Zhen,da dong,da dong zhen,大洞,大洞镇', 24.0294300, 113.0694800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20682, 'Gaogang', 'Gaogang', 'Gaogang,Gaogang Zhen,gao gang,gao gang zhen,高岗,高岗镇', 24.0210300, 113.5801700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20683, 'Banjiang', 'Banjiang', 'Banjiang,Banjiang Zhen,ban jiang,ban jiang zhen,半江,半江镇', 24.0348700, 114.5553100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20684, 'Luohu', 'Luohu', 'Luohu,Luohu Zhen,luo hu,luo hu zhen,骆湖,骆湖镇', 24.0462700, 114.8732300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20685, 'Shuibian', 'Shuibian', 'Shuibian,Shuibian Zhen,shui bian,shui bian zhen,水边,水边镇', 24.0984000, 113.1693400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20686, 'Shaba', 'Shaba', 'Shaba,Shaba Zhen,sha ba,sha ba zhen,沙坝,沙坝镇', 24.0908100, 113.0813700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20687, 'Zhangxi', 'Zhangxi', 'Zhangxi,Zhangxi Shezuxiang,zhang xi,zhang xi she zu xiang,漳溪,漳溪畲族乡', 24.1027400, 114.9225500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20688, 'Shangguan', 'Shangguan', 'Shangguan,Shangguan Zhen,shang guan,shang guan zhen,上莞,上莞镇', 24.0992500, 114.9866000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20689, 'Shuntian', 'Shuntian', 'Shuntian,Shuntian Zhen,shun tian,shun tian zhen,顺天,顺天镇', 24.1026700, 114.7627000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20690, 'Huanggang', 'Huanggang', 'Huanggang,Huanggang Zhen,huang gang,huang gang zhen,黄岗,黄岗镇', 24.1333300, 113.4988700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20691, 'Huangqi', 'Huangqi', 'Huangqi,Huangqi Zhen,huang qi,huang qi zhen,黄磜,黄磜镇', 24.1683600, 114.2215600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20692, 'Huangsha', 'Huangsha', 'Huangsha,Huangsha Zhen,huang sha,huang sha zhen,黄沙,黄沙镇', 24.1709200, 114.8436200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20693, 'Qixia', 'Qixia', 'Qixia,Qixia Zhen,qi xia,qi xia zhen,磜下,磜下镇', 24.1891700, 114.0344400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20694, 'Tianyuan', 'Tianyuan', 'Tianyuan,Tianyuan Zhen,tian yuan,tian yuan zhen,田源,田源镇', 24.1874400, 114.4185900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20695, 'Youxi', 'Youxi', 'Youxi,Youxi Zhen,you xi,you xi zhen,油溪,油溪镇', 24.2184000, 114.6855900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20696, 'Lishi', 'Lishi', 'Lishi,Lishi Zhen,li shi,li shi zhen,礼士,礼士镇', 24.2227200, 114.9966500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20697, 'Zhoupi', 'Zhoupi', 'Zhoupi,Zhoupi Zhen,zhou bei,zhou bei zhen,周陂,周陂镇', 24.2513900, 114.0202800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20698, 'Miaodun', 'Miaodun', 'Miaodun,Miaodun Zhen,miao dun,miao dun zhen,庙墩,庙墩镇', 24.2455700, 113.9110700, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20699, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 24.2535200, 113.7710100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20700, 'Xiuduan', 'Xiuduan', 'Xiuduan,Xiuduan Zhen,xiu duan,xiu duan zhen,绣缎,绣缎镇', 24.2701000, 114.8548900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20701, 'Xishan', 'Xishan', 'Xishan,Xishan Zhen,xi shan,xi shan zhen,溪山,溪山镇', 24.2648100, 114.4219400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20702, 'Gongbai', 'Gongbai', 'Gongbai,Gongbai Zhen,gong bai,gong bai zhen,公白,公白镇', 24.2789200, 114.9540300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20703, 'Zhangbei', 'Zhangbei', 'Zhangbei,Zhangbei Zhen,Zhangpi,zhang bei,zhang bei zhen,张陂,张陂镇', 24.2926900, 113.0521900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20704, 'Yinghong', 'Yinghong', 'Yinghong,Yinghong Zhen,Yinghong Zonghe Jingjiqu,ying hong,ying hong zhen,英红,英红镇', 24.2991200, 113.4072300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20705, 'Hengshitang', 'Hengshitang', 'Hengshitang,Hengshitang Zhen,heng shi tang,heng shi tang zhen,横石塘,横石塘镇', 24.3470600, 113.3668400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20706, 'Yunling', 'Yunling', 'Yunling,Yunling Zhen,yun ling,yun ling zhen,云岭,云岭镇', 24.3469400, 113.4388700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20707, 'Qingzhou', 'Qingzhou', 'Qingzhou,Qingzhou Zhen,qing zhou,qing zhou zhen,青州,青州镇', 24.3552400, 114.8032500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20708, 'Hengshishui', 'Hengshishui', 'Hengshishui,Hengshishui Zhen,heng shi shui,heng shi shui zhen,横石水,横石水镇', 24.3557200, 113.8010900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20709, 'Neiguan', 'Neiguan', 'Neiguan,Neiguan Zhen,nei guan,nei guan zhen,内莞,内莞镇', 24.3648700, 114.5588800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20710, 'Jiulian', 'Jiulian', 'Jiulian,Jiulian Zhen,jiu lian,jiu lian zhen,九连,九连镇', 24.3679200, 114.7052200, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20711, 'Boluo', 'Boluo', 'Boluo,Boluo Zhen,bo luo,bo luo zhen,波罗,波罗镇', 24.4542500, 113.0127300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20712, 'Reshui', 'Reshui', 'Reshui,Reshui Zhen,re shui,re shui zhen,热水,热水镇', 24.4536000, 114.8282700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20713, 'Tielong', 'Tielong', 'Tielong,Tielong Zhen,tie long,tie long zhen,铁龙,铁龙镇', 24.5017800, 113.6807800, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20714, 'Daba', 'Daba', 'Daba,Daba Zhen,da ba,da ba zhen,大坝,大坝镇', 24.5075800, 114.9354100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20715, 'Zhangshi', 'Zhangshi', 'Zhangshi,Zhangshi Zhen,zhang shi,zhang shi zhen,樟市,樟市镇', 24.5453300, 113.5160100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20716, 'Liyuan', 'Liyuan', 'Liyuan,Liyuan Zhen,lian yuan,lian yuan zhen,浰源,浰源镇', 24.5587800, 114.7614200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20717, 'Aizi', 'Aizi', 'Aizi,Aizi Zhen,ai zi,ai zi zhen,隘子,隘子镇', 24.6180300, 113.9888500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20718, 'Longgui', 'Longgui', 'Longgui,Longgui Zhen,long gui,long gui zhen,龙归,龙归镇', 24.7345000, 113.4485700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20719, 'Xilian', 'Xilian', 'Xilian,Xilian Zhen,xi lian,xi lian zhen,西联,西联镇', 24.7608300, 113.5352800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20720, 'Duheng', 'Duheng', 'Duheng,Duheng Xiang,dou heng,dou heng xiang,都亨,都亨乡', 24.7687200, 114.2752800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20721, 'Leyuan', 'Leyuan', 'Leyuan,Leyuan Zhen,le yuan,le yuan zhen,乐园,乐园镇', 24.7556300, 113.5818500, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20722, 'Fengwan', 'Fengwan', 'Fengwan,Fengwan Zhen,feng wan,feng wan zhen,枫湾,枫湾镇', 24.8004400, 113.8088600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20723, 'Yiliu', 'Yiliu', 'Yiliu,Yiliu Zhen,yi liu,yi liu zhen,一六,一六镇', 24.8358300, 113.4050000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20724, 'Shendushui', 'Shendushui', 'Shendushui,Shendushui Yaozuxiang,Shendushuiyaozuxiang,shen du shui,shen du shui yao zu xiang,深渡水,深渡水瑶族乡', 24.8198000, 114.0884100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20725, 'Shiliting', 'Shiliting', 'Shiliting,Shiliting Zhen,shi li ting,shi li ting zhen,十里亭,十里亭镇', 24.8477800, 113.5650000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20726, 'Luoba', 'Luoba', 'Luoba,Luoba Zhen,luo ba,luo ba zhen,罗坝,罗坝镇', 24.8665800, 114.2106100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20727, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,dong ping,dong ping zhen,东坪,东坪镇', 24.7438600, 113.1884100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20728, 'Zhongyang', 'Zhongyang', 'Zhongyang,Zhongyang Zhen,zhong yang,zhong yang zhen,重阳,重阳镇', 24.8841300, 113.4590300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20729, 'Dungang', 'Dungang', 'Dungang,Dungang Zhen,dun gang,dun gang zhen,顿岗,顿岗镇', 24.9180900, 114.1304000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20730, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,da qiao,da qiao zhen,大桥,大桥镇', 24.9109300, 113.7553500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20731, 'Shensuo', 'Shensuo', 'Shensuo,Shensuo Zhen,chen suo,chen suo zhen,沈所,沈所镇', 24.9210900, 113.9764600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20732, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Zhen,cheng nan,cheng nan zhen,城南,城南镇', 24.9281900, 114.0552600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20733, 'Youxi', 'Youxi', 'Youxi,Youxi Zhen,you xi,you xi zhen,游溪,游溪镇', 24.9569400, 113.3602800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20734, 'Gushi', 'Gushi', 'Gushi,Gushi Zhen,gu shi,gu shi zhen,古市,古市镇', 25.0558800, 114.2480700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20735, 'Zhutian', 'Zhutian', 'Zhutian,Zhutian Zhen,zhu tian,zhu tian zhen,主田,主田镇', 25.0652800, 114.2958300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20736, 'Huangkeng', 'Huangkeng', 'Huangkeng,Huangkeng Zhen,huang keng,huang keng zhen,黄坑,黄坑镇', 25.0584600, 113.8189700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20737, 'Danxia', 'Danxia', 'Danxia,Danxia Jiedao,dan xia,dan xia jie dao,丹霞,丹霞街道', 25.0469000, 113.7486500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20738, 'Changlai', 'Changlai', 'Changlai,Changlai Zhen,zhang lai,zhang lai zhen,长来,长来镇', 25.0855600, 113.3938900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20739, 'Jiangtou', 'Jiangtou', 'Jiangtou,Jiangtou Zhen,jiang tou,jiang tou zhen,江头,江头镇', 25.0864800, 114.4454400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20740, 'Shaping', 'Shaping', 'Shaping,Shaping Zhen,sha ping,sha ping zhen,沙坪,沙坪镇', 25.0862700, 113.0372900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20741, 'Yunyan', 'Yunyan', 'Yunyan,Yunyan Zhen,yun yan,yun yan zhen,云岩,云岩镇', 25.1310900, 113.1035100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20742, 'Quan’an', 'Quan''an', 'Quan''an,Quan''an Zhen,Quan’an,Quan’an Zhen,quan an,quan an zhen,全安,全安镇', 25.1297600, 114.2592800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20743, 'Cangshi', 'Cangshi', 'Cangshi,Cangshi Zhen,cang shi,cang shi zhen,苍石,苍石镇', 25.1310300, 114.2039400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20744, 'Pingtian', 'Pingtian', 'Pingtian,Pingtian Zhen,ping tian,ping tian zhen,坪田,坪田镇', 25.1915000, 114.6244500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20745, 'Wenshao', 'Wenshao', 'Wenshao,Wenshao Zhen,wen shao,wen shao zhen,闻韶,闻韶镇', 25.1404400, 113.8842000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20746, 'Langtian', 'Langtian', 'Langtian,Langtian Zhen,lang tian,lang tian zhen,廊田,廊田镇', 25.1550700, 113.4531200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20747, 'Nanmu', 'Nanmu', 'Nanmu,Nanmu Zhen,nan mu,nan mu zhen,南亩,南亩镇', 25.1618700, 114.5558700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20748, 'Xiushui', 'Xiushui', 'Xiushui,Xiushui Zhen,xiu shui,xiu shui zhen,秀水,秀水镇', 25.1711800, 112.9956700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20749, 'Beixiang', 'Beixiang', 'Beixiang,Beixiang Zhen,bei xiang,bei xiang zhen,北乡,北乡镇', 25.1944400, 113.3597200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20750, 'Zhuji', 'Zhuji', 'Zhuji,Zhuji Zhen,zhu ji,zhu ji zhen,珠玑,珠玑镇', 25.1854500, 114.3594300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20751, 'Lanhe', 'Lanhe', 'Lanhe,Lanhe Zhen,lan he,lan he zhen,澜河,澜河镇', 25.2341800, 114.1404900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20752, 'Jiezhi', 'Jiezhi', 'Jiezhi,Jiezhi Zhen,jie zhi,jie zhi zhen,界址,界址镇', 25.2428800, 114.7160400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20753, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Zhen,hong shan,hong shan zhen,红山,红山镇', 25.2553000, 113.5927400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20754, 'Wushan', 'Wushan', 'Wushan,Wushan Zhen,wu shan,wu shan zhen,五山,五山镇', 25.2510400, 113.4801500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20755, 'Dengfang', 'Dengfang', 'Dengfang,Dengfang Zhen,deng fang,deng fang zhen,邓坊,邓坊镇', 25.2625800, 114.4426700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20756, 'Datang', 'Datang', 'Datang,Datang Zhen,da tang,da tang zhen,大塘,大塘镇', 25.2810200, 114.5247400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20757, 'Kongjiang', 'Kongjiang', 'Kongjiang,Kongjiang Zhen,kong jiang,kong jiang zhen,孔江,孔江镇', 25.2818100, 114.6170000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20758, 'Maozifeng', 'Maozifeng', 'Maozifeng,Maozifeng Zhen,Maozifengfa Linchang,mao zi feng,mao zi feng zhen,帽子峰,帽子峰镇', 25.2252100, 114.2262300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20759, 'Youshan', 'Youshan', 'Youshan,Youshan Zhen,you shan,you shan zhen,油山,油山镇', 25.3596700, 114.5404700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20760, 'Liangjiang', 'Liangjiang', 'Liangjiang,Liangjiang Zhen,liang jiang,liang jiang zhen,两江,两江镇', 25.3722200, 113.3000000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20761, 'Qingyun', 'Qingyun', 'Qingyun,Qingyun Zhen,qing yun,qing yun zhen,庆云,庆云镇', 25.3901200, 113.1764700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20762, 'Huangpu', 'Huangpu', 'Huangpu,Huangpu Zhen,huang pu,huang pu zhen,黄圃,黄圃镇', 25.4320300, 113.1736600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20763, 'Baishi', 'Baishi', 'Baishi,Baishi Zhen,bai shi,bai shi zhen,白石,白石镇', 25.4512200, 113.2520500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20764, 'Shangen', 'Shangen', 'Shangen,Shangen Zhen,shan gen,shan gen zhen,山根,山根镇', 18.9694800, 110.4822900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20765, 'Timeng', 'Timeng', 'Timeng,Timeng Xiang,ti meng,ti meng xiang,提蒙,提蒙乡', 18.5528300, 110.0257300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20766, 'Changfeng', 'Changfeng', 'Changfeng,Changfeng Zhen,zhang feng,zhang feng zhen,长丰,长丰镇', 18.8037700, 110.3086100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20767, 'Damao', 'Damao', 'Damao,Damao Zhen,da mao,da mao zhen,大茂,大茂镇', 18.8492000, 110.3924400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20768, 'Heping', 'Heping', 'Heping,Heping Zhen,he ping,he ping zhen,和平,和平镇', 18.9009000, 110.0198300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20769, 'Beida', 'Beida', 'Beida,Beida Zhen,bei da,bei da zhen,北大,北大镇', 18.9241600, 110.3307900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20770, 'Changzheng', 'Changzheng', 'Changzheng,Changzheng Zhen,zhang zheng,zhang zheng zhen,长征,长征镇', 18.9616100, 109.8746200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20771, 'Shang’an', 'Shang''an', 'Shang''an,Shang''an Xiang,Shang’an,Shang’an Xiang,shang an,shang an xiang,上安,上安乡', 18.8775800, 109.8330000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20772, 'Diaoluoshan', 'Diaoluoshan', 'Diaoluoshan,Diaoluoshan Xiang,diao luo shan,diao luo shan xiang,吊罗山,吊罗山乡', 18.7954500, 109.8739200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20773, 'Qunying', 'Qunying', 'Qunying,Qunying Xiang,qun ying,qun ying xiang,群英,群英乡', 18.6005100, 109.8355000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20774, 'Liugong', 'Liugong', 'Liugong,Liugong Xiang,liu gong,liu gong xiang,六弓,六弓乡', 18.5399200, 109.7778500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20775, 'Wenluo', 'Wenluo', 'Wenluo,Wenluo Zhen,wen luo,wen luo zhen,文罗,文罗镇', 18.5178900, 109.9528900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20776, 'Longguang', 'Longguang', 'Longguang,Longguang Zhen,long guang,long guang zhen,隆广,隆广镇', 18.5052600, 109.8991300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20777, 'Jiamao', 'Jiamao', 'Jiamao,Jiamao Zhen,jia mao,jia mao zhen,加茂,加茂镇', 18.5562200, 109.6976200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20778, 'Nanlin', 'Nanlin', 'Nanlin,Nanlin Xiang,nan lin,nan lin xiang,南林,南林乡', 18.4130700, 109.6092100, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20779, 'Jiusuo', 'Jiusuo', 'Jiusuo,Jiusuo Zhen,jiu suo,jiu suo zhen,九所,九所镇', 18.4442500, 108.9101500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20780, 'Lincuo', 'Lincuo', 'Lincuo,Meiling Zhen,lin cuo,林厝', 23.6606200, 117.2594600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20781, 'Dongyingcun', 'Dongyingcun', 'Dongying,Dongyingcun,Qianlou Zhen,dong ying cun,东英村', 23.6885200, 117.3856000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20782, 'Xingxi', 'Xingxi', 'Qiaodong Zhen,Xingxi,qiao dong zhen,xing xi,兴溪,桥东镇', 23.7049800, 117.1907100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20783, 'Zhangtang', 'Zhangtang', 'Zhangtang,Zhangtang Zhen,zhang tang,樟塘', 23.7214100, 117.4466800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20784, 'Xinzhai', 'Xinzhai', 'Shenqiao Zhen,Xinzhai,xin zhai,新寨', 23.7204800, 117.1486600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20785, 'Kangmei', 'Kangmei', 'Kangmei,Kangmei Zhen,kang mei,康美', 23.7355900, 117.4726600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20786, 'Lushikeng', 'Lushikeng', 'Jinxing,Lushikeng,jin xing,lu shi keng,金星,鹿食坑', 23.7605800, 117.2553400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20787, 'Jingbaoshan', 'Jingbaoshan', 'Jianshe,Jingbaoshan,jian she,jin bao shan,建设,进宝山', 23.8085300, 117.0964300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20788, 'Lieyu', 'Lieyu', 'Lieyu,Lieyu Zhen,lie yu,列屿', 23.8239400, 117.4623700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20789, 'Dongpu', 'Dongpu', 'Dongpu,Hongxing,dong bu,hong xing,东埔,红星', 23.8858800, 117.1164500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20790, 'Dongkeng', 'Dongkeng', 'Dongkeng,Dongxia Zhen,dong keng,dong sha,东厦,东坑', 23.9500700, 117.3825400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20791, 'Zhaizipu', 'Zhaizipu', 'Heping,Zhaizipu,he ping,zhai zi bu,和平,寨仔埔', 23.9567500, 117.2626600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20792, 'Xiage', 'Xiage', 'Xiage,Xiage Zhen,Yangdong,xia ge,霞葛', 23.9935500, 117.0113400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20793, 'Xiufeng', 'Xiufeng', 'Xiufeng,Xiufeng Xiang,xiu feng,xiu feng xiang,秀峰,秀峰乡', 24.3304500, 116.9821600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20794, 'Daxi', 'Daxi', 'Daljan'',Daxi,Daxi Xiang,Tailian,da xi,da xi xiang,tai lian,Далянь,大溪,大溪乡,太联', 24.6312400, 116.9085400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20795, 'Guzhu', 'Guzhu', 'Guzhu,Guzhu Xiang,gu zhu,gu zhu xiang,古竹,古竹乡', 24.7019500, 116.9863100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20796, 'Jinsha', 'Jinsha', 'Jinsha,Jinsha Xiang,Xitian,jin sha,jin sha xiang,xi tian,西田,金沙乡,金砂', 24.7481600, 116.6849500, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20797, 'Xixi', 'Xixi', 'Fujia,Xixi,Xixi Xiang,fu jia,xi xi,xi xi xiang,富家,西溪,西溪乡', 24.7811800, 116.7324200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20798, 'Xiadu', 'Xiadu', 'Xiadu,Xiadu Xiang,xia dou,xia dou xiang,下都,下都乡', 24.8194200, 116.4633100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20799, 'Tangbao', 'Tangbao', 'Cunzhong,Tangbao,Tangbao Xiang,cun zhong,tang bao,tang bao xiang,堂堡,堂堡乡,村中', 24.8738800, 116.8117800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20800, 'Xiangdong', 'Xiangdong', 'Xiangdong,Xiangdong Xiang,xiang dong,xiang dong xiang,象洞,象洞乡', 24.9243300, 116.3272100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20801, 'Peifeng', 'Peifeng', 'Dapai,Peifeng,Peifeng Zhen,da pai,pei feng,pei feng zhen,培丰,培丰镇,大排', 24.9067500, 116.9394800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20802, 'Hugang', 'Hugang', 'Hubei,Hugang,Hugang Xiang,hu bei,hu gang,hu gang xiang,虎北,虎岗,虎岗乡', 24.9966200, 116.7934100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20803, 'Fenglin', 'Fenglin', 'Fenglin,Fenglin Zhen,feng lin,feng lin zhen,风林,风林镇', 28.5228500, 118.4991800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20804, 'Maofan', 'Maofan', 'Maofan,mao ban,茅坂', 28.5433400, 118.4858800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20805, 'Xintangbian', 'Xintangbian', 'Xintangbian,Xintangbian Zhen,xin tang bian,xin tang bian zhen,新塘边,新塘边镇', 28.6216100, 118.4515200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20806, 'Wucun', 'Wucun', 'Wucun,wu cun,吴村', 28.6597800, 118.4536400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20807, 'Baishijie', 'Baishijie', 'Baishi Zhen,Baishijie,bai shi jie,bai shi zhen,白石街,白石镇', 28.8227300, 118.4037800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20808, 'Dong’an', 'Dong''an', 'Dong''an,Dong’an,dong an,东案', 28.9829900, 118.6573200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20809, 'Huangliao', 'Huangliao', 'Huangliao,Huangliao Xiang,Huangshan,huang liao,huang liao xiang,huang shan,黄寮,黄寮乡,黄山', 27.9461500, 119.8860000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20810, 'Meiqi', 'Meiqi', 'Meiqi,Meiqi Xiang,mei qi,mei qi xiang,梅岐乡,梅歧', 27.9122200, 119.7605600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20811, 'Huangqiao', 'Huangqiao', 'Huangqiao,Huangqiao Xiang,Yuanqiao,huang qiao,huang qiao xiang,yuan qiao,园桥,黄桥,黄桥乡', 27.7794600, 119.7972800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20812, 'Zhuli', 'Zhuli', 'Zhuli,Zhuli Shezu Xiang,zhu li,zhu li she zu xiang,竹里,竹里畲族乡', 27.7083300, 119.7683300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20813, 'Fengmen', 'Fengmen', 'Fengmen,Fengmen Xiang,Waiyang,feng men,feng men xiang,wai yang,外垟,峰门,峰门乡', 27.6983300, 119.8591700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20814, 'Wengshan', 'Wengshan', 'Waiyang,Wengshan,Wengshan Xiang,wai yang,weng shan,weng shan xiang,外垟,翁山,翁山乡', 27.5693300, 119.9731000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20815, 'Xuexi', 'Xuexi', 'Xuexi,Xuexi Xiang,Yanxi,xue xi,xue xi xiang,yan xi,岩溪,雪溪,雪溪乡', 27.3962500, 119.9163600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20816, 'Guihu', 'Guihu', 'Guihu,Guihu Zhen,gui hu,gui hu zhen,龟湖,龟湖镇', 27.3233300, 119.8044400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20817, 'Zhouling', 'Zhouling', 'Zhoubian,Zhouling,Zhouling Xiang,zhou bian,zhou ling,zhou ling xiang,洲岭,洲岭乡,洲边', 27.4310100, 119.7375000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20818, 'Jingnan', 'Jingnan', 'Jingnan,Jingnan Xiang,Zhongxi,jing nan,jing nan xiang,zhong xi,忠溪,景南,景南乡', 27.7613900, 119.6444400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20819, 'Yanxi', 'Yanxi', 'Yanxi,Yanxi Xiang,yan xi,yan xi xiang,雁溪,雁溪乡', 27.7353200, 119.5953500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20820, 'Dadi', 'Dadi', 'Dadi,Dadi Xiang,da de,da de xiang,大地,大地乡', 27.7656200, 119.4598400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20821, 'Biaoxi', 'Biaoxi', 'Biaoxi,Biaoxi Xiang,biao xi,biao xi xiang,标溪,标溪乡', 27.8516100, 119.4979200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20822, 'Jiadi', 'Jiadi', 'Jiadi,Jiadi Xiang,jia de,jia de xiang,家地,家地乡', 27.7183900, 119.5217200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20823, 'Guantang', 'Guantang', 'Guantang,Guantang Xiang,guan tang,guan tang xiang,官塘,官塘乡', 27.6749100, 119.4494400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20824, 'Jianggen', 'Jianggen', 'Jianggen,Jianggen Xiang,jiang gen,jiang gen xiang,江根,江根乡', 27.5573200, 119.4366500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20825, 'Yushang', 'Yushang', 'Shangen,Yushang,Yushang Xiang,shan gen,yu shang,yu shang xiang,山根,淤上,淤上乡', 27.5730600, 118.9877800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20826, 'Longxi', 'Longxi', 'Longxi,Longxi Xiang,Xixi,long xi,long xi xiang,龙溪,龙溪乡', 27.4491700, 119.2433300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20827, 'Annan', 'Annan', 'Annan,Annan Xiang,Dongcun,an nan,an nan xiang,dong cun,东村,安南,安南乡', 27.5077400, 119.0547400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20828, 'Zhangcun', 'Zhangcun', 'Zhangcun,Zhangcun Xiang,zhang cun,zhang cun xiang,张村,张村乡', 27.6780100, 119.3036100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20829, 'Qiulu', 'Qiulu', 'Qiulu,Qiulu Xiang,qiu lu,qiu lu xiang,秋炉,秋炉乡', 27.7264200, 119.3458300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20830, 'Dajun', 'Dajun', 'Dajun,Dajun Shezuxiang,Dajun Xiang,da jun,da jun xiang,大均,大均乡', 27.9541700, 119.5619400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20831, 'Geshan', 'Geshan', 'Geshan,Geshan Xiang,ge shan,ge shan xiang,葛山,葛山乡', 27.8911100, 119.3480600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20832, 'Huangtian', 'Huangtian', 'Huangtian,Huangtian Zhen,Xibian,huang tian,huang tian zhen,xi bian,西边,黄田,黄田镇', 27.7655600, 118.9330600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20833, 'Sishan', 'Sishan', 'Sanxi,Sishan,Sishan Xiang,san xi,si shan,si shan xiang,三溪,四山,四山乡', 27.6994400, 119.0600000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20834, 'Hehu', 'Hehu', 'Hehu,Hehu Xiang,he hu,he hu xiang,合湖,合湖乡', 27.7813800, 119.2837000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20835, 'Shiyang', 'Shiyang', 'Shangyang,Shiyang,Shiyang Xiang,shang yang,shi yang,shi yang xiang,上垟,石垟,石垟乡', 27.8527700, 119.8602300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20836, 'Fu’ao', 'Fu''ao', 'Fu''ao,Fu''ao Xiang,Fu''aoqiao,Fu’ao,Fu’ao Xiang,Fu’aoqiao,fu ao,fu ao qiao,fu ao xiang,富岙,富岙乡,富岙桥', 27.8074000, 119.9645900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20837, 'Baoyang', 'Baoyang', 'Baoyang,Baoyang Xiang,bao yang,bao yang xiang,包垟,包垟乡', 27.6652800, 119.9475000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20838, 'Lianyun', 'Lianyun', 'Lianyun,Lianyun Xiang,Ruoyang,lian yun,lian yun xiang,ruo yang,箬垟,联云,联云乡', 27.6233300, 119.9841700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20839, 'Fengyang', 'Fengyang', 'Fengyang,Fengyang Xiang,Pangyang,feng yang,feng yang xiang,pang yang,凤垟,凤垟乡,旁垟', 27.5151400, 119.9795500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20840, 'Yangxi', 'Yangxi', 'Yangbian,Yangxi,Yangxi Xiang,yang bian,yang xi,yang xi xiang,垟溪,垟溪乡,垟边', 27.4027800, 119.8047200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20841, 'Beipai', 'Beipai', 'Beipai,Beipai Xiang,bei pai,bei pai xiang,碑排,碑排乡', 27.6508300, 119.7075000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20842, 'Lingtou', 'Lingtou', 'Lingtou,Lingtou Xiang,ling tou,ling tou xiang,岭头,岭头乡', 27.5525100, 119.2462200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20843, 'Pingdu', 'Pingdu', 'Badu,Pingdu,Pingdu Zhen,ping dou,ping dou zhen,屏都,屏都镇', 27.6128900, 118.9666600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20844, 'Longnan', 'Longnan', 'Jiaoyang,Longnan,Longnan Xiang,jiao yang,long nan,long nan xiang,蛟垟,龙南,龙南乡', 27.9348900, 119.2938800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20845, 'Yunfeng', 'Yunfeng', 'Yunfeng,Yunfeng Xiang,Zhangjiadi,yun feng,yun feng xiang,zhang jia de,云丰,云丰乡,张家地', 27.9769400, 119.3752800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20846, 'Wutong', 'Wutong', 'Wutong,Wutong Xiang,wu tong,wu tong xiang,梧桐,梧桐乡', 27.8897300, 119.5099500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20847, 'Luci', 'Luci', 'Luci,Luci Xiang,lu ci,lu ci xiang,鸬鹚,鸬鹚乡', 27.8772200, 119.4025000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20848, 'Linghou', 'Linghou', 'Linghou,Linghou Xiang,ling hou,ling hou xiang,岭后,岭后乡', 27.8033200, 119.8869600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20849, 'Sanlian', 'Sanlian', 'Sanlian,Sanlian Zhen,san lian,san lian zhen,三联,三联镇', 29.0418300, 120.3454600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20850, 'Fangqian', 'Fangqian', 'Fangqian,Fangqian Zhen,fang qian,fang qian zhen,方前,方前镇', 29.0516000, 120.6794900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20851, 'Fangjun', 'Fangjun', 'Fangjun,Fangjun Zhen,fang jun,fang jun zhen,防军,防军镇', 29.0713900, 120.2450000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20852, 'Mazhai', 'Mazhai', 'Mazhai,Mazhai Zhen,ma zhai,ma zhai zhen,马宅,马宅镇', 29.0926200, 120.3662500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20853, 'Pingqiao', 'Pingqiao', 'Pingqiao,Pingqiao Zhen,ping qiao,ping qiao zhen,平桥,平桥镇', 29.1525200, 120.8808800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20854, 'Huangtianfan', 'Huangtianfan', 'Huangtianfan,Huangtianfan Zhen,huang tian fan,huang tian fan zhen,黄田畈,黄田畈镇', 29.1674900, 120.1360600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20855, 'Huaxi', 'Huaxi', 'Huaxi,Huaxi Zhen,hua xi,hua xi zhen,画溪,画溪镇', 29.1948700, 120.1591200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20856, 'Guozhai', 'Guozhai', 'Guozhai,Guozhai Zhen,guo zhai,guo zhai zhen,郭宅,郭宅镇', 29.2209900, 120.3954900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20857, 'Xichou', 'Xichou', 'Dongyangjiang,Dongyangjiang Zhen,Xichou,dong yang jiang zhen,qian chou,东阳江镇,茜畴', 29.2440700, 120.4377000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20858, 'Beijiang', 'Beijiang', 'Beijiang,Beijiang Zhen,bei jiang,bei jiang zhen,北江,北江镇', 29.2739000, 120.3753100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20859, 'Diji', 'Diji', 'Diji,Sandan,di ji,san dan,三单,底吉', 29.2988900, 120.6313900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20860, 'Zuocun', 'Zuocun', 'Zuocun,Zuocun Zhen,zuo cun,zuo cun zhen,佐村,佐村镇', 29.3258700, 120.4976200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20861, 'Huailu', 'Huailu', 'Huailu,Huailu Zhen,huai lu,huai lu zhen,怀鲁,怀鲁镇', 29.3433000, 120.3817400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20862, 'Dianqian', 'Dianqian', 'Dianqian,Jingping,dian qian,jing ping,殿前,镜屏', 29.3389700, 120.7810500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20863, 'Xiachengli', 'Xiachengli', 'Hulu,Hulu Zhen,Xiachengli,hu lu,sha cheng li,厦程里,虎鹿', 29.3728200, 120.4535500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20864, 'Lingbeizhou', 'Lingbeizhou', 'Lingbei,Lingbei Zhen,Lingbeizhou,ling bei zhen,ling bei zhou,岭北周,岭北镇', 29.3968000, 120.3038300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20865, 'Gaochengtou', 'Gaochengtou', 'Gaochengtou,Tongshan,Tongshan Zhen,gao cheng tou,tong shan zhen,同山镇,高城头', 29.5825300, 120.0611200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20866, 'Lipu', 'Lipu', 'Lipu,Lipu Zhen,hai pu,hai pu zhen,浬浦,浬浦镇', 29.6140800, 120.3464500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20867, 'Wangjiajing', 'Wangjiajing', 'Wangjiajing,Wangjiajing Zhen,wang jia jing,wang jia jing zhen,王家井,王家井镇', 29.6278300, 120.2147000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20868, 'Pukou', 'Pukou', 'Pukou,Pukou Jiedao,pu kou,pu kou jie dao,浦口,浦口街道', 29.6319600, 120.8558800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20869, 'Datang’an', 'Datang''an', 'Datang,Datang Zhen,Datang''an,Datang’an,da tang an,da tang zhen,大唐庵,大唐镇', 29.6922200, 120.1638900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20870, 'Zhaojia', 'Zhaojia', 'Zhaojia,Zhaojia Zhen,zhao jia,zhao jia zhen,赵家,赵家镇', 29.7563900, 120.4563900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20871, 'Jiangzao', 'Jiangzao', 'Jiangzao,Jiangzao Zhen,jiang zao,jiang zao zhen,江藻,江藻镇', 29.8414200, 120.3157900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20872, 'Shanxiahu', 'Shanxiahu', 'Shanxiahu,Shanxiahu Zhen,shan xia hu,shan xia hu zhen,山下湖,山下湖镇', 29.8566800, 120.3529600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20873, 'Ruanshi', 'Ruanshi', 'Ruanshi,Ruanshi Zhen,ruan shi,ruan shi zhen,阮市,阮市镇', 29.8767300, 120.3780300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20874, 'Louta', 'Louta', 'Louta,Louta Zhen,lou ta,lou ta zhen,楼塔,楼塔镇', 29.9068300, 120.1243900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20875, 'Diankou', 'Diankou', 'Diankou,Diankou Zhen,dian kou,dian kou zhen,店口,店口镇', 29.9401700, 120.3508700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20876, 'Changtang', 'Changtang', 'Changtang,Changtang Zhen,zhang tang,zhang tang zhen,长塘,长塘镇', 29.9550400, 120.7918800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20877, 'Fusheng', 'Fusheng', 'Fusheng,Fusheng Zhen,fu sheng,fu sheng zhen,富盛,富盛镇', 29.9632500, 120.7200900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20878, 'Lianghu', 'Lianghu', 'Lianghu,Lianghu Zhen,liang hu,liang hu zhen,梁湖,梁湖镇', 29.9915200, 120.8984500, 'CN', '2011-02-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20879, 'Jinsanjiao', 'Jinsanjiao', 'Fuquan,Fuquan Zhen,Jinsanjiao,fu quan zhen,jin san jiao,福全镇,金三角', 29.9893800, 120.5271600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20880, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Xiang,xin qiao,xin qiao xiang,新桥,新桥乡', 30.2508300, 118.9319400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20881, 'Longgang', 'Longgang', 'Longgang,long gang,龙岗', 30.1623400, 119.1229600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20882, 'Yongchang', 'Yongchang', 'Yongchang,yong chang,永昌', 30.0380600, 119.7316700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20883, 'Shoujiang', 'Shoujiang', 'Shoujiang,Shouxiang,shou jiang,受降', 30.1266700, 119.9594400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20884, 'Banqiao', 'Banqiao', 'Banqiao,ban qiao,板桥', 30.1666700, 119.7811100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20885, 'Linglong', 'Linglong', 'Linglong,Linglong Zhen,Linglongzhen,ling long,ling long zhen,玲珑,玲珑镇', 30.1900700, 119.6378700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20886, 'Luniao', 'Luniao', 'Luniao,lu niao,鸬鸟', 30.4541300, 119.7545400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20887, 'Ximu', 'Ximu', 'Ximu,Ximu Xiang,xi mu,xi mu xiang,西亩,西亩乡', 30.7416800, 119.5845500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20888, 'Huaikan', 'Huaikan', 'Huaihuakan,Huaikan,Huaikan Xiang,huai hua kan,huai kan,huai kan xiang,槐坎,槐坎乡,槐花磡', 31.0705500, 119.6811600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20889, 'Chagan', 'Chagan', 'Chagan,Chagan Zhen,cha gan,cha gan zhen,差干,差干镇', 24.8866900, 115.9587000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20890, 'Guangfu', 'Guangfu', 'Guangfu,Guangfu Zhen,guang fu,guang fu zhen,广福,广福镇', 24.8298400, 116.1802100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20891, 'Huangshe', 'Huangshe', 'Huangshe,Huangshe Zhen,huang she,huang she zhen,黄畲,黄畲镇', 24.8067300, 115.8366900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20892, 'Shangju', 'Shangju', 'Shangju,Shangju Zhen,shang ju,shang ju zhen,上举,上举镇', 24.7879800, 115.9850200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20893, 'Sishui', 'Sishui', 'Sishui,Sishui Zhen,si shui,si shui zhen,泗水,泗水镇', 24.7535900, 116.0263500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20894, 'Wenfu', 'Wenfu', 'Wenfu,Wenfu Zhen,wen fu,wen fu zhen,文福,文福镇', 24.7458400, 116.1951800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20895, 'Hetou', 'Hetou', 'Hetou,Hetou Zhen,he tou,he tou zhen,河头,河头镇', 24.6803100, 115.8733800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20896, 'Changtan', 'Changtan', 'Changtan,Changtan Zhen,zhang tan,zhang tan zhen,长潭,长潭镇', 24.6765900, 116.1527400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20897, 'Xiache', 'Xiache', 'Xiache,Xiache Zhen,xia che,xia che zhen,下车,下车镇', 24.6525300, 115.1155800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20898, 'Zhongxing', 'Zhongxing', 'Zhongxing,Zhongxing Zhen,zhong xing,zhong xing zhen,中行,中行镇', 24.6630300, 115.8222900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20899, 'Lanfang', 'Lanfang', 'Lanfang,Lanfang Zhen,lan fang,lan fang zhen,蓝坊,蓝坊镇', 24.6426700, 116.2156300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20900, 'Maoping', 'Maoping', 'Maoping,Maoping Zhen,mao ping,mao ping zhen,茅坪,茅坪镇', 24.6475800, 115.9833600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20901, 'Xingfu', 'Xingfu', 'Xingfu,Xingfu Zhen,xing fu,xing fu zhen,兴福,兴福镇', 24.6497600, 116.1716800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20902, 'Taoyao', 'Taoyao', 'Taoyao,Taoyao Zhen,tao yao,tao yao zhen,桃尧,桃尧镇', 24.6357800, 116.4372200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20903, 'Batou', 'Batou', 'Batou,Batou Zhen,ba tou,ba tou zhen,坝头,坝头镇', 24.6123400, 115.9335200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20904, 'Changtang', 'Changtang', 'Changtang,Changtang Zhen,zhang tang,zhang tang zhen,长塘,长塘镇', 24.5578500, 115.1458000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20905, 'Chaozhu', 'Chaozhu', 'Chaozhu,Chaozhu Zhen,chao zhu,chao zhu zhen,超竹,超竹镇', 24.5367100, 115.8994900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20906, 'Songdong', 'Songdong', 'Songdong,Songdong Zhen,song dong,song dong zhen,松东,松东镇', 24.5299500, 116.4604300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20907, 'Qingxi', 'Qingxi', 'Qingxi,Qingxi Zhen,qing xi,qing xi zhen,青溪,青溪镇', 24.5240600, 116.5850700, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20908, 'Yousheng', 'Yousheng', 'Yousheng,Yousheng Zhen,you sheng,you sheng zhen,优胜,优胜镇', 24.5094200, 115.0868600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20909, 'Yanzhen', 'Yanzhen', 'Yanzhen,Yanzhen Zhen,yan zhen,yan zhen zhen,岩镇,岩镇镇', 24.4894400, 115.4502800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20910, 'Songnan', 'Songnan', 'Songnan,Songnan Zhen,song nan,song nan zhen,松南,松南镇', 24.4978200, 116.4161500, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20911, 'Xihe', 'Xihe', 'Xihe,Xihe Zhen,xi he,xi he zhen,西河,西河镇', 24.4854300, 116.7480400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20912, 'Changtian', 'Changtian', 'Changtian,Changtian Zhen,zhang tian,zhang tian zhen,长田,长田镇', 24.4699300, 115.9656300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20913, 'Beidun', 'Beidun', 'Beidun,Beidun Zhen,bei dun,bei dun zhen,贝墩,贝墩镇', 24.4561100, 115.2116700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20914, 'Meixi', 'Meixi', 'Meixi,Meixi Zhen,mei xi,mei xi zhen,梅西,梅西镇', 24.4555600, 115.8540800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20915, 'Xintian', 'Xintian', 'Xintian,Xintian Zhen,xin tian,xin tian zhen,新田,新田镇', 24.4570400, 115.5193800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20916, 'Shishan', 'Shishan', 'Shishan,Shishan Zhen,shi shan,shi shan zhen,石扇,石扇镇', 24.4475500, 116.0858800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20917, 'Luogang', 'Luogang', 'Luogang,Luogang Zhen,luo gang,luo gang zhen,罗岗,罗岗镇', 24.4266400, 115.6297200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20918, 'Shikeng', 'Shikeng', 'Shikeng,Shikeng Zhen,shi keng,shi keng zhen,石坑,石坑镇', 24.3901900, 115.8287900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20919, 'Yingya', 'Yingya', 'Yingya,Yingya Zhen,ying ya,ying ya zhen,英雅,英雅镇', 24.3841000, 116.4820500, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20920, 'Yanshang', 'Yanshang', 'Yanshang,Yanshang Zhen,yan shang,yan shang zhen,岩上,岩上镇', 24.4375100, 116.8088700, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20921, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Zhen,cheng dong,cheng dong zhen,城东,城东镇', 24.3785500, 116.1392200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20922, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,迴龙,迴龙镇', 24.3701300, 115.5255800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20923, 'Sanxiang', 'Sanxiang', 'Sanxiang,Sanxiang Zhen,san xiang,san xiang zhen,三乡,三乡镇', 24.3340400, 116.3706800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20924, 'Daping', 'Daping', 'Daping,Daping Zhen,da ping,da ping zhen,大坪,大坪镇', 24.3275000, 115.5784200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20925, 'Pingyang', 'Pingyang', 'Pingyang,Pingyang Zhen,ping yang,ping yang zhen,坪洋,坪洋镇', 24.3264400, 115.6703100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20926, 'Dadong', 'Dadong', 'Dadong,Dadong Zhen,da dong,da dong zhen,大东,大东镇', 24.3112300, 116.8889900, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20927, 'Yaoshang', 'Yaoshang', 'Yaoshang,Yaoshang Zhen,yao shang,yao shang zhen,瑶上,瑶上镇', 24.3137300, 115.9293100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20928, 'Huangshi', 'Huangshi', 'Huangshi,Huangshi Zhen,huang shi,huang shi zhen,黄石,黄石镇', 24.3401100, 115.2624600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20929, 'Linzhai', 'Linzhai', 'Linzhai,Linzhai Zhen,lin zhai,lin zhai zhen,林寨,林寨镇', 24.2880200, 115.0701700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20930, 'Longbei', 'Longbei', 'Longbei,Longbei Zhen,long bei,long bei zhen,龙北,龙北镇', 24.2841200, 115.7248800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20931, 'Xiyang', 'Xiyang', 'Xiyang,Xiyang Zhen,xi yang,xi yang zhen,西阳,西阳镇', 24.2788400, 116.1984100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20932, 'Yinjiang', 'Yinjiang', 'Yinjiang,Yinjiang Zhen,yin jiang,yin jiang zhen,银江,银江镇', 24.2659200, 116.4421600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20933, 'Tianxin', 'Tianxin', 'Tianxin,Tianxin Zhen,tian xin,tian xin zhen,田心,田心镇', 24.2643100, 115.4906800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20934, 'Shuangxi', 'Shuangxi', 'Shuangxi,Shuangxi Zhen,shuang xi,shuang xi zhen,双溪,双溪镇', 24.2648100, 116.8394600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20935, 'Heshui', 'Heshui', 'Heshui,Heshui Zhen,he shui,he shui zhen,合水,合水镇', 24.2487500, 115.6985100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20936, 'Pingyuan', 'Pingyuan', 'Pingyuan,Pingyuan Zhen,ping yuan,ping yuan zhen,平原,平原镇', 24.2120100, 116.7128400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20937, 'Zhourui', 'Zhourui', 'Zhourui,Zhourui Zhen,zhou rui,zhou rui zhen,洲瑞,洲瑞镇', 24.2043200, 116.5533600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20938, 'Guye', 'Guye', 'Guye,Guye Zhen,gu ye,gu ye zhen,古野,古野镇', 24.1937300, 116.6229000, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20939, 'Yetang', 'Yetang', 'Yetang,Yetang Zhen,ye tang,ye tang zhen,叶塘,叶塘镇', 24.1942400, 115.6621300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20940, 'Jingnan', 'Jingnan', 'Jingnan,Jingnan Zhen,jing nan,jing nan zhen,径南,径南镇', 24.1922400, 115.9194500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20941, 'Ningtang', 'Ningtang', 'Ningtang,Ningtang Zhen,ning tang,ning tang zhen,宁塘,宁塘镇', 24.1754200, 115.7474900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20942, 'Yenan', 'Yenan', 'Yenan,Yenan Zhen,ye nan,ye nan zhen,叶南,叶南镇', 24.1874600, 115.6407000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20943, 'Fengren', 'Fengren', 'Fengren,Fengren Zhen,feng ren,feng ren zhen,丰稔,丰稔镇', 24.1735700, 115.3267900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20944, 'Guqian', 'Guqian', 'Guqian,Guqian Zhen,gu qian,gu qian zhen,谷前,谷前镇', 24.1824400, 115.4245800, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20945, 'Yidu', 'Yidu', 'Yidu,Yidu Zhen,yi dou,yi dou zhen,义都,义都镇', 24.1575100, 115.1373800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20946, 'Xinbei', 'Xinbei', 'Xinbei,Xinbei Zhen,Xinpi Zhen,xin bei,xin bei zhen,新陂,新陂镇', 24.1583200, 115.6894200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20947, 'Ningxin', 'Ningxin', 'Ningxin,Ningxin Jiedao,Ningxin Zhen,ning xin,ning xin jie dao,ning xin zhen,宁新,宁新街道,宁新镇', 24.1379700, 115.7547900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20948, 'Meinan', 'Meinan', 'Meinan,Meinan Zhen,mei nan,mei nan zhen,梅南,梅南镇', 24.1550000, 116.0845600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20949, 'Hesi', 'Hesi', 'Hesi,Hesi Zhen,he si,he si zhen,河泗镇,荷泗', 24.1567800, 115.9919100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20950, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 24.1527700, 115.5680900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20951, 'Shangrao', 'Shangrao', 'Shangrao,Shangrao Zhen,shang rao,shang rao zhen,上饶,上饶镇', 24.1494400, 116.9097300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20952, 'Guangde', 'Guangde', 'Guangde,Guangde Zhen,guang de,guang de zhen,光德,光德镇', 24.1439200, 116.7324300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20953, 'Libei', 'Libei', 'Libei,li bei,坜陂', 24.1196200, 115.7905600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20954, 'Fucheng', 'Fucheng', 'Fucheng,Fucheng Zhen,fu cheng,fu cheng zhen,附城,附城镇', 24.1001500, 115.2315400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20955, 'Raoyang', 'Raoyang', 'Raoyang,Raoyang Zhen,rao yang,rao yang zhen,饶洋,饶洋镇', 24.1008000, 116.8754900, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20956, 'Diaofang', 'Diaofang', 'Diaofang,Diaofang Zhen,diao fang,diao fang zhen,刁坊,刁坊镇', 24.0983400, 115.7498600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20957, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃源,桃源镇', 24.0863700, 116.6430100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20958, 'Nibei', 'Nibei', 'Nibei,Nibei Zhen,Nipi Zhen,ni bei,ni bei zhen,坭陂,坭陂镇', 24.0809200, 115.8144500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20959, 'Jingmen', 'Jingmen', 'Jingmen,Jingmen Zhen,jing men,jing men zhen,径门,径门镇', 24.0708300, 116.3597200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20960, 'Dengyun', 'Dengyun', 'Dengyun,Dengyun Zhen,deng yun,deng yun zhen,登云,登云镇', 24.0693300, 115.3932600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20961, 'Dalonghua', 'Dalonghua', 'Dalonghua,Dalonghua Zhen,da long hua,da long hua zhen,大龙华,大龙华镇', 24.0626400, 116.3130700, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20962, 'Tongqu', 'Tongqu', 'Tongqu,Tongqu Zhen,tong qu,tong qu zhen,通衢,通衢镇', 24.0489300, 115.3756800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20963, 'Tanshan', 'Tanshan', 'Tanshan,Tanshan Zhen,tan shan,tan shan zhen,潭山,潭山镇', 24.0309300, 116.5877100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20964, 'Shuangtou', 'Shuangtou', 'Shuangtou,Shuangtou Zhen,shuang tou,shuang tou zhen,双头,双头镇', 24.0229200, 115.4834600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20965, 'Jianrao', 'Jianrao', 'Jianrao,Jianrao Zhen,jian rao,jian rao zhen,建饶,建饶镇', 24.0193000, 116.9096300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20966, 'Longgang', 'Longgang', 'Longgang,Longgang Zhen,long gang,long gang zhen,龙岗,龙岗镇', 23.9986100, 116.2279500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20967, 'Huangbu', 'Huangbu', 'Huangbu,Huangbu Zhen,huang bu,huang bu zhen,黄布,黄布镇', 23.9797200, 115.2999400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20968, 'Xintang', 'Xintang', 'Xintang,Xintang Zhen,xin tang,xin tang zhen,新塘,新塘镇', 23.9436900, 116.7768800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20969, 'Zishi', 'Zishi', 'Zishi,Zishi Zhen,zi shi,zi shi zhen,紫市,紫市镇', 23.9320700, 115.3507500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20970, 'Pantian', 'Pantian', 'Pantian,Pantian Zhen,Pantianpu,pan tian,pan tian zhen,潘田,潘田镇', 23.9185000, 116.3230000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20971, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Zhen,dong shan,dong shan zhen,东山,东山镇', 23.9088500, 116.9288800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20972, 'Tangxi', 'Tangxi', 'Tangxi,Tangxi Zhen,tang xi,tang xi zhen,汤溪,汤溪镇', 23.9014800, 116.8626600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20973, 'Datian', 'Datian', 'Datian,Datian Zhen,da tian,da tian zhen,大田,大田镇', 23.8584300, 115.4463600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20974, 'Fubin', 'Fubin', 'Fubin,Fubin Zhen,fu bin,fu bin zhen,浮滨,浮滨镇', 23.8447200, 116.8570700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20975, 'Guotian', 'Guotian', 'Guotian,Guotian Zhen,guo tian,guo tian zhen,郭田,郭田镇', 23.8333800, 115.9285600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20976, 'Chifeng', 'Chifeng', 'Chifeng,Chifeng Zhen,chi feng,chi feng zhen,赤凤,赤凤镇', 23.8177700, 116.5412100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20977, 'Xinxu', 'Xinxu', 'Xinxu,Xinxu Zhen,Xinyu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 23.8160600, 116.9400900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20978, 'Kanghe', 'Kanghe', 'Kanghe,Kanghe Zhen,kang he,kang he zhen,康禾,康禾镇', 23.7790600, 115.0846000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20979, 'Guihu', 'Guihu', 'Guihu,Guihu Zhen,gui hu,gui hu zhen,归湖,归湖镇', 23.7676200, 116.5836700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20980, 'Wenci', 'Wenci', 'Wenci,Wenci Zhen,wen ci,wen ci zhen,文祠,文祠镇', 23.7699300, 116.6716600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20981, 'Zhangxi', 'Zhangxi', 'Zhangxi,Zhangxi Zhen,zhang xi,zhang xi zhen,樟溪,樟溪镇', 23.7435200, 116.8861600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20982, 'Gaotang', 'Gaotang', 'Gaotang,Gaotang Zhen,gao tang,gao tang zhen,高堂,高堂镇', 23.7250700, 116.9457800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20983, 'Shuanghua', 'Shuanghua', 'Shuanghua,Shuanghua Zhen,shuang hua,shuang hua zhen,双华,双华镇', 23.7277300, 115.8149900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20984, 'Lianrao', 'Lianrao', 'Lianrao,Lianrao Zhen,lian rao,lian rao zhen,联饶,联饶镇', 23.7352200, 116.9806100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20985, 'Tangnan', 'Tangnan', 'Tangnan,Tangnan Zhen,tang nan,tang nan zhen,汤南,汤南镇', 23.7239600, 116.2008500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20986, 'Dengtang', 'Dengtang', 'Dengtang,Dengtang Zhen,deng tang,deng tang zhen,登塘,登塘镇', 23.6821400, 116.5259100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20987, 'Linxi', 'Linxi', 'Linxi,Linxi Zhen,lin xi,lin xi zhen,磷溪,磷溪镇', 23.6551300, 116.7113400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20988, 'Jingzi', 'Jingzi', 'Jingzi,Jingzi Zhen,jing zi,jing zi zhen,敬梓,敬梓镇', 23.6308300, 115.4111400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20989, 'Mianyang', 'Mianyang', 'Mianyang,Mianyang Zhen,mian yang,mian yang zhen,棉洋,棉洋镇', 23.6330800, 115.7155800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20990, 'Fengtang', 'Fengtang', 'Fengtang,Fengtang Zhen,feng tang,feng tang zhen,凤塘,凤塘镇', 23.6283400, 116.5718500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20991, 'Putian', 'Putian', 'Putian,Putian Zhen,bu tian,bu tian zhen,埔田,埔田镇', 23.6160500, 116.3887600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20992, 'Guantang', 'Guantang', 'Guantang,Guantang Zhen,guan tang,guan tang zhen,官塘,官塘镇', 23.6220800, 116.7265700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20993, 'Dacheng', 'Dacheng', 'Dacheng,Dacheng Zhen,da cheng,da cheng zhen,大埕,大埕镇', 23.6116300, 117.1616600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20994, 'Tiepu', 'Tiepu', 'Tiepu,Tiepu Zhen,tie pu,tie pu zhen,铁铺,铁铺镇', 23.6153500, 116.7539800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20995, 'Suocheng', 'Suocheng', 'Suocheng,Suocheng Zhen,suo cheng,suo cheng zhen,所城,所城镇', 23.6099800, 117.1141900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20996, 'Yanhong', 'Yanhong', 'Yanhong,Yanhong Zhen,yan hong,yan hong zhen,盐鸿,盐鸿镇', 23.5962400, 116.8574900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20997, 'Guiling', 'Guiling', 'Guiling,Guiling Zhen,gui ling,gui ling zhen,桂岭,桂岭镇', 23.5880000, 116.2375000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20998, 'Yunlu', 'Yunlu', 'Yunlu,Yunlu Zhen,yun lu,yun lu zhen,云路,云路镇', 23.5973700, 116.4758700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(20999, 'Longdu', 'Longdu', 'Longdou Zhen,Longdu,Longdu Zhen,long dou,long dou zhen,隆都,隆都镇', 23.5726400, 116.7238100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21000, 'Longwei', 'Longwei', 'Longwei,Longwei Zhen,long wei,long wei zhen,龙尾,龙尾镇', 23.5755400, 116.1473300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21001, 'Liangtian', 'Liangtian', 'Liangtian,Liangtian Xiang,liang tian,liang tian xiang,良田,良田乡', 23.5532800, 115.8500700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21002, 'Yuecheng', 'Yuecheng', 'Yuecheng,Yuecheng Zhen,yue cheng,yue cheng zhen,月城,月城镇', 23.5633000, 116.2691000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21003, 'Linpan', 'Linpan', 'Linpan,Linpan Zhen,lin pan,lin pan zhen,霖磐,霖磐镇', 23.5546200, 116.2365500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21004, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Zhen,dong feng,东风', 23.5413600, 116.6815700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21005, 'Haishan', 'Haishan', 'Haishan,Haishan Zhen,hai shan,hai shan zhen,海山,海山镇', 23.5288900, 116.9532900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21006, 'Shuidun', 'Shuidun', 'Shuidun,Shuidun Zhen,shui dun,shui dun zhen,水墩,水墩镇', 23.5333500, 115.4170400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21007, 'Jinshi', 'Jinshi', 'Jinshi,Jinshi Zhen,jin shi,jin shi zhen,金石,金石镇', 23.5329300, 116.6164600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21008, 'Shaxi', 'Shaxi', 'Shaxi,Shaxi Zhen,sha xi,sha xi zhen,沙溪,沙溪镇', 23.5258000, 116.5866300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21009, 'Lianshang', 'Lianshang', 'Lianshang,Lianshang Zhen,lian shang,lian shang zhen,莲上,莲上镇', 23.5213600, 116.7933700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21010, 'Jingxiyuan', 'Jingxiyuan', 'Jingxiyuan,Jingxiyuan Zhen,jing xi yuan,jing xi yuan zhen,京溪园,京溪园镇', 23.5277800, 116.0557700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21011, 'Meiyun', 'Meiyun', 'Meiyun,Meiyun Jiedao,mei yun,mei yun jie dao,梅云,梅云街道', 23.5206200, 116.3124200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21012, 'Caitang', 'Caitang', 'Caitang,Caitang Zhen,cai tang,cai tang zhen,彩塘,彩塘镇', 23.4877300, 116.6643700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21013, 'Nanshan', 'Nanshan', 'Nanshan,Nanshan Zhen,nan shan,nan shan zhen,南山,南山镇', 23.4903900, 115.9670700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21014, 'Lianxia', 'Lianxia', 'Lianxia,Lianxia Zhen,lian xia,lian xia zhen,莲下,莲下镇', 23.5005000, 116.7724800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21015, 'Nanxi', 'Nanxi', 'Nanxi,Nanxi Zhen,nan xi,nan xi zhen,南溪,南溪镇', 23.5061700, 116.2397200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21016, 'Tatou', 'Tatou', 'Tatou,Tatou Zhen,ta tou,ta tou zhen,塔头,塔头镇', 23.4985000, 116.0618800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21017, 'Xianqiao', 'Xianqiao', 'Xianqiao,Xianqiao Jiedao,xian qiao,xian qiao jie dao,仙桥,仙桥街道', 23.4973400, 116.3475400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21018, 'Huizhai', 'Huizhai', 'Huizhai,Huizhai Zhen,hui zhai,hui zhai zhen,灰寨,灰寨镇', 23.4871200, 116.0033900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21019, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,long tan,long tan zhen,龙潭,龙潭镇', 23.4512100, 115.8737100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21020, 'Shen’ao', 'Shen''ao', 'San''ao,San’ao,Shen''ao,Shen''ao Zhen,Shen’ao,Shen’ao Zhen,shen ao,shen ao zhen,深澳,深澳镇', 23.4529900, 117.1071300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21021, 'Jiushu', 'Jiushu', 'Jiushu,Jiushu Zhen,jiu shu,jiu shu zhen,九树,九树镇', 23.4561600, 115.1816800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21022, 'Jinzao', 'Jinzao', 'Jinyu,Jinyu Zhen,Jinzao,jin yu,jin zao,金灶,金玉', 23.4541000, 116.3903900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21023, 'Waisha', 'Waisha', 'Waisha,Waisha Zhen,wai sha,wai sha zhen,外砂,外砂镇', 23.4349500, 116.7497400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21024, 'Jinhe', 'Jinhe', 'Jinhe,Jinhe Zhen,jin he,jin he zhen,金和,金和镇', 23.4306100, 116.0515600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21025, 'Tuotang', 'Tuotang', 'Liantang,Tuotang,Tuotang Jiedao,tuo tang,鮀塘', 23.4191500, 116.5874900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21026, 'Daxi', 'Daxi', 'Daxi,Daxi Zhen,da xi,da xi zhen,大溪,大溪镇', 23.4226900, 115.9592900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21027, 'Yun’ao', 'Yun''ao', 'Yun''ao,Yun''ao Zhen,Yun’ao,Yun’ao Zhen,yun ao,yun ao zhen,云澳,云澳镇', 23.4102300, 117.1184300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21028, 'Tuopu', 'Tuopu', 'Tuopu,Tuopu Jiedao,tuo pu,鮀浦', 23.4132700, 116.6455500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21029, 'Xinxi', 'Xinxi', 'Xinxi,Xinxi Zhen,xin xi,xin xi zhen,新溪,新溪镇', 23.4023900, 116.7691500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21030, 'Wuyun', 'Wuyun', 'Wuyun,Wuyun Zhen,wu yun,wu yun zhen,五云,五云镇', 23.3957800, 115.7801400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21031, 'Pingshang', 'Pingshang', 'Pingshang,Pingshang Zhen,ping shang,ping shang zhen,坪上,坪上镇', 23.4016900, 115.8898200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21032, 'Qiankeng', 'Qiankeng', 'Qiankeng,Qiankeng Zhen,qian keng,qian keng zhen,钱坑,钱坑镇', 23.3886600, 115.9930000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21033, 'Xilu', 'Xilu', 'Xilu,Xilu Zhen,xi lu,xi lu zhen,西胪,西胪镇', 23.3854300, 116.5049800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21034, 'Luoxi', 'Luoxi', 'Luoxi,Luoxi Zhen,luo xi,luo xi zhen,螺溪,螺溪镇', 23.3760700, 115.6184600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21035, 'Qilin', 'Qilin', 'Qilin,Qilin Zhen,qi lin,麒麟', 23.4227800, 116.2850000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21036, 'Gurao', 'Gurao', 'Gurao,Gurao Zhen,gu rao,gu rao zhen,谷饶,谷饶镇', 23.3468700, 116.4113300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21037, 'Suqu', 'Suqu', 'Suqu,Suqu Zhen,su qu,su qu zhen,苏区,苏区镇', 23.3535400, 115.3497400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21038, 'Nanwan', 'Nanwan', 'Nanwan,Nanwan Zhen,nan wan,nan wan zhen,南万,南万镇', 23.3504400, 115.5098700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21039, 'Meitang', 'Meitang', 'Meitang,Meitang Zhen,mei tang,mei tang zhen,梅塘,梅塘镇', 23.3474700, 116.0831400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21040, 'Liaoyuan', 'Liaoyuan', 'Liaoyuan,Liaoyuan Zhen,liao yuan,liao yuan zhen,燎原,燎原镇', 23.3329100, 116.1583300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21041, 'Nanjing', 'Nanjing', 'Nanjing,Nanjing Zhen,Nankin,nan jing,nan jing zhen,Нанкин,南径,南径镇', 23.3398900, 116.2971300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21042, 'Hexi', 'Hexi', 'Hexi,Hexi Zhen,he xi,he xi zhen,河溪,河溪镇', 23.3248200, 116.5467100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21043, 'Zhanlong', 'Zhanlong', 'Zhanlong,Zhanlong Zhen,zhan long,zhan long zhen,占陇,占陇镇', 23.2892900, 116.2672300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21044, 'Tongyu', 'Tongyu', 'Tongmeng,Tongyu,Tongyu Zhen,tong yu,tong yu zhen,铜盂,铜盂镇', 23.2869600, 116.4217600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21045, 'Dongkeng', 'Dongkeng', 'Dongkeng,Dongkeng Zhen,dong keng,dong keng zhen,东坑,东坑镇', 23.2762800, 115.7116500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21046, 'Chendian', 'Chendian', 'Chendian,Chendian Zhen,chen dian,chen dian zhen,陈店,陈店镇', 23.2754600, 116.3170400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21047, 'Majiao', 'Majiao', 'Majiao,Majiao Jiedao,ma jiao,ma jiao jie dao,马滘,马滘街道', 23.2696600, 116.7080000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21048, 'Mashan', 'Mashan', 'Mashan,ma shan,马山', 23.2684200, 115.2383300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21049, 'Dananshan', 'Dananshan', 'Dananshan,Dananshan Zhen,da nan shan,da nan shan zhen,大南山,大南山镇', 23.2583800, 116.1754200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21050, 'Junbu', 'Junbu', 'Junbu,Junbu Zhen,jun bu,jun bu zhen,军埠,军埠镇', 23.2567300, 116.2574700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21051, 'Shanghu', 'Shanghu', 'Shanghu,Shanghu Zhen,shang hu,shang hu zhen,上护,上护镇', 23.2551500, 115.5902500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21052, 'Jinpu', 'Jinpu', 'Jinpu,Jinpu Jiedao,Jinpujieban,jin pu,金浦', 23.2498900, 116.5479300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21053, 'Xiajiashan', 'Xiajiashan', 'Xiajiashan,Xiajiashan Zhen,xia jia shan,xia jia shan zhen,下架山,下架山镇', 23.2462000, 116.2504900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21054, 'Xiancheng', 'Xiancheng', 'Xiancheng,Xiancheng Zhen,xian cheng,xian cheng zhen,仙城,仙城镇', 23.2373000, 116.3172800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21055, 'Chuanpu', 'Chuanpu', 'Chuanpu,Chuanpu Zhen,chuan bu,chuan bu zhen,船埔,船埔镇', 23.2248400, 115.8898200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21056, 'Lugang', 'Lugang', 'Lugang,Lugang Zhen,lu gang,lu gang zhen,胪岗,胪岗镇', 23.2246400, 116.4598000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21057, 'Baokou', 'Baokou', 'Baokou,Baokou Zhen,bao kou,bao kou zhen,宝口,宝口镇', 23.2119700, 115.2060300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21058, 'Liangying', 'Liangying', 'Liangying,Liangying Zhen,liang ying,liang ying zhen,两英,两英镇', 23.2187200, 116.3562500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21059, 'Jingdu', 'Jingdu', 'Jingdou Zhen,Jingdu,Jingdu Zhen,jing dou,jing dou zhen,井都,井都镇', 23.1905100, 116.5505300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21060, 'Xintian', 'Xintian', 'Xintian,Xintian Zhen,xin tian,xin tian zhen,新田,新田镇', 23.1844500, 115.5496600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21061, 'Hongchang', 'Hongchang', 'Hongchang,Hongchang Zhen,hong chang,hong chang zhen,红场,红场镇', 23.1193800, 116.3112600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21062, 'Pingdong', 'Pingdong', 'Pingdong,Pingdong Zhen,ping dong,ping dong zhen,平东,平东镇', 23.0985900, 115.4882000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21063, 'Leiling', 'Leiling', 'Leiling,Leiling Zhen,lei ling,lei ling zhen,雷岭,雷岭镇', 23.0852100, 116.3666400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21064, 'Xinan', 'Xinan', 'Xinan,Xinan Zhen,xi nan,xi nan zhen,西南,西南镇', 23.0618400, 115.5512600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21065, 'Baipenzhu', 'Baipenzhu', 'Baipenzhu,Baipenzhu Zhen,bai pen zhu,bai pen zhu zhen,白盆珠,白盆珠镇', 23.0742000, 115.0252700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21066, 'Bawan', 'Bawan', 'Bawan,Bawan Zhen,ba wan,ba wan zhen,八万,八万镇', 23.0336700, 115.7523500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21067, 'Beiyang', 'Beiyang', 'Beiyang,Beiyang Zhen,Piyang Zhen,bei yang,bei yang zhen,陂洋,陂洋镇', 23.0304000, 115.8473200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21068, 'Huahu', 'Huahu', 'Huahu,Huahu Zhen,hua hu,hua hu zhen,华湖,华湖镇', 23.0315300, 116.3520000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21069, 'Zhoutian', 'Zhoutian', 'Zhoutian,Zhoutian Zhen,zhou tian,zhou tian zhen,周田,周田镇', 23.0101100, 116.4571000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21070, 'Donglong', 'Donglong', 'Donglong,Donglong Zhen,dong long,dong long zhen,东陇,东陇镇', 23.0094700, 116.2827500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21071, 'Yangjiao', 'Yangjiao', 'Yangjiao,Yangjiao Xiang,yang jiao,yang jiao xiang,羊角,羊角乡', 38.9830400, 114.6950500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21072, 'Shimen', 'Shimen', 'Shimen,Shimen Xiang,shi men,shi men xiang,石门,石门乡', 38.9560800, 114.5733600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21073, 'Zhaitou', 'Zhaitou', 'Zhaitou,Zhaitou Xiang,zhai tou,zhai tou xiang,寨头,寨头乡', 38.5651400, 114.0273100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21074, 'Datai', 'Datai', 'Datai,Datai Xiang,da tai,da tai xiang,大台,大台乡', 38.9811100, 114.3727800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21075, 'Taiyu', 'Taiyu', 'Taiyu,Taiyu Xiang,tai yu,tai yu xiang,台峪,台峪乡', 38.9207200, 114.4667500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21076, 'Fanjiazhuang', 'Fanjiazhuang', 'Fanjiazhuang,Fanjiazhuang Xiang,fan jia zhuang,fan jia zhuang xiang,范家庄,范家庄乡', 38.9146700, 114.6111000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21077, 'Beitai', 'Beitai', 'Beitai,Beitai Xiang,bei tai,bei tai xiang,北台,北台乡', 38.8515500, 114.5503000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21078, 'Beiguoyuan', 'Beiguoyuan', 'Beiguoyuan,Beiguoyuan Xiang,bei guo yuan,bei guo yuan xiang,北果园,北果园乡', 38.7745700, 114.3172900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21079, 'Jiukouzi', 'Jiukouzi', 'Jiukouzi,Jiukouzi Xiang,jiu kou zi,jiu kou zi xiang,九口子,九口子乡', 38.6447900, 114.3559000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21080, 'Beihe', 'Beihe', 'Beihe,Beihe Xiang,bei he,bei he xiang,北河,北河乡', 38.6317300, 114.4985000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21081, 'Nandiantou', 'Nandiantou', 'Nandiantou,Nandiantou Xiang,nan dian tou,nan dian tou xiang,南店头,南店头乡', 38.7210000, 114.8969700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21082, 'Changgucheng', 'Changgucheng', 'Changgucheng,Changgucheng Xiang,zhang gu cheng,zhang gu cheng xiang,长古城,长古城乡', 38.7042600, 114.9644000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21083, 'Pangcun', 'Pangcun', 'Pangcun,Pangcun Zhen,pang cun,pang cun zhen,庞村,庞村镇', 38.6149000, 114.9671600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21084, 'Zhaocun', 'Zhaocun', 'Zhaocun,Zhaocun Xiang,zhao cun,zhao cun xiang,赵村,赵村乡', 38.5571400, 114.9115400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21085, 'Nandayue', 'Nandayue', 'Nandayue,Nandayue Zhen,nan da yue,nan da yue zhen,南大岳,南大岳镇', 38.4749000, 114.7912500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21086, 'Zhengmo', 'Zhengmo', 'Zhengmo,Zhengmo Zhen,zheng mo,zheng mo zhen,正莫,正莫镇', 38.4671400, 114.7317100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21087, 'Nanqiao', 'Nanqiao', 'Nanqiao,Nanqiao Zhen,nan qiao,nan qiao zhen,南桥,南桥镇', 38.5151100, 114.5620600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21088, 'Nanyanchuan', 'Nanyanchuan', 'Nanyanchuan,Nanyanchuan Xiang,nan yan chuan,nan yan chuan xiang,南燕川,南燕川乡', 38.4747200, 114.2297200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21089, 'Dongwangpo', 'Dongwangpo', 'Dongwangpo,Dongwangpo Xiang,dong wang po,dong wang po xiang,东王坡,东王坡乡', 38.4475300, 114.1284800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21090, 'Shangsanji', 'Shangsanji', 'Shangsanji,Shangsanji Xiang,shang san ji,shang san ji xiang,上三汲,上三汲乡', 38.3223200, 114.2292800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21091, 'Xidawu', 'Xidawu', 'Xidawu,Xidawu Xiang,xi da wu,xi da wu xiang,西大吾,西大吾乡', 38.3075500, 114.0940200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21092, 'Nanxing', 'Nanxing', 'Nanxing,Nanxing Xiang,nan xing,nan xing xiang,南陉,南陉乡', 38.1819300, 114.0527300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21093, 'Xiaozuo', 'Xiaozuo', 'Xiaozuo,Xiaozuo Zhen,xiao zuo,xiao zuo zhen,小作,小作镇', 38.1187400, 114.0164600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21094, 'Sunzhuang', 'Sunzhuang', 'Sunzhuang,Sunzhuang Xiang,sun zhuang,sun zhuang xiang,孙庄,孙庄乡', 38.1517800, 114.1374400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21095, 'Niucheng', 'Niucheng', 'Niucheng,Niucheng Xiang,niu cheng,niu cheng xiang,牛城,牛城乡', 38.2728000, 114.3015300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21096, 'Yi’an', 'Yi''an', 'Yi''an,Yi''an Zhen,Yi’an,Yi’an Zhen,yi an,yi an zhen,宜安,宜安镇', 38.1891700, 114.2747200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21097, 'Dubei', 'Dubei', 'Dubei,Dubei Xiang,du bei,du bei xiang,杜北,杜北乡', 38.1330600, 114.4327800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21098, 'Sanshengyuan', 'Sanshengyuan', 'Sanshengyuan,Sanshengyuan Xiang,san sheng yuan,san sheng yuan xiang,三圣院,三圣院乡', 38.2838900, 114.4298400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21099, 'Nanlou', 'Nanlou', 'Nanlou,Nanlou Xiang,nan lou,nan lou xiang,南楼,南楼乡', 38.2682700, 114.5465100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21100, 'Huapi', 'Huapi', 'Huapi,Huapi Zhen,hua pi,hua pi zhen,化皮,化皮镇', 38.3115600, 114.5563900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21101, 'Beiwa', 'Beiwa', 'Beiwa,Beiwa Xiang,bei wa,bei wa xiang,北洼,北洼乡', 38.3492600, 114.4418000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21102, 'Dugu', 'Dugu', 'Dugu,Dugu Zhen,du gu,du gu zhen,杜固,杜固镇', 38.3971600, 114.8633300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21103, 'Zengcun', 'Zengcun', 'Zengcun,Zengcun Zhen,zeng cun,zeng cun zhen,增村,增村镇', 38.2451000, 114.7367200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21104, 'Donghoufang', 'Donghoufang', 'Donghoufang,Donghoufang Xiang,dong hou fang,dong hou fang xiang,东侯坊,东侯坊乡', 38.1825000, 114.8977800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21105, 'Gangshang', 'Gangshang', 'Gangshang,Gangshang Zhen,gang shang,gang shang zhen,岗上,岗上镇', 38.0466300, 114.6887300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21106, 'Songying', 'Songying', 'Songying,Songying Zhen,song ying,song ying zhen,宋营,宋营镇', 38.0257800, 114.6262800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21107, 'Zhufutun', 'Zhufutun', 'Zhufutun,Zhufutun Zhen,zhu fu tun,zhu fu tun zhen,诸福屯,诸福屯镇', 38.1575900, 114.6465200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21108, 'Baozhu', 'Baozhu', 'Baozhu,Baozhu Zhen,bao zhu,bao zhu zhen,宝珠,宝珠镇', 23.1133100, 111.6103000, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21109, 'Jiushi', 'Jiushi', 'Jiushi,Jiushi Zhen,jiu shi,jiu shi zhen,九市,九市镇', 23.1372200, 111.9700000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21110, 'Xinxu', 'Xinxu', 'Xinwei,Xinxu,Xinyu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 23.1693500, 111.7627900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21111, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 23.2198200, 111.6842000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21112, 'Maxu', 'Maxu', 'Mawei,Maxu,Mayu Zhen,ma wei,ma wei zhen,马圩,马圩镇', 23.2397400, 111.8367800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21113, 'Pingtai', 'Pingtai', 'Pingtai,Pingtai Zhen,ping tai,ping tai zhen,平台,平台镇', 23.2502100, 111.4157400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21114, 'Pingfeng', 'Pingfeng', 'Pingfeng,Pingfeng Zhen,ping feng,ping feng zhen,平凤,平凤镇', 23.3032500, 111.4693900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21115, 'Luodong', 'Luodong', 'Luodong,Luodong Zhen,luo dong,luo dong zhen,罗董,罗董镇', 23.3812600, 111.6164600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21116, 'Jiangchuan', 'Jiangchuan', 'Jiangchuan,Jiangchuan Zhen,jiang chuan,jiang chuan zhen,江川,江川镇', 23.4044500, 111.4717600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21117, 'Baigou', 'Baigou', 'Baigou,Baigou Zhen,bai gou,bai gou zhen,白垢,白垢镇', 23.5065800, 111.6346300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21118, 'Dazhou', 'Dazhou', 'Dazhou,Dazhou Zhen,da zhou,da zhou zhen,大洲,大洲镇', 23.5167600, 111.5391700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21119, 'He’erkou', 'He''erkou', 'He''erkou,He''erkou Zhen,He’erkou,He’erkou Zhen,he r kou,he r kou zhen,河儿口,河儿口镇', 23.5091800, 111.7850100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21120, 'Duping', 'Duping', 'Douping Zhen,Duping,dou ping,dou ping zhen,都平,都平镇', 23.6389600, 111.6875000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21121, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 23.7447200, 111.9700000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21122, 'Ganping', 'Ganping', 'Gangping Zhen,Ganping,gang ping,gang ping zhen,岗坪,岗坪镇', 23.9877800, 111.9700000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21123, 'Maning', 'Maning', 'Maning,Maning Zhen,ma ning,ma ning zhen,马宁,马宁镇', 24.0302800, 111.9642700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21124, 'Lengkeng', 'Lengkeng', 'Lengkeng,Lengkeng Zhen,leng keng,leng keng zhen,冷坑,冷坑镇', 24.0341400, 112.0391100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21125, 'Lianmai', 'Lianmai', 'Lianmai,Lianmai Zhen,lian mai,lian mai zhen,莲麦,连麦镇', 24.0488200, 112.1545000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21126, 'Mingjing', 'Mingjing', 'Mingjing,Mingjing Zhen,ming jing,ming jing zhen,明迳,明迳镇', 24.2011400, 112.9066600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21127, 'Xiashuai', 'Xiashuai', 'Xiashuai,Xiashuai Zhuangzu Yaozuxiang,xia shuai,xia shuai zhuang zu yao zu xiang,下帅,下帅壮族瑶族乡', 24.2239700, 112.0759800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21128, 'Yanbei', 'Yanbei', 'Yanbei,Yanbei Zhen,yan bei,yan bei zhen,岩背,岩背镇', 24.2739200, 112.8224700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21129, 'Qingkeng', 'Qingkeng', 'Qingkeng,Qingkeng Zhen,qing keng,qing keng zhen,青坑,青坑镇', 24.4200000, 112.9061200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21130, 'Damaishan', 'Damaishan', 'Damaishan,Damaishan Zhen,da mai shan,da mai shan zhen,大麦山,大麦山镇', 24.4891200, 112.2692600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21131, 'Jiangying', 'Jiangying', 'Jiangying,Jiangying Zhen,jiang ying,jiang ying zhen,江英,江英镇', 24.4985100, 112.8397400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21132, 'Woshui', 'Woshui', 'Woshui,Woshui Zhen,wo shui,wo shui zhen,涡水,涡水镇', 24.5716700, 112.2255600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21133, 'Xiangping', 'Xiangping', 'Xiangping,Xiangping Zhen,xiang ping,xiang ping zhen,香坪,香坪镇', 24.5891900, 112.1237300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21134, 'Xiaojiang', 'Xiaojiang', 'Xiaojiang,Xiaojiang Zhen,xiao jiang,xiao jiang zhen,小江,小江镇', 24.6147100, 112.5951000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21135, 'Dafu', 'Dafu', 'Dafu,Dafu Zhen,da fu,da fu zhen,大富,大富镇', 24.6475200, 112.0555200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21136, 'Sanpai', 'Sanpai', 'Sanpai,Sanpai Zhen,san pai,san pai zhen,三排,三排镇', 24.6563100, 112.2835100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21137, 'Jiubei', 'Jiubei', 'Jiubei,Jiubei Zhen,jiu bei,jiu bei zhen,九陂,九陂镇', 24.6694400, 112.3661100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21138, 'Huangben', 'Huangben', 'Huangben,Huangben Zhen,huang ben,huang ben zhen,黄坌,黄坌镇', 24.6927200, 112.6846600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21139, 'Hedong', 'Hedong', 'Hedong,Hedong Zhen,he dong,he dong zhen,禾洞,禾洞镇', 24.7625000, 112.0788900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21140, 'Longping', 'Longping', 'Longping,Longping Zhen,long ping,long ping zhen,龙坪,龙坪镇', 24.8207800, 112.4777000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21141, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Zhen,Bao’an,Bao’an Zhen,bao an,bao an zhen,保安,保安镇', 24.9172200, 112.3866700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21142, 'Yao’an', 'Yao''an', 'Yao''an,Yao''an Yaozuxiang,Yao''anyaozuxiang,Yao’an,Yao’an Yaozuxiang,Yao’anyaozuxiang,yao an,yao an yao zu xiang,瑶安,瑶安瑶族乡', 25.0197200, 112.4038900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21143, 'Shantang', 'Shantang', 'Shantang,Shantang Zhen,shan tang,shan tang zhen,山塘,山塘镇', 25.0749200, 112.5988400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21144, 'Sanshui', 'Sanshui', 'Sanshui,Sanshui Yaozuxiang,Sanshuiyaozuxiang,san shui,san shui yao zu xiang,三水,三水瑶族乡', 25.1019700, 112.2315800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21145, 'Sanxi', 'Sanxi', 'Sanxi,Sanxi Zhen,san xi,san xi zhen,三溪,三溪镇', 25.2745900, 112.9001100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21146, 'Lingcheng', 'Lingcheng', 'Lingcheng,Lingcheng Zhen,ling cheng,ling cheng zhen,陵城,陵城镇', 35.5340000, 116.9180000, 'CN', '2014-10-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21147, 'Zhoucheng', 'Zhoucheng', '', 35.9122200, 116.3116700, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21148, 'Caoxi', 'Caoxi', 'Caoxi,Caoxi Jiedao,Caoxizhen,cao xi,cao xi jie dao,曹溪,曹溪街道', 25.0704500, 117.0315300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21149, 'Hulin', 'Hulin', 'Hulin,Hulin Xiang,Xipo,hu lin,hu lin xiang,xi bei,湖林,湖林乡,西陂', 25.1165900, 117.5493700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21150, 'Lantian', 'Lantian', 'Lantian,Lantian Xiang,lan tian,lan tian xiang,蓝田,蓝田乡', 25.1344400, 117.8736100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21151, 'Tieshan', 'Tieshan', 'Tieshan,Tieshan Jiedao,tie shan,tie shan jie dao,铁山,铁山街道', 25.1404800, 117.0596300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21152, 'Yanshan', 'Yanshan', 'Qinyuan,Yanshan,Yanshan Xiang,qin yuan,yan shan,yan shan xiang,岩山,岩山乡,芹园', 25.1591700, 117.1783300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21153, 'Hushang', 'Hushang', 'Hushang,Hushang Xiang,hu shang,hu shang xiang,湖上,湖上乡', 25.2469400, 117.9627800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21154, 'Yanshi', 'Yanshi', 'Yanjiang,Yanshi,Yanshi Zhen,yan jiang,yan shi,yan shi zhen,雁江,雁石,雁石镇', 25.2555600, 117.1383300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21155, 'Luzhi', 'Luzhi', 'Hezhai,Luzhi,Luzhi Xiang,he zhai,lu zhi,lu zhi xiang,和宅,芦芝,芦芝乡', 25.2825000, 117.4597200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21156, 'Futian', 'Futian', 'Futian,Futian Xiang,fu tian,fu tian xiang,福田,福田乡', 25.2646700, 117.6131800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21157, 'Taozhou', 'Taozhou', 'Taozhou,Taozhou Xiang,tao zhou,tao zhou xiang,桃舟,桃舟乡', 25.3539900, 117.7697700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21158, 'Wan’an', 'Wan''an', 'Hongguang,Wan''an,Wan''an Zhen,Wan’an,Wan’an Zhen,hong guang,wan an,wan an zhen,万安,万安镇,红光', 25.4090300, 117.0586700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21159, 'Hengkou', 'Hengkou', 'Hengkou,Hengkou Xiang,Hengkouzhen,Waiyang,heng kou,heng kou xiang,wai yang,外洋,横口,横口乡', 25.4554400, 117.8906800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21160, 'Jiyang', 'Jiyang', 'Jiyang,ji yang,济阳', 25.5372200, 117.9577800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21161, 'Wushan', 'Wushan', 'Wushan,wu shan,吴山', 25.5373700, 117.8980500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21162, 'Xieyang', 'Xieyang', 'Xieyang,xie yang,谢洋', 25.5542500, 117.7560500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21163, 'Chunmei', 'Chunmei', 'Chunmei,Chunmei Xiang,Shangchunyang,chun mei,chun mei xiang,shang chun yang,上春洋,春美,春美乡', 25.6860400, 117.9934800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21164, 'Humei', 'Humei', 'Humei,Humei Zhen,Hushang,hu mei,hu mei zhen,hu shang,湖上,湖美,湖美镇', 25.7947700, 117.9341600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21165, 'Tangtou', 'Tangtou', 'Tangtou,Tangtou Xiang,tang tou,tang tou xiang,汤头,汤头乡', 25.8055100, 118.1321800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21166, 'Dongyang', 'Dongyang', 'Dongyang,Dongyang Xiang,dong yang,dong yang xiang,东洋,东洋乡', 25.9136200, 118.6409200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21167, 'Pangu', 'Pangu', 'Pangu,Pangu Xiang,pan gu,pan gu xiang,盘谷,盘谷乡', 25.9777500, 118.8017300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21168, 'Hongxing', 'Hongxing', 'Hongxing,Hongxing Xiang,hong xing,hong xing xiang,红星,红星乡', 25.9938900, 118.8373300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21169, 'Zhangyang', 'Zhangyang', 'Zhangyang,Zhangyang Zhen,zhang yang,zhang yang zhen,樟洋,樟洋镇', 25.9167500, 118.7793400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21170, 'Tong’an', 'Tong''an', 'Tong''an,Tong''an Zhen,Tong’an,Tong’an Zhen,tong an,tong an zhen,同安,同安镇', 25.8328300, 118.7557300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21171, 'Linglu', 'Linglu', 'Linglu,Linglu Xiang,ling lu,ling lu xiang,岭路,岭路乡', 25.8207400, 118.9313000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21172, 'Qingliang', 'Qingliang', 'Qingliang,Qingliang Zhen,qing liang,qing liang zhen,清凉,清凉镇', 25.9015800, 118.9205800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21173, 'Chengfeng', 'Chengfeng', 'Chengfeng,Chengfeng Zhen,cheng feng,cheng feng zhen,城峰,城峰镇', 25.8683200, 118.9336600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21174, 'Guiyang', 'Guiyang', 'Guiyang,Guiyang Xiang,gui yang,gui yang xiang,桂阳,桂阳乡', 25.7721200, 118.2279700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21175, 'Daming', 'Daming', 'Daming,Daming Xiang,da ming,da ming xiang,大铭,大铭乡', 25.6906900, 118.0790100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21176, 'Meihu', 'Meihu', 'Meihu,Xiaohu,mei hu,xiao hu,小湖,美湖', 25.6147200, 118.0800000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21177, 'Gaide', 'Gaide', 'Gaide,gai de,盖德', 25.5077800, 118.1747200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21178, 'Guobao', 'Guobao', 'Guobao,Guobao Xiang,guo bao,guo bao xiang,国宝,国宝乡', 25.6100000, 118.1780600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21179, 'Xunzhong', 'Xunzhong', 'Xunzhong,Xunzhong Zhen,xun zhong,xun zhong zhen,浔中,浔中镇', 25.4943100, 118.2388500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21180, 'Longmentan', 'Longmentan', 'Longmentan,Longmentan Zhen,long men tan,long men tan zhen,龙门滩,龙门滩镇', 25.5031300, 118.3416500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21181, 'Xiyuan', 'Xiyuan', 'Xiyuan,Xiyuan Xiang,xi yuan,xi yuan xiang,西苑,西苑乡', 25.4961000, 118.5643100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21182, 'Changtai', 'Changtai', 'Changtai,Changtai Zhen,chang tai,chang tai zhen,常太,常太镇', 25.4977000, 118.9316400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21183, 'Shufeng', 'Shufeng', 'Shufeng,Shufeng Xiang,shu feng,shu feng xiang,书峰,书峰乡', 25.4278100, 118.6573100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21184, 'Gaiwei', 'Gaiwei', 'Gaiwei,Gaiwei Zhen,gai wei,gai wei zhen,盖尾,盖尾镇', 25.3518400, 118.8065200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21185, 'Daji', 'Daji', 'Daji,Daji Zhen,da ji,da ji zhen,大济,大济镇', 25.3726100, 118.6345300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21186, 'Yudou', 'Yudou', 'Yudou,Yudou Zhen,yu dou,yu dou zhen,玉斗,玉斗镇', 25.3928000, 118.0371800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21187, 'Bailai', 'Bailai', 'Bailai,Bailai Xiang,bai lai,bai lai xiang,白濑,白濑乡', 25.2769400, 118.0269400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21188, 'Xianjia', 'Xianjia', 'Duzhai''an,Duzhai’an,Xianjia,Xianjia Zhen,du zhai an,xian jia,xian jia zhen,仙夹,仙夹镇,杜宅垵', 25.2633300, 118.2130600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21189, 'Penghua', 'Penghua', 'Banshan,Penghua,Penghua Zhen,peng hua,peng hua zhen,蓬华,蓬华镇', 25.1949000, 118.1941900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21190, 'Wulijie', 'Wulijie', 'Wulijie,Wulijie Zhen,Zhenwudian,wu li jie,wu li jie zhen,zhen wu dian,五里街,五里街镇,真武殿', 25.3307000, 118.2709900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21191, 'Wufeng', 'Wufeng', 'Qiaotoupu,Wufeng,Wufeng Zhen,qiao tou bu,wu feng,wu feng zhen,吾峰,吾峰镇,桥头埔', 25.3925000, 118.2405600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21192, 'Sukeng', 'Sukeng', 'Daxiban,Sukeng,Sukeng Zhen,da xi ban,su keng,su keng zhen,大溪坂,苏坑,苏坑镇', 25.4353100, 118.2147300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21193, 'Jiefu', 'Jiefu', 'Dacaopu,Jiefu,Jiefu Xiang,jie fu,jie fu xiang,介福,介福乡', 25.4309300, 118.3104600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21194, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,Taipingjie,dong ping,dong ping zhen,东平,东平镇', 25.3063100, 118.3332000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21195, 'Waishan', 'Waishan', 'Songxi,Waishan,Waishan Xiang,wai shan,wai shan xiang,外山,外山乡', 25.3208600, 118.4725100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21196, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Xiang,hong shan,hong shan xiang,虹山,虹山乡', 25.2781700, 118.5913900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21197, 'Luodong', 'Luodong', 'Luodong,Luodong Zhen,luo dong,luo dong zhen,罗东,罗东镇', 25.1589500, 118.4936000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21198, 'Chengxiang', 'Chengxiang', 'Chengxiang,Chengxiang Zhen,cheng xiang,cheng xiang zhen,城厢,城厢镇', 25.0447200, 118.1897200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21199, 'Shigu', 'Shigu', 'Shenzhongyang,Shigu,Shigu Zhen,shen zhong yang,shi gu,shi gu zhen,深中洋,石鼓,石鼓镇', 25.3391500, 118.2470000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21200, 'Donglin', 'Donglin', 'Donglin,Gulei Zhen,dong lin,gu lei zhen,东林,古雷镇', 23.8375200, 117.6153700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21201, 'Keren', 'Keren', 'Keren,ke ren,科任', 24.5805700, 118.6620900, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21202, 'Wubu', 'Wubu', 'Wubu,wu bao,五堡', 24.5958900, 118.5535900, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21203, 'Tatou', 'Tatou', 'Tatou,ta tou,塔头', 24.6137800, 118.5258500, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21204, 'Houxi', 'Houxi', 'Houxi,Houxi Zhen,hou xi,hou xi zhen,后溪,后溪镇', 24.6313000, 118.0332700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21205, 'Yinglin', 'Yinglin', '', 24.6322200, 118.5805600, 'CN', '2004-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21206, 'Xike', 'Xike', 'Xike,Xike Zhen,xi ke,xi ke zhen,西柯,西柯镇', 24.6733800, 118.1500000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21207, 'Maping', 'Maping', 'Maping,ma ping,马坪', 24.6872200, 118.5527800, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21208, 'Hongtang', 'Hongtang', 'Hongtang,Hongtang Zhen,hong tang,hong tang zhen,洪塘,洪塘镇', 24.7143500, 118.1953800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21209, 'Wuxian', 'Wuxian', 'Wuxian,Wuxian Zhen,wu xian,wu xian zhen,五显,五显镇', 24.7430900, 118.1616400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21210, 'Neikeng', 'Neikeng', 'Neikeng,Neikeng Zhen,nei keng,nei keng zhen,内坑,内坑镇', 24.7854400, 118.4603700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21211, 'Chendai', 'Chendai', 'Chendai,Chendai Zhen,Sijing,chen dai,chen dai zhen,陈埭,陈埭镇', 24.8220100, 118.5997900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21212, 'Baiqi', 'Baiqi', 'Baiqi,Baiqihuizuxiang,bai qi,百崎', 24.8824400, 118.7086900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21213, 'Shanxia', 'Shanxia', 'Shanxia,shan xia,山霞', 24.9380200, 118.8817000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21214, 'Xiangyun', 'Xiangyun', '', 24.9711100, 118.1602800, 'CN', '2004-03-24', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21215, 'Jingfeng', 'Jingfeng', 'Jingfeng,jing feng,净峰', 24.9744100, 118.9648600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21216, 'Dalianwan', 'Dalianwan', '', 39.0286100, 121.6950000, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21217, 'Meishan', 'Meishan', 'Damei,Meishan,Meishan Xiang,mei shan,mei shan xiang,眉山,眉山乡', 25.0839600, 118.3031300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21218, 'Anjie', 'Anjie', 'Anjie,Anjie Xiang,an jie,an jie xiang,庵杰,庵杰乡', 25.9578800, 116.4618900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21219, 'Tiechang', 'Tiechang', 'Tiechang,Tiechang Xiang,tie zhang,tie zhang xiang,铁长,铁长乡', 25.9317600, 116.3954700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21220, 'Dengjia', 'Dengjia', 'Dengjia,deng jia,邓家', 25.9165300, 116.8387300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21221, 'Sibao', 'Sibao', 'Sibao,Sibao Xiang,si bao,si bao xiang,四堡,四堡乡', 25.8951900, 116.7063100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21222, 'Datong', 'Datong', 'Datong,Datong Zhen,da tong,da tong zhen,大同,大同镇', 25.8423100, 116.3588600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21223, 'Lijia', 'Lijia', 'Lijia,li jia,李家', 25.8277600, 116.7864600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21224, 'Gechuan', 'Gechuan', 'Gechuan,Gechuan Xiang,ge chuan,ge chuan xiang,隔川,隔川乡', 25.7568900, 116.7404500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21225, 'Jiele', 'Jiele', 'Jiele,Jiele Xiang,jie le,jie le xiang,揭乐,揭乐乡', 25.7284800, 116.7829900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21226, 'Liwu', 'Liwu', 'Liwu,Liwu Xiang,li wu,li wu xiang,李屋,李屋乡', 25.6491700, 116.8691700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21227, 'Xuanhe', 'Xuanhe', 'Xuanhe,Xuanhe Xiang,xuan he,xuan he xiang,宣和,宣和乡', 25.6104700, 116.6409300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21228, 'Sanzhou', 'Sanzhou', 'Sanzhou,Sanzhou Xiang,san zhou,san zhou xiang,三州,三州乡', 25.5926100, 116.3786800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21229, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Xiang,hong shan,hong shan xiang,红山,红山乡', 25.4950600, 116.1026700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21230, 'Xiangdian', 'Xiangdian', 'Xiangdian,Xiangdian Xiang,xiang dian,xiang dian xiang,湘店,湘店乡', 25.4436200, 116.2098500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21231, 'Yanggu', 'Yanggu', 'Yanggu,Yanggu Xiang,yang gu,yang gu xiang,羊牯,羊牯乡', 25.3860600, 116.3162900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21232, 'Buyun', 'Buyun', 'Buyun,Buyun Xiang,bu yun,bu yun xiang,步云,步云乡', 25.2703100, 116.8547300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21233, 'Shanhu', 'Shanhu', 'Shanhu,Shanhu Xiang,shan hu,shan hu xiang,珊瑚,珊瑚乡', 25.2311100, 116.3272200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21234, 'Wudong', 'Wudong', 'Wudong,Wudong Xiang,wu dong,wu dong xiang,武东,武东乡', 25.1093000, 116.2460000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21235, 'Qifang', 'Qifang', 'Chengxiang,Chengxiang Xiang,Qifang,cheng xiang,cheng xiang xiang,qi fang,七坊,城厢,城厢乡', 25.1000100, 116.0994500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21236, 'Xikou', 'Xikou', 'Xikou,Xikou Xiang,xi kou,xi kou xiang,溪口,溪口乡', 25.0641500, 116.6750400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21237, 'Lincheng', 'Lincheng', 'Lincheng,Lincheng Zhen,lin cheng,lin cheng zhen,临城,临城镇', 25.0593800, 116.4080800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21238, 'Nanyang', 'Nanyang', 'Hongfang,Hongfang Zhen,Nanyang,hong fang,hong fang zhen,nan yang,南阳,红坊,红坊镇', 25.0265400, 116.9525200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21239, 'Aodong', 'Aodong', 'Aodong,Aodong Zhen,ao dong,ao dong zhen,敖东,敖东镇', 25.4529800, 119.7293700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21240, 'Baitang', 'Baitang', 'Baitang,Baitang Zhen,bai tang,bai tang zhen,白塘,白塘镇', 25.4504700, 119.0949300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21241, 'Dalian', 'Dalian', 'Dalian,Dalian Xiang,da lian,da lian xiang,大练,大练乡', 25.6403100, 119.6858000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21242, 'Guohuan', 'Guohuan', 'Guohuan,Guohuan Zhen,guo huan,guo huan zhen,国欢,国欢镇', 25.4769300, 119.1106500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21243, 'Hunan', 'Hunan', 'Hunan,Hunan Zhen,hu nan,hu nan zhen,湖南,湖南镇', 25.9713800, 119.6457100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21244, 'Lancheng', 'Lancheng', 'Lancheng,Lancheng Xiang,lan cheng,lan cheng xiang,岚城,岚城乡', 25.5107000, 119.7775200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21245, 'Luolian', 'Luolian', 'Luolian,Luolian Xiang,Sanshan,luo lian,luo lian xiang,罗联,罗联乡', 25.8558500, 119.4686400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21246, 'Luyang', 'Luyang', 'Luyang,Luyang Xiang,lu yang,lu yang xiang,芦洋,芦洋乡', 25.5855600, 119.7577400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21247, 'Minjiang', 'Minjiang', 'Minjiang,Minjiang Xiang,min jiang,min jiang xiang,闽江,闽江乡', 25.9563100, 119.3920300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21248, 'Nanling', 'Nanling', 'Nanling,Nanling Zhen,nan ling,nan ling zhen,南岭,南岭镇', 25.7709300, 119.4961300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21249, 'Qingkou', 'Qingkou', 'Qingkou,Qingkou Zhen,qing kou,qing kou zhen,青口,青口镇', 25.8941200, 119.3861600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21250, 'Sanjiangkou', 'Sanjiangkou', 'Sanjiangkou,Sanjiangkou Zhen,san jiang kou,san jiang kou zhen,三江口,三江口镇', 25.4429600, 119.1156800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21251, 'Shapu', 'Shapu', 'Shapu,Shapu Zhen,sha bu,sha bu zhen,沙埔,沙埔镇', 25.4355000, 119.5243000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21252, 'Wenwusha', 'Wenwusha', 'Wenwusha,Wenwusha Zhen,wen wu sha,wen wu sha zhen,文武砂,文武砂镇', 25.8989200, 119.5753700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21253, 'Xincuo', 'Xincuo', 'Xincuo,Xincuo Zhen,xin cuo,xin cuo zhen,新厝,新厝镇', 25.5138100, 119.2512100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21254, 'Xiuyu', 'Xiuyu', 'Xiuyu,Xiuyu Zhen,xiu yu,xiu yu zhen,秀屿,秀屿镇', 25.2555000, 119.0345400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21255, 'Yangxia', 'Yangxia', 'Yangxia,Yangxia Zhen,yang xia,yang xia zhen,阳下,阳下镇', 25.7422700, 119.3800300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21256, 'Yinxi', 'Yinxi', 'Yinxi,Yinxi Zhen,yin xi,yin xi zhen,音西,音西镇', 25.7330500, 119.3586600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21257, 'Yutou', 'Yutou', 'Yutou,Yutou Xiang,yu tou,yu tou xiang,屿头,屿头乡', 25.6496300, 119.5888800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21258, 'Nanhai', 'Nanhai', 'Nanhai,Nanhai Xiang,Zhangcuo,nan hai,nan hai xiang,南海,南海乡', 25.3757400, 119.7178800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21259, 'Zhonglou', 'Zhonglou', 'Zhonglou,Zhonglou Xiang,zhong lou,zhong lou xiang,中楼,中楼乡', 25.5629400, 119.7724000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21260, 'Zhoutou', 'Zhoutou', 'Zhoutou,Zhoutou Xiang,zhou tou,zhou tou xiang,周头,周头乡', 37.9122200, 115.0163900, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21261, 'Liantang', 'Liantang', 'Liantang,Liantang Zhen,Xialiantang,lian tang,lian tang zhen,xia lian tang,下连塘,莲塘,莲塘镇', 27.9238900, 118.5161100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21262, 'Wan’an', 'Wan''an', 'Wan''an,Wan''an Xiang,Wan’an,Wan’an Xiang,wan an,wan an xiang,万安,万安乡', 27.9166700, 118.5538900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21263, 'Wuyishan', 'Wuyishan', 'Bú-î-soaⁿ-chhī,Ciudad de Wuyishan,U-i-sang-che,Vu Di Son,Vu-yi-san-su,Vú-yî-sân-sṳ,Vũ Di Sơn,WUS,Wuyishan,Wuyishan City,u-isan si,wayshan,wu yi shan,wu yi shan shi,wwyyshan,wwyyshan  fwjyan,Ū-ì-săng-chê,وایشان,ووئیشان، فوجیان,ووییشان,ཝུའུ་དབྱི་ཧྲན་གྲོང་ཁྱེར།,武夷山,武夷山市,우이산 시', 27.7599500, 118.0306600, 'CN', '2017-05-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21264, 'Xidong', 'Xidong', 'Xidong,Xidong Xiang,xi dong,xi dong xiang,溪东,溪东乡', 27.7502800, 118.7797200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21265, 'Da’an', 'Da''an', 'Da''an,Da''an Xiang,Da’an,Da’an Xiang,da an,da an xiang,大安,大安乡', 27.5100700, 119.5185200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21266, 'Xiadang', 'Xiadang', 'Xiadang,Xiadang Xiang,xia dang,xia dang xiang,下党,下党乡', 27.4083300, 119.3050000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21267, 'Qingyuan', 'Qingyuan', 'Jiangcuo,Qingyuan,Qingyuan Xiang,jiang cuo,qing yuan,qing yuan xiang,姜厝,清源,清源乡', 27.4016300, 119.4900000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21268, 'Qinyang', 'Qinyang', 'Qinyang,Qinyang Xiang,qin yang,qin yang xiang,芹洋,芹洋乡', 27.3852800, 119.3905600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21269, 'Xingxi', 'Xingxi', 'Xingxi,Xingxi Xiang,xing xi,xing xi xiang,星溪,星溪乡', 27.3675900, 118.8580600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21270, 'Zhuguanlong', 'Zhuguanlong', 'Wugangting,Zhuguanlong,wu gang ting,zhu guan long,梧冈亭,竹管垄', 27.3418400, 119.5637300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21271, 'Fankeng', 'Fankeng', 'Fankeng,Fankeng Xiang,fan keng,fan keng xiang,范坑,范坑乡', 27.3069400, 119.7236100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21272, 'Yingshan', 'Yingshan', 'Ronghuacuo,Yingshan,Yingshan Xiang,rong hua cuo,ying shan,ying shan xiang,英山,英山乡,荣华厝', 27.2833300, 119.8019400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21273, 'Zhayang', 'Zhayang', 'Zhayang,Zhayang Xiang,zha yang,zha yang xiang,乍洋,乍洋乡', 27.2388900, 119.9770200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21274, 'Dongyuan', 'Dongyuan', 'Dongyuan,Dongyuan Xiang,dong yuan,dong yuan xiang,东源,东源乡', 27.2133300, 119.8963100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21275, 'Tantou', 'Tantou', 'Tantou,Tantou Zhen,tan tou,tan tou zhen,潭头,潭头镇', 27.2047900, 119.6606700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21276, 'Huangbai', 'Huangbai', 'Huangbai,Huangbai Xiang,huang bai,huang bai xiang,黄柏,黄柏乡', 27.1865100, 119.7842200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21277, 'Xiaoyang', 'Xiaoyang', 'Xiaoyang,Xiaoyang Zhen,xiao yang,xiao yang zhen,晓阳,晓阳镇', 27.1877300, 119.4509500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21278, 'Shuiyuan', 'Shuiyuan', 'Shuiyuan,Shuiyuan Xiang,shui yuan,shui yuan xiang,水源,水源乡', 27.1583300, 118.7400000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21279, 'Puyuan', 'Puyuan', 'Puyuan,Puyuan Zhen,pu yuan,pu yuan zhen,浦源,浦源镇', 27.1233300, 119.2944400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21280, 'Zhaizhong', 'Zhaizhong', 'Zhaizhong,Zhaizhong Xiang,zhai zhong,zhai zhong xiang,宅中,宅中乡', 27.1243600, 119.8597600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21281, 'Banzhong', 'Banzhong', 'Banzhong,Banzhong Shezu Xiang,ban zhong,ban zhong she zu xiang,坂中,坂中畲族乡', 27.1008300, 119.6275000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21282, 'Kangcuo', 'Kangcuo', 'Kangcuo,Kangcuo Shezu Xiang,kang cuo,kang cuo she zu xiang,康厝,康厝畲族乡', 27.0525800, 119.5317200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21283, 'Limen', 'Limen', 'Limen,Limen Xiang,li men,li men xiang,礼门,礼门乡', 27.0456600, 119.2094400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21284, 'Haidao', 'Haidao', 'Haidao,Haidao Xiang,hai dao,hai dao xiang,海岛,海岛乡', 26.5044300, 120.0481700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21285, 'Xibin', 'Xibin', 'Xibi Zhen,Xibin,xi bin,xi bin zhen,西滨,西滨镇', 26.3683200, 118.3746900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21286, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Zhen,xi cheng,xi cheng zhen,西城,西城镇', 26.1630200, 118.1419300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21287, 'Xinyang', 'Xinyang', 'Xinyang,Xinyang Zhen,xin yang,xin yang zhen,新阳,新阳镇', 26.0511900, 117.9448800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21288, 'Tianyuan', 'Tianyuan', 'Tianyuan,tian yuan,田源', 26.0543000, 116.8450500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21289, 'Qitao', 'Qitao', 'Qitao,Qitao Zhen,qi tao,qi tao zhen,奇韬,奇韬镇', 26.0525800, 117.8687400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21290, 'Yupeng', 'Yupeng', 'Yupeng,yu peng,余朋', 26.1011100, 117.0411100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21291, 'Baziqiao', 'Baziqiao', 'Baziqiao,Baziqiao Xiang,ba zi qiao,ba zi qiao xiang,八字桥,八字桥乡', 26.1879000, 117.8499900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21292, 'Chengnan', 'Chengnan', 'Chengnan,cheng nan,城南', 26.2156000, 116.7140900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21293, 'Xiaochi', 'Xiaochi', 'Wenjiao,Xiaochi,wen jiao,xiao chi,小池,温郊', 26.2337100, 117.0180800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21294, 'Xinshi', 'Xinshi', 'Shibi Zhen,Xinshi,shi bi zhen,xin shi,新市,石壁镇', 26.2485900, 116.5142000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21295, 'Nanxia', 'Nanxia', 'Nanxia,Nanxia Xiang,nan xia,nan xia xiang,南霞,南霞乡', 26.2808500, 117.8744500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21296, 'Xubi', 'Xubi', 'Xubi,xu bi,俆碧', 26.2797500, 117.6325200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21297, 'Chenda', 'Chenda', 'Chenda,Chenda Zhen,chen da,chen da zhen,陈大,陈大镇', 26.3142100, 117.6447000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21298, 'Hanxian', 'Hanxian', 'Hanxian,Hanxian Zhen,han xian,han xian zhen,瀚仙,瀚仙镇', 26.3597400, 117.2901000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21299, 'Langkou', 'Langkou', 'Langkou,Langkou Zhen,lang kou,lang kou zhen,琅口,琅口镇', 26.3874000, 117.8396700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21300, 'Helong', 'Helong', 'Helong,he long,河龙', 26.4462000, 116.6536700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21301, 'Xiafang', 'Xiafang', 'Xiafang,Xiafang Xiang,xia fang,xia fang xiang,夏坊,夏坊乡', 26.5724700, 116.9340500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21302, 'Lishu', 'Lishu', 'Lishu,Lishu Xiang,li shu,li shu xiang,梨树,梨树乡', 26.5933200, 117.7162300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21303, 'Long’an', 'Long''an', 'Long''an,Long''an Xiang,Long’an,Long’an Xiang,long an,long an xiang,龙安,龙安乡', 26.6337200, 117.0348900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21304, 'Dushang', 'Dushang', 'Dushang,Yijia,dou shang,yi jia,伊家,都上', 26.6891700, 116.7545900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21305, 'Dabu', 'Dabu', 'Dabu,Dabu Xiang,da bu,da bu xiang,大布,大布乡', 26.7140700, 117.0093500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21306, 'Huangbu', 'Huangbu', 'Huangbu,huang bu,黄埠', 26.7421000, 116.6532600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21307, 'Kaishan', 'Kaishan', 'Kaishan,Kaishan Xiang,kai shan,kai shan xiang,开善,开善乡', 26.7532800, 117.1801400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21308, 'Shuinan', 'Shuinan', 'Shuinan,Shuinan Zhen,shui nan,shui nan zhen,水南,水南镇', 26.7246400, 117.7954000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21309, 'Hedong', 'Hedong', 'Hedong,Jinxi,he dong,jin xi,河东,金溪', 26.8353700, 116.8479000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21310, 'Jihui', 'Jihui', 'Jihui,Jihui Xiang,ji hui,ji hui xiang,际会,际会乡', 26.8511200, 117.8980700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21311, 'Hongdun', 'Hongdun', 'Hongdun,Hongdun Zhen,hong dun,hong dun zhen,洪墩,洪墩镇', 26.9782700, 117.6663100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21312, 'Danxi', 'Danxi', 'Danxi,Danxi Xiang,dan xi,dan xi xiang,丹溪,丹溪乡', 24.6093700, 115.7754600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21313, 'Wudang', 'Wudang', 'Wudang,Wudang Zhen,wu dang,wu dang zhen,武当,武当镇', 24.6399300, 114.7521700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21314, 'Changpu', 'Changpu', 'Changpu,Changpu Xiang,Changpuxu,chang pu,chang pu xiang,菖蒲,菖蒲乡', 24.7417800, 115.5227800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21315, 'Lintang', 'Lintang', 'Lintang,Lintang Xiang,lin tang,lin tang xiang,临塘,临塘乡', 24.7909500, 114.7968700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21316, 'Nanqiao', 'Nanqiao', 'Nanqiao,Nanqiao Zhen,nan qiao,nan qiao zhen,南桥,南桥镇', 24.7944100, 115.7147800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21317, 'Taojiang', 'Taojiang', 'Taojiang,Taojiang Xiang,tao jiang,tao jiang xiang,桃江,桃江乡', 24.9168400, 114.7797300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21318, 'Luoshan', 'Luoshan', 'Luoshan,Luoshan Xiang,Luoshanxu,luo shan,luo shan wei,luo shan xiang,罗珊,罗珊乡,罗珊圩', 25.1447500, 115.8164500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21319, 'Changling', 'Changling', 'Changling,Changling Xiang,zhang ling,zhang ling xiang,长岭,长岭乡', 25.2463500, 115.8009300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21320, 'Dongtou', 'Dongtou', 'Dongtou,Dongtou Xiang,Tangtou,dong tou,dong tou xiang,洞头,洞头乡', 25.3073300, 115.9102900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21321, 'Caifang', 'Caifang', 'Caifang,Caifang Xiang,cai fang,cai fang xiang,蔡坊,蔡坊乡', 25.3003900, 115.4456300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21322, 'Shuangyuan', 'Shuangyuan', 'Shuangyuan,Shuangyuan Xiang,Shuangyuanxu,shuang yan,shuang yan xiang,双芫,双芫乡', 25.4930400, 115.3003200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21323, 'Baying', 'Baying', 'Baying,Baying Xiang,Bayingxu,ba ying,ba ying xiang,拔英,拔英乡', 25.6472100, 115.9694300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21324, 'Zhuangbu', 'Zhuangbu', 'Zhuangbu,Zhuangbu Xiang,zhuang bu,zhuang bu xiang,庄埠,庄埠乡', 25.6984500, 115.5939800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21325, 'Qilushan', 'Qilushan', 'Qilushan,Qilushan Zhen,qi lu shan,qi lu shan zhen,祁禄山,祁禄山镇', 25.6958000, 115.2984500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21326, 'Fenghuangdong', 'Fenghuangdong', 'Fenghuangdong,Fenghuangdong Xiang,Fenghuangdongxu,feng huang dong,feng huang dong wei,feng huang dong xiang,凤凰崠,凤凰崠乡,凤凰崠圩', 25.7275000, 115.7413900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21327, 'Hefeng', 'Hefeng', 'Hefeng,Hefeng Zhen,Hefengxu,he feng,he feng wei,he feng zhen,禾丰,禾丰圩,禾丰镇', 25.8008500, 115.4886300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21328, 'Xinbei', 'Xinbei', 'Xinbei,Xinbei Xiang,Xinbeixu,xin bei,xin bei wei,xin bei xiang,新陂,新陂乡,新陂圩', 25.8738300, 115.3475700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21329, 'Xiaomi', 'Xiaomi', 'Xiaomi,Xiaomi Xiang,Xiaomixu,xiao mi,xiao mi xiang,小密,小密乡', 25.8765900, 115.7064100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21330, 'Luojiang', 'Luojiang', 'Luojiang,Luojiang Xiang,Luojiangxu,luo jiang,luo jiang wei,luo jiang xiang,罗江,罗江乡,罗江圩', 25.8800100, 115.2525500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21331, 'Shaxin', 'Shaxin', 'Shaxin,Shaxin Xiang,Shaxinxu,sha xin,sha xin wei,sha xin xiang,沙心,沙心乡,沙心圩', 25.9933300, 115.7663000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21332, 'Zhukeng', 'Zhukeng', 'Zhukeng,Zhukeng Xiang,zhu keng,zhu keng xiang,珠坑,珠坑乡', 26.2156000, 116.3611900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21333, 'Jiecun', 'Jiecun', 'Jiecun,Jiecun Xiang,Jiecunxu,jie cun,jie cun xiang,杰村,杰村乡', 26.2188900, 115.4363900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21334, 'Jiantian', 'Jiantian', 'Jiantian,Jiantian Xiang,jian tian,jian tian xiang,涧田,涧田乡', 26.2744500, 115.0187500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21335, 'Butou', 'Butou', 'Butou,Butou Xiang,bu tou,bu tou xiang,埠头,埠头乡', 26.2908300, 115.3375000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21336, 'Longping', 'Longping', 'Longping,Longping Xiang,long ping,long ping xiang,隆坪,隆坪乡', 26.3555500, 115.2352200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21337, 'Dinglong', 'Dinglong', 'Dinglong,Dinglong Xiang,Dinglongxu,ding long,ding long xiang,鼎龙,鼎龙乡', 26.4154500, 115.4545100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21338, 'Shuicha', 'Shuicha', 'Shuicha,Shuicha Xiang,shui cha,shui cha xiang,水槎,水槎乡', 26.5230600, 115.0663700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21339, 'Tangfang', 'Tangfang', 'Tangfang,Tangfang Xiang,tang fang,tang fang xiang,塘坊,塘坊乡', 26.6216600, 116.4828900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21340, 'Xiaping', 'Xiaping', 'Jinggangshan Shi,Xiaping,jing gang shan shi,sha ping,井冈山市,厦坪', 26.7313900, 114.2702800, 'CN', '2013-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21341, 'Guanxi', 'Guanxi', 'Guanxi,Guanxi Zhen,guan xi,guan xi zhen,灌溪,灌溪镇', 26.7528700, 115.1218400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21342, 'Sanfang', 'Sanfang', 'Sanfang,Sanfang Xiang,san fang,san fang xiang,三坊,三坊乡', 26.8692400, 115.4145600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21343, 'Wanhe', 'Wanhe', 'Wanhe,Wanhe Zhen,wan he,wan he zhen,万合,万合镇', 26.8961200, 115.0273100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21344, 'Qianshan', 'Qianshan', 'Qianshan,Qianshan Xiang,qian shan,qian shan xiang,千善,千善乡', 26.9311800, 116.4698300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21345, 'Wenbei', 'Wenbei', 'Wenbei,Wenbei Xiang,wen bei,wen bei xiang,文陂,文陂乡', 26.9428700, 115.1143400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21346, 'Zhangping', 'Zhangping', 'Zhangping,Zhangping Shezuxiang,zhang ping,zhang ping she zu xiang,樟坪,樟坪畲族乡', 27.9968300, 117.4208200, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21347, 'Taiyuan', 'Taiyuan', 'Taiyuan,Taiyuan Shezuxiang,tai yuan,tai yuan she zu xiang,太源,太源畲族乡', 28.0091700, 117.5077800, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21348, 'Pengwan', 'Pengwan', 'Pengwan,Pengwan Xiang,peng wan,peng wan xiang,彭湾,彭湾乡', 28.0956400, 117.1235400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21349, 'Gangdong', 'Gangdong', 'Gangdong,Gangdong Xiang,gang dong,港东', 28.1163900, 117.6625000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21350, 'Yingjiang', 'Yingjiang', 'Yingjiang,Yingjiang Xiang,ying jiang,ying jiang xiang,英将,英将乡', 28.1386100, 117.9133300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21351, 'Tieshan', 'Tieshan', 'Tieshan,Tieshan Xiang,tie shan,tie shan xiang,铁山,铁山乡', 28.2152800, 118.0950300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21352, 'Hongqiao', 'Hongqiao', 'Hongqiao,Hongqiao Xiang,hong qiao,hong qiao xiang,虹桥,虹桥乡', 28.2488900, 117.6844400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21353, 'Xin’anbu', 'Xin''anbu', 'Xin''anbu,Xin''anbu Xiang,Xin’anbu,Xin’anbu Xiang,xin an bu,xin an bu xiang,新安埠,新安埠乡', 28.2670100, 117.5943000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21354, 'Ehu', 'Ehu', 'Ehu,Ehu Zhen,e hu,e hu zhen,鹅湖,鹅湖镇', 28.2905000, 117.7943100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21355, 'Hengshan', 'Hengshan', 'Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横山,横山镇', 28.3172400, 118.1970600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21356, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,沙田,沙田镇', 28.3380100, 118.2807000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21357, 'Hongtang', 'Hongtang', 'Hongtang,Hongtang Zhen,hong tang,hong tang zhen,鸿塘,鸿塘镇', 28.3581500, 117.0166100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21358, 'Dongtuan', 'Dongtuan', 'Dongtuan,Dongtuan Xiang,dong tuan,dong tuan xiang,董团,董团乡', 28.3914200, 117.8486300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21359, 'Maocun', 'Maocun', 'Maocun,Maocun Zhen,mao cun,mao cun zhen,毛村,毛村镇', 28.3942000, 118.3643600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21360, 'Dashi', 'Dashi', 'Dashi,Dashi Xiang,da shi,da shi xiang,大石,大石乡', 28.4024700, 118.2123200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21361, 'Huating', 'Huating', 'Huating,Huating Xiang,hua ting,hua ting xiang,花亭,花亭乡', 28.4338900, 117.4422200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21362, 'Gangbian', 'Gangbian', 'Gangbian,Gangbian Xiang,gang bian,gang bian xiang,港边,港边乡', 28.4663900, 117.6891700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21363, 'Paishan', 'Paishan', 'Paishan,Paishan Zhen,pai shan,pai shan zhen,排山,排山镇', 28.4595600, 118.2793900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21364, 'Puqian', 'Puqian', 'Puqian,Puqian Zhen,pu qian,pu qian zhen,铺前,铺前镇', 28.4733300, 117.6136100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21365, 'Shehou', 'Shehou', 'Shehou,Shehou Xiang,she hou,she hou xiang,社后,社后乡', 28.4801100, 118.3673300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21366, 'Wucun', 'Wucun', 'Wucun,Wucun Zhen,wu cun,wu cun zhen,吴村,吴村镇', 28.4989100, 118.2771500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21367, 'Huqiao', 'Huqiao', 'Huqiao,Huqiao Zhen,hu jiao,hu jiao zhen,壶峤,壶峤镇', 28.5483300, 118.1577800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21368, 'Xianyan', 'Xianyan', 'Xianyan,Xianyan Zhen,xian yan,xian yan zhen,仙岩,仙岩镇', 28.5733300, 118.3941700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21369, 'Hufeng', 'Hufeng', 'Hufeng,Hufeng Zhen,hu feng,hu feng zhen,湖丰,湖丰镇', 28.5902800, 118.1908300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21370, 'Liudu', 'Liudu', 'Liudu,Liudu Xiang,liu dou,liu dou xiang,六都,六都乡', 28.6461200, 118.3051800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21371, 'Linhu', 'Linhu', 'Linhu,Linhu Zhen,lin hu,lin hu zhen,临湖,临湖镇', 28.6595800, 117.9376800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21372, 'Shangfang', 'Shangfang', 'Shangfang,Shangfang Xiang,shang fang,shang fang xiang,上坊,上坊乡', 28.6783300, 117.0458300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21373, 'Yanrui', 'Yanrui', 'Yanrui,Yanrui Zhen,yan rui,yan rui zhen,岩瑞,岩瑞镇', 28.7139900, 118.3371500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21374, 'Siguqiao', 'Siguqiao', 'Siguqiao,Siguqiao Xiang,si gu qiao,si gu qiao xiang,四股桥,四股桥乡', 28.7467700, 118.2619100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21375, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Zhen,bai yun,bai yun zhen,白云,白云镇', 28.7577900, 118.3259300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21376, 'Zhangcun', 'Zhangcun', 'Zhangcun,Zhangcun Xiang,zhang cun,zhang cun xiang,张村,张村乡', 28.7602300, 117.5606500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21377, 'Lilin', 'Lilin', 'Lilin,Lilin Zhen,li lin,li lin zhen,礼林,礼林镇', 28.8633800, 117.1650500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21378, 'Wukou', 'Wukou', 'Wukou,Wukou Zhen,wu kou,wu kou zhen,浯口,浯口镇', 28.9806200, 117.2391600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21379, 'Gaojia', 'Gaojia', 'Gaojia,Gaojia Zhen,gao jia,gao jia zhen,高家,高家镇', 29.0011100, 117.3825000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21380, 'Tanbuqiao', 'Tanbuqiao', 'Tanbuqiao,Tanbuqiao Zhen,tan bu qiao,tan bu qiao zhen,潭埠桥,潭埠桥镇', 29.0070100, 117.6296500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21381, 'Liyang', 'Liyang', 'Liyang,Liyang Xiang,li yang,li yang xiang,丽阳,丽阳乡', 29.2206400, 117.0369700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21382, 'Zhentou', 'Zhentou', 'Zhentou,Zhentou Zhen,Zhentoudian,zhen tou,zhen tou zhen,镇头,镇头镇', 29.2667700, 117.4682700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21383, 'Longshan', 'Longshan', 'Longshan,Longshan Xiang,long shan,long shan xiang,龙山,龙山乡', 29.2706100, 117.6848900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21384, 'Jialu', 'Jialu', 'Jialu,Jialu Xiang,jia lu,jia lu xiang,甲路,甲路乡', 29.3532000, 117.6205600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21385, 'Bailu', 'Bailu', 'Bailu,Bailu Xiang,bai lu,bai lu xiang,白路,白路乡', 27.9101400, 116.1994400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21386, 'Baimaqiao', 'Baimaqiao', 'Baimaqiao,Baimaqiao Xiang,bai ma qiao,bai ma qiao xiang,白马桥,白马桥乡', 28.6401000, 116.7380400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21387, 'Baixu', 'Baixu', 'Baixu,Baixu Xiang,bai wei,bai wei xiang,白圩,白圩乡', 28.2615600, 116.2524900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21388, 'Bajiang', 'Bajiang', 'Bajiang,Bajiang Xiang,ba jiang,ba jiang xiang,八江,八江乡', 27.2036300, 115.3515200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21389, 'Beigang', 'Beigang', 'Beigang,Beigang Xiang,Beigangxu,bei gang,bei gang xiang,北岗,北岗乡', 27.9287300, 115.0934100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21390, 'Changjun', 'Changjun', 'Changjun,Changjun Xiang,Changjunlong,zhang jun,zhang jun xiang,长均,长均乡', 28.8661800, 115.7141900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21391, 'Chenfangji', 'Chenfangji', 'Chenfangji,Chenfangji Xiang,chen fang ji,chen fang ji xiang,陈坊积,陈坊积乡', 28.0593900, 116.5537600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21392, 'Chonggang', 'Chonggang', 'Chonggang,Chonggang Zhen,chong gang,chong gang zhen,崇岗,崇岗镇', 27.9112600, 116.3742400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21393, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Xiang,da qiao,da qiao xiang,大桥,大桥乡', 28.0545300, 115.5806000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21394, 'Datang', 'Datang', 'Datang,Dataong Xiang,da tang,da tang xiang,大塘,大塘乡', 28.7796000, 116.5184400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21395, 'Dayangzhou', 'Dayangzhou', 'Dayangzhou,Dayangzhou Zhen,da yang zhou,da yang zhou zhen,大洋洲,大洋洲镇', 27.9005900, 115.4489800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21396, 'Dengdun', 'Dengdun', 'Dengdun,Dengdun Xiang,deng dun,deng dun xiang,邓墩,邓墩乡', 28.3996000, 116.5763200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21397, 'Dengfang', 'Dengfang', 'Dengfang,Dengfang Xiang,deng fang,deng fang xiang,邓坊,邓坊乡', 27.8111200, 116.5249000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21398, 'Dinghu', 'Dinghu', 'Dinghu,Dinghu Zhen,ding hu,ding hu zhen,鼎湖,鼎湖镇', 28.8375600, 115.5449400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21399, 'Dongxin', 'Dongxin', 'Dongxin,Dongxin Xiang,dong xin,dong xin xiang,东新,东新乡', 28.5893200, 115.8277700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21400, 'Dongyuan', 'Dongyuan', 'Dongyuan,Dongyuan Xiang,dong yuan,dong yuan xiang,东源,东源乡', 28.7704900, 116.4486000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21401, 'Duantan', 'Duantan', 'Duangangtan,Duantan,Duantan Xiang,duan tan,duan tan xiang,段潭,段潭乡', 28.2684600, 115.9524200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21402, 'Ducheng', 'Ducheng', 'Ducheng,Ducheng Zhen,Duchengxu,du cheng,du cheng zhen,独城,独城镇', 28.2334600, 115.4915300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21403, 'Fubei', 'Fubei', 'Fubei,Fubei Zhen,fu bei,fu bei zhen,抚北,抚北镇', 28.0065300, 116.2928000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21404, 'Gangshang', 'Gangshang', 'Gangshang,Gangshang Zhen,Gangshangjie,gang shang,gang shang zhen,岗上,岗上镇', 28.4172100, 115.8632800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21405, 'Gaoping', 'Gaoping', 'Gaoping,Gaoping Zhen,gao ping,gao ping zhen,高坪,高坪镇', 27.9271300, 116.1548700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21406, 'Gugang', 'Gugang', 'Gugang,Gugang Xiang,gu gang,gu gang xiang,谷岗,谷岗乡', 27.3841300, 116.0011600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21407, 'Hangbu', 'Hangbu', 'Hangbu,Hangbu Zhen,hang bu,hang bu zhen,航埠,航埠镇', 27.8153000, 116.2457800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21408, 'Hebu', 'Hebu', 'Hebu,Hebu Xiang,he bu,he bu xiang,河埠,河埠乡', 27.7882500, 116.3982700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21409, 'Heling', 'Heling', 'Heling,Heling Xiang,he ling,he ling xiang,荷岭,荷岭乡', 28.3531400, 115.4108200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21410, 'Heshan', 'Heshan', 'Heshan,Heshan Xiang,he shan,he shan xiang,禾山,禾山乡', 28.5981700, 116.5522500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21411, 'Hongjiazui', 'Hongjiazui', 'Hongjiazui,Hongjiazui Xiang,hong jia zui,hong jia zui xiang,洪家嘴,洪家嘴乡', 28.6991000, 116.6576400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21412, 'Houtian', 'Houtian', 'Houtian,Houtian Xiang,Houtianjie,hou tian,hou tian xiang,厚田,厚田乡', 28.4652200, 115.7906000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21413, 'Hualingang', 'Hualingang', 'Hualingang,Hualingang Xiang,hua lin gang,hua lin gang xiang,华林岗,华林岗乡', 28.7063300, 116.6930700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21414, 'Huangcheng', 'Huangcheng', 'Huangcheng,Huangcheng Zhen,huang cheng,huang cheng zhen,隍城,隍城镇', 28.3601600, 115.5615600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21415, 'Huangma', 'Huangma', 'Huangma,Huangma Xiang,Huangmajie,huang ma,huang ma xiang,黄马,黄马乡', 28.3520900, 116.0119700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21416, 'Huangxi', 'Huangxi', 'Huangxi,Huangxi Zhen,huang xi,huang xi zhen,潢溪,潢溪镇', 28.3340800, 116.8767000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21417, 'Huangzhuang', 'Huangzhuang', 'Huangzhuang,Huangzhuang Xiang,huang zhuang,huang zhuang xiang,黄庄,黄庄乡', 28.4772800, 116.9516500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21418, 'Hutang', 'Hutang', 'Hutang,Hutang Xiang,hu tang,hu tang xiang,湖塘,湖塘乡', 28.3236200, 115.6121100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21419, 'Huxu', 'Huxu', 'Huxu,Huxu Xiang,hu wei,hu wei xiang,虎圩,虎圩乡', 28.1770200, 116.5744800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21420, 'Jiaokeng', 'Jiaokeng', 'Jiaokeng,Jiaokeng Xiang,jiao keng,jiao keng xiang,蕉坑,蕉坑乡', 27.7557200, 115.8160500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21421, 'Jingkou', 'Jingkou', 'Jingkou,Jingkou Xiang,Jingkoujie,jing kou,jing kou xiang,泾口,泾口乡', 28.6514800, 116.1605700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21422, 'Jinqiao', 'Jinqiao', 'Jinqiao,Jinqiao Xiang,jin qiao,jin qiao xiang,金桥,金桥乡', 28.9699400, 115.9085100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21423, 'Jinshanzui', 'Jinshanzui', 'Jinshanzui,Jinshanzui Xiang,jin shan zui,jin shan zui xiang,金山嘴,金山嘴乡', 28.7335100, 116.5603300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21424, 'Lehua', 'Lehua', 'Lehua,Lehua Zhen,Lehuajie,le hua,le hua zhen,乐化,乐化镇', 28.8210500, 115.8648900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21425, 'Liancheng', 'Liancheng', 'Liancheng,Liancheng Xiang,lian cheng,lian cheng xiang,连城,连城乡', 27.8925600, 116.3071500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21426, 'Liugongmiao', 'Liugongmiao', 'Liugongmiao,Liugongmiao Zhen,liu gong miao,liu gong miao zhen,刘公庙,刘公庙镇', 28.1105300, 115.3057400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21427, 'Liuhu', 'Liuhu', 'Liuhu,Liuhu Xiang,Liuhujie,liu hu,liu hu xiang,流湖,流湖乡', 28.4697500, 115.7218900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21428, 'Longhushan', 'Longhushan', 'Longhushan,Longhushan Zhen,long hu shan,long hu shan zhen,龙虎山,龙虎山镇', 28.1234600, 116.9759200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21429, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,Longtanqiaojie,long tan,long tan zhen,龙潭,龙潭镇', 28.3925900, 115.2372700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21430, 'Longxi', 'Longxi', 'Longxi,Longxi Zhen,long xi,long xi zhen,龙溪,龙溪镇', 27.7139900, 116.2878700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21431, 'Lufang', 'Lufang', 'Lufang,Lufang Xiang,lu fang,lu fang xiang,陆坊,陆坊乡', 28.0104800, 116.8205500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21432, 'Luoshi', 'Luoshi', 'Luoshi,Luoshi Zhen,luo shi,luo shi zhen,洛市,洛市镇', 27.9922500, 115.8296500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21433, 'Luoting', 'Luoting', 'Luoting,Luoting Zhen,luo ting,luo ting zhen,罗亭,罗亭镇', 28.8901200, 115.7870700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21434, 'Luozhen', 'Luozhen', 'Luozhen,Luozhen Zhen,luo zhen,luo zhen zhen,罗针,罗针镇', 28.1204800, 116.2627300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21435, 'Lusigang', 'Lusigang', 'Lusigang,Lusigang Xiang,lu si gang,lu si gang xiang,鹭鸶港,鹭鸶港乡', 28.7543300, 116.6498300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21436, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Zhen,Ma''anping,Ma’an,Ma’an Zhen,Ma’anping,ma an,ma an zhen,马安,马安镇', 27.7412600, 115.9043800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21437, 'Mahong', 'Mahong', 'Mahong,Mahong Xiang,ma hong,ma hong xiang,马洪,马洪乡', 27.9190700, 115.0175300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21438, 'Maopai', 'Maopai', 'Maopai,Maopai Xiang,mao pai,mao pai xiang,茅排,茅排乡', 27.6246100, 116.5051700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21439, 'Maqiu', 'Maqiu', 'Maqiu,Maqiu Zhen,Maqiujie,ma qiu,ma qiu zhen,麻丘,麻丘镇', 28.6710900, 116.0784200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21440, 'Meiling', 'Meiling', 'Meiling,Meiling Zhen,mei ling,mei ling zhen,梅岭,梅岭镇', 28.7922500, 115.7450200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21441, 'Nantai', 'Nantai', 'Nantai,Nantai Xiang,nan tai,nan tai xiang,南台,南台乡', 28.4915200, 116.4041900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21442, 'Pengzhou', 'Pengzhou', 'Pengzhou,Pengzhou Xiang,peng zhou,peng zhou xiang,鹏洲,鹏洲乡', 27.4920500, 115.7242500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21443, 'Qiaole', 'Qiaole', 'Qiaole,Qiaole Xiang,qiao le,qiao le xiang,乔乐,乔乐乡', 28.6441400, 115.5637500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21444, 'Qidu', 'Qidu', 'Qidu,Qidu XIang,qi dou,qi dou xiang,七都,七都乡', 27.2756000, 115.5563100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21445, 'Qiligang', 'Qiligang', 'Qiligang,Qiligang Xiang,qi li gang,qi li gang xiang,七里岗,七里岗乡', 28.0097000, 116.4241600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21446, 'Qingyun', 'Qingyun', 'Qingyun,Qingyun Zhen,qing yun,qing yun zhen,青云,青云镇', 28.6620800, 116.9247200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21447, 'Quanling', 'Quanling', 'Quanling,Quanling Xiang,quan ling,quan ling xiang,泉岭,泉岭乡', 28.3779900, 116.0720200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21448, 'Raobu', 'Raobu', 'Raobu,Raobu Zhen,rao bu,rao bu zhen,饶埠,饶埠镇', 28.8785900, 116.9472800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21449, 'Raofeng', 'Raofeng', 'Raofeng,Raofeng Zhen,Raofengzonghekenzhichang,rao feng,rao feng zhen,饶丰,饶丰镇', 28.9563900, 116.8194400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21450, 'Rongtang', 'Rongtang', 'Rongtang,Rongtang Zhen,rong tang,rong tang zhen,荣塘,荣塘镇', 28.1086200, 115.7151600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21451, 'Sangtian', 'Sangtian', 'Sangtian,Sangtian Zhen,sang tian,sang tian zhen,桑田,桑田镇', 27.1257800, 116.5666600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21452, 'Sanshan', 'Sanshan', 'Sanshan,Sanshan Xiang,Sanshanmiao,san shan,san shan xiang,三山,三山乡', 27.8419800, 115.9877100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21453, 'Shanghu', 'Shanghu', 'Shanghu,Shanghu Xiang,Shanghuxu,shang hu,shang hu xiang,上湖,上湖乡', 28.3465900, 115.3274200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21454, 'Shuangcun', 'Shuangcun', 'Shuangcun,Shuangcun Zhen,shuang cun,shuang cun zhen,双村,双村镇', 27.3938600, 115.2181400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21455, 'Songhu', 'Songhu', 'Songhu,Songhu Xiang,song hu,song hu xiang,嵩湖,嵩湖乡', 27.9080500, 116.4742100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21456, 'Sundu', 'Sundu', 'Sundu,Sundu Zhen,Sunjiadu,sun du,sun du zhen,孙渡,孙渡镇', 28.1395000, 115.7649500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21457, 'Tacheng', 'Tacheng', 'Tacheng,Tacheng Xiang,Tachengjie,ta cheng,ta cheng xiang,塔城,塔城乡', 28.5067300, 116.0937300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21458, 'Tangang', 'Tangang', 'Tangang,Tangang Xiang,tan gang,tan gang xiang,潭港,潭港乡', 27.4171400, 115.7530500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21459, 'Taobei', 'Taobei', 'Taobei,Taobei Xiang,Taobeicun,tao bei,tao bei xiang,桃陂,桃陂乡', 27.6318800, 116.2704000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21460, 'Taohua', 'Taohua', 'Taohua,Taohua Zhen,tao hua,tao hua zhen,桃花,桃花镇', 28.6533800, 115.8730600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21461, 'Taoxi', 'Taoxi', 'Taoxi,Taoxi Xiang,Taoxijie,tao xi,tao xi xiang,桃溪,桃溪乡', 27.7823000, 115.5817200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21462, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Xiang,tao yuan,tao yuan xiang,桃源,桃源乡', 27.6375800, 116.0405500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21463, 'Tiannan', 'Tiannan', 'Tiannan,Tiannan Zhen,Tiannanxu,tian nan,tian nan zhen,田南,田南镇', 28.1067600, 115.1072700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21464, 'Tonglin', 'Tonglin', 'Tonglin,Tonglin Xiang,tong lin,tong lin xiang,桐林,桐林乡', 27.5122900, 115.4188000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21465, 'Wanchong', 'Wanchong', 'Wanchong,Wanchong Zhen,Wanchongjie,wan chong,wan chong zhen,万崇,万崇镇', 27.2127000, 115.7017500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21466, 'Wangcheng', 'Wangcheng', 'Wangcheng,Wangcheng Zhen,Wangchenggangjie,wang cheng,wang cheng zhen,望城,望城镇', 28.6733500, 115.7813800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21467, 'Wangjia', 'Wangjia', 'Wangjia,Wangjia Xiang,wang jia,wang jia xiang,汪家,汪家乡', 28.7090700, 116.9386000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21468, 'Wuyang', 'Wuyang', 'Wuyang,Wuyang Zhen,Wuyangjie,wu yang,wu yang zhen,武阳,武阳镇', 28.5187800, 116.0104500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21469, 'Xiangshan', 'Xiangshan', 'Xiangshan,Xiangshan Zhen,xiang shan,xiang shan zhen,象山,象山镇', 28.9534800, 115.9809700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21470, 'Xiangshan', 'Xiangshan', 'Xiangshan,Xiangshan Zhen,xiang shan,xiang shan zhen,相山,相山镇', 27.5570800, 116.0301100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21471, 'Xiaohuang', 'Xiaohuang', 'Xiaohuang,Xiaohuang Zhen,xiao huang,xiao huang zhen,小璜,小璜镇', 28.3122200, 116.7097200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21472, 'Xiaotang', 'Xiaotang', 'Xiaotang,Xiaotang Xiang,Xiaotangxu,xiao tang,xiao tang xiang,筱塘,筱塘乡', 28.2085300, 115.9120200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21473, 'Xixia', 'Xixia', 'Xixia,Xixia Zhen,xi xia,xi xia zhen,溪霞,溪霞镇', 28.8585500, 115.8432600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21474, 'Xufang', 'Xufang', 'Xufang,Xufang Xiang,xu fang,xu fang xiang,许坊,许坊乡', 27.6531700, 116.2187200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21475, 'Xushangqiao', 'Xushangqiao', 'Xushangqiao,Xushangqiao Zhen,wei shang qiao,wei shang qiao zhen,圩上桥,圩上桥镇', 28.2287900, 116.5463900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21476, 'Yanbei', 'Yanbei', 'Yanbei,Yanbei Zhen,yan bei,yan bei zhen,沿陂,沿陂镇', 27.3697400, 115.5323400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21477, 'Yangqiaodian', 'Yangqiaodian', 'Yangqiaodian,Yangqiaodian Zhen,yang qiao dian,yang qiao dian zhen,杨桥殿,杨桥殿镇', 28.3716100, 116.5418400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21478, 'Yangshan', 'Yangshan', 'Yangshan,Yangshan Xiang,yang shan,yang shan xiang,仰山,仰山乡', 28.7614700, 115.0287000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21479, 'Yangsi', 'Yangsi', 'Yangsi,Yangsi Xiang,yang si,yang si cun,杨泗,杨泗村', 28.9937800, 115.7555100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21480, 'Tianjingyuan', 'Tianjingyuan', 'Tianjingyuan,Tianjingyuan Xiang,tian jing yuan,tian jing yuan xiang,天井源,天井源乡', 27.5317100, 116.6473000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21481, 'Yaotian', 'Yaotian', 'Yaotian,Yaotian Zhen,Yaotianxu,yao tian,yao tian zhen,瑶田,瑶田镇', 27.1296400, 115.6207900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21482, 'Yaoxu', 'Yaoxu', 'Yaoxu,Yaoxu Xiang,Yaoxujie,yao wei,yao wei xiang,瑶圩,瑶圩乡', 28.1096000, 116.7931100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21483, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Zhen,yong he,yong he zhen,永和,永和镇', 27.0311100, 115.0146900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21484, 'Yuandu', 'Yuandu', 'Yuandu,Yuandu Zhen,yuan du,yuan du zhen,袁渡,袁渡镇', 28.2636400, 116.0472400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21485, 'Zhangxiang', 'Zhangxiang', 'Zhangjiaxiang,Zhangxiang,Zhangxiang Zhen,zhang xiang,zhang xiang zhen,张巷,张巷镇', 28.1496100, 115.9130800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21486, 'Zhangshan', 'Zhangshan', 'Zhangshan,Zhangshan Zhen,zhang shan,zhang shan zhen,樟山,樟山镇', 27.1849500, 115.0440800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21487, 'Zhanxu', 'Zhanxu', 'Zhanxu,Zhanxu Zhen,zhan wei,zhan wei zhen,詹圩,詹圩镇', 28.2201100, 116.4236300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21488, 'Zhaobu', 'Zhaobu', 'Zhaobu,Zhaobu Xiang,zhao bu,zhao bu xiang,赵埠,赵埠乡', 28.5699600, 116.2624800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21489, 'Zhenkou', 'Zhenkou', 'Zhenkou,Zhenkou Xiang,Zhenkoucun,zhen kou,zhen kou xiang,圳口,圳口乡', 27.3987900, 116.3428700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21490, 'Zuofang', 'Zuofang', 'Zuofang,Zuofang Xiang,zuo fang,zuo fang xiang,左坊,左坊乡', 27.8232800, 116.7509100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21491, 'Changping', 'Changping', 'Changping,Changping Xiang,chang ping,chang ping xiang,常平,常平乡', 35.2408300, 112.9266700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21492, 'Xingsha', 'Xingsha', 'Changsha Xian,Xingsha,xing sha,zhang sha xian,星沙,长沙县', 28.2397200, 113.0877800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21493, 'Beizhouzi', 'Beizhouzi', 'Beizhouzi,Beizhouzi Nongchang,Beizhouzi Zhen,bei zhou zi,bei zhou zi zhen,北洲子,北洲子镇', 29.1652800, 112.6875000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21494, 'Chating', 'Chating', 'Chating,Chating Zhen,cha ting,cha ting zhen,茶亭,茶亭镇', 28.4975000, 112.9261100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21495, 'Daweishan', 'Daweishan', 'Daweishan,Daweishan Zhen,da wei shan,da wei shan zhen,大围山,大围山镇', 28.4618600, 114.0078500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21496, 'Dongjing', 'Dongjing', 'Dongjing,Dongjing Zhen,Dongjingpu,dong jing,dong jing zhen,洞井,洞井镇', 28.0873600, 113.0288100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21497, 'Dongtang', 'Dongtang', 'Dongtang,Dongtang Zhen,dong tang,dong tang zhen,东塘,东塘镇', 28.7775000, 112.9691700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21498, 'Fanjiayuan', 'Fanjiayuan', 'Fanjiayuan,Fanjiayuan Zhen,fan jia yuan,fan jia yuan zhen,范家园,范家园镇', 28.8855600, 113.0872200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21499, 'Guantouzui', 'Guantouzui', 'Guantouzui,Guantouzui Zhen,guan tou ju,guan tou ju zhen,罐头咀,罐头咀镇', 29.0526800, 112.0018400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21500, 'Heishanzui', 'Heishanzui', 'Heishanzui,Heishanzui Xiang,hei shan zui,hei shan zui xiang,黑山嘴,黑山嘴乡', 29.1118900, 112.0087300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21501, 'Heshan', 'Heshan', 'Heshan,Heshan Qu,he shan,he shan qu,赫山,赫山区', 28.5825000, 112.3502800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21502, 'Huangzhuzhou', 'Huangzhuzhou', 'Huangzhuzhou,Huangzhuzhou Xiang,huang zhu zhou,huang zhu zhou xiang,黄珠洲,黄珠洲乡', 29.1173900, 112.0846600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21503, 'Jiangjiazui', 'Jiangjiazui', 'Jiajiazhui Zhen,Jiangjiazui,jiang jia zui,jiang jia zui zhen,蒋家嘴,蒋家嘴镇', 28.8216700, 112.2211100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21504, 'Liulinzhou', 'Liulinzhou', 'Junshan,Junshan Nongchang,Junshan Qu,Liulinzhou,jun shan,jun shan qu,liu lin zhou,君山,君山区,柳林洲', 29.4563900, 113.0102800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21505, 'Longmen', 'Longmen', 'Longmen,Longmen Zhen,long men,long men zhen,龙门,龙门镇', 28.8090900, 114.0527600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21506, 'Muyun', 'Muyun', 'Muyun,Muyun Zhen,mu yun,mu yun zhen,暮云,暮云镇', 28.0333300, 112.9769400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21507, 'Yueyang', 'Yueyang', 'Juee-jang,Juehjan,Juejang,Jüe-jang,Ngok-yong-su,Ngo̍k-yòng-sṳ,Nhac Duong,Nhạc Dương,YUG,Yo Chau,Yochau,Yochow,Youchou,Youchow,weyang si,yue yang shi,Юэян,岳阳市,岳陽市,웨양 시', 29.3745500, 113.0948100, 'CN', '2015-11-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21508, 'Qiaokou', 'Qiaokou', 'Qiaokou,Qiaokou Zhen,qiao kou,qiao kou zhen,乔口,乔口镇', 28.5025000, 112.7333300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21509, 'Qiaoyi', 'Qiaoyi', 'Qiaoyi,Qiaoyi Zhen,qiao yi,qiao yi zhen,桥驿,桥驿镇', 28.4172200, 112.9202800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21510, 'Datong', 'Datong', 'Datong,Datong Xiang,Renyi,da tong,da tong xiang,大同,大同乡', 29.0608300, 112.4161100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21511, 'Sanchahe', 'Sanchahe', 'Sanchahe,Sanchahe Xiang,san cha he,san cha he xiang,三岔河,三岔河乡', 29.1177800, 112.2980600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21512, 'Qingtan', 'Qingtan', 'Qingtan,Qingtan Xiang,Shangshan,qing tan,qing tan xiang,青潭,青潭乡', 28.8597200, 112.8444400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21513, 'Shimeitang', 'Shimeitang', 'Shimeitang,Shimeitang Zhen,shi mei tang,shi mei tang zhen,十美堂,十美堂镇', 29.1936300, 112.0701700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21514, 'Sijihong', 'Sijihong', 'Sijihong,Sijihong Zhen,si ji hong,si ji hong zhen,四季红,四季红镇', 29.1061100, 112.5705600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21515, 'Songmutang', 'Songmutang', 'Songmutang,Songmutang Zhen,song mu tang,song mu tang zhen,松木塘,松木塘镇', 28.3188900, 112.0819400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21516, 'Tuanzhou', 'Tuanzhou', 'Tuanzhou,Tuanzhou Xiang,tuan zhou,tuan zhou xiang,团洲,团洲乡', 29.3325000, 112.7722200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21517, 'Cuiping', 'Cuiping', 'Cuiping,Cuiping Xiang,Xiatang,cui ping,cui ping xiang,崔坪,崔坪乡', 28.2408600, 112.0997500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21518, 'Baisha', 'Baisha', 'Baisha,Baisha Xiang,Ximing,bai sha,bai sha xiang,白沙,白沙乡', 28.9438900, 112.3791700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21519, 'Xinhe', 'Xinhe', 'Xinhe,Xinhe Xiang,Xinhekou,xin he,xin he xiang,新河,新河乡', 29.4269400, 112.5197200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21520, 'Xintang', 'Xintang', 'Xintang,Xintang Xiang,Xintangwu,xin tang,xin tang xiang,新塘,新塘乡', 28.9997200, 113.0341700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21521, 'Yuejiaqiao', 'Yuejiaqiao', 'Yuejiaqiao,Yuejiaqiao Zhen,yue jia qiao,yue jia qiao zhen,岳家桥,岳家桥镇', 28.3297400, 112.4365800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21522, 'Yujia’ao', 'Yujia''ao', 'Yujia''ao,Yujia''ao Xiang,Yujia’ao,Yujia’ao Xiang,yu jia ao,yu jia ao xiang,喻家坳,喻家坳乡', 28.1940800, 112.2626000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21523, 'Yuhua', 'Yuhua', 'Yuhua,Yuhua Xiang,Yushiqiao,yu hua,yu hua xiang,玉华,玉华乡', 28.5811100, 112.9533300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21524, 'Zhonghekou', 'Zhonghekou', 'Zhonghekou,Zhonghekou Zhen,zhong he kou,zhong he kou zhen,中河口,中河口镇', 29.3218100, 111.9875900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21525, 'Zhouwenmiao', 'Zhouwenmiao', 'Zhouwenmiao,Zhouwenmiao Xiang,zhou wen miao,zhou wen miao xiang,周文庙,周文庙乡', 28.9121000, 112.0517000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21526, 'Yanwukou', 'Yanwukou', 'Yanwukou,Yanwukou Xiang,yan wu kou,yan wu kou xiang,岩屋口,岩屋口乡', 29.5013800, 109.9164600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21527, 'Shigaoshan', 'Shigaoshan', 'Shigao,Shigao Zhen,Shigaoshan,shi gao shan,shi gao zhen,石羔山,石羔镇', 29.5135800, 109.4653200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21528, 'Xincheng', 'Xincheng', 'Xincheng,Xincheng Xiang,xin cheng,xin cheng xiang,新城,新城乡', 29.4620700, 109.4582600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21529, 'Bixidong', 'Bixidong', 'Bixi,Bixidong,Bixidong Xiang,bi xi dong,bi xi dong xiang,比溪洞,比溪洞乡', 29.3841400, 109.6881100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21530, 'Xiluo', 'Xiluo', 'Xiluo,Xiluo Xiang,xi luo,xi luo xiang,洗洛,洗洛乡', 29.4086600, 109.4664700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21531, 'Cengjiawan', 'Cengjiawan', 'Baiyang Xiang,Cengjiawan,bai yang xiang,ceng jia wan,曾家湾,白羊乡', 29.4204900, 109.3750700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21532, 'Longzui', 'Longzui', 'Longju,Longzui,Wantang Xiang,long zui,wan tang xiang,湾塘乡,龙嘴', 29.3342500, 109.3672200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21533, 'Xinzhaipo', 'Xinzhaipo', 'Liaoye,Xinzhaipo,liao ye,xin zhai po,新寨坡,辽叶', 29.2847800, 109.4224500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21534, 'Shangdongjie', 'Shangdongjie', 'Shandongjie Xiang,Shangdongjie,shang dong jie,shang dong jie xiang,上洞街,上洞街乡', 29.3297200, 109.9873800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21535, 'Xinchang', 'Xinchang', 'Xinchang,Yanjing Xiang,xin chang,yan jing xiang,新场,盐井乡', 29.2581000, 109.7304500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21536, 'Chenzhouzhai', 'Chenzhouzhai', 'Chenzhouzhai,Wafang Xiang,chen zhou zhai,wa fang xiang,瓦房乡,辰州寨', 29.2734200, 109.4632000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21537, 'Luotache', 'Luotache', 'Luota Xiang,Luotache,luo ta che,luo ta xiang,洛塔乡,洛塔车', 29.2086800, 109.5226600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21538, 'Laoxingchang', 'Laoxingchang', 'Laoxing,Laoxing Xiang,Laoxingchang,lao xing chang,lao xing xiang,老兴乡,老兴场', 29.1558400, 109.3431100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21539, 'Guitangba', 'Guitangba', 'Guitang,Guitang Zhen,Guitangba,gui tang,gui tang ba,gui tang zhen,桂塘,桂塘坝,桂塘镇', 29.1092200, 109.2592700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21540, 'Fengxizhai', 'Fengxizhai', 'Fengxi Xiang,Fengxizhai,feng xi xiang,feng xi zhai,凤溪乡,凤溪寨', 29.0069000, 109.4455400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21541, 'Mengxihu', 'Mengxihu', 'Mengxi Xiang,Mengxihu,meng xi hu,meng xi xiang,猛溪乡,猛溪湖', 29.1219600, 109.4775800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21542, 'Xishaping', 'Xishaping', 'Ganxi Xiang,Xishaping,gan xi xiang,xi sha ping,干溪乡,细砂坪', 29.1425700, 109.5283000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21543, 'Liandonggang', 'Liandonggang', 'Liandong,Liandong Xiang,Liandonggang,lian dong gang,lian dong xiang,连洞乡,连洞岗', 29.0075100, 109.8822700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21544, 'Guancangping', 'Guancangping', 'Cangping,Cangping Xiang,Guancangping,cang ping,cang ping xiang,guan cang ping,仓坪,仓坪乡,官仓坪', 29.1821600, 109.9186400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21545, 'Yanbanpu', 'Yanbanpu', 'Wanfu Xiang,Yanbanpu,wan fu xiang,yan ban pu,万福乡,岩板铺', 29.0914600, 109.8327300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21546, 'Cheping', 'Cheping', 'Cheping,Cheping Xiang,che ping,che ping xiang,车坪,车坪乡', 29.1544400, 110.0025000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21547, 'Yanchi', 'Yanchi', 'Yanchi,Yanchi Xiang,Yanchiping,yan chi,yan chi ping,yan chi xiang,雁池,雁池乡,雁池坪', 29.7992200, 110.9298800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21548, 'Baishi', 'Baishi', 'Baishi,Baishi Xiang,bai shi,bai shi xiang,白石,白石乡', 29.7035800, 110.5852100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21549, 'Zhenjiatai', 'Zhenjiatai', 'Changtanping Xiang,Zhenjiatai,zhang tan ping xiang,zhen jia tai,甄家台,长潭坪乡', 29.6928800, 110.4753300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21550, 'Linxihe', 'Linxihe', 'Linxihe,Linxihe Baizuxiang,lin xi he,lin xi he bai zu xiang,淋溪河,淋溪河白族乡', 29.6324200, 110.3713400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21551, 'Bamaoxi', 'Bamaoxi', 'Bamaoxi,Bamaoxi Xiang,ba mao xi,ba mao xi xiang,芭茅溪,芭茅溪乡', 29.6738400, 110.0248700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21552, 'Sifangxi', 'Sifangxi', 'Sifangxi,Sifangxi Xiang,xi fang xi,xi fang xi xiang,西方溪,西方溪乡', 29.6595400, 110.1687600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21553, 'Zhangjiaqiao', 'Zhangjiaqiao', 'Qiaoziwan Xiang,Zhangjiaqiao,qiao zi wan xiang,zhang jia qiao,张家桥,桥自湾乡', 29.5068500, 110.1420200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21554, 'Xianchiyu', 'Xianchiyu', 'Mihu,Mihu Xiang,Xianchiyu,mi hu,mi hu xiang,xian chi yu,咸池峪,汨湖,汨湖乡', 29.4639200, 110.4714000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21555, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Xiang,qiao tou,qiao tou xiang,桥头,桥头乡', 29.3469900, 110.2832500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21556, 'Shanmuqiao', 'Shanmuqiao', 'Shanmuqiao,Shanmuqiao Zhen,shan mu qiao,shan mu qiao zhen,杉木桥,杉木桥镇', 29.5381100, 110.9321500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21557, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Tujiazu Xiang,Tanjiaqiao,gao feng,gao feng tu jia zu xiang,qin jia qiao,覃家桥,高峰,高峰土家族乡', 29.4368300, 110.9170800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21558, 'Xujiafang', 'Xujiafang', 'Xujiafang,Xujiafang Tujiazuxiang,xu jia fang,xu jia fang tu jia zu xiang,许家坊,许家坊土家族乡', 29.2436900, 110.6546800, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21559, 'Qing’anping', 'Qing''anping', 'Qing''anping,Qing''anping Xiang,Qing’anping,Qing’anping Xiang,qing an ping,qing an ping xiang,青安坪,青安坪乡', 29.2808300, 110.1550400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21560, 'Daming', 'Daming', 'Daming,Daming Xiang,da ming,da ming xiang,大明,大明乡', 29.1078300, 110.0511500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21561, 'Chexi', 'Chexi', 'Chexi,Runya,Runya Xiang,che xi,run ya,run ya xiang,润雅,润雅乡,澈溪', 29.1152600, 110.1671800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21562, 'Shuangxiqiao', 'Shuangxiqiao', 'Shuangxiqiao,Shuangxiqiao Xiang,shuang xi qiao,shuang xi qiao xiang,双溪桥,双溪桥乡', 29.0256300, 110.6393700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21563, 'Sigangtou', 'Sigangtou', 'Jinyan,Jinyan Tujiazuxiang,Sigangtou,jin yan,jin yan tu jia zu xiang,si gang tou,寺岗头,金岩,金岩土家族乡', 29.1767200, 110.6749900, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21564, 'Wangjiaping', 'Wangjiaping', 'Wangjiaping,Wangjiaping Zhen,wang jia ping,wang jia ping zhen,王家坪,王家坪镇', 29.0443900, 110.8151600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21565, 'Nanshanping', 'Nanshanping', 'Nanshanping,Nanshanping Xiang,nan shan ping,nan shan ping xiang,南山坪,南山坪乡', 29.3174600, 110.8941100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21566, 'Huolianpo', 'Huolianpo', 'Huolianpo,Huolianpo Zhen,huo lian po,huo lian po zhen,火连坡,火连坡镇', 29.8837100, 111.4532300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21567, 'Fuxingchang', 'Fuxingchang', 'Fuxing,Fuxingchang,Fuxingchang Zhen,fu xing chang,fu xing chang zhen,复兴厂,复兴厂镇', 29.8343800, 111.8456000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21568, 'Shuanglong', 'Shuanglong', 'Shuanglong,Shuanglong Xiang,Shunlinqiao,shuang long,shuang long xiang,shun lin qiao,双龙,双龙乡,顺林桥', 29.8193800, 111.8986800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21569, 'Leigongta', 'Leigongta', 'Leigongta,Leigongta Zhen,lei gong ta,lei gong ta zhen,雷公塔,雷公塔镇', 29.7926900, 111.7692700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21570, 'Cennan', 'Cennan', 'Cengjiahe,Cennan,Cennan Xiang,cen nan,cen nan xiang,ceng jia he,曾家河,涔南,涔南乡', 29.7499300, 111.7687700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21571, 'Zhongwu', 'Zhongwu', 'Zhongwu,Zhongwu Xiang,Zhongwuqiao,zhong wu,zhong wu qiao,zhong wu xiang,中武,中武乡,中武桥', 29.7747200, 111.6725000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21572, 'Jinluo', 'Jinluo', 'Jinluo,Jinluo Zhen,jin luo,jin luo zhen,金罗,金罗镇', 29.8097000, 111.5981200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21573, 'Sansheng', 'Sansheng', 'Sansheng,Sansheng Xiang,Sanshengmiao,san sheng,san sheng miao,san sheng xiang,三圣,三圣乡,三圣庙', 29.8070900, 111.2475700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21574, 'Yangjiafang', 'Yangjiafang', 'Yangjiafang,Yangjiafang Xiang,yang jia fang,yang jia fang xiang,杨家坊,杨家坊乡', 29.7556900, 111.3575300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21575, 'Jiuli', 'Jiuli', 'Jiuli,Jiuli Xiang,Lishankou,jiu li,jiu li xiang,li shan kou,九里,九里乡,栗山口', 29.6946800, 111.5857000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21576, 'Daping', 'Daping', 'Daping,Daping Xiang,Zhoujiapo,da ping,da ping xiang,zhou jia po,周家坡,大坪,大坪乡', 29.6611100, 111.6436100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21577, 'Yongfeng', 'Yongfeng', 'Meijiagang,Meijiaxiang,Yongfeng,Yongfeng Xiang,mei jia xiang,yong feng,yong feng xiang,梅家巷,永丰,永丰乡', 29.6841300, 111.9382500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21578, 'Xiaodukou', 'Xiaodukou', 'Xiaodukou,Xiaodukou Zhen,xiao du kou,xiao du kou zhen,小渡口,小渡口镇', 29.6283300, 111.9122200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21579, 'Jiuyuan', 'Jiuyuan', 'Ganjiawan,Jiuyuan,Jiuyuan Xiang,gan jia wan,jiu yuan,jiu yuan xiang,九垸,九垸乡,甘家湾', 29.5661300, 111.9204600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21580, 'Lijiapu', 'Lijiapu', 'Lijiapu,Lijiapu Xiang,li jia pu,li jia pu xiang,李家铺,李家铺乡', 29.4970100, 111.9193000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21581, 'Baohedi', 'Baohedi', 'Baohedi,Baohedi Zhen,bao he di,bao he di zhen,保河堤,保河堤镇', 29.4049600, 111.9906000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21582, 'Lingquan', 'Lingquan', 'Lingquan,Lingquan Xiang,Wuquanpu,ling quan,ling quan xiang,wu quan pu,五泉铺,灵泉,灵泉乡', 29.5280600, 111.8236100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21583, 'Li’nan', 'Li''nan', 'Li''nan,Li''nan Xiang,Liujiahe,Li’nan,Li’nan Xiang,li nan,li nan xiang,liu jia he,刘家河,澧南,澧南乡', 29.6174900, 111.7561100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21584, 'Zhanggongmiao', 'Zhanggongmiao', 'Zhanggongmiao,Zhanggongmiao Zhen,zhang gong miao,zhang gong miao zhen,张公庙,张公庙镇', 29.6019500, 111.6467000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21585, 'Yangban', 'Yangban', 'Yangban,Yangban Xiang,Yangbanqiao,yang ban,yang ban qiao,yang ban xiang,杨板,杨板乡,杨板桥', 29.5299600, 111.6907500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21586, 'Fenghuo', 'Fenghuo', 'Fenghuo,Fenghuo Xiang,Guanyin''an,Guanyin’an,feng huo,feng huo xiang,guan yin an,烽火,烽火乡,观音庵', 29.4587600, 111.7477300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21587, 'Sixingang', 'Sixingang', 'Sixingang,Sixingang Zhen,si xin gang,si xin gang zhen,四新岗,四新岗镇', 29.3596400, 111.6359100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21588, 'Leigongmiao', 'Leigongmiao', 'Leigongmiao,Leigongmiao Zhen,lei gong miao,lei gong miao zhen,雷公庙,雷公庙镇', 29.2564700, 111.6178300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21589, 'Changlinggang', 'Changlinggang', 'Changlinggang,Changlinggang Xiang,zhang ling gang,zhang ling gang xiang,长岭岗,长岭岗乡', 29.2332000, 111.6929400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21590, 'Taifu', 'Taifu', 'Taifu,Taifu Zhen,Yansi''an,Yansi’an,tai fu,tai fu zhen,yan si an,太浮,太浮镇,衍嗣庵', 29.2891200, 111.5856200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21591, 'Wenjia', 'Wenjia', 'Wenjia,Wenjia Xiang,Wenjiadian,wen jia,wen jia dian,wen jia xiang,文家,文家乡,文家店', 29.3805500, 111.5446900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21592, 'Shanban', 'Shanban', 'Shanban,Shanban Xiang,Shanbanqiao,shan ban,shan ban qiao,shan ban xiang,杉板,杉板乡,杉板桥', 29.5570700, 111.5263200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21593, 'Xinguan', 'Xinguan', 'Xinguan,Xinguan Zhen,xin guan,xin guan zhen,新关,新关镇', 29.6196900, 111.3073300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21594, 'Mazongling', 'Mazongling', 'Mazongling,Mazongling Xiang,ma zong ling,ma zong ling xiang,马鬃岭,马鬃岭乡', 29.2406500, 111.4556200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21595, 'Haoping', 'Haoping', 'Haoping,Haoping Xiang,hao ping,hao ping xiang,郝坪,郝坪乡', 29.2750500, 111.2713300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21596, 'Erfangping', 'Erfangping', 'Erfangping,Erfangping Xiang,er fang ping,er fang ping xiang,二方坪,二方坪乡', 29.2883300, 111.1938900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21597, 'Lingxi', 'Lingxi', 'Lingxi,Lingxi Zhen,ling xi,ling xi zhen,零溪,零溪镇', 29.3708200, 111.1741000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21598, 'Wuxihe', 'Wuxihe', 'Longtanqiao,Wuxihe,Wuxihe Xiang,long tan qiao,wu xi he,wu xi he xiang,浯溪河,浯溪河乡,龙潭桥', 29.0228300, 111.4144000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21599, 'Fengshu', 'Fengshu', 'Fengshu,Fengshu Wewuerzu Huizuxiang,Zhuangjiaqiao,feng shu,feng shu wei wu er zu hui zu xiang,zhuang jia qiao,庄家桥,枫树,枫树维吾尔族回族乡', 29.0158300, 111.4890200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21600, 'Mutangyuan', 'Mutangyuan', 'Mutangyuan,Mutangyuan Xiang,Sanchagang,mu tang yuan,mu tang yuan xiang,san cha gang,三汊港,木塘垸,木塘垸乡', 29.0157300, 111.5495100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21601, 'Huangjiapu', 'Huangjiapu', 'Huangjiapu,Huangjiapu Xiang,huang jia pu,huang jia pu xiang,黄甲铺,黄甲铺乡', 29.1132600, 111.2875700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21602, 'Guanxi', 'Guanxi', 'Guanxi,Guanxi Zhen,Guanxisi,guan xi,guan xi si,guan xi zhen,灌溪,灌溪寺,灌溪镇', 29.1121500, 111.6164700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21603, 'Caijiagang', 'Caijiagang', 'Caijiagang,Caijiagang Zhen,Yancun''an,Yancun’an,cai jia gang,cai jia gang zhen,yan cun an,延存庵,蔡家岗,蔡家岗镇', 29.1888300, 111.6182100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21604, 'Baiheshan', 'Baiheshan', 'Baiheshan,Baiheshan Xiang,Wanjin,Wanjinzhang,bai he shan,bai he shan xiang,wan jin zhang,万金障,白鹤山,白鹤山乡', 29.1127800, 111.8088900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21605, 'Fangshiping', 'Fangshiping', 'Fangshiping,Fangshiping Zhen,fang shi ping,fang shi ping zhen,方石坪,方石坪镇', 29.8010400, 111.4376500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21606, 'Fuzhiping', 'Fuzhiping', 'Fuzhi Xiang,Fuzhiping,fu zhi ping,fu zhi xiang,抚志乡,抚志坪', 28.8955600, 109.9233300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21607, 'Liexi', 'Liexi', 'Liexi,Liexi Xiang,lie xi,lie xi xiang,列夕,列夕乡', 28.7861100, 109.8323800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21608, 'Xiqi', 'Xiqi', 'Xiqi,Xiqi Xiang,xi qi,xi qi xiang,西岐,西岐乡', 28.9821400, 109.6663600, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21609, 'Heping', 'Heping', 'Heping,Heping Xiang,Yanjing,he ping,he ping xiang,和平,和平乡', 28.9346400, 109.7294400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21610, 'Duishan', 'Duishan', 'Duishan,Duishan Xiang,Duishanzhai,dui shan,dui shan xiang,对山,对山乡', 28.9110200, 109.6583800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21611, 'Pojiao', 'Pojiao', 'Pojiao,Pojiao Xiang,po jiao,po jiao xiang,坡脚,坡脚乡', 28.8898600, 109.5317500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21612, 'Miao’ertan', 'Miao''ertan', 'Miao''ertan,Miao''ertan Zhen,Miao’ertan,Miao’ertan Zhen,miao r tan,miao r tan zhen,苗儿滩,苗儿滩镇', 28.9499000, 109.4731000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21613, 'Yanchong', 'Yanchong', 'Shumudong,Yanchong,Yanchong Xiang,yan chong,yan chong xiang,岩冲,岩冲乡', 28.8071100, 109.3421000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21614, 'Changtan', 'Changtan', 'Changtan,Changtan Xiang,zhang tan,zhang tan xiang,长潭,长潭乡', 28.8161100, 109.3097200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21615, 'Bamian', 'Bamian', 'Bamian,Bamian Xiang,Chujiawan,ba mian,ba mian xiang,八面,八面乡', 28.8883300, 109.2541700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21616, 'Mawang', 'Mawang', 'Mawang,Mawang Xiang,ma wang,ma wang xiang,马王,马王乡', 28.7726300, 109.4011100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21617, 'Yezhuping', 'Yezhuping', 'Yezhuping,Yezhuping Zhen,ye zhu ping,ye zhu ping zhen,野竹坪,野竹坪镇', 28.6751400, 109.2934400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21618, 'Tuanjie', 'Tuanjie', 'Tuanjie,Tuanjie Zhen,tuan jie,tuan jie zhen,团结,团结镇', 28.5487500, 109.3773300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21619, 'Longtan', 'Longtan', 'Longtan,Longtan Zhen,long tan,long tan zhen,龙潭,龙潭镇', 28.4891000, 109.3923500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21620, 'Mao’er', 'Mao''er', 'Mao''er,Mao''er Xiang,Mao''erzhai,Mao’er,Mao’er Xiang,Mao’erzhai,mao r,mao r xiang,猫儿,猫儿乡', 28.4225900, 109.3573200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21621, 'Paiwu', 'Paiwu', 'Paiwu,Paiwu Xiang,Xiaopaiwu,pai wu,pai wu xiang,排吾,排吾乡', 28.3654300, 109.4091000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21622, 'Pailiao', 'Pailiao', 'Pailiao,Pailiao Xiang,pai liao,pai liao xiang,排料,排料乡', 28.3762900, 109.6042400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21623, 'Jilue', 'Jilue', 'Jilue,Jilue Xiang,Longwu,ji e,ji e xiang,long wu,己略,己略乡,龙舞', 28.3627200, 109.7103400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21624, 'Dongmaku', 'Dongmaku', 'Dongmaku,Dongmaku Xiang,dong ma ku,dong ma ku xiang,董马库,董马库乡', 28.4319800, 109.5655500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21625, 'Morong', 'Morong', 'Morong,Morong Zhen,mo rong,mo rong zhen,默戎,默戎镇', 28.4887800, 109.8475700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21626, 'Woshao', 'Woshao', 'Woshao,Woshao Xiang,wo shao,wo shao xiang,窝勺,窝勺乡', 28.5043100, 109.4811800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21627, 'Dao’er', 'Dao''er', 'Dao''er,Dao''er Xiang,Dao’er,Dao’er Xiang,Jianshan,dao er,dao er xiang,道二,道二乡', 28.5152300, 109.4405500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21628, 'Qingshui', 'Qingshui', 'Hebian,Qingshui,Qingshui Xiang,qing shui,qing shui xiang,清水,清水乡', 28.6001200, 109.4819300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21629, 'Boji', 'Boji', 'Boji,Boji Xiang,Yanbian,bo ji,bo ji xiang,簸箕,簸箕乡', 28.6144000, 109.4018000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21630, 'Datuo', 'Datuo', 'Datuo,Datuo Xiang,da tuo,da tuo xiang,大妥,大妥乡', 28.6764200, 109.4670600, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21631, 'Longxi', 'Longxi', 'Longxi,Longxi Zhen,Ruxiangyan,long xi,long xi zhen,龙溪,龙溪镇', 28.7400800, 109.6670100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21632, 'Meihua', 'Meihua', 'Meihua,Meihua Xiang,mei hua,mei hua xiang,梅花,梅花乡', 28.7004400, 109.6583800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21633, 'Shuangxi', 'Shuangxi', 'Shuangxi,Shuangxi Xiang,Tangshang,shuang xi,shuang xi xiang,双溪,双溪乡', 28.6148800, 109.8806500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21634, 'Tuzha', 'Tuzha', 'Tuzha,Tuzha Xiang,tu zha,tu zha xiang,涂乍,涂乍乡', 28.5821000, 109.6930000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21635, 'Shuiyin', 'Shuiyin', 'Shuiyin,Shuiyin Xiang,shui yin,shui yin xiang,水银,水银乡', 28.5765200, 109.6358600, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21636, 'Baiyan', 'Baiyan', 'Baiyan,Baiyan Xiang,Xinzhaiping,bai yan,bai yan xiang,xin zhai ping,新寨坪,白岩,白岩乡', 28.4224100, 109.8510100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21637, 'Pingba', 'Pingba', 'Pingba,Pingba Xiang,Yutou,ping ba,ping ba xiang,坪坝,坪坝乡', 28.4086100, 109.9405600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21638, 'Shuangtang', 'Shuangtang', 'Shuangtang,Shuangtang Zhen,Zhoujiazhai,shuang tang,shuang tang zhen,双塘,双塘镇', 28.1935700, 109.7056000, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21639, 'Xiaozhang', 'Xiaozhang', 'Xiaotong,Xiaozhang,Xiaozhang Xiang,xiao zhang,xiao zhang xiang,小章,小章乡', 28.1271700, 109.8851200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21640, 'Qiaoxikou', 'Qiaoxikou', 'Paodongtan,Qiaoxikou,Qiaoxikou Xiang,pao dong tan,qiao xi kou,qiao xi kou xiang,桥溪口,桥溪口乡,泡洞潭', 28.0430900, 109.6827800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21641, 'Sangongqiao', 'Sangongqiao', 'Sangongqiao,Sangongqiao Xiang,san gong qiao,san gong qiao xiang,三拱桥,三拱桥乡', 28.1884300, 109.6479900, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21642, 'Zhaiyang', 'Zhaiyang', 'Zhaiyang,Zhaiyang Xiang,zhai yang,zhai yang xiang,寨阳,寨阳乡', 28.3098800, 109.6526900, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21643, 'Shetangpo', 'Shetangpo', 'Shetangpo,Shetangpo Xiang,she tang po,she tang po xiang,社塘坡,社塘坡乡', 28.2288600, 109.5986500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21644, 'Miliang', 'Miliang', 'Bake,Miliang,Miliang Xiang,ba ke,mi liang,mi liang xiang,米良,米良乡,芭科', 28.2438100, 109.5077200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21645, 'Dalongdong', 'Dalongdong', 'Dalongdong,Dalongdong Xiang,da long dong,da long dong xiang,大龙洞,大龙洞乡', 28.2787200, 109.4769300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21646, 'Yaxi', 'Yaxi', 'Hangdu,Yaxi,Yaxi Zhen,ya xi,ya xi zhen,雅西,雅西镇', 28.2012600, 109.3751200, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21647, 'Lianglin', 'Lianglin', 'Lianglin,Lianglin Xiang,liang lin,liang lin xiang,两林,两林乡', 28.1577900, 109.3838500, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21648, 'Liangtouyang', 'Liangtouyang', 'Guanzhuangping,Liangtouyang,Liangtouyang Xiang,guan zhuang ping,liang tou yang,liang tou yang xiang,两头羊,两头羊乡,官庄坪', 28.1273800, 109.4859800, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21649, 'Qiangongping', 'Qiangongping', 'Mashanxia,Qiangongping,Qiangongping Xiang,ma shan xia,qian gong ping,qian gong ping xiang,千工坪,千工坪乡,马山下', 28.0300700, 109.5018600, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21650, 'Shanjiang', 'Shanjiang', 'Shanjiang,Shanjiang Zhen,shan jiang,shan jiang zhen,山江,山江镇', 28.0465000, 109.4630300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21651, 'Banpan', 'Banpan', 'Banpan,Banpan Xiang,ban pan,ban pan xiang,板畔,板畔乡', 28.0050000, 109.4016700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21652, 'Canmang', 'Canmang', 'Canmang,Canmang Xiang,Canmangping,can mang,can mang ping,can mang xiang,蚕忙,蚕忙乡,蚕忙坪', 28.9192500, 110.8919900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21653, 'Nanmu', 'Nanmu', 'Nanmu,Nanmu Xiang,nan mu,nan mu xiang,南木,南木乡', 28.8809000, 110.9096200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21654, 'Luoping', 'Luoping', 'Luoping,Luoping Xiang,luo ping,luo ping xiang,落坪,落坪乡', 28.6825000, 110.5361100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21655, 'Siduping', 'Siduping', 'Siduping,Siduping Xiang,si dou ping,si dou ping xiang,四都坪,四都坪乡', 28.9305000, 110.4301000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21656, 'Shiziqiao', 'Shiziqiao', 'Shiziqiao,Yangfeng Xiang,shi zi qiao,yang feng,yang feng xiang,yangfeng,狮子桥,羊峰,羊峰乡', 28.9795800, 110.0685600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21657, 'Huilongan', 'Huilongan', 'Huilong,Huilong Xiang,Huilongan,hui long,hui long an,hui long xiang,回龙,回龙乡,回龙庵', 28.8893000, 110.1821900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21658, 'Baoping', 'Baoping', 'Baoping,Baoping Xiang,bao ping,bao ping xiang,保坪,保坪乡', 28.8227800, 110.0269400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21659, 'Shanzao', 'Shanzao', 'Shancaoxi,Shanzao,Shanzao Xiang,shan zao,shan zao xiang,山枣,山枣乡', 28.4691700, 110.0969400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21660, 'Baisha', 'Baisha', 'Baisha,Luxi Xian,bai sha,lu xi xian,泸溪县,白沙', 28.2197100, 110.2169500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21661, 'Kuixi', 'Kuixi', 'Kuixi,Kuixi Zhen,kui xi,kui xi zhen,奎溪,奎溪镇', 28.2335300, 110.8159100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21662, 'Shanxi', 'Shanxi', 'Shanxi,Shanxi Xiang,Shanxijiang,shan xi,shan xi xiang,善溪,善溪乡', 28.0316700, 110.9544400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21663, 'Yongping', 'Yongping', 'Yongping,Yongping Xiang,yong ping,yong ping xiang,用坪,用坪乡', 28.1527800, 110.3808300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21664, 'Chuanxi', 'Chuanxi', 'Chuanxi,Chuanxi Xiang,Chuanxiyi,chuan xi,chuan xi xiang,船溪,船溪乡', 28.1716700, 110.2608300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21665, 'Guanyinsi', 'Guanyinsi', 'Guanyinsi,Guanyinsi Zhen,guan yin si,guan yin si zhen,观音寺,观音寺镇', 28.9161700, 111.0854500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21666, 'Qinglin', 'Qinglin', 'Maocaojie,Qinglin,Qinglin Huizu Weiwu''erzuxiang,Qinglin Huizu Weiwu’erzuxiang,mao cao jie,qing lin,qing lin hui zu wei wu er zu xiang,茅草街,青林,青林回族维吾尔族乡', 28.9542600, 111.4689000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21667, 'Shenshuigang', 'Shenshuigang', 'Shenshuigang,Shenshuigang Xiang,Tongmugang,shen shui gang,shen shui gang xiang,tong mu gang,桐木港,深水港,深水港乡', 28.9159000, 111.3979100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21668, 'Xujiaqiao', 'Xujiaqiao', 'Majiaxiang,Xujiaqiao,Xujiaqiao Huizu Weiwu''erzuxiang,Xujiaqiao Huizu Weiwu’erzuxiang,ma jia xiang,xu jia qiao,xu jia qiao hui zu wei wu er zu xiang,许家桥,许家桥回族维吾尔族乡,麻家巷', 28.9136500, 111.5847600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21669, 'Dingjiagang', 'Dingjiagang', 'Dingjiagang,Dingjiagang Xiang,ding jia gang,ding jia gang xiang,丁家港,丁家港乡', 28.8805600, 111.5597200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21670, 'Changmaoling', 'Changmaoling', 'Changmaoling,Changmaoling Xiang,zhang mao ling,zhang mao ling xiang,长茅岭,长茅岭乡', 28.7861100, 111.6027800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21671, 'Siping', 'Siping', 'Siping,Siping Xiang,si ping,si ping xiang,寺坪,寺坪乡', 28.6902800, 111.2983300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21672, 'Guniushan', 'Guniushan', 'Guniushan,Guniushan Xiang,Sanjiang,gu niu shan,gu niu shan xiang,牯牛山,牯牛山乡', 28.5457000, 111.2614700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21673, 'Luhuatan', 'Luhuatan', 'Dujiabang,Luhuatan,Luhuatan Xiang,lu hua tan,lu hua tan xiang,芦花潭,芦花潭乡', 28.6683300, 111.4241700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21674, 'Luojiaping', 'Luojiaping', 'Luojiaping,Luojiaping Xiang,luo jia ping,luo jia ping xiang,罗家坪,罗家坪乡', 28.6023400, 111.7831500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21675, 'Qianjiaping', 'Qianjiaping', 'Qianjiaping,Qianjiaping Xiang,qian jia ping,qian jia ping xiang,钱家坪,钱家坪乡', 28.6611100, 111.7044400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21676, 'Xinxing', 'Xinxing', 'Xinxing,Xinxing Xiang,Zhoujiawan,xin xing,xin xing xiang,zhou jia wan,周家湾,新兴,新兴乡', 28.9572200, 111.8233200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21677, 'Weidihu', 'Weidihu', 'Cangerzong,Weidihu,Weidihu Xiang,cang r zong,wei di hu,wei di hu xiang,仓儿总,围堤湖,围堤湖乡', 28.9763500, 111.9621500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21678, 'Wuqishan', 'Wuqishan', 'Guojiawan,Wuqishan,Wuqishan Xiang,wu qi shan,wu qi shan xiang,乌旗山,乌旗山乡', 28.6386100, 111.9397200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21679, 'Maidiping', 'Maidiping', 'Maidiping,Maidiping Baizuxiang,mai de ping,mai de ping bai zu xiang,麦地坪,麦地坪白族乡', 29.4915500, 110.3585900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21680, 'Wuyahe', 'Wuyahe', 'Wuya Xiang,Wuyahe,wu ya he,wu ya xiang,乌鸦乡,乌鸦河', 29.5765200, 109.7124100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21681, 'Zanguoping', 'Zanguoping', 'Zanguo Xiang,Zanguoping,zan guo ping,zan guo xiang,咱果乡,咱果坪', 29.0262300, 109.3487700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21682, 'Yezhu', 'Yezhu', 'Yezhu,Yezhu Xiang,ye zhu,ye zhu xiang,野竹,野竹乡', 28.5527800, 110.0513900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21683, 'Bamao', 'Bamao', 'Bamao,Bamao Xiang,ba mao,ba mao xiang,拔茅,拔茅乡', 28.7663900, 109.4891700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21684, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Xiang,bai yang,bai yang xiang,柏杨,柏杨乡', 28.8072000, 109.7336300, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21685, 'Dashuitian', 'Dashuitian', 'Dashuitian,Dashuitian Xiang,da shui tian,da shui tian xiang,大水田,大水田乡', 27.4130600, 110.8152800, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21686, 'Huxingshan', 'Huxingshan', 'Huxingshan,Huxingshan Yaozuxiang,hu xing shan,hu xing shan yao zu xiang,虎形山,虎形山瑶族乡', 27.5488900, 110.6966700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21687, 'Nanyuemiao', 'Nanyuemiao', 'Nanyuemiao,Nanyuemiao Xiang,nan yue miao,nan yue miao xiang,南岳庙,南岳庙乡', 27.1273300, 110.8519300, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21688, 'Sangesi', 'Sangesi', 'Sangesi,Sangesi Xiang,san ge si,san ge si xiang,三阁司,三阁司乡', 27.0669400, 110.9544400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21689, 'Bojia', 'Bojia', '', 26.4672200, 111.9680600, 'CN', '2011-03-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21690, 'Qidi', 'Qidi', 'Chongtou,Qidi,Qidi Xiang,chong tou,qi de,qi de xiang,七地,七地乡,冲头', 26.9559200, 113.6613700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21691, 'Lingfang', 'Lingfang', 'Dizhou''ao,Dizhou’ao,Lingfang,Lingfang Xiang,di zhou ao,ling fang,ling fang xiang,堤州坳,舲舫,舲舫乡', 26.7257300, 113.6141500, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21692, 'Huanxi', 'Huanxi', 'Huanxi,Huanxi Zhen,Huanxixu,huan xi,huan xi wei,huan xi zhen,浣溪,浣溪圩,浣溪镇', 26.5637700, 113.6009600, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21693, 'Huju', 'Huju', 'Huju,Huju Shan,Huju Zhen,hu ju,hu ju shan,hu ju zhen,虎踞,虎踞山,虎踞镇', 26.9163900, 113.3900000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21694, 'Jiangkou', 'Jiangkou', 'Jiangkou,Jiangkou Xiang,jiang kou,jiang kou xiang,江口,江口乡', 26.6572300, 113.7971700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21695, 'Yatian', 'Yatian', 'Lijiawuchang,Yatian,Yatian Zhen,li jia wu chang,ya tian,ya tian zhen,鸭田,鸭田镇,黎家屋场', 27.5919400, 111.0144400, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21696, 'Beishan', 'Beishan', 'Beishan,Beishan Xiang,Niejiating,bei shan,bei shan xiang,nie jia ting,北山,北山乡,聂家亭', 27.0822500, 111.0881100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21697, 'Zhitang', 'Zhitang', 'Pengjiaci,Zhitang,Zhitang Xiang,peng jia ci,zhi tang,zhi tang xiang,彭家祠,秩堂,秩堂乡', 26.9433000, 113.8599700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21698, 'Shimen', 'Shimen', 'Choushuhuan,Shimen,Shimenxiang,chou shu yuan,shi men,shi men xiang,椆树垸,石门,石门乡', 27.2269400, 111.0300000, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21699, 'Xiaotian', 'Xiaotian', 'Chepili,Xiaotian,Xiaotian Xiang,che pi li,xiao tian,xiao tian xiang,小田,小田乡,车皮里', 26.8558700, 113.8374100, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21700, 'Batuan', 'Batuan', 'Batuan,Batuan Xiang,Yangjiawu,ba tuan,ba tuan xiang,yang jia wu,八团,八团乡,杨家屋', 27.0377800, 113.7216700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21701, 'Yaoshui', 'Yaoshui', 'Yaoshi,Yaoshui,Yaoshui Xiang,yao shi,yao shui,yao shui xiang,尧市,尧水,尧水乡', 26.8255400, 113.6849700, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21702, 'Yushanpu', 'Yushanpu', 'Yushanpu,Yushanpu Zhen,yu shan pu,yu shan pu zhen,雨山铺,雨山铺镇', 27.1505600, 111.1130600, 'CN', '2012-02-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21703, 'Sidu', 'Sidu', 'Sidu,Sidu Zhen,si dou,si dou zhen,四都,四都镇', 24.2154400, 115.2507800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21704, 'Shatian', 'Shatian', 'Shatian,Shatian Zhen,sha tian,sha tian zhen,砂田,砂田镇', 24.1429600, 116.4471500, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21705, 'Denggang', 'Denggang', 'Denggang,Denggang Zhen,deng gang,deng gang zhen,登岗,登岗镇', 23.5445700, 116.5159500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21706, 'Xichang', 'Xichang', 'Xichang,Xichang Zhen,xi chang,xi chang zhen,锡场,锡场镇', 23.6127800, 116.3263200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21707, 'Wushi', 'Wushi', 'Wushi,Wushi Zhen,wu shi,wu shi zhen,乌石,乌石镇', 23.6263900, 115.1944200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21708, 'Linjiang', 'Linjiang', 'Linjiang,Linjiang Zhen,lin jiang,lin jiang zhen,临江,临江镇', 23.6512500, 114.6939700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21709, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Zhen,shui kou,水口', 23.1541200, 114.5213900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21710, 'Songkeng', 'Songkeng', 'Songkeng,song keng,松坑', 23.1825100, 114.9137500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21711, 'Mabei', 'Mabei', 'Mabei,Mabei Zhen,Mapi Zhen,ma bei,ma bei zhen,麻陂,麻陂镇', 23.4932600, 114.5228600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21712, 'Zengguang', 'Zengguang', 'Zengguang,zeng guang,增光', 23.0180200, 114.8721500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21713, 'Meilin', 'Meilin', 'Meilin,Meilin Zhen,mei lin,mei lin zhen,梅林,梅林镇', 23.2398700, 115.9964600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21714, 'Chengtian', 'Chengtian', 'Ch''eng-t''ien,Chengtian,Chengtian Zhen,Ch’eng-t’ien,cheng tian,cheng tian zhen,成田,成田镇', 23.1863000, 116.4727900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21715, 'Daba', 'Daba', 'Daba,Daba Zhen,Ta-pa-hsu,Ta-pa-hsü,da ba,da ba zhen,大坝,大坝镇', 23.3642100, 116.1869900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21716, 'Xiayang', 'Xiayang', 'Hsia-yang,Xiayang,Xiayang Zhen,xia yang,xia yang zhen,下洋,下洋镇', 20.5129900, 110.5031700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21717, 'Beihe', 'Beihe', 'Beihe,Beihe Zhen,Pei-ho,bei he,bei he zhen,北和,北和镇', 20.6530000, 109.8773600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21718, 'Tiandian', 'Tiandian', 'T''ien-tien,Tiandian,Tiandian Zhen,T’ien-tien,tian dian,tian dian zhen,田店,田店镇', 31.0294500, 113.4484100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21719, 'Hujindian', 'Hujindian', 'Hu-chin-tien,Hujindian,Hujindian Zhen,hu jin dian,hu jin dian zhen,胡金店,胡金店镇', 31.0722200, 113.6581200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21720, 'Muzi', 'Muzi', 'Mu-tzu-shu,Muzi,Muzi Xiang,mu zi,mu zi xiang,木梓,木梓乡', 31.2294400, 113.5469400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21721, 'Jidian', 'Jidian', 'Chi-chia-tien,Jidian,Jidian Xiang,ji dian,ji dian xiang,季店,季店乡', 31.2873200, 113.9030300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21722, 'Wangyi Zhendian', 'Wangyi Zhendian', 'Wang-i-chen-tien,Wangyi Zhendian,Wangyi Zhendian Zhen,wang yi zhen dian,wang yi zhen dian zhen,王义贞店,王义贞店镇', 31.3305500, 113.3796400, 'CN', '2013-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21723, 'Jieguan', 'Jieguan', 'Chieh-kuan-t''ing,Chieh-kuan-t’ing,Jieguan,Jieguan Xiang,jie guan,jie guan xiang,接官,接官乡', 31.4347700, 113.7543000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21724, 'Baolin', 'Baolin', 'Baolin,Baolin Xiang,Pao-lin-ssu,bao lin,bao lin xiang,宝林,宝林乡', 31.6738200, 113.8703200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21725, 'Shili', 'Shili', 'Shih-li-ho-shih,Shili,Shili Jiedao,shi li,shi li jie dao,十里,十里街道', 31.6141600, 113.8801300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21726, 'Guanmiao', 'Guanmiao', 'Guanmiao,Guanmiao Zhen,Kuan-ti-miao,guan miao,guan miao zhen,关庙,关庙镇', 31.7050700, 113.7048700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21727, 'Yudian', 'Yudian', 'Yu-chia-tien,Yudian,Yudian Zhen,Yü-chia-tien,yu dian,yu dian zhen,余店,余店镇', 31.7836400, 113.6347000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21728, 'Zhichanghe', 'Zhichanghe', 'Chih-ch''ang-ho,Chih-ch’ang-ho,Zhichanghe,Zhichanghe Zhen,zhi chang he,zhi chang he zhen,纸厂河,纸厂河镇', 30.0280600, 111.8447200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21729, 'Zishi', 'Zishi', 'Tzu-tu-ssu,Zishi,Zishi Zhen,zi shi,zi shi zhen,资市,资市镇', 30.1824800, 112.4087800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21730, 'Libu', 'Libu', 'Li-chia-pu,Libu,Libu Zhen,li bu,li bu zhen,李埠,李埠镇', 30.3222300, 112.0666700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21731, 'Moshi', 'Moshi', 'Mo-shih,Moshi,Moshi Zhen,mo shi,mo shi zhen,磨市,磨市镇', 30.4148700, 111.2386600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21732, 'Luotaping', 'Luotaping', 'Luotaping,Luotaping Xiang,luo ta ping,luo ta ping xiang,罗塔坪,罗塔坪乡', 29.1871300, 110.1251500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21733, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,gao qiao,gao qiao zhen,高桥,高桥镇', 29.1745400, 110.9873500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21734, 'Luoshui', 'Luoshui', 'Luoshui,Luoshui Xiang,luo shui,luo shui xiang,罗水,罗水乡', 29.2682900, 110.2536600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21735, 'Maoba', 'Maoba', 'Maoba,Maoba Xiang,mao ba,mao ba xiang,毛坝,毛坝乡', 29.2720100, 109.8873800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21736, 'Liangchahe', 'Liangchahe', 'Liangcha Xiang,Liangchahe,liang cha he,liang cha xiang,两岔乡,两岔河', 29.1757400, 109.7184000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21737, 'Guanba', 'Guanba', 'Guanba,Guanba Xiang,guan ba,guan ba xiang,官坝,官坝乡', 29.2954200, 109.9657200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21738, 'Taozixi', 'Taozixi', 'Taozixi,Taozixi Xiang,tao zi xi,tao zi xi xiang,桃子溪,桃子溪乡', 29.3083300, 110.0544400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21739, 'Lianghekou', 'Lianghekou', 'Lianghekou,Lianghekou Xiang,liang he kou,liang he kou xiang,两河口,两河口乡', 29.4522200, 110.0258300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21740, 'Xinglongjie', 'Xinglongjie', 'Xinglongjie,Xinglongjie Xiang,xing long jie,xing long jie xiang,兴隆街,兴隆街乡', 29.4549800, 109.5301700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21741, 'Sanhekou', 'Sanhekou', 'Sanhekou,Sanhekou Xiang,san he kou,san he kou xiang,三合口,三合口乡', 29.6267400, 110.8241600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21742, 'Zhujiatai', 'Zhujiatai', 'Tielu,Tielu Xiang,Zhujiatai,tie lu,tie lu xiang,zhu jia tai,朱家台,铁炉,铁炉乡', 29.7400100, 110.5027200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21743, 'Yongmao', 'Yongmao', 'Yongmao,Yongmao Zhen,yong mao,yong mao zhen,永茂,永茂镇', 29.0148800, 110.2753300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21744, 'Macha', 'Macha', 'Macha,Macha Xiang,ma cha,ma cha xiang,麻岔,麻岔乡', 29.0426400, 110.0466900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21745, 'Tasha', 'Tasha', 'Tasha,Tasha Xiang,ta sha,ta sha xiang,他砂,他砂乡', 29.0580600, 109.5669700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21746, 'Xinzhaiping', 'Xinzhaiping', 'Xinzhai Xiang,Xinzhaiping,xin zhai ping,xin zhai xiang,新寨乡,新寨坪', 29.1343000, 109.8918000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21747, 'Sanjiaguan', 'Sanjiaguan', 'Sanjiaguan,Sanjiaguan Xiang,san jia guan,san jia guan xiang,三家馆,三家馆乡', 29.1630500, 110.2897000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21748, 'Jianxin', 'Jianxin', 'Jianxin,Yanghuping,Yanghuping Zhen,jian xin,yang hu ping,yang hu ping zhen,建新,阳湖坪,阳湖坪镇', 29.1451300, 110.5509000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21749, 'Matizhai', 'Matizhai', 'Matizhai,Nongche Xiang,ma ti zhai,nong che xiang,农车乡,马蹄寨', 29.1729100, 109.6286900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21750, 'Shanmu', 'Shanmu', 'Shanmu,Shanmu Xiang,shan mu,shan mu xiang,杉木,杉木乡', 29.2667400, 109.8460600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21751, 'Zhonghuping', 'Zhonghuping', 'Zhonghu,Zhonghu Xiang,Zhonghuping,zhong hu,zhong hu ping,zhong hu xiang,中湖,中湖乡,中湖坪', 29.3640600, 110.3825700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21752, 'Ruchihe', 'Ruchihe', 'Ruchihe,Tani Xiang,ru chi he,ta ni xiang,塔泥乡,汝池河', 29.2963800, 109.7139900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21753, 'Bishagou', 'Bishagou', 'Bishagou,Xihu Xiang,bi sha gou,xi hu xiang,比沙沟,西湖乡', 29.3426400, 109.5913900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21754, 'Shuishaping', 'Shuishaping', 'Shuishaping,Shuishaping Xiang,shui sha ping,shui sha ping xiang,水沙坪,水沙坪乡', 29.3777900, 109.5550500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21755, 'Tongche', 'Tongche', 'Tongche,Tongche Xiang,tong che,tong che xiang,桶车,桶车乡', 29.5060500, 109.5671800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21756, 'Tianzishan', 'Tianzishan', 'Tianzishan,Tianzishan Zhen,tian zi shan,tian zi shan zhen,天子山,天子山镇', 29.4097200, 110.4364300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21757, 'Zhaojiagang', 'Zhaojiagang', 'Zhaojiagang,Zhaojiagang Tujiazu Xiang,zhao jia gang,zhao jia gang tu jia zu xiang,赵家岗,赵家岗土家族乡', 29.4962200, 110.6769800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21758, 'Furongqiao', 'Furongqiao', 'Furongqiao,Furongqiao Baizuxiang,fu rong qiao,fu rong qiao bai zu xiang,芙容桥,芙容桥白族乡', 29.5143500, 110.3000100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21759, 'Jianjiapo', 'Jianjiapo', 'Jianjiapo,Jianjiapo Xiang,jian jia po,jian jia po xiang,蹇家坡,蹇家坡乡', 29.5527100, 109.9556900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21760, 'Nanzhen', 'Nanzhen', 'Nanbei,Nanbei Zhen,Nanzhen,nan bei,nan bei zhen,nan zhen,南北,南北镇,南镇', 29.8718800, 110.5484800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21761, 'Dengying', 'Dengying', 'Dengying,Dengyingcun,deng ying,登瀛', 36.1388900, 120.5741700, 'CN', '2014-02-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21762, 'Kutao', 'Kutao', 'Kutao,ku tao,枯桃', 36.1450000, 120.4877800, 'CN', '2014-02-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21763, 'Beizhai', 'Beizhai', 'Beizhai,Beizhaike', 36.2197200, 120.5288900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21764, 'Qingshancun', 'Qingshancun', 'Cinshan'',Qingshan,Qingshancun,qing shan,qing shan cun,Циншань,青山,青山村', 36.1541500, 120.6824000, 'CN', '2016-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21765, 'Xinzhuang', 'Xinzhuang', 'Hou-hsin-chuang,Xinzhuang,Xinzhuang Zhen,xin zhuang,xin zhuang zhen,辛庄,辛庄镇', 39.0249000, 117.3437700, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21766, 'Weiwangzhuang', 'Weiwangzhuang', 'Weiwangzhuang,Yin-chuang-tzu,wei wang zhuang,魏王庄', 39.0250000, 117.4408300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21767, 'Goutou', 'Goutou', 'Goutou,Kou-t''ou,Kou-t’ou', 39.8050000, 117.1991700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21768, 'Meipu', 'Meipu', 'Meipu,mei bu,梅埔', 26.2112000, 118.8956100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21769, 'Rong’an', 'Rong''an', 'Jung-an,Rong''an,Rong’an', 26.1247200, 119.1213900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21770, 'Shangjie', 'Shangjie', 'Shang-chieh,Shangjie,Shangjie Zhen,shang jie,shang jie zhen,上街,上街镇', 26.0867900, 119.1849400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21771, 'Kuai’an', 'Kuai''an', '', 26.0341700, 119.4163900, 'CN', '2001-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21772, 'Chengmen', 'Chengmen', 'Chengmen,Chengmen Zhen,cheng men,cheng men zhen,城门,城门镇', 25.9933900, 119.3613600, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21773, 'Hongtang', 'Hongtang', 'Hongtang,Hung-t''ang,Hung-t’ang', 26.0705600, 119.2308300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21774, 'Huai’an', 'Huai''an', 'Huai''an,Huai’an,huai an,淮安', 26.0989900, 119.2217100, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21775, 'Donghu', 'Donghu', 'Donghu,Donghu Zhen,Tung-hu,dong hu,dong hu zhen,东湖,东湖镇', 26.2345300, 119.5143000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21776, 'Houyu', 'Houyu', 'Hou-hsu,Hou-hsü,Houyu,Houyu Xiang,hou yu,hou yu xiang,猴屿,猴屿乡', 26.0595800, 119.5350200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21777, 'Jitou', 'Jitou', 'Jitou,ji tou,迹头', 26.4768100, 119.6051700, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21778, 'Beishan', 'Beishan', 'Beishan,Pei-shan,bei shan,北山', 26.4375500, 119.6327800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21779, 'Huangtian', 'Huangtian', 'Huangtian,Huangtian Zhen,huang tian,huang tian zhen,黄田,黄田镇', 26.4385100, 118.6239800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21780, 'Dingtou', 'Dingtou', 'Dingtou,T''eng-t''ou,T’eng-t’ou,ding tou,顶头', 26.8397700, 119.6611100, 'CN', '2014-03-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21781, 'Miaoba', 'Miaoba', 'Miaoba,Miaoba Zhen,miao ba,miao ba zhen,庙坝,庙坝镇', 31.9361500, 108.5178600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21782, 'Zhaojia', 'Zhaojia', 'Zhaojia,Zhaojia Zhen,zhao jia,zhao jia zhen,赵家,赵家镇', 31.0812500, 108.4116400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21783, 'Gulu', 'Gulu', 'Gulu,Gulu Zhen,gu lu,gu lu zhen,古路,古路镇', 31.3301000, 109.4399100, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21784, 'Dong’an', 'Dong''an', 'Dong''an,Dong''an Xiang,Dong’an,Dong’an Xiang,Shuikouchang,dong an,dong an xiang,shui kou chang,东安,东安乡,水口场', 31.7775600, 109.0860600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21785, 'Zhongliang', 'Zhongliang', 'Dujiaping,Zhongliang,Zhongliang Xiang,du jia ping,zhong liang,zhong liang xiang,中梁,中梁乡,杜家坪', 31.5898600, 109.3390000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21786, 'Zouma', 'Zouma', 'Zouma,Zouma Zhen,zou ma,zou ma zhen,走马,走马镇', 30.5696000, 108.4375200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21787, 'Shibao', 'Shibao', 'Shibao,Shibao Zhen,shi bao,shi bao zhen,石宝,石宝镇', 30.4236300, 108.1922200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21788, 'Wuyang', 'Wuyang', 'Wuyang,Wuyang Zhen,wu yang,wu yang zhen,乌杨,乌杨镇', 30.2042300, 107.9976400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21789, 'Yantai', 'Yantai', 'Yantai,Yantai Zhen,yan tai,yan tai zhen,砚台,砚台镇', 30.1467000, 107.3196000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21790, 'Miaoxi', 'Miaoxi', 'Miaoxi,Miaoxi Xiang,miao xi,miao xi xiang,庙溪,庙溪乡', 29.0501600, 108.4590200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21791, 'Daxi', 'Daxi', 'Daxi,Daxi Zhen,da xi,da xi zhen,大溪,大溪镇', 29.0940500, 109.1479700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21792, 'Miaoya', 'Miaoya', 'Miaoya,Miaoya Xiang,miao ya,miao ya xiang,庙垭,庙垭乡', 29.4459300, 107.3195200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21793, 'Sanmiao', 'Sanmiao', 'Sanmiao,Sanmiao Zhen,san miao,san miao zhen,三庙,三庙镇', 30.2376300, 106.1270400, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21794, 'Rongxi', 'Rongxi', 'Rongxi,Rongxi Zhen,rong xi,rong xi zhen,溶溪,溶溪镇', 28.5248500, 108.8803800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21795, 'Yipin', 'Yipin', 'Yipin,Yipin Zhen,Yipinchang,yi pin,yi pin zhen,一品,一品镇', 29.2847200, 106.5613900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21796, 'Longsheng', 'Longsheng', 'Longsheng,Longsheng Zhen,Longshengchang,long sheng,long sheng zhen,隆盛,隆盛镇', 29.0813900, 106.8163900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21797, 'Lixi', 'Lixi', 'Lixi,Lixi Zhen,Yangjiaba,li xi,li xi zhen,yang jia ba,李溪,李溪镇,杨家坝', 28.5312600, 108.6110000, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21798, 'Ouyang', 'Ouyang', 'Hsin-hua-so,Ouyang,ou yang,欧阳', 26.4191000, 109.2160000, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21799, 'Dengyuantai', 'Dengyuantai', '', 26.6880600, 110.5422200, 'CN', '2004-05-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21800, 'Xinmin', 'Xinmin', 'Xinmin,Xinmin Zhen,xin min,xin min zhen,新民,新民镇', 24.7150800, 118.1305000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21801, 'Yingcun', 'Yingcun', 'Yingcun,Yingcun Jiedao,ying cun,ying cun jie dao,英村,英村街道', 24.6023700, 118.1039900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21802, 'Xike', 'Xike', 'Xiguanxun,Xike,Xike Zhen,xi ke,xi ke zhen,西柯,西柯镇', 24.6611700, 118.1433000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21803, 'Longjiao', 'Longjiao', 'Longjiao,Longjiao Shezu Xiang,long jiao,long jiao she zu xiang,隆教,隆教畲族乡', 24.2550700, 118.0553000, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21804, 'Dongxiang', 'Dongxiang', 'Dongxiang,Dongxiang Xiang,dong xiang,dong xiang xiang,东庠,东庠乡', 25.5945600, 119.8818200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21805, 'Xindu', 'Xindu', 'Xindu,Xindu Zhen,xin du,xin du zhen,新度,新度镇', 25.3991200, 119.0378900, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21806, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Zhen,cheng dong,cheng dong zhen,城东,城东镇', 25.3682000, 118.7011000, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21807, 'Shenqiao', 'Shenqiao', 'Shenqiao,shen qiao,深桥', 23.7300300, 117.1405100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21808, 'Wenling', 'Wenling', 'Wenling,Wenling Zhen,wen ling,wen ling zhen,文岭,文岭镇', 25.9966200, 119.6497400, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21809, 'Baiqing', 'Baiqing', 'Baiqing,Baiqing Xiang,bai qing,bai qing xiang,白青,白青乡', 25.6511900, 119.7679800, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21810, 'Yanggu’ao', 'Yanggu''ao', 'Yanggu''ao,Yanggu’ao,Yangu''ao Xiang,Yangu’ao Xiang,yang gu ao,yang gu ao xiang,羊古坳,羊古坳乡', 27.4866700, 110.9438900, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21811, 'Hetian', 'Hetian', 'Hetian,Hetian Xiang,Qinglongqiao,he tian,he tian xiang,qing long qiao,荷田,荷田乡,青龙桥', 27.3469400, 110.9716700, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21812, 'Matangshan', 'Matangshan', 'Matangshan,Matangshan Xiang,Xingwuchang,ma tang shan,ma tang shan xiang,xing wu chang,兴屋场,麻塘山,麻塘山乡', 27.3880600, 110.6927800, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21813, 'Xiyangjiang', 'Xiyangjiang', 'Xinchao,Xiyangjiang,Xiyangjiang Zhen,xi yang jiang,xi yang jiang zhen,xin chao,新潮,西洋江,西洋江镇', 27.1902800, 110.8288900, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21814, 'Qijiang', 'Qijiang', 'Qijiang,Qijiang Xiang,Shibei,qi jiang,qi jiang xiang,shi bei,七江,七江乡,石背', 27.4494400, 110.9730600, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21815, 'Hedong', 'Hedong', 'Hedong,Hedong Xiang,he dong,he dong xiang,河东,河东乡', 27.5258300, 118.7908300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21816, 'Shitun', 'Shitun', 'Shitun,Shitun Zhen,shi tun,shi tun zhen,石屯,石屯镇', 27.3577300, 118.7525800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21817, 'Chuanshi', 'Chuanshi', 'Chuanshi,Chuanshi Xiang,chuan shi,chuan shi xiang,川石,川石乡', 27.2521000, 118.6846300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21818, 'Lidun', 'Lidun', 'Lidun,Lidun Zhen,li dun,li dun zhen,李墩,李墩镇', 27.0516700, 119.2811100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21819, 'Xinpu', 'Xinpu', 'Jitou,Wuzhai,Xinpu,Xinpu Xiang,ji tou,xin pu,xin pu xiang,新浦,新浦乡,漈头', 27.6284300, 119.9317200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21820, 'Dongxi', 'Dongxi', 'Dongxi,Dongxi Xiang,dong xi,dong xi xiang,东溪,东溪乡', 27.4237100, 119.9597700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21821, 'Wanpai', 'Wanpai', 'Shangpai,Wanpai,Wanpai Xiang,shang pai,wan pai,wan pai xiang,万排,万排乡,上排', 27.3492800, 119.9242000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21822, 'Shanjie', 'Shanjie', 'Hujia,Shanjia,Shanjie,Shanjie Huizuxiang,hu jia,shan jie,shan jie hui zu xiang,山界,山界回族乡,胡家', 27.0775000, 111.0194400, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21823, 'Dazhai', 'Dazhai', 'Dazhai,da zhai,大寨', 25.8098000, 110.1500000, 'CN', '2017-05-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21824, 'Jiangdong', 'Jiangdong', 'Jiangdong,Jiangdong Zhen,jiang dong,jiang dong zhen,江东,江东镇', 23.5895900, 116.6622100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21825, 'Fengjiang', 'Fengjiang', 'Fengjiang,Fengjiang Zhen,feng jiang,feng jiang zhen,凤江,凤江镇', 23.4466900, 116.1228300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21826, 'Tanxia', 'Tanxia', 'Tanxia,Tanxia Zhen,tan xia,tan xia zhen,潭下,潭下镇', 23.9451500, 115.5351900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21827, 'Hedong', 'Hedong', 'Hedong,Hedong Zhen,he dong,he dong zhen,河东,河东镇', 23.9196000, 115.7801000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21828, 'Xinan', 'Xinan', 'Xinan,Xinan Zhen,xi nan,xi nan zhen,溪南,溪南镇', 23.5466800, 116.8077600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21829, 'Wutun', 'Wutun', 'Wutun,Wutun Zhen,wu tun,武屯', 34.6376800, 109.2951200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21830, 'Beitun', 'Beitun', 'Beitun,bei tun,北屯', 34.6176900, 109.2312100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21831, 'Xinxing', 'Xinxing', 'Xinxing,xin xing,新兴', 34.6668900, 109.2743600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21832, 'Zhenxing', 'Zhenxing', 'Zhenxing,zhen xing,振兴', 34.6685300, 109.1928400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21833, 'Renliu', 'Renliu', 'Renliu,ren liu,任留', 34.4901700, 109.2273700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21834, 'Zhangbu', 'Zhangbu', 'Zhangbu,zhang bo,张卜', 34.4835800, 109.1173200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21835, 'Xiaojin', 'Xiaojin', 'Xiaojin,xiao jin,小金', 34.3395100, 109.4134900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21836, 'Muzhai', 'Muzhai', 'Muzhai,mu zhai,穆寨', 34.3660600, 109.3677100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21837, 'Tuqiao', 'Tuqiao', 'Tuqiao,tu qiao,土桥', 34.3516600, 109.3187800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21838, 'Xiquan', 'Xiquan', 'Xiquan,Xiquan Zhen,xi quan,西泉', 34.4075400, 109.1385800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21839, 'Xinhe', 'Xinhe', 'Xinhe,xin he,新合', 34.4190400, 109.0997400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21840, 'Yuchu', 'Yuchu', 'Yuchu,yu chu,榆楚', 34.5027200, 109.0578800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21841, 'Dongda', 'Dongda', 'Dongda,Dongda Jieban,dong da,dong da jie ban,东大,东大街办', 34.0440700, 108.7681700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21842, 'Xinglong', 'Xinglong', 'Xinglong,xing long,兴隆', 34.1246800, 108.8168000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21843, 'Qujiang', 'Qujiang', 'Qujiang,Qujiang Jieban,qu jiang,qu jiang jie ban,曲江,曲江街办', 34.1931600, 108.9882500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21844, 'Dengjiapo', 'Dengjiapo', 'Dengjiapo,Dengjiapo Jieban,deng jia po,等驾坡', 34.2272300, 109.0251300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21845, 'Daminggong', 'Daminggong', 'Daminggong,Daminggong Jieban,da ming gong,da ming gong jie ban,大明宫,大明宫街办', 34.3045500, 108.9632900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21846, 'Hancheng', 'Hancheng', 'Hancheng,Hancheng Jieban,han cheng,han cheng jie ban,汉成,汉成街办', 34.3350000, 108.9077800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21847, 'Tanjia', 'Tanjia', 'Tanjia,Tanjia Jieban,tan jia,tan jia jie ban,谭家,谭家街办', 34.3322200, 108.9677800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21848, 'Baoli', 'Baoli', 'Baoli,pao li,炮里', 34.1709500, 109.1365100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21849, 'Huaxu', 'Huaxu', 'Huaxu,Huaxu Zhen,hua xu,华胥', 34.2249500, 109.1822900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21850, 'Shijiazhai', 'Shijiazhai', 'Shijiazhai,shi jia zhai,史家寨', 34.0780500, 109.1493200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21851, 'Yangzhuang', 'Yangzhuang', 'Yangzhuang,yang zhuang,杨庄', 34.0412500, 109.1403300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21852, 'Wangmang', 'Wangmang', 'Wangmang,wang mang,王莽', 34.0578600, 109.0555200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21853, 'Wutai', 'Wutai', 'Wutai,wu tai,五台', 34.0340100, 108.9712100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21854, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,gao qiao,高桥', 34.2433300, 108.7055600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21855, 'Weifeng', 'Weifeng', 'Weifeng,Weifeng Zhen,wei feng,wei feng zhen,渭丰,渭丰镇', 34.1950800, 108.6134300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21856, 'Cangyou', 'Cangyou', 'Cangyou,Cangyou Zhen,cang you,cang you zhen,苍游,苍游镇', 34.1632400, 108.6544400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21857, 'Tianqiao', 'Tianqiao', 'Tianqiao,tian qiao,天桥', 34.0519400, 108.5625000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21858, 'Jiufeng', 'Jiufeng', 'Jiufeng,jiu feng,九峰', 34.1014900, 108.4270300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21859, 'Wuzhu', 'Wuzhu', 'Wuzhu,wu zhu,五竹', 34.1130200, 108.6580000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21860, 'Shijing', 'Shijing', 'Shijing,Sijing Zhen,shi jing,shi jing zhen,石井,石井镇', 34.0283300, 108.5886100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21861, 'Houjia', 'Houjia', 'Houjia,Houjiacun,hou jia,侯家', 34.1651400, 108.1808200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21862, 'Xinyang', 'Xinyang', 'Xinyang,xin yang,新阳', 34.4829400, 108.1405200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21863, 'Moxi', 'Moxi', 'Moxi,mo xi,漠西', 34.5150000, 108.1888900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21864, 'Fengyang', 'Fengyang', 'Fengyang,Fengyang Zhen,feng yang,feng yang zhen,峰阳,峰阳镇', 34.6831400, 108.2772200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21865, 'Zhuganzhen', 'Zhuganzhen', 'Zhugan Zhen,Zhuganzhen,zhu gan,zhu gan zhen,注泔,注泔镇', 34.6241700, 108.3086100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21866, 'Liangshan', 'Liangshan', 'Liangshan,Liangshan Zhen,liang shan,liang shan zhen,梁山,梁山镇', 34.6208500, 108.1927100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21867, 'Dayang', 'Dayang', 'Dayang,Dayang Xiang,Dayangcun,da yang,da yang xiang,大杨,大杨乡', 34.4983300, 108.3108300, 'CN', '2013-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21868, 'Shiniu', 'Shiniu', 'Shiniu,shi niu,石牛', 34.5075800, 108.0727200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21869, 'Yanxia', 'Yanxia', 'Yanxia,Yanxiazhen,yan xia,yan xia zhen,烟霞,烟霞镇', 34.5755600, 108.5430600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21870, 'Jianling', 'Jianling', 'Jianling,Jianlingzhen,jian ling,jian ling zhen,建陵,建陵镇', 34.6397200, 108.4150000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21871, 'Zhaoling', 'Zhaoling', 'Zhaoling,zhao ling,昭陵', 34.5630600, 108.4475000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21872, 'Fengyi', 'Fengyi', 'Fengyi,Fengyi Xiang,feng yi,feng yi xiang,丰仪,丰仪乡', 34.2491400, 108.4113900, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21873, 'Tianfu', 'Tianfu', 'Tianfu,tian fu,田阜', 34.2644400, 108.5941700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21874, 'Fuzhai', 'Fuzhai', 'Fuzhai,fu zhai,阜寨', 34.2538900, 108.5222200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21875, 'Baiwang', 'Baiwang', 'Baiwang,Baiwang Zhen,bai wang,bai wang zhen,白王,白王镇', 34.6733300, 108.6491100, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21876, 'Zhongzhang', 'Zhongzhang', 'Zhongzhang,Zhongzhangzhen,zhong zhang,zhong zhang zhen,中张,中张镇', 34.5544500, 108.7668400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21877, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 34.5058300, 108.7361100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21878, 'Yanwang', 'Yanwang', 'Yanwang,yan wang,燕王', 34.5716700, 108.8019400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21879, 'Longquan', 'Longquan', 'Longquan,long quan,龙泉', 34.6847200, 108.8680600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21880, 'Chongwen', 'Chongwen', 'Chongwen,chong wen,崇文', 34.4943000, 108.9331700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21881, 'Cuo’e', 'Cuo''e', 'Cuo''e,Cuo’e,cuo e,蹉峨', 34.7391700, 108.8788900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21882, 'Xumu', 'Xumu', 'Xumu,xu mu,徐木', 34.6941400, 109.1156000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21883, 'Beixi', 'Beixi', 'Beixi,Beixi Zhen,bei xi,陂西', 34.6201200, 109.1089400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21884, 'Duma', 'Duma', 'Duma,du ma,渡马', 34.7652800, 108.1350000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21885, 'Yujiagong', 'Yujiagong', 'Yujiagong,yu jia gong,御驾宫', 34.7293300, 108.1877500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21886, 'Shangyi', 'Shangyi', 'Shangyi,shang yi,上邑', 34.8347700, 108.2646600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21887, 'Bojia', 'Bojia', 'Bojia,bo jia,卜家', 34.9266700, 108.5125000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21888, 'Qinhe', 'Qinhe', 'Qinhe,qin he,秦河', 34.9202800, 108.5927800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21889, 'Meijiaping', 'Meijiaping', 'Meijiaping,mei jia ping,梅家坪', 34.8660500, 108.9929400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21890, 'Huazhu', 'Huazhu', 'Huazhu,hua zhu,华朱', 34.7860100, 109.1956500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21891, 'Xiaohui', 'Xiaohui', 'Xiaohui,Xiaohui Xiang,xiao hui,xiao hui xiang,小惠,小惠乡', 34.9092600, 109.2706400, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21892, 'Gongli', 'Gongli', 'Gongli,Gongli Zhen,gong li,宫里', 34.8311400, 109.1441400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21893, 'Qicun', 'Qicun', 'Qicun,qi cun,齐村', 34.8227100, 109.1094400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21894, 'Mizi', 'Mizi', 'Mizi,mi zi,觅子', 34.8124200, 109.0154100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21895, 'Maquan', 'Maquan', 'Maquan,Maquanzhen,ma quan,ma quan zhen,马泉,马泉镇', 34.3236100, 108.6036100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21896, 'Weibin', 'Weibin', 'Weibin,Weibinzhen,wei bin,wei bin zhen,渭滨,渭滨镇', 34.3158300, 108.6458300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21897, 'Diaotai', 'Diaotai', 'Diaotai,Diaotaizhen,diao tai,diao tai zhen,汈台,汈台镇', 34.2855600, 108.6863900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21898, 'Wujiabao', 'Wujiabao', 'Wujiabao,Wujiabao Jieban,wu jia bao,wu jia bao jie ban,吴家堡,吴家堡街办', 34.3475400, 108.6992600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21899, 'Fengdong', 'Fengdong', 'Fengdong,Fengdong Zhen,feng dong,feng dong zhen,沣东,沣东镇', 34.3247200, 108.7583300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21900, 'Weicheng', 'Weicheng', 'Weicheng,Weicheng Zhen,wei cheng,wei cheng zhen,渭城,渭城镇', 34.3841700, 108.7780600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21901, 'Zhengyang', 'Zhengyang', 'Zhengyang,Zhengyangzhen,zheng yang,zheng yang zhen,正阳,正阳镇', 34.4236100, 108.9213900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21902, 'Weiyanggong', 'Weiyanggong', 'Weiyanggong,Weiyanggong Jieban,wei yang gong,wei yang gong jie ban,未央宫,未央宫街办', 34.2893600, 108.9105800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21903, 'Yanta', 'Yanta', 'Yanta,Yanta Qu,yan ta,yan ta qu,雁塔,雁塔区', 34.2063600, 108.9524000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21904, 'Zhangbagou', 'Zhangbagou', 'Zhangbagou,Zhangbagou Jieban,zhang ba gou,zhang ba gou jie ban,丈八沟,丈八沟街办', 34.2129100, 108.8802800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21905, 'Youfeng', 'Youfeng', 'Youfeng,Youfeng Zhen,you feng,you feng zhen,游凤,游凤镇', 34.3909100, 108.0437700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21906, 'Sufang', 'Sufang', 'Sufang,Sufangzhen,su fang,su fang zhen,苏坊,苏坊镇', 34.3961400, 108.0846100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21907, 'Daijia', 'Daijia', 'Daijia,dai jia,戴家', 34.3351400, 108.1504300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21908, 'Changning', 'Changning', 'Changning,Changningzhen,zhang ning,zhang ning zhen,长宁,长宁镇', 34.3015200, 108.2912500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21909, 'Xingzhe', 'Xingzhe', 'Xingzhe,Xingzhe Jieban,xing zhe,行者', 34.4052300, 109.1969300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21910, 'Hexi', 'Hexi', 'Hexi,he xi,河西', 34.4111900, 109.5251000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21911, 'Yancun', 'Yancun', 'Yancun,Yancun Zhen,yan cun,阎村', 34.4189700, 109.4949600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21912, 'Xipi', 'Xipi', 'Xipi,Xipi Jiedao,xi bei,xi bei jie dao,西陂,西陂街道', 25.0916700, 117.0105600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21913, 'Lingdi', 'Lingdi', 'Lingdi,ling de,灵地', 25.6071100, 117.5857600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21914, 'Xiyuan', 'Xiyuan', 'Kerentou,Xiyuan,Xiyuan Xiang,ke ren tou,xi yuan,xi yuan xiang,可人头,西园,西园乡', 25.3344400, 117.3619400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21915, 'Jingchen', 'Jingchen', 'Jingchen,Jingcheng Jiedao,Qingcheng,jing cheng,jing cheng jie dao,qing cheng,菁城,菁城街道,青城', 25.2969400, 117.4077800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21916, 'Jishan', 'Jishan', 'Jishan,Jishan Xiang,ji shan,ji shan xiang,吉山,吉山乡', 25.9570900, 117.3181400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21917, 'Huaxing', 'Huaxing', 'Huaxing,hua xing,华兴', 25.6933300, 117.8858300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21918, 'Shangqing', 'Shangqing', 'Hanqing,Shangqing,han qing,shang qing,尚卿,翰卿', 25.1097200, 117.9642500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21919, 'Cannei', 'Cannei', 'Cannei,Dacuo,can nei,da cuo,参内,大厝', 25.0719400, 118.2163900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21920, 'Chengxiang', 'Chengxiang', 'Chengxiang,Chengxiang Xiang,Cunziwei,cheng xiang,cheng xiang xiang,cun zi wei,呈祥,呈祥乡,村仔尾', 25.4475000, 118.1402800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21921, 'Yunxing', 'Yunxing', 'Tso-yun,Tso-yun-hsien,Tso-yün,Tso-yün-hsien,Tszoyun'',Tszöyun’,Yunxing,Yunxing Zhen,Zuoyun Xian,yun xing,yun xing zhen,zuo yun xian,云兴,云兴镇,左云县', 39.9991000, 112.6978700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21922, 'Zunhua', 'Zunhua', 'Tsun-hua,Tsun-hua-ch''eng-kuan,Tsun-hua-ch’eng-kuan,Tsun-hua-hsien,Tsunhwa,Zunhua,zun hua,遵化', 40.1791700, 117.9586100, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21923, 'Zhuozishan', 'Zhuozishan', 'Cho-tzu,Cho-tzu-shan,Chotzushanchen,Zhuozi,Zhuozi Xian,Zhuozishan,Zhuozishan Zhen,zhuo zi shan,zhuo zi shan zhen,zhuo zi xian,卓资县,卓资山,卓资山镇', 40.8991700, 112.5602800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21924, 'Zhuolu', 'Zhuolu', 'Cho-lu,Cho-lu-ch''eng-kuan,Cho-lu-ch’eng-kuan,Pao-an,Zhuolu,zhuo lu,涿鹿', 40.3694400, 115.2161100, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21925, 'Zhujia', 'Zhujia', 'Zhujia,Zhujia Zhen,zhu jia,zhu jia zhen,朱家,朱家镇', 44.8710900, 129.8472300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21926, 'Zhoushizhuang', 'Zhoushizhuang', 'Chou-shih-chuang,Zhoushizhuang,Zhoushizhuang Zhen,zhou shi zhuang,zhou shi zhuang zhen,周士庄,周士庄镇', 40.1138900, 113.4661100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21927, 'Zhoujia', 'Zhoujia', 'Zhoujia,Zhoujia Zhen,zhou jia,zhou jia zhen,周家,周家镇', 40.5440700, 122.7445800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21928, 'Zhongxin', 'Zhongxin', 'Chung-hsin,Zhongxin,Zhongxin Zhen,zhong xin,zhong xin zhen,中心,中心镇', 47.6848600, 125.3292700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21929, 'Zhonghe', 'Zhonghe', 'Chung-ho,Chung-ho-chen,Zhonghe,Zhonghe Zhen,zhong he,zhong he zhen,中和,中和镇', 46.8671500, 125.7136600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21930, 'Zhonghe', 'Zhonghe', 'Chung-ho,Zhonghe,Zhonghe Zhen,zhong he,zhong he zhen,中和,中和镇', 45.5052300, 128.7716900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21931, 'Zhong’an', 'Zhong''an', 'Chung-an-p''u,Chung-an-p’u,Zhong''an,Zhong''an Zhen,Zhong''anpu,Zhong’an,Zhong’an Zhen,Zhong’anpu,zhong an,zhong an zhen,中安,中安镇', 41.6052400, 121.9790300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21932, 'Dalazi', 'Dalazi', 'Dalazi,Zhixin Zhen,da la zi,zhi xin zhen,大砬子,智新镇', 42.6393500, 129.5615900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21933, 'Zhenzhuquan', 'Zhenzhuquan', 'Chen-chu-ch''uan,Chen-chu-ch’üan,Zhenzhuquan,Zhenzhuquan Xiang,zhen zhu quan,zhen zhu quan xiang,珍珠泉,珍珠泉乡', 40.5569300, 116.4167800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21934, 'Zhenxing', 'Zhenxing', 'Zhenxing,Zhenxing Xiang,zhen xing,zhen xing xiang,振兴,振兴乡', 47.1027100, 130.6647000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21935, 'Zhenxiang', 'Zhenxiang', 'Chen-fu-hsiang-chen,Chen-hsiang,Zhenxiang,Zhenxiang Zhen,zhen xiang,zhen xiang zhen,祯祥,祯祥镇', 46.9927500, 125.7903700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21936, 'Zhenlai', 'Zhenlai', 'Ch''a-kan-nao,Ch''a-kan-shao,Chen-lai,Chen-lai-chen,Chen-tung,Chen-tung-hsien,Chzhendun,Ch’a-kan-nao,Ch’a-kan-shao,Zhenlai,zhen lai,镇赉', 45.8495500, 123.2973000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21937, 'Zhengjiatun', 'Zhengjiatun', 'Cheng-chia-t''un,Cheng-chia-t''un-chen,Cheng-chia-t’un,Cheng-chia-t’un-chen,Chengkiatun,Liao-yuan,Liao-yuan-hsien,Liao-yüan,Liao-yüan-hsien,Shuangliao,Zhengjiatun', 43.5063900, 123.5063900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21938, 'Zheng’an', 'Zheng''an', 'Cheng-an,Cheng-an-p''u,Cheng-an-p''u-ts''un,Cheng-an-pao,Cheng-an-pao-ts''un,Cheng-an-pao-ts’un,Cheng-an-p’u,Cheng-an-p’u-ts’un,Zheng''an,Zheng''an Zhen,Zheng''anpu,Zheng’an,Zheng’an Zhen,Zheng’anpu,zheng an,zheng an zhen,正安,正安镇', 41.7042300, 121.9304400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21939, 'Zhazi', 'Zhazi', 'Zhazi,Zhazi Zhen,zha zi,zha zi zhen,砟子,砟子镇', 42.0032300, 126.5577200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21940, 'Zhaozhou', 'Zhaozhou', 'Chao Chow,Chao-chi,Chao-chou,Chao-chou-chen,Chao-chou-hsien,Chzhaochzhou,Lao-ch''eng-chi,Lao-chieh-chi,Lao-ch’eng-chi,Zhaozhou,Чжаочжоу', 45.6833300, 125.3166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21941, 'Zhaoyuan', 'Zhaoyuan', 'Chao-chou,Chao-yuan,Chao-yuan-chen,Chao-yuan-hsien,Chao-yüan,Chao-yüan-chen,Chao-yüan-hsien,Chaochow,Chzhaochzhou,Chzhaoyuan'',Chzhaoyuan''gay,Chzhaoyuan’,Chzhaoyuan’gay,Gokhoutsi,Kuo-erh-lo-ssu-hou-ch''i,Kuo-erh-lo-ssu-hou-ch’i,Kuo-hou-ch''i,Kuo-hou-ch’i,Zhaoyuan', 45.5000000, 125.1333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21942, 'Zhaotun', 'Zhaotun', 'Zhaojitun,Zhaotun,zhao tun,zhao tun zhen,赵屯,赵屯镇', 41.4062000, 121.8754200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21943, 'Zhaodong', 'Zhaodong', 'Chao-tung,Chao-tung-chen,Chzhaodun,Man''gou,Man-kou,Man’gou,T''ien-tsao-kang,T’ien-tsao-kang,Zhaodong,Zhaodong Shi,Zhaodong Zhen,zhao dong,zhao dong shi,zhao dong zhen,肇东,肇东市,肇东镇', 46.0677100, 125.9826300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21944, 'Zhangjiakou', 'Zhangjiakou', 'Cang-tia-kchou,Chang-chia-k''ou,Chang-chia-k''ou-shih,Chang-chia-k’ou,Chang-chia-k’ou-shih,Chang-kia-k''ou,Chang-kia-k’ou,Changchiakow,Changkiakow,Chzhanczjakou,Chzhantseyakou,Diong-ga-kau,Diŏng-gă-kāu,Dzhandzjakou,Ganjakou,Kalgan,Khaalgan,Tiuⁿ-ka-kháu-chhī,Truong Gia Khau,Trương Gia Khẩu,Wan-ch''uan,Wan-ch''uan-hsien,Wan-ch’üan,Wan-ch’üan-hsien,ZQZ,Zhangjiakou,jangjakeou si,jangjyakw,zhang jia kou,zhang jia kou shi,zhangjyakww,Čang-ťia-kchou,Ĝanjakou,Џангђакоу,Джандзякоу,Хаалган,Чжанцзякоу,جانگجیاکو,ژانگجیاکوو,张家口市,張家口,張家口市,장자커우 시', 40.8100000, 114.8794400, 'CN', '2013-10-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21945, 'Zhangjiachang', 'Zhangjiachang', 'Chang-chia-ch''ang,Chang-chia-ch’ang,Zhangjiachang,Zhangjiachang Xiang,zhang jia chang,zhang jia chang xiang,张家场,张家场乡', 40.0836000, 112.8317100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21946, 'Zhangzhen', 'Zhangzhen', 'Chang-ko,Chang-ko-chuang,Chzhangechzhuan,Zhanggezhuang,Zhangzhen,zhang ge zhuang,zhang zhen,张各庄,张镇', 40.1462000, 116.9465200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21947, 'Zhangdiyingzi', 'Zhangdiyingzi', 'Zhangdiyingzi,Zhangdiyingzi Xiang,zhang de ying zi,zhang de ying zi xiang,张地营子,张地营子乡', 50.5471100, 127.3290500, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21948, 'Zhangdang', 'Zhangdang', 'Chang-tang,Zhangdang,Zhangdang Zhen,zhang dang,zhang dang zhen,章党,章党镇', 41.9075000, 124.0744000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21949, 'Zhangbei', 'Zhangbei', 'Chang-pei,Chang-pei-ch''eng-kuan,Chang-pei-ch’eng-kuan,Chang-pei-hsien,Changpeh,Hsing-ho-ch''eng,Hsing-ho-ch’eng,Zhangbei,zhang bei,张北', 41.1525000, 114.7077800, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21950, 'Zhalantun', 'Zhalantun', 'Butha Qi,Cha-lan-tun,Chzhalan''tun'',Chzhalantun,Cjalanjtunj,NZL,Pu-t''e-ha-ch''i,Pu-t’e-ha-ch’i,Tsa-lan-t''un,Tsa-lan-t’un,Xinghua,Xinghua Jiedao,Ya-lu,Ya-lu-hsien,Zalantun,Zhalantun,Zhalantun Shi,bu te ha qi,xing hua,xing hua jie dao,zha lan tun,zha lan tun shi,Чжаланьтунь,兴华,兴华街道,布特哈旗,扎兰屯,扎兰屯市', 48.0094500, 122.7365100, 'CN', '2016-06-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21951, 'Yushutun', 'Yushutun', 'Yushutun,Yushutun Xiang,yu shu tun,yu shu tun xiang,榆树屯,榆树屯乡', 47.1549200, 123.8882300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21952, 'Yushugou', 'Yushugou', 'Yu-shu-kou,Yushugou,Yushugou Xiang,Yü-shu-kou,yu shu gou,yu shu gou xiang,榆树沟,榆树沟乡', 44.1240000, 127.5307200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21953, 'Yushuchuan', 'Yushuchuan', 'Yushuchuan,Yushuchuan Xiang,yu shu chuan,yu shu chuan xiang,榆树川,榆树川乡', 42.3294500, 127.2035000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21954, 'Yushu', 'Yushu', 'Jujshu,Ku-yu-shu,Ku-yü-shu,Yu-shu-chen,Yu-shu-hsien,Yushu,Yü-shu-chen,Yü-shu-hsien,Юйшу', 44.8000000, 126.5333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21955, 'Yushu', 'Yushu', 'Yushu,Yushu Xiang,yu shu,yu shu xiang,榆树,榆树乡', 41.6436000, 124.8164500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21956, 'Yuquan', 'Yuquan', 'Erh Tieng Tien Tze,Erh-ts''eng-tien-tzu,Erh-ts''eng-ting-tzu,Erh-ts’eng-tien-tzu,Erh-ts’eng-ting-tzu,Yu-ch''uan,Yuquan,Yuquan Zhen,Yü-ch’üan,yu quan,yu quan zhen,玉泉,玉泉镇', 45.4100100, 127.1590200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21957, 'Yulin', 'Yulin', 'Yulin,Yulin Zhen,yu lin,yu lin zhen,榆林,榆林镇', 40.9925100, 125.9375600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21958, 'Yukou', 'Yukou', 'Yu-k''ou-chen,Yukou,Yukou Zhen,Yü-k’ou-chen,yu kou,yu kou zhen,峪口,峪口镇', 40.1886700, 117.0027700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21959, 'Yugong', 'Yugong', 'Yugong,Yugong Xiang,yu gong,yu gong xiang,愚公,愚公乡', 46.4291400, 130.0470300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21960, 'Yuelai', 'Yuelai', 'Huachuan,Huachuan Xian,Hwachwan,Khuachuan'',Khuachuan’,Yueh-lai,Yueh-lai-chen,Yueh-lai-chieh,Yuelai,Yuelai Zhen,Yüeh-lai,Yüeh-lai-chen,Yüeh-lai-chieh,hua chuan xian,yue lai,yue lai zhen,悦来,悦来镇,桦川县', 47.0232500, 130.7129600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21961, 'Yuchi', 'Yuchi', 'Yuchi,Yuchi Chaoxianzu Xiang,yu chi,yu chi chao xian zu xiang,鱼池,鱼池朝鲜族乡', 44.9312400, 128.7620800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21962, 'Yuanlin', 'Yuanlin', 'Juan''lin'',Yuanlin,Yuanlin Zhen,yuan lin,yuan lin zhen,Юаньлинь,原林,原林镇', 49.8854600, 121.3873500, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21963, 'Yuanbao', 'Yuanbao', 'Yuanbao,Yuanbao Zhen,yuan bao,yuan bao zhen,元宝,元宝镇', 45.2574400, 128.2732800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21964, 'Youhao', 'Youhao', 'Youhao,Youhao Jiedao,Youhao Qu,Yu-hao,you hao,you hao jie dao,you hao qu,友好,友好区,友好街道', 47.8530600, 128.8356500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21965, 'Yongheng', 'Yongheng', 'Yongheng,Yongheng Xiang,Yongshun,yong heng,yong heng xiang,永恒,永恒乡', 46.0421200, 130.1648500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21966, 'Yongning', 'Yongning', 'Yongning,Yongning Zhen,Yung-ning,Yung-ning-ch''eng,Yung-ning-ch’eng,Yunninchen,yong ning,yong ning zhen,永宁,永宁镇', 40.5253300, 116.1574800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21967, 'Yongling', 'Yongling', 'Yongling,Yongling Zhen,Yung-ling,Yung-ling-chieh,Yung-ling-kai,Yunlin,yong ling,yong ling zhen,永陵,永陵镇', 41.7080400, 124.8210500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21968, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Zhen,yong feng,yong feng zhen,永丰,永丰镇', 46.8776800, 126.0190100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21969, 'Yongfa', 'Yongfa', 'Yongfa,Yongfa Xiang,yong fa,yong fa xiang,永发,永发乡', 47.1547700, 123.0429200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21970, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Manzu Zhen,Yong’an,Yong’an Manzu Zhen,yong an,yong an man zu zhen,永安,永安满族镇', 46.5499100, 126.6554300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21971, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 45.8131800, 121.6406800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21972, 'Yitulihe', 'Yitulihe', 'I-t''u-li-ho,I-tuli,I-t’u-li-ho,Yitulihe,Yitulihe Zhen,yi tu hei he,yi tu hei he zhen,伊图黑河,伊图黑河镇', 50.6351000, 121.5676600, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21973, 'Yitong', 'Yitong', 'I-t''ung,I-t''ung-chen,I-t''ung-hsien,I-t’ung,I-t’ung-chen,I-t’ung-hsien,Yitong,yi tong,伊通', 43.3262800, 125.2972600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21974, 'Yirshi', 'Yirshi', 'I-erh-hsieh,I-erh-shih,Yi''ershi,Yi''ershi Zhen,Yirshi,Yi’ershi,Yi’ershi Zhen,yi er shi,yi er shi zhen,伊尔施,伊尔施镇', 47.3000000, 119.7500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21975, 'Yinhao', 'Yinhao', 'Yinhao,yin hao,银号', 41.1195900, 110.3063500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21976, 'Yingshouyingzi', 'Yingshouyingzi', 'Ying-shou-ying,Ying-shou-ying-ts''un,Ying-shou-ying-ts’un,Ying-shou-ying-tzi,Ying-shou-ying-tzu,Yingshouyingzi,Yingshouyingzi Zhen,ying shou ying zi,ying shou ying zi zhen,鹰手营子,鹰手营子镇', 40.5514700, 117.6615500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21977, 'Yingluo', 'Yingluo', 'Yingluo,Yingluo Zhen,ying luo,ying luo zhen,英落,英落镇', 40.6427200, 122.6984100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21978, 'Yinglan', 'Yinglan', 'Yinglan,Yinglan Chaoxianzu Xiang,ying lan,ying lan chao xian zu xiang,迎兰,迎兰朝鲜族乡', 46.3407700, 129.5441900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21979, 'Yingkou', 'Yingkou', 'Eiko,Inkou,Newchwang,Niu-chuang,YDD,YKH,Ying-k''ou-hsien,Ying-k''ou-shih,Ying-k’ou-hsien,Ying-k’ou-shih,Yingkou,Yingkou Shi,Yingkow,ingkeou si,ying kou,ying kou shi,Инкоу,営口,営口市,營口,营口,营口市,잉커우 시', 40.6648200, 122.2283300, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21980, 'Ying’ebu', 'Ying''ebu', 'Ying''ebu,Ying''ebu Zhen,Ying-o-pu,Ying’ebu,Ying’ebu Zhen,ying e bu,ying e bu zhen,英额布,英额布镇', 41.7302800, 125.5563900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21981, 'Yilong', 'Yilong', 'Chiu-i-an,I-an,I-an-hsien,I-lung,Lung-ch''uan,Lung-ch''uan-chen,Lung-ch’üan,Lung-ch’üan-chen,Luntsyuan''chzhen'',Luntsyuan’chzhen’,Yi-an hsien,Yilong,Yilong Zhen,yi long,yi long zhen,依龙,依龙镇', 47.4710500, 125.3586700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21982, 'Yilan', 'Yilan', 'I-lan,I-lan-chen,I-lan-hsien,San-hsing,Sang-hsing,Sansing,Sen-hsing,YLN,Yilan,Yilan Xian,Yilan Zhen,yi lan,yi lan xian,yi lan zhen,依兰,依兰县,依兰镇', 46.3161800, 129.5545500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21983, 'Yilaha', 'Yilaha', 'I-la-ha,I-la-ha-chan,Ilakha,Ilakhachzhan,Yilaha,Yilaha Zhen,yi la ha,yi la ha zhen,Илаха,伊拉哈,伊拉哈镇', 48.8211100, 125.1579500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21984, 'Yichun', 'Yichun', 'I-cchun,I-chhun-chhi,I-chhun-chhī,I-chung,I-čchun,Ichun'',LDS,Y Xuan,Y Xuân,Yichun,Yichun i Heilongjiang,Yīchūn,ichun si,ichuni,yaychan,yi chun,yi chun shi,Ĭ-chŭng,Ичунь,یایچان,یکھن، ہیلونگجیانگ,იჩუნი,伊春,伊春市,이춘 시', 47.7214300, 128.8752900, 'CN', '2012-12-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21985, 'Yi’an', 'Yi''an', 'I-an,I-an-chen,T''ai-an,T''ai-an-chen,T’ai-an,T’ai-an-chen,Yi''an,Yi''an Xian,Yi''an Zhen,Yi’an,Yi’an Xian,Yi’an Zhen,yi an,yi an xian,yi an zhen,依安,依安县,依安镇', 47.8890000, 125.3039200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21986, 'Yebaishou', 'Yebaishou', 'Chien-p''ing,Chien-p’ing,Jianping,Teh-pai-shou,Tszyan''pin,Tszyan’pin,Yebaishou,Yeh-pai-shou,Yeh-pai-shou-chen,Yeh-pai-shu,Yeh-po-shou', 41.3975000, 119.6408300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21987, 'Yaotun', 'Yaotun', 'Jaotun'',Yaotun,Yaotun Xiang,yao tun,yao tun xiang,Яотунь,腰屯,腰屯乡', 49.4349200, 127.4956700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21988, 'Yantongtun', 'Yantongtun', 'Yantongtun,Yantongtun Zhen,Yen-t''ung-t''un,Yen-t’ung-t’un,yan tong tun,yan tong tun zhen,烟筒屯,烟筒屯镇', 47.0081700, 124.1674600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21989, 'Yantongshan', 'Yantongshan', 'Yantongshan,Yen-t''ung-shan,Yen-t’ung-shan', 43.2919400, 126.0094400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21990, 'Yanshou', 'Yanshou', 'T''ung-pin,Tunbin,T’ung-pin,Yanshou,Yanshou Xian,Yen-shou,Yen-shou-chen,Yen-shou-hsien,Yen-show,yan shou,yan shou xian,延寿,延寿县', 45.4532400, 128.3267800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21991, 'Yanqing', 'Yanqing', 'Yanqing,Yanqing Xian,Yanqing Zhen,Yen-ch''ing,Yen-ch’ing,Yenking,yan qing,yan qing xian,yan qing zhen,延庆,延庆县,延庆镇', 40.4609300, 115.9715000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21992, 'Yanjiang', 'Yanjiang', 'Huo-erh-mo-chin,Huormojin,Yanjiang,Yanjiang Manzu Dawo''erzu,Yanjiang Manzu Dawo''erzu Xiang,Yanjiang Manzu Dawo’erzu,Yanjiang Manzu Dawo’erzu Xiang,yan jiang,yan jiang man zu da wo er zu,yan jiang man zu da wo er zu xiang,沿江,沿江满族达斡尔族,沿江满族达斡尔族乡', 49.5730800, 127.7826600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21993, 'Yanjia', 'Yanjia', 'Yanjia,Yanjia Zhen,Yen-chia,Yen-chia-t''un,Yen-chia-t’un,yan jia,yan jia zhen,阎家,阎家镇', 46.1005300, 130.5155300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21994, 'Yanji', 'Yanji', 'Chu-tzu-chieh,Chu-tzu-kai,Chü-tzu-chieh,Chü-tzu-kai,Dien Cat,Diên Cát,Jan''czi,YNJ,Yang-chi-t''eng,Yen-chi,Yen-chi-shih,yan ji shi,yangzhy,yanjy,yenji si,yeongil,Јанђи,Яньцзи,يانجي,یانجی,یانگژی,延吉市,연길,옌지 시', 42.9075000, 129.5077800, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21995, 'Yangsong', 'Yangsong', 'Yangsong,Yangsong Zhen,yang song,yang song zhen,杨宋,杨宋镇', 40.2947400, 116.6778100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21996, 'Yangshufang', 'Yangshufang', 'Xiaoshipeng Xiang,Yangshufang,xiao shi peng xiang,yang shu fang,小石棚乡,杨树房', 40.2425400, 122.4328100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21997, 'Yangmulinzi', 'Yangmulinzi', 'Yang-mu-lin,Yangmulinzi,Yangpao,Yangpao Manzu Xiang,yang mu lin zi,yang pao man zu xiang,杨木林子,杨泡满族乡', 42.9022200, 130.4963900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21998, 'Maoqitun', 'Maoqitun', 'Maoqitun,Yang Chia Chuang Tzu,Yang-chang-tzu,Yang-chia-chang-tzu,Yang-kia-chang-tze,Yangjiazhangzi,Yangjiazhangzi Jiedao,Yantszyachzhantszy,mao qi tun,yang jia zhang zi,杨家杖子,毛祁屯', 40.8056400, 120.5447500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(21999, 'Yangjiapu', 'Yangjiapu', 'Yangjiapu,Yangjiapu Zhen,yang jia bao,yang jia bao zhen,杨家堡,杨家堡镇', 40.1928900, 123.3312800, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22000, 'Yangzhen', 'Yangzhen', 'Yang-ko-chuang,Yangechzhuan,Yanggezhuang,Yangzhen,yang ge zhuang,yang zhen,杨各庄,杨镇', 40.1519700, 116.8173500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22001, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,Yang-chiao,Yang-kao,Yang-kao-hsien,Yanggao,Yanggao Xian,long quan,long quan zhen,yang gao xian,阳高县,龙泉,龙泉镇', 40.3638000, 113.6661600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22002, 'Yangfang', 'Yangfang', 'Yanfan,Yang-fang-chen,Yangfang,Yangfang Zhen,yang fang,yang fang zhen,阳坊,阳坊镇', 40.1385700, 116.1285600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22003, 'Yangcao', 'Yangcao', 'Yangcao,Yangcao Zhen,yang cao,yang cao zhen,羊草,羊草镇', 46.3318200, 125.4153000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22004, 'Yanchi', 'Yanchi', 'Yanchi,Yanchi Zhen,Yen-ch''ih,Yen-ch''ih-chih-ts''un,Yen-ch''ih-ts''un,Yen-ch’ih,Yen-ch’ih-chih-ts’un,Yen-ch’ih-ts’un,yan chi,yan chi zhen,雁翅,雁翅镇', 40.0155100, 115.8269600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22005, 'Yakeshi', 'Yakeshi', 'Hsi-kuei-t''u,Hsi-kuei-t’u,Jakehshi,Shih-k''o-ya,Shih-k’o-ya,Xingong Jiedao,Xuguit Qi,Ya-k''o-shih,Ya-k’o-shih,Yakeshi,Yakeshi Shi,xi gui tu qi,xin gong jie dao,ya ke shi,ya ke shi shi,Якэши,喜桂图旗,新工街道,牙克石,牙克石市', 49.2833300, 120.7333300, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22006, 'Yahe', 'Yahe', 'Ya-ho,Yahe,Yahe Xiang,ya he,ya he xiang,亚河,亚河乡', 45.3956300, 130.4276700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22007, 'Yahe', 'Yahe', 'Yahe,Yahe Zhen,ya he,ya he zhen,雅河,雅河镇', 40.2278500, 123.2769500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22008, 'Yagou', 'Yagou', 'Yagou,Yagou Zhen,ya gou,ya gou zhen,亚沟,亚沟镇', 45.4806100, 127.0789100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22009, 'Yadong', 'Yadong', 'Ya-tung,Yadong,Yadong Zhen,ya dong,ya dong zhen,亚东,亚东镇', 48.5031000, 123.7827300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22010, 'Yabuli', 'Yabuli', 'Ya-p''o-lo-ni,Ya-pu-li,Ya-pu-li-chan,Ya-pu-lo-ni,Ya-p’o-lo-ni,Yabuli,Yabuli Zhen,ya bu li,ya bu li zhen,亚布力,亚布力镇', 44.9299000, 128.6087100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22011, 'Xutun', 'Xutun', 'Xutun,Xutun Zhen,xu tun,xu tun zhen,徐屯,徐屯镇', 40.3438000, 122.3885800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22012, 'Xunhe', 'Xunhe', 'Chiu-hsun-ho,Chiu-hsün-ho,Hsun-ho,Hsun-ho-hsien,Hsün-ho,Hsün-ho-hsien,Pi-la-erh,Sun''kheh,Sunho,Sunkhe,Syunkhe,Xunhe,Xunhe Zhen,xun he,xun he zhen,Суньхэ,逊河,逊河镇', 49.3443800, 128.0716500, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22013, 'Xutun', 'Xutun', 'Hsu-chia-t''un,Hsu-chia-t''un-chan,Hsü-chia-t’un,Hsü-chia-t’un-chan,Xujiatun,Xutun,Xutun Zhen,xu tun,xu tun zhen,许屯,许屯镇', 40.0377400, 122.0771900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22014, 'Xuetian', 'Xuetian', 'Xuetian,Xuetian Xiang,xue tian,xue tian xiang,学田,学田乡', 45.6666700, 121.2666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22015, 'Xubu', 'Xubu', 'Hsu-chia-p''u,Hsu-chia-pao,Hsu-pao,Hsü-chia-pao,Hsü-chia-p’u,Hsü-pao,Xubu,Xubu Zhen,xu bao,xu bao zhen,许堡,许堡镇', 40.0279200, 113.7447300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22016, 'Zhangjiakou Shi Xuanhua Qu', 'Zhangjiakou Shi Xuanhua Qu', 'Ch''ang-chia-k''ou-shih,Ch’ang-chia-k’ou-shih,Hsuan-hua,Hsuan-hua-ch''eng,Hsuan-hua-hsien,Hsuan-hua-shih,Hsüan-hua,Hsüan-hua-ch’eng,Hsüan-hua-hsien,Hsüan-hua-shih,Suanhwa,Xuanhua,Zhangjiakou Shi Xuanhua Qu,zhang jia kou shi xuan hua qu,张家口市宣化区', 40.6102800, 115.0447200, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22017, 'Xiwengzhuang', 'Xiwengzhuang', 'Ch''i-weng-chuang,Ch’i-weng-chuang,Hsi-weng-chuang,Xiwengzhuang,Xiwengzhuang Zhen,xi weng zhuang,xi weng zhuang zhen,溪翁庄,溪翁庄镇', 40.4698800, 116.8385700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22018, 'Xiwanzi', 'Xiwanzi', 'Ch''ung-li,Ch''ung-li-hsien,Chongli,Ch’ung-li,Ch’ung-li-hsien,Hsi-wan,Hsi-wan-tzu,Hsiwantze,Siwantze,Siwantzu,T''ai-p''ing-chan,T''ai-p''ing-chuang,T’ai-p’ing-chan,T’ai-p’ing-chuang,Xiwanzi,Xiwanzi Zhen,xi wan zi,西湾子', 40.9713900, 115.2725000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22019, 'Xiuyan', 'Xiuyan', 'Hsiu-yen,Hsiu-yen-chen,Hsiu-yen-hsien,Hsiujen,Siuyen,Xiuyan,Yu-yen,xiu yan,岫岩', 40.2927800, 123.2744400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22020, 'Xitiangezhuang', 'Xitiangezhuang', 'Hsi-t''ien-ko-chuang,Hsi-t’ien-ko-chuang,T''ien-ko-chuang,T’ien-ko-chuang,Xitiangezhuang,Xitiangezhuang Zhen,xi tian ge zhuang,xi tian ge zhuang zhen,西田各庄,西田各庄镇', 40.4036900, 116.7661000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22021, 'Xisi', 'Xisi', 'Xisi,Xisi Zhen,xi si,xi si zhen,西四,西四镇', 40.9662800, 122.4490900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22022, 'Xishanzui', 'Xishanzui', 'Hsi-shan-tsui,Urad Qianqi,Wu-la-t''e-ch''ien-ch''i,Wu-la-t’e-ch’ien-ch’i,Wulateqian Qi.,Xishanzui,Xishanzui Zhen,wu la te qian qi,xi shan zui,xi shan zui zhen,乌拉特前旗,西山嘴,西山嘴镇', 40.7075000, 108.6438900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22023, 'Xipingpo', 'Xipingpo', 'Xiping,Xipingpo,Xipingpo Manzuxiang,xi ping po,xi ping po man zu xiang,西平坡,西平坡满族乡', 40.4482100, 120.1714900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22024, 'Xiping', 'Xiping', 'Datong Xian,Hsi-p''ing,Hsi-p’ing,Ta-t''ung,Ta-t''ung-hsien,Ta-t’ung,Ta-t’ung-hsien,Xiping,Xiping Zhen,da tong xian,xi ping,xi ping zhen,大同县,西坪,西坪镇', 40.0395200, 113.6045500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22025, 'Xiongyue', 'Xiongyue', 'Hiungyocheng,Hsiungyaocheng,Hsiungyueh,JYQ,Xiongyue,Xiongyuecheng,Xióngyuè,xiong yue,xiong yue zhen,熊岳,熊岳镇', 40.1773700, 122.1228400, 'CN', '2013-12-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22026, 'Xiong’erzhai', 'Xiong''erzhai', 'Hsiung-erh-chai,Xiong''erzhai,Xiong''erzhai Xiang,Xiong’erzhai,Xiong’erzhai Xiang,xiong r zhai,xiong r zhai xiang,熊儿寨,熊儿寨乡', 40.2779600, 117.1241600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22027, 'Xinxing', 'Xinxing', 'Xinxing,Xinxing E''lunchchunzu,Xinxing E''lunchunzu Xiang,Xinxing E’lunchchunzu,Xinxing E’lunchunzu Xiang,xin xing,xin xing e lun chun zu,xin xing e lun chun zu xiang,新兴,新兴鄂伦春族,新兴鄂伦春族乡', 49.3683700, 129.0014900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22028, 'Xintun', 'Xintun', 'Xintun,Xintun Xiang,xin tun,xin tun xiang,新屯,新屯乡', 47.8439300, 125.0602500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22029, 'Xintian', 'Xintian', 'Xintian,Xintian Zhen,xin tian,xin tian zhen,新天,新天镇', 51.2035400, 124.2085200, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22030, 'Xintaimen', 'Xintaimen', 'Hsin-t''ai-men,Hsin-t’ai-men,Xintaimen,xin tai men,新台门', 40.8346400, 120.4178100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22031, 'Xinsheng Elunchunzu', 'Xinsheng Elunchunzu', 'Xinsheng Elunchunzu,Xinsheng Elunchunzu Xiang,Xinshengcun,xin sheng e lun chun zu,xin sheng e lun chun zu xiang,新生鄂伦春族,新生鄂伦春族乡', 50.5099300, 126.7914700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22032, 'Xinrong', 'Xinrong', 'Hsin-jung,Hsin-jung-ch''u,Hsin-jung-ch’ü,Nuan-yao-ts''un,Nuan-yao-ts’un,Xinrong,Xinrong Qu,Xinrong Zhen,xin rong,xin rong qu,xin rong zhen,新荣,新荣区,新荣镇', 40.2579000, 113.1360000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22033, 'Xinqing', 'Xinqing', 'Xinqing,xin qing,新青', 48.2870100, 129.5233700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22034, 'Xinmin', 'Xinmin', 'Hsin-min,Hsin-min-chen,Hsin-min-hsien,Hsin-ming-t''ing,Hsin-ming-t’ing,Sin''min'',Sinmin,Xinmin,Синьминь', 41.9908300, 122.8252800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22035, 'Xinlin', 'Xinlin', 'Xinlin,Xinlin Qu,Xinlin Zhen,xin lin,xin lin qu,xin lin zhen,新林,新林区,新林镇', 51.7000000, 124.3333300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22036, 'Xiniqi', 'Xiniqi', 'Hsi-ni-ch''i,Hsi-ni-ch’i,Xiniqi,Xiniqi Zhen,xi ni qi,xi ni qi zhen,西尼气,西尼气镇', 50.3850800, 121.6976700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22037, 'Xinhui', 'Xinhui', 'Ao-han-ch''i,Ao-han-ch’i,Aohan Qi,Hsin-hui,Ts''ai-yuan-tzu,Ts’ai-yüan-tzu,Xinhui,Xinhui Zhen,ao han qi,xin hui,xin hui zhen,敖汉旗,新惠,新惠镇', 42.2838900, 119.8983300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22038, 'Xinhua', 'Xinhua', 'Xinhua,Xinhua Zhen,xin hua,xin hua zhen,新华,新华镇', 47.1130400, 130.2961800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22039, 'Xingshu', 'Xingshu', 'Hsing-shu,Xingshu,Xingshu Chaoxianzu Xiang,xing shu,xing shu chao xian zu xiang,杏树,杏树朝鲜族乡', 45.9206800, 130.5623300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22040, 'Xingshou', 'Xingshou', 'Xingshou,Xingshou Zhen,xing shou,xing shou zhen,兴寿,兴寿镇', 40.2201600, 116.4061600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22041, 'Xingcan', 'Xingcan', 'Xingcan,Xingcan Zhen,Xingshen,xing can,xing can zhen,兴参,兴参镇', 42.4779500, 127.2204500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22042, 'Xingren', 'Xingren', 'Hsing-jen,Hsing-jen-chen,Lung-wang-miao,Xingren,Xingren Zhen,xing ren,xing ren zhen,兴仁,兴仁镇', 47.1749000, 126.1419200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22043, 'Xingnong', 'Xingnong', 'Xingnong,Xingnong Zhen,xing nong,xing nong zhen,兴农,兴农镇', 47.8004100, 125.9574000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22044, 'Xingnong', 'Xingnong', 'Xingnong,Xingnong Zhen,xing nong,xing nong zhen,兴农,兴农镇', 45.5013600, 130.9463300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22045, 'Xinglongshan', 'Xinglongshan', 'Hsing-lung-shan,Xinglongshan', 43.9561100, 125.4661100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22046, 'Xinglongquan', 'Xinglongquan', 'Xinglongquan,Xinglongquan Zhen,xing long quan,xing long quan zhen,兴隆泉,兴隆泉镇', 46.2187200, 124.6162100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22047, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Xiang,xing long,xing long xiang,兴隆,兴隆乡', 48.0317500, 123.6571300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22048, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Xiang,xing long,xing long xiang,兴隆,兴隆乡', 45.3000000, 126.9000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22049, 'Xinglong', 'Xinglong', 'Hsing-lung,Hsing-lung-ch''eng-kuan,Hsing-lung-ch’eng-kuan,Hsing-lung-hsien,Hsing-lung-shan-hsun,Hsing-lung-shan-hsün,Xinglong,xing long,兴隆', 40.4202800, 117.5075000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22050, 'Xinghua', 'Xinghua', 'Hsing-hua,Xinghua,Xinghua Xiang,xing hua,xing hua xiang,兴华,兴华乡', 52.1308700, 126.0162700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22051, 'Xinghua', 'Xinghua', 'Hsing-hua,Hsing-hua-chen,Xinghua,Xinghua Zhen,xing hua,xing hua zhen,兴华,兴华镇', 47.0372000, 126.1812400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22052, 'Dahuanggou', 'Dahuanggou', 'Dahuanggou,Ta-huang-kou,Xinghua,Xinglin Zhen,da huang gou,xing lin zhen,兴林镇,大荒沟', 42.0508300, 126.1265500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22053, 'Xinghe Chengguanzhen', 'Xinghe Chengguanzhen', 'Erh-tao-ho,Hingho,Hingho-hsien,Hsing-ho,Hsing-ho-hsien,Xinghe,Xinghe Chengguanzhen,Xinghe Xian,xing he,xing he cheng guan zhen,xing he xian,兴和,兴和县,兴和城关镇', 40.8755600, 113.8838900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22054, 'Xingguo', 'Xingguo', 'Xingguo,Xingguo Xiang,xing guo,xing guo xiang,兴国,兴国乡', 47.5403700, 126.1815700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22055, 'Xingcheng', 'Xingcheng', 'Hingcheng,Hsing-ch''eng,Hsing-ch''eng-chen,Hsing-ch''eng-hsien,Hsing-ch’eng,Hsing-ch’eng-chen,Hsing-ch’eng-hsien,Ning-yuan,Ning-yuan-chou,Ning-yüan,Ning-yüan-chou,Shinchon,Sinchehn,Xingcheng,Синчэн', 40.6166700, 120.7166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22056, 'Xinfa', 'Xinfa', 'Xinfa,Xinfa Xiang,xin fa,xin fa xiang,新发,新发乡', 44.5833300, 122.4500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22057, 'Xin’e', 'Xin''e', 'Hsin-o-ts''un,Hsin-o-ts’un,Xin''e,Xin''e E''lunchunzu Xiang,Xin''e Elunchunzu,Xin''ecun,Xin’e,Xin’e Elunchunzu,Xin’e E’lunchunzu Xiang,Xin’ecun,xin e,xin e e lun chun zu,xin e e lun chun zu xiang,新鄂,新鄂鄂伦春族,新鄂鄂伦春族乡', 49.1492500, 127.9745300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22058, 'Xindian', 'Xindian', 'Hsin-tien,Xindian,Xindian Zhen,xin dian,xin dian zhen,新甸,新甸镇', 45.9179700, 127.8259700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22059, 'Xindian', 'Xindian', 'Dashan,Xindian,Xindian Manzu Zhen,Xindian Zhen,da shan,xin dian,xin dian man zu zhen,xin dian zhen,大山,新甸,新甸满族镇,新甸镇', 40.1073500, 123.1126600, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22060, 'Xincun', 'Xincun', 'Xincun,Xincun Xiang,xin cun,xin cun xiang,新村,新村乡', 46.8725700, 125.6216700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22061, 'Xinchengzi', 'Xinchengzi', 'Hsin-ch''eng-tzu,Hsin-cheng,Hsin-ch’eng-tzu,Xinchengzi,Xinchengzi Zhen,xin cheng zi,xin cheng zi zhen,新城子,新城子镇', 40.6383900, 117.3230100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22062, 'Gucheng', 'Gucheng', 'Guchenchzhen'',Guchenchzhen’,Gucheng,Gucheng Zhen,Hsin-ch''eng,Hsin-ch’eng,Ku-ch''eng,Ku-ch''eng-chen,Ku-ch’eng,Ku-ch’eng-chen,Xincheng,gu cheng,gu cheng zhen,古城,古城镇', 45.3528000, 130.2854200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22063, 'Xin Bulag', 'Xin Bulag', 'Hobot Xar,Hsiang-huang-ch''i,Hsiang-huang-ch’i,Hsin-pao-la-ka,Hsin-pao-li-ko,Shang-tu-hsiang-huang-ch''i,Shang-tu-hsiang-huang-ch’i,Shang-tu-hsiang-huang-lien-ho-ch''i,Shang-tu-hsiang-huang-lien-ho-ch’i,Xianghuang Qi,Xin Bulag,Xinbo Lage,Xinbo Lage Zhen,xiang huang qi,xin bao la ge,xin bao la ge zhen,新宝拉格,新宝拉格镇,镶黄旗', 42.2375000, 113.8363900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22064, 'Xin’an', 'Xin''an', 'Hsin-an,Hsin-an-chen,Xin''an,Xin''an Chaoxianzu Zhen,Xin’an,Xin’an Chaoxianzu Zhen,xin an,xin an chao xian zu zhen,新安,新安朝鲜族镇', 44.4207400, 129.1194000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22065, 'Xin’an', 'Xin''an', 'Hsin-an,Xin''an,Xin''an Xiang,Xin’an,Xin’an Xiang,xin an,xin an xiang,新安,新安乡', 44.2658500, 127.3652600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22066, 'Ximu', 'Ximu', 'Hsi-mu-ch''eng,Hsi-mu-ch’eng,Hsi-shui-ch''eng,Hsi-shui-ch’eng,Hsin-mu-ch''eng,Hsin-mu-ch’eng,Shimucheng,Ximu,Ximu Zhen,Ximucheng,xi mu,xi mu zhen,析木,析木镇', 40.6997000, 122.9074300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22067, 'Ximapo', 'Ximapo', 'Ximapo,Ximapo Zhen,xi ma po,xi ma po zhen,西马坡,西马坡镇', 40.1667300, 116.6479200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22068, 'Xiliu', 'Xiliu', 'Xiliu,Xiliu Zhen,xi liu,xi liu zhen,西柳,西柳镇', 40.8485800, 122.6241700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22069, 'Xilin Hot', 'Xilin Hot', 'A-pa-ha-na-erh-ch''i,A-pa-ha-na-erh-ch’i,A-pa-ha-na-erh-tso-i-ch''i,A-pa-ha-na-erh-tso-i-ch’i,A-pa-ha-na-erh-yu-i-ch''i,A-pa-ha-na-erh-yu-i-ch’i,A-pa-k''a-pei-tzu-fu,A-pa-k’a-pei-tzu-fu,Abaga Pei-tzu-fu,Abagnar Qi,Hsi-lin-hao-t''e,Hsi-lin-hao-t’e,Hsi-lin-kuo-ch''in,Hsi-lin-kuo-ch’in,Pei-tzu-fu,Pei-tzu-miao,Peitzemiao,Silinghot,XIL,Xilin Hot,Xilinhaote Shi,Xilinhot,a ba ha na er qi,xi lin hao te,xi lin hao te shi,锡林浩特,锡林浩特市,阿巴哈纳尔旗', 43.9666700, 116.0333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22070, 'Xilinhe', 'Xilinhe', 'Xilinhe,Xilinhe Xiang,xi lin he,xi lin he xiang,细鳞河,细鳞河乡', 42.8364700, 129.1580500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22071, 'Xilin', 'Xilin', 'Hsi-lin,Xilin,Xilin Jiedao,Xilin Qu,xi lin,xi lin jie dao,xi lin qu,西林,西林区,西林街道', 47.4760600, 129.3036900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22072, 'Xiji', 'Xiji', 'Hsi-chi,Hsi-chi-ch''ang,Hsi-chi-chen,Hsi-chi-ch’ang,Sitsichang,Xiji,Xiji Zhen,xi ji,xi ji zhen,西集,西集镇', 46.1485200, 127.1705500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22073, 'Xihanling', 'Xihanling', 'Hsi-han-chua-ling,Hsi-han-chuä-ling,Hsi-han-ling,Xihanling,Xihanling Zhen,xi han ling,xi han ling zhen,西韩岭,西韩岭镇', 40.0146900, 113.2399700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22074, 'Xihai', 'Xihai', 'Xihai,Xihai Jiedao,xi hai,xi hai jie dao,西海,西海街道', 40.4339700, 122.3132100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22075, 'Xigangzi', 'Xigangzi', 'Hsi-kang-tzu,Siganczy,Xigangzi,Xigangzi Zhen,xi gang zi,xi gang zi zhen,Сиганцзы,西岗子,西岗子镇', 49.8966000, 127.3387400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22076, 'Xifeng', 'Xifeng', 'Hsi-feng,Hsi-feng-chen,Hsi-feng-hsien,Sifeng,T''ao-lu,T’ao-lu,Xifeng', 42.7372200, 124.7222200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22077, 'Xidoupu', 'Xidoupu', 'Hsi-tou-p''u,Hsi-tou-p’u,Hsi-wu-t''ou-p''u,Hsi-wu-t’ou-p’u,Xidoupu,Xidoupu Zhen,Xinmin,xi dou pu,xi dou pu zhen,xin min,新民,西斗铺,西斗铺镇', 41.2248700, 109.7981100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22078, 'Xicheng', 'Xicheng', 'Hsi-ch''eng,Hsi-ch''eng-chen,Hsi-ch’eng,Hsi-ch’eng-chen,Hsi-ning,Xicheng,Yang-yuan-ch''eng-kuan,Yang-yüan-ch’eng-kuan,Yangyuan,xi cheng,西城', 40.1105600, 114.1588900, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22079, 'Xibeiwang', 'Xibeiwang', 'Hsi-pei-wang,Xibeiwang,Xibeiwang Zhen,xi bei wang,xi bei wang zhen,西北旺,西北旺镇', 40.0456300, 116.2540700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22080, 'Xibali', 'Xibali', 'Hsi-pa-li,Xibali,Xibali Zhen,xi ba li,xi ba li zhen,西八里,西八里镇', 40.4536100, 115.3475000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22081, 'Xiayingzi', 'Xiayingzi', 'Xiayingzi,Xiayingzi Jiedao,xia ying zi,xia ying zi jie dao,下营子,下营子街道', 41.7231800, 124.5521400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22082, 'Xiawa', 'Xiawa', 'Hsia-wa,Xiawa,Xiawa Zhen,xia wa,xia wa zhen,下洼,下洼镇', 42.5862800, 120.5393400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22083, 'Xiaozhuangzi', 'Xiaozhuangzi', 'Xiaozhuangzi,Xiaozhuangzi Zhen,xiao zhuang zi,小庄子', 40.2707800, 120.4299700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22084, 'Xiaoyangqi', 'Xiaoyangqi', 'Hsiao-yang-ch''i,Hsiao-yang-ch’i,Xiaoyangqi,Xiaoyangqi Zhen,xiao yang qi,xiao yang qi zhen,小杨气,小杨气镇', 50.8000000, 124.2833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22085, 'Yanghe', 'Yanghe', 'Hsiao-yang-ho-tzu,Xiaoyanghe,Yang-ho,Yanghe,Yanghe Zhen,yang he,yang he zhen,洋河,洋河镇', 40.0583300, 123.4088900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22086, 'Xiaowuzhan', 'Xiaowuzhan', 'Xiaowuzhan,Xiaowuzhan Zhen,xiao wu zhan,xiao wu zhan zhen,小五站,小五站镇', 45.7263100, 130.7633300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22087, 'Xiaotangshan', 'Xiaotangshan', 'Hsiao-t''ang-shan,Hsiao-t’ang-shan,T''ang-shan,Ta-t''ang-shan,Ta-t’ang-shan,T’ang-shan,Xiaotangshan,Xiaotangshan Zhen,xiao tang shan,xiao tang shan zhen,小汤山,小汤山镇', 40.1766300, 116.3845600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22088, 'Xiaoshi', 'Xiaoshi', 'Benxi,Benxi Xian,Hsiao-shih,Hsiao-shih-chen,Pen-ch''i,Pen-ch''i-hsien,Pen-ch’i,Pen-ch’i-hsien,Pen-hsi,Pen-hsi-hsien,Xiaoshi,Xiaoshi Zhen,ben xi,ben xi xian,xiao shi,xiao shi zhen,小市,小市镇,本溪,本溪县', 41.2971100, 124.1209200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22089, 'Xiaoling', 'Xiaoling', 'Hsiao-ling,Xiaoling,Xiaoling Zhen,xiao ling,xiao ling zhen,小岭,小岭镇', 45.3363700, 127.3053900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22090, 'Xiaochengzi', 'Xiaochengzi', 'Hsiao-ch''eng-tzu,Hsiao-ch’eng-tzu,Xiaochengzi,Xiaochengzi Zhen,xiao cheng zi,xiao cheng zi zhen,小城子,小城子镇', 42.8899900, 123.2045200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22091, 'Xianrenqiao', 'Xianrenqiao', 'Daying,Ta-ying,Xianrenqiao,Xianrenqiao Zhen,xian ren qiao,xian ren qiao zhen,仙人桥,仙人桥镇', 42.1720000, 127.2316000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22092, 'Xiangying', 'Xiangying', 'Xiangying,Xiangying Xian,xiang ying,xiang ying xiang,香营,香营乡', 40.5676400, 116.1467000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22093, 'Xiangyang', 'Xiangyang', 'Hsiang-yang,Xiangyang,Xiangyang Zhen,xiang yang,xiang yang zhen,向阳,向阳镇', 44.6208600, 127.4219800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22094, 'Xianglan', 'Xianglan', 'Hsiang-lan,Xianglan,Xianglan Zhen,xiang lan,xiang lan zhen,香兰,香兰镇', 46.6493000, 129.7501500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22095, 'Xianghai', 'Xianghai', 'Hsiang-hai-miao,Xianghai,Xianghai Mengguzu Xiang,xiang hai,xiang hai meng gu zu xiang,向海,向海蒙古族乡', 45.0333300, 122.3500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22096, 'Xiangfu', 'Xiangfu', 'Xiangfu,Xiangfu Zhen,xiang fu,xiang fu zhen,祥富,祥富镇', 47.2756000, 126.7820300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22097, 'Xi Ail', 'Xi Ail', 'Xi Ail,Xi''aili,Xi''aili Mengguzu Xiang,Xi’aili,Xi’aili Mengguzu Xiang,xi ai li,xi ai li meng gu zu xiang,西艾力,西艾力蒙古族乡', 44.9000000, 122.8000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22098, 'Chengzhen', 'Chengzhen', 'Chengzhen,Hsia-hua-yuan,Hsia-hua-yüan,Xiahuayuan,cheng zhen,城镇', 40.4797200, 115.2677800, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22099, 'Xiachengzi', 'Xiachengzi', 'Hsia-ch''eng-tzu,Hsia-ch''eng-tzu-ts''un,Hsia-ch’eng-tzu,Hsia-ch’eng-tzu-ts’un,Hsiao-ch''eng-tzu,Hsiao-ch’eng-tzu,Syachentszy,Xiachengzi,Xiachengzi Zhen,xia cheng zi,xia cheng zi zhen,下城子,下城子镇', 44.6862500, 130.4510500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22100, 'Xar Holoi', 'Xar Holoi', 'Sharihaolai,Sharihaolai Zhen,Xar Holoi,sha ri hao lai,sha ri hao lai zhen,沙日浩来,沙日浩来镇', 42.5599400, 120.7544200, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22101, 'Xamba', 'Xamba', 'Hang-chin-hou-ch''i,Hang-chin-hou-ch’i,Hanggin Houqi,Hangginhou Qi,Hsia-pa,Shan''ba,Shan-pa,Shan-pa-chen,Shan-pa-shih,Shanba,Shanba Zhen,Shan’ba,Shenpa,T''ai-an-chen,T’ai-an-chen,Xamba,hang jin hou qi,shan ba,shan ba zhen,杭锦后旗,陕坝,陕坝镇', 40.8847200, 107.1400000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22102, 'Wuyapao', 'Wuyapao', 'Wuyapao,Wuyapao Zhen,wu ya pao,wu ya pao zhen,乌鸦泡,乌鸦泡镇', 45.9756300, 128.8467000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22103, 'Wumahe', 'Wumahe', 'Wumahe,Wumahe Jiedao,Wumahe Qu,wu ma he,wu ma he jie dao,wu ma he qu,乌马河,乌马河区,乌马河街道', 47.7234800, 128.7927700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22104, 'Wulu Butie', 'Wulu Butie', 'Wu-lu-pu-t''ieh,Wu-lu-pu-t’ieh,Wulu Butie,Wulu Butie Zhen,wu lu bu tie,wu lu bu tie zhen,乌鲁布铁,乌鲁布铁镇', 49.8925000, 124.3461100, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22105, 'Wulin', 'Wulin', 'Wu-ho-lin,Wulin,Wulin Zhen,wu lin,wu lin zhen,五林,五林镇', 44.8191000, 129.7918000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22106, 'Xiwulan Bulang', 'Xiwulan Bulang', 'Ch''ien-wu-lan-pu-lang,Ch’ien-wu-lan-pu-lang,Ulan-Bulang,Ulanbulan,Wu-lan-pu-lang,Wulanbulang,Wulangpulang,Xiwulan Bulang,Xiwulan Bulang Xiang,wu lan bu lang,xi wu lan bu lang,xi wu lan bu lang xiang,乌兰不浪,西乌兰不浪,西乌兰不浪乡', 41.1186300, 110.9692000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22107, 'Wukeshu', 'Wukeshu', 'Wu-k''o-shu,Wu-k’o-shu,Wukeshu,Wukeshu Zhen,wu ke shu,wu ke shu zhen,五棵树,五棵树镇', 46.0734300, 123.7096500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22108, 'Wujimi', 'Wujimi', 'Wu-chi-mi,Wujimi,Wujimi Xiang,wu ji mi,wu ji mi xiang,乌吉密,乌吉密乡', 45.2185300, 127.8358000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22109, 'Wudan', 'Wudan', 'Ch''uan-ning,Ch’üan-ning,Ongniud Qi,Vennyutetsi,Weng-niu-t''e-ch''i,Weng-niu-t’e-ch’i,Wengniute Qi,Wu-tan,Wu-tan-ch''eng,Wu-tan-ch’eng,Wudan,Wudan Zhen,weng niu te qi,wu dan,wu dan zhen,乌丹,乌丹镇,翁牛特旗', 42.9344400, 119.0238900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22110, 'Wuchang', 'Wuchang', 'Huan-hsi-ling,Uchan,Wu-ch''ang-chen,Wu-ch''ang-hsien,Wu-ch''ang-t''ing,Wu-ch’ang-chen,Wu-ch’ang-hsien,Wu-ch’ang-t’ing,Wuchang,Wuchang Shi,Wuchang Zhen,Wutschangting,wu chang,wu chang shi,wu chang zhen,Учан,五常,五常市,五常镇', 44.9142800, 127.1500100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22111, 'Wuchagou', 'Wuchagou', 'Wu-ch''a-kou,Wu-ch’a-kou,Wu-i-kou,Wuchagou,Wuchagou Zhen,wu cha gou,wu cha gou zhen,五岔沟,五岔沟镇', 46.7410300, 120.3077500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22112, 'Woniutu', 'Woniutu', 'Woniutu,Woniutu Dawo''er Zu,Woniutu Dawo''er Zu Zhen,Woniutu Dawo’er Zu,Woniutu Dawo’er Zu Zhen,wo niu tu,wo niu tu da wo er zu,wo niu tu da wo er zu zhen,卧牛吐,卧牛吐达斡尔族,卧牛吐达斡尔族镇', 47.5622200, 123.9869400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22113, 'Woniuhe', 'Woniuhe', 'Woniuhe,Woniuhe Xiang,wo niu he,wo niu he xiang,卧牛河,卧牛河乡', 49.5470700, 127.1320400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22114, 'Woniuhe', 'Woniuhe', 'Woniuhe,Woniuhe Zhen,wo niu he,wo niu he zhen,卧牛河,卧牛河镇', 48.1010500, 122.6578700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22115, 'Wolongquan', 'Wolongquan', 'Wolongquan,Wolongquan Zhen,wo long quan,wo long quan zhen,卧龙泉,卧龙泉镇', 40.2581600, 122.7351000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22116, 'Wolitun', 'Wolitun', 'Wolitun,Wolitun Xiang,wo li tun,wo li tun xiang,卧里屯,卧里屯乡', 46.4678400, 125.2873000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22117, 'Woken', 'Woken', 'Qijia,Woken,Woken Zhen,qi jia,wo ken,wo ken zhen,倭肯,倭肯镇,祁家', 45.9992300, 130.5122800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22118, 'Dalian', 'Dalian', 'Dalian,Wenxiang,Wenxiang Zhen,da lian,wen xiang zhen,温香镇,达连', 41.0695900, 122.5985100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22119, 'Wenquan', 'Wenquan', 'Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 40.0420400, 116.1908100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22120, 'Wenkutu', 'Wenkutu', 'Wenkutu,Wenkutu Xiang,wen ku tu,wen ku tu xiang,温库图,温库图乡', 49.4464700, 122.4844700, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22121, 'Wenchun', 'Wenchun', 'Wen-ch''un-ts''un,Wen-ch’un-ts’un,Wenchun,Wenchun Zhen,wen chun,wen chun zhen,温春,温春镇', 44.4301300, 129.4869600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22122, 'Weiziyu', 'Weiziyu', 'Wei-tzu-yu,Wei-tzu-yü,Weiziyu,Weiziyu Zhen,wei zi yu,wei zi yu zhen,苇子峪,苇子峪镇', 41.4362200, 124.5049200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22123, 'Weihe', 'Weihe', 'Veishakhe,Wei-ho,Wei-ho-hsien,Wei-sha-ho,Weichaho,Weihe,Weihe Zhen,wei he,wei he zhen,苇河,苇河镇', 44.9553500, 128.3773500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22124, 'Weichang', 'Weichang', 'Chiutzeshan,Chui-tzu-shan,Chzhuytszyshan,Tienpanshan,Tienpaoshan,Veychan,Wei-chang-hsien,Weichang,Zhuizishan,wei chang,围场', 41.9447200, 117.7480600, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22125, 'Waxing', 'Waxing', 'Wa-hsing-chen,Waxing,Waxing Zhen,wa xing,wa xing zhen,洼兴,洼兴镇', 46.3569600, 127.4790400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22126, 'Wanliang', 'Wanliang', 'Wan-liang-ho,Wanliang,Wanliang Zhen,wan liang,wan liang zhen,万良,万良镇', 42.4322200, 127.2891700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22127, 'Wanghai', 'Wanghai', 'Dawanghaizhai,Wanghai,Wanghai Jiedao,Wangzhai,da wang hai zhai,wang hai,wang hai jie dao,大望海寨,望海,望海街道', 40.3413000, 122.1688600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22128, 'Wangshi', 'Wangshi', 'Wangshi,Wangshi Zhen,wang shi,wang shi zhen,王石,王石镇', 40.8598600, 122.8162500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22129, 'Wangqing', 'Wangqing', 'Ta-tu-ch''uan,Ta-tu-ch’uan,Ta-wang-kou,Vancine,Wang-ch''ing,Wang-ch''ing-chen,Wang-ch''ing-hsien,Wang-ch’ing,Wang-ch’ing-chen,Wang-ch’ing-hsien,Wangqing,Wangqing Xian,Wangqing Zhen,wang qing,wang qing xian,wang qing zhen,Ванцине,汪清,王清县,王清镇', 43.3217900, 129.7634200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22130, 'Hepingjie', 'Hepingjie', 'Hepingjie,Wan-kou,Wangou,Wangou Zhen,he ping jie,wan gou,wan gou zhen,和平街,湾沟,湾沟镇', 42.0597200, 126.9158300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22131, 'Wangkui', 'Wangkui', 'Shuang-lung,Ta-wu-ching-tzu,Wang-k''uei,Wang-k''uei-chen,Wang-k''uei-hsien,Wang-k’uei,Wang-k’uei-chen,Wang-k’uei-hsien,Wangkui,Wangkui Xian,Wangkui Zhen,wang kui,wang kui xian,wang kui zhen,望奎,望奎县,望奎镇', 46.8328300, 126.4776800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22132, 'Wangjiang', 'Wangjiang', 'Wangjiang,Wangjiang Zhen,wang jiang,wang jiang zhen,望江,望江镇', 46.8543600, 130.1607100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22133, 'Wangbao', 'Wangbao', 'Wangbao,Wangbao Zhen,wang bao zhen,王宝镇', 40.1544200, 120.1315600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22134, 'Wanfu', 'Wanfu', 'Wan-fu-chuang,Wan-fu-chuang-ts''un,Wan-fu-chuang-ts’un,Wan-fu-chung-ts''un,Wan-fu-chung-ts’un,Wanfu,Wanfu Zhen,Wanfuchwang,Wang-tu-chuang,wan fu,wan fu zhen,万福,万福镇', 40.1389600, 122.5467700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22135, 'Dadianzi', 'Dadianzi', 'Dadianzi,Ta-tien-tzu,Wan-p''ao-ho-tzu,Wan-pao,Wan-p’ao-ho-tzu,Wanbao Zhen,Wang-p''ao-ho-tzu,Wang-p’ao-ho-tzu,Wanpaotun,da dian zi,wan bao zhen,万宝镇,大甸子', 42.8730600, 128.3244400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22136, 'Wafang', 'Wafang', 'Wafang,Wafang Zhen,wa fang,wa fang zhen,瓦房,瓦房镇', 45.6833300, 122.3500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22137, 'Uliastai', 'Uliastai', 'Dong Ujimqin Qi,Dongwuzhumuqin Qi,Dun''uchzhumutsintsi,Dun’uchzhumutsintsi,La-ma-k''u-lieh-miao,La-ma-k''u-lien-miao,La-ma-k''u-lun-miao,La-ma-k’u-lieh-miao,La-ma-k’u-lien-miao,La-ma-k’u-lun-miao,Lamakhure Sume,Lamakoulun,Lamakoulunmiao,Lamakulienmiay,Ramakuresumu,Ramakuresūmu,Sumoyn Khuren Sume,Sumyyn Khuren''-Sume,Sumyyn Khuren’-Sume,Tung-wu-chu-mu-ch''in-ch''i,Tung-wu-chu-mu-ch’in-ch’i,Uliastai,Wu-li-ya-ssu-t''ai,Wu-li-ya-ssu-t’ai,Wuliyasitai,Wuliyasitai Zhen,dong wu zhu mu qin qi,la ma ku lun miao,wu li ya si tai,wu li ya si tai zhen,东乌珠穆沁旗,乌里雅斯太,乌里雅斯太镇,喇嘛库伦庙', 45.5500000, 116.8333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22138, 'Ulan Hua', 'Ulan Hua', 'Dorbod Qi,Durben Khukhut Banner,Siziwang Qi,Ssu-tzu-wang-ch''i,Ssu-tzu-wang-ch’i,Ulan Hua,Ulan''khua,Ulan’khua,Wu-lan-hua,Wu-lan-hua-chen,Wulanhua,Wulanhua Zhen,si zi wang qi,wu lan hua,wu lan hua zhen,乌兰花,乌兰花镇,四子王旗', 41.5130600, 111.6963900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22139, 'Ulanhot', 'Ulanhot', 'HLH,Horqin Youyi Qianqi,Huai-yuan-chen,Huai-yuän-chen,K''o-erh-ch''in-yu-ch''ien-ch''i,K''o-erh-ch''in-yu-i-ch''ien-ch''i,K’o-erh-ch’in-yu-ch’ien-ch’i,K’o-erh-ch’in-yu-i-ch’ien-ch’i,Ulan Hot,Ulan Hoto,Ulan-Khoto,Ulanhot,Ulanhot Shi,Van''''yemyao,Van’’yemyao,Wang-yeh-miao,Wangyemiao,Wu-lan-hao-t''e,Wu-lan-hao-t''e-shih,Wu-lan-hao-t’e,Wu-lan-hao-t’e-shih,Wulanhaote Shi,wang ye miao,wu lan hao te,wu lan hao te shi,乌兰浩特,乌兰浩特市,王爷庙', 46.0833300, 122.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22140, 'Wulan Hada', 'Wulan Hada', 'Ulan Had,Ulan Had Sum,Wu-lan-ha-ta,Wulan Hada,Wulan Hada Sumu,wu lan ha da,wu lan ha da su mu,乌兰哈达,乌兰哈达苏木', 41.6301400, 113.1855500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22141, 'Tushan', 'Tushan', 'T''u-shan-tzu-shih,Tu-shan-tzu,Tushan,Tushan Zhen,Tushanzi,T’u-shan-tzu-shih,tu shan,tu shan zhen,tu shan zi,土山,土山子,土山镇', 42.6282300, 129.0340600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22142, 'Tuquan', 'Tuquan', 'K''o-erh-ch''in-yu-i-chung-ch''i,K’o-erh-ch’in-yu-i-chung-ch’i,Li-ch''uan,Li-ch’üan,T''u-ch''uan,T''u-ch''uan-chen,T''u-ch''uan-hsien,Tuquan,Tuquan Xian,Tuquan Zhen,Tutsyuan'',Tutsyuan’,T’u-ch’üan,T’u-ch’üan-chen,T’u-ch’üan-hsien,tu quan,tu quan xian,tu quan zhen,突泉,突泉县,突泉镇', 45.4030400, 121.6046200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22143, 'Tuozaminnutuke', 'Tuozaminnutuke', 'T''o-cha-min-nu-t''u-k''o,Tuozaminnutuke,Tuozhamin,Tuozhamin Xiang,Tuozhaminnutuke,T’o-cha-min-nu-t’u-k’o,tuo zha min,tuo zha min xiang,托扎敏,托扎敏乡', 50.1594400, 123.1030600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22144, 'Tuoyaozi', 'Tuoyaozi', 'T''o-yao-tzu,Tuoyaozi,Tuoyaozi Zhen,T’o-yao-tzu,tuo yao zi,tuo yao zi zhen,驼腰子,驼腰子镇', 46.2377100, 130.7777300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22145, 'Tumen', 'Tumen', 'T''u-men-chan,T''u-men-shih,Tjumenskij,Tumen,T’u-men-chan,T’u-men-shih,Тюменский', 42.9661100, 129.8425000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22146, 'Tulongshan', 'Tulongshan', 'T''u-lung-shan,Tulongshan,Tulongshan Zhen,T’u-lung-shan,tu long shan,tu long shan zhen,土龙山,土龙山镇', 46.3486200, 130.2158400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22147, 'Tulihe', 'Tulihe', 'T''u-li-ho,Tulihe,Tulihe Zhen,T’u-li-ho,tu li he,tu li he zhen,图里河,图里河镇', 50.4835400, 121.6744300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22148, 'Tule Mod', 'Tule Mod', 'T''u-lieh-mao-tu,Tule Mod,Tuliemaodu,Tuliemaodu Zhen,T’u-lieh-mao-tu,tu lie mao dou,tu lie mao dou zhen,吐列毛都,吐列毛都镇', 45.5500000, 120.8666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22149, 'Tuchengzi', 'Tuchengzi', 'Tuchengzi,Tuchengzi Zhen,tu cheng zi,tu cheng zi zhen,土城子,土城子镇', 42.3391500, 120.8075800, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22150, 'Tuanshanzi', 'Tuanshanzi', 'T''uan-shan-tzu,Tuanshanzi,Tuanshanzi Xiang,T’uan-shan-tzu,tuan shan zi,tuan shan zi xiang,团山子,团山子乡', 46.3152600, 129.9050500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22151, 'Tuanjie', 'Tuanjie', 'Tuanjie,Tuanjie Zhen,tuan jie,tuan jie zhen,团结,团结镇', 47.4844600, 130.8713300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22152, 'Touzhan', 'Touzhan', 'Touzhan,Touzhan Xiang,tou zhan,tou zhan xiang,头站,头站乡', 46.9600100, 123.2529700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22153, 'Beixinjie', 'Beixinjie', 'Beixinjie,Shanhochen,T''ou-tao-kou,T''u-ta-kou,Toudao,Toudao Zhen,Toudaogou,Towtaokow,T’ou-tao-kou,T’u-ta-kou,bei xin jie,tou dao gou,tou dao zhen,北新街,头道沟,头道镇', 42.7484000, 129.1989800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22154, 'Toudao', 'Toudao', 'T''ou-tao,T''ou-tao-wai-tzu,Toudao,Toudao Zhen,T’ou-tao,T’ou-tao-wai-tzu,tou dao,tou dao zhen,头道,头道镇', 41.5124400, 125.8721200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22155, 'Tongyuanpu', 'Tongyuanpu', 'T''ung-yuan-p''u,T''ung-yuan-pao,T''ung-yun-p''u,Tongyuanpu,Tongyuanpu Zhen,Tung-yuan-pau,T’ung-yun-p’u,T’ung-yüan-pao,T’ung-yüan-p’u,tong yuan bao,tong yuan bao zhen,通远堡,通远堡镇', 40.7922200, 123.9158300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22156, 'Tongquan', 'Tongquan', 'Tongquan,Tongquan Xiang,tong quan,tong quan xiang,通泉,通泉乡', 47.3008400, 125.9290000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22157, 'Tongliao', 'Tongliao', 'Bayan Tala,Horqin Qu,Ke''erqin Qu,Ke’erqin Qu,Pa-lin-ai-hsin,Pai-an-ta-la,Pai-yin-t''ai-lai,Pai-yin-t’ai-lai,Payintala,T''ung-liao,T''ung-liao-hsien,T''ung-liao-shih,TGO,Thong Lieu,Thong-liau-chhi,Thong-liâu-chhī,Thung-liau-su,Thông Liêu,Thûng-liàu-sṳ,Tongliao,Tongliao Shi,Tonljao khot,Tung-lieu,Tunglao,Tungliaochen,Tunljao,Tŭng-lièu,T’ung-liao,T’ung-liao-hsien,T’ung-liao-shih,ba yan ta la,ke er qin qu,tong liao,tong liao shi,tunglyao si,twnglyaw,Тонляо хот,Тунгљао,Тунляо,تونگلیاو,ٹونگلیاو,巴彦塔拉,科尔沁区,通辽,通辽市,通遼,通遼市,퉁랴오 시', 43.6125000, 122.2652800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22158, 'Tongle', 'Tongle', 'T''ung-le,Tongle,Tongle Xiang,T’ung-le,tong le,tong le xiang,同乐,同乐乡', 47.0564600, 127.3940500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22159, 'Tongjiang', 'Tongjiang', 'T''ung-chiang,T''ung-chiang-fou,Tongjiang,Tongjiang Zhen,T’ung-chiang,T’ung-chiang-fou,tong jiang,tong jiang zhen,通江,通江镇', 46.6517800, 126.4497900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22160, 'Tonghe', 'Tonghe', 'Ch''a-lin,Ch’a-lin,T''ung-ho,T''ung-ho-chen,T''ung-ho-hsien,Ta-t''ung,Ta-t’ung,Tonghe,Tonghe Xian,Tunkho,T’ung-ho,T’ung-ho-chen,T’ung-ho-hsien,tong he,tong he xian,通河,通河县', 45.9761000, 128.7428900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22161, 'Tongda', 'Tongda', 'Tongda,Tongda Zhen,tong da,tong da zhen,通达,通达镇', 47.1728100, 125.6317000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22162, 'Tongbei', 'Tongbei', 'T''ung-pei,Tongbei,Tongbei Zhen,T’ung-pei,tong bei,tong bei zhen,通北,通北镇', 47.7700700, 126.7632700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22163, 'Tumu’ertai', 'Tumu''ertai', 'Ch''a-ha-erh-yu-hou-ch''i,Ch’a-ha-erh-yu-hou-ch’i,T''u-mu-erh-t''ai,T''u-mu-lu-t''ai,T''u-mu-t''ai-erh,Tomortai,Tomortai Zhen,Tomortei,Tumourtai,Tumu''ertai,Tumu''ertai Zhen,Tumu’ertai,Tumu’ertai Zhen,T’u-mu-erh-t’ai,T’u-mu-lu-t’ai,T’u-mu-t’ai-erh,tu mu er tai,tu mu er tai zhen,土木尔台,土木尔台镇', 41.8422800, 113.1428600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22164, 'Togrog Ul', 'Togrog Ul', 'Ch''a-ha-erh-yu-ch''ien-ch''i,Ch''a-ha-erh-yu-i-ch''ien-ch''i,Ch''a-yu-ch''ien-ch''i,Chaha''eryouyiqian Qi,Chaha’eryouyiqian Qi,Ch’a-ha-erh-yu-ch’ien-ch’i,Ch’a-ha-erh-yu-i-ch’ien-ch’i,Ch’a-yu-ch’ien-ch’i,Kuan-ts''un,Kuan-ts’un,Qahar Youyi Qianqi,T''u-kuei-wu-la,Togrog Ul,Togrog Ul Xiang,Tuguiwula,Tuguiwula Zhen,T’u-kuei-wu-la,cha ha er you yi qian qi,tu gui wu la,tu gui wu la xiang,tu gui wu la zhen,土贵乌拉,土贵乌拉乡,土贵乌拉镇,察哈尔右翼前旗', 40.7867000, 113.2050000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22165, 'Tieling', 'Tieling', 'Tieling,Tieling Zhen,tie ling,tie ling zhen,铁岭,铁岭镇', 44.5915300, 129.6777600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22166, 'Tieling', 'Tieling', 'T''e-ling,T''ieh-ling,T''ieh-ling-hsien,TTV,Telin,Tieling,Tiělíng,T’e-ling,T’ieh-ling,T’ieh-ling-hsien,tie ling,tyeling si,zhi ling shi,Телин,鉄嶺市,鐵嶺,铁岭,톄링 시', 42.2930600, 123.8413900, 'CN', '2014-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22167, 'Tieli', 'Tieli', 'T''ieh-li,T''ieh-li-chen,T''ieh-li-hsien,T''ieh-shan-pao,Teli,Tieli,Tieli Shi,Tieli Zhen,T’ieh-li,T’ieh-li-chen,T’ieh-li-hsien,T’ieh-shan-pao,tie li,tie li shi,tie li zhen,铁力,铁力市,铁力镇', 46.9804300, 128.0449700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22168, 'Tianzhuangtai', 'Tianzhuangtai', 'T''ien-chuang-t''ai,Tianzhuangtai,Tianzhuangtai Zhen,Tienchwangtai,T’ien-chuang-t’ai,tian zhuang tai,tian zhuang tai zhen,田庄台,田庄台镇', 40.8391400, 122.1380200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22169, 'Tianzhu', 'Tianzhu', 'T''ien-chu,T''ien-chu-ts''un,Tianzhu,Tianzhu Zhen,T’ien-chu,T’ien-chu-ts’un,tian zhu,tian zhu zhen,天竺,天竺镇', 40.0575600, 116.5745500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22170, 'Yuquan', 'Yuquan', 'T''ien-chen,T''ien-chen-hsien,T''ien-chen-hsien-ch''eng,Tianzhen,Tianzhen Xian,T’ien-chen,T’ien-chen-hsien,T’ien-chen-hsien-ch’eng,Yuquan,Yuquan Zhen,tian zhen xian,yu quan,yu quan zhen,天镇县,玉泉,玉泉镇', 40.4425900, 113.9744200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22171, 'Tianyi', 'Tianyi', 'Ninchen,Ningcheng,Ningcheng Xian,T''ien-i,T''ien-i-hao,Tianyi,Tianyi Zhen,T’ien-i,T’ien-i-hao,ning cheng xian,tian yi,tian yi zhen,天义,天义镇,宁城县', 41.5666700, 119.3333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22172, 'Tianshifu', 'Tianshifu', 'Dapu,T''ien-shih-fu,T''ien-shih-fu-kou,T''ien-shih-fu-kou-k''ou,T''ien-shih-fu-kow,T''ien-shih-fu-ku-k''ou,T''ien-tzu-fu,T''ien-tzu-fu-kou-k''ou,Tianshifu,Tianshifu Zhen,Tien-shi-fu,T’ien-shih-fu,T’ien-shih-fu-kou,T’ien-shih-fu-kou-k’ou,T’ien-shih-fu-kow,T’ien-shih-fu-ku-k’ou,T’ien-tzu-fu,T’ien-tzu-fu-kou-k’ou,da bao,tian shi fu,tian shi fu zhen,大堡,田师付,田师付镇', 41.2556300, 124.3531300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22173, 'Tianshan', 'Tianshan', 'A-lu-k''o-erh-ch''in-ch''i,A-lu-k’o-erh-ch’in-ch’i,Ar Horqin Qi,Ch''a-pu-kan-miao,Ch’a-pu-kan-miao,T''ien-shan,Tianshan,Tianshan Zhen,T’ien-shan,a lu ke er qin qi,tian shan,tian shan zhen,天山,天山镇,阿鲁科尔沁旗', 43.8873700, 120.0933600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22174, 'Tianqiaoling', 'Tianqiaoling', 'T''ien-ch''iao-ling,Tianqiaoling,Tianqiaoling Zhen,T’ien-ch’iao-ling,tian qiao ling,tian qiao ling zhen,天桥岭,天桥岭镇', 43.5900700, 129.6297400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22175, 'Tianmen', 'Tianmen', 'Nan-t''ien-men,Nan-t''ien-men-t''un,Nan-t’ien-men,Nan-t’ien-men-t’un,T''ien-men,Tianmen,Tianmen Xiang,T’ien-men,tian men,tian men xiang,天门,天门乡', 45.8816700, 128.6648800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22176, 'Tengke', 'Tengke', 'Tengke,Tengke Xiang,teng ke,teng ke xiang,腾克,腾克乡', 49.0110700, 124.7251000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22177, 'Fu’an', 'Fu''an', 'Fu''an,Fu’an,T''eng-ao-chen,T''eng-ao-p''u-ts''un,T''eng-ao-pao,Teng''ao,Teng''ao Zhen,Teng''aopu,Teng-ao-tao,Teng’ao,Teng’ao Zhen,Teng’aopu,T’eng-ao-chen,T’eng-ao-pao,T’eng-ao-p’u-ts’un,fu an,teng ao zhen,福安,腾鳌镇', 41.0750000, 122.8305600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22178, 'Tazicheng', 'Tazicheng', 'T''a-tzu-ch''eng,Tazicheng,Tazicheng Zhen,T’a-tzu-ch’eng,Wu-hsing,ta zi cheng,ta zi cheng zhen,塔子城,塔子城镇', 46.6083600, 123.0577700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22179, 'Tayuan', 'Tayuan', 'Tayuan,Tayuan Zhen,ta yuan,ta yuan zhen,塔源,塔源镇', 51.4513600, 124.2654100, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22180, 'Tashantun', 'Tashantun', 'Tashantun,Tashantun Zhen,ta shan tun,ta shan tun zhen,塔山屯,塔山屯镇', 40.2549400, 120.3954900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22181, 'Yingta', 'Yingta', 'Tashan,Tashan Xiang,Yingta,ta shan,ying ta,塔山,英塔', 40.8456900, 120.9360300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22182, 'Targen', 'Targen', 'Ta''ergen,Ta''ergen Zhen,Targen,Ta’ergen,Ta’ergen Zhen,ta er gen,ta er gen zhen,塔尔根,塔尔根镇', 52.2405200, 124.7076500, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22183, 'Taoshan', 'Taoshan', 'Taoshan,Taoshan Zhen,tao shan,tao shan zhen,桃山,桃山镇', 46.9230400, 128.1652000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22184, 'Guangming', 'Guangming', 'Guangming,T''ao-nan-chen,T''ao-nan-fu,T''ao-nan-hsien,Tao''an,Taonan,Taonan Shi,Taonan'',Tao’an,T’ao-nan-chen,T’ao-nan-fu,T’ao-nan-hsien,guang ming,tao nan shi,Таонань,光明,洮南市', 45.3333300, 122.7833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22185, 'Taohua', 'Taohua', 'T''ao-hua-p''u,Taohua,Taohua Zhen,T’ao-hua-p’u,tao hua,tao hua zhen,桃花,桃花镇', 40.0595600, 115.0147200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22186, 'Taodong', 'Taodong', 'T''ao-tung,Taodong,Taodong Xiang,T’ao-tung,tao dong,tao dong xiang,洮东,洮东乡', 45.5666700, 122.5500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22187, 'Tantu', 'Tantu', 'Tantu,Tantu Zhen,tan tu,tan tu zhen,坦途,坦途镇', 46.1848800, 123.3423400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22188, 'Tangyuan', 'Tangyuan', 'T''ang-wang-ho,T''ang-yuan-chen,T''ang-yuan-hsien,Tangyuan,Tangyuan Xian,Tangyuan Zhen,T’ang-wang-ho,T’ang-yüan-chen,T’ang-yüan-hsien,tang yuan,tang yuan xian,tang yuan zhen,汤原,汤原县,汤原镇', 46.7264200, 129.8996600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22189, 'Tangtu', 'Tangtu', 'T''ang-t''u-huo-lo,Tangtu,Tangtu Manzu Xiang,T’ang-t’u-huo-lo,tang tu,tang tu man zu xiang,汤图,汤图满族乡', 41.8272300, 124.3369500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22190, 'Tanghekou', 'Tanghekou', 'T''ang-ho-k''ou,Tanghekou,Tanghekou Zhen,T’ang-ho-k’ou,tang he kou,tang he kou zhen,汤河口,汤河口镇', 40.7345600, 116.6371200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22191, 'Tangchi', 'Tangchi', 'T''ang-ch''ih,T''ang-ch''ih-t''un,Tangchi,Tangchi Zhen,T’ang-ch’ih,T’ang-ch’ih-t’un,tang chi,tang chi zhen,汤池,汤池镇', 46.9811300, 123.7640000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22192, 'Tangchi', 'Tangchi', 'T''ang-ch''ih,T''ang-ch''ih-ts''un,Tangchi,Tangchi Zhen,T’ang-ch’ih,T’ang-ch’ih-ts’un,tang chi,tang chi zhen,汤池,汤池镇', 40.5303400, 122.6231700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22193, 'Talin Hiag', 'Talin Hiag', 'Talaha,Talaha Zhen,Talin Hiag,ta la ha,ta la ha zhen,他拉哈,他拉哈镇', 46.1589700, 124.1415400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22194, 'Taishitun', 'Taishitun', 'T''ai-shih-t''un,Taishitun,Taishitun Zhen,T’ai-shih-t’un,tai shi tun,tai shi tun zhen,太师屯,太师屯镇', 40.5383600, 117.1186200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22195, 'Taishang', 'Taishang', 'Taishang,Taishang Zhen,tai shang,tai shang zhen,台上,台上镇', 41.2986800, 125.8421600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22196, 'Taipingzhuang', 'Taipingzhuang', 'Taipingzhuang,Taipingzhuang Zhen,tai ping zhuang,tai ping zhuang zhen,太平庄,太平庄镇', 46.8383000, 125.3924800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22197, 'Taipingzhuang', 'Taipingzhuang', 'Taipingzhuang,Taipingzhuang Xiang,tai ping zhuang,tai ping zhuang xiang,太平庄,太平庄乡', 40.1691400, 122.8081500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22198, 'Taiping', 'Taiping', 'T''ai-p''ing-ch''uan,T''ai-p''ing-chen,T''ai-p''ing-chen-ts''un,Taiping,Taiping Zhen,Taypinchuan'',Taypinchuan’,T’ai-p’ing-chen,T’ai-p’ing-chen-ts’un,T’ai-p’ing-ch’uan,tai ping,tai ping zhen,太平,太平镇', 46.7612200, 130.6984200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22199, 'Pingshan', 'Pingshan', 'Pingshan,Pingshan Zhen,Taiping,ping shan,ping shan zhen,平山,平山镇', 46.3893100, 126.1039200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22200, 'Tailai', 'Tailai', 'T''ai-lai-chen,T''ai-lai-hsien,Tailai,Tailai Xian,Tailai Zhen,Tailaichi,T’ai-lai-chen,T’ai-lai-hsien,tai lai,tai lai xian,tai lai zhen,泰来,泰来县,泰来镇', 46.3890900, 123.4137100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22201, 'Taikang', 'Taikang', 'Dorbod,Du''erbote,Du''erbote Mengguzu Zizhixian,Duerbotetsi,Durvet,Du’erbote,Du’erbote Mengguzu Zizhixian,Hsiao-hao-tzu,Syaokhaotszy,T''ai-k''ang-chen,T''ai-k''ang-hsien,Taikang,Taikang Zhen,Taykan,Tu-erh-po-t''e,Tu-erh-po-t''e-ch''i,Tu-erh-po-t''e-meng-ku-tsu-tzu-chih-hsien,Tu-erh-po-t’e,Tu-erh-po-t’e-ch’i,Tu-erh-po-t’e-meng-ku-tsu-tzu-chih-hsien,T’ai-k’ang-chen,T’ai-k’ang-hsien,du er bo te,du er bo te meng gu zu zi zhi xian,tai kang,tai kang zhen,杜尔伯特,杜尔伯特蒙古族自治县,泰康,泰康镇', 46.8613500, 124.4420000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22202, 'Taijiying', 'Taijiying', 'Taijiying,Taijiying Xiang,tai ji ying,tai ji ying xiang,台吉营,台吉营乡', 42.1697800, 120.9732700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22203, 'Taijitun', 'Taijitun', 'Taijitun,tai ji tun,台集屯', 41.0573700, 120.8720400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22204, 'Taidong', 'Taidong', 'T''ai-tung,Taidong,Taidong Xiang,T’ai-tung,tai dong,tai dong xiang,太东,太东乡', 47.9002200, 125.4648800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22205, 'Tahe', 'Tahe', 'Ku-ch''i-ku,Ku-ch’i-ku,T''a-ho,Tahe,T’a-ho', 52.3333300, 124.7333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22206, 'Taha Man Zu', 'Taha Man Zu', 'Dawo''er Zu,Dawo’er Zu,T''a-ha-chan,T''a-ha-erh,T''a-ha-erh-chan,Taha,Taha Man Zu,Taha Man Zu Dawo''er Zu Xiang,Taha Man Zu Dawo’er Zu Xiang,Takha,Takhaerchzhan'',Takhaerchzhan’,Takhar,Takharchzhan,Tawo''er Zu Xiang,Tawo’er Zu Xiang,T’a-ha-chan,T’a-ha-erh,T’a-ha-erh-chan,da wo er zu,da wo er zu xiang,ta ha,ta ha man zu,ta ha man zu da wo er zu xiang,塔哈,塔哈满族,塔哈满族达斡尔族乡,达斡尔族,达斡尔族乡', 47.5572800, 124.2159100, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22207, 'Suzigou', 'Suzigou', 'Su-tzu-kou,Suzigou,Suzigou Zhen,su zi gou,su zi gou zhen,苏子沟,苏子沟镇', 40.4005800, 123.4085500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22208, 'Suqin Huimin', 'Suqin Huimin', 'Su-ch''in,Su-ch’in,Sucin'',Suqin,Suqin Huimin,Suqin Huimin Xiang,su qin hui min,su qin hui min xiang,Суцинь,苏沁回民,苏沁回民乡', 50.4564800, 119.7724500, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22209, 'Sunwu', 'Sunwu', 'Sun''u,Sun-wu-chen,Sun-wu-hsien,Sunwu,Sunwu Zhen,sun wu,sun wu zhen,Суньу,孙吴,孙吴镇', 49.4174900, 127.3155000, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22210, 'Sunjia Buzi', 'Sunjia Buzi', 'Sun-chia-p''u-tzu,Sun-chia-pao-tzu,Sun-chia-p’u-tzu,Sunjia Buzi,Sunjiapuzi,sun jia bao zi,孙家堡子', 42.0170700, 126.5851300, 'CN', '2014-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22211, 'Sunhe', 'Sunhe', 'Sun''khechzhen'',Sun-ho,Sun-ho-chen,Sunhe,Sunhe Xiang,Sun’khechzhen’,sun he,sun he xiang,孙河,孙河乡', 40.0435100, 116.5227700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22212, 'Sujiatun', 'Sujiatun', 'Hsu-chia-t''un,Hsu-chia-t’un,Ssu-chia-t''un,Ssu-chia-t’un,Su-chia-t''un,Su-chia-t’un,Suczjatun'',Sujiatun,Sukiatun,Суцзятунь', 41.6591700, 123.3391700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22213, 'Sujiadian', 'Sujiadian', 'Su-chia-tien,Su-chia-tien-ts''un,Su-chia-tien-ts’un,Sujiadian,Sujiadian Zhen,su jia dian,su jia dian zhen,苏家店,苏家店镇', 46.9029600, 130.7808400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22214, 'Suizhong', 'Suizhong', 'Chung-hou-so,Sui-chung,Sui-chung-chen,Sui-chung-hsien,Suichun,Suizhong,Suizhong Xian,sui zhong,sui zhong xian,绥中,绥中县', 40.3291600, 120.3365300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22215, 'Suiyang', 'Suiyang', 'Hsiao-sui-fen,Hsiao-sui-fen-ho,Sui-fen,Sui-fen-hsien,Sui-feng,Suiyang,Suiyang Zhen,Suyyan,sui yang,sui yang zhen,绥阳,绥阳镇', 44.4218700, 130.8814200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22216, 'Suileng', 'Suileng', 'K''o-yin-ho,K’o-yin-ho,Sui-leng Hsien,Sui-leng-chen,Suileng,Suileng Xian,Suileng Zhen,sui leng,sui leng xian,sui leng zhen,绥棱,绥棱县,绥棱镇', 47.2480500, 127.0953500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22217, 'Suihua', 'Suihua', 'Chui-hua,Chŭi-huá,Pei-lin-tzu,Pei-t''uan-lin-tzu,Pei-t’uan-lin-tzu,Suej-chua,Suejkhua,Sui-hoa-chhi,Sui-hoà-chhī,Sui-hua-chen,Sui-hua-hsien,Sui-hwa,Suihua,Suihua Shi,Sujkhua,Tuy Hoa,Tuy Hóa,sayhwa,ssu-ihwa si,sui hua,sui hua shi,Суејхуа,Суйхуа,سایهوا,سوئہوا,綏化,綏化市,绥化,绥化市,쑤이화 시', 46.6395400, 126.9950800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22218, 'Suifenhe', 'Suifenhe', 'FUD,Pogranichinaya,Pogranichnaya,Sui-fen-ho,Sui-fen-ho-shih,Suifenhe,Suífēnhé,sui fen he,綏芬河,绥芬河', 44.3998200, 131.1477500, 'CN', '2014-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22219, 'Sugehe', 'Sugehe', 'Su-ko-ho,Sugehe,Sugehe Xiang,Sugehkheh,su ge he,su ge he xiang,Сугэхэ,苏格河,苏格河乡', 48.1666700, 121.2333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22220, 'Subrag', 'Subrag', 'So-pu-li-ka,Subrag,Suobo Riga,Suobo Riga Sumu,suo bo ri ga,suo bo ri ga su mu,索博日嘎,索博日嘎苏木', 44.2000000, 118.4666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22221, 'Songzhan', 'Songzhan', 'Sonchan,Songzhan,Songzhan Zhen,Sung,Sung-chan,Sung-i,Sung-li,Urimu,Wu-li-mo,Wu-li-mu,Wu-li-mu-chan,song zhan,song zhan zhen,Ūrīmu,宋站,宋站镇', 46.2214300, 125.6257700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22222, 'Songshu', 'Songshu', 'Songshu,Songshu Zhen,Songshujie,Songshuzhen,Sung-shu-chen,song shu,song shu jie,song shu zhen,松树,松树街,松树镇', 42.0436100, 127.1072200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22223, 'Songshugou', 'Songshugou', 'Songshugou,Songshugou Xiang,Sunshugou,song shu gou,song shu gou xiang,Суншугоу,松树沟,松树沟乡', 49.3408000, 128.6295900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22224, 'Songjianghe', 'Songjianghe', 'Songjianghe,Songjianghe Zhen,Sung-chiang-ho,song jiang he,song jiang he zhen,松江河,松江河镇', 42.1859000, 127.4789500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22225, 'Songjiang', 'Songjiang', 'An-t''u-hsien,An-t’u-hsien,Antu,Chiu-an-t''u,Chiu-an-t’u,Niang-niang-k''u,Niang-niang-k’u,Songjiang,Songjiang Zhen,Sung-chiang,Sung-chiang-chen,song jiang,song jiang zhen,松江,松江镇', 42.5775000, 128.3341700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22226, 'Songjiang', 'Songjiang', 'Songjiang,Songjiang Xiang,song jiang,song jiang xiang,松江,松江乡', 42.2258300, 127.3561100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22227, 'Siping', 'Siping', 'OSQ,S-pching,Se-bing,Siping,Sipingjie,Ssupingkai,Su-peng-chhi,Supin,Sypin,Szeping,Szepingkai,Sé-bìng,Sìpíng,Sìpíngjiē,Sù-pêng-chhī,Tu Binh,Tứ Bình,si ping,si ping jie,si ping shi,spng  jyln,sseuping si,sypyng,Сипинг,Съпин,Сыпин,سپنگ، جیلن,سیپینگ,四平,四平市,四平街,쓰핑 시', 43.1614300, 124.3778500, 'CN', '2013-12-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22228, 'Sipeng', 'Sipeng', 'Sipeng,Sipeng Xiang,si peng,si peng xiang,四棚,四棚乡', 41.8622200, 125.5722200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22229, 'Simenzi', 'Simenzi', 'Simenzi,Simenzi Zhen,Ssu-men,si men zi,si men zi zhen,四门子,四门子镇', 40.7333300, 123.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22230, 'Beisijiazi', 'Beisijiazi', 'Beisijiazi,Beisijiazi Xiang,Sijiazi,Ssu-chia-tzu,bei si jia zi,bei si jia zi xiang,北四家子,北四家子乡', 42.8485700, 123.4858600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22231, 'Sihaidian', 'Sihaidian', 'Sihaidian,Sihaidian Zhen,Ssu-hai,Ssu-hai-tien,si hai dian,si hai dian zhen,四海店,四海店镇', 47.4742600, 127.5056200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22232, 'Sihai', 'Sihai', 'Sihai,Sihai Zhen,Ssu-hai,Ssu-hai-pao,Ssu-hai-yeh,si hai,si hai zhen,四海,四海镇', 40.5245800, 116.4051400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22233, 'Sifangtai', 'Sifangtai', 'Sifangtai,Sifangtai Zhen,Ssu-fang-t''ai,Ssu-fang-t’ai,si fang tai,si fang tai zhen,四方台,四方台镇', 46.9205400, 126.9819900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22234, 'Si’erbao', 'Si''erbao', 'Si''erbao,Si''erbao Zhen,Si''erpu,Si’erbao,Si’erbao Zhen,Si’erpu,Ssu-erh-p''u,Ssu-erh-pao,Ssu-erh-p’u,si r bao,si r bao zhen,寺儿堡,寺儿堡镇', 40.7966100, 120.7381900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22235, 'Sidaogou', 'Sidaogou', 'Sidaogou,Sidaogou Zhen,Ssu-tao-kou,si dao gou,si dao gou zhen,四道沟,四道沟镇', 41.7446800, 127.0516400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22236, 'Shunyi', 'Shunyi', 'Shun''i,Shun-i,Shun-i-ch''u,Shun-i-ch’ü,Shun-i-hsien,Shunyi,shun yi,Шуньи,顺义', 40.1217500, 116.6478300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22237, 'Shumugou', 'Shumugou', 'Shu-mu-kou,Shumugou,Shumugou Xiang,shu mu gou,shu mu gou xiang,树木沟,树木沟乡', 46.1666700, 120.8000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22238, 'Shulinzhao', 'Shulinzhao', 'Dalad Qi,Dalat,Dalate Qi,O-erh-to-ssu-tso-i-hou-ch''i,O-erh-to-ssu-tso-i-hou-ch''i-wang-fu,O-erh-to-ssu-tso-i-hou-ch’i,O-erh-to-ssu-tso-i-hou-ch’i-wang-fu,Shu-lin-chao,Shulin Jo,Shulin Jo Zhen,Shulinzhao,Shulinzhao Zhen,Ta-la-t''e-ch''i,Ta-la-t’e-ch’i,da la te qi,shu lin zhao,shu lin zhao zhen,树林召,树林召镇,达拉特旗', 40.3927800, 110.0269400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22239, 'Shulan', 'Shulan', 'Shu-lan-chen,Shu-lan-chieh,Shulan,Shulan'',Ssu-chia-fang,Шулань', 44.4166700, 126.9500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22240, 'Shuiyuan', 'Shuiyuan', 'Shuiyuan,Shuiyuan Zhen,shui yuan,shui yuan zhen,水源,水源镇', 40.8058700, 122.1480900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22241, 'Shuiquan', 'Shuiquan', 'Shuiquan,Shuiquan Zhen,shui quan,shui quan zhen,水泉,水泉镇', 45.4954300, 121.8142100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22242, 'Shuangyashan', 'Shuangyashan', 'Chien-shan,Seng-ak-sang,Shuang-ya-shan-shih,Shuangjashan,Shuangyashan,Shuanujashan'',Siang-ah-san-chhi,Siang-ah-san-chhī,Song Ap Son,Song Áp Sơn,Suang-ja-san,Sĕ̤ng-ák-săng,shuang ya shan,shuang ya shan shi,shwangyashan,swang-yasan si,Šuang-ja-šan,Шуангјашан,Шуанъяшань,شوانگیاشان,双鴨山市,双鸭山市,雙鴨山,솽야산 시', 46.6361100, 131.1538900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22243, 'Shuangyang', 'Shuangyang', 'Shuang-yang-chen,Shuangyang,Shuangyang Zhen,Shuanyang,shuang yang,shuang yang zhen,双阳,双阳镇', 47.5578200, 125.5937700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22244, 'Shuangyang', 'Shuangyang', 'Shuang-yang-chen,Shuang-yang-ho,Shuang-yang-hsien,Shuangyang,Shwangyang,Suan-yang-ho', 43.5241700, 125.6736100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22245, 'Shuangxing', 'Shuangxing', 'Shuang-hsing,Shuangxing,Shuangxing Xiang,shuang xing,shuang xing xiang,双兴,双兴乡', 47.0907700, 125.9064200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22246, 'Shuangtashan', 'Shuangtashan', 'Shuangtashan,shuang ta shan,双塔山', 40.9477800, 117.7947200, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22247, 'Shuangtai', 'Shuangtai', 'Shuang-t''ai-tzu,Shuang-t’ai-tzu,Shuangtai,Shuangtai Zhen,Shuangtaizi,shuang tai,shuang tai zhen,双台,双台镇', 40.2177400, 122.2740500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22248, 'Shuangshan', 'Shuangshan', 'Shuang-shan-t''un,Shuang-shan-t’un,Shuangshan,Shuangshan Zhen,Shuanshan'',shuang shan,shuang shan zhen,Шуаншань,双山,双山镇', 48.8790400, 125.2459000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22249, 'Shuanglu', 'Shuanglu', 'Shuanglu,Shuanglu Xiang,shuang lu,shuang lu xiang,双录,双录乡', 47.6314900, 127.0473500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22250, 'Shuanghe', 'Shuanghe', 'Shuang-ho,Shuang-ho-chen,Shuanghe,Shuanghe Zhen,shuang he,shuang he zhen,双河,双河镇', 46.8827500, 127.1679400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22251, 'Shuanghe', 'Shuanghe', 'Erh-tao-ho-tzu,Shuang-ho,Shuang-ho-chen,Shuang-t''ai-chen,Shuang-t’ai-chen,Shuanghe,Shuanghe Zhen,shuang he,shuang he zhen,双河,双河镇', 45.9781200, 130.2767000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22252, 'Shuanggang', 'Shuanggang', 'Shuang-kang,Shuang-kang-tzu,Shuanggang,Shuanggang Zhen,shuang gang,shuang gang zhen,双岗,双岗镇', 45.1058300, 122.9237800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22253, 'Shuangfeng', 'Shuangfeng', 'Shuangfeng,Shuangfeng Zhen,shuang feng,shuang feng zhen,双丰,双丰镇', 46.9666700, 127.7520100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22254, 'Shuangcheng', 'Shuangcheng', 'Schwang-tschong-ting,Schwang-tschöng-ting,Schwangcheng,Shuang-ch''eng-chen,Shuang-ch''eng-hsien,Shuang-ch''eng-pao,Shuang-ch’eng-chen,Shuang-ch’eng-hsien,Shuang-ch’eng-pao,Shuangcheng,Shwangcheng', 45.3500000, 126.2833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22255, 'Shizijie', 'Shizijie', 'Shizijie,Shizijie Zhen,shen zi jie,shen zi jie zhen,什字街,什字街镇', 40.0619000, 122.4889500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22256, 'Shixian', 'Shixian', 'Ka-ya-ho,Shih-hsien,Shixian,Shixian Zhen,shi xian,shi xian zhen,石岘,石岘镇', 43.0833300, 129.7666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22257, 'Shiwei', 'Shiwei', 'Chi-la-lin,Czilalin'',Jilalin,Kilalin,Shih-wei,Shih-wei-hsien,Shivei,Shivey,Shivoi,Shiwei,Shiwei Zhen,shi wei,shi wei zhen,Цзилалинь,室韦,室韦镇', 51.3333300, 119.9000000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22258, 'Shitouhe', 'Shitouhe', 'Shitouhe,Shitouhe Zhen,Shitouhezi,shi tou he,shi tou he zhen,石头河,石头河镇', 46.1169400, 130.8881400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22259, 'Shitouhezi', 'Shitouhezi', 'Hsin-chan,Shih-t''ou-ho,Shih-t''ou-ho-tzu,Shih-t’ou-ho,Shih-t’ou-ho-tzu,Shitouhezi,Shitouhezi Zhen,shi tou he zi,shi tou he zi zhen,石头河子,石头河子镇', 44.8699300, 128.6852500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22260, 'Shiyan', 'Shiyan', 'Ning-ku-t''a,Ning-ku-t’a,Shih-t''ou,Shih-t''ou-chan,Shih-t’ou,Shih-t’ou-chan,Shitou,Shiyan,Shiyan Zhen,shi yan,shi yan zhen,石岩,石岩镇', 44.1767100, 129.3353800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22261, 'Shisanling', 'Shisanling', 'Shih-san-ling,Shisanling,Shisanling Zhen,shi san ling,shi san ling zhen,十三陵,十三陵镇', 40.2704100, 116.2253400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22262, 'Shiren', 'Shiren', 'Shih-jen,Shih-jen-kou,Shih-ju,Shiren,Shiren Zhen,shi ren,shi ren zhen,石人,石人镇', 41.9629800, 126.5659400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22263, 'Shiqi', 'Shiqi', 'Shih-ch''i-chieh,Shih-ch’i-chieh,Shiqi,Shiqijie,Xinhe Xiang,shi qi,xin he xiang,十骑,新合乡', 42.9561100, 128.5272200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22264, 'Shimiaozi', 'Shimiaozi', 'Shih-miao-tzu,Shimiaozi,Shimiaozi Zhen,shi miao zi,shi miao zi zhen,石庙子,石庙子镇', 40.6569200, 123.5141800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22265, 'Shimen', 'Shimen', 'Chatiaogou,Shimen,Shimen Zhen,shi men,shi men zhen,石门,石门镇', 43.0333300, 129.0166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22266, 'Shilibu', 'Shilibu', 'Shi-li-p''u,Shi-li-p’u,Shilibu,Shilibu Zhen,shi li bao,shi li bao zhen,十里堡,十里堡镇', 40.3587100, 116.7957400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22267, 'Shihuiyao', 'Shihuiyao', 'Shih-hui-yao,Shihuiyao,Shihuiyao Zhen,shi hui yao,shi hui yao zhen,石灰窑,石灰窑镇', 40.3126300, 123.1056300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22268, 'Gongyi', 'Gongyi', 'Gongyi,Shih-hu,Shihu,Shihu Zhen,gong yi,shi hu zhen,公益,石湖镇', 41.5091200, 126.2802500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22269, 'Shihe', 'Shihe', 'Shih-ho,Shih-ho-ts''un,Shih-ho-ts’un,Shihe,Shihe Xiang,shi he,shi he xiang,石河,石河乡', 44.5118500, 129.2575000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22270, 'Shiguai', 'Shiguai', 'Shiguai,Shiguai Jiedao,Shiguai Qu,Shiguaigou,Shih-kuai,Shih-kuai-chen,Shih-kuai-kou,Shih-kuai-kou-kung-ch''u,Shih-kuai-kou-kung-ch’ü,Shih-kuai-tzu,Shih-kuai-tzw,Shihkuaitsun,Xiguit Kuangqu,shi guai,shi guai jie dao,shi guai kuang qu,shi guai qu,石拐,石拐区,石拐矿区,石拐街道', 40.7058300, 110.2855600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22271, 'Shi’erdaogou', 'Shi''erdaogou', 'Shi''erdaogou,Shi''erdaogou Xiang,Shih-erh-tao-kou,Shi’erdaogou,Shi’erdaogou Xiang,shi er dao gou,shi er dao gou xiang,十二道沟,十二道沟乡', 41.4644400, 127.5444400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22272, 'Shenyang', 'Shenyang', 'Feng-t''ien,Feng-t’ien,Gorad Shehn''jan,Moukden,Mukden,SHE,Sen''gian''nk,Sen-jang,Senjana,Senjang,Senjangas,Senjango,Shehn''jan,Shehn''jan khot,Shen''jan,Shen-yang-hsien,Shen-yang-shih,Shengking,Shenjang,Shenyan,Shenyang,Shenyang Shi,Shunjan,Sim-iong-chhi,Sing-iong,Sjenyang,Swnjyangh,Sím-iông-chhī,Sīng-iòng,Tham Duong,Thẩm Dương,cenyan,chen yang,chen yang shi,san''yanga,sein hyang,sen''yan,senayanga,seon-yang,seon-yang si,shen yang,shen yang shi,shnyang,shnyangh,shynyang,sim-yang,Ŝenjango,Šen-jang,Šenjangas,Šeņjana,Σενγιάνγκ,Горад Шэньян,Шеньян,Шеньяң,Шенјанг,Шънян,Шэньян,Шэньян хот,שן-יאנג,شنيانغ,شنیانگ,شن‌یانگ,شینیانگ,شېنياڭ شەھىرى,शेनयांग,षन्यांग,ਸ਼ੇਨਯਾਂਗ,சென்யாங்,ഷെന്യാങ്,เสิ่นหยาง,沈阳,沈阳市,沉阳市,瀋陽,瀋陽市,선양,선양 시,심양', 41.7922200, 123.4327800, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22273, 'Shenshu', 'Shenshu', 'Shenshu,Shenshu Zhen,shen shu,shen shu zhen,神树,神树镇', 46.9413600, 128.4198100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22274, 'Shenjia', 'Shenjia', 'Shen-chia,Shen-chia-chan,Shenjia,Shenjia Zhen,chen jia,chen jia zhen,沈家,沈家镇', 46.0927400, 126.7670400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22275, 'Shengping', 'Shengping', 'Sheng-p''ing-chen,Sheng-p’ing-chen,Shengping,Shengping Zhen,Shenpinchzhen'',Shenpinchzhen’,sheng ping,sheng ping zhen,升平,升平镇', 46.2143800, 125.2670000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22276, 'Shengli', 'Shengli', 'Shengli,Shengli Xiang,sheng li,sheng li xiang,胜利,胜利乡', 46.8224700, 129.9991100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22277, 'Shengli', 'Shengli', 'Shengli,Shengli Mengguzu Xiang,sheng li,sheng li meng gu zu xiang,胜利,胜利蒙古族乡', 46.4556600, 123.6092000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22278, 'Shengli', 'Shengli', 'Gaolimao,Kao-li-mao-tzu,Kao-li-miao,Kaolingyao,Pin-kung,Shengli,Shengli Zhen,Wanchun,sheng li,sheng li zhen,胜利,胜利镇', 45.8000000, 128.0500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22279, 'Bohai', 'Bohai', 'Bohai,Bohai Zhen,Shayu,bo hai,bo hai zhen,sha yu,沙峪,渤海,渤海镇', 40.4118400, 116.4683800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22280, 'Shaowen', 'Shaowen', 'Shaowen,Shaowen Xiang,shao wen,shao wen xiang,绍文,绍文乡', 47.5345500, 124.8966300, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22281, 'Shanshi', 'Shanshi', 'Shan-shih,Shan-shih-ts''un,Shan-shih-ts’un,Shanshi,Shanshi Zhen,shan shi,shan shi zhen,山市,山市镇', 44.5758100, 129.0949000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22282, 'Shanhecun', 'Shanhecun', 'Shan-ho-t''un,Shan-ho-t’un,Shanhecun,Shanhetun,shan he cun,山河村', 45.7113100, 128.5802900, 'CN', '2017-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22283, 'Shanhaiguan', 'Shanhaiguan', 'Lin-yu,Lin-yü,SHF,Shan''khajguan'',Shan-hai-kuan,Shanhaiguan,Shanhaikwan,shan hai guan,Шаньхайгуань,山海关', 40.0025000, 119.7488900, 'CN', '2017-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22284, 'Shangzhi', 'Shangzhi', 'Chu-he,Chu-ho,Chu-ho-hsien,Shang-chih,Shang-chih-chen,Shangzhi,Shangzhi Shi,Uchzukhe,Wu-chi-mi-ho,Wu-chu-ho,Wukimichan,Wukimiho,shang zhi,shang zhi shi,尚志,尚志市', 45.2140600, 127.9742600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22285, 'Shangtuhai', 'Shangtuhai', 'Shangtuhai,Shangtuhai Xiang,shang tu hai,shang tu hai xiang,上秃亥,上秃亥乡', 41.1818900, 111.3114100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22286, 'Shangmatun', 'Shangmatun', 'Shangmatun,Shangmatun Xiang,shang ma tun,shang ma tun xiang,上麻屯,上麻屯乡', 40.9430600, 123.3628400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22287, 'Shangkuli', 'Shangkuli', 'Shang-k''u-li-ho,Shang-k’u-li-ho,Shangkuli,Shangkuli Xiang,Shankuli,Verkhniy Kul'',Verkhniy Kul’,Verkhniye-Kuli,shang ku li,shang ku li xiang,Шанкули,上库力,上库力乡', 50.2564900, 120.4623100, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22288, 'Shangjiahe', 'Shangjiahe', 'Shang-chia-ho,Shangjiahe,Shangjiahe Zhen,shang jia he,shang jia he zhen,上夹河,上夹河镇', 41.8500500, 124.4842900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22289, 'Shangjia', 'Shangjia', 'Shangjia,Shangjia Zhen,shang jia,shang jia zhen,尚家,尚家镇', 46.1239400, 125.8682700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22290, 'Shangji', 'Shangji', 'Chiu-sui-leng,Shang-chi,Shang-chi-ch''ang,Shang-chi-ch’ang,Shangji,Shangji Zhen,Sui-leng,shang ji,shang ji zhen,上集,上集镇', 47.1521500, 127.3215300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22291, 'Qitai', 'Qitai', 'Ch''i-t''ai,Ch’i-t’ai,Qitai,Qitai Zhen,Shandu,Shang Tou,Shang-tu,Shang-tu-ch''eng-kuan,Shang-tu-ch’eng-kuan,Shang-tu-hsien,Shang-tu-hsien-ch''eng,Shang-tu-hsien-ch’eng,Shangdu,Shangdu Xian,qi tai,qi tai zhen,shang dou,shang dou xian,七台,七台镇,商都,商都县', 41.5494400, 113.5338900, 'CN', '2012-05-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22292, 'Shandongzhuang', 'Shandongzhuang', 'Shandongzhuang,Shandongzhuang Zhen,shan dong zhuang,shan dong zhuang zhen,山东庄,山东庄镇', 40.1908100, 117.1587700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22293, 'Shalizhai', 'Shalizhai', 'Sha-li-chai,Shalizhai,Shalizhai Zhen,sha li zhai,sha li zhai zhen,沙里寨,沙里寨镇', 40.1813200, 123.6881700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22294, 'Shalan', 'Shalan', 'Sha-la-chan,Sha-lan-chan,Sha-lan-chen,Sha-lan-ts''un,Sha-lan-ts’un,Shalan,Shalan Zhen,sha lan,sha lan zhen,沙兰,沙兰镇', 44.1659600, 128.9658200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22295, 'Shahezi', 'Shahezi', 'Sha-ho,Sha-ho-tzu,Shahezi,Shahezi Zhen,sha he zi,sha he zi zhen,沙河子,沙河子镇', 44.4403300, 127.6111500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22296, 'Shahe', 'Shahe', 'Shahe,Shahe Zhen,sha he,sha he zhen,沙河,沙河镇', 40.2739100, 120.2462700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22297, 'Shaheying', 'Shaheying', 'Shaheying,Shaheying Xiang,sha he ying,sha he ying xiang,沙河营,沙河营乡', 40.8252600, 120.7633100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22298, 'Shahe', 'Shahe', 'Sha-ho,Shahe,Shahe Zhen,sha he,sha he zhen,沙河,沙河镇', 40.1232400, 116.2607600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22299, 'Shaguotun', 'Shaguotun', 'Sha-kuo-t''un,Sha-kuo-t’un,Shaguotun,Shaguotun Jiedao,Wei-tung,sha guo tun,沙锅屯', 41.1313000, 120.6913100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22300, 'Shagang', 'Shagang', 'Sha-kang,Shagang,Shagang Zhen,sha gang,sha gang zhen,沙岗,沙岗镇', 40.3494200, 122.2570200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22301, 'Shacheng', 'Shacheng', 'Huai-lai-hsien,Huailai,Sha-ch''eng,Sha-ch''eng-pao,Sha-ch’eng,Sha-ch’eng-pao,Shacheng,sha cheng,沙城', 40.3913900, 115.5113900, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22302, 'Sanxing', 'Sanxing', 'San-hsing,Sanxing,Sanxing Zhen,san xing,san xing zhen,三兴,三兴镇', 47.6157800, 125.0360800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22303, 'Santun', 'Santun', 'San-t''un-pao,San-tung-p''u,San-tung-pao,San-tung-p’u,San-t’un-pao,Santun,Santun Xiang,san tun,san tun xiang,三屯,三屯乡', 40.1000000, 112.7166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22304, 'Sandaowan', 'Sandaowan', 'San-tao-wai,Sandao,Sandaowan,Sandaowan Zhen,Santouwai,san dao wan,san dao wan zhen,三道湾,三道湾镇', 43.1655600, 129.1744400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22305, 'Sanka', 'Sanka', 'Sanka,Sanka Xiang,Sanqia,san ka,san ka xiang,三卡,三卡乡', 51.1495500, 126.8992800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22306, 'Sankeyushu', 'Sankeyushu', 'San-k''o-yu-shu,San-k’o-yü-shu,Sankeyushu,Sankeyushu Zhen,san ke yu shu,san ke yu shu zhen,三棵榆树,三棵榆树镇', 41.7419400, 125.3894400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22307, 'Sanjiazi', 'Sanjiazi', 'San-chia-tzu,Sanjiazi,Sanjiazi Zhen,san jia zi,san jia zi zhen,三家子,三家子镇', 40.6680600, 123.3313900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22308, 'Sanhe', 'Sanhe', 'Argun'',Argun’,Nai-chia-mu-t''u,Nai-chia-mu-t’u,Nai-ju-mu-t''u,Nai-ju-mu-t’u,Nai-le-mu-t''u,Nai-le-mu-t’u,Nai-lo-mu-t''u,Nai-lo-mu-t’u,O-erh-ku-na-ch''i,O-erh-ku-na-ch’i,San''kheh,San-ho,Sanhe,Sanhe Zhen,Tung-o-ch''i,Tung-o-ch’i,san he,san he zhen,Саньхэ,三河,三河镇', 50.4490900, 120.1053200, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22309, 'Sanhe', 'Sanhe', 'San-ho,Sanhe,Sanhe Xiang,san he,san he xiang,三合,三合乡', 47.2308100, 124.7111400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22310, 'Sanhe', 'Sanhe', 'San-ho,San-ho-ts''un,San-ho-ts’un,Sanhe,Sanhe Zhen,san he,san he zhen,三合,三合镇', 42.4753200, 129.7358500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22311, 'Sandao', 'Sandao', 'San-tao-chen,San-tao-kou,Sandao,Sandao Zhen,san dao,san dao zhen,三道,三道镇', 47.4173300, 126.4003000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22312, 'Sandaotong', 'Sandaotong', 'San-tao-kou,San-tao-t''ung,San-tao-t’ung,Sandaotong,Sandaotong Zhen,san dao tong,san dao tong zhen,三道通,三道通镇', 45.6801700, 129.7358500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22313, 'Jinjiadian', 'Jinjiadian', 'Jinjiadian,San-tao-hu,Sandaohu,Sandaohu Zhen,jin jia dian,san dao hu zhen,三道湖镇,金家店', 42.3436100, 126.8891700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22314, 'Sandaohezi', 'Sandaohezi', 'San-tao-ho,San-tao-ho-tzu,Sandaohezi,Sandaohezi Zhen,san dao he zi,san dao he zi zhen,三道河子,三道河子镇', 45.3019600, 129.7714800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22315, 'Sandaogang', 'Sandaogang', 'San''daoga,San-tao-kang,San-tao-kang-ts''un,San-tao-kang-ts’un,Sandaogang,Sandaogang Zhen,San’daoga,san dao gang,san dao gang zhen,三道岗,三道岗镇', 46.1145200, 130.1037800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22316, 'Sandao', 'Sandao', 'San-tao,Sandao,Sandao Xiang,san dao,san dao xiang,三道,三道乡', 42.5277800, 128.4494400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22317, 'Sanchazi', 'Sanchazi', 'Hsia-tien-tzu,San-ch''a-tze,San-ch''a-tzu,San-ch’a-tze,San-ch’a-tzu,Sanchazi', 42.0816700, 126.6002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22318, 'Sanchahe', 'Sanchahe', 'San-ch''a-ho,San-ch''a-ho-chieh,San-ch’a-ho,San-ch’a-ho-chieh,San-ho-ch''a,San-ho-ch’a,Sanchahe,Shih-t''ou-ch''eng,Shih-t''ou-ch''eng-tzu,Shih-t’ou-ch’eng,Shih-t’ou-ch’eng-tzu,san cha he,三岔河', 44.9630600, 126.0153200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22319, 'Salaqi', 'Salaqi', 'Sa-hsien,Sa-la-ch''i,Sa-la-ch''i-hsien,Sa-la-ch’i,Sa-la-ch’i-hsien,Salaqi,Salatsi,Salqin,Saratsi,Saratsi-ting,T''u-mo-t''e-yu-ch''i,Tumd Youqi,Tumoteyou Qi,T’u-mo-t’e-yu-ch’i,sa la qi,tu mo te you qi,土默特右旗,萨拉齐', 40.5413900, 110.5108300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22320, 'Saihan Tal', 'Saihan Tal', 'Sai-han-t''a-la,Sai-han-t’a-la,Saihan Tal,Saihantala,Saihantala Zhen,Sonid Youqi,Su-ni-t''e-yu-ch''i,Su-ni-t’e-yu-ch’i,Suniteyou Qi,sai han ta la,sai han ta la zhen,su ni te you qi,苏尼特右旗,赛汉塔拉,赛汉塔拉镇', 42.7358300, 112.6513900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22321, 'Ruiting', 'Ruiting', 'Ruiting,Ruiting Xiang,rui ting,rui ting xiang,瑞廷,瑞廷乡', 47.6440100, 123.7559000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22322, 'Rongxing', 'Rongxing', 'Rongxing,Rongxing Chaoxianzu Xiang,Rongxing Zhen,rong xing,rong xing chao xian zu xiang,rong xing zhen,荣兴,荣兴朝鲜族乡,荣兴镇', 40.7783800, 122.0845100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22323, 'Renmin', 'Renmin', 'An-ta,An-ta-hsien,Cheng-ya-chen,Jen-min,Jen-min-chen,Jen-min-ts''un,Jen-min-ts’un,Renmin,Renmin Zhen,ren min,ren min zhen,任民,任民镇', 46.6350200, 125.5425300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22324, 'Fendou', 'Fendou', 'Fendou,Fendou Jiedao,Jang-hu-lu,Ranghulu,Ranghulu Qu,Ya-hu-lu-p''ao,Ya-hu-lu-p’ao,fen dou,fen dou jie dao,rang hu lu,rang hu lu qu,奋斗,奋斗街道,让胡路,让胡路区', 46.6414200, 124.8628300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22325, 'Qujiadian', 'Qujiadian', 'Ch''u-chia-tien,Ch’ü-chia-tien,Qujiadian,Qujiadian Xiang,qu jia dian,qu jia dian xiang,曲家店,曲家店乡', 43.2222600, 123.9292400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22326, 'Quanyang', 'Quanyang', 'Ch''uan-yang,Ch''uan-yang-ho-tzu,Ch’üan-yang,Ch’üan-yang-ho-tzu,Quanyang,Quanyang Zhen,quan yang,quan yang zhen,泉阳,泉阳镇', 42.3516700, 127.5452800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22327, 'Quantou', 'Quantou', 'Ch''uan-t''ou,Ch’üan-t’ou,Quantou,Quantou Zhen,quan tou,泉头', 42.8653700, 124.1703200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22328, 'Taihecun', 'Taihecun', 'Ch''i-ho-ho,Ch''i-t''ai-ho,Ch’i-ho-ho,Ch’i-t’ai-ho,Qitaihe,Taihe,Taihecun,tai he,tai he cun,太和,太河村', 45.7634700, 130.8504800, 'CN', '2017-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22329, 'Qiqihar', 'Qiqihar', 'Ca-ca-hak-i,Ch''i-ch''i-ha-erh,Ch''i-ch''i-ha-erh-shih,Chhe-chhe-ha-ngi-su,Chhè-chhè-hâ-ngì-sṳ,Ch’i-ch’i-ha-erh,Ch’i-ch’i-ha-erh-shih,Ciciharas,Ciciharo,Cicikar,Cicikhar,Cà̤-cà̤-hăk-ī,Lung-chiang,Lung-chiang-hsien,Lungkiang,NDG,Qiqiha''er,Qiqiha''er Shi,Qiqihaer,Qiqihar,Qiqihar Shi,Qiqihar-chhi,Qiqihar-chhī,Qiqiha’er,Qiqiha’er Shi,Te Te Cap Nhi,Tsitsihar,Tề Tề Cáp Nhĩ,Zizikar,chichi har,chichiha-eol si,chichiharu,chichiharu shi,chychyhar,qi qi ha er,qi qi ha er shi,Ĉiĉiharo,Čičiharas,Ћићихар,Цицикар,Цицихар,Ціцікар,چىچىخار شەھىرى,چیچیهار,چیچیہار,ฉีฉีฮาร์,チチハル,チチハル市,齊齊哈爾,齊齊哈爾市,齐齐哈尔,齐齐哈尔市,치치하얼 시', 47.3408800, 123.9604500, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22330, 'Qiqian', 'Qiqian', 'Ch''i-ch''ien,Ch''i-ch''ien-hsien,Ch''i-kan,Chechinchan,Chghuergankhe,Chi-ju-mu-t''u,Chi-ju-mu-t’u,Chi-lo-mu-t''u,Chi-lo-mu-t’u,Chikanhsien,Chikeen,Chikien,Chu-erh-kan,Chu-erh-kan-ho,Chzhurgan,Ch’i-ch’ien,Ch’i-ch’ien-hsien,Ch’i-kan,Hsi-o-ch''i,Hsi-o-ch’i,Ki-kien,Kilemotu,Qiqian,Qiqian Xiang,Tsigan,Tszilemutu,qi gan,qi gan xiang,奇乾,奇乾乡', 52.1842700, 120.7631600, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22331, 'Qinlao', 'Qinlao', 'Qinlao,Qinlao Zhen,qin lao,qin lao zhen,勤劳,勤劳镇', 47.0332500, 127.5558400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22332, 'Qinjia', 'Qinjia', 'Ch''in-chia,Ch’in-chia,Qinjia,Qinjia Zhen,qin jia,qin jia zhen,秦家,秦家镇', 46.7961100, 126.9997200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22333, 'Qingyang', 'Qingyang', 'Ch''ing-yang,Ch’ing-yang,Qingyang,Qingyang Zhen,qing yang,qing yang zhen,庆阳,庆阳镇', 45.3662000, 128.7918300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22334, 'Qingxi', 'Qingxi', 'Ch''ing-hsi,Ch’ing-hsi,Qingxi,Qingxi Xiang,qing xi,qing xi xiang,清溪,清溪乡', 49.3252000, 127.1395300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22335, 'Qingshiling', 'Qingshiling', 'Qingshiling,Qingshiling Zhen,qing shi ling,qing shi ling zhen,青石岭,青石岭镇', 40.4753100, 122.4139900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22336, 'Qingshi', 'Qingshi', 'Qingshi,Qingshi Zhen,qing shi,qing shi zhen,青石,青石镇', 41.3593800, 126.5129600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22337, 'Qingshan', 'Qingshan', 'Ch''ing-shan,Ch''ing-shan-p''u,Ch''ing-shan-pao,Ch’ing-shan,Ch’ing-shan-pao,Ch’ing-shan-p’u,Qingshan,Qingshan Xiang,qing shan,qing shan xiang,青山,青山乡', 45.0891500, 126.8994600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22338, 'Qinglong', 'Qinglong', 'Ch''ing-lung,Ch''ing-lung-ch''eng-kuan,Ch’ing-lung,Ch’ing-lung-ch’eng-kuan,Qinglong,Ta-chang-tzu,Ting-tu,Tu-shan,Tu-shan-she-chih-chu,Tu-shan-she-chih-chü,qing long,青龙', 40.4055600, 118.9438900, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22339, 'Qingkenpao', 'Qingkenpao', 'Qingkenpao,Qingkenpao Xiang,qing ken pao,qing ken pao xiang,青肯泡,青肯泡乡', 46.4082500, 125.4410600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22340, 'Qinghecheng', 'Qinghecheng', 'Ch''ing-ho-ch''eng,Ch’ing-ho-ch’eng,Qinghecheng,Qinghecheng Zhen,Tsinghocheng,Tsinkhechen,qing he cheng,qing he cheng zhen,清河城,清河城镇', 41.4546000, 124.2252100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22341, 'Qinghe', 'Qinghe', 'Ch''ing-ho,Ch’ing-ho,Qinghe,Qinghe Zhen,qing he,qing he zhen,清河,清河镇', 46.1820600, 129.3108000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22342, 'Qinghe', 'Qinghe', 'Ch''ing-ho,Ch’ing-ho,Qinghe,Qinghe Zhen,qing he,qing he zhen,清河,清河镇', 41.4387400, 125.9286500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22343, 'Qinghe', 'Qinghe', 'Ch''ing-ho,Ch''ing-ho-chen,Ch’ing-ho,Ch’ing-ho-chen,Qinghe,Qinghe Jiedao,Tsinkhe,qing he,qing he jie dao,清河,清河街道', 40.0296700, 116.3332600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22344, 'Qinggis Han', 'Qinggis Han', 'Ch''ang-ch''i-ssu-hau,Ch''eng-chi-ssu-han,Chengjisihan,Chengjisihan Zhen,Chiang-ch''i-ssu-hsu,Chiang-ch’i-ssu-hsu,Chingghis-Khan,Ch’ang-ch’i-ssu-hau,Ch’eng-chi-ssu-han,Hsin-chan,Qinggis Han,cheng ji si han,cheng ji si han zhen,成吉思汗,成吉思汗镇', 47.7500000, 122.8333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22345, 'Qinggang', 'Qinggang', 'Ch''ing-kang,Ch''ing-kang-chen,Ch''ing-kang-hsien,Ch’ing-kang,Ch’ing-kang-chen,Ch’ing-kang-hsien,Qinggang,Qinggang Xian,Qinggang Zhen,Tsingkang,Tso-shu-kang,qing gang,qing gang xian,qing gang zhen,青冈,青冈县,青冈镇', 46.6846900, 126.1059500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22346, 'Qingduizi', 'Qingduizi', 'Ch''ing-tui-tzu,Ch’ing-tui-tzu,Qingduizi,Qingduzi Zhen,qing dui zi,qing dui zi zhen,青堆子,青堆子镇', 41.4456100, 121.9084800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22347, 'Qingchengzi', 'Qingchengzi', 'Ch''ing-ch''eng,Ch''ing-ch''eng-tzu,Ch’ing-ch’eng,Ch’ing-ch’eng-tzu,Qingchengzi,Qingchengzi Zhen,qing cheng zi,qing cheng zi zhen,青城子,青城子镇', 40.7302800, 123.6050000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22348, 'Qing’an', 'Qing''an', 'Ch''ing-an,Ch''ing-an-chen,Ch''ing-ch''eng,Ch’ing-an,Ch’ing-an-chen,Ch’ing-ch’eng,Kingcheng,Qing''an,Qing''an Xian,Qing''an Zhen,Qing’an,Qing’an Xian,Qing’an Zhen,Yu-ch''ing,Yu-ch''ing-chieh,Yu-ching-kai,Yuking,Yü-ch’ing,Yü-ch’ing-chieh,qing an,qing an xian,qing an zhen,庆安,庆安县,庆安镇', 46.8775900, 127.5005400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22349, 'Qikou', 'Qikou', 'Ch''i-k''ou,Ch’i-k’ou,Lan-ch''i-k''ou-ts''un,Lan-ch''i-p''u,Lan-ch’i-k’ou-ts’un,Lan-ch’i-p’u,Qikou,Qikou Zhen,qi kou,qi kou zhen,旗口,旗口镇', 40.8549200, 122.4233700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22350, 'Qikeshu', 'Qikeshu', 'Qikeshu,Qikeshu Zhen,qi ke shu,qi ke shu zhen,七棵树,七棵树镇', 47.5254800, 123.2579300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22351, 'Qidaogou', 'Qidaogou', 'Ch''i-tao-kou,Ch’i-tao-kou,Qidaogou,Qidaogou Zhen,qi dao gou,qi dao gou zhen,七道沟,七道沟镇', 41.5471300, 126.3030600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22352, 'Guta', 'Guta', 'Ch''ien-t''un-we,Ch''ien-t''un-wei,Ch''ien-wei,Ch’ien-t’un-we,Ch’ien-t’un-wei,Ch’ien-wei,Guta,Qianwei,Qianwei Zhen,gu ta,qian wei,qian wei zhen,前卫,前卫镇,古塔', 40.1908400, 120.0983400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22353, 'Qiansuo', 'Qiansuo', 'Chung-ch''ien-so,Chung-ch’ien-so,Qiansuo,Qiansuo Zhen,qian suo,qian suo zhen,前所,前所镇', 40.0948600, 119.9477600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22354, 'Qiaozi', 'Qiaozi', 'Qiaozi,Qiaozi Zhen,qiao zi,qiao zi zhen,桥梓,桥梓镇', 40.2900500, 116.5726000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22355, 'Qianjiadian', 'Qianjiadian', 'Ch''ien-chia-tien,Ch’ien-chia-tien,Qianjiadian,Qianjiadian Zhen,qian jia dian,qian jia dian zhen,千家店,千家店镇', 40.6947600, 116.3420500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22356, 'Songyuan', 'Songyuan', 'Songyuan,Sunujuan'',Sōngyuán,YSQ,sangywan,song yuan,ssung-wian si,Сунъюань,سانگیوان,松原,쑹위안 시', 45.1290200, 124.8276900, 'CN', '2016-11-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22357, 'Qianfeng', 'Qianfeng', 'Ch''ien-feng,Ch’ien-feng,Qianfeng,Qianfeng Zhen,gan feng,gan feng zhen,乾丰,乾丰镇', 47.7777400, 126.2462300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22358, 'Qian’an', 'Qian''an', 'Ch''ang-fa-t''un,Ch''ien-an,Ch''ien-an-chen,Ch’ang-fa-t’un,Ch’ien-an,Ch’ien-an-chen,Qian''an,Qian’an,Tsyan''an,Tsyan’an,gan an,乾安', 44.9932400, 124.0581100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22359, 'Qasq', 'Qasq', 'Ch''a-su-ch''i,Ch’a-su-ch’i,Qasq,T''u-mo-t''e-tso-ch''i,Tu-mo-t''e-ch''i,Tu-mo-t’e-ch’i,Tumd Zuoqi,Tumoteyou Qi,T’u-mo-t’e-tso-ch’i,cha su qi,tu mo te you qi,土默特右旗,察素齐', 40.7122200, 111.1288900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22360, 'Qagan Obo', 'Qagan Obo', 'Chagan Aobao,Chagan Aobao Sumu,Qagan Obo,cha gan ao bao,cha gan ao bao su mu,查干敖包,查干敖包苏木', 44.2484000, 111.7394700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22361, 'Ming’antu', 'Ming''antu', 'Ch''a-han-nao,Ch''a-han-nao-erh,Chagannao''er,Chagannao’er,Cheng-hsiang-pai-ch''i,Cheng-hsiang-pai-ch’i,Ch’a-han-nao,Ch’a-han-nao-erh,Ho-shih-miao,Ming''antu,Ming''antu Zhen,Ming’antu,Ming’antu Zhen,Qagan Nur,Zhengxiangbai Qi,cha gan nao er,he shuo miao,ming an tu,ming an tu zhen,zheng xiang bai qi,和硕庙,明安图,明安图镇,查干淖尔,正镶白旗', 42.3027800, 114.9933300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22362, 'Pingzhuang', 'Pingzhuang', 'P''ing-chuang,Pingzhuang,Pingzhuang Zhen,P’ing-chuang,Yuanbaoshan Qu,ping zhuang,ping zhuang zhen,yuan bao shan qu,元宝山区,平庄,平庄镇', 42.0372200, 119.2888900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22363, 'Pingyang', 'Pingyang', 'Chzhen,P''in-niang-chen,P''in-yang-chen,P''ing-yang-chen,Pingyang,Pingyang Zhen,Pinvanezhen,P’in-niang-chen,P’in-yang-chen,P’ing-yang-chen,ping yang,ping yang zhen,平阳,平阳镇', 48.2715900, 124.3481100, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22364, 'Pingyang', 'Pingyang', 'Pingyang,Pingyang Zhen,ping yang,ping yang zhen,平洋,平洋镇', 46.6019900, 123.5389500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22365, 'Pingtai', 'Pingtai', 'Pingtai,Pingtai Zhen,ping tai,ping tai zhen,平台,平台镇', 45.7166700, 122.6500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22366, 'Pingshan', 'Pingshan', 'Erh-tao-ho,Erh-tao-ho-tzu,Pingshan,Pingshan Zhen,ping shan,ping shan zhen,平山,平山镇', 45.3229100, 127.3975800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22367, 'Pingquan', 'Pingquan', 'P''ing-ch''uan,P''ing-ch''uan-ch''eng-kuan,P''ing-ch''uan-hsien,P''ing-hsuan,Pa-kou,Pakow,Pingquan,Pingtsuen,Pingtsüen,P’ing-ch’uan,P’ing-ch’üan-ch’eng-kuan,P’ing-ch’üan-hsien,P’ing-hsuan,ping quan,平泉', 41.0025000, 118.6841700, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22368, 'Pingdingshan', 'Pingdingshan', 'P''ing-ting-shan,Pindinshan'',Pindinshan’,Pingdingshan,Pingdingshan Zhen,P’ing-ting-shan,ping ding shan,ping ding shan zhen,平顶山,平顶山镇', 41.4129600, 124.7622700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22369, 'Pingdingbu', 'Pingdingbu', 'Guyuan,Ku-yuan,Ku-yüan,P''ing-ting-p''u,P''ing-ting-pao,Pingdingbu,P’ing-ting-pao,P’ing-ting-p’u,ping ding bao,平定堡', 41.6652800, 115.6977800, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22370, 'Ping’an', 'Ping''an', 'P''ing-an-chen,Ping''an,Ping''an Zhen,Ping''anzhen,Ping’an,Ping’an Zhen,Ping’anzhen,P’ing-an-chen,ping an,ping an zhen,平安,平安镇', 45.7500000, 122.5333300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22371, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Xiang,Ping’an,Ping’an Xiang,ping an,ping an xiang,平安,平安乡', 40.8823800, 122.1585800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22372, 'Panshi', 'Panshi', 'Mo-p''a-shan,Mo-p''an-shan,Mo-p’a-shan,Mo-p’an-shan,P''an-shih,P''an-shih-chen,P''an-shih-hsien,Pan''shi,Panshi,Panshihtun,P’an-shih,P’an-shih-chen,P’an-shih-hsien,Паньши', 42.9422200, 126.0561100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22373, 'Panshan', 'Panshan', 'P''an-shan-chen,P''an-shan-hsien,Panshan,P’an-shan-chen,P’an-shan-hsien,Shuang-t''ai-tzu,Shuang-t’ai-tzu', 41.1880600, 122.0494400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22374, 'Oupu', 'Oupu', 'Ou-p''u-hsien,Ou-p’u-hsien,Oupu,Oupu Xiang,Wo-hsi-men,ou pu,ou pu xiang,Оупу,鸥浦,鸥浦乡', 52.7831600, 126.0567400, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22375, 'Oroin Xibe', 'Oroin Xibe', 'Aolin Xibo,Aolin Xibo Xiang,Oroin Xibe,ao lin xi bo,ao lin xi bo xiang,敖林西伯,敖林西伯乡', 46.3233800, 124.2529500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22376, 'Nuanchitang', 'Nuanchitang', 'Nuan-ch''ih-t''ang,Nuan-ch’ih-t’ang,Nuanchitang,Nuanchitang Zhen,nuan chi tang,nuan chi tang zhen,暖池塘,暖池塘镇', 41.0280300, 120.6638500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22377, 'Nonghe', 'Nonghe', 'Nonghe,Nonghe Zhen,Nung-ho,Nung-ho-chen,Nunkhechzhen'',Nunkhechzhen’,nong he,nong he zhen,浓河,浓河镇', 45.9948300, 128.3597600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22378, 'Nong’an', 'Nong''an', 'Ku-huang-lung-fu,Lungwan,Nong''an,Nong’an,Nung-an,Nung-an-chen,Nung-an-hsien,nong an,农安', 44.3819800, 125.1684700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22379, 'Lubei', 'Lubei', 'Lubei,Niu-chuang,Niu-chuang-ch''eng,Niu-chuang-ch’eng,Niuzhuang,Niuzhuang Zhen,lu bei,niu zhuang zhen,牛庄镇,路北', 40.9480100, 122.5274800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22380, 'Niuxinbao', 'Niuxinbao', 'Niu-hsin-p''u,Niu-hsin-pao,Niu-hsin-p’u,Niuxinbao,Niuxinbao Xiang,niu xin bao,niu xin bao xiang,牛心堡,牛心堡乡', 40.0522000, 112.5228800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22381, 'Niulanshan', 'Niulanshan', 'Niulanshan,Niulanshan Zhen,Nyulan''shan'',Nyulan’shan’,niu lan shan,niu lan shan zhen,牛栏山,牛栏山镇', 40.2158100, 116.6529800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22382, 'Niu’erhe', 'Niu''erhe', 'Niu''erhe,Niu''erhe Zhen,Niu-erh-ho,Niu’erhe,Niu’erhe Zhen,niu er he,niu er he zhen,牛耳河,牛耳河镇', 51.5569000, 121.7457200, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22383, 'Nirji', 'Nirji', 'Busi,Hsi-pu-t''e-ha,Hsi-pu-t’e-ha,I-pu-ch''i,I-pu-ch’i,Irutsi,Mo-li-ta-wa-ch''i,Mo-li-ta-wa-ch’i,Mo-li-ta-wa-ta-wo-erh-tsu-tzu-chih-ch''i,Mo-li-ta-wa-ta-wo-erh-tsu-tzu-chih-ch’i,Molidawa Dawo''erzu Zizhiqi,Molidawa Dawo’erzu Zizhiqi,Morin Dawa,Morin Dawa Daurzu Zizhiqi,Ni''erji,Ni''erji Zhen,Ni-erh-chi,Nirji,Ni’erji,Ni’erji Zhen,Pu-hsi,Pu-hsi-hsien,Pushi,Ta-kan-erh-tsu-tzu-chih-ch''i,Ta-kan-erh-tsu-tzu-chih-ch’i,mo li da wa da wo er zu zi zhi qi,ni er ji,ni er ji zhen,尼尔基,尼尔基镇,莫力达瓦达斡尔族自治旗', 48.4833300, 124.4833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22384, 'Ningjiang', 'Ningjiang', 'Ningjiang,Ningjiang Mengguzu Xiang,ning jiang,ning jiang meng gu zu xiang,宁姜,宁姜蒙古族乡', 46.2856000, 123.7257500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22385, 'Ning’an', 'Ning''an', 'Ninan,Ning''an,Ning''an Shi,Ning-an-chen,Ning-an-hsien,Ning-ku-t''a,Ning-ku-t’a,Ningata,Ninguta,Ning’an,Ning’an Shi,ning an,ning an shi,宁安,宁安市', 44.3439500, 129.4655600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22386, 'Nianzishan', 'Nianzishan', 'Ch''ien-nien-tzu-shan,Ch’ien-nien-tzu-shan,Nianzishan,Nien-tzu-shan,Nien-tzu-shan-chan', 47.5166700, 122.8833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22387, 'Nianpan', 'Nianpan', 'Nianpan,Nianpan Xiang,nian pan,nian pan xiang,碾盘,碾盘乡', 41.8213400, 124.0376300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22388, 'Nenjiang', 'Nenjiang', 'Mergen,Mo-erh-ken,Nen-ch''eng,Nen-ch''eng-hsien,Nen-chiang,Nen-chiang-chen,Nen-ch’eng,Nen-ch’eng-hsien,Nenjiang,Nenjiang Xian,Nenkiang,Nun Cheng,Nun-ch''iang,Nun-ch''ien,Nun-ch’iang,Nun-ch’ien,Nunkiang,Nunkianghsien,Nünkianghsien,nen jiang,nen jiang xian,嫩江,嫩江县', 49.1741400, 125.2177400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22389, 'Nehe', 'Nehe', 'Bordo,Bordotschan,Na-ho,Ne-ho,Nehe,Nehkheh,Nekhe,No-ho,No-ho-chen,No-ho-hsien,Nê-ho,Po-erh-to,Porto,Нэхэ', 48.4833300, 124.8333300, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22390, 'Na’erhong', 'Na''erhong', 'Na''erhong,Na''erhong Zhen,Na-erh-hung,Narhong,Na’erhong,Na’erhong Zhen,na er hong,na er hong zhen,那尔轰,那尔轰镇', 42.6913900, 126.9915300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22391, 'Naran Bulag', 'Naran Bulag', 'Naran Bulag,Naren Baolage,Naren Baolage Sumu,na ren bao la ge,na ren bao la ge su mu,那仁宝拉格,那仁宝拉格苏木', 44.6333300, 114.1166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22392, 'Naozhi', 'Naozhi', 'Naozhi,Naozhi Zhen,nao zhi,nao zhi zhen,闹枝,闹枝镇', 41.9261800, 127.0243400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22393, 'Nanzamu', 'Nanzamu', 'Nan-cha-mu-huo-lo,Nan-tsa-mu,Nan-tsa-mu-huo-lo,Nanzamu,Nanzamu Zhen,nan za mu,nan za mu zhen,南杂木,南杂木镇', 41.9692700, 124.4110100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22394, 'Nantai', 'Nantai', 'Nantai,Nantai Zhen,nan tai,nan tai zhen,南台,南台镇', 40.9241000, 122.8043700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22395, 'Nanshao', 'Nanshao', 'Nanshao,Nanshao Zhen,nan shao,nan shao zhen,南邵,南邵镇', 40.2059100, 116.2795900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22396, 'Nanping', 'Nanping', 'Dehua Zhen,Nanping,Nanping Zhen,de hua zhen,nan ping,nan ping zhen,南坪,南坪镇,德化镇', 42.2629200, 129.2044400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22397, 'Nanpiao', 'Nanpiao', 'Nanpiao,Pien-lien-tzu,nan piao,南票', 41.0982200, 120.7479200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22398, 'Nankouqian', 'Nankouqian', 'Nan-k''ou-ch''ien,Nan-k’ou-ch’ien,Nankouqian,Nankouqian Zhen,nan kou qian,nan kou qian zhen,南口前,南口前镇', 41.9865900, 124.6008100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22399, 'Nankou', 'Nankou', 'Nan-k''ou-chen,Nan-k’ou-chen,Nankou,Nankou Zhen,nan kou,nan kou zhen,南口,南口镇', 40.2358500, 116.1247800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22400, 'Nanhaoqian', 'Nanhaoqian', 'Nan-hao-ch''ien,Nan-hao-ch’ien,Nanhaoqian,Shang-i,Shangyi,nan hao qian,南壕堑', 41.0680600, 113.9602800, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22401, 'Nanfaxin', 'Nanfaxin', 'Nanfaxin,Nanfaxin Zhen,nan fa xin,nan fa xin zhen,南法信,南法信镇', 40.1208800, 116.6025000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22402, 'Nandulehe', 'Nandulehe', 'Nan-tu-lo-ho,Nan-tu-lou-ho,Nandulehe,Nandulehe Zhen,nan du le he,nan du le he zhen,南独乐河,南独乐河镇', 40.1706700, 117.2134300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22403, 'Nandianzi', 'Nandianzi', 'Goukou,Nan-tien,Nan-tien-tzu,Nandian,Nandianzi,Nandianzi Zhen,gou kou,nan dian zi,nan dian zi zhen,南甸子,南甸子镇,沟口', 41.2817700, 124.3702400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22404, 'Lianhe', 'Lianhe', 'Lianhe,Lianhe Jiedao,Nan-ch''a-t''un,Nan-ch’a-t’un,Nancha,Nancha Qu,lian he,lian he jie dao,nan cha,nan cha qu,南岔,南岔区,联合,联合街道', 47.1333300, 129.2742600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22405, 'Nancai', 'Nancai', 'Nancai,Nancai Zhen,nan cai,nan cai zhen,南彩,南彩镇', 40.1362500, 116.6959500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22406, 'Naji', 'Naji', 'A-jung-ch''i,A-jung-ch’i,Aron,Arong Qi,Arun Qi,Na-chi,Na-chi-t''un,Na-chi-t’un,Naji,Naji Zhen,Najitun,a rong qi,na ji,na ji qi,那吉,那吉旗,阿荣旗', 48.1221700, 123.4590400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22407, 'Muyuzi', 'Muyuzi', 'Mu-yu-tzu,Mu-yü-tzu,Muyuzi,Muyuzi Zhen,mu yu zi,mu yu zi zhen,木盂子,木盂子镇', 41.3817500, 124.9550300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22408, 'Muyuan', 'Muyuan', 'Mujuan'',Muyuan,Muyuan Zhen,mu yuan,mu yuan zhen,Муюань,牧原,牧原镇', 49.4008900, 121.1242700, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22409, 'Muqi', 'Muqi', 'Muqi,Muqi Zhen,mu qi,mu qi zhen,木奇,木奇镇', 41.7718100, 124.6202100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22410, 'Muniu', 'Muniu', 'Muniu,Muniu Xiang,mu niu,mu niu xiang,牧牛,牧牛乡', 40.6582200, 123.2255300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22411, 'Muleng', 'Muleng', 'Mu-leng,Mu-leng-chan,Mu-leng-chen,Mu-leng-hsien,Muleng,Muleng Zhen,Muling,Mulingchan,mu leng,mu leng zhen,穆棱,穆棱镇', 44.5202500, 130.2513000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22412, 'Mulin', 'Mulin', 'Mulin,Mulin Zhen,mu lin,mu lin zhen,木林,木林镇', 40.2429000, 116.7818600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22413, 'Mulan', 'Mulan', 'Mu-lan-chen,Mu-lan-hsien,Mulan,Mulan Xian,Wu-chan,mu lan,mu lan xian,木兰,木兰县', 45.9471500, 128.0370600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22414, 'Mujiayingzi', 'Mujiayingzi', '', 42.1166700, 118.7833300, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22415, 'Mudanjiang', 'Mudanjiang', 'Bo-tan-kang-chhi,Bó͘-tan-kang-chhī,MDG,Mau GJon Giang,Mu-dang-geng,Mu-tan-chiang,Mu-tan-chiang-shih,Mu-tan-tiang,Mu-tan-ťiang,Mudan''czjan,Mudancjan,Mudandziangas,Mudandzjan,Mudanjiang,Mudanjiang Shi,Mutankiang,Mū-dăng-gĕ̤ng,Mẫu Đơn Giang,mu dan jiang,mu dan jiang shi,mudanjang si,mwdanjyang,Мудандзян,Муданьцзян,Муданђанг,مودانجیانگ,مۇدەنجياڭ شەھىرى,牡丹江,牡丹江市,무단장 시', 44.5833300, 129.6000000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22416, 'Mo’er Daoga', 'Mo''er Daoga', 'Mo''er Daoga,Mo''er Daoga Zhen,Mo-erh-tao-a,Mo-erh-tao-ka,Mordaga,Moridaga,Moridaga Zhen,Mo’er Daoga,Mo’er Daoga Zhen,mo er dao ga,mo er dao ga zhen,Мордага,莫尔道嘎,莫尔道嘎镇', 51.2590100, 120.7708400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22417, 'Moguqi', 'Moguqi', 'Ma-ku-ch''i,Ma-ku-ch’i,Meng-ku-chi,Mo-ku-ch''i,Mo-ku-ch''i-tun,Mo-ku-ch’i,Mo-ku-ch’i-tun,Moguqi,Moguqi Zhen,Mokechzha,Myngutszi,mo gu qi,mo gu qi zhen,蘑菇气,蘑菇气镇', 47.4947500, 122.3723100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22418, 'Modaoshi', 'Modaoshi', 'Mo-tao-shih,Mo-tao-shih-ts''un,Mo-tao-shih-ts’un,Modaoshi,Modaoshi Zhen,mo dao shi,mo dao shi zhen,磨刀石,磨刀石镇', 44.5603800, 129.8596400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22419, 'Mishan', 'Mishan', 'Dunan,Hsin-mi-shan,Mi-shan-chen,Mishan,Mishan'',Tung-an,Мишань', 45.5500000, 131.8833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22420, 'Minyi', 'Minyi', 'Minyi,Minyi Xiang,min yi,min yi xiang,民意,民意乡', 44.9255400, 127.2969800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22421, 'Minle', 'Minle', 'Minle,Minle Xiang,min le,min le xiang,民乐,民乐乡', 47.5233400, 126.0408500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22422, 'Minle', 'Minle', 'Minle,Minle Zhen,min le,min le zhen,民乐,民乐镇', 46.7301100, 127.4205500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22423, 'Mingyue', 'Mingyue', 'An-t''u,An-t''u-hsien,An-t’u,An-t’u-hsien,Antuzhan,Ming-yueh-chen,Ming-yueh-kou,Ming-yueh-kou-chen,Ming-yüeh-chen,Ming-yüeh-kou,Ming-yüeh-kou-chen,Mingyue,Mingyuegou,Weng-sheng-la-tzu,ming yue,明月', 43.1069400, 128.9216700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22424, 'Mingyi', 'Mingyi', 'Mingyi,Mingyi Xiang,ming yi,ming yi xiang,明义,明义乡', 46.4446900, 130.4328200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22425, 'Mingshuihe', 'Mingshuihe', 'Mingshuihe,Mingshuihe Zhen,ming shui he,ming shui he zhen,明水河,明水河镇', 46.6582600, 120.7088400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22426, 'Mingshui', 'Mingshui', 'Hsing-lung-chen,Ming-shui-chen,Ming-shui-hsien,Mingshui,Mingshui Xian,Mingshui Zhen,ming shui,ming shui xian,ming shui zhen,明水,明水县,明水镇', 47.1815000, 125.9002700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22427, 'Mingshui', 'Mingshui', 'Mingshui,Mingshui Manzuxiang,ming shui,ming shui man zu xiang,明水,明水满族乡', 40.3616600, 119.8878100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22428, 'Mingshan', 'Mingshan', 'Mingshan,Mingshan Zhen,ming shan,ming shan zhen,名山,名山镇', 47.6769400, 131.0733300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22429, 'Mijiang', 'Mijiang', 'Mi-chiang,Mi-chiang-t''un,Mi-chiang-t’un,Mijiang,Mijiang Xiang,mi jiang,mi jiang xiang,密江,密江乡', 42.9961100, 130.1408300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22430, 'Miaocheng', 'Miaocheng', 'Miaocheng,Miaocheng Zhen,miao cheng,miao cheng zhen,庙城,庙城镇', 40.2920900, 116.6228100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22431, 'Mianduhe', 'Mianduhe', 'Mianduhe,Mianduhe Zhen,Mien-tu-ho,Mien-tu-ko,Mjan''dukheh,Myandukhe,mian du he,mian du he zhen,Мяньдухэ,免渡河,免渡河镇', 49.1000000, 121.0333300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22432, 'Mengjiagang', 'Mengjiagang', 'Meng-chia-kang,Mengjiagang,Mengjiagang Zhen,meng jia gang,meng jia gang zhen,孟家岗,孟家岗镇', 46.4224000, 130.6600000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22433, 'Meiyao', 'Meiyao', 'Meiyao,Meiyao Xiang,Wanbao,mei yao,mei yao xiang,煤窑,煤窑乡', 45.7833300, 121.8333300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22434, 'Meixi', 'Meixi', 'Mei-ch''i,Mei-ch’i,Mei-hsi,Meixi,Meixi Jiedao,Meixi Qu,mei xi,mei xi jie dao,mei xi qu,美溪,美溪区,美溪街道', 47.6317000, 129.1306400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22435, 'Meilisi', 'Meilisi', 'Mei-li-ssu,Mei-lo-ssu,Meilisi,Meilisi Jiedao,Mi-la-ssu,mei li si,mei li si jie dao,梅里斯,梅里斯街道', 47.3149900, 123.7544200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22436, 'Meihekou', 'Meihekou', 'Hai-lung,Hai-lung-hsien,Hailong,Mei-ho-k''ou,Mei-ho-k''ou-chen,Mei-ho-kow,Mei-ho-k’ou,Mei-ho-k’ou-chen,Meihekou', 42.5272200, 125.6752800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22437, 'Mazhonghe', 'Mazhonghe', 'Mazhonghe,Mazhonghe Zhen,ma zhong he,ma zhong he zhen,马仲河,马仲河镇', 42.7145200, 124.0233200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22438, 'Mayihe', 'Mayihe', 'Ma-i-ho,Mayihe,Mayihe Xiang,ma yi he,ma yi he xiang,蚂蚁河,蚂蚁河乡', 41.8158300, 127.1141700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22439, 'Mashan', 'Mashan', 'Ma-shan-t''un,Ma-shan-t’un,Mashan,Mashan Qu,ma shan,ma shan qu,麻山,麻山区', 45.2050800, 130.5261400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22440, 'Maqiaohe', 'Maqiaohe', 'Ma-ch''iao-ho,Ma-ch''iao-ho-ts''un,Ma-ch’iao-ho,Ma-ch’iao-ho-ts’un,Makiaoho,Maqiaohe,Maqiaohe Zhen,Matsyaokhe,ma qiao he,ma qiao he zhen,马桥河,马桥河镇', 44.6910000, 130.5358900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22441, 'Mao’ershan', 'Mao''ershan', 'Mao''ershan,Mao''ershan Zhen,Mao-erh-shan,Mao-shan,Maoerhshanchan,Mao’ershan,Mao’ershan Zhen,mao r shan,mao r shan zhen,帽儿山,帽儿山镇', 45.2755500, 127.5028500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22442, 'Manzhouli', 'Manzhouli', 'Lu-pin-hsien,Lupin,Man-chou-li,Man-chou-li-shih,Man-chow-li,Manchuli,Manchuria,Manchuriya,Manchzhuriya,Mandschurei,Manzhouli,NZH,man zhou li,man zhou li shi,man''chzhurija,manjeouli,manzhuur,Манжуур,Маньчжурия,満州里,満州里市,满洲里市,만저우리', 49.6000000, 117.4333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22443, 'Manjiang', 'Manjiang', 'Man-chiang,Man-chiang-ts''un,Man-chiang-ts’un,Manjiang,Manjiang Zhen,man jiang,man jiang zhen,漫江,漫江镇', 41.9475600, 127.5908300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22444, 'Mangui', 'Mangui', 'Man''gui,Man-kuei,Mangui,Mangui Zhen,man gui,man gui zhen,Маньгуи,满归,满归镇', 52.0413600, 122.0656300, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22445, 'Mandalt', 'Mandalt', 'Man-tu-la-t''u,Man-tu-la-t’u,Mandalt,Mandulatu,Mandulatu Zhen,Pei-le-miao,Pei-lo-miao,Sonid Zuoqi,Su-ni-t''e-tso-ch''i,Su-ni-t’e-tso-ch’i,Sunitezuo Qi,man dou la tu,man dou la tu zhen,su ni te zuo qi,满都拉图,满都拉图镇,苏尼特左旗', 43.8402800, 113.7155600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22446, 'Mahe', 'Mahe', 'Ma-lien-ho,Ma-lien-ho-ts''un,Ma-lien-ho-ts’un,Mahe,Mahe Xiang,Malianhe,ma he,ma he xiang,马河,马河乡', 44.0457300, 129.1880100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22447, 'Majunying', 'Majunying', 'Ma-chun-ying,Ma-chün-ying,Majunying,Majunying Xiang,ma jun ying,ma jun ying xiang,马军营,马军营乡', 40.0908300, 113.2247200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22448, 'Majuanzi', 'Majuanzi', 'Ma-ch''uan-zi,Ma-ch’üan-zi,Majuanzi,Majuanzi Xiang,ma quan zi,ma quan zi xiang,马圈子,马圈子乡', 41.5254600, 124.3697700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22449, 'Mafeng', 'Mafeng', 'Mafeng,Mafeng Zhen,ma feng,ma feng zhen,马风,马风镇', 40.8089500, 122.9095000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22450, 'Tongshanjie', 'Tongshanjie', 'Madang,Madang Zhen,Tongshanjie,ma dang,ma dang zhen,tong shan jie,铜山街,马当,马当镇', 41.8400400, 125.8500300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22451, 'Machikou', 'Machikou', 'Ma-ch''ih-k''ou,Ma-ch’ih-k’ou,Machikou,Machikou Zhen,ma chi kou,ma chi kou zhen,马池口,马池口镇', 40.1823100, 116.1613400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22452, 'Machangying', 'Machangying', 'Machangying,Machangying Zhen,ma chang ying,ma chang ying zhen,马昌营,马昌营镇', 40.1377700, 117.0151200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22453, 'Lüyang', 'Luyang', 'Lu-yang-i,Luyang,Luyang Zhen,Luyangyi,Lü-yang-i,Lüyang,Lüyang Zhen,Lüyangyi,Yen-yang-tse,lu yang,lu yang zhen,闾阳,闾阳镇', 41.3819300, 121.6663200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22454, 'Lüwang', 'Luwang', 'Luwang,Luwang Zhen,Lüwang,Lüwang Zhen,lu wang,lu wang zhen,吕王,吕王镇', 40.3997100, 122.8729200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22455, 'Lushuihe', 'Lushuihe', 'Hsi-nan-ch''a,Hsi-nan-ch’a,Lu-shui-ho,Lushuihe,Lushuihe Zhen,lu shui he,lu shui he zhen,露水河,露水河镇', 42.5189900, 127.7825700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22456, 'Luozigou', 'Luozigou', 'Ku-ch''eng,Ku-ch’eng,Lo-tzu-kou,Luozigou,Luozigou Zhen,Sui-fen,Sui-fen-ta-tien-tzu,luo zi gou,luo zi gou zhen,罗子沟,罗子沟镇', 43.7293200, 130.3404200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22457, 'Luoluopu', 'Luoluopu', 'Luoluopu,Luoluopu Zhen,luo luo bao,luo luo bao zhen,罗罗堡,罗罗堡镇', 41.5529100, 121.7142000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22458, 'Lunhe', 'Lunhe', 'Lun-ho,Lun-ho-chen,Lunhe,Lunhe Zhen,lun he,lun he zhen,伦河,伦河镇', 47.1378200, 126.4291400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22459, 'Luhe', 'Luhe', 'Lu-ho,Luhe,Luhe Zhen,lu he,lu he zhen,芦河,芦河镇', 46.5616500, 126.1601000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22460, 'Lubei', 'Lubei', 'Cha-lu-t''e-ch''i,Cha-lu-t’e-ch’i,Jarod,Jarud Qi,Lu-pei,Lu-pei-chieh,Lu-pei-hsien,Lubai,Lubei,Lubei Zhen,Lubey,Lupeh,Zhalute Qi,lu bei,lu bei zhen,zha lu te qi,扎鲁特旗,鲁北,鲁北镇', 44.6086600, 120.9556000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22461, 'Luanping', 'Luanping', 'An-chiang-t''un,An-chiang-t’un,An-chiang-ying,Anjiangying,Luan''pin,Luan-p''ing-hsien,Luan-p’ing-hsien,Luanping,Luan’pin,luan ping,滦平', 40.9166700, 117.2833300, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22462, 'Loujiadian', 'Loujiadian', 'Loujiadian,Loujiadian Xiang,lou jia dian,lou jia dian xiang,娄家店,娄家店乡', 42.0580700, 120.6719900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22463, 'Longzhua', 'Longzhua', 'Longzhao,Longzhua,Longzhua Zhen,long zhao,long zhao zhen,龙爪,龙爪镇', 45.2490100, 130.1439700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22464, 'Longwantun', 'Longwantun', 'Longwantun,Longwantun Zhen,long wan tun,long wan tun zhen,龙湾屯,龙湾屯镇', 40.2228000, 116.8568300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22465, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,Lung-ch''uan,Lung-ch’üan,long quan,long quan zhen,龙泉,龙泉镇', 46.2077100, 127.4571100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22466, 'Longjing', 'Longjing', 'Liu-tao-kou,Longjing,Lung-ching,Lung-ching-chen,Lung-ching-chieh,Lung-ching-shih,Lung-ching-ts''un,Lung-ching-ts’un,Luntszintsun,Ryuseison,Ryūseison,Yanji,Yen-chi-hsien,Yonjontsuon,long jing,龙井', 42.7713900, 129.4233300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22467, 'Longjiang', 'Longjiang', 'Chu-chia-k''an,Chu-chia-k’an,Chukiakan,Lonczjan,Longjiang,Longjiang Xian,Longjiang Zhen,Lung-chiang,Lung-chiang-chen,T''u-erh-ch''ih-ha,T’u-erh-ch’ih-ha,long jiang,long jiang xian,long jiang zhen,Лонцзян,龙江,龙江县,龙江镇', 47.3307200, 123.1781600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22468, 'Longhua', 'Longhua', 'Huang-ku-t''un,Huang-ku-t’un,Longhua,Lung-hua,Lung-hua-ch''eng-kuan,Lung-hua-ch’eng-kuan,Lung-hua-hsien,long hua,隆化', 41.3116700, 117.7250000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22469, 'Longfengshan', 'Longfengshan', 'Longfengshan,Longfengshan Xiang,long feng shan,long feng shan xiang,龙凤山,龙凤山乡', 44.7657800, 127.5801500, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22470, 'Longfeng', 'Longfeng', 'Longfeng,Longfeng Jiedao,Longfeng Qu,Lung-feng,Lung-feng-shan,long feng,long feng jie dao,long feng qu,龙凤,龙凤区,龙凤街道', 46.5316800, 125.1038000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22471, 'Long’anqiao', 'Long''anqiao', 'Long''anqiao,Long''anqiao Zhen,Long’anqiao,Long’anqiao Zhen,Lung-an-ch''iao,Lung-an-ch’iao,long an qiao,long an qiao zhen,龙安桥,龙安桥镇', 47.5188100, 124.4443800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22472, 'Liutuan', 'Liutuan', 'Liutuan,Liutuan Zhen,liu tuan,liu tuan zhen,六团,六团镇', 45.5778300, 128.4869100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22473, 'Liushutun', 'Liushutun', 'Liushutun,Liushutun Muguzu Manzuxiang,liu shu tun,liu shu tun meng gu zu man zu xiang,柳树屯,柳树屯蒙古族满族乡', 42.6267900, 122.9677600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22474, 'Liushu', 'Liushu', 'Liushu,Liushu Zhen,Liushuhe,liu shu,liu shu zhen,柳树,柳树镇', 44.9090200, 130.0077800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22475, 'Liulimiao', 'Liulimiao', 'Liu-li-miao-tzu,Liulimiao,Liulimiao Zhen,Po-li-miao,liu li miao,liu li miao zhen,琉璃庙,琉璃庙镇', 40.6276200, 116.6452400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22476, 'Liujiahe', 'Liujiahe', 'Liu-chia-ho,Liujiahe,Liujiahe Zhen,liu jia he,liu jia he zhen,刘家河,刘家河镇', 40.6696100, 123.9792900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22477, 'Liuhe', 'Liuhe', 'Liuhe,Liuhe Zhen,liu he,liu he zhen,柳河,柳河镇', 46.0116200, 127.7187500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22478, 'Liuhe', 'Liuhe', 'Liu-ho,Liu-ho-chen,Liu-ho-hsien,Liu-hu-ch''eng,Liu-hu-ch’eng,Liu-shu-ho-tzu,Liuhe,Ljukheh,Luiho,liu he,Люхэ,柳河', 42.2400700, 125.7171700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22479, 'Liudaogou', 'Liudaogou', 'Liu-tao-kou,Liudaogou,Liudaogou Zhen,liu dao gou,liu dao gou zhen,六道沟,六道沟镇', 41.6047900, 127.1879500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22480, 'Liudaogou', 'Liudaogou', 'Guosong Zhen,Liu-tao-kou,Liu-tao-kou-t''un,Liu-tao-kou-t’un,Liudaogou,Ta-lo-ch''uan He,Ta-lo-ch’üan He,guo song zhen,liu dao gou,六道沟,果松镇', 41.6081000, 126.2522700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22481, 'Liubinbu', 'Liubinbu', 'Liu-pin-p''u,Liu-pin-p’u,Liubinbu,Liubinbu Xiang,liu bin bao,liu bin bao xiang,刘斌堡,刘斌堡乡', 40.5667300, 116.2132300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22482, 'Lisui', 'Lisui', 'Li-sui-chen,Li-sui-chuang,Li-sui-tien,Lisui,Lisui Zhen,Lisuychzhuan,li sui,li sui zhen,李遂,李遂镇', 40.0883900, 116.7500200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22483, 'Lishu', 'Lishu', 'Lishu,Lishu Qu,Lishuzhen,li shu,li shu qu,梨树,梨树区', 45.0897800, 130.6913600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22484, 'Lishu', 'Lishu', 'Chiu-li-shu,Feng-hua,Fenghwa,Li-shu-chen,Li-shu-hsien,Lishat'',Lishu,Mai-mai-chieh,li shu,Лишать,梨树', 43.3047200, 124.3277800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22485, 'Linyuan', 'Linyuan', 'Linyuan,Linyuan Zhen,lin yuan,lin yuan zhen,林源,林源镇', 46.3073900, 124.7079600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22486, 'Linxi', 'Linxi', 'Lin-hsi,Lin-hsi-hsien,Linsi,Linxi,Linxi Zhen,xi lin,xi lin zhen,西林,西林镇', 43.5166700, 118.0333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22487, 'Linkou', 'Linkou', 'Lin-k''ou-chen,Lin-k''ou-hsien,Lin-k’ou-chen,Lin-k’ou-hsien,Linkou,Linkou Xian,Linkow,lin kou,lin kou xian,林口,林口县', 45.2860600, 130.2615100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22488, 'Linjiang', 'Linjiang', 'Lin''czjane,Lin-chiang,Lin-chiang-hsien,Linjiang,Mao-erh-shan,Mao-tzu-shan,Maoerhshanchan,lin jiang,Линьцзяне,临江', 41.8069400, 126.9077800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22489, 'Linhai', 'Linhai', 'Linhai,Linhai Zhen,lin hai,lin hai zhen,林海,林海镇', 51.5976700, 124.3516000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22490, 'Lingyuan', 'Lingyuan', 'Chien-ch''ang,Kienchang,Ling-yuan-chen,Ling-yuan-hsien,Ling-yüan-chen,Ling-yüan-hsien,T''a-kou', 41.2400000, 119.4011100, 'CN', '2006-01-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22491, 'Lingdong', 'Lingdong', 'Ling-tung,Lingdong', 46.5669400, 131.1452800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22492, 'Lindong', 'Lindong', 'Bairin Zuoqi,Balin''tszotsi,Balin’tszotsi,Chiu-hsiao-pa-lin-pei-tzu-fu,Chiu-pei-tzu-fu,Hsiao-pa-lin-pei-tzu-fu,Hsiaopalinpeitze,Huuchin,Lin-tung,Lin-tung-hsien,Lindong,Lindong Zhen,Pa-lin-tso-ch''i,Pa-lin-tso-ch’i,Pa-lin-tso-i-ch''i,Pa-lin-tso-i-ch’i,ba lin zuo qi,lin dong,lin dong zhen,巴林左旗,林东,林东镇', 43.9833300, 119.1833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22493, 'Lindian', 'Lindian', 'Lin''dyan'',Lin-tien,Lin-tien-chen,Lin-tien-hsien,Lindian,Lindian Xian,Lindian Zhen,Lin’dyan’,Ta-lin-chia-tien,lin dian,lin dian xian,lin dian zhen,林甸,林甸县,林甸镇', 47.1825800, 124.8677300, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22494, 'Lidong', 'Lidong', 'Lidong,Lidong Zhen,li dong,li dong zhen,利东,利东镇', 46.0788900, 127.8911200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22495, 'Lidayao', 'Lidayao', 'Li-ta-yao,Lidayao,Lidayao Xiang,li da yao,li da yao xiang,李达窑,李达窑乡', 40.2371500, 112.4536700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22496, 'Liaozhong', 'Liaozhong', 'A-shih-niu-lu,A-ssu-niu,A-ssu-niu-lu,Chiu-liao-chung,Liao-chung,Liao-chung-chen,Liao-chung-hsien,Liaozhong,Lyaochzhun', 41.5061100, 122.7241700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22497, 'Liaoyuan', 'Liaoyuan', 'Dongliao,Hsi-an,Laeojuan,Liao-juean,Liao-jüan,Liao-yuan-shih,Liao-yüan-shih,Liaojuanas,Liaoyuan,Liau-goan-chhi,Lieu Nguyen,Lieu-nguong,Liâu-goân-chhī,Lièu-nguòng,Liêu Nguyên,Ljaojuan'',Ljaojuen,Läojuan,Pei-feng,Pei-feng-hsien,Shian,Sian,T''a-k''a-ta,Ta-ko-tan,Tung-liao,T’a-k’a-ta,liao yuan,liao yuan shi,lyaowian si,lyawywan,Љаојуен,Ляоюань,لیاویوان,辽源市,遼源,遼源市,랴오위안 시', 42.9036100, 125.1358300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22498, 'Liaoyang', 'Liaoyang', 'LQQ,Liao-jang,Liao-yang-hsien,Liao-yang-shih,Liaojangas,Liaoyang,Liau-iong-chhi,Lieu Duong,Lieu-iong,Liâu-iông-chhī,Lièu-iòng,Liêu Dương,Ljaojan,Ljaojang,liao yang,liao yang shi,lyaoyang si,lyawyang,Љаојанг,Ляоян,لياۋياڭ شەھەر,لیاویانگ,辽阳市,遼陽,遼陽市,랴오양 시', 41.2719400, 123.1730600, 'CN', '2014-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22499, 'Liaotun', 'Liaotun', 'Liaotun,Liaotun Zhen,liao tun,liao tun zhen,廖屯,廖屯镇', 41.4851400, 121.7678900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22500, 'Liaodian', 'Liaodian', 'Liaodian,Liaodian Manzuxiang,Liaodianzi,liao dian,liao dian man zu xiang,料甸,料甸满族乡', 45.6326100, 127.0539300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22501, 'Lianjiangkou', 'Lianjiangkou', 'Lianjiangkou,Lianjiangkou Zhen,Lien-chiang-k''ou,Lien-chiang-k''ou-chen,Lien-chiang-k’ou,Lien-chiang-k’ou-chen,Udagan,Udāgan,lian jiang kou,lian jiang kou zhen,莲江口,莲江口镇', 46.8618500, 130.3075600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22502, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,Lien-hua,lian hua,lian hua zhen,莲花,莲花镇', 46.9904700, 126.8095600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22503, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,Lien-hua,Lien-hua-p''ao,Lien-hua-p’ao,lian hua,lian hua zhen,莲花,莲花镇', 45.5304300, 129.7896700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22504, 'Yongfeng', 'Yongfeng', 'Liangzhong,Liangzhongqiao Zhen,Yongfeng,liang zhong qiao zhen,yong feng,亮中桥镇,永丰', 42.7405300, 123.8495800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22505, 'Liangtun', 'Liangtun', 'Liangtun,Liangtun Zhen,liang tun,liang tun zhen,梁屯,梁屯镇', 40.2113900, 122.5189700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22506, 'Liangshui', 'Liangshui', 'Liang-shui-ch''uan,Liang-shui-ch’üan,Liangshui,Liangshui Chaoxianzu,Liangshui Chaoxianzu Xiang,liang shui,liang shui chao xian zu,liang shui chao xian zu xiang,凉水,凉水朝鲜族,凉水朝鲜族乡', 40.9285200, 125.8530800, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22507, 'Dongjiang', 'Dongjiang', 'Dongjiang,Liang-chiang-k''ou,Liang-chiang-k’ou,Liangjiang Zhen,Liangjiangkou,Lyantszyankou,dong jiang,liang jiang zhen,东江,两江镇', 42.6488900, 128.1002800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22508, 'Lianghe', 'Lianghe', 'Lianghe,Lianghe Zhen,liang he,liang he zhen,亮河,亮河镇', 45.1609400, 128.7617400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22509, 'Daihai', 'Daihai', 'Daihai,Daihai Zhen,Hsin-t''ang,Hsin-t''ang-chen,Hsin-t’ang,Hsin-t’ang-chen,Liangcheng,Liangcheng Xian,dai hai,dai hai zhen,liang cheng,liang cheng xian,凉城,凉城县,岱海,岱海镇', 40.5211100, 112.4930600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22510, 'Liangbing', 'Liangbing', 'Liang-ping-t''ai,Liang-ping-t’ai,Liangbing,Liangbing Zhen,Liangbingtai,liang bing,liang bing zhen,亮兵,亮兵镇', 43.1833300, 128.7833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22511, 'Quangou', 'Quangou', 'Laosiping,Laosiping Zhen,Quangou,lao si ping,lao si ping zhen,quan gou,泉沟,老四平,老四平镇', 43.1819800, 124.2612100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22512, 'Laojinchang', 'Laojinchang', 'Laojinchang,Laojinchang Zhen,lao jin chang,lao jin chang zhen,老金厂,老金厂镇', 42.9075000, 127.3536100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22513, 'Laojieji', 'Laojieji', 'Laojieji,Laojieji Xiang,lao jie ji,lao jie ji xiang,老街基,老街基乡', 44.9711600, 127.9621200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22514, 'Laoheishan', 'Laoheishan', 'Lao-hei-shan-pen-ts''un,Lao-hei-shan-pen-ts’un,Laoheishan,Laoheishan Zhen,lao hei shan,lao hei shan zhen,老黑山,老黑山镇', 43.7117600, 130.8801200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22515, 'Laocheng', 'Laocheng', 'Ch''ang-t''u-ch''eng,Ch''ang-t''u-chen,Ch''ang-t''u-hsien,Chang-tu-fa,Changtu Laocheng,Ch’ang-t’u-chen,Ch’ang-t’u-ch’eng,Ch’ang-t’u-hsien,Laocheng,Laocheng Zhen,Tschangtu,lao cheng,lao cheng zhen,老城,老城镇', 42.7834800, 123.9940000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22516, 'Biancheng', 'Biancheng', 'Biancheng,Biancheng Zhen,Lao-pien,Laobian,Laobian Qu,bian cheng,bian cheng zhen,lao bian,lao bian qu,老边,老边区,边城,边城镇', 40.6785200, 122.3623300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22517, 'Lanxi', 'Lanxi', 'Lan-hsi,Lan-hsi-chen,Lan-hsi-hsien,Lansi,Lanxi,Lanxi Xian,Lanxi Zhen,Shuang-miao-tzu,lan xi,lan xi xian,lan xi zhen,兰西,兰西县,兰西镇', 46.2578500, 126.2826900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22518, 'Langxiang', 'Langxiang', 'Lang-hsiang,Langxiang,Langxiang Zhen,lang xiang,lang xiang zhen,朗乡,朗乡镇', 46.9498500, 128.8684900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22519, 'Langtou', 'Langtou', 'Lang-t''ou-chen,Lang-t’ou-chen,Langtou', 40.0261100, 124.3286100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22520, 'Langang', 'Langang', 'Lan-kang,Lan-kang-ts''un,Lan-kang-ts’un,Langang,Langang Zhen,lan gang,lan gang zhen,兰岗,兰岗镇', 44.2628000, 129.4074000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22521, 'Lamawan', 'Lamawan', 'Lamawan,Lamawan Zhen,la ma wan,la ma wan zhen,喇嘛湾,喇嘛湾镇', 40.0769400, 111.3813900, 'CN', '2012-11-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22522, 'Lamadian', 'Lamadian', 'Lamadian,Lamadian Zhen,Lamadianzi,la ma dian,la ma dian zhen,喇嘛甸,喇嘛甸镇', 46.6951300, 124.7799800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22523, 'Laiguangying', 'Laiguangying', 'Laiguangying,Laiguangying Xiang,lai guang ying,lai guang ying xiang,来广营,来广营乡', 40.0249800, 116.4336300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22524, 'E’erguna', 'E''erguna', 'E''erguna,E''erguna Shi,Ergun,Ergun Shi,Ergun Youqi,E’erguna,E’erguna Shi,La-pu-ta-jen,Lablarin,Labu Dalin,Labudalin'',Na-pu-ta-lin,O-erh-ku-na-yu-ch''i,O-erh-ku-na-yu-ch’i,O-yu-ch''i,O-yu-ch’i,Rabudarin,e er gu na,e er gu na shi,e er gu na you qi,la bu da lin,Лабудалинь,拉布大林,拉布达林,额尔古纳,额尔古纳右旗,额尔古纳市', 50.2236200, 120.1709200, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22525, 'Laba Goumen', 'Laba Goumen', 'La-pa-kou-men,Laba Goumen,Laba Goumen Manzuxiang,la ba gou men,la ba gou men man zu xiang,喇叭沟门,喇叭沟门满族乡', 40.8978000, 116.6163400, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22526, 'Kuruqi', 'Kuruqi', 'Kuruqi,Kuruqi Xiang,ku ru qi,ku ru qi xiang,库如奇,库如奇乡', 48.9629400, 123.8203300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22527, 'Kuishan', 'Kuishan', 'Kuishan,Kuishan Xiang,kui shan,kui shan xiang,奎山,奎山乡', 45.2282700, 130.3967600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22528, 'Kuangdonggou', 'Kuangdonggou', 'K''uang-tung-kou,Kuangdonggou,Kuangdonggou Zhen,K’uang-tung-kou,kuang dong gou,kuang dong gou zhen,矿洞沟,矿洞沟镇', 40.1736100, 122.7041700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22529, 'Kuandian', 'Kuandian', 'K''uan-tien,K''uan-tien-chen,K''uan-tien-hsien,Kuandian,Kwan-tien,K’uan-tien,K’uan-tien-chen,K’uan-tien-hsien', 40.7286100, 124.7847200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22530, 'Kuancheng', 'Kuancheng', 'K''uan-chieng,Kuancheng,Kwancheng,Kwangheng,K’uan-chieng,kuan cheng,宽城', 40.6055600, 118.4825000, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22531, 'Kuanbang', 'Kuanbang', 'Kuanbang,Kuanbang Zhen,kuan bang,kuan bang zhen,宽帮,宽帮镇', 40.5072800, 120.1213900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22532, 'Kuaidamao', 'Kuaidamao', 'K''uai-ta-mao,K''uai-ta-mao-tzu,K''uai-tang-mao-tzu,Kuaidamao,K’uai-ta-mao,K’uai-ta-mao-tzu,K’uai-tang-mao-tzu,T''ung-hua-hsien,Tonghua,T’ung-hua-hsien,kuai da mao,快大茂', 41.6553200, 125.7422500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22533, 'Kouquan', 'Kouquan', 'K''ou-ch''uan,K''ou-ch''uan-chen,Kouquan,Kouquan Zhen,K’ou-ch’üan,K’ou-ch’üan-chen,Nanjiao Qu,kou quan,kou quan zhen,nan jiao qu,南郊区,口泉,口泉镇', 39.9982000, 113.1450000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22534, 'Kouqian', 'Kouqian', 'K''ou-ch''ien,Kouqian,K’ou-ch’ien,Yongji,Yung-chi,kou qian,口前', 43.6391400, 126.4578400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22535, 'Kongjiazhuang', 'Kongjiazhuang', 'K''ung-chia-chuang,Kongjiazhuang,K’ung-chia-chuang,Wanquan,kong jia zhuang,孔家庄', 40.7525000, 114.7261100, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22536, 'Keyihe', 'Keyihe', 'Keyihe,Keyihe Zhen,Ko-i-ho,ke yi he,ke yi he zhen,克一河,克一河镇', 50.6388300, 122.4972000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22537, 'Kertai', 'Kertai', 'Ke''ertai,Ke''ertai Xiang,Kertai,Ke’ertai,Ke’ertai Xiang,ke er tai,ke er tai xiang,克尔台,克尔台乡', 46.8962300, 124.2030200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22538, 'Keluo', 'Keluo', 'K''o-lo,K''o-lo-Tun,K''o-lo-chan,K''o-lo-erh,K''o-lo-ts''un,Kelochzhan,Keluo,Keluo Zhen,Ko-ro,K’o-lo,K’o-lo-Tun,K’o-lo-chan,K’o-lo-erh,K’o-lo-ts’un,Xiangyang,ke luo,ke luo zhen,科洛,科洛镇', 49.2676700, 125.7604600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22539, 'Keli', 'Keli', 'Keli,Keli Xiang,ke li,ke li xiang,克利,克利乡', 46.5034900, 123.4391200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22540, 'Kangzhuang', 'Kangzhuang', 'K''ang-chuang,Kangzhuang,Kangzhuang Zhen,Kwang-chang,K’ang-chuang,kang zhuang,kang zhuang zhen,康庄,康庄镇', 40.3777900, 115.8936700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22541, 'Kangping', 'Kangping', 'K''ang-p''ing-chen,K''ang-p''ing-hsien,Kangping,Kangping Xian,K’ang-p’ing-chen,K’ang-p’ing-hsien,kang ping,kang ping xian,康平,康平县', 42.7391700, 123.3494400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22542, 'Kangjin', 'Kangjin', 'K''ang-chia-ching,K''ang-chin-chen,K''ang-chin-ching,Kangjin,Kangjin Zhen,Kangjinjing,K’ang-chia-ching,K’ang-chin-chen,K’ang-chin-ching,kang jin,kang jin zhen,康金,康金镇', 46.1971000, 126.8040500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22543, 'Kangbao', 'Kangbao', 'K''ang-pao,K''ang-pao-ch''eng-kuan,Kanbao,Kangbao,K’ang-pao,K’ang-pao-ch’eng-kuan,kang bao,康保', 41.8463900, 114.6138900, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22544, 'Kaiyuan', 'Kaiyuan', 'Jih-pen-tsu-chieh-ti,K''ai-yuan-chen,Kaiyuan,Kajjuan'',K’ai-yüan-chen,Sun-chia-t''ai,Sun-chia-t’ai,Кайюань', 42.5330600, 124.0402800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22545, 'Kaitong', 'Kaitong', 'Ch''i-ching-tsa,Ch''i-ching-tzu,Ch’i-ching-tsa,Ch’i-ching-tzu,K''ai-t''ung,K''ai-t''ung-chen,K''ai-t''ung-hsien,Kaibung,Kaitong,Kaitun,K’ai-t’ung,K’ai-t’ung-chen,K’ai-t’ung-hsien,T''ung-yu,Tongyu,T’ung-yü,kai tong,开通', 44.8135100, 123.1500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22546, 'Kaishantun', 'Kaishantun', 'Kaishantun,Kaishantun Zhen,kai shan tun,kai shan tun zhen,开山屯,开山屯镇', 42.7017700, 129.7573800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22547, 'Kailu', 'Kailu', 'K''ai-lu-hsien,Kailu,Kailu Xian,Kailun,Kailun Zhen,K’ai-lu-hsien,kai lu,kai lu xian,kai lu zhen,开鲁,开鲁县,开鲁镇', 43.5833300, 121.2000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22548, 'Juyuan', 'Juyuan', 'Juyuan,Juyuan Zhen,ju yuan,ju yuan zhen,巨源,巨源镇', 45.9418200, 126.9714600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22549, 'Jurh', 'Jurh', 'Jurh,Zhurihe,Zhurihe Zhen,zhu ri he,zhu ri he zhen,珠日河,珠日河镇', 44.2000000, 121.6666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22550, 'Jule', 'Jule', 'Chu-le-p''u,Chu-lo-p''u,Chu-lo-pao,Chu-lo-p’u,Chü-le-p’u,Chü-lo-pao,Jule,Jule Xiang,Julebu', 40.1650000, 113.5747200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22551, 'Jugezhuang', 'Jugezhuang', 'Chu-ko-chuang,Chü-ko-chuang,Jugezhuang,Jugezhuang Zhen,ju ge zhuang,ju ge zhuang zhen,巨各庄,巨各庄镇', 40.3761900, 116.9508600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22552, 'Jixinggang', 'Jixinggang', 'Jixinggang,Jixinggang Xiang,ji xing gang,ji xing gang xiang,吉星岗,吉星岗乡', 46.6271500, 125.7859800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22553, 'Jixi', 'Jixi', 'Chi-hsi,Chi-hsi-shih,Chi-ning,Chi-ning-chieh,Czisi,Dzisi,Gie-sa,Giĕ-să̤,JXA,Jixi,Jixi Shi,Ke Tay,Ke-se-chhi,Ke-se-chhī,Kisi,Kê Tây,Ti-si,ji xi,ji xi shi,jisi si,jyshy,Ťi-si,Ђиси,Цзиси,جیشی,鶏西,鶏西市,鷄西,鸡西,鸡西市,지시 시', 45.3010900, 130.9571800, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22554, 'Jiwen', 'Jiwen', 'Chi-wen,Jiwen,Jiwen Zhen,ji wen,ji wen zhen,吉文,吉文镇', 50.5744600, 123.1859400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22555, 'Jiuzhai', 'Jiuzhai', 'Jiuzhai,Jiuzhai Zhen,jiu zhai,jiu zhai zhen,九寨,九寨镇', 40.0911500, 122.1040900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22556, 'Jiuxian', 'Jiuxian', 'Chiu-hsien,Jiuxian,Jiuxian Zhen,jiu xian,jiu xian zhen,旧县,旧县镇', 40.5506700, 116.0892700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22557, 'Jiutai', 'Jiutai', 'Chiu-t''ai,Chiu-t''ai-chen,Chiu-t''ai-hsien,Chiu-t’ai,Chiu-t’ai-chen,Chiu-t’ai-hsien,Hsia-chiu-t''ai,Hsia-chiu-t’ai,Jiutai,Shachutai,Shāchūtai,Siakiutai,T''eu-t''ai,Teutay,Teymau,Teymaū,T’eu-t’ai', 44.1525000, 125.8327800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22558, 'Jiupu', 'Jiupu', '', 41.0666700, 122.9500000, 'CN', '2013-12-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22559, 'Jiucaigou', 'Jiucaigou', 'Jiucaigou,jiu cai gou,韭菜沟', 40.5905500, 123.3736200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22560, 'Jiubing', 'Jiubing', 'Chiu-ping-t''ai,Chiu-ping-t’ai,Jiubing,Jiubing Xiang,Jiubingtai,jiu bing,jiu bing xiang,救兵,救兵乡', 41.6422500, 124.1099300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22561, 'Jishu', 'Jishu', 'Chi-shu,Jishu', 44.3166700, 126.8000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22562, 'Jirin Gol', 'Jirin Gol', 'Chi-lin-kuo-le,Hao-erh-ch''in-miao,Hao-erh-ch’in-miao,Hsi-wu-chu-mu-ch''in-ch''i,Hsi-wu-chu-mu-ch’in-ch’i,Jiren Gaole,Jiren Gaole Zhen,Jirin Gol,Wang-fu-miao,Wang-kai-miao,ji ren gao lei,ji ren gao lei zhen,吉仁高勒,吉仁高勒镇', 44.4666700, 117.0666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22563, 'Jinzhou', 'Jinzhou', 'Cam Chau,Chien-hsien,Chin,Chin-chou,Chin-chou-shih,Chin-hsien,Chinchow,Czin''chzhou,Cẩm Châu,Dzindzou,Dzindžou,Ging-ciu,Gjingou,Gīng-ciŭ,JNZ,Jintsjou,Jinzhou,Kim-chiu-chhi,Kinchou,Kintschou,Kím-chiu-chhī,Tin-cou,dzinjou,jin zhou,jin zhou shi,jinjeou si,jnzhww,jynjw,Ĝjinĝou,Ťin-čou,Ђинџоу,Цзиньчжоу,Цзіньчжоу,جنژوو,جینجو,ძინჯოუ,錦州,錦州市,锦州市,진저우 시', 41.1077800, 121.1416700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22564, 'Jinzhan', 'Jinzhan', 'Jinzhan,Jinzhan Xiang,jin zhan,jin zhan xiang,金盏,金盏乡', 40.0053300, 116.5704200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22565, 'Lianshan', 'Lianshan', 'Chin-hsi,Chin-hsi-chen,Chinshi,Chinsi,Jinxi,Leinshan,Lianshan,Lianshan Qu,Lien-shan,lian shan,lian shan qu,连山,连山区', 40.7643200, 120.8532700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22566, 'Fendou', 'Fendou', 'Ch''i-pa-ch''i,Chin-shan-t''un,Chin-shan-t’un,Ch’i-pa-ch’i,Fendou,Fendou Jiedao,Jinshantun,Jinshantun Qu,fen dou,fen dou jie dao,jin shan tun,jin shan tun qu,奋斗,奋斗街道,金山屯,金山屯区', 47.4095500, 129.4282200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22567, 'Jinshan', 'Jinshan', 'Chin-shan,Chin-shan-chen,Harqin Qi,Jinshan,Jinshan Zhen,K''a-la-ch''in-ch''i,K''o-la-ch''in-ch''i,Kalaqin Qi,K’a-la-ch’in-ch’i,K’o-la-ch’in-ch’i,jin shan,jin shan zhen,ka la qin qi,喀喇沁旗,锦山,锦山镇', 41.9166700, 118.6666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22568, 'Jinma', 'Jinma', 'Jinma,Jinma Zhen,jin ma,jin ma zhen,金马,金马镇', 44.6112600, 127.4215000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22569, 'Jinjia', 'Jinjia', 'Chin-chia-chen,Jinjia,Jinjia Zhen,Jinjiazhen,jin jia,金家', 42.8007300, 123.7046700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22570, 'Jining', 'Jining', 'Chi-ning,Chi-ning-hsien,Chi-ning-shih,Czinin,Jining,Jining Qu,P''ing-ti-ch''uan,P''ing-ti-ch''uan-chen,P’ing-ti-ch’üan,P’ing-ti-ch’üan-chen,Tsining,Tszinin,ji ning,ji ning qu,ping de quan zhen,Цзинин,平地泉镇,集宁,集宁区', 41.0275000, 113.1058300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22571, 'Jinhe', 'Jinhe', 'Chin-ho,Jinhe,Jinhe Zhen,jin he,jin he zhen,金河,金河镇', 51.3376100, 121.4893000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22572, 'Jinhe', 'Jinhe', 'Jinhe,Jinhe Zhen,jin he,jin he zhen,津河,津河镇', 46.7355200, 127.1519200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22573, 'Jingyu', 'Jingyu', 'Ching-yu,Ching-yu-chen,Ching-yü,Ching-yü-chen,Jingyu,Meng-chiang,Meng-chiang-hsien,Mengkiang,Ta-tien-tzu,jing yu,靖宇', 42.3726700, 126.8011500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22574, 'Jingxing', 'Jingxing', 'Ching-hsing,Ching-hsing-hsien,Jingxing,Jingxing Zhen,Kingsing,Kingsingchen,Tszinsin,jing xing,jing xing zhen,景星,景星镇', 47.0698800, 123.0302100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22575, 'Jingpeng', 'Jingpeng', 'Ching-feng,Ching-p''en,Ching-p''eng,Ching-p''eng-hsien,Ching-p''eng-ying,Ching-p’en,Ching-p’eng,Ching-p’eng-hsien,Ching-p’eng-ying,Hexigten Qi,Jingfeng,Jingpeng,Jingpeng Zhen,K''o-shih-k''o-t''eng-ch''i,Keshiketeng Qi,Kingpeng,K’o-shih-k’o-t’eng-ch’i,Pai-t''a-ssu,Pai-t’a-ssu,jing peng,jing peng zhen,ke shen ke teng qi,克什克腾旗,经棚,经棚镇', 43.2500000, 117.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22576, 'Jingjian', 'Jingjian', 'Jingjian,Jingjian Xiang,jing jian,jing jian xiang,经建,经建乡', 45.8168900, 127.6220800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22577, 'Jilin', 'Jilin', 'Cat Lam,Chi-lin,Chi-lin-shih,Chi-ling,Ciudad de Jilin,Csilin,Czilin'',Cát Lâm,Dzilin,Dzilinas,Gek-ling,Gilino,Girin,Girin khot,Gék-lìng,JIL,Jilin,Jilin Ceety,Jilin City,Jilin Hiria,Jilin Shi,Jilin i Jilin,Jilinstad,Kiat-lim-chhi,Kiat-lîm-chhī,Kilin,Kirin,Kota Jilin,Ti-lin,Yung-chi,Yung-chi-hsien,Yung-chi-shih,Yungki,gylyn,ji lin,ji lin shi,jilin si,jilina,Ĝilino,Ťi-lin,Ђилин,Гирин,Гирин хот,Дзилин,Цзилинь,גילין,جىلىن شەھىرى,جیلن شہر,جی‌لین,ਜਿਲਿਨ,吉林,吉林市,지린 시', 43.8508300, 126.5602800, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22578, 'Jiguanshan', 'Jiguanshan', 'Ch''i-chuan-shan,Chi-kuan-shan,Ch’i-chuan-shan,Jiguanshan,Jiguanshan Zhen,ji guan shan,ji guan shan zhen,鸡冠山,鸡冠山镇', 40.5201700, 123.9145100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22579, 'Jiguan', 'Jiguan', 'Chi-kuan,Chi-kuan-lei-tzu,Jiguan,Jiguan Xiang,ji guan,ji guan xiang,鸡冠,鸡冠乡', 43.4740600, 129.8608400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22580, 'Jiewen', 'Jiewen', 'Jiewen,Jiewen Zhen,Jiewenzhai,jie wen,jie wen zhen,接文,接文镇', 40.7094700, 123.0078100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22581, 'Jidong', 'Jidong', 'Chi-tung,Chi-tung-chen,Jidong', 45.2166700, 131.0833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22582, 'Jiaxin', 'Jiaxin', 'Chia-hsin-tzu,Jiaxin,Jiaxin Zhen,Jiaxinzi,jia xin,jia xin zhen,加信,加信镇', 45.6672600, 128.7101600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22583, 'Erdaocha', 'Erdaocha', 'Chia-p''i-kou,Chia-p’i-kou,Erdaocha,Jiapigou,Jiapigou Zhen,er dao cha,jia pi gou,jia pi gou zhen,二道岔,夹皮沟,夹皮沟镇', 42.8673800, 127.4879300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22584, 'Minzhu', 'Minzhu', 'Chiacho,Chiao-ho,Chiao-ho-chen,Chiao-ho-hsien,Czjaokheh,Jiaohe,Kiaoho,Minzhu,O-mu-hsien,Omu,Ta-chiao-ho,Tachiaho,Takiaoho,min zhu,Цзяохэ,民主', 43.7214500, 127.3340100, 'CN', '2014-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22585, 'Jianyi', 'Jianyi', 'Jianyi,Jianyi Zhen,Jieguanting,jian yi,jian yi zhen,jie guan ting,建一,建一镇,接官厅', 40.4824100, 122.8642100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22586, 'Jiantang', 'Jiantang', 'Jiantang,Jiantang Xiang,jian tang,jian tang xiang,建堂,建堂乡', 45.6781800, 130.0456800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22587, 'Jiangqiao', 'Jiangqiao', 'Chiang-ch''iao,Chiang-ch’iao,Ha-la-erh-ka,Jiangqiao,Jiangqiao Mengguzu Xiang,jiang qiao,jiang qiao meng gu zu xiang,江桥,江桥蒙古族乡', 46.7699100, 123.6745600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22588, 'Jianchang', 'Jianchang', 'Chien-ch''ang,Chien-ch’ang,Jianchang,Jianchang Zhen,Tszyan''chan,Tszyan’chan,jian chang,jian chang zhen,碱厂,碱厂镇', 41.2508300, 124.4711300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22589, 'Ji’an', 'Ji''an', 'Chi-an,Chi-an-chen,Chi-an-hsien,Ji''an,Ji''an Shi,Ji’an,Ji’an Shi,T''ung-kou,T''ung-kou-ch''eng,Tsian,T’ung-kou,T’ung-kou-ch’eng,ji an,ji an shi,集安,集安市', 41.1234900, 126.1763100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22590, 'Jiamusi', 'Jiamusi', 'Ch''a-mu-ssu,Chia-mu-ssu,Chia-mu-ssu-shih,Chieh-mu-ssu,Ch’a-mu-ssu,Czjamusy,Dziamusi,Ga-muk-su,Giai Moc Tu,Giai Mộc Tư,Gjamusi,Gă-mŭk-sṳ̆,Hua-ch''uan-hsien,Hua-chuan,Hua-ch’uan-hsien,Hwachwan,JMU,Jiamusi,Jiamusi Shi,Ka-bok-su-chhi,Ka-bo̍k-su-chhī,Kiamusas,Kiamusze,Tia-mu-s'',jamusseu si,jamusu,jamusu shi,jia mu si,jia mu si shi,jyamwsy,Ťia-mu-s’,Ђамуси,Цзямусы,جيامۇسى شەھىرى,جیاموسی,ジャムス,ジャムス市,佳木斯,佳木斯市,자무쓰 시', 46.7992700, 130.3163300, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22591, 'Jiajiaying', 'Jiajiaying', 'Jiajiaying,Jiajiaying Xiang,gu jia ying,gu jia ying xiang,贾家营,贾家营乡', 41.7892600, 127.1895000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22592, 'Jalai Nur', 'Jalai Nur', 'Cha-lai-no-erh,Chaiainor,Chalainor,Chzhalajnor,Chzhalaynor,Dalainur,Dalaynur,Jalai Nur,Zhalai Nuo''er,Zhalai Nuo’er,zha lai nuo er,Чжалайнор,扎赉诺尔', 49.4500000, 117.7000000, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22593, 'Jagdaqi', 'Jagdaqi', 'Chia-ko-ta-ch''i,Chia-ko-ta-ch’i,Jagdaqi,K''u-erh-ch''i,K''u-lu-ch''i,Kurchi,K’u-erh-ch’i,K’u-lu-ch’i', 50.4166700, 124.1166700, 'CN', '2011-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22594, 'Inder', 'Inder', 'Cha-lai-t''e-ch''i,Cha-lai-t’e-ch’i,Inder,Jalaid Qi,Yin-te-erh,Yinde''er,Yinde''er Zhen,Yinde’er,Yinde’er Zhen,Zhalaite Qi,yin de er,yin de er zhen,zha lai te qi,扎赉特旗,音德尔,音德尔镇', 46.7000000, 122.9333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22595, 'Huzhuang', 'Huzhuang', 'Hu-chuang-t''un,Hu-chuang-t’un,Huzhuang,Huzhuang Zhen,hu zhuang,hu zhuang zhen,虎庄,虎庄镇', 40.7163900, 122.5402800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22596, 'Huyuan', 'Huyuan', 'Huyuan,Huyuan Zhen,hu yuan,hu yuan zhen,呼源,呼源镇', 51.7521600, 123.5661800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22597, 'Hushitai', 'Hushitai', 'Hu-shih-t''ai,Hu-shih-t’ai,Hushitai', 41.9322200, 123.5113900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22598, 'Kulun', 'Kulun', 'Hsiao-k''u-lun,Hsiao-k’u-lun,Hure Qi,K''u-lun,K''u-lun-ch''i,K''u-lun-chen,K''u-lun-chieh,Kulun,Kulun Qi,Kulun Zhen,Kulunkai,K’u-lun,K’u-lun-chen,K’u-lun-chieh,K’u-lun-ch’i,Sui-tung,Sui-tung Old City,Sui-tung-ku-chih,ku lun,ku lun qi,ku lun zhen,库伦,库伦旗,库伦镇', 42.7305600, 121.7755600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22599, 'Huoshishan', 'Huoshishan', 'Huo-shih-shan,Huoshishan,Huoshishan Xiang,huo shi shan,huo shi shan xiang,火石山,火石山乡', 46.5002800, 125.6747400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22600, 'Huolongmen', 'Huolongmen', 'Hongfeng,Huo-lung-men,Huolongmen,Huolongmen Xiang,huo long men,huo long men xiang,霍龙门,霍龙门乡', 49.8016200, 125.7776700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22601, 'Hunchun', 'Hunchun', 'Hui-ch''un,Hui-ch’un,Hun-ch''un-chen,Hun-ch''un-hsien,Hun-ch''ung,Hun-ch’un-chen,Hun-ch’un-hsien,Hun-ch’ung,Hunchun,Hunchun Shi,Hungtschung,Khun''chun'',hui chun,hui chun shi,Хуньчунь,珲春,珲春市', 42.8675000, 130.3580600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22602, 'Khuma', 'Khuma', 'Hu-ma-chen,Hu-ma-chiu-chih,Hu-ma-hsien,Huma,Huma Xian,Huma Zhen,Khuma,Ku-chan,hu ma,hu ma xian,hu ma zhen,Хума,呼玛,呼玛县,呼玛镇', 51.7166700, 126.6333300, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22603, 'Huludao', 'Huludao', 'Hu-lu-tao,Hu-lu-tao-hsien,Huludao,Koroto,hu lu dao,葫芦岛', 40.7524300, 120.8355200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22604, 'Hulitu', 'Hulitu', 'Hulitu,Hulitu Mengguzu Xiang,hu li tu,hu li tu meng gu zu xiang,胡力吐,胡力吐蒙古族乡', 45.9500000, 121.8666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22605, 'Hulan Ergi', 'Hulan Ergi', 'Fu-erh-la-chi,Fu-la-erh-chi,Fularki,Hulan Ergi,Lung-chiang', 47.2041700, 123.6333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22606, 'Hulan', 'Hulan', 'Chu-lan-tschong,Chu-lan-tschöng,Hu-lan-chen,Hu-lan-hsien,Hu-lang-ch''eng,Hu-lang-ch’eng,Hulan,Khulan,Хулан', 45.9833300, 126.6000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22607, 'Hujil Tohom', 'Hujil Tohom', 'Huji Tumo,Huji Tumo Zhen,Hujil Tohom,hu ji tu mo,hu ji tu mo zhen,胡吉吐莫,胡吉吐莫镇', 46.4475100, 124.1331600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22608, 'Hujigou', 'Hujigou', 'Hujigou,hu ji gou,忽鸡沟', 40.8434700, 110.0688000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22609, 'Huinan', 'Huinan', 'Chiu-hui-nan,Hui-nan-chen,Hui-nan-hsien,Huinan,Huinanzhen,Hwei-nan,Hweinan-ting', 42.6225000, 126.2613900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22610, 'Huifa', 'Huifa', 'Huifa,Huifa Zhen,Huifaheng,hui fa,hui fa zhen,会发,会发镇', 45.7914700, 128.6637200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22611, 'Huayuankou', 'Huayuankou', 'Huayuan,Huayuankou,Huayuankou Zhen,hua yuan kou,hua yuan kou zhen,花园口,花园口镇', 42.2866800, 127.0633300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22612, 'Huashu', 'Huashu', 'Huashu,Huashu Zhen,hua shu,hua shu zhen,桦树,桦树镇', 41.9908200, 127.2174700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22613, 'Huashan', 'Huashan', 'Huashan,Huashan Zhen,hua shan,hua shan zhen,花山,花山镇', 41.8844400, 126.8661100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22614, 'Huanren', 'Huanren', 'Chiu-huai-jen,Huai-jen,Huan-jen,Huan-jen-chen,Huan-jen-hsien,Huanren,Hwanjen,Yuan Jen', 41.2647200, 125.3666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22615, 'Huangtuling', 'Huangtuling', 'Huang-t''u-ling-tzu,Huang-t’u-ling-tzu,Huangtuling,Huangtuling Zhen,huang tu ling,huang tu ling zhen,黄土岭,黄土岭镇', 40.4132200, 122.7914400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22616, 'Huangnihe', 'Huangnihe', 'Huang-ni-ho,Huang-ni-ho-tzu,Huangnihe', 43.5583300, 128.0238900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22617, 'Jiuduhe', 'Jiuduhe', 'Huangkan,Jiuduhe,Jiuduhe Zhen,huang kan,jiu du he,jiu du he zhen,九渡河,九渡河镇,黄坎', 40.3612600, 116.4616000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22618, 'Huangdi', 'Huangdi', 'Huangdi,Huangdi Zhen,huang de,huang de zhen,荒地,荒地镇', 40.2347600, 120.2662100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22619, 'Huangbai', 'Huangbai', 'Huang-pai,Huangbai,Qingshi Zhen,huang bai,qing shi zhen,青石镇,黄柏', 41.2692900, 126.3512300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22620, 'Huanan', 'Huanan', 'Ch''ien-chen-chieh,Ch''ien-chen-hsiang,Ch’ien-chen-chieh,Ch’ien-chen-hsiang,Hu-nan-ying,Hu-nan-ying-chen,Hua-ch''uan,Hua-ch''uan-chen,Hua-ch’uan,Hua-ch’uan-chen,Hua-nan-chen,Huanan,Huanan Xian,Huanan Zhen,hua nan,hua nan xian,hua nan zhen,桦南,桦南县,桦南镇', 46.2207000, 130.5250000, 'CN', '2014-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22621, 'Huamin', 'Huamin', 'Huamin,Huamin Xiang,hua min,hua min xiang,华民,华民乡', 47.1231600, 123.4531500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22622, 'Hualin', 'Hualin', 'Hua-shu-lin-tzu,Hualin,Hualin Zhen,hua lin,hua lin zhen,桦林,桦林镇', 44.6829100, 129.6752300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22623, 'Huadian', 'Huadian', 'Hua-tien,Hua-tien-tzu,Huadian,Huadian Zhen,Huadianzi,hua dian,hua dian zhen,花甸,花甸镇', 41.2994300, 125.7772400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22624, 'Huadian', 'Huadian', 'Hua-tien,Hua-tien-chen,Hua-tien-hsien,Huadian,Huen-tien,Hwatien,K''uang-kai,Koangai,Kuan-chieh,K’uang-kai', 42.9633300, 126.7477800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22625, 'Changshun', 'Changshun', 'Changshun,Changshun Zhen,Chapser,Chapsyr,Chia-p''u-ssu,Chia-p’u-ssu,Chiapser,Hsin-ming,Hsin-ming-hsien,Hua-te,Hua-te-chen,Huade,Huade Xian,Te-hua,Te-hua-hsien,hua de,hua de xian,zhang shun,zhang shun zhen,化德,化德县,长顺,长顺镇', 41.8913900, 113.9922200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22626, 'Hongyan', 'Hongyan', 'Hongyan,Hongyan Zhen,Hongyanzhan,Hung-yen,hong yan,hong yan zhen,红彦,红彦镇', 49.5100000, 124.9736100, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22627, 'Hongtoushan', 'Hongtoushan', 'Hongtoushan,Hongtoushan Zhen,hong tou shan,hong tou shan zhen,红透山,红透山镇', 41.9952300, 124.5051800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22628, 'Hongshi', 'Hongshi', 'Hongshi,Hongshilazi,Hongshilazi Zhen,Hung-shih,Shihongshilazi,hong shi,hong shi la zi,hong shi la zi zhen,红石,红石砬子,红石砬子镇', 42.9563500, 127.1010700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22629, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Jiedao,Shangganling Qu,hong shan,hong shan jie dao,shang gan ling qu,上甘岭区,红山,红山街道', 47.9758000, 129.0219900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22630, 'Hongqi Yingzi', 'Hongqi Yingzi', 'Hongqi Yingzi,Hongqi Yingzi Xiang,Hung-ch''i,Hung-ch’i,hong qi ying zi,hong qi ying zi xiang,红旗营子,红旗营子乡', 40.3344400, 123.4372200, 'CN', '2012-12-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22631, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,Hung-ch''i,Hung-ch’i,hong qi,hong qi zhen,红旗,红旗镇', 40.1413100, 123.8756700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22632, 'Hongkeli', 'Hongkeli', 'Hongkeli,Hongkeli Zhen,Hung-k''o-li,Hung-k’o-li,Hung-li-k''o,Hung-li-k’o,Hunholu,hong ke li,hong ke li zhen,宏克力,宏克力镇', 46.5754000, 129.8430400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22633, 'Honggor', 'Honggor', 'Hongge''er,Hongge''er Sumu,Hongge’er,Hongge’er Sumu,Honggor,Hongor,Hung-ko-erh,hong ge er,hong ge er su mu,洪格尔,洪格尔苏木', 44.6924200, 112.2057200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22634, 'Honggang', 'Honggang', 'Honggang,Honggang Jiedao,Honggang Qu,hong gang,hong gang jie dao,hong gang qu,红岗,红岗区,红岗街道', 46.4012400, 124.8832200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22635, 'Holt', 'Holt', 'Hao''ertu,Hao''ertu Xiang,Hao-erh-t''e,Hao-erh-t''u,Hao-erh-t’e,Hao-erh-t’u,Hao’ertu,Hao’ertu Xiang,Ho-erh-t''u,Ho-erh-t’u,Holoto,Holt,Holto,Holtu,Horuto,Huo-erh-t''u,Huo-erh-t’u,Kholutu,Khorudo,hao er tu,hao er tu xiang,浩尔吐,浩尔吐乡', 44.4333300, 119.2000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22636, 'Hohhot', 'Hohhot', 'Choech Chot,Choech chot,Chöch Chot,Chöch chot,HET,Hohhot,Hohhot Shi,Hohhot-chhi,Hohhot-chhī,Hohhot-su,Hohhot-sṳ,Hohotas,Hohoto,Hou-ho,Hoĥoto,Hu-ho-hao-t''e,Hu-ho-hao-t''e-shih,Hu-ho-hao-t’e,Hu-ho-hao-t’e-shih,Huhe Hoter,Huhehaote,Huhehot,Huhhot,Khokh khot,Khokhot,Khukh-Khoto,Koekxot shehiri,Kuei-hua,Kuei-sui,Kuei-sui-hsien,Kuei-sui-shih,Kuku-khoto,Kwei-hwa-cheng,Kwei-hwa-ting,Kweihwa,Kweihwa-Suiyuan,Kweisui,Kweisui-hsien,Kökxot shehiri,Suiyuan,Suiyüan,fufuhoto,fufuhoto shi,hohota,hu he hao te,hu he hao te shi,hu hxt,huheohaoteo si,hwhhwt,hwhwt,Хох хот,Хохот,Хух-Хото,Хөх хот,חוחחוט,هوهوت,ہوہوٹ,होहोत,ฮูฮอต,མཁར་སྔོན་གྲོང་ཁྱེར།,ᠬᠥᠬᠡᠬᠣᠲᠠ,フフホト,フフホト市,呼和浩特,呼和浩特市,후허하오터 시', 40.8105600, 111.6522200, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22637, 'Hoh Ereg', 'Hoh Ereg', 'Hoh Ereg,K''o-chen,K''o-k''o-i-li-keng,K''o-k''o-i-li-keng-chen,K’o-chen,K’o-k’o-i-li-keng,K’o-k’o-i-li-keng-chen,Wu-ch''uan-hsien,Wu-ch’uan-hsien,Wuchuan,Wuchwan', 41.0955600, 111.4408300, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22638, 'Hobor', 'Hobor', 'Ch''a-ha-erh-yu-chung-ch''i,Ch''a-ha-erh-yu-i-chung-ch''i,Ch''a-yu-chung-ch''i,Chaha''eryouyizhong Qi,Chaha’eryouyizhong Qi,Chakhar''''yuchzhuntsi,Chakhar’’yuchzhuntsi,Chiu-t''ao-lin,Chiu-t’ao-lin,Ch’a-ha-erh-yu-chung-ch’i,Ch’a-ha-erh-yu-i-chung-ch’i,Ch’a-yu-chung-ch’i,Hobor,K''o-pu-erh,Kebu''er,Kebu''er Zhen,Kebu’er,Kebu’er Zhen,K’o-pu-erh,Qahar Youyi Zhongqi,T''ao-lin,Tao-lin-hsien,T’ao-lin,cha ha er you yi zhong qi,ke bu er,ke bu er zhen,察哈尔右翼中旗,科布尔,科布尔镇', 41.2715400, 112.6266300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22639, 'Fendou', 'Fendou', 'Fendou,Hengshan,Hengshan Qu,fen dou,heng shan qu,奋斗,恒山区', 45.2123500, 130.9025400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22640, 'Hengdaohezi', 'Hengdaohezi', 'Heng-tao-ho-tzu,Hengdaohezi,Hengdaohezi Zhen,Hengtaohotze,heng dao he zi,heng dao he zi zhen,横道河子,横道河子镇', 44.8077100, 129.0687900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22641, 'Henanzhai', 'Henanzhai', 'Henanzhai,Henanzhai Zhen,he nan zhai,he nan zhai zhen,河南寨,河南寨镇', 40.3359800, 116.8321300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22642, 'Helong', 'Helong', 'Helong,Helong Shi,Helong Zhen,Ho-lung,Ho-lung-chen,Khehlune,Longcheng Zhen,San-tao-kou,he long,he long shi,he long zhen,long cheng zhen,Хэлуне,和龙,和龙市,和龙镇,龙城镇', 42.5397400, 128.9972200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22643, 'Heli', 'Heli', 'Hao-Li,Hao-li-chen,Hao-li-hsien,Hao-li-kang,Heli,Heli Zhen,Heo-li-kang,Ho-kang,Ho-li,Ho-li-kang,Holih,Shih-t''ou-ho,Shih-t’ou-ho,he li,he li zhen,鹤立,鹤立镇', 47.0554400, 130.2814200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22644, 'Heishui', 'Heishui', 'Hei-ho,Heishui,Heishui Zhen,hei shui,hei shui zhen,黑水,黑水镇', 45.2000000, 122.8166700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22645, 'Heishantou', 'Heishantou', 'Heishantou,Heishantou Zhen,hei shan tou,hei shan tou zhen,黑山头,黑山头镇', 50.2138900, 119.5043400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22646, 'Heishan', 'Heishan', 'Chen-an,He Shan,Hei-shan-chen,Hei-shan-hsien,Heishan', 41.6891700, 122.1127800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22647, 'Heilonggong', 'Heilonggong', 'Heilonggong,Heilonggong Zhen,hei long gong,hei long gong zhen,黑龙宫,黑龙宫镇', 45.4311400, 127.8972600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22648, 'Heihe', 'Heihe', 'Ai-hun,Ai-hun-hsien,Aigun,Aihui,Chej-che,HEK,Hac Ha,Haik-o,Hei-ho,Hei-ho-chen,Hei-ho-t''un,Hei-ho-t’un,Heihe,Heihe Shi,Hek-ho-chhi,Hek-hô-chhī,Háik-ò̤,Hắc Hà,Khehjkheh,Sa-ha-liang,Sachaljan,Sakhalyan,Ta-hei-ho,hayhy,hei he,hei he shi,heiheo si,Хэйхэ,هایهی,ہئیہے,黑河,黑河市,黒河,黒河市,헤이허 시', 50.2441300, 127.4901600, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22649, 'Heigang', 'Heigang', 'Heigang,Heigang Xiang,hei gang,hei gang xiang,黑岗,黑岗乡', 47.2482400, 123.3991100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22650, 'Heichengzi', 'Heichengzi', 'Hei-ch''eng-tzu,Hei-ch’eng-tzu,Heichengzi,Heichengzi Zhen,hei cheng zi,hei cheng zi zhen,黑城子,黑城子镇', 42.1395400, 120.9749400, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22651, 'Hegang', 'Hegang', 'Che-kang,Hac Cuong,Hao-kang,Hao-kang-shih,Hegang,Hegang Shi,Hegangas,Hingshanchen,Hinshanchen,Ho-kang,Hok-gong,Hok-kong-chhi,Ho̍k-kong-chhī,Hsian-yuan-t''un,Hsian-yüan-t’un,Hsiangyuantun,Hsing-shan,Hsing-shan-chen,Hsing-shan-chieh,Hsinganchen,Hŏk-gŏng,Hạc Cương,Khegan,Khegang,Khehgan,Khugan,Sinshan Chzhen,he gang,he gang shi,heogang si,hngang,Хеганг,Хъган,Хэган,هنگانگ,ہیگانگ,鶴崗,鶴崗市,鹤岗,鹤岗市,허강 시', 47.3511800, 130.3001200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22652, 'Har Nur', 'Har Nur', 'Ha-jih-nu-la,Har Nur,Harinuo''er,Harinuo''er Sumu,Harinuo’er,Harinuo’er Sumu,ha ri nuo er,ha ri nuo er su mu,哈日诺尔,哈日诺尔苏木', 45.6374000, 120.0834800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22653, 'Har Huxu', 'Har Huxu', 'Hala Heshao,Hala Heshao Xiang,Har Huxu,ha la he shao,ha la he shao xiang,哈拉合少,哈拉合少乡', 40.9741000, 110.9183900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22654, 'Harbin', 'Harbin', 'Cap Nhi Tan,Charbin,Charbinas,Charmpin,Cáp Nhĩ Tân,Gorad Kharbin,HRB,Ha''erbin,Ha-erh-pin,Ha-erh-pin-shih,Harbin,Harbin Shi,Harbin-chhi,Harbin-chhī,Harbina,Harbino,Ha’erbin,Kharbin,Lungsod ng Harbin,Pin-chiang,Pin-chiang-hsien,Pinkiang,Xarbin,ha er bin,ha er bin shi,ha-eolbin si,har bin,harabina,harbn,harbyn,harpina,harubin,harubin shi,hrbyn,kharbini,Χαρμπίν,Горад Харбін,Харбин,Харбін,Խարբին,חרבין,خاربىن شەھىرى,هاربن,هاربین,ہاربن,हारबिन,हार्पिन,ਹਾਰਬਿਨ,ฮาร์บิน,ဟာရ်ပင်းမြို့,ხარბინი,ハルビン,ハルビン市,哈尔滨,哈尔滨市,哈爾濱,하얼빈 시', 45.7500000, 126.6500000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22655, 'Haolianghe', 'Haolianghe', 'Hao-liang-ho,Hao-liao-ho,Haolianghe,Haolianghe Zhen,hao liang he,hao liang he zhen,浩良河,浩良河镇', 46.7266600, 129.6304400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22656, 'Haoguantun', 'Haoguantun', 'Haoguantun,Haoguantun Zhen,hao guan tun,hao guan tun zhen,郝官屯,郝官屯镇', 42.6744400, 123.4869100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22657, 'Hanjiayuan', 'Hanjiayuan', 'Hanjiaweizi,Hanjiayuan,Hanjiayuan Zhen,han jia yuan,han jia yuan zhen,韩家园,韩家园镇', 52.0634100, 125.7312000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22658, 'Hanghuadian', 'Hanghuadian', 'Hanghuadian,Hanghuadian Zhen,Huang-hua-tien,huang hua dian,huang hua dian zhen,黄花甸,黄花甸镇', 40.5565200, 123.4693900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22659, 'Handgai', 'Handgai', 'Handagai,Handagai Sumu,Handgai,han da gai,han da gai su mu,罕达盖,罕达盖苏木', 47.5000000, 119.4000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22660, 'Handaqi', 'Handaqi', 'Han-ta-ch''i,Han-ta-ch’i,Handaqi,Handaqi Zhen,Kan-ta-ch''i,Kan-ta-ch’i,Khan''daci,Khan''datsi,Khan’datsi,han da qi,han da qi zhen,Ханьдаци,罕达汽,罕达汽镇', 50.1352300, 126.1932000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22661, 'Hamatang', 'Hamatang', 'Hamatang,Hamatang Xiang,ha ma tang,ha ma tang xiang,蛤蟆塘,蛤蟆塘乡', 43.4230500, 129.4991900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22662, 'Haliut', 'Haliut', 'Chung-kung-ch''i,Chung-kung-ch’i,Ha-i-ryu-to,Hai-liu-t''u,Hai-liu-t’u,Hailutu,Hailutu Zhen,Haliut,Urad Zhonghou Lianheqi,Urad Zhongqi,WZQ,Wu-la-t''e-chung-ch''i,Wu-la-t''e-chung-hou-ch''i,Wu-la-t''e-chung-hou-lien-ho-ch''i,Wu-la-te-chung-ch''i-pei-tzu-fu,Wu-la-te-chung-ch’i-pei-tzu-fu,Wu-la-t’e-chung-ch’i,Wu-la-t’e-chung-hou-ch’i,Wu-la-t’e-chung-hou-lien-ho-ch’i,Wulatezhong Qi,hai liu tu,hai liu tu zhen,wu la te zhong hou lian he qi,wu la te zhong qi,乌拉特中后联合旗,乌拉特中旗,海流图,海流图镇', 41.5561100, 108.5197200, 'CN', '2016-04-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22663, 'Hale', 'Hale', 'Hale,Hale Zhen,Harul,Harul Xiang,ha le,ha le zhen,哈乐,哈乐镇', 41.2186100, 111.6755000, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22664, 'Haixing', 'Haixing', 'Haixing,Haixing Zhen,hai xing,hai xing zhen,海星,海星镇', 47.7601600, 126.9138800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22665, 'Hailun', 'Hailun', 'Hai-lun-chen,Hai-lun-hsien,Hailun,Hailun Shi,Hailun Zhen,T''ung-ken,T''ung-ken-ho,Tung-kei,T’ung-ken,T’ung-ken-ho,hai lun,hai lun shi,hai lun zhen,海伦,海伦市,海伦镇', 47.4565000, 126.9536800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22666, 'Hailin', 'Hailin', 'Hai-lin-chen,Hai-lin-ts''un,Hai-lin-ts’un,Hailin,Hailin Shi,Khajlin,hai lin,hai lin shi,Хайлин,海林,海林市', 44.5714900, 129.3853900, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22667, 'Hailar', 'Hailar', 'HLD,Hai-la-erh,Hai-la-erh-shih,Hailar,Hailar Shi,Hairaru,Hairāru,Hu-lun,Khailar,Khajlar,hai la er qu,hairaru qu,Хайлар,ハイラル区,海拉尔区', 49.2000000, 119.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22668, 'Hailang', 'Hailang', 'Hailang,Hailang Zhen,hai lang,hai lang zhen,海浪,海浪镇', 44.3255900, 129.2335200, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22669, 'Haifeng', 'Haifeng', 'Haifeng,Haifeng Zhen,hai feng,hai feng zhen,海丰,海丰镇', 46.8283600, 126.8278700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22670, 'Haicheng', 'Haicheng', 'Hai-ch''eng-chen,Hai-ch''eng-hsien,Hai-ch’eng-chen,Hai-ch’eng-hsien,Haicheng,Haicheng Shi,Haitschong,Haitschöng,Lo-lang,hai cheng,hai cheng shi,海城,海城市', 40.8515800, 122.7475400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22671, 'Haibei', 'Haibei', 'Hai-pei,Hai-pei-chen,Haibei,Haibei Zhen,Ta-t''ien-chu-t''ang,Ta-t’ien-chu-t’ang,hai bei,hai bei zhen,海北,海北镇', 47.6595900, 126.8400000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22672, 'Hadayang', 'Hadayang', 'Ha-ta-yang,Hadayang,Hadayang Zhen,Khadajan,ha da yang,ha da yang zhen,Хадаян,哈达阳,哈达阳镇', 49.2960800, 125.2105700, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22673, 'Zhongxin', 'Zhongxin', 'Ha-ta-men,Hadamen Xiang,Zhongxin,ha da men xiang,zhong xin,中心,哈达门乡', 42.9300000, 130.4863900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22674, 'Hadabei', 'Hadabei', 'Hadabei,Hadabei Zhen,ha da bei,ha da bei zhen,哈达碑,哈达碑镇', 40.3421100, 123.1542400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22675, 'Hada', 'Hada', 'Hada,Hada Zhen,Xiahada,ha da,ha da zhen,xia ha da,下哈达,哈达,哈达镇', 41.9718600, 124.1415600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22676, 'Guzhuyingzi', 'Guzhuyingzi', 'Guzhuying,Guzhuyingzi,Guzhuyingzi Xiang,gu zhu ying zi,gu zhu ying zi xiang,孤竹营子,孤竹营子乡', 40.9380500, 120.2671900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22677, 'Guyuan', 'Guyuan', 'Guyuan,Guyuan Zhen,Ku-yuan,Ku-yüan,gu yuan,gu yuan zhen,古源,古源镇', 50.9369700, 124.3115400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22678, 'Jinshan', 'Jinshan', 'Guyang Xian,Jinshan,Ku-yang,Ku-yang-ch''eng-kuan-chen,Ku-yang-ch’eng-kuan-chen,Ku-yang-hsien,Kuang-i-k''uei,Kuang-i-k’uei,gu yang xian,jin shan,固阳县,金山', 41.0334900, 110.0520500, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22679, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,Gushanzimanzu,Ku-shan,gu shan,gu shan zhen,孤山,孤山镇', 40.5856500, 122.9652400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22680, 'Guji', 'Guji', 'Guji,Guji Xiang,Longbaotun,gu ji,gu ji xiang,古迹,古迹乡', 46.0666700, 121.4833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22681, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,Ku-ch''eng,Ku-ch''eng-tzu,Ku-ch’eng,Ku-ch’eng-tzu,gu cheng,gu cheng zhen,古城,古城镇', 47.9621900, 125.6685700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22682, 'Gubeikou', 'Gubeikou', 'Gubeikou,Gubeikou Zhen,Ku-pei-k''ou,Ku-pei-k’ou,Kupehkow,gu bei kou,gu bei kou zhen,古北口,古北口镇', 40.6896300, 117.1583200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22683, 'Guayuan', 'Guayuan', 'Guayuan,Guayuan Zhen,Kua-yuan,Kua-yüan,gua yuan,gua yuan zhen,瓜园,瓜园镇', 40.0208100, 113.6524300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22684, 'Guantun', 'Guantun', 'Guantun,Guantun Zhen,guan tun,guan tun zhen,官屯,官屯镇', 40.6863600, 122.5596400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22685, 'Zhenluoying', 'Zhenluoying', 'Shangguan,Zhenluoying,Zhenluoying Zhen,shang guan,zhen luo ying,zhen luo ying zhen,上官,镇罗营,镇罗营镇', 40.3396600, 117.1342900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22686, 'Guanjiabao', 'Guanjiabao', 'Guanjiabao,Guanjiabao Xiang,Kuan-chia-pu,Mieh-lu-p''u,Mieh-lu-pao,Mieh-lu-p’u,guan jia bao,guan jia bao xiang,管家堡,管家堡乡', 40.1798400, 112.8866200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22687, 'Guanghua', 'Guanghua', 'Guanghua,Guanghua Zhen,Kuang-hua,guang hua,guang hua zhen,光华,光华镇', 41.9459700, 125.9857800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22688, 'Goubangzi', 'Goubangzi', 'Goubangzi,Goubangzi Zhen,Kou-pang-tzu,Kowpangtze,gou bang zi,gou bang zi zhen,沟帮子,沟帮子镇', 41.3679700, 121.7732700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22689, 'Gongzhuling', 'Gongzhuling', 'Gunchzhulina,Huai-te,Huai-to-hsien,Huaide,Kung-chu-ling,Kung-chu-ling-chen,Гунчжулина', 43.5007500, 124.8197900, 'CN', '2010-05-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22690, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Zhen,gong he,gong he zhen,共和,共和镇', 47.4472700, 123.6833400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22691, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Zhen,gong he,gong he zhen,共合,共合镇', 47.3413300, 126.6270200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22692, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Xiang,gong he,gong he xiang,共和,共和乡', 44.1110800, 130.2048400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22693, 'Gongchangling', 'Gongchangling', 'Gongchangling,Kung-ch''ang-ling,Kung-ch’ang-ling', 41.1166700, 123.4500000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22694, 'Gaoliban', 'Gaoliban', 'Gaoliban,Gaoliban Zhen,Golin Baixing,K''o-erh-ch''in-yu-chung-ch''i,K''o-erh-ch''in-yu-i-chung-ch''i,Kanlipan,Kao-li-pan,Kao-li-pan-ts''un,Kao-li-pan-ts’un,Kao-lin-pai-hsing,K’o-erh-ch’in-yu-chung-ch’i,K’o-erh-ch’in-yu-i-chung-ch’i,gao li ban,gao li ban zhen,高力板,高力板镇', 44.8833300, 121.8000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22695, 'Genhe', 'Genhe', 'Ergun Zuoqi,Genhe,Genhe Shi,Hexi,Hexi Jiedao,Ken-ho,O-erh-ku-na-ch''i,O-erh-ku-na-ch’i,O-erh-ku-na-tso-ch''i,O-erh-ku-na-tso-ch’i,O-tso-ch''i,O-tso-ch’i,e er gu na zuo qi,gen he,gen he shi,he xi,he xi jie dao,根河,根河市,河西,河西街道,额尔古纳左旗', 50.7833300, 121.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22696, 'Gengzhuang', 'Gengzhuang', 'Gengzhuang,Gengzhuang Zhen,Keng Chuan Tzu,Keng-chuang,Keng-chuang-tzu,geng zhuang,geng zhuang zhen,耿庄,耿庄镇', 40.9852300, 122.7017800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22697, 'Gaotun', 'Gaotun', 'Gaotun,Gaotun Zhen,gao tun,gao tun zhen,高屯,高屯镇', 40.4340500, 122.6028800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22698, 'Gaotai', 'Gaotai', 'Gaotai,Gaotai Zhen,Gaotaipu,gao tai,gao tai zhen,高台,高台镇', 40.3790700, 120.2331700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22699, 'Gaoshanzi', 'Gaoshanzi', 'Gaoshanzi,Gaoshanzi Zhen,Kao-shan-tzu,gao shan zi,gao shan zi zhen,高山子,高山子镇', 41.5478700, 122.0494800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22700, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,Gaoqiaozhen,Kao-ch''iao,Kao-ch''iao-chen,Kao-ch’iao,Kao-ch’iao-chen,Kaokiao,gao qiao,gao qiao zhen,高桥,高桥镇', 40.8987700, 120.9968600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22701, 'Gaoliying', 'Gaoliying', 'Gaolin,Gaoliying,Gaoliying Zhen,Kai-li-ying,Kao-li-ying,gao li ying,gao li ying zhen,高丽营,高丽营镇', 40.1705700, 116.4963000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22702, 'Gaoling', 'Gaoling', 'Gaoling,Gaoling Zhen,Kao-ling,gao ling,gao ling zhen,高岭,高岭镇', 40.6021900, 117.1046100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22703, 'Gaoling', 'Gaoling', 'Gaoling,Gaoling Zhen,gao ling,gao ling zhen,高岭,高岭镇', 40.1456800, 120.0081400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22704, 'Gaokan', 'Gaokan', 'Gaokan,Gaokan Zhen,gao kan,gao kan zhen,高坎,高坎镇', 40.7732200, 122.3741500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22705, 'Ganwang', 'Ganwang', 'Ganwang,Ganwang Zhen,Ta-kan-wang-chai,gan wang,gan wang zhen,感王,感王镇', 40.8130600, 122.5516500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22706, 'Ganquan', 'Ganquan', 'Ganquan,Ganquan Zhen,gan quan,gan quan zhen,甘泉,甘泉镇', 40.9642600, 122.8541800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22707, 'Ganq Ger', 'Ganq Ger', 'Ganq Ger,Gashigen,Gashigen Xiang,Ka-shih-ken,ga shen gen,ga shen gen xiang,嘎什根,嘎什根乡', 46.2132600, 123.6669900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22708, 'Gannan', 'Gannan', 'Erh-chan,Gannan,Gannan Xian,Gannan Zhen,Kan-ching-tzu,Kan-nan,Kan-nan-chen,Kan-nan-hsien,gan nan,gan nan xian,gan nan zhen,甘南,甘南县,甘南镇', 47.9147200, 123.5030600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22709, 'Ganhe', 'Ganhe', 'Ganhe,Ganhe Zhen,Kan-ho,Kan-ho-chen,gan he,gan he zhen,甘河,甘河镇', 50.6500000, 123.1000000, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22710, 'Gangtun', 'Gangtun', 'Gangtun,Gangtun Zhen,Kang-t''un,Kang-t’un,gang tun,gang tun zhen,钢屯,钢屯镇', 40.9197900, 120.6169800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22711, 'Gangou', 'Gangou', 'Gangou,Gangou Xiang,Kan-kou,gan gou,gan gou xiang,干沟,干沟乡', 41.8633300, 125.7144400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22712, 'Ganchazi', 'Ganchazi', 'Ganchazi,Ganchazi Xiang,Kan-ch''a-tzu,Kan-ch’a-tzu,gan cha zi,gan cha zi xiang,干岔子,干岔子乡', 49.4724400, 128.2665400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22713, 'Gaizhou', 'Gaizhou', 'Chin-p''ing,Chin-p’ing,Gaipin,Gaixian,Gaizhou,Gaizhou Shi,K''ai-p''ing,Kai-chou,Kai-hsien,Kai-p''ing-chen,Kai-p''ing-hsien,Kai-p’ing-chen,Kai-p’ing-hsien,Kaichow,K’ai-p’ing,gai zhou,gai zhou shi,盖州,盖州市', 40.3941700, 122.3686100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22714, 'Fuyuan', 'Fuyuan', 'FYJ,Fu-yuan-chen,Fu-yuan-hsien,Fu-yüan-chen,Fu-yüan-hsien,Fujuan'',Fuyuan,Fuyuanzhen,Fǔyuǎn,Sui-yuan,Sui-yüan,fu yuan,Фуюань,抚远,撫遠', 48.3630600, 134.2891700, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22715, 'Fuyu', 'Fuyu', 'Fu-yu-chen,Fu-yü-chen,Fuyu,Fuyu Xian,Fuyu Zhen,Fuyuy,Ning-nien,Ning-nien Chan,Yantszyatun'',Yantszyatun’,fu yu,fu yu xian,fu yu zhen,富裕,富裕县,富裕镇', 47.7975600, 124.4573100, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22716, 'Fuyu', 'Fuyu', 'Betuna,Bodune,Fu-yu-chen,Fu-yu-hsien,Fu-yü-chen,Fu-yü-hsien,Fuyu,Hsin-ch''eng,Hsin-ch''eng-hsien,Hsin-ch’eng,Hsin-ch’eng-hsien,Petuna,Po-tu-na,Po-tu-no,Sincheng', 45.1833300, 124.8166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22717, 'Jincang', 'Jincang', 'Fu-hsing,Fuxing,Fuxing Zhen,Jincang,fu xing,fu xing zhen,jin cang,复兴,复兴镇,金仓', 43.3630800, 130.4797300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22718, 'Fuxin', 'Fuxin', 'A-chin,Fou-hsin,Fou-hsin-chen,Fou-hsin-hsien,Fou-hsin-hsien-t''u-mo-t''e-ch''i,Fou-hsin-hsien-t’u-mo-t’e-ch’i,Fou-hsin-meng-ku-tsu-tzu-chih-hsien,Fu-hsin,Fu-sin,Fushin,Fusin'',Fuxin,Hsin-fou-hsien-t''u-mo-t''e-ch''i,Hsin-fou-hsien-t’u-mo-t’e-ch’i,Фусинь', 42.0588900, 121.7450000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22719, 'Fuxin', 'Fuxin', 'Fou-hsin,Fou-hsin-shih,Fu-hsin,Fu-sin,Fusin,Fusin'',Fusinas,Fuxin,Hu-sin-chhi,Hū-sin-chhī,Paiu-sing,Phu Tan,Phụ Tân,Pâiu-sĭng,faksyn,fu xin,fu xin shi,fwshn,pusin si,Фусин,Фусинь,Фүшинь хот,فاکسین,فوشن,阜新,阜新市,푸신 시', 42.0155600, 121.6588900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22720, 'Fusong', 'Fusong', 'Fu-shun,Fu-sung,Fu-sung-chen,Fu-sung-hsien,Fusong,Fusong Xian,Fusong Zhen,Mang-niu-shao,Mangnesia,fu song,fu song xian,fu song zhen,抚松,抚松县,抚松镇', 42.3250500, 127.2726500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22721, 'Fushun', 'Fushun', 'Bu-sun-chhi,Bú-sūn-chhī,Chiu-fu-shun,Fu-shan,Fu-shun-hsien,Fu-shun-shih,Fu-sun,Fu-šun,Fushun,Fushun'',Fushuncheng,Fusjun,Fusun,Fusunas,Fusuno,Fuŝuno,Fušunas,Phu Thuan,Phủ Thuận,U-song,fu shun,fu shun shi,fusuna,fwshwn,pusun si,pwswn,Ū-sông,Фушун,Фушунь,פושון,فوشون,ਫ਼ੁਸ਼ੁਨ,抚顺市,撫順,撫順市,푸순 시', 41.8558300, 123.9233300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22722, 'Furao', 'Furao', 'Furao,Furao Zhen,fu rao,fu rao zhen,富饶,富饶镇', 47.4141900, 125.5451200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22723, 'Fuqiang', 'Fuqiang', 'Fuqiang,Fuqiang Zhen,fu qiang,fu qiang zhen,富强,富强镇', 47.4750200, 125.7918900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22724, 'Fulu', 'Fulu', 'Dalayke,Fu-yu,Fu-yu-chen,Fu-yu-hsien,Fu-yü,Fu-yü-chen,Fu-yü-hsien,Fulu,Fulu Zhen,Fuyui,Fuyuychzhen'',Fuyuychzhen’,Ta-lai-k''o,Ta-lai-k''o-t''un,Ta-lai-k’o,Ta-lai-k’o-t’un,fu lu,fu lu zhen,富路,富路镇', 47.6432100, 124.6772600, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22725, 'Fuli', 'Fuli', 'Chi-hsien,Fu-li-chen,Fuli,Fulitun,Jixian,Фули', 46.7216700, 131.1394400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22726, 'Fujin', 'Fujin', 'Fu-chin,Fu-chin-chen,Fu-chin-hsien,Fu-k''o-chin,Fu-k’o-chin,Fuczin'',Fujin,Fukin,Фуцзинь', 47.2600000, 132.0322200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22727, 'Fujia', 'Fujia', 'Fu-chia-t''un,Fu-chia-t’un,Fujia,Fujia Zhen,Fujiatun,fu jia,fu jia zhen,傅家,傅家镇', 43.2837400, 123.8112600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22728, 'Jianchanggou', 'Jianchanggou', 'Chien-ch''ang-kou,Chien-ch’ang-kou,Fujiang Xiang,Jianchanggou,fu jiang xiang,jian chang gou,富江乡,碱厂沟', 41.7737700, 125.3312000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22729, 'Fuhai', 'Fuhai', 'Fuhai,Fuhai Zhen,fu hai,fu hai zhen,富海,富海镇', 47.8695100, 124.8552900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22730, 'Fudong', 'Fudong', 'Fu-tung,Fudong,Fudong Zhen,fu dong,fu dong zhen,福洞,福洞镇', 42.5741600, 129.1478100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22731, 'Beichengqu', 'Beichengqu', 'Beichengqu,Beichengqu Jiedao,Feng-chen,Feng-chen-hsien,Fengzhen,Fengzhen Shi,bei cheng qu,bei cheng qu jie dao,feng zhen,feng zhen shi,li zhen,li zhen shi,丰镇,丰镇市,北城区,北城区街道,豊鎮,豊鎮市', 40.4394400, 113.1536100, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22732, 'Fengxiang', 'Fengxiang', 'Feng-hsiang,Feng-hsiang-chen,Feng-huang-chen,Fengsiang,Fengxiang,Fengxiang Zhen,Lo-pei,Luobei,Luobei Xian,feng xiang,feng xiang zhen,luo bei xian,Фенгсианг,凤翔,凤翔镇,萝北县', 47.5754900, 130.8230600, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22733, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Zhen,feng shan,feng shan zhen,凤山,凤山镇', 46.2610000, 128.5500800, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22734, 'Fengcheng', 'Fengcheng', 'Feng-ch''eng-chen,Feng-ch''eng-hsien,Feng-ch’eng-chen,Feng-ch’eng-hsien,Feng-huang-ch''eng,Feng-huang-ch’eng,Fengcheng,Fenghwangcheng', 40.4536100, 124.0716700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22735, 'Fengchan', 'Fengchan', 'Fengchan,Fengchan Xiang,feng chan,feng chan xiang,丰产,丰产乡', 47.6286100, 125.8446800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22736, 'Fendou', 'Fendou', 'Fendou,Fendou Xiang,fen dou,fen dou xiang,奋斗,奋斗乡', 49.1120800, 127.5081200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22737, 'Fangzheng', 'Fangzheng', 'Fanchzen,Fang-chen,Fang-cheng,Fang-cheng-chen,Fang-cheng-hsien,Fang-cheng-p''ao,Fang-cheng-p’ao,Fangzhen Xian,Fangzheng,fang zheng,fang zheng xian,方正,方正县', 45.8388100, 128.8275700, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22738, 'Fangtai', 'Fangtai', 'Fangtai,Fangtai Zhen,fang tai,fang tai zhen,方台,方台镇', 46.0891700, 126.9333100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22739, 'Yanqi', 'Yanqi', 'Fangezhuang,Yanqi,Yanqi Zhen,fan ge zhuang,yan qi,yan qi zhen,范各庄,雁栖,雁栖镇', 40.3617200, 116.6562600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22740, 'Erzhan', 'Erzhan', 'Erh-chan,Erh-chang,Erzhan,Erzhan Xiang,K''u-mu-erh,K’u-mu-erh,er zhan,er zhan xiang,二站,二站乡', 49.6730900, 126.9544000, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22741, 'Erniusuokou', 'Erniusuokou', 'Erh-niu-so-k''ou,Erh-niu-so-k’ou,Erniusuokou,Erniusuokou Zhen,er niu suo kou,r niu suo kou zhen,二牛所口,儿牛所口镇', 42.7661800, 123.1548600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22742, 'Ermi', 'Ermi', 'Ermi,Ermi Zhen,er mi,er mi zhen,二密,二密镇', 41.7880600, 125.8297200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22743, 'Erhe', 'Erhe', 'Erhe,Erhe Xiang,er he,er he xiang,二河,二河乡', 45.0809600, 127.3108300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22744, 'Erfenzi', 'Erfenzi', 'Erfenzi,Erfenzi Xiang,Erh-fen-tzu,er fen zi,er fen zi xiang,二份子,二份子乡', 41.3645400, 110.7269100, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22745, 'Erenhot', 'Erenhot', 'ERL,Ereen,Erenhot,Erh-lien,Erh-lien-hao-t''e,Erh-lien-hao-t''e-shih,Erh-lien-hao-t’e,Erh-lien-hao-t’e-shih,Erlianhaote Shi,Erlin,Erlyan'',Erlyan’,I-lin-ta-pu-su,I-lin-tu-pa-su,Iren,Iren Dabasu,P''ang-pei,P’ang-pei,Wulan,Wulan Jiedao,Yeh-lieh-ta-pa-sha,Yu-lin-ta-pa-su,er lian hao te,er lian hao te shi,wu lan,wu lan jie dao,乌兰,乌兰街道,二连浩特,二连浩特市', 43.6475000, 111.9766700, 'CN', '2013-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22746, 'Eren Gobi', 'Eren Gobi', 'Eren Gaobi,Eren Gaobi Sumu,Eren Gobi,e ren gao bi,e ren gao bi su mu,额仁高毕,额仁高毕苏木', 46.1833300, 118.3000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22747, 'Erdaojiang', 'Erdaojiang', 'Erdaojiang,Erh-tao-chiang,Erh-tao-kou', 41.7763900, 126.0319400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22748, 'Erdaohezi', 'Erdaohezi', 'Erdaohezi,Erdaohezi Zhen,Erh-tao-ho-tzu,er dao he zi,er dao he zi zhen,二道河子,二道河子镇', 45.1079300, 129.7383400, 'CN', '2013-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22749, 'Erdao', 'Erdao', 'Erdao,Erdao Zhen,Erdaogou,er dao,er dao gou,er dao zhen,二道,二道沟,二道镇', 40.5958200, 122.2671900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22750, 'Erdaodianzi', 'Erdaodianzi', 'Erdaodianzi,Erdaodianzi Zhen,Erh-tao-tien-tzu,er dao dian zi,er dao dian zi zhen,二道甸子,二道甸子镇', 43.1423200, 127.1425700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22751, 'Erdaobaihe', 'Erdaobaihe', 'Erdaobaihe,Erdaobaihe Zhen,Erh-tao-pai-ho,er dao bai he,er dao bai he zhen,二道白河,二道白河镇', 42.4245600, 128.1104800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22752, 'Duolun', 'Duolun', 'Dolon Nor,Dolonnur,Dolonor,Doloon Nuur,Dolunnor,Duolun,Duolun Xian,Duolunnao''er Zhen,Duolunnao’er Zhen,Lam-yao,Lama Miao,Lamo Miao,To-lun,To-lun-hsien,Tolunnoerh,duo lun nao er,duo lun nao er zhen,duo lun xian,la ma miao,喇嘛庙,多伦县,多伦淖尔,多伦淖尔镇', 42.1871200, 116.4890900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22753, 'Dunhua', 'Dunhua', 'Ao-tung-ch''eng,Ao-tung-ch’eng,Dun''khua,Dunhua,Tun-hua,Tun-hua-chen,Tun-hua-hsien,Tung Hua,Tunhwa,Дуньхуа', 43.3725000, 128.2425000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22754, 'Dongyang', 'Dongyang', 'Dongyang,Dongyang Zhen,Tung-yang,Tung-yang-chen,dong yang,dong yang zhen,东阳,东阳镇', 48.0124100, 124.2474400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22755, 'Dongxing', 'Dongxing', 'Dongxing,Dongxing Xiang,dong xing,dong xing xiang,东兴,东兴乡', 47.2677500, 125.0302100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22756, 'Dongxing', 'Dongxing', 'Dongxing,Dongxing Zhen,Tung-hsing,Tung-hsing-chen,Tung-hsing-hsien,Tunghing,dong xing,dong xing zhen,东兴,东兴镇', 46.3799100, 127.8648400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22757, 'Dongxiaokou', 'Dongxiaokou', 'Dongxiaokou,Dongxiaokou Zhen,dong xiao kou,dong xiao kou zhen,东小口,东小口镇', 40.0571500, 116.4031000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22758, 'Dongshengyong', 'Dongshengyong', 'Dongshengyong,Dongshengyong Zhen,Tung-sheng-yung,dong sheng yong,dong sheng yong zhen,东盛涌,东盛涌镇', 42.8089000, 129.5001100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22759, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Xiang,dong sheng,dong sheng xiang,东胜,东胜乡', 48.2329900, 126.6602400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22760, 'Dongshaoqu', 'Dongshaoqu', 'Dongshaoqu,Dongshaoqu Zhen,dong shao qu,dong shao qu zhen,东邵渠,东邵渠镇', 40.2894900, 116.9573800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22761, 'Dongshangen', 'Dongshangen', 'Dongshangen,Qiuzigou Xiang,dong shan gen,qiu zi gou xiang,东山根,秋子沟乡', 40.3755300, 119.7718300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22762, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,Tung-p''ing,Tung-p’ing,dong ping,dong ping zhen,东屏,东屏镇', 46.0889800, 123.2764500, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22763, 'Dongning', 'Dongning', 'Dongning,Dongning Xian,Dongning Zhen,Hsiao-ch''eng-tzu,Hsiao-ch’eng-tzu,Tung-ning,Tung-ning-chen,Tung-ning-hsien,dong ning,dong ning xian,dong ning zhen,东宁,东宁县,东宁镇', 44.0621900, 131.1207500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22764, 'Dongling', 'Dongling', 'Dongling,Donlin,Tung-ling,Донлин', 41.8144400, 123.5758300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22765, 'Dongjingcheng', 'Dongjingcheng', 'Dongjingcheng,Dongjingcheng Zhen,Duntszinchen,Shih-huan-chen,Tung-ching-ch''eng,Tung-ching-ch’eng,Tungtzuchen,dong jing cheng,dong jing cheng zhen,东京城,东京城镇', 44.1142600, 129.2100300, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22766, 'Dongguang', 'Dongguang', 'Dongguang,Dongguang Zhen,dong guang,dong guang zhen,东光,东光镇', 43.2912300, 129.8074000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22767, 'Donggaocun', 'Donggaocun', 'Donggaocun,Donggaocun Zhen,Tung-kao-chuang,Tung-kao-ts''un,Tung-kao-ts’un,dong gao cun,dong gao cun zhen,东高村,东高村镇', 40.1065300, 117.1119000, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22768, 'Donggang', 'Donggang', 'Donggang,Donggang Zhen,Tung-kang,dong gang,dong gang zhen,东岗,东岗镇', 42.1615600, 127.4858900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22769, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Zhen,dong feng,dong feng zhen,东风,东风镇', 47.4102000, 127.1047200, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22770, 'Dongfeng', 'Dongfeng', 'Dongfeng,Ta-tu-ch''uan,Ta-tu-ch’uan,Tung-feng,Tung-feng-chen,Tung-feng-hsien,Tung-p''ing-hsien,Tung-p’ing-hsien,dong feng,东丰', 42.6403100, 125.5117600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22771, 'Pucheng', 'Pucheng', 'Dongcheng,Dongcheng Zhen,Pucheng,dong cheng zhen,pu cheng,东城镇,普城', 42.7437000, 129.3247900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22772, 'Dongbeicha', 'Dongbeicha', 'Dongbeicha,Dongbeicha Xiang,dong bei cha,dong bei cha xiang,东北岔,东北岔乡', 41.7375000, 127.2877800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22773, 'Dolod', 'Dolod', 'Daolaodu,Daolaodu Sumu,Dolod,dao lao dou,dao lao du,dao lao du su mu,道老杜,道老杜苏木,道老都', 44.5000000, 121.4500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22774, 'Dongxing', 'Dongxing', 'Didao,Didao Qu,Dongxing,Ti-tao,di dao,di dao qu,dong xing,东兴,滴道,滴道区', 45.3608800, 130.7867900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22775, 'Diaoling', 'Diaoling', 'Diaoling,Diaoling Zhen,Tiaoling,diao ling,diao ling zhen,刁翎,刁翎镇', 45.7778400, 129.9924800, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22776, 'Xinhua', 'Xinhua', 'Dexingtai,Te-hsing-t''ai,Te-hsing-t’ai,Xinhua,Xinhua Zhen,xin hua,xin hua zhen,新华,新华镇', 44.5833300, 122.8666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22777, 'Derbur', 'Derbur', 'De''er Bu''er Zhen,De''erbu''er,Derbur,De’er Bu’er Zhen,De’erbu’er,Te-erh-pu-erh,de er bu er,de er bu er zhen,得尔布尔,得尔布尔镇', 50.9920600, 121.0584300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22778, 'Deliqi’er', 'Deliqi''er', 'Deliqi''er,Deliqi''er Ewenkeminzu Xiang,Deliqi’er,Deliqi’er Ewenkeminzu Xiang,de li qi er,de li qi er e wen ke min zu xiang,得力其尔,得力其尔鄂温克民族乡', 48.6354400, 123.7177500, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22779, 'Dehui', 'Dehui', 'Chang-chia-wan,Dehui,Te-hui,Te-hui-chen,Tszhantszyavan'',Tszhantszyavan’,Yao-men', 44.5333300, 125.7000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22780, 'Dazhuangke', 'Dazhuangke', 'Dazhuangke,Dazhuangke Xiang,Ta-chuang-ko,da zhuang ke,da zhuang ke xiang,大庄科,大庄科乡', 40.4351100, 116.2226200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22781, 'Dayushu', 'Dayushu', 'Dayushu,Dayushu Zhen,da yu shu,da yu shu zhen,大榆树,大榆树镇', 40.4330900, 116.0213600, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22782, 'Dayingzi', 'Dayingzi', 'Dayingzi,Dayingzi Zhen,Ta-ying-tzu,da ying zi,da ying zi zhen,大营子,大营子镇', 40.3141700, 123.6075000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22783, 'Dayangshu', 'Dayangshu', 'Dajanshu,Dayangshu,Dayangshu Zhen,Gan''kuy,Gan’kuy,Kan-ho,Kan-k''uei,Kan-k’uei,Ta-yang-shu,Tayanshu,da yang shu,da yang shu zhen,Даяншу,大杨树,大杨树镇', 49.7500000, 124.5666700, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22784, 'Dayangqi', 'Dayangqi', 'Dayangqi,Dayangqi Zhen,Ta-yang-ch''i,Ta-yang-ch’i,da yang qi,da yang qi zhen,大扬气,大扬气镇', 51.0000000, 124.0833300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22785, 'Daxingzhuang', 'Daxingzhuang', 'Daxingzhuang,Daxingzhuang Zhen,da xing zhuang,da xing zhuang zhen,大兴庄,大兴庄镇', 40.1470200, 117.0453800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22786, 'Daxing', 'Daxing', 'Daxing,Daxing Xiang,Daxingpu,da xing,da xing xiang,大兴,大兴乡', 40.9655800, 120.9419800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22787, 'Daxinggou', 'Daxinggou', 'Daxinggou,Daxinggou Zhen,Ta-hsing-kou,da xing gou,da xing gou zhen,大兴沟,大兴沟镇', 43.4073400, 129.6612000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22788, 'Daxing', 'Daxing', 'Daxing,Daxing Zhen,da xing,da xing zhen,大兴,大兴镇', 46.8750000, 123.7418700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22789, 'Linhai', 'Linhai', 'Daxing,Linhai,Linhai Zhen,lin hai,lin hai zhen,林海,林海镇', 45.5195200, 122.7541400, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22790, 'Dawusu', 'Dawusu', 'Dausu,Dawusu,Dawusu Zhen,Ta-wu-su,da wu su,da wu su zhen,Даусу,大乌苏,大乌苏镇', 51.7998700, 124.5179000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22791, 'Dawa', 'Dawa', 'Dawa,Dawa Zhen,Ta-wa,da wa,da wa zhen,大洼,大洼镇', 40.9937300, 122.0680400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22792, 'Datun', 'Datun', 'Datun,Datun Jiedao,da tun,da tun jie dao,大屯,大屯街道', 39.9876000, 116.4177700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22793, 'Datong', 'Datong', 'Datong,Datong Qu,Datong Zhen,Datun,Ta-t''ung,Ta-t''ung-chen,Ta-t''ung-chieh,Ta-t’ung,Ta-t’ung-chen,Ta-t’ung-chieh,da tong,da tong qu,da tong zhen,Датун,大同,大同区,大同镇', 46.0337600, 124.8106400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22794, 'Datong', 'Datong', 'DAT,Dagu,Daido,Datong,Datongas,Datongo,Datun,Datung,GJai GJong,Ta-jen,Ta-jen-hsien,Ta-ku,Ta-t''ung,Ta-t''ung-hsien,Ta-t''ung-shih,Ta-tchung,Ta-t’ung,Ta-t’ung-hsien,Ta-t’ung-shih,da tong shi,datung si,datwng,Đại Đồng,Датун,Датунг,داتونگ,داتۇڭ شەھىر,大同市,다퉁 시', 40.0936100, 113.2913900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22795, 'Datan', 'Datan', 'Datan,Ta-t''an,Ta-t’an,Wu-tung,da tan,大滩', 41.2661700, 112.1696600, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22796, 'Dasuhe', 'Dasuhe', 'Dasuhe,Dasuhe Xiang,Ta-su-ho,da su he,da su he xiang,大苏河,大苏河乡', 41.9181700, 124.9562400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22797, 'Dasizhan', 'Dasizhan', 'Dasizhan,Dasizhan Zhen,da si zhan,da si zhan zhen,大四站,大四站镇', 45.8555900, 130.4274100, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22798, 'Dasiping', 'Dasiping', 'Dasiping,Dasiping Zhen,da si ping,da si ping zhen,大四平,大四平镇', 41.3168600, 124.7134300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22799, 'Dashitou', 'Dashitou', 'Dashitou,Ta-shih-t''ou,Ta-shih-t''ou-ho-tzu,Ta-shih-t’ou,Ta-shih-t’ou-ho-tzu,Tashitou', 43.3066700, 128.5113900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22800, 'Dashiqiao', 'Dashiqiao', 'Dashiqiao,Dashiqiao Shi,Ta-shih-ch''iao,Ta-shih-ch''iao-chen,Ta-shih-ch’iao,Ta-shih-ch’iao-chen,Tashihkiao,Yingkou,da shi qiao,da shi qiao shi,大石桥,大石桥市', 40.6373200, 122.5025100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22801, 'Dashi', 'Dashi', 'Dashi,Dashi Zhen,Dashibaozi,da shi,da shi zhen,大市,大市镇', 41.7736300, 121.7701500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22802, 'Dashahe', 'Dashahe', 'Dashahe,Ta-sha-ho,Ta-sha-ho-k''ou-tzu,Ta-sha-ho-k’ou-tzu,Yongqing Xiang,da sha he,yong qing xiang,大沙河,永庆乡', 42.7226600, 128.2544300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22803, 'Daquanyuan', 'Daquanyuan', 'Daquanyuan,Daquanyuan Manzu Chaoxianzu Xiang,Ta-ch''uan-yuan,Ta-ch’üan-yüan,da quan yuan,da quan yuan man zu chao xian zu xiang,大泉源,大泉源满族朝鲜族乡', 41.5540600, 125.6040100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22804, 'Daqin Tal', 'Daqin Tal', 'Daqin Tal,Daqin Tala Zhen,Nai-man-ch''i,Nai-man-ch’i,Nai-man-wang-fu,Naiman Qi,Ta-ch''in-t''a-la,Ta-ch’in-t’a-la,Tah-sing-tala,Tai-ch''in-t''a-la,Tai-ch’in-t’a-la,da qin ta la,da qin ta la zhen,nai man qi,大沁他拉,大沁他拉镇,奈曼旗', 42.8871900, 120.6746600, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22805, 'Daqing', 'Daqing', 'An-ta,An-ta-shih,Anda,DQA,Dachin,Dacin,Dai-keng,Daqing,Dâi-kéng,GJai Khanh,Gorad Dacyn,Sa-erh-t''u,Sa-erh-t’u,Sartu,Sha-erh-t''u,Sha-erh-t’u,Ta-cching,Ta-čching,Tai-kheng-chhi,Tāi-khèng-chhī,da qing,da qing shi,daching si,dachyng,dakyng,Đại Khánh,Горад Дацын,Дацин,Дачин,داچىڭ شەھىر,داچینگ,داکینگ,大庆市,大慶,大慶市,다칭 시', 46.5833300, 125.0000000, 'CN', '2013-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22806, 'Dapuchaihe', 'Dapuchaihe', 'Dapuchaihe,Dapuchaihe Zhen,Ta-p''u-ch''ai-ho,Ta-pu-ts''ai-ho,Ta-pu-ts’ai-ho,Ta-p’u-ch’ai-ho,da pu chai he,da pu chai he zhen,大蒲柴河,大蒲柴河镇', 42.8797300, 128.0304900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22807, 'Daotaiqiao', 'Daotaiqiao', 'Daotaiqiao,Daotaiqiao Zhen,Tao-t''ai-ch''iao,Tao-t’ai-ch’iao,dao tai qiao,dao tai qiao zhen,道台桥,道台桥镇', 46.1976800, 129.8429400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22808, 'Daohe', 'Daohe', 'Daohe,Daohe Zhen,Tao-ho,dao he,dao he zhen,道河,道河镇', 44.0332100, 130.8285700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22809, 'Dandong', 'Dandong', 'An-tung-hsien,An-tung-shih,Antung,DDG,Dan''dun,Dandong,Dandong - dan dong,Dandong - 丹东,Dandong Shi,Dandun,Dandung,Dang-dung,Dăng-dŭng,GJan GJong,Sha-ho-ch''en,Sha-ho-ch’en,Sha-ho-tzu,Tan-tong-chhi,Tan-tong-chhī,Tan-tung,Tan-tung-shih,dan dong,dan dong shi,dandung si,dandwng,dandwngh,dandwnj,tan tng,Đan Đông,Дандун,Дандунг,Даньдун,Դանդուն,داندونج,داندونغ,داندونگ,ഡാൻദോങ്,ตานตง,丹东市,丹東,丹東市,단둥 시', 40.1291700, 124.3947200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22810, 'Dandai', 'Dandai', 'Dandai,Dandai Xiang,dan dai,dan dai xiang,丹岱,丹岱乡', 46.2737200, 123.8396600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22811, 'Damiao', 'Damiao', 'Damiao,Damiao Xiang,da miao,da miao xiang,大庙,大庙乡', 41.0924500, 110.5062200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22812, 'Daluo', 'Daluo', 'Daluo,Daluo Zhen,Ta-lo-chen,da luo,da luo zhen,大罗,大罗镇', 46.6228200, 127.5724400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22813, 'Daluomi', 'Daluomi', 'Daluolemi,Daluomi,Daluomi Zhen,Lo-la-mi,Lo-lo-mi,Ta-lo-lo,Ta-lo-lo-mi,Ta-lo-mi,Talolemi,da luo mi,da luo mi zhen,大罗密,大罗密镇', 45.9571900, 129.2051300, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22814, 'Dalu', 'Dalu', 'Dalu,Dalu Zhen,da lu,da lu zhen,大路,大路镇', 40.9954700, 125.7712100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22815, 'Dalizi', 'Dalizi', 'Dairisshiko,Dalizi,Dalizi Zhen,Ta-li,Ta-li-tsu,Ta-li-tzu,Ta-li-tzu-ko,Ta-li-tzu-kou,da su zi,da su zi zhen,大粟子,大粟子镇', 41.7302800, 126.8333300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22816, 'Daliuhao', 'Daliuhao', 'Daliuhao,Ta-liu-hao,Ta-lu-hao,da liu hao,大六号', 41.2259400, 113.2905800, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22817, 'Linghai', 'Linghai', 'Chin,Chin-hsien,Dalinghe,Jinxian,Linghai,Linghai Shi,Ta-ling-ho,Ta-ling-ho-chen,Ta-ling-ho-tien,Ta-ling-ho-tien-tzu', 41.1652800, 121.3666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22818, 'Dalianhe', 'Dalianhe', 'Dalianhe,Dalianhe Zhen,da lian he,da lian he zhen,达连河,达连河镇', 46.1693100, 129.4037900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22819, 'Dalain Hob', 'Dalain Hob', 'Buhelanda,Dalai Hob,Dalai Hob Zhen,Dalaihubu,Dalaihubu Zhen,Dalain Hob,Dalankebu,Eji''na Qi,Ejin Qi,Eji’na Qi,O-chi-na-ch''i,O-chi-na-ch’i,Pu-ho-lan-ta,Pu-k''o-lan-ta,Pu-k’o-lan-ta,Ta-lan-k''o-pu,Ta-lan-k''u-pu,Ta-lan-k’o-pu,Ta-lan-k’u-pu,da lai hu bu,da lai hu bu zhen,e ji na qi,达来呼布,达来呼布镇,额济纳旗', 41.9652800, 101.0638900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22820, 'Dalai', 'Dalai', 'Dalai,Dalai Zhen,da lai,da lai zhen,大来,大来镇', 46.6822100, 129.9455200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22821, 'Dalai', 'Dalai', 'Da''an,Dalai,Dalaysyan'',Dalaysyan’,Da’an,Mo-lo-hung-kang-tzu,Ta-an,Ta-lai,Ta-lai-chen,Ta-lai-hsien,Talaicheng', 45.5000000, 124.3000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22822, 'Dalai', 'Dalai', 'Dalai,Dalai Sumu,da lai,da lai su mu,达来,达来苏木', 44.6264200, 112.9890200, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22823, 'Dajinggou', 'Dajinggou', 'Dajinggou,Dajinggou Xiang,da jing gou,da jing gou xiang,大镜沟,大镜沟乡', 41.8624300, 126.5237500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22824, 'Dailing', 'Dailing', 'Dailing,Dailing Jiedao,Dailing Qu,Tai-ling,Tai-ling-t''un,Tai-ling-t’un,dai ling,dai ling jie dao,dai ling qu,带岭,带岭区,带岭街道', 47.0238900, 129.0190400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22825, 'Dahuashan', 'Dahuashan', 'Dahuashan,Dahuashan Zhen,Hua-shan-chuang,Ta-hua-shan,Ta-hua-shan-ts''un,Ta-hua-shan-ts’un,da hua shan,da hua shan zhen,大华山,大华山镇', 40.2755500, 117.0668900, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22826, 'Dagui', 'Dagui', 'Dagui,Dagui Zhen,Ta-kuei,da gui,da gui zhen,大贵,大贵镇', 46.2420900, 127.8062400, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22827, 'Dage', 'Dage', 'Dage,Fengning,Fynnin,Ta-ko,Ta-ko-chen,Ta-kou-chen,Ta-ku-chen,da ge,大阁', 41.1988900, 116.6441700, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22828, 'Daduling', 'Daduling', 'Daduling,Daduling Xiang,Ta-tu-ling,da dou ling,da dou ling xiang,大都岭,大都岭乡', 41.6175000, 125.6908300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22829, 'Daduchuan', 'Daduchuan', 'Daduchuan,Daduchuan Zhen,Ta-tu-ch''uan,Ta-tu-ch’uan,da du chuan,da du chuan zhen,大肚川,大肚川镇', 43.9453200, 131.0677200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22830, 'Dachengzi', 'Dachengzi', 'Dachengzi,Dachengzi Zhen,Ta-ch''eng-tzu,Ta-ch’eng-tzu,da cheng zi,da cheng zi zhen,大城子,大城子镇', 40.3924000, 117.1048700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22831, 'Daban', 'Daban', 'Bairin Youqi,Balin''yutsi,Balinyou Qi,Balin’yutsi,Daban,Daban Zhen,Daban''shan,Daban’shan,Pa-lin-yu-ch''i,Pa-lin-yu-ch’i,Pa-lin-yu-i-ch''i,Pa-lin-yu-i-ch’i,Ta-pa-lin-wang-fu,Ta-pa-shang,Ta-pan,Ta-pan-shang,ba lin you qi,da ban,da ban zhen,大板,大板镇,巴林右旗', 43.5333300, 118.6666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22832, 'Da’an', 'Da''an', 'Da''an,Da''an Zhen,Da’an,Da’an Zhen,Ta-an,da an,da an zhen,大安,大安镇', 41.8355600, 126.1272200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22833, 'Shuguang', 'Shuguang', 'Cuiluan,Cuiluan Qu,Shuguang,Shuguang Jiedao,Ts''ui-luan,Ts''ui-man,Ts’ui-luan,Ts’ui-man,cui luan,cui luan qu,shu guang,shu guang jie dao,曙光,曙光街道,翠峦,翠峦区', 47.7241100, 128.6739900, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22834, 'Cuigang', 'Cuigang', 'Cuigang,Cuigang Zhen,Cujgan,Ts''ui-kang,Ts’ui-kang,cui gang,cui gang zhen,Цуйган,翠岗,翠岗镇', 52.0413800, 124.6952900, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22835, 'Chunyang', 'Chunyang', 'Ch''un-yang-ts''un,Chunyang,Chunyang Zhen,Ch’un-yang-ts’un,chun yang,chun yang zhen,春阳,春阳镇', 43.7117500, 129.4326100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22836, 'Xitumenzi', 'Xitumenzi', 'Chunhua,Chunhua Zhen,Tung-hsing-chen,Xitumenzi,chun hua zhen,xi tu men zi,春化镇,西土门子', 43.1951400, 131.0725700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22837, 'Choushui', 'Choushui', 'Ch''ou-shui-ho,Choushui,Choushui Xiang,Ch’ou-shui-ho,chou shui,chou shui xiang,抽水,抽水乡', 42.3946300, 127.0762700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22838, 'Chongshan', 'Chongshan', 'Ch''ung-shan,Chongshan,Chongshan Zhen,Ch’ung-shan,chong shan,chong shan zhen,崇善,崇善镇', 42.0933900, 128.9994600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22839, 'Chonghe', 'Chonghe', 'Ch''ung-ho,Ch''ung-ho-chen,Chonghe,Chonghe Zhen,Ch’ung-ho,Ch’ung-ho-chen,Tsunho,chong he,chong he zhen,冲河,冲河镇', 44.6698100, 127.7311200, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22840, 'Chongde', 'Chongde', 'Chongde,Chongde Zhen,chong de,chong de zhen,崇德,崇德镇', 47.2783700, 125.5930100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22841, 'Chifeng', 'Chifeng', 'CIF,Cch''-feng,Ch''ih-feng,Ch''ih-feng-chou,Ch''ih-feng-hsien,Ch''ih-feng-shih,Chhak-fung-su,Chhak-fûng-sṳ,Chhek-hong-chhi,Chhek-hong-chhī,Chiah-hung,Chifehn,Chifeng,Chifeng Shi,Chiáh-hŭng,Ch’ih-feng,Ch’ih-feng-chou,Ch’ih-feng-hsien,Ch’ih-feng-shih,Ha-ta,Hongshan Qu,Tschifoeng,Tschiföng,Ulaan Hada,Ulaankhad,Ulanhad,Wu-lan-ha-ta,Xich Phong,Xích Phong,cheupeong si,chi feng,chi feng shi,chyfng,chyfyng,hong shan qu,Čch’-feng,Улаанхад,Чифенг,Чифэн,چیفنگ,چیفینگ,红山区,赤峰,赤峰市,츠펑 시', 42.2683300, 118.9636100, 'CN', '2013-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22842, 'Chicheng', 'Chicheng', 'Ch''ih-ch''eng,Ch''ih-ch''eng-ch''eng-kuan,Ch''ih-ch''eng-hsien,Chicheng,Ch’ih-ch’eng,Ch’ih-ch’eng-ch’eng-kuan,Ch’ih-ch’eng-hsien,chi cheng,赤城', 40.8666700, 115.8333300, 'CN', '2015-02-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22843, 'Chenming', 'Chenming', 'Chenming,Chenming Zhen,Nung-ming,chen ming,chen ming zhen,晨明,晨明镇', 46.9764800, 129.4832100, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22844, 'Chengzihe', 'Chengzihe', 'Ch''eng-tzu-ho,Chengzihe,Ch’eng-tzu-ho', 45.3333300, 131.0666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22845, 'Chengde', 'Chengde', 'CDE,Ccheng-te,Cengde,Ch''eng-te,Ch''eng-te-hsien,Ch''eng-te-shih,Chehndeh,Chengde,Chengdé,Chengteh,Ch’eng-te,Ch’eng-te-hsien,Ch’eng-te-shih,Je-ho,Jehoi,Jehol,Jo-ho,Seng-tek-chhi,Sing-daik,Sêng-tek-chhī,Sìng-dáik,Thua GJuc,Thừa Đức,Tschongto,cheng de,cheng de shi,cheongdeo si,chngdh,Čcheng-te,Čengdė,Ченгде,Чэндэ,چنگده,چینگدے,承徳市,承德,承德市,청더 시', 40.9519000, 117.9588300, 'CN', '2016-08-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22846, 'Chelu', 'Chelu', 'Chehlu,Chelu,Chelu Xiang,che lu,che lu xiang,Чэлу,车陆,车陆乡', 49.4424200, 128.7860900, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22847, 'Chaoyangchuan', 'Chaoyangchuan', 'Chaoyangchuan,Chaoyangchuan Zhen,chao yang chuan,chao yang chuan zhen,朝阳川,朝阳川镇', 42.8797100, 129.3614600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22848, 'Qiujia', 'Qiujia', 'Chaoyang,Chaoyang Zhen,Qiujia,chao yang,chao yang zhen,qiu jia,朝阳,朝阳镇,邱家', 43.1173600, 124.0726300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22849, 'Chaoyang', 'Chaoyang', 'Ch''ao-yang-chen,Ch''ao-yang-shen,Chaojan,Chaoyang,Ch’ao-yang-chen,Ch’ao-yang-shen,Huinan,chao yang,Чаоян,朝阳', 42.6622300, 126.0263000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22850, 'Chaoyang', 'Chaoyang', 'CHG,Ch''ao-yang-chen,Ch''ao-yang-hsien,Ch''ao-yang-shih,Chaiyang,Chaojan,Chaoyang,Ch’ao-yang-chen,Ch’ao-yang-hsien,Ch’ao-yang-shih,San-tso-t''a,San-tso-t’a,chao yang shi,chaoyang si,chawyang,Чаоян,چاویانگ,朝陽市,차오양 시', 41.5702800, 120.4586100, 'CN', '2017-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22851, 'Changxingdian', 'Changxingdian', 'Ch''ang-hsing,Ch''ang-hsing-tien,Changxingdian,Changxingdian Zhen,Ch’ang-hsing,Ch’ang-hsing-tien,chang xing dian,chang xing dian zhen,常兴店,常兴店镇', 41.4495100, 121.7250900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22852, 'Changxing', 'Changxing', 'Changxing,Changxing Xiang,zhang xing,zhang xing xiang,长兴,长兴乡', 43.1813300, 128.9378600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22853, 'Changtu', 'Changtu', 'Ch''ang-t''u-chen,Ch''ang-tu-chan,Changtu,Changtu Xian,Chantu,Ch’ang-tu-chan,Ch’ang-t’u-chen,chang tu,chang tu xian,Чанту,昌图,昌图县', 42.7788400, 124.0954500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22854, 'Changting', 'Changting', 'Ch''ang-t''ing-tzu,Changting,Changting Zhen,Ch’ang-t’ing-tzu,zhang ting,zhang ting zhen,长汀,长汀镇', 44.4691100, 128.9184700, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22855, 'Changshaoying', 'Changshaoying', 'Changshaoying,Changshaoying Manzuxiang,zhang shao ying,zhang shao ying man zu xiang,长哨营,长哨营满族乡', 40.7938900, 116.7422500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22856, 'Changshan', 'Changshan', 'Changshan,Changshan Xiang,zhang shan,zhang shan xiang,长山,长山乡', 47.7671000, 123.5420400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22857, 'Changping', 'Changping', 'Ch''ang-p''ing-ch''u,Ch''ang-p''ing-chen,Ch''ang-p''ing-hsien,Changping,Chanpin,Ch’ang-p’ing-chen,Ch’ang-p’ing-ch’ü,Ch’ang-p’ing-hsien,chang ping,Чанпин,昌平', 40.2161200, 116.2347100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22858, 'Changling', 'Changling', 'Ch''ang-ling-chen,Ch''ang-ling-hsien,Ch''ang-ling-tzu,Changling,Ch’ang-ling-chen,Ch’ang-ling-hsien,Ch’ang-ling-tzu,zhang ling,长岭', 44.2653200, 124.0004500, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22859, 'Changfa', 'Changfa', 'Changfa,Changfa Zhen,Changfatun,zhang fa,zhang fa zhen,长发,长发镇', 46.7326800, 130.4677100, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22860, 'Changfa', 'Changfa', 'Ch''ang-fa-t''un,Changfa,Changfa Xiang,Ch’ang-fa-t’un,zhang fa,zhang fa xiang,长发,长发乡', 47.5275900, 126.9336300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22861, 'Xichangfa', 'Xichangfa', 'Changfa,Xichangfa,Xichangfa Zhen,xi zhang fa,xi zhang fa zhen,西长发,西长发镇', 46.4234600, 126.6923700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22862, 'Changchun', 'Changchun', 'Ch''ang-ch''un-chen,Chanchun'',Changchun,Changchun Zhen,Ch’ang-ch’un-chen,zhang chun,zhang chun zhen,Чанчунь,长春,长春镇', 47.7318600, 125.6586300, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22863, 'Changchun', 'Changchun', 'CGQ,Cancuna,Cangcun,Cangcunas,Cangcuno,Cangzcenh,Cchang-cchun,Ch''ang-ch''un-hsien,Ch''ang-ch''un-shih,Chanchun,Chanchun'',Changchuen,Changchun,Changchun Shi,Chhong-chhun-su,Chhòng-chhûn-sṳ,Chángchūn,Ch’ang-ch’un-hsien,Ch’ang-ch’un-shih,Csangcsun,Diong-chung,Diòng-chŭng,Gorad Chanchun'',Hsin-chin,Hsin-ching,Hsinking,K''ua-ch''eng-tzu,Kwan-cheng-tze,K’ua-ch’eng-tzu,Tiong-chhun-chhi,Tiông-chhun-chhī,Truong Xuan,Trường Xuân,cangacuna,changachuna,changchun si,changchwn,jangchun,tshanghtshwn,zhang chun,zhang chun shi,Çangçun,Ĉangĉuno,Čangčun,Čangčunas,Čančuņa,Čchang-čchun,Горад Чанчунь,Чангчуен,Чанчун,Чанчунь,Чанчүнь хот,Չանչուն,צאנגצון,تشانغتشون,چانگچون,چاڭچۈن شەھىرى,चांगचून,छांगछुन,ਚਾਂਗਚੁਨ,ചാങ്ചൻ,ချောင်ချွန်းမြို့,長春,長春市,长春,长春市,장춘,창춘 시', 43.8800000, 125.3227800, 'CN', '2017-06-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22864, 'Changbai', 'Changbai', 'Ch''ang-pai-ch''ao-hsien-tsu-tzu-chih-hsien,Ch''ang-pai-chen,Ch''ang-pai-hsien,Chang-pai,Changbai,Changpai-fu,Changpaishan,Ch’ang-pai-chen,Ch’ang-pai-ch’ao-hsien-tsu-tzu-chih-hsien,Ch’ang-pai-hsien,zhang bai,长白', 41.4167300, 128.1905300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22865, 'Chaihe', 'Chaihe', 'Ch''ai-ho,Chaihe,Chaihe Zhen,Ch’ai-ho,chai he,chai he zhen,柴河,柴河镇', 47.5554100, 121.3060400, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22866, 'Chaihe', 'Chaihe', 'Ch''ai-ho,Chaihe,Chaihe Zhen,Ch’ai-ho,chai he,chai he zhen,柴河,柴河镇', 44.7598000, 129.6782600, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22867, 'Chaigoubu', 'Chaigoubu', 'Ch''ai-kou-p''u,Ch''ai-kou-pao,Chaigoubu,Ch’ai-kou-pao,Ch’ai-kou-p’u,Huai''an,Huai’an,chai gou bao,柴沟堡', 40.6677800, 114.4113900, 'CN', '2015-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22868, 'Chahayang', 'Chahayang', 'Chahayang,Chahayang Xiang,cha ha yang,cha ha yang xiang,查哈阳,查哈阳乡', 48.4234300, 124.2920000, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22869, 'Chagou', 'Chagou', 'Ch''a-kou,Chagou,Chagou Zhen,Ch’a-kou,Pa-ch''a-kou,Pa-ch’a-kou,cha gou,cha gou zhen,岔沟,岔沟镇', 40.6168000, 122.8609100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22870, 'Caohekou', 'Caohekou', 'Caohekou,Caohekou Zhen,Ts''ao-ho-k''ou,Ts’ao-ho-k’ou,cao he kou,cao he kou zhen,草河口,草河口镇', 40.8789500, 123.9038200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22871, 'Cangshan', 'Cangshan', 'Cangshan,Cangshan Zhen,Ts''ang-shan,Ts’ang-shan,cang shan,cang shan zhen,苍山,苍山镇', 51.7880400, 123.5922700, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22872, 'Caiyuan', 'Caiyuan', 'Caiyuan,Caiyuan Zhen,Ts''ai-yuan,Ts’ai-yüan,cai yuan,cai yuan zhen,财源,财源镇', 41.3375100, 125.7129700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22873, 'Burgastai', 'Burgastai', 'Baorige Sitai,Baorige Sitai Sumu,Burgastai,bao ri ge si tai,bao ri ge si tai su mu,宝日格斯台,宝日格斯台苏木', 45.1247200, 118.9736100, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22874, 'Bulaotun', 'Bulaotun', 'Bulaotun,Bulaotun Zhen,Pu-lao-t''un,Pu-lao-t’un,bu lao tun,bu lao tun zhen,不老屯,不老屯镇', 40.5668900, 116.9741200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22875, 'Budayuan', 'Budayuan', 'Budayuan,Budayuan Zhen,Pu-ta-yuan,Pu-ta-yuan-erh,Pu-ta-yüan,Pu-ta-yüan-erh,bu da yuan,bu da yuan zhen,步达远,步达远镇', 40.9339600, 125.3333000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22876, 'Borong', 'Borong', 'Borong,Borong Xiang,bo rong,bo rong xiang,博荣,博荣乡', 48.3946800, 124.4938800, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22877, 'Bor Ondor', 'Bor Ondor', 'Baolawendu,Baolawendu Mengguzu Xiang,Bor Ondor,Mi-tzu-huang,Mizihuang,bao la wen dou,bao la wen dou meng gu zu xiang,包拉温都,包拉温都蒙古族乡', 44.2666700, 122.4000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22878, 'Boluopu', 'Boluopu', 'Boluopu,Boluopu Zhen,Po-lo-p''u,Po-lo-pao,Po-lo-p’u,bo luo pu,bo luo pu zhen,博洛铺,博洛铺镇', 40.5290000, 122.4593300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22879, 'Boli', 'Boli', 'Boli,Boli Xian,P''o-li,P''o-li-chen,P''o-li-hsien,P’o-li,P’o-li-chen,P’o-li-hsien,bo li,bo li xian,Боли,勃利,勃利县', 45.7527900, 130.5721100, 'CN', '2014-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22880, 'Bohai', 'Bohai', 'Bohai,Bohai Zhen,bo hai,bo hai zhen,渤海,渤海镇', 44.1166700, 129.1500000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22881, 'Bizhou', 'Bizhou', 'Bichzhou,Bizhou,Bizhou Zhen,Pi-chou,bi zhou,bi zhou zhen,Бичжоу,碧州,碧州镇', 51.9432900, 124.5969800, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22882, 'Bishui', 'Bishui', 'Bishui,Bishui Zhen,Bishuj,Pi-shui,bi shui,bi shui zhen,Бишуй,碧水,碧水镇', 52.1245900, 123.6684200, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22883, 'Binzhou', 'Binzhou', 'Bin Xian,Binsyan,Binxian,Binzhou,Pin,Pin-chou,Pin-chou-chen,Pin-chow,Pin-hsien,Pintschou,Wei-tzu-kou,bin xian,bin zhou,bin zhou zhen,宾县,宾州,宾州镇', 45.7528100, 127.4798600, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22884, 'Binxi', 'Binxi', 'Binxi,Binxi Zhen,Pin-hsi,bin xi,bin xi zhen,宾西,宾西镇', 45.7487000, 127.1562800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22885, 'Bin’an', 'Bin''an', 'Bin''an,Bin''an Zhen,Bin’an,Bin’an Zhen,Pin-an,bin an,bin an zhen,宾安,宾安镇', 45.8415600, 127.7608200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22886, 'Benxi', 'Benxi', 'Ban Khe,Behn''si,Ben''si,Bensi,Benxi,Bunsi,Bản Khê,Pen Shi,Pen-ch''i,Pen-ch''i-hsien,Pen-ch''i-hu,Pen-ch''i-shih,Pen-ch’i,Pen-ch’i-hsien,Pen-ch’i-hu,Pen-ch’i-shih,Pen-hsi,Pen-hsi-shih,Pen-si,Penki,Penkihu,Pun-khe-chhi,Pún-khe-chhī,ben xi,ben xi shi,beonsi si,bnshy,bnsy,bynshy,Бенси,Беньсі,Бънси,Бэньси,Բենսի,בנשי,بنشی,بینشی,本渓,本渓市,本溪,本溪市,번시 시', 41.2886100, 123.7650000, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22887, 'Beizhuang', 'Beizhuang', 'Beizhuang,Beizhuang Zhen,Pei-chuang,bei zhuang,bei zhuang zhen,北庄,北庄镇', 40.5075200, 117.1682100, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22888, 'Beiyinhe', 'Beiyinhe', 'Beiyinhe,Beiyinhe Zhen,Pei-yin-ho,Pei-ying-ho,bei yin he,bei yin he zhen,北荫河,背荫河镇', 45.1666700, 127.0000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22889, 'Beixiaoying', 'Beixiaoying', 'Beixiaoying,Beixiaoying Zhen,bei xiao ying,bei xiao ying zhen,北小营,北小营镇', 40.1979100, 116.7199700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22890, 'Beiwu', 'Beiwu', 'Beiwu,Beiwu Zhen,bei wu,bei wu zhen,北务,北务镇', 40.0575600, 116.8210200, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22891, 'Beisijia', 'Beisijia', 'Beisijia,Beisijia Xiang,bei si jia,bei si jia xiang,北四家,北四家乡', 42.1458100, 120.6786100, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22892, 'Beishicao', 'Beishicao', 'Beishicao,Beishicao Zhen,bei shi cao,bei shi cao zhen,北石槽,北石槽镇', 40.2480400, 116.5243300, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22893, 'Beiqijia', 'Beiqijia', 'Beiqijia,Beiqijia Zhen,bei qi jia,bei qi jia zhen,北七家,北七家镇', 40.1171800, 116.4171500, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22894, 'Beipiao', 'Beipiao', 'Beipiao,Pehpiao,Pei-p''iao,Pei-p''iao-chen,Pei-p''iao-hsien,Pei-p’iao,Pei-p’iao-chen,Pei-p’iao-hsien', 41.7919400, 120.7791700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22895, 'Liucun', 'Liucun', 'Liucun,Liucun Zhen,liu cun,liu cun zhen,流村,流村镇', 40.1696500, 116.0613800, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22896, 'Beijiazao', 'Beijiazao', 'Beijiazao,Hsin-chia-tsao,Pei-chia-tsao', 40.0533300, 113.4691700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22897, 'Beigang', 'Beigang', 'Beigang,Beigang Zhen,T''ou-tao-la-tzu-ho,T''ou-tao-lei-tzu-ho,T’ou-tao-la-tzu-ho,T’ou-tao-lei-tzu-ho,bei gang,bei gang zhen,北岗,北岗镇', 42.4197200, 127.5344400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22898, 'Bei’an', 'Bei''an', 'Bei''an,Bei’an,Lungchen,Pehanchen,Pei-an,Pei-an-chen,Pei-an-hsien,Pei-an-shih', 48.2666700, 126.6000000, 'CN', '2013-05-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22899, 'Bayart Huxu', 'Bayart Huxu', 'Baya''er Tuhushuo,Baya''er Tuhushuo Zhen,Bayart Huxu,Baya’er Tuhushuo,Baya’er Tuhushuo Zhen,ba ya er tu hu shuo,ba ya er tu hu shuo zhen,巴雅尔吐胡硕,巴雅尔吐胡硕镇', 45.1000000, 120.3500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22900, 'Bayan Tug', 'Bayan Tug', 'Bayan Tug,Bayantuga,Bayantuga Sumu,ba yan tu ga,ba yan tu ga su mu,巴彦图嘎,巴彦图嘎苏木', 44.9166700, 114.6500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22901, 'Bayan Tuohai', 'Bayan Tuohai', 'Bayan Tohoi,Bayan Tuohai,Bayan Tuohai Zhen,Ewenkizu Zizhiqi,Han-t''un,Han-t’un,Na-yin-t''un,Na-yin-t’un,Nai-t''un,Nai-t''ung,Nai-t’un,Nai-t’ung,Naintun,Nan''tun'',Nan-t''un,Nan-t’un,Nayntun,Naytun,O-wen-k''o-tsu-tzu-chih-ch''i,O-wen-k’o-tsu-tzu-chih-ch’i,So-lun-ch''i,So-lun-ch’i,Solon,ba yan tuo hai,ba yan tuo hai zhen,e wen ke zu zi zhi qi,Наньтунь,巴彦托海,巴彦托海镇,鄂温克族自治旗', 49.1333300, 119.7333300, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22902, 'Bayan Tal', 'Bayan Tal', 'Bayan Tal,Bayantala,Bayantala Sumu,Pai-yin-t''a-la,Pai-yin-t’a-la,ba yan ta la,ba yan ta la su mu,巴彦塔拉,巴彦塔拉苏木', 44.4000000, 120.4500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22903, 'Bayan Qagan', 'Bayan Qagan', 'Bayan Chagan,Bayan Chagan Xiang,Bayan Qagan,Pai-yin-ch''a-kan,Pai-yin-ch’a-kan,ba yan cha gan,ba yan cha gan xiang,巴彦查干,巴彦查干乡', 46.3385400, 124.0453900, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22904, 'Baiyin Chagan', 'Baiyin Chagan', 'Baiyin Chagan,Baiyin Chagan Zhen,Bayan Qagan,Ch''a-ha-erh-yu-i-hou-ch''i,Ch''a-yu-hou-ch''i,Chaha''ershi Yihou Qi,Chaha’ershi Yihou Qi,Ch’a-ha-erh-yu-i-hou-ch’i,Ch’a-yu-hou-ch’i,Pai-yin-ch''a-kan,Pai-yin-ch’a-kan,Qahar Youyi Houqi,bai yin cha gan,bai yin cha gan zhen,cha ha er shi yi hou qi,察哈尔石翼后旗,白音岔干,白音岔干镇', 41.4533300, 113.1833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22905, 'Bayan Huxu', 'Bayan Huxu', 'Bayan Huxu,Bayanhushu,Bayanhushu Zhen,Horqin Youyi Zhongqi,K''o-erh-ch''in-yu-i-chung-ch''i,Ke''erqinyouyiqian Qi,Ke’erqinyouyiqian Qi,K’o-erh-ch’in-yu-i-chung-ch’i,Pai-yun-hu-shih,Pai-yün-hu-shih,ba yan hu shu,ba yan hu shu zhen,bai yin hu shuo,ke er qin you yi zhong qi,巴彦呼舒,巴彦呼舒镇,白音胡硕,科尔沁右翼中旗', 45.1500000, 121.4000000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22906, 'Bayan Huxu', 'Bayan Huxu', 'Bayan Hushu,Bayan Hushu Sumu,Bayan Huxu,Pa-yen-hu-shu,ba yan hu shu,ba yan hu shu su mu,巴彦胡舒,巴彦胡舒苏木', 44.8833300, 117.4833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22907, 'Bayan Hure', 'Bayan Hure', 'Barga,Bayan Hure,Bayankuren,Bayankuren Zhen,Ch''en-pa-erh-hu-ch''i,Chen Barag Qi,Chenba''erhu Qi,Chenba’erhu Qi,Ch’en-pa-erh-hu-ch’i,Pa-yen-k''u-jen,Pa-yen-k’u-jen,ba yan ku ren,ba yan ku ren zhen,chen ba er hu qi,巴彦库仁,巴彦库仁镇,陈巴尔虎旗', 49.5000000, 119.5166700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22908, 'Bayan Gol', 'Bayan Gol', 'Bayan Gaole,Bayan Gaole Zhen,Bayan Gol,Pa-yen-kao-le,ba yan gao lei,ba yan gao lei zhen,巴彦高勒,巴彦高勒镇', 46.5666700, 122.4833300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22909, 'Bayan Gol', 'Bayan Gol', 'Bayan Gol,Bayangaole,Bayangaole Zhen,Dengkou,Dengkou Xian,Pa-yen-kao-le,Pa-yen-kao-le-chen,Pa-yen-kao-lo,Pa-yen-kao-lo-chen,Pa-yen-kao-lo-shih,San''shengun,San-sheng-kung,San-tao-ho,Santokho,San’shengun,Teng-k''ou,Teng-k''ou-hsien,Teng-k’ou,Teng-k’ou-hsien,ba yan gao lei,ba yan gao lei zhen,deng kou xian,巴彦高勒,巴彦高勒镇,磴口县', 40.3000000, 106.9833300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22910, 'Bayangang', 'Bayangang', 'Bayangang,Bayangang Zhen,ba yan gang,ba yan gang zhen,巴彦港,巴彦港镇', 46.0430900, 127.5414400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22911, 'Bayan Bulag', 'Bayan Bulag', 'Bayan Baolage,Bayan Baolage Sumu,Bayan Bulag,Pa-yen-pao-li-ko,ba yan bao la ge,ba yan bao la ge su mu,巴彦宝拉格,巴彦宝拉格苏木', 44.2333300, 115.9500000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22912, 'Bayan', 'Bayan', 'Bajan,Bayan,Bayan Xian,Bayan Zhen,Pa Jen,Pa-yen-chen,Pa-yen-hsien,Pa-yen-su,Pa-yen-su-su,Payen,ba yan,ba yan xian,ba yan zhen,Баян,巴彦,巴彦县,巴彦镇', 46.0755600, 127.3984000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22913, 'Baoxing', 'Baoxing', 'Baoxing,Baoxing Xiang,bao xing,bao xing xiang,保兴,保兴乡', 48.6161900, 130.5130800, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22914, 'Baotou', 'Baotou', 'BAV,Bao GJau,Bao Đầu,Baotou,Baotou Shi,Baotou shaary,Bau-tau,Bautouo,Baŭtoŭo,Bugat khot,Bău-tàu,Pao-t''ou,Pao-t''ou-hsien,Pao-t''ou-shih,Pao-tchou,Pao-tow,Pao-t’ou,Pao-t’ou-hsien,Pao-t’ou-shih,Paotou,Pau-thau-chhi,Pau-theu-su,Pau-thâu-chhī,Pâu-thèu-sṳ,ba''otu,bao tou,bao tou shi,baoteou si,baywtw,Баотоу,Баотоу шаары,Бугат хот,Բաոտոու,بائوتو,باۋتۇ شەھىر,ਬਾਓਟੂ,包头市,包頭,包頭市,바오터우 시', 40.6522200, 109.8222200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22915, 'Baoshi', 'Baoshi', 'Baoshi,Baoshi Zhen,Baoshitun,bao shi,bao shi zhen,宝石,宝石镇', 45.8166700, 121.1666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22916, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Zhen,Baoshansi,Pao-shan-ssu,bao shan,bao shan si,bao shan zhen,宝山,宝山寺,宝山镇', 40.6949100, 116.5621700, 'CN', '2012-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22917, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Xiang,Baoshan'',bao shan,bao shan xiang,Баошань,宝山,宝山乡', 48.1281200, 123.9455400, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22918, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan'',Pao-shan,Баошань', 46.5586100, 131.4244400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22919, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Zhen,bao shan,bao shan zhen,宝山,宝山镇', 40.3638400, 123.8615000, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22920, 'Baoqing', 'Baoqing', 'Baocin,Baoqing,Baotsin,Pao-ch''ing,Pao-ch''ing-chen,Pao-ch''ing-hsien,Pao-ch’ing,Pao-ch’ing-chen,Pao-ch’ing-hsien,Paotsing,Баоцин', 46.3316700, 132.2111100, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22921, 'Baomin', 'Baomin', 'Baomin,Baomin Xiang,bao min,bao min xiang,保民,保民乡', 46.2348700, 123.2775000, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22922, 'Baokang', 'Baokang', 'Baokang,Baokang Zhen,Horqin Zuoyi Zhongqi,K''o-erh-ch''in-tso-chung-ch''i,K''o-erh-ch''in-tso-i-chung-ch''i,K''o-tso-chung-ch''i,Ke''erqinzuoyizhong Qi,Kezuo Zhongqi,Ke’erqinzuoyizhong Qi,K’o-erh-ch’in-tso-chung-ch’i,K’o-erh-ch’in-tso-i-chung-ch’i,K’o-tso-chung-ch’i,Pao-k''ang,Pao-k’ang,bao kang,bao kang zhen,ke er qin zuo yi zhong qi,ke zuo zhong qi,保康,保康镇,科尔沁左翼中旗,科左中旗', 44.1197200, 123.3047200, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22923, 'Baochang', 'Baochang', 'Baochang,Baochang Zhen,Koting,Pao-ch''ang,Pao-ch''ang-chen,Pao-ch''ang-hsien,Pao-ch’ang,Pao-ch’ang-chen,Pao-ch’ang-hsien,T''ai-p''u-ssu-ch''i,Taibusi Qi,Taipusi Qi,T’ai-p’u-ssu-ch’i,bao chang,bao chang zhen,tai pu si qi,太仆寺旗,宝昌,宝昌镇', 41.8844400, 115.2788900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22924, 'Banshi', 'Banshi', 'Banshi,Banshi Zhen,Pan-shih,Pan-shih-kou-t''un,Pan-shih-kou-t’un,Pan-shin,ban shi,ban shi zhen,板石,板石镇', 42.7783300, 130.3383300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22925, 'Bamiantong', 'Bamiantong', 'Bamiantong,Mu-leng,Mu-leng-hsien,Muleng Shi,Muling,Pa-mien-t''ung,Pa-mien-t''ung-chen,Pa-mien-t’ung,Pa-mien-t’ung-chen,ba mian tong,mu leng shi,八面通,穆棱市', 44.9173800, 130.5200000, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22926, 'Bamiancheng', 'Bamiancheng', 'Bamiancheng,Bamiancheng Zhen,Pa-mien-ch''eng,Pa-mien-ch’eng,ba mian cheng,ba mian cheng zhen,八面城,八面城镇', 43.1972700, 124.0492400, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22927, 'Balin', 'Balin', 'Balin,Balin Zhen,Balin'',Barim,Pa-li-mu,Pa-lin,Pa-lin-mu,Palim,ba lin,ba lin zhen,Балинь,巴林,巴林镇', 48.3099700, 122.3259100, 'CN', '2013-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22928, 'Balidianzi', 'Balidianzi', 'Balidianzi,Balidianzi Zhen,Pa-li-tien-tzu,ba li dian zi,ba li dian zi zhen,八里甸子,八里甸子镇', 41.2396800, 124.8902600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22929, 'Baliang', 'Baliang', 'Baliang,Da''erfenzi,Da’erfenzi,ba liang,da er fen zi,坝梁,大二分子', 41.0913100, 109.7593000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22930, 'Bali', 'Bali', 'Bali,Bali Zhen,Pa-li-ho,ba li,ba li zhen,八里,八里镇', 40.7885700, 122.7545100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22931, 'Bajiazi', 'Bajiazi', 'Bajiazi,Bajiazi Zhen,Pa-chia-tzu,Shangnan,ba jia zi,ba jia zi zhen,八家子,八家子镇', 42.6659500, 129.1138900, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22932, 'Baiyinna', 'Baiyinna', 'Baiyinna,Baiyinna Elunchunzu Xiang,Baiyinna Orogenzu Xiang,Bajin''na,Pai-yin-na,bai yin na,bai yin na e lun chun zu xiang,Байиньна,白银纳,白银纳鄂伦春族乡', 52.4114800, 125.9009200, 'CN', '2013-03-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22933, 'Baishuitan', 'Baishuitan', 'Baishuitan,Yanjiang Xiang,bai shui tan,yan jiang xiang,沿江乡,白水滩', 42.7594600, 127.8006100, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22934, 'Baishishan', 'Baishishan', 'Baishishan,Pai-shih-shan', 43.5833300, 127.5666700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22935, 'Baishan', 'Baishan', 'Baishan,Baishan Xiang,bai shan,bai shan xiang,白山,白山乡', 47.2676600, 123.2434800, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22936, 'Baishan', 'Baishan', 'Baishan,Baishan Zhen,Baishanzhen,Pai-shan,bai shan,bai shan zhen,白山,白山镇', 42.7337600, 127.2343700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22937, 'Baiquan', 'Baiquan', 'Baiquan,Baiquan Xian,Baiquan Zhen,Pai-ch''uan,Pai-ch''uan-chen,Pai-ch''uan-hsien,Pai-ch’üan,Pai-ch’üan-chen,Pai-ch’üan-hsien,Ta-p''ao-tzu,Ta-p’ao-tzu,bai quan,bai quan xian,bai quan zhen,拜泉,拜泉县,拜泉镇', 47.6060500, 126.0848100, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22938, 'Baiquan', 'Baiquan', 'Baiquan,Pai-ch''uan,Pai-ch’üan,bai quan,白泉', 42.8853800, 124.9582700, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22939, 'Bailingnao', 'Bailingnao', 'Bailingnao,bai ling nao,百灵淖', 41.2891000, 110.2242300, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22940, 'Bailingmiao', 'Bailingmiao', 'Bail Miao,Bailingmiao,Bata Khalga,Batu Halga Sume,Baylinmyao,Darhan Muminggan Lianheqi,Darhan Qi,Pai-lin,Pai-lin-miao,Pai-ling-miao,Pei-lo-miao,Polingmiao,So-ha-lun-k''u-lieh Miao,So-ha-lun-k’u-lieh Miao,Ta-erh-han-mao-ming-an-ch''i,Ta-erh-han-mao-ming-an-ch’i,Ta-erh-han-mao-ming-an-lien-ho-ch''i,Ta-erh-han-mao-ming-an-lien-ho-ch’i,Ta-mao-lien-ho-ch''i,Ta-mao-lien-ho-ch’i,bai ling miao,da er han mao ming an lian he qi,da er han qi,百灵庙,达尔罕旗,达尔罕茂明安联合旗', 41.6919400, 110.4355600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22941, 'Baikui', 'Baikui', 'Baikui,Baikui Zhen,Pai-k''uei-p''u,Pai-k’uei-p’u,bai kui,bai kui zhen,白奎,白奎镇', 46.3643200, 126.9963600, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22942, 'Baicheng', 'Baicheng', 'Bach Thanh,Bah-siang,Baicheng,Baicheng Shi,Bajchehn,Bajchen,Bajcheng,Băh-siàng,Bạch Thành,DBC,Pai-ch''eng,Pai-ch''eng-shih,Pai-ch''eng-tzu,Pai-ch’eng,Pai-ch’eng-shih,Pai-ch’eng-tzu,Paichengtze,Paj-ccheng,Paj-čcheng,Pe̍k-siâⁿ-chhī,T''ao-an,T''ao-an-hsien,T''ao-yen,T’ao-an,T’ao-an-hsien,T’ao-yen,bai cheng,bai cheng shi,baicheong si,baychng,baychyng,Байчен,Байчэн,Бајченг,بائچینگ,بایچنگ,白城,白城市,바이청 시', 45.6074600, 122.8207600, 'CN', '2016-03-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22943, 'Baicaogou', 'Baicaogou', 'Baicaogou,Baicaogou Zhen,Hsiao-pai-ts''ao-kou,Hsiao-pai-ts’ao-kou,Pai-ts''ao-kou,Pai-ts’ao-kou,Potsaokou,Wang-ch''ing-hsien,Wang-ch’ing-hsien,bai cao gou,bai cao gou zhen,百草沟,百草沟镇', 43.2654300, 129.6027200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22944, 'Xiqu', 'Xiqu', 'Bahechuan,Pa-ho-ch''uan,Pa-ho-ch’uan,Xiqu,xi qu,西区', 26.6056600, 101.5982800, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22945, 'Baishan', 'Baishan', 'Bach Son,Badaojiang,Bah-sang,Baishan,Baishan Shi,Bajshan'',Băh-săng,Bạch Sơn,Hun-chiang,Hun-chiang-shih,Hunjiang,NBS,Pa-tao-chiang,Pa-tao-kou,Paj-san,Paj-šan,Pek-san-chhi,Pe̍k-san-chhī,ba dao jiang,bai shan,bai shan shi,baisan si,bayshan,Байшань,بائشان,بایشان,八道江,白山,白山市,바이산 시', 41.9385300, 126.4196500, 'CN', '2017-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22946, 'Badaogou', 'Badaogou', 'Badaogou,Badaogou Zhen,ba dao gou,ba dao gou zhen,八道沟,八道沟镇', 41.5172600, 127.2646600, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22947, 'Badai', 'Badai', 'Badai,Badai Xiang,ba dai,ba dai xiang,巴岱,巴岱乡', 46.6446800, 123.1657700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22948, 'Wenquan', 'Wenquan', 'A''ershan Shi,A-erh-shan,A-erh-shan-k''uang-ch''uan,A-erh-shan-k''uang-shui-yuan,A-erh-shan-k’uang-ch’üan,A-erh-shan-k’uang-shui-yüan,A-erh-shan-wen-ch''uan,A-erh-shan-wen-ch’üan,Arshan,Arxan,Arxan Shi,A’ershan Shi,Khalin-Arshan,Khalun-Arshan,Ven''tsyuan'',Ven’tsyuan’,Wen-ch''uan,Wen-ch’üan,Wenquan,Wenquan Jiedao,a er shan,a er shan shi,wen quan,wen quan jie dao,温泉,温泉街道,阿尔山,阿尔山市', 47.1833300, 119.9666700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22949, 'Aoluguya Ewenke Minzu', 'Aoluguya Ewenke Minzu', 'Aolugua,Aoluguya,Aoluguya Ewenke Minzu,Aoluguya Ewenke Minzu Xiang,ao lu gu ya,ao lu gu ya e wen ke min zu,ao lu gu ya e wen ke min zu xiang,Аолугуа,敖鲁古雅,敖鲁古雅鄂温克民族,敖鲁古雅鄂温克民族乡', 52.1759600, 122.0790300, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22950, 'Aojiabao', 'Aojiabao', 'Ao-chia-p''u,Ao-chia-pao-tzu,Ao-chia-p’u,Aojiabao,Aojiabao Xiang,ao jia bao,ao jia bao xiang,敖家堡,敖家堡乡', 41.9110600, 124.7773300, 'CN', '2012-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22951, 'Anshan', 'Anshan', 'Anshan,Anshan Zhen,an shan,an shan zhen,安山,安山镇', 45.5116200, 128.5196300, 'CN', '2013-05-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22952, 'Anshan', 'Anshan', 'AOG,An Son,An Sơn,An''shan'',An-san,An-san-chhi,An-san-chhī,An-shan-shih,An-šan,Ang-sang,Ansanas,Ansano,Anshan,Anshan Shi,Ansjan,Anxan,Anŝano,Anšanas,an shan,an shan shi,anasana,ansan si,anshan,Ăng-săng,Аншан,Аньшань,אנשאן,آنشان,ئەنشەن شەھىرى,انشان,ਅਨਸ਼ਾਨ,鞍山,鞍山市,안산 시', 41.1236100, 122.9900000, 'CN', '2013-12-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22953, 'Anjia', 'Anjia', 'An-chia,Anjia,Anjia Zhen,an jia,an jia zhen,安家,安家镇', 45.0510900, 127.0675200, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22954, 'Xinxing', 'Xinxing', 'Ang''angxi,Ang''angxi Qu,Ang-ang-hsi,Ang’angxi,Ang’angxi Qu,Xinxing,Xinxing Jiedao,ang ang xi,ang ang xi qu,xin xing,xin xing jie dao,新兴,新兴街道,昂昂溪,昂昂溪区', 47.1546700, 123.8098700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22955, 'Anding', 'Anding', 'An-ting,Anding,Anding Zhen,Chang-chia-wo-p''u,Chang-chia-wo-p’u,Zhangjiawopu,an ding,an ding zhen,安定,安定镇', 45.1666700, 122.6000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22956, 'Anda', 'Anda', 'An-ta,An-ta-chan,An-ta-chen,An-ta-hsien,An-ta-shih,Anda,Anda Shi,Anda Zhen,an da,an da shi,an da zhen,Анда,安达,安达市,安达镇', 46.4020200, 125.3145400, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22957, 'Amgalang', 'Amgalang', 'A-mu-chan-lang,A-mu-k''o-lang,A-mu-ku-lang,A-mu-ku-liang,A-mu-k’o-lang,Amgalan,Amgalang,Amgolan,Amu Gulang,Amugulang Zhen,Amuguro,East New Barga,Hsin-pa-erh-hu-tso-ch''i,Hsin-pa-erh-hu-tso-ch’i,Hsin-pa-erh-hu-tso-i-ch''i,Hsin-pa-erh-hu-tso-i-ch’i,Tung-hsin-pa-ch''i,Tung-hsin-pa-ch’i,Xin Barag Zuoqi,Xinba Erhu Zuoqi,a mu gu lang,a mu gu lang zhen,xin ba er hu zuo qi,Амгалан,新巴尔虎左旗,阿木古郎,阿木古郎镇,阿穆古郎', 48.2500000, 118.2000000, 'CN', '2014-06-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22958, 'Altan Hil', 'Altan Hil', 'Alatan Heli,Alatan Heli Sumu,Altan Hil,a la tan he li,a la tan he li su mu,阿拉坦合力,阿拉坦合力苏木', 45.2000000, 115.5000000, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22959, 'Alongshan', 'Alongshan', 'A-lung-shan,Alongshan,Alongshan Zhen,a long shan,a long shan zhen,阿龙山,阿龙山镇', 51.6979100, 121.8660400, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22960, 'Oroqen Zizhiqi', 'Oroqen Zizhiqi', 'A-li,A-li-ho,Alihe,Alihe Zhen,Alikheh,Ari,Elunchun Zizhiqi,O-lun-ch''un-tsu-tzu-chih-ch''i,O-lun-ch''un-tzu-chih-ch''i,O-lun-ch’un-tsu-tzu-chih-ch’i,O-lun-ch’un-tzu-chih-ch’i,Oroqen Zizhiqi,a li he,a li he zhen,e lun chun zi zhi qi,Алихэ,鄂伦春自治旗,阿里河,阿里河镇', 50.5666700, 123.7166700, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22961, 'Aihui', 'Aihui', 'Ai-hui-hsiang,Ai-hui-ts''un,Ai-hui-ts’un,Ai-hun,Ai-hun-ts''un,Ai-hun-ts’un,Ai-kun,Aigun,Aihui,Aihui Zhen,Aygun'',Aygun’,Chiu-ai-hun,ai hui,ai hui zhen,爱辉,爱辉镇', 49.9794600, 127.4811900, 'CN', '2013-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22962, 'Aguitu', 'Aguitu', 'A-kuei-t''u,A-kuei-t’u,Aguit,Aguitu,Wangbing Cun,a gui tu,wang bing cun,王丙村,阿贵图', 41.7745100, 113.1388700, 'CN', '2013-06-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22963, 'Adun Chulu', 'Adun Chulu', 'A-tun-ch''u-lu,A-tun-ch’u-lu,Adun Chulu,Adun Chulu Sumu,Adun Qulu,a dui chu lu,a dui chu lu su mu,阿敦楚鲁,阿敦楚鲁苏木', 48.4432300, 116.1841800, 'CN', '2013-01-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22964, 'Acheng', 'Acheng', 'A-ch''eng-chen,A-ch''eng-hsien,A-ch’eng-chen,A-ch’eng-hsien,A-shih-ho,A-shih-ko,Acheng,Acheng Shi,Akheng,Asche-ho,Ashiho,a cheng,a cheng shi,Ахенг,阿城,阿城市', 45.5454500, 126.9770300, 'CN', '2012-01-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22965, 'Shisidaogou', 'Shisidaogou', 'Shih-ssu-tao-kou,Shisidaogou,Shisidaogou Zhen,shi si dao gou,shi si dao gou zhen,十四道沟,十四道沟镇', 41.4516700, 127.9216700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22966, 'Jinhua', 'Jinhua', 'Banqiegou,Barjiegou,Jinhua,Jinhua Xiang,Pan-chieh-kou,jin hua,jin hua xiang,金华,金华乡', 41.4277800, 128.0275000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22967, 'Zhalong', 'Zhalong', 'Cha-lung-t''un,Cha-lung-t’un,Zhalong,Zhalong Xiang,zha long,zha long xiang,扎龙,扎龙乡', 47.2118900, 124.2009700, 'CN', '2013-04-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22968, 'Shisandaogou', 'Shisandaogou', 'Shih-san-tao-kou,Shisandaogou,Shisandaogou Xiang,shi san dao gou,shi san dao gou xiang,十三道沟,十三道沟乡', 41.4291700, 127.7786100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22969, 'Changgang', 'Changgang', 'Ch''ang-kang-tzu,Changgang,Changgang Xiang,Ch’ang-kang-tzu,zhang gang,zhang gang xiang,长岗,长岗乡', 46.3451500, 126.4325900, 'CN', '2013-04-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22970, 'Shiren', 'Shiren', 'Shih-jen-ch''eng,Shih-jen-ch’eng,Shiren,Shiren Zhen,Shirencheng,shi ren,shi ren zhen,石人,石人镇', 46.2926400, 126.8909300, 'CN', '2013-04-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22971, 'Xiaoshahe', 'Xiaoshahe', 'Heng-tao-tzu,Xiaoshahe,Xiaoshahe Xiang,xiao sha he,xiao sha he xiang,小沙河,小沙河乡', 42.6394400, 128.2936100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22972, 'Donglai', 'Donglai', 'Donglai,Donglai Xiang,dong lai,dong lai xiang,东来,东来乡', 41.6523400, 126.1444900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22973, 'Songling', 'Songling', 'Songling,Sung-ling,song ling,松岭', 40.2930300, 118.2690800, 'CN', '2015-02-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22974, 'Oukenhe', 'Oukenhe', 'Oukehn''kheh,Oukenhe,Oukenhe Zhen,ou ken he,ou ken he zhen,Оукэньхэ,欧垦河,欧垦河镇', 49.7906600, 124.8013800, 'CN', '2013-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22975, 'Bayan Ewenke Minzu', 'Bayan Ewenke Minzu', 'Bayan Ewenke Minzu,Bayan Ewenke Minzu Xiang,Man-tu-hu-ch''ien,Man-tu-hu-ch’ien,ba yan e wen ke min zu,ba yan e wen ke min zu xiang,巴彦鄂温克民族,巴彦鄂温克民族乡', 49.4622900, 124.7660600, 'CN', '2013-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22976, 'Guangyilong', 'Guangyilong', 'Guangyilong,Guangyilong Xiang,Kuang-i-lung,guang yi long,广益隆', 41.5658300, 112.2815600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22977, 'Sanjinquan', 'Sanjinquan', 'Sanjinquan,Xiaoxi Cun,san jing quan,xiao xi cun,三井泉,小西村', 41.8108700, 112.8340500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22978, 'Teshage', 'Teshage', 'Hsia-t''ieh-sha-kai,Hsia-t’ieh-sha-kai,Tesge,Tesge Xiang,Teshage,Xiashage,te sha gai,xia sha gai,下沙盖,特沙盖', 41.5610600, 112.5678900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22979, 'Benhong', 'Benhong', 'Benhong,Benhong Xiang,Pen-hung,ben hong,贲红', 41.2913000, 113.2440500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22980, 'Hongpan', 'Hongpan', 'Hongpan,Hongpan Xiang,Hung-p''an,Hung-p’an,hong pan,宏盘', 41.4046700, 112.7761100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22981, 'Sandaogou', 'Sandaogou', 'San-tao-kou,Sandaogou,Sandaogou Xiang,san dao gou,san dao gou xiang,三道沟,三道沟乡', 41.3794900, 112.6495100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22982, 'Jinpen', 'Jinpen', 'Chin-p''en,Chin-p’en,Jinpen,jin pen,金盆', 41.0404000, 112.4765900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22983, 'Menggusi', 'Menggusi', 'Meng-ku-ssu,Menggusi,Mongol Us,Mongol Us Xiang,meng gu si,蒙古寺', 41.2745900, 112.0146700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22984, 'Touhao', 'Touhao', 'T''ou-hao,Touhao,Touhao Xiang,T’ou-hao,tou hao,头号', 41.3055500, 112.3136300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22985, 'Dongtucheng', 'Dongtucheng', 'Dongtucheng,Dongtucheng Xiang,Tung-t''u-ch''eng-tzu,Tung-t’u-ch’eng-tzu,dong tu cheng,dong tu cheng xiang,东土城,东土城乡', 41.1185900, 111.2607700, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22986, 'Bayinbaolige', 'Bayinbaolige', 'Bayinbaolige,Bayinbaolige Zhen,Dong Xur Miao,Dongsheng Miao,Tung-shih-erh-miao,Urad Houqi,Wulatehou Qi,ba yin bao li ge,ba yin bao li ge zhen,dong sheng miao,wu la te hou qi,东升庙,乌拉特后旗,巴音宝力格,巴音宝力格镇', 41.0913900, 107.0663900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22987, 'Ulashan', 'Ulashan', 'Erh-ta-lai-tien,T''ieh-tzu-tien,T’ieh-tzu-tien,Ul Shan,Ulashan,Urad Qianqi,Wulashan,Wulashan Zhen,Wulateqian Qi,wu la shan,wu la shan zhen,wu la te qian qi,乌拉山,乌拉山镇,乌拉特前旗', 40.6650000, 108.7447200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22988, 'Gongyimin', 'Gongyimin', 'Gongyimin,Gongyimin Xiang,Hsi-ying-tzu,gong yi min,gong yi min xiang,公益民,公益民 乡', 40.9922000, 110.0434100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22989, 'Halamendu', 'Halamendu', 'Dongyao,Ha-la-men-to,Halamendu,Halamendu Xiang,Har Mod,Har Mod Xiang,dong yao,ha la men du,ha la men du xiang,东窑,哈拉门独,哈拉门独乡', 40.9844400, 110.7211100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22990, 'Tongfosi', 'Tongfosi', 'Tongfosi,Tongfosi Zhen,tong fu si,tong fu si zhen,铜佛寺,铜佛寺镇', 42.8873700, 129.2425700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22991, 'Erdao', 'Erdao', 'Erdao,Erdaogou,Xicheng Zhen,er dao,xi cheng zhen,二道,西城镇', 42.6975600, 129.0931600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22992, 'Ying’an', 'Ying''an', 'Ying''an,Ying''an Zhen,Ying-an-t''un,Ying-an-t’un,Ying’an,Ying’an Zhen,ying an,ying an zhen,英安,英安镇', 42.8900000, 130.2858300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22993, 'Sanjiazi', 'Sanjiazi', 'San-chia-tzu,Sanjiazi,Sanjiazi Manzu Xiang,san jia zi,san jia zi man zu xiang,三家子,三家子满族乡', 42.8400000, 130.3055600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22994, 'Erdaopaozi', 'Erdaopaozi', 'Erdaopaozi,Jingxin Zhen,er dao pao zi,jing xin zhen,二道泡子,敬信镇', 42.6375000, 130.4716700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22995, 'Dashiren', 'Dashiren', 'Dashiren,Dashiren Xiang,Dashiren Zhen,da shi ren,da shi ren zhen,大石人,大石人镇', 41.9335000, 126.5469400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22996, 'Weishahe', 'Weishahe', 'Wei-sha-ho,Weishahe,Weishahe Xiang,Weishahe Zhen,wei sha he,wei sha he zhen,苇沙河,苇沙河镇', 41.7369400, 126.7483300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22997, 'Xiangrong', 'Xiangrong', 'Longtan Zhen,Xiangrong,long tan zhen,xiang rong,相荣,龙潭镇', 40.1405600, 123.1169400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22998, 'Hongwei', 'Hongwei', 'Hongwei,Hongwei Zhen,hong wei,hong wei zhen,宏伟,宏伟镇', 51.9769100, 123.6523300, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(22999, 'Hongtu', 'Hongtu', 'Hongtu,Hongtu Zhen,hong tu,hong tu zhen,宏图,宏图镇', 51.6238900, 124.1475000, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23000, 'Jinsong', 'Jinsong', 'Jinsong,Jinsong Zhen,jin song,jin song zhen,劲松,劲松镇', 51.0714200, 124.1876500, 'CN', '2013-01-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23001, 'Beijiang', 'Beijiang', 'Beijiang,Beijiang Xiang,bei jiang,bei jiang xiang,北疆,北疆乡', 51.0380200, 126.0927800, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23002, 'Sijiazi', 'Sijiazi', 'Sijiazi,Sijiazi Manzu Xiang,si jia zi,si jia zi man zu xiang,四嘉子,四嘉子满族乡', 50.1778800, 127.5118300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23003, 'Xifengshan', 'Xifengshan', 'Xifengshan,Xifengshan Xiang,xi feng shan,xi feng shan xiang,西峰山,西峰山乡', 50.5647000, 126.9653500, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23004, 'Jiulong', 'Jiulong', 'I-lan-kou,Jiulong,Yilan Zhen,jiu long,yi lan zhen,九龙,依兰镇', 43.1068300, 129.5171600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23005, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Zhen,bao shan,bao shan zhen,宝山,宝山镇', 41.6186900, 127.2911100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23006, 'Xinfangzi', 'Xinfangzi', 'Xinfangzi,Xinfangzi Zhen,xin fang zi,xin fang zi zhen,新房子,新房子镇', 41.5551700, 127.3603800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23007, 'Baoquanshan', 'Baoquanshan', 'Baoquanshan,Baoquanshan Zhen,bao quan shan,bao quan shan zhen,宝泉山,宝泉山镇', 41.5141700, 127.4563900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23008, 'Badaling', 'Badaling', 'Badaling,Badaling Zhen,ba da ling,ba da ling zhen,八达岭,八达岭镇', 40.3639700, 115.9851100, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23009, 'Sandaogou', 'Sandaogou', 'Sandaogou,Sandaogou Zhen,san dao gou,san dao gou zhen,三道沟,三道沟镇', 41.6471900, 126.5114700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23010, 'Maxian', 'Maxian', 'Maxian,Maxian Xiang,ma xian,ma xian xiang,麻线,麻线乡', 41.0995500, 126.1527700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23011, 'Haoxinying', 'Haoxinying', 'Haoxinying,Haoxinying Zhen,hao qin ying,hao qin ying zhen,毫沁营,毫沁营镇', 40.8822200, 111.7150000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23012, 'Wuliangtai', 'Wuliangtai', 'Wuliangtai,wu liang tai,五良太', 40.0469400, 111.7822200, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23013, 'Liqiao', 'Liqiao', 'Liqiao,Liqiao Zhen,li qiao,li qiao zhen,李桥,李桥镇', 40.0617500, 116.6327200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23014, 'Huilongguan', 'Huilongguan', 'Huilongguan,Huilongguan Zhen,hui long guan,hui long guan zhen,回龙观,回龙观镇', 40.0771800, 116.3352700, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23015, 'Sujiatuo', 'Sujiatuo', 'Sujiatuo,Sujiatuo Zhen,su jia tuo,su jia tuo zhen,苏家坨,苏家坨镇', 40.0766900, 116.1586000, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23016, 'Cuicun', 'Cuicun', 'Cuicun,Cuicun Zhen,cui cun,cui cun zhen,崔村,崔村镇', 40.2188900, 116.3517400, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23017, 'Changling', 'Changling', 'Changling,Changling Zhen,zhang ling,zhang ling zhen,长陵,长陵镇', 40.2951000, 116.2480600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23018, 'Beifang', 'Beifang', 'Beifang,Beifang Zhen,bei fang,bei fang zhen,北房,北房镇', 40.3240200, 116.6871800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23019, 'Jingzhuang', 'Jingzhuang', 'Jingzhuang,Jingzhuang Zhen,jing zhuang,jing zhuang zhen,井庄,井庄镇', 40.4627400, 116.0913600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23020, 'Shenjiaying', 'Shenjiaying', 'Shenjiaying,Shenjiaying Zhen,chen jia ying,chen jia ying zhen,沈家营,沈家营镇', 40.4859500, 116.0435200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23021, 'Shicheng', 'Shicheng', 'Nanshicheng,Shicheng,Shicheng Zhen,nan shi cheng,shi cheng,shi cheng zhen,南石城,石城,石城镇', 40.5404100, 116.8133200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23022, 'Dahudian', 'Dahudian', 'Dahudian,Dahudian Zhen,da hu dian,da hu dian zhen,达呼店,达呼店镇', 47.5293200, 123.8100900, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23023, 'Jiujianfang', 'Jiujianfang', 'Huanan Xiang,Jiujianfang,hua nan xiang,jiu jian fang,九间房,桦南乡', 42.9645000, 126.8551200, 'CN', '2013-09-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23024, 'Xinxigang', 'Xinxigang', 'Xigang Xiang,Xinxigang,xi gang xiang,xin xi gang,新西岗,西岗乡', 42.0647200, 127.3558300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23025, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Xiang,xing long,xing long xiang,兴隆乡,兴龙', 42.2616700, 127.3861100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23026, 'Songjiao', 'Songjiao', 'Songjiao,Songjiao Xiang,song jiao,song jiao xiang,松郊,松郊乡', 42.3038200, 127.2783200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23027, 'Yushu', 'Yushu', 'Yushu,Yushu Zhen,yu shu,yu shu zhen,榆树,榆树镇', 42.5385600, 127.1663300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23028, 'Zhaoquanhe', 'Zhaoquanhe', 'Zhaoquanhe,Zhaoquanhe Xiang,zhao quan he,zhao quan he xiang,赵圈河,赵圈河乡', 40.9592200, 121.9940500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23029, 'Mashizhai', 'Mashizhai', 'Ertai,Ertai Xiang,Mashizhai,er tai,er tai xiang,ma shi zhai,二台,二台乡,马石寨', 40.0885900, 122.0816100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23030, 'Wangjia', 'Wangjia', 'Wangjia,Wangjia Xiang,wang jia,wang jia xiang,王家,王家乡', 40.9508800, 122.0621500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23031, 'Erjiegou', 'Erjiegou', 'Erjiegou,Erjiegou Zhen,Yushu,er jie gou,er jie gou zhen,yu shu,二界沟,二界沟镇,榆树', 40.8505000, 122.0796800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23032, 'Jiulongdi', 'Jiulongdi', 'Jiulongdi,Jiulongdi Manzu Zhen,Jiulongdi Zhen,jiu long de,jiu long de man zu zhen,jiu long de zhen,九垄地,九垄地满族镇,九垄地镇', 40.1531800, 122.1062600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23033, 'Xilanqi', 'Xilanqi', 'Hongqi Manzu Zhen,Hongqi Zhen,Xilanqi,hong qi man zu zhen,hong qi zhen,xi lan qi,红旗满族镇,红旗镇,西兰旗', 40.2232600, 122.1451500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23034, 'Heping', 'Heping', 'Chentun,Chentun Zhen,Heping,chen tun,chen tun zhen,he ping,和平,陈屯,陈屯镇', 40.1375500, 122.1966900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23035, 'Lutun', 'Lutun', 'Lutun,Lutun Zhen,lu tun,lu tun zhen,芦屯,芦屯镇', 40.2639900, 122.1893600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23036, 'Xi’an', 'Xi''an', 'Xi''an,Xi''an Zhen,Xi’an,Xi’an Zhen,xi an,xi an zhen,西安,西安镇', 40.9226500, 122.2348100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23037, 'Gouyan', 'Gouyan', 'Gouyan,Gouyan Zhen,gou yan,gou yan zhen,沟沿,沟沿镇', 40.8190100, 122.2448300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23038, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Zhen,dong feng,dong feng zhen,东风,东风镇', 40.9748900, 122.2663200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23039, 'Tuanshan', 'Tuanshan', 'Tuanshan,Tuanshan Jiedao,tuan shan,tuan shan jie dao,团山,团山街道', 40.3967600, 122.2830000, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23040, 'Lunan', 'Lunan', 'Lunan,Lunan Zhen,lu nan,lu nan zhen,路南,路南镇', 40.6882000, 122.3008200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23041, 'Jianli', 'Jianli', 'Jianli,Shifo,Shifo Zhen,jian li,shi fu,shi fu zhen,建立,石佛,石佛镇', 40.8765900, 122.3289000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23042, 'Taiyangsheng', 'Taiyangsheng', 'Taiyangsheng,Taiyangsheng Jiedao,tai yang sheng,tai yang sheng jie dao,太阳升,太阳升街道', 40.3704500, 122.3601000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23043, 'Jinqiao', 'Jinqiao', 'Jinqiao,Jinqiao Jiedao,jin qiao,jin qiao jie dao,金桥,金桥街道', 40.6327800, 122.4820400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23044, 'Tuandian', 'Tuandian', 'Tuandian,Tuandian Zhen,tuan dian,tuan dian zhen,团甸,团甸镇', 40.4327400, 122.4671600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23045, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 40.5711400, 122.4919800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23046, 'Nuanquan', 'Nuanquan', 'Nuanquan,Nuanquan Zhen,nuan quan,nuan quan zhen,暖泉,暖泉镇', 40.3817500, 122.5031500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23047, 'Zhongxiao', 'Zhongxiao', 'Zhongxiao,Zhongxiao Zhen,zhong xiao,zhong xiao zhen,中小,中小镇', 40.8898500, 122.5577600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23048, 'Dongsi', 'Dongsi', 'Dongsi,Dongsi Jiedao,dong si,dong si jie dao,东四,东四街道', 40.8968100, 122.6302200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23049, 'Bangshipu', 'Bangshipu', 'Bangshipu,Bangshipu Zhen,bang shi bao,bang shi bao zhen,榜式堡,榜式堡镇', 40.4151400, 122.6611700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23050, 'Maoqi', 'Maoqi', 'Maoqi,Maoqi Zhen,mao qi,mao qi zhen,毛祁,毛祁镇', 40.7929300, 122.6935100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23051, 'Buyunshan', 'Buyunshan', 'Buyunshan,Buyunshan Xiang,bu yun shan,bu yun shan xiang,步云山,步云山乡', 40.0225800, 122.7049900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23052, 'Weiziyu', 'Weiziyu', 'Weiziyu,Weiziyu Zhen,Xiweiziyu,wei zi yu,wei zi yu zhen,xi wei zi yu,苇子峪,苇子峪镇,西苇子峪', 40.4818800, 122.7269500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23053, 'Xiangtang', 'Xiangtang', 'Xiangtang,Xiangtang Jiedao,xiang tang,xiang tang jie dao,响堂,响堂街道', 40.8327100, 122.7685100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23054, 'Pailou', 'Pailou', 'Pailou,Pailou Zhen,pai lou,pai lou zhen,牌楼,牌楼镇', 40.7329400, 122.8165400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23055, 'Taling', 'Taling', 'Taling,Talingmanzu,Talingmazu Zhen,ta ling,ta ling man zu,ta ling man zu zhen,塔岭,塔岭满族,塔岭满族镇', 40.0517500, 123.1094600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23056, 'Lanqi', 'Lanqi', 'Lanqi,Lanqi Zhen,Lanqipuzi,lan qi,lan qi bao zi,lan qi zhen,蓝旗,蓝旗堡子,蓝旗镇', 40.1018000, 123.7843100, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23057, 'Pianling', 'Pianling', 'Pianling,Pianling Zhen,pian ling,pian ling zhen,偏岭,偏岭镇', 40.4779800, 123.1586700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23058, 'Dafangshen', 'Dafangshen', 'Dafangshen,Dafangshen Xiang,da fang shen,da fang shen xiang,大房身,大房身乡', 40.4952600, 123.3298500, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23059, 'Linggou', 'Linggou', 'Linggou,Linggou Xiang,ling gou,ling gou xiang,岭沟,岭沟乡', 40.1728800, 123.4295700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23060, 'Tanggou', 'Tanggou', 'Tanggou,Tanggou Zhen,tang gou,tang gou zhen,汤沟,汤沟镇', 40.6003000, 123.6102600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23061, 'Baiqi', 'Baiqi', 'Baiqi,Baiqi Zhen,bai qi,bai qi zhen,白旗,白旗镇', 40.3097400, 123.8414800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23062, 'Wangjiazhuang', 'Wangjiazhuang', 'Wangjiazhuang,Wanjia Zhen,wan jia zhen,wang jia zhuang,万家镇,王家庄', 40.0550700, 119.8550300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23063, 'Xidianzi', 'Xidianzi', 'Xidianzi,Xidianzi Zhen,xi dian zi,xi dian zi zhen,西甸子,西甸子镇', 40.0880700, 119.9360700, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23064, 'Lijiabao', 'Lijiabao', 'Lijiabao,Lijiabao Xiang,li jia bao,li jia bao xiang,李家堡,李家堡乡', 40.1087500, 119.8057600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23065, 'Dadianzi', 'Dadianzi', 'Dadianzi,Yong''anbao Xiang,Yong’anbao Xiang,da dian zi,yong an bao xiang,大甸子,永安堡乡', 40.2316100, 119.8072300, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23066, 'Fanjia', 'Fanjia', 'Fanjia,Fanjia Manzuxiang,fan jia,fan jia man zu xiang,范家,范家满族乡', 40.2970500, 120.0311100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23067, 'Jiabeiyan', 'Jiabeiyan', 'Jiabeiyan,Jiabeiyang Xiang,jia bei yan,jia bei yan xiang,加碑岩,加碑岩乡', 40.3295300, 119.7317400, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23068, 'Guangyudian', 'Guangyudian', 'Gejia Manzuxiang,Guangyudian,ge jia man zu xiang,guang yu dian,广裕店,葛家满族乡', 40.4709000, 119.9783900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23069, 'Wanghu', 'Wanghu', 'Jinxing Zhen,Wanghu,jin xing zhen,wang hu,网户,金星镇', 41.0349700, 120.9430000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23070, 'Futun', 'Futun', 'Futun,Futun Xiang,fu tun,fu tun xiang,富屯,富屯乡', 41.6300000, 121.7825000, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23071, 'Zhenjiang', 'Zhenjiang', 'Zhenjiang,Zhenjiang Zhen,Zhenjiangcun,zhen jiang,zhen jiang zhen,振江,振江镇', 40.7571200, 125.4278600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23072, 'Dongyingfang', 'Dongyingfang', 'Dongyingfang,Dongyingfang Xiang,dong ying fang,dong ying fang xiang,东营坊,东营坊乡', 41.2198200, 124.5226900, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23073, 'Caohezhang', 'Caohezhang', 'Caohezhang,Caohezhang Zhen,cao he zhang,cao he zhang zhen,草河掌,草河掌镇', 41.0678700, 124.0407800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23074, 'Hou’an', 'Hou''an', 'Hou''an,Hou''an Zhen,Hou’an,Hou’an Zhen,hou an,hou an zhen,后安,后安镇', 41.7041700, 124.2139200, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23075, 'Lanshan', 'Lanshan', 'Jinjia,Lanshan,Lanshan Xiang,jin jia,lan shan,lan shan xiang,兰山,兰山乡,金家', 41.7994000, 124.0949100, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23076, 'Dongzhou', 'Dongzhou', 'Dongzhou,Dongzhou Jiedao,dong zhou,dong zhou jie dao,东州,东州街道', 41.8643100, 124.0384600, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23077, 'Qiandian', 'Qiandian', 'Kaoshan,Qiandian,Qiandian Chaoxianzu,Qiandian Zhen,kao shan,qian dian,qian dian chao xian zu,qian dian zhen,前甸,前甸朝鲜族,前甸镇,靠山', 41.8946200, 124.0023800, 'CN', '2012-01-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23078, 'Wangtai', 'Wangtai', 'Ta-wang-t''ai,Ta-wang-t’ai,Wangtai,Wangtai Zhen,wang tai,wang tai zhen,望台,望台镇', 40.9846900, 122.6034500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23079, 'Datun', 'Datun', 'Datun,Datun Zhen,da tun,da tun zhen,Датун,大屯,大屯镇', 40.9937800, 122.9131800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23080, 'Liushu', 'Liushu', 'Liu-shu-t''un,Liu-shu-t’un,Liushu,Liushu Zhen,liu shu,liu shu zhen,柳树,柳树镇', 40.6129500, 122.4143300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23081, 'Quchi', 'Quchi', 'Quchi,Quchi Xiang,Taping,qu chi,qu chi xiang,ta ping,塔坪,曲尺,曲尺乡', 31.0362800, 109.7488600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23082, 'Shigang', 'Shigang', 'Shigang,Shigang Xiang,shi gang,shi gang xiang,石岗,石岗乡', 31.1361100, 109.3643200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23083, 'Kangping', 'Kangping', 'Kangping,Kangping Xiang,Xiaowan,kang ping,kang ping xiang,xiao wan,小湾,康坪,康坪乡', 30.9784100, 109.2445800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23084, 'Longdong', 'Longdong', 'Bashang,Longdong,Longdong Xiang,ba shang,long dong,long dong xiang,坝上,龙洞,龙洞乡', 30.9734600, 109.1658500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23085, 'Gaoyang', 'Gaoyang', 'Gaoyang,Gaoyang Zhen,gao yang,gao yang zhen,高阳,高阳镇', 31.0993900, 108.6791200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23086, 'Tailong', 'Tailong', 'Tailong,Tailong Zhen,tai long,tai long zhen,太龙,太龙镇', 30.8979100, 108.5241500, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23087, 'Xikou', 'Xikou', 'Xikou,Xikou Xiang,xi kou,xi kou xiang,溪口,溪口乡', 30.6102000, 108.3392400, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23088, 'Yanshan', 'Yanshan', 'Xiaxingchang,Yanshan,Yanshan Xiang,xia xing chang,yan shan,yan shan xiang,夏兴场,燕山,燕山乡', 30.5543500, 108.3090800, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23089, 'Tushi', 'Tushi', 'Tushi,Tushi Xiang,tu shi,tu shi xiang,土市,土市乡', 25.5330600, 112.2941700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23090, 'Jiangdong', 'Jiangdong', 'Jiangdong,Jiangdong Yaozuxiang,jiang dong,jiang dong yao zu xiang,浆洞,浆洞瑶族乡', 25.2580600, 112.2613900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23091, 'Huiyuan', 'Huiyuan', 'Huiyuan,Huiyuan Yaozuxiang,hui yuan,hui yuan yao zu xiang,汇源,汇源瑶族乡', 25.3783300, 112.0938900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23092, 'Litou', 'Litou', 'Litou,Litou Yaozuxiang,li tou,li tou yao zu xiang,犁头,犁头瑶族乡', 25.4350000, 112.1019400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23093, 'Shunling', 'Shunling', 'Shunling,Shunling Zhen,shun ling,shun ling zhen,舜陵,舜陵镇', 25.5930600, 111.9327800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23094, 'Tiantang', 'Tiantang', 'Tiantang,Tiantang Zhen,tian tang,tian tang zhen,天堂,天堂镇', 25.5516700, 111.8863900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23095, 'Jingzhu', 'Jingzhu', 'Jingzhu,Jingzhu Yaozuxiang,jing zhu,jing zhu yao zu xiang,荆竹,荆竹瑶族乡', 25.1219400, 111.9819400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23096, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Yaozuxiang,da qiao,da qiao yao zu xiang,大桥,大桥瑶族乡', 25.1138900, 112.1091700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23097, 'Ziliang', 'Ziliang', 'Ziliang,Ziliang Yaozuxiang,zi liang,zi liang yao zu xiang,紫良,紫良瑶族乡', 25.2286100, 112.0897200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23098, 'Jiuyi', 'Jiuyi', 'Jiuyi,Jiuyi Yaozuxiang,jiu yi,jiu yi yao zu xiang,九疑,九疑瑶族乡', 25.3647200, 111.9891700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23099, 'Heting', 'Heting', 'Heting,Heting Zhen,he ting,he ting zhen,禾亭,禾亭镇', 25.6630600, 112.0166700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23100, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 25.6611100, 112.1230600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23101, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Xiang,Bao’an,Bao’an Xiang,bao an,bao an xiang,保安,保安乡', 25.7277800, 112.0816700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23102, 'Shizi', 'Shizi', 'Shizi,Shizi Xiang,shi zi,shi zi xiang,十字,十字乡', 25.7627800, 112.1194400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23103, 'Sanjing', 'Sanjing', 'Sanjing,Sanjing Xiang,san jing,san jing xiang,三井,三井乡', 25.7894400, 112.2105600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23104, 'Shiyang', 'Shiyang', 'Shiyang,Shiyang Zhen,shi yang,shi yang zhen,石羊,石羊镇', 25.7522200, 112.2344400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23105, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,long quan,long quan zhen,龙泉,龙泉镇', 25.8997200, 112.2111100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23106, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Xiang,lian hua,lian hua xiang,莲花,莲花乡', 25.9436100, 112.2775000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23107, 'Jicun', 'Jicun', 'Jicun,Jicun Zhen,ji cun,ji cun zhen,骥村,骥村镇', 25.9569400, 112.1538900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23108, 'Maoli', 'Maoli', 'Maoli,Maoli Xiang,mao li,mao li xiang,毛里,毛里乡', 25.8547200, 112.1444400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23109, 'Xinlong', 'Xinlong', 'Xinlong,Xinlong Zhen,xin long,xin long zhen,新隆,新隆镇', 25.7866700, 112.3508300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23110, 'Gaoshan', 'Gaoshan', 'Gaoshan,Gaoshan Xiang,gao shan,gao shan xiang,高山,高山乡', 25.7863900, 112.3144400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23111, 'Maojia', 'Maojia', 'Maojia,Maojia Xiang,mao jia,mao jia xiang,茂家,茂家乡', 25.8352800, 112.2002800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23112, 'Xinxu', 'Xinxu', 'Xinxu,Xinxu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 25.8027800, 112.2697200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23113, 'Taoling', 'Taoling', 'Taoling,Taoling Xiang,tao ling,tao ling xiang,陶玲,陶玲乡', 25.7411100, 112.3208300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23114, 'Lengshui', 'Lengshui', 'Lengshui,Lengshui Zhen,leng shui,leng shui zhen,冷水,冷水镇', 25.5530600, 112.0313900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23115, 'Tongmuluo', 'Tongmuluo', 'Tongmuluo,Tongmuluo Yaozuxiang,tong mu luo,tong mu luo yao zu xiang,桐木漯,桐木漯瑶族乡', 25.9336100, 111.9502800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23116, 'Huangtang', 'Huangtang', 'Huangtang,Huangtang Yaozuxiang,huang tang,huang tang yao zu xiang,荒塘,荒塘瑶族乡', 26.0394400, 112.0350000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23117, 'Lengshuijing', 'Lengshuijing', 'Lengshuijing,Lengshuijing Xiang,leng shui jing,leng shui jing xiang,冷水井,冷水井乡', 25.9416700, 112.1094400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23118, 'Menlouxia', 'Menlouxia', 'Menlouxia,Menlouxia Yaozuxiang,men lou xia,men lou xia yao zu xiang,门楼下,门楼下瑶族乡', 26.0144400, 112.2072200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23119, 'Xinxu', 'Xinxu', 'Xinxu,Xinxu Zhen,xin wei,xin wei zhen,新圩,新圩镇', 25.4219400, 112.3725000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23120, 'Yongjiang', 'Yongjiang', 'Yongjiang,Yongjiang Xiang,yong jiang,yong jiang xiang,永江,永江乡', 25.8936100, 111.5883300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23121, 'Hejiadong', 'Hejiadong', 'Hejia,Hejiadong,Hejiadong Xiang,he jia dong,he jia dong xiang,何家洞,何家洞乡', 25.8863900, 111.5008300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23122, 'Shangrenli', 'Shangrenli', 'Shangrenli,Shangrenli Xiang,shang ren li,shang ren li xiang,尚仁里,尚仁里乡', 25.8930600, 111.6430600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23123, 'Majiang', 'Majiang', 'Majiang,Majiang Xiang,ma jiang,ma jiang xiang,麻江,麻江乡', 25.9702800, 111.8400000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23124, 'Lefutang', 'Lefutang', 'Lefutang,Lefutang Xiang,le fu tang,le fu tang xiang,乐福堂,乐福堂乡', 25.6483300, 111.5033300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23125, 'Shouyan', 'Shouyan', 'Shouyan,Shouyan Zhen,shou yan,shou yan zhen,寿雁,寿雁镇', 25.5713900, 111.5022200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23126, 'Xinche', 'Xinche', 'Xinche,Xinche Xiang,xin che,xin che xiang,新车,新车乡', 25.4144400, 111.4927800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23127, 'Daojiang', 'Daojiang', 'Daojiang,Daojiang Zhen,dao jiang,dao jiang zhen,道江,道江镇', 25.5330600, 111.5805600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23128, 'Dongmen', 'Dongmen', 'Dongmen,Dongmen Xiang,dong men,dong men xiang,东门,东门乡', 25.5238900, 111.6088900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23129, 'Wanjiazhuang', 'Wanjiazhuang', 'Wanjiazhuang,Wanjiazhuang Xiang,wan jia zhuang,wan jia zhuang xiang,万家庄,万家庄乡', 25.4986100, 111.5719400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23130, 'Shenzhangtang', 'Shenzhangtang', 'Shenzhangtang,Shenzhangtang Yaozuxiang,shen zhang tang,shen zhang tang yao zu xiang,审章塘,审章塘瑶族乡', 25.3552800, 111.5997200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23131, 'Hengling', 'Hengling', 'Hengling,Hengling Yaozuxiang,heng ling,heng ling yao zu xiang,横岭,横岭瑶族乡', 25.3372200, 111.7311100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23132, 'Baimadu', 'Baimadu', 'Baimadu,Baimadu Zhen,bai ma du,bai ma du zhen,白马渡,白马渡镇', 25.5491700, 111.6880600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23133, 'Baimangpu', 'Baimangpu', 'Baimangpu,Baimangpu Xiang,bai mang pu,bai mang pu xiang,白芒铺,白芒铺乡', 25.5341700, 111.7019400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23134, 'Simaqiao', 'Simaqiao', 'Simaqiao,Simaqiao Zhen,si ma qiao,si ma qiao zhen,四马桥,四马桥镇', 25.4161100, 111.7611100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23135, 'Futang', 'Futang', 'Futang,Futang Xiang,fu tang,fu tang xiang,富塘,富塘乡', 25.5588900, 111.5994400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23136, 'Yuankou', 'Yuankou', 'Yuankou,Yuankou Yaozuxiang,yuan kou,yuan kou yao zu xiang,源口,源口瑶族乡', 25.0008300, 111.0552800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23137, 'Lanxi', 'Lanxi', 'Lanxi,Lanxi Yaozuxiang,lan xi,lan xi yao zu xiang,兰溪,兰溪瑶族乡', 25.0983300, 111.1563900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23138, 'Qianjiadong', 'Qianjiadong', 'Qianjiadong,Qianjiadong Yaozuxiang,qian jia dong,qian jia dong yao zu xiang,千家峒,千家峒瑶族乡', 25.3719400, 111.3238900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23139, 'Shangjiangxu', 'Shangjiangxu', 'Shangjiangxu,Shangjiangxu Zhen,shang jiang wei,shang jiang wei zhen,上江圩,上江圩镇', 25.3558300, 111.4269400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23140, 'Xiaopu', 'Xiaopu', 'Xiaopu,Xiaopu Zhen,xiao pu,xiao pu zhen,潇浦,潇浦镇', 25.2808300, 111.3444400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23141, 'Songbo', 'Songbo', 'Songbo,Songbo Yaozuxiang,song bai,song bai yao zu xiang,松柏,松柏瑶族乡', 25.1086100, 111.4552800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23142, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 25.2927800, 111.5369400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23143, 'Dongtian', 'Dongtian', 'Dongtian,Dongtian Zhen,dong tian,dong tian zhen,东田,东田镇', 25.1494400, 111.6494400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23144, 'Xiangjiang', 'Xiangjiang', 'Xiangjiang,Xiangjiang Xiang,xiang jiang,xiang jiang xiang,湘江,湘江乡', 25.0691700, 111.8191700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23145, 'Jiuli', 'Jiuli', 'Jiuli,Jiuli Jiedao,Jiuli Qu,jiu li,jiu li jie dao,jiu li qu,九里,九里区,九里街道', 34.2934100, 117.1371000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23146, 'Mositai', 'Mositai', 'Holingol,Holingol Shi,Huolin Gol,Huolinguole Shi,Mositai,Mositai Jiedao,huo lin guo lei,huo lin guo lei shi,mo si tai,mo si tai jie dao,莫斯台,莫斯台街道,霍林郭勒,霍林郭勒市', 45.5353800, 119.6669800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23147, 'Hanbin', 'Hanbin', 'Ankang Shi,Hanbin,Hanbin Qu,an kang shi,han bin,han bin qu,安康市,汉滨,汉滨区', 32.8897200, 108.9044400, 'CN', '2013-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23148, 'Xiling', 'Xiling', 'Xiling,Xiling Jiedao,xi ling,xi ling jie dao,西陵,西陵街道', 30.7160600, 111.2839000, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23149, 'E’zhou', 'E''zhou', 'E''zhou,E''zhou Shi,E’zhou,E’zhou Shi,Wuchang,e zhou,e zhou shi,鄂州,鄂州市', 30.3960700, 114.8865500, 'CN', '2015-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23150, 'Hong’an', 'Hong''an', 'Fula''erji,Fula''erji Qu,Fularji,Fula’erji,Fula’erji Qu,Hong''an,Hong''an Jiedao,Hong’an,Hong’an Jiedao,Hulan Ergi Qu,fu la er ji,fu la er ji qu,hong an,hong an jie dao,富拉尔基,富拉尔基区,红岸,红岸街道', 47.2055400, 123.6252400, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23151, 'Liushun', 'Liushun', 'Cuiyun Xiang,Liushun,Liushun Xiang,cui yun xiang,liu shun,liu shun xiang,六顺,六顺乡,翠云乡', 22.6279600, 100.7240200, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23152, 'Yangla', 'Yangla', 'Yangla,Yangla Xiang,yang la,yang la xiang,羊拉,羊拉乡', 28.9418300, 99.1278000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23153, 'Foshan', 'Foshan', 'Foshan,Foshan Xiang,fu shan,fu shan xiang,佛山,佛山乡', 28.7340100, 98.8061200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23154, 'Dongwang', 'Dongwang', 'Dongwang,Dongwang Xiang,dong wang,dong wang xiang,东旺,东旺乡', 28.5614600, 99.7436200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23155, 'Yanmen', 'Yanmen', 'Yanmen,Yanmen Xiang,yan men,yan men xiang,燕门,燕门乡', 28.0722500, 99.0231600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23156, 'Yunling', 'Yunling', 'Yunling,Yunling Xiang,yun ling,yun ling xiang,云岭,云岭乡', 28.2928400, 98.9715700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23157, 'Benzilan', 'Benzilan', 'Benzilan,Benzilan Zhen,ben zi lan,ben zi lan zhen,奔子栏,奔子栏镇', 28.2359100, 99.3682700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23158, 'Xiaruo', 'Xiaruo', 'Xiaruo,Xiaruo Lisuzu Xiang,xia ruo,xia ruo li su zu xiang,霞若,霞若傈僳族乡', 27.8089700, 99.3576000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23159, 'Gezan', 'Gezan', 'Gezan,Gezan Xiang,ge zan,ge zan xiang,格咱,格咱乡', 28.2038900, 99.8094400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23160, 'Badi', 'Badi', 'Badi,Badi Xiang,ba di,ba di xiang,巴迪,巴迪乡', 27.8801300, 99.0907600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23161, 'Yezhi', 'Yezhi', 'Yezhi,Yezhi Zhen,ye zhi,ye zhi zhen,叶枝,叶枝镇', 27.7022300, 99.1263300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23162, 'Tuoding', 'Tuoding', 'Tuoding,Tuoding Lisuzu Xiang,tuo ding,tuo ding li su zu xiang,拖顶,拖顶傈僳族乡', 27.7591600, 99.4714500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23163, 'Wujing', 'Wujing', 'Wujing,Wujing Xiang,wu jing,wu jing xiang,五境,五境乡', 27.7022300, 99.5372700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23164, 'Kangpu', 'Kangpu', 'Kangpu,Kangpu Xiang,kang pu,kang pu xiang,康普,康普乡', 27.5955000, 99.1014300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23165, 'Jinniu', 'Jinniu', 'Jinniu,jin niu,金牛', 25.8006200, 100.5743500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23166, 'Nanzhao', 'Nanzhao', 'Nanzhao,nan zhao,南诏', 25.2222200, 100.3034400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23167, 'Jiantang', 'Jiantang', 'Jiantang,jian tang,建塘', 27.8224400, 99.7692900, 'CN', '2013-11-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23168, 'Nayun', 'Nayun', 'Nayun,na yun,那允', 22.3319600, 99.5613200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23169, 'Dingcheng', 'Dingcheng', 'Dingcheng,Dingcheng Qu,Wuling,Wuling Zhen,ding cheng,ding cheng qu,wu ling,wu ling zhen,武陵,武陵镇,鼎成,鼎成区', 29.0193700, 111.6797600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23170, 'Liangshi', 'Liangshi', 'Liangshi,liang shi,两市', 27.2063600, 111.7371400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23171, 'Yunji', 'Yunji', 'Yunji,yun ji,云集', 26.6932000, 112.6674800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23172, 'Chengzhong', 'Chengzhong', 'Chengzhong,Chengzhong Jiedao,cheng zhong,cheng zhong jie dao,城中,城中街道', 23.3405500, 112.6876400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23173, 'Jianghai', 'Jianghai', 'Jianghai,Jianghai Qu,jiang hai,jiang hai qu,江海,江海区', 22.5751800, 113.1190400, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23174, 'Lianjiang', 'Lianjiang', 'Lianjiang,Lianjiang Qu,lian jiang,lian jiang qu,莲江,莲江区', 22.5901800, 113.0764200, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23175, 'Leicheng', 'Leicheng', 'Leicheng,Leicheng Jiedao,lei cheng,lei cheng jie dao,雷城,雷城街道', 20.9155800, 110.0837100, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23176, 'Dongzhen', 'Dongzhen', 'Dongzhen,Dongzhen Jiedao,dong zhen,dong zhen jie dao,东镇,东镇街道', 22.3797100, 110.9388500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23177, 'Chuncheng', 'Chuncheng', 'Chuncheng,Chuncheng Jiedao,chun cheng,chun cheng jie dao,春城,春城街道', 22.1729400, 111.7868800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23178, 'Luozhou', 'Luozhou', 'Luozhou,Luozhou Jiedao,luo zhou,luo zhou jie dao,罗州,罗州街道', 21.6058900, 110.2770500, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23179, 'Hexi', 'Hexi', 'Hexi,Hexi Qu,he xi,he xi qu,河西,河西区', 21.6865100, 110.6341700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23180, 'Chengjiang', 'Chengjiang', 'Chengjiang,Chengjiang Zhen,cheng jiang,cheng jiang zhen,程江,程江镇', 24.2798800, 116.0873400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23181, 'Taihe', 'Taihe', 'Taihe,Taihe Zhen,tai he,tai he zhen,太和,太和镇', 23.7353500, 112.9778200, 'CN', '2013-10-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23182, 'Xiangjiaba', 'Xiangjiaba', 'Shuifu Xian,Xiangjiaba,shui fu xian,xiang jia ba,向家坝,水富县', 28.6326600, 104.4041600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23183, 'Zhongcheng', 'Zhongcheng', 'Suijiang Xian,Zhongcheng,sui jiang xian,zhong cheng,中城,绥江县', 28.5910300, 103.9395800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23184, 'Guizhumao', 'Guizhumao', 'Guizhumao,Guizhumao Zhen,gui zhu mao,gui zhu mao zhen,桂竹帽,桂竹帽镇', 24.9226300, 115.5299000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23185, 'Shiqiao', 'Shiqiao', 'Shiqiao,shi qiao,仕桥', 27.9819500, 120.5591700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23186, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Xiang,hong shan,hong shan xiang,洪山,洪山乡', 24.7463000, 116.5153600, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23187, 'Ningzhong', 'Ningzhong', 'Ningzhong,Ningzhong Zhen,ning zhong,ning zhong zhen,宁中,宁中镇', 24.1547700, 115.7430700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23188, 'Xiaosheng', 'Xiaosheng', 'Xiaosheng,Xiaosheng Zhen,xiao sheng,xiao sheng zhen,小胜,小胜镇', 24.0666900, 116.4547200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23189, 'Beiqi', 'Beiqi', 'Beiqi,Beiqi Zhen,bei qi,bei qi zhen,北磜,北磜镇', 24.7887400, 116.3584200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23190, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Zhen,cheng bei,cheng bei zhen,城北,城北镇', 24.3276000, 116.0998300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23191, 'Gaopi', 'Gaopi', 'Gaopi,Gaopi Zhen,gao bei,gao bei zhen,高陂,高陂镇', 24.1919600, 116.6335900, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23192, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Jiedao,san he,三河', 23.2871700, 116.6557400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23193, 'Banghai', 'Banghai', 'Banghai,Banghai Jiedao,bang hai,浜海', 23.2510300, 116.6839300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23194, 'Yuxin', 'Yuxin', 'Yuxin,Yuxin Jiedao,yu xin,yu xin jie dao,玉新,玉新街道', 23.2862600, 116.6588000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23195, 'Outing', 'Outing', 'Outing,Outing Jiedao,ou ting,欧汀', 23.4161900, 116.7132700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23196, 'Shanghua', 'Shanghua', 'Shanghua,Shanghua Zhen,shang hua,shang hua zhen,上华,上华镇', 23.5238700, 116.7091500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23197, 'Guangyi', 'Guangyi', 'Guangyi,Guangyi Jiedao,guang yi,广益', 23.4743600, 116.7671300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23198, 'Buzhai', 'Buzhai', 'Buzhai,Puzhai Zhen,bu zhai,bu zhai zhen,埔寨,埔寨镇', 23.6498800, 116.1519800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23199, 'Tangxi', 'Tangxi', 'Tangxi,Tangxi Zhen,tang xi,tang xi zhen,汤西,汤西镇', 23.7576900, 116.1525900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23200, 'Guangtai', 'Guangtai', 'Guangtai,Guangtai Zhen,guang tai,guang tai zhen,广太,广太镇', 23.4730200, 116.2807500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23201, 'Linhu', 'Linhu', 'Linhu,Linhu Zhen,lin hu,lin hu zhen,临湖,临湖镇', 31.1273100, 120.4562300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23202, 'Hefeng', 'Hefeng', 'Hefeng,Hefeng Zhen,he feng,he feng zhen,和凤,和凤镇', 31.3922500, 119.0001200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23203, 'Yushan', 'Yushan', 'Changshu Shi,Yushan,Yushan Zhen,chang shu shi,yu shan,yu shan zhen,常熟市,虞山,虞山镇', 31.6774800, 120.8013400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23204, 'Jincheng', 'Jincheng', 'Jincheng,Jincheng Zhen,Jintan Shi,jin cheng,jin cheng zhen,jin tan shi,金坛市,金城,金城镇', 31.7442200, 119.5741600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23205, 'Yongyang', 'Yongyang', 'Yongyang,yong yang,永阳', 31.6581100, 119.0277200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23206, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Jiedao,gao qiao,gao qiao jie dao,高桥,高桥街道', 28.5886100, 121.2278900, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23207, 'Yanjiang', 'Yanjiang', 'Yanjiang,Yanjiang Zhen,yan jiang,yan jiang zhen,沿江,沿江镇', 28.7437300, 121.2359600, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23208, 'Qidou', 'Qidou', 'Qidou,Qidou Zhen,qi dou,qi dou zhen,七都,七都镇', 30.9527300, 120.3881300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23209, 'Jieshan', 'Jieshan', 'Jieshan,Jieshan Zhen,jie shan,jie shan zhen,界山,界山镇', 25.2226200, 118.8540200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23210, 'Fashi', 'Fashi', 'Donghai,Donghai Zhen,Fashi,dong hai,dong hai zhen,fa shi,东海,东海镇,法石', 24.8814900, 118.6188900, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23211, 'Chidian', 'Chidian', 'Chidian,Chidian Zhen,chi dian,chi dian zhen,池店,池店镇', 24.8610200, 118.5729300, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23212, 'Xibin', 'Xibin', 'Xibin,Xibin Zhen,xi bin,xi bin zhen,西滨,西滨镇', 24.7988700, 118.6200800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23213, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Xiang,cheng bei,cheng bei xiang,城北,城北乡', 20.3246300, 110.1782200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23214, 'Jiaoweixiang', 'Jiaoweixiang', 'Jiaowei Xiang,Jiaoweixiang,jiao wei,jiao wei xiang,角尾,角尾乡', 20.2684500, 109.9610600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23215, 'He’an', 'He''an', 'He''an,He''an Zhen,He’an,He’an Zhen,he an,he an zhen,和安,和安镇', 20.6295100, 110.3698000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23216, 'Liujie', 'Liujie', 'Liujie,Liujie Zhen,liu jie,liu jie zhen,六街,六街镇', 24.8210700, 102.2286100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23217, 'Xiaojie', 'Xiaojie', 'Xiaojie,Xiaojie Xiang,xiao jie,xiao jie xiang,小街,小街乡', 24.8645600, 102.1350500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23218, 'Liujie', 'Liujie', 'Liujie,Liujie Xiang,liu jie,liu jie xiang,六街,六街乡', 24.5365700, 102.6862800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23219, 'Longwu', 'Longwu', 'Longwu,Longwu Zhen,Longwupu,long wu,long wu pu,long wu zhen,龙武,龙武铺,龙武镇', 24.0017400, 102.4004600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23220, 'Xiyang', 'Xiyang', 'Xiyang,Xiyang Yizuxiang,xi yang,xi yang yi zu xiang,夕阳,夕阳彝族乡', 24.4639900, 102.2907300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23221, 'Xiaojie', 'Xiaojie', 'Xiaojie,Xiaojie Zhen,xiao jie,xiao jie zhen,小街,小街镇', 24.1581000, 102.4612000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23222, 'Panjiang', 'Panjiang', 'Panjiang,Panjiang Xiang,pan jiang,pan jiang xiang,盘江,盘江乡', 24.0195200, 103.1249800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23223, 'Shuanghejie', 'Shuanghejie', 'Shuanghe,Shuanghe Yizuxiang,Shuanghejie,shuang he,shuang he jie,shuang he yi zu xiang,双河,双河彝族乡,双河街', 24.5664600, 102.4364300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23224, 'Xinjiezi', 'Xinjiezi', 'Pubei Yizuxiang,Xinjiezi,pu bei yi zu xiang,xin jie zi,新街子,浦贝彝族乡', 24.6168800, 102.1820400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23225, 'Lishan', 'Lishan', 'Lishan,Lishan Yizuxiang,li shan,li shan yi zu xiang,里山,里山彝族乡', 24.0722500, 102.7495200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23226, 'Jiujie', 'Jiujie', 'Erjie,Jiujie,Jiujie Zhen,er jie,jiu jie,jiu jie zhen,九街,九街镇,二街', 24.1136700, 102.6867800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23227, 'Caopujie', 'Caopujie', 'Caopu,Caopu Zhen,Caopujie,cao pu,cao pu jie,cao pu zhen,草铺,草铺街,草铺镇', 24.9350800, 102.3804400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23228, 'Shijie', 'Shijie', 'Shijie,Shijie Yizuxiang,shi jie,shi jie yi zu xiang,十街,十街彝族乡', 24.5020000, 102.1586100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23229, 'Shangfang Xinjie', 'Shangfang Xinjie', 'Baofeng,Baofeng Zhen,Shangfang Xinjie,bao feng,bao feng zhen,shang fang xin jie,上方新街,宝峰,宝峰镇', 24.5544000, 102.5516200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23230, 'Dalongtan', 'Dalongtan', 'Dalongtan,Dalongtan Xiang,da long tan,da long tan xiang,大龙潭,大龙潭乡', 24.4358300, 102.1083200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23231, 'Baigecun', 'Baigecun', 'Baigecun,Xingmeng,Xingmeng Mengguzuxiang,bai ge cun,xing meng meng gu zu xiang,兴蒙蒙古族乡,白阁村', 24.1575000, 102.6638200, 'CN', '2016-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23232, 'Najiaying', 'Najiaying', 'Nagu,Nagu Zhen,Najiaying,na gu,na gu zhen,na jia ying,纳古,纳古镇,纳家营', 24.1825200, 102.7388600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23233, 'Huichang', 'Huichang', 'Gucheng,Gucheng Zhen,Huichang,gu cheng,gu cheng zhen,hui chang,古城,古城镇,恢厂', 24.7405600, 102.5948400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23234, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Xiang,xin jie,xin jie xiang,新街,新街乡', 24.7444900, 102.7210600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23235, 'Taiping', 'Taiping', 'Taiping,Taiping Zhen,tai ping,tai ping zhen,太平,太平镇', 24.9525000, 102.5883400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23236, 'Xianjie', 'Xianjie', 'Xianjie,Xianjie Zhen,xian jie,xian jie zhen,县街,县街镇', 24.8577500, 102.4221000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23237, 'Laojiangjunjie', 'Laojiangjunjie', 'Laojiangjunjie,Shangsuan,Shangsuan Xiang,lao jiang jun jie,shang suan,shang suan xiang,上蒜,上蒜乡,老将军街', 24.6796400, 102.7115900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23238, 'Huayue', 'Huayue', 'Huayue,Huayue Xiang,hua le,hua le xiang,化乐,化乐乡', 24.6210100, 102.7521600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23239, 'Mingyihe', 'Mingyihe', 'Mingyihe,Mingyihe Xiang,ming yi he,ming yi he xiang,鸣矣河,鸣矣河乡', 24.7875700, 102.4279000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23240, 'Chahe', 'Chahe', 'Chahe,Chahe Xiang,cha he,cha he xiang,岔河,岔河乡', 24.2833000, 102.2509900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23241, 'Xiongguan', 'Xiongguan', 'Xiongguan,Xiongguan Xiang,xiong guan,xiong guan xiang,雄关,雄关乡', 24.2254500, 102.8011900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23242, 'Xiaojie', 'Xiaojie', 'Xiaojie,Yousuo,Yousuo Zhen,xiao jie,you suo,右所,小街', 24.6439300, 102.9314300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23243, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南羊,南羊镇', 24.8479000, 103.1344700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23244, 'Caodianjie', 'Caodianjie', 'Caodian,Caodian Zhen,Caodianjie,cao dian,cao dian jie,cao dian zhen,草甸,草甸街,草甸镇', 24.8718100, 103.0511400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23245, 'Jiulong', 'Jiulong', 'Jiucun,Jiucun Zhen,Jiulong,jiu cun,jiu cun zhen,jiu long,九村,九村镇,九龙', 24.6935500, 102.9798100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23246, 'Longjie', 'Longjie', 'Longjie,Longjie Zhen,long jie,long jie zhen,龙街,龙街镇', 24.6500800, 102.8920600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23247, 'Dayingjie', 'Dayingjie', 'Dayingjie,Jiuxi,Jiuxi Zhen,da ying jie,jiu xi,jiu xi zhen,九溪,九溪镇,大营街', 24.3068100, 102.6390500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23248, 'Qianwei', 'Qianwei', 'Qianwei,Qianwei Zhen,qian wei,qian wei zhen,前卫,前卫镇', 24.3412600, 102.7288500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23249, 'Anhua Daying', 'Anhua Daying', 'Anhua,Anhua Daying,Anhua Yizuxiang,an hua,an hua da ying,an hua yi zu xiang,安化,安化大营,安化彝族乡', 24.4187600, 102.6726700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23250, 'Sijia', 'Sijia', 'Sijia,Wushan,Wushan Xiang,si jia,wu shan,wu shan xiang,五山,五山乡,四家', 24.1650500, 103.1959400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23251, 'Tonghong', 'Tonghong', 'Tonghong,Tonghong Yizu Miaozuxiang,tong hong,tong hong yi zu miao zu xiang,通红,通红彝族苗族乡', 24.3382600, 103.0700300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23252, 'Haikoudajie', 'Haikoudajie', 'Haikou Zhen,Haikoudajie,hai kou da jie,hai kou zhen,海口大街,海口镇', 24.5266500, 102.9474200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23253, 'Liujia', 'Liujia', 'Liujia,Liujia Yingxiang,liu jia,liu jia ying xiang,六甲,六甲营乡', 24.9639900, 102.7160900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23254, 'Ala', 'Ala', 'Ala,Ala Yizuxiang,a la,a la yi zu xiang,阿拉,阿拉彝族乡', 24.9984800, 102.7883500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23255, 'Xiaobanqiao', 'Xiaobanqiao', 'Xiaobanqiao,Xiaobanqiao Zhen,xiao ban qiao,xiao ban qiao zhen,小板桥,小板桥镇', 24.9794400, 102.7738000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23256, 'Xiaowangjiaying', 'Xiaowangjiaying', 'Dounan Zhen,Xiaowangjiaying,dou nan zhen,xiao wang jia ying,小王家营,斗南镇', 24.9126500, 102.7915600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23257, 'Xilong', 'Xilong', 'Xi''er Zhen,Xilong,Xi’er Zhen,xi er zhen,xi long,西二镇,西龙', 24.4208600, 103.1772600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23258, 'Huakoulongtan', 'Huakoulongtan', 'Huakoulongtan,Xisan Zhen,hua kou long tan,xi san zhen,花口龙潭,西三镇', 24.5013200, 103.4133800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23259, 'Taipingguan', 'Taipingguan', 'Dayu Zhen,Taipingguan,da yu zhen,tai ping guan,大鱼镇,太平关', 24.8300300, 102.7912400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23260, 'Wujiaying', 'Wujiaying', 'Wujiaying,Wujiaying Xiang,wu jia ying,wu jia ying xiang,吴家营,吴家营乡', 24.8750200, 102.8452200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23261, 'Qidian', 'Qidian', 'Qidian,Qidian Xiang,qi dian,qi dian xiang,七甸,七甸乡', 24.9603400, 102.9467500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23262, 'Dake', 'Dake', 'Dake,Dake Xiang,da ke,da ke xiang,大可,大可乡', 24.6157500, 103.2391100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23263, 'Weize', 'Weize', 'Weize,Weize Xiang,wei ze,wei ze xiang,维则,维则乡', 24.7077200, 103.4050100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23264, 'Shilin', 'Shilin', 'Kamennyj les,Shilin,Shilin Zhen,shi lin,shi lin zhen,Каменный лес,Шилин,石林,石林镇', 24.8187800, 103.3323700, 'CN', '2013-11-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23265, 'Beidacun Xiaozhai', 'Beidacun Xiaozhai', 'Beidacun Xiang,Beidacun Xiaozhai,bei da cun xiang,bei da cun xiao zhai,北大村乡,北大村小寨', 24.8578900, 103.3598800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23266, 'Beigucheng', 'Beigucheng', 'Beigucheng,Beigucheng Zhen,bei gu cheng,bei gu cheng zhen,北古城,北古城镇', 24.9847000, 103.1815900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23267, 'Yanhe', 'Yanhe', 'Yanhe,Yanhe Zhen,yan he,yan he zhen,研和,研和镇', 24.2587600, 102.4959200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23268, 'Gaocang', 'Gaocang', 'Gaocang,Gaocang Zhen,gao cang,gao cang zhen,高仓,高仓镇', 24.3220000, 102.5218800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23269, 'Chunhe', 'Chunhe', 'Chunhe,Chunhe Zhen,chun he,chun he zhen,春和,春和镇', 24.4033500, 102.5305500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23270, 'Liqi', 'Liqi', 'Liqi,Liqi Zhen,li qi,li qi zhen,李棋,李棋镇', 24.3883000, 102.5519700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23271, 'Dayingjie', 'Dayingjie', 'Dayingjie,Dayingjie Zhen,da ying jie,da ying jie zhen,大营街,大营街镇', 24.3385700, 102.4951000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23272, 'Xiaoshiqiao', 'Xiaoshiqiao', 'Xiaoshiqiao,Xiaoshiqiao Yizuxiang,xiao shi qiao,xiao shi qiao yi zu xiang,小石桥,小石桥彝族乡', 24.4468000, 102.6175300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23273, 'Luohe', 'Luohe', 'Luohe,Luohe Yizuxiang,luo he,luo he yi zu xiang,洛河,洛河彝族乡', 24.3303400, 102.3891700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23274, 'Fucheng', 'Fucheng', 'Fucheng,Fucheng Zhen,fu cheng,fu cheng zhen,附城,附城镇', 20.9227200, 110.0951400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23275, 'Haitou', 'Haitou', 'Haitou,Haitou Jiedao,hai tou,hai tou jie dao,海头,海头街道', 21.2013100, 110.3864200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23276, 'Longtou', 'Longtou', 'Longtou,Longtou Zhen,long tou,long tou zhen,龙头,龙头镇', 21.3595000, 110.5191800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23277, 'Huguang', 'Huguang', 'Huguang,Huguang Zhen,hu guang,hu guang zhen,湖光,湖光镇', 21.1258200, 110.2887200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23278, 'Shiwan', 'Shiwan', 'Shiwan,Shiwan Jiedao,shi wan,shi wan jie dao,石湾,石湾街道', 21.6680300, 110.5363100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23279, 'Shicheng', 'Shicheng', 'Shicheng,Shicheng Zhen,shi cheng,shi cheng zhen,石城,石城镇', 21.5972800, 110.2739200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23280, 'Wangcungang', 'Wangcungang', 'Wangcungang,Wangcungang Zhen,wang cun gang,王村港', 21.4299400, 110.9394300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23281, 'Dashanjiang', 'Dashanjiang', 'Dashanjiang,Dashanjiang Jiedao,da shan jiang,da shan jiang jie dao,大山江,大山江街道', 21.4282900, 110.7970600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23282, 'Bopu', 'Bopu', 'Bopu,Bopu Jiedao,bo pu,bo pu jie dao,博铺,博铺街道', 21.4489600, 110.7941000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23283, 'Haibin', 'Haibin', 'Haibin,Haibin Jiedao,hai bin,hai bin jie dao,海滨,海滨街道', 21.3987600, 110.7832800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23284, 'Shanmei', 'Shanmei', 'Shanmei,Shanmei Jiedao,shan mei,shan mei jie dao,山美,山美街道', 21.9308700, 110.8740500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23285, 'Jinshan', 'Jinshan', 'Jinshan,Jinshan Jiedao,jin shan,jin shan jie dao,金山,金山街道', 21.8351900, 110.8371600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23286, 'Shiziling', 'Shiziling', 'Shizailing Jiedao,Shiziling,shi zi ling,shi zi ling jie dao,石仔岭,石仔岭街道', 21.8887900, 110.8221800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23287, 'Magui', 'Magui', 'Magui,Magui Zhen,ma gui,ma gui zhen,马贵,马贵镇', 22.2031100, 111.3143700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23288, 'Hetang', 'Hetang', 'Hetang,Hetang Zhen,he tang,he tang zhen,荷塘,荷塘镇', 22.0104100, 110.7126600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23289, 'Guandu', 'Guandu', 'Guandu,Guandu Jiedao,guan du,guan du jie dao,官渡,官渡街道', 21.6796100, 110.9190500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23290, 'Shaba Zhen', 'Shaba Zhen', 'Shaba Zhen,sha ba,沙扒', 21.5316200, 111.4788400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23291, 'Ganglie', 'Ganglie', 'Ganglie,Ganglie Jiedao,gang lie,gang lie jie dao,岗列,岗列街道', 21.8496500, 111.9629200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23292, 'Chengxi', 'Chengxi', 'Chengxi,Chengxi Jiedao,cheng xi,cheng xi jie dao,城西,城西街道', 21.8256100, 111.9375400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23293, 'Pingshi', 'Pingshi', 'Pingshi,Pingshi Jiedao,ping shi,ping shi jie dao,平石,平石街道', 22.2021100, 112.3236600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23294, 'Huanshi', 'Huanshi', 'Huanshi,Huanshi Jiedao,huan shi,huan shi jie dao,环市,环市街道', 22.5935700, 113.0666000, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23295, 'Huicheng', 'Huicheng', 'Huicheng,Huicheng Jiedao,hui cheng,hui cheng jie dao,会城,会城街道', 22.5262500, 113.0298500, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23296, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Xiang,ban qiao,ban qiao xiang,板桥,板桥乡', 32.6227000, 105.3449400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23297, 'Qifo', 'Qifo', 'Qifo,Qifo Xiang,qi fu,qi fu xiang,七佛,七佛乡', 32.3039800, 105.2848100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23298, 'Magong', 'Magong', 'Magong,Magong Xiang,ma gong,ma gong xiang,马公,马公乡', 32.3277100, 105.0323400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23299, 'Suhe', 'Suhe', 'Suhe,Suhe Xiang,su he,su he xiang,苏河,苏河乡', 32.3545500, 105.1692000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23300, 'Huohua', 'Huohua', 'Huohua,huo hua,火花', 30.7590000, 106.0593600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23301, 'Jida', 'Jida', 'Jida,Jida Jiedao,ji da,ji da jie dao,吉大,吉大街道', 22.2545100, 113.5702000, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23302, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,hong qi,hong qi zhen,红旗,红旗镇', 22.1478500, 113.3426600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23303, 'Lengshui', 'Lengshui', 'Lengshui,Lengshui Zhen,leng shui,leng shui zhen,冷水,冷水镇', 27.9090900, 117.1847500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23304, 'Zhangdun', 'Zhangdun', 'Zhangdun,Zhangdun Zhen,zhang dun,zhang dun zhen,漳墩,漳墩镇', 27.4769300, 118.4662000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23305, 'Ouning', 'Ouning', 'Ouning,Ouning Jiedao,ou ning,ou ning jie dao,欧宁,欧宁街道', 27.0315600, 118.3109600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23306, 'Qinglin', 'Qinglin', 'Qinglin,Qinglin Xiang,qing lin,qing lin xiang,青林,青林乡', 32.7759100, 106.0345800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23307, 'Majiaba', 'Majiaba', 'Majiaba,Majiaba Xiang,ma jia ba,ma jia ba xiang,马家坝,马家坝乡', 32.8011900, 105.9975800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23308, 'Pingxi', 'Pingxi', 'Pingxi,Pingxi Xiang,ping xi,ping xi xiang,平溪,平溪乡', 32.6514900, 106.0841700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23309, 'Zhongzi', 'Zhongzi', 'Zhongzi,Zhongzi Zhen,zhong zi,zhong zi zhen,中子,中子镇', 32.6911900, 106.0319000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23310, 'Linxi', 'Linxi', 'Linxi,Linxi Xiang,lin xi,lin xi xiang,临溪,临溪乡', 32.5590600, 106.0116700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23311, 'Maliu', 'Maliu', 'Maliu,Maliu Xiang,ma liu,ma liu xiang,麻柳,麻柳乡', 32.5259300, 106.0467300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23312, 'Lijia', 'Lijia', 'Lijia,Lijia Xiang,li jia,li jia xiang,李家,李家乡', 32.5603800, 106.2056900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23313, 'Wangjia', 'Wangjia', 'Wangjia,Wangjia Xiang,wang jia,wang jia xiang,汪家,汪家乡', 32.5250800, 106.1569400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23314, 'Huangmao', 'Huangmao', 'Huangmao,Huangmao Xiang,huang mao,huang mao xiang,黄猫,黄猫乡', 32.0918700, 106.3971400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23315, 'Gaopo', 'Gaopo', 'Gaopo,Gaopo Zhen,gao po,gao po zhen,高坡,高坡镇', 32.0915400, 106.3380500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23316, 'Zhongshangang', 'Zhongshangang', 'Zhongshangang,Zhongshangang Jiedao,zhong shan gang,zhong shan gang jie dao,中山港,中山港街道', 22.5646000, 113.4869900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23317, 'Xinan', 'Xinan', 'Xinan,xi nan,西南', 23.1544500, 112.8934400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23318, 'Shunde', 'Shunde', 'Shunde,shun de,顺德', 22.8008700, 113.2920800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23319, 'Zhangcha', 'Zhangcha', 'Zhangcha,Zhangcha Jiedao,zhang cha,zhang cha jie dao,张槎,张槎街道', 23.0370100, 113.0763400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23320, 'Guicheng', 'Guicheng', 'Guicheng,Guicheng Jiedao,gui cheng,gui cheng jie dao,桂城,桂城街道', 23.0362500, 113.1856000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23321, 'Shishan', 'Shishan', 'Shishan,Shishan Zhen,shi shan,shi shan zhen,狮山,狮山镇', 23.1238500, 113.0087500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23322, 'Xinfa', 'Xinfa', 'Xinfa,xin fa,新发', 28.8307100, 104.3207700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23323, 'Guixu', 'Guixu', 'Guixu,Guixu Zhen,gui wei,gui wei zhen,桂圩,桂圩镇', 23.1523300, 111.4599900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23324, 'Fenghuang', 'Fenghuang', 'Fenghuang,Fenghuang Zhen,feng huang,feng huang zhen,凤凰,凤凰镇', 23.2038900, 112.5667800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23325, 'Huanggang', 'Huanggang', 'Huanggang,Huanggang Zhen,huang gang,huang gang zhen,黄岗,黄岗镇', 23.0751200, 112.5099900, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23326, 'Guicheng', 'Guicheng', 'Guicheng,Guicheng Jiedao,gui cheng,gui cheng jie dao,桂城,桂城街道', 23.1921900, 112.5701000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23327, 'Panzhihua', 'Panzhihua', 'PZI,Panzhihua,pan zhi hua,攀枝花', 26.5850900, 101.7127600, 'CN', '2013-03-31', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23328, 'Qianjin', 'Qianjin', 'Qianjin,Qianjin Zhen,qian jin,qian jin zhen,前进,前进镇', 26.5425000, 101.6974500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23329, 'Jia’erduo', 'Jia''erduo', 'Jia''er Duoduo,Jia''erduo,Jia''erduo Xiang,Jia’er Duoduo,Jia’erduo,Jia’erduo Xiang,jia er duo,jia er duo duo,jia er duo xiang,甲尔多,甲尔多乡,甲尔多多', 33.0134600, 101.5754800, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23330, 'Andou', 'Andou', 'Andou,Andou Xiang,an dou,an dou xiang,安斗,安斗乡', 33.0014900, 101.5471600, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23331, 'Dege', 'Dege', 'Dege,Dege Xiang,de ge,de ge xiang,德格,德格乡', 32.9245900, 101.6300900, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23332, 'Hezhi', 'Hezhi', 'Hezhi,Hezhi Xiang,he zhi,he zhi xiang,河支,河支乡', 32.9129400, 101.6462400, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23333, 'Longcang', 'Longcang', 'Longcang,Longcang Xiang,long cang,long cang xiang,龙藏,龙藏乡', 32.9408700, 101.7026000, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23334, 'Wa’erma', 'Wa''erma', 'Wa''erma,Wa''erma Xiang,Wa’erma,Wa’erma Xiang,wa er ma,wa er ma xiang,哇尔玛,哇尔玛乡', 32.9236500, 101.7199900, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23335, 'Kehe', 'Kehe', 'Kehe,Kehe Xiang,ke he,ke he xiang,柯河,柯河乡', 32.5920300, 101.3882700, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23336, 'Kuasha', 'Kuasha', 'Kuasha,Kuasha Xiang,kua sha,kua sha xiang,垮沙,垮沙乡', 32.6148000, 101.5232300, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23337, 'Rong’an', 'Rong''an', 'Rong''an,Rong''an Xiang,Rong’an,Rong’an Xiang,rong an,rong an xiang,茸安,茸安乡', 32.5292300, 101.5994400, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23338, 'Qiujima', 'Qiujima', 'Qiujima,Qiujima Xiang,qiu ji ma,qiu ji ma xiang,求吉玛,求吉玛乡', 33.4594700, 101.6275700, 'CN', '2013-02-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23339, 'Haikuotiankong', 'Haikuotiankong', '', 22.5288100, 113.9399000, 'CN', '2009-07-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23340, 'Shezhu', 'Shezhu', 'Shezhu,Shezhu Zhen,she zhu,she zhu zhen,社渚,社渚镇', 31.3153700, 119.3105100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23341, 'Zhoucheng', 'Zhoucheng', 'Zhoucheng,Zhoucheng Zhen,zhou cheng,zhou cheng zhen,周城,周城镇', 31.3439700, 119.3687300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23342, 'Nandu', 'Nandu', 'Nandu,Nandu Zhen,nan du,nan du zhen,南渡,南渡镇', 31.4277300, 119.3728200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23343, 'Shangpei', 'Shangpei', 'Shangpei,Shangpei Zhen,shang pei,shang pei zhen,上沛,上沛镇', 31.4743500, 119.2176800, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23344, 'Shangxing', 'Shangxing', 'Shangxing,Shangxing Zhen,shang xing,shang xing zhen,上兴,上兴镇', 31.5084300, 119.2859900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23345, 'Zhuze', 'Zhuze', 'Zhuze,Zhuze Zhen,zhu ze,zhu ze zhen,竹箦,竹箦镇', 31.5574600, 119.3605600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23346, 'Xuebu', 'Xuebu', 'Xuebu,Xuebu Zhen,xue bu,xue bu zhen,薛埠,薛埠镇', 31.7076100, 119.3942700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23347, 'Yangjiang', 'Yangjiang', 'Yangjiang,Yangjiang Zhen,yang jiang,yang jiang zhen,阳江,阳江镇', 31.3335600, 118.8077700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23348, 'Changqiao', 'Changqiao', 'Changqiao,Changqiao Zhen,chang qiao,chang qiao zhen,晿桥,晿桥镇', 31.5380500, 119.0796600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23349, 'Shuiyang', 'Shuiyang', 'Shuiyang,Shuiyang Zhen,shui yang,shui yang zhen,水阳,水阳镇', 31.6615800, 119.0342900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23350, 'Danyang', 'Danyang', 'Danyang,Danyang Zhen,dan yang,dan yang zhen,丹阳,丹阳镇', 31.6483700, 118.7149900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23351, 'Tongjing', 'Tongjing', 'Tongjing,Tongjing Zhen,tong jing,tong jing zhen,铜井,铜井镇', 31.7975000, 118.5372600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23352, 'Shiqiao', 'Shiqiao', 'Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 31.9282500, 118.4157000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23353, 'Qiaolin', 'Qiaolin', 'Qiaolin,Qiaolin Zhen,qiao lin,qiao lin zhen,桥林,桥林镇', 31.9497000, 118.5209100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23354, 'Tuqiao', 'Tuqiao', 'Tuqiao,Tuqiao Zhen,tu qiao,tu qiao zhen,土桥,土桥镇', 31.9333600, 119.0674000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23355, 'Xingdian', 'Xingdian', 'Xingdian,Xingdian Zhen,xing dian,xing dian zhen,星甸,星甸镇', 32.0395900, 118.4351100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23356, 'Tangquan', 'Tangquan', 'Tangquan,Tangquan Zhen,tang quan,tang quan zhen,汤泉,汤泉镇', 32.0988300, 118.5178500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23357, 'Zhujiang', 'Zhujiang', 'Zhujiang,Zhujiang Zhen,zhu jiang,zhu jiang zhen,珠江,珠江镇', 32.0630800, 118.6210200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23358, 'Shuining', 'Shuining', 'Shuining,Shuining Zhen,shui ning,shui ning zhen,水宁,水宁镇', 32.1432700, 118.5625000, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23359, 'Pancheng', 'Pancheng', 'Pancheng,Pancheng Zhen,pan cheng,pan cheng zhen,盘城,盘城镇', 32.2060900, 118.7201000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23360, 'Baguazhou', 'Baguazhou', 'Baguazhou,Baguazhou Zhen,ba gua zhou,ba gua zhou zhen,八卦洲,八卦洲镇', 32.1723800, 118.8222500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23361, 'Yudai', 'Yudai', 'Yudai,Yudai Zhen,yu dai,yu dai zhen,玉带,玉带镇', 32.2214100, 118.9111100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23362, 'Jing’an', 'Jing''an', 'Jing''an,Jing''an Zhen,Jing’an,Jing’an Zhen,jing an,jing an zhen,靖安,靖安镇', 32.2285600, 119.1429900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23363, 'Xilinji', 'Xilinji', 'Xilinji,xi lin ji,西林吉', 52.9906300, 123.2352200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23364, 'Gufu', 'Gufu', 'Gufu,gu fu,古夫', 31.3620800, 110.7291800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23365, 'Hongmiao', 'Hongmiao', 'Hongmiao,hong miao,红庙', 32.2248300, 118.9197500, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23366, 'Shiyan', 'Shiyan', 'Shiyan,Shiyan Jiedao,shi yan,shi yan jie dao,石岩,石岩街道', 22.6858800, 113.9411800, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23367, 'Shirong', 'Shirong', 'Shirong,shi rong,市荣', 29.3509200, 102.6524800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23368, 'Nanwai', 'Nanwai', 'Nanwai,nan wai,南外', 31.2047400, 107.5036300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23369, 'Xiwai', 'Xiwai', 'Xiwai,xi wai,西外', 31.2168200, 107.4752500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23370, 'Huangyang', 'Huangyang', 'Huangyang,Huangyang Zhen,huang yang,huang yang zhen,黄洋,黄洋镇', 32.2388000, 106.3686800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23371, 'Maying', 'Maying', 'Maying,Maying Xiang,ma ying,ma ying xiang,麻英,麻英乡', 32.3213500, 106.1210400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23372, 'Yanhe', 'Yanhe', 'Yanhe,Yanhe Xiang,yan he,yan he xiang,盐河,盐河乡', 32.5490400, 106.3387100, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23373, 'Sanjiang', 'Sanjiang', 'Sanjiang,Sanjiang Zhen,san jiang,san jiang zhen,三江,三江镇', 32.2376400, 106.5411000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23374, 'Wuquan', 'Wuquan', 'Wuquan,Wuquan Zhen,wu quan,wu quan zhen,五权,五权镇', 32.3322200, 106.6428300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23375, 'Jinxi', 'Jinxi', 'Jinxi,Jinxi Zhen,jin xi,jin xi zhen,金溪,金溪镇', 32.2872300, 106.6579800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23376, 'Zhanghua', 'Zhanghua', 'Zhanghua,Zhanghua Zhen,zhang hua,zhang hua zhen,张华,张华镇', 32.1478400, 106.1850600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23377, 'Longfeng', 'Longfeng', 'Longfeng,Longfeng Xiang,long feng,long feng xiang,龙凤,龙风乡', 32.1710900, 106.4047400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23378, 'Mumen', 'Mumen', 'Mumen,Mumen Zhen,mu men,mu men zhen,木门,木门镇', 32.1099000, 106.5260900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23379, 'Hualong', 'Hualong', 'Hualong,Hualong Xiang,hua long,hua long xiang,化龙,化龙乡', 32.1292500, 106.4625000, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23380, 'Lingbei', 'Lingbei', 'Cunwei,Lingbei,Lingbei Xiang,cun wei,ling bei,ling bei xiang,岭北,岭北乡,村尾', 27.5988500, 119.6606400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23381, 'Pingdu', 'Pingdu', 'Pingdu', 27.6117100, 118.9714100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23382, 'Zhoukou', 'Zhoukou', 'Zhoukou', 27.6968400, 118.9193800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23383, 'Xibian', 'Xibian', 'Xibian', 27.7645900, 118.9376600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23384, 'Sanxi', 'Sanxi', 'Sanxi', 27.6959000, 119.0626200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23385, 'Jushui', 'Jushui', 'Jushui', 27.4972900, 119.1761000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23386, 'Wudabao', 'Wudabao', 'Wudabao', 27.6080000, 119.1712600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23387, 'Binheng', 'Binheng', 'Binheng,Binheng Zhen,bin heng,bin heng zhen,宾亨,宾亨镇', 23.4706500, 112.4214200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23388, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 23.3350100, 112.7217100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23389, 'Chengzhao', 'Chengzhao', 'Chengzhao,Chengzhao Xiang,cheng zhao,cheng zhao xiang,澄照,澄照乡', 27.9239400, 119.6183400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23390, 'Hexi', 'Hexi', 'Hexi', 27.9804700, 119.6352800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23391, 'Zhengkeng', 'Zhengkeng', 'Zhengkeng,Zhengkeng Xiang,zheng keng,zheng keng xiang,郑坑,郑坑乡', 27.9893500, 119.8040200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23392, 'Xiayang', 'Xiayang', 'Xiayang,Xiayang Xiang,xia yang,xia yang xiang,下垟,下垟乡', 27.8776800, 119.8046800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23393, 'Yunhu', 'Yunhu', 'Yunhu,Yunhu Xiang,Zhishan,yun hu,yun hu xiang,zhi shan,云湖,云湖乡,支山', 27.7217900, 119.9197500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23394, 'Zhishan', 'Zhishan', 'Zhishan', 27.7163300, 119.9192100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23395, 'Xiyang', 'Xiyang', 'Menlou''ao,Menlou’ao,Xiyang,Xiyang Zhen,men lou ao,xi yang,xi yang zhen,西旸,西旸镇,门楼坳', 27.4360500, 119.8734600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23396, 'Menlou’ao', 'Menlou''ao', 'Menlou''ao,Menlou’ao', 27.4336300, 119.8748200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23397, 'Baishe', 'Baishe', 'Baishe,Baishe Xiang,bai she,bai she xiang,柏社,柏社乡', 29.3397600, 119.6501100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23398, 'Meijiang', 'Meijiang', 'Meijiang,Meijiang Zhen,mei jiang,mei jiang zhen,梅江,梅江镇', 29.3670900, 119.8098700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23399, 'Tongziwu', 'Tongziwu', 'Tongziwu,Tongziwu Xiang,tong zi wu,tong zi wu xiang,桐子坞,桐子坞乡', 29.5560700, 118.8449800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23400, 'Lingyuan', 'Lingyuan', 'Lingyuan,Lingyuan Xiang,ling yuan,ling yuan xiang,岭源,岭源乡', 29.9137900, 119.2749200, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23401, 'Zhoujia', 'Zhoujia', 'Zhoujia,zhou jia,周家', 29.0721200, 118.9050900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23402, 'Baitashan', 'Baitashan', 'Baitashan,Wantian,bai ta shan,wan tian,万田,白塔山', 29.0176900, 118.8597600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23403, 'Huanggu', 'Huanggu', 'Huanggu,Huanggu Xiang,huang gu,huang gu xiang,黄谷,黄谷乡', 29.2809500, 118.5605400, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23404, 'Dongshandi', 'Dongshandi', 'Dongshandi,Furong,dong shan di,fu rong,东山底,芙蓉', 29.1247100, 118.6485700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23405, 'Chisong', 'Chisong', 'Chisong,Chisong Xiang,chi song,chi song xiang,赤松,赤松乡', 29.1643400, 119.6928800, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23406, 'Sumeng', 'Sumeng', 'Sumeng,Sumeng Xiang,su meng,su meng xiang,苏孟,苏孟乡', 29.0305800, 119.6376900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23407, 'Wangzhai', 'Wangzhai', 'Wangzhai,Wangzhai Zhan,wang zhai,wang zhai zhen,汪宅,汪宅镇', 29.6980200, 119.0125900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23408, 'Jiuhua', 'Jiuhua', 'Jiuhua,jiu hua,九华', 29.0475600, 118.8435500, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23409, 'Zitong', 'Zitong', 'Zitong,Zitong Zhen,zi tong,zi tong zhen,梓潼,梓潼镇', 30.7502000, 103.6965700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23410, 'Guangsheng', 'Guangsheng', 'Guangsheng,Guangsheng Zhen,guan sheng,guan sheng zhen,观胜,观胜镇', 30.7371300, 103.6691300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23411, 'Xia’er', 'Xia''er', 'Jiulong Xian,Xia''er,Xia’er,ga er,jiu long xian,九龙县,呷尔', 29.0059400, 101.5143900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23412, 'Qianying', 'Qianying', 'Qianying,Qianying Zhen,qian ying,qian ying zhen,前营,前营镇', 40.1584800, 123.1807000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23413, 'Hangbu', 'Hangbu', 'Hangbu,Hangbu Zhen,hang bu,hang bu zhen,航埠,航埠镇', 28.9365700, 118.7786200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23414, 'Anren', 'Anren', 'Anren,Anren Zhen,an ren,an ren zhen,安仁,安仁镇', 28.0614700, 119.3365000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23415, 'Shitang', 'Shitang', 'Shitang,Shitang Zhen,shi tang,shi tang zhen,石塘,石塘镇', 28.2232600, 119.6655800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23416, 'Huajie', 'Huajie', 'Huajie,Huajie Zhen,hua jie,hua jie zhen,花街,花街镇', 28.9233400, 119.9676000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23417, 'Bihu', 'Bihu', 'Bihu,Bihu Zhen,bi hu,bi hu zhen,碧湖,碧湖镇', 28.3404500, 119.7873900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23418, 'Liancheng', 'Liancheng', 'Liancheng,Liancheng Zhen,lian cheng,lian cheng zhen,联城,联城镇', 28.4743300, 119.8533200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23419, 'Shuige', 'Shuige', 'Shuige,Shuige Jiedao,shui ge,shui ge jie dao,水阁,水阁街道', 28.4175000, 119.8599800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23420, 'Shuangxi', 'Shuangxi', 'Shuangxi,Shuangxi Zhen,shuang xi,shuang xi zhen,双溪,双溪镇', 28.5946700, 119.8755200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23421, 'Lakou', 'Lakou', 'Lakou,Lakou Zhen,la kou,la kou zhen,腊口,腊口镇', 28.3385800, 119.9554500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23422, 'Zhongshan', 'Zhongshan', 'Chung-san-su,Chzhunshan'',Chûng-sân-sṳ,Cung-san,Dzungshan,Jongshen shehiri,Trung Son,Trung Sơn,Xiangshan,ZGN,Zhongshan,Zhongshan Shi,jungsan si,zhong shan,zhong shan shi,Čung-šan,Џунгшан,Чжуншань,中山,中山市,중산 시', 22.5230600, 113.3791200, 'CN', '2013-12-15', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23423, 'Nan’an', 'Nan''an', 'Nan''an,Nan''an Xiang,Nan’an,Nan’an Xiang,nan an,nan an xiang,南安,南安乡', 29.7834700, 103.4937900, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23424, 'Suyang', 'Suyang', 'Pengcai Xiang,Suyang,peng cai xiang,su yang,苏羊,蓬菜乡', 24.9170500, 103.1396800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23425, 'Luoyang', 'Luoyang', 'Luoyang,Luoyang Zhen,luo yang,luo yang zhen,洛羊,洛羊镇', 24.9297400, 102.8052200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23426, 'Bantian', 'Bantian', 'Bantian,ban tian,坂田', 22.6363600, 114.0498900, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23427, 'Meisha', 'Meisha', 'Meisha,Meisha Jiedao,mei sha,mei sha jie dao,梅沙,梅沙街道', 22.5984000, 114.3010700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23428, 'Shatoujiao', 'Shatoujiao', 'Shatoujiao,sha tou jiao,沙头角', 22.5546300, 114.2258900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23429, 'Xiegang', 'Xiegang', 'Xiegang,Xiegang Zhen,xie gang,xie gang zhen,谢岗,谢岗镇', 22.9610100, 114.1409700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23430, 'Qiaotou', 'Qiaotou', 'Qiaotou,Qiaotou Zhen,qiao tou,qiao tou zhen,桥头,桥头镇', 23.0246600, 114.0922700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23431, 'Wanjiangqu', 'Wanjiangqu', 'Wanjiang Jiedao,Wanjiangqu,wan jiang,wan jiang jie dao,万江,万江街道', 23.0575300, 113.7365200, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23432, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Jiedao,nan cheng,nan cheng jie dao,南城,南城街道', 23.0248600, 113.7437300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23433, 'Piaojia', 'Piaojia', 'Wanghu Manzuxiang,pu jia,wang hu man zu xiang,朴家,网户满族乡', 40.1912500, 120.1901800, 'CN', '2009-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23434, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Xiang,cheng jiao,cheng jiao xiang,城郊,城郊乡', 40.3346800, 120.3402900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23435, 'Gaodianzi', 'Gaodianzi', 'Gaodianzi,Gaodianzi Manzuxiang,gao dian zi,gao dian zi man zu xiang,高甸子,高甸子满族乡', 40.3834500, 120.1391800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23436, 'Maojiadian', 'Maojiadian', 'Maojiadian,Maojiadian Zhen,mao jia dian,mao jia dian zhen,毛家店,毛家店镇', 43.0420800, 124.2930000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23437, 'Dasijiazi', 'Dasijiazi', 'Dasijiazi,Dasijiazi Xiang,da si jia zi,da si jia zi xiang,大四家子,大四家子乡', 42.7559000, 123.6369800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23438, 'Shibajiazi', 'Shibajiazi', 'Shibajiazi,Shibajiazi Xiang,shi ba jia zi,shi ba jia zi xiang,十八家子,十八家子乡', 42.6685400, 123.7558700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23439, 'Guyushu', 'Guyushu', 'Guyushu,Tongjiangkou Xiang,gu yu shu,tong jiang kou xiang,孤榆树,通江口乡', 42.6270500, 123.7037200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23440, 'Daxing', 'Daxing', 'Daxing,Daxing Xiang,da xing,da xing xiang,大兴,大兴乡', 42.7878300, 123.8445200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23441, 'Ertaizi', 'Ertaizi', 'Ertaizi,Taiping Xiang,er tai zi,tai ping xiang,二台子,太平乡', 42.8732400, 124.0519200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23442, 'Xia’ertai', 'Xia''ertai', 'Xia''ertai,Xia''ertai Xiang,Xia’ertai,Xia’ertai Xiang,xia er tai,xia er tai xiang,下二台,下二台乡', 42.9495000, 124.2915300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23443, 'Luzhou', 'Luzhou', 'Luzhou,Luzhou Zhen,lu zhou,lu zhou zhen,芦洲,芦洲镇', 23.3662600, 114.5235900, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23444, 'Pianbai', 'Pianbai', 'Pianbai,Pianbai Xiang,pian bai,pian bai xiang,偏柏,偏柏乡', 29.0310900, 109.0922100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23445, 'Wufu', 'Wufu', 'Wufu,Wufu Xiang,wu fu,wu fu xiang,五福,五福乡', 29.1217100, 109.1174700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23446, 'Dahe', 'Dahe', 'Dahe,Dahe Zhen,da he,da he zhen,大河,大河镇', 29.4320300, 109.1786900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23447, 'Shangzhai', 'Shangzhai', 'Lushui,Lushui Xiang,Lüshui,Lüshui Xiang,Shangzhai,lu shui xiang,shang zhai,上寨,绿水乡', 29.3798100, 109.3009800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23448, 'Piduhe', 'Piduhe', 'Huoyanxiang,Piduhe,huo yan xiang,pi du he,火岩乡,皮渡河', 29.2368200, 109.3164400, 'CN', '2011-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23449, 'Shadiping', 'Shadiping', 'Badagongshan Xiang,Shadiping,ba da gong shan xiang,sha de ping,八大公山乡,砂地坪', 29.6649300, 109.8215200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23450, 'Geleche', 'Geleche', 'Geleche,Geleche Xiang,ge lei che,ge lei che xiang,革勒车,革勒车乡', 29.5502200, 109.2456200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23451, 'Keda', 'Keda', 'Keda,Keda Xiang,ke da,ke da xiang,可大,可大乡', 29.0289400, 109.2405900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23452, 'Jiajiaba', 'Jiajiaba', 'Jiaba,Jiaba Xiang,Jiajiaba,gu ba,gu ba xiang,gu jia ba,贾坝,贾坝乡,贾家坝', 29.1443700, 109.3842200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23453, 'Shaoha', 'Shaoha', 'Shaoha,Shaoha Xiang,shao ha,shao ha xiang,勺哈,勺哈乡', 29.0227400, 109.7681700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23454, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 23.7321600, 113.0582700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23455, 'Henghe', 'Henghe', 'Henghe,Henghe Jiedao,heng he,heng he jie dao,横荷,横荷街道', 23.6330800, 113.0597300, 'CN', '2012-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23456, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Jiedao,cheng jiao,cheng jiao jie dao,城郊,城郊街道', 23.5653600, 113.5735400, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23457, 'Jiangpu', 'Jiangpu', 'Jiangpu,Jiangpu Jiedao,jiang bu,jiang bu jie dao,江埔,江埔街道', 23.5449000, 113.5965100, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23458, 'Tongqiao', 'Tongqiao', 'Tongqiao,Tongqiao Zhen,tong qiao,潼桥', 23.0193900, 114.3375400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23459, 'Henan’an', 'Henan''an', 'Henan''an,Henan''an Jiedao,Henan’an,Henan’an Jiedao,he nan an,he nan an jie dao,河南岸,河南岸街道', 23.0726900, 114.4185300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23460, 'Huihuan', 'Huihuan', 'Huihuan,Huihuan Jiedao,hui huan,hui huan jie dao,惠环,惠环街道', 23.0327900, 114.3668700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23461, 'Shazhuang', 'Shazhuang', 'Shazhuang,Shazhuang Jiedao,sha zhuang,沙庄', 23.1333000, 113.8350700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23462, 'Dipa', 'Dipa', 'Dipa,Dipa Zhen,Dipai Zhen,de pai,de pai zhen,地派,地派镇', 23.8474700, 114.0803500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23463, 'Houzhai', 'Houzhai', 'Houzhai,hou zhai,后宅', 23.4243600, 117.0165900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23464, 'Piaojia', 'Piaojia', 'Piaojia,Wanghu Manzuxiang,pu jia,wang hu man zu xiang,朴家,网户满族乡', 40.1912500, 120.1901800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23465, '城郊', 'cheng jiao', 'Chengjiao Xiang,cheng jiao xiang,城郊乡', 40.3346800, 120.3402900, 'CN', '2013-07-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23466, 'Gaodianzi', 'Gaodianzi', 'Gaodianzi Manzuxiang,gao dian zi,gao dian zi man zu xiang,高甸子,高甸子满族乡', 40.3834500, 120.1391800, 'CN', '2009-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23467, 'Laowobao', 'Laowobao', 'Laowobao,Shandongtun Xiang,lao wo bao,shan dong tun xiang,山东屯乡,老窝堡', 42.9310600, 123.5333700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23468, 'Liangjiazi', 'Liangjiazi', 'Liangjiazi,Liangjiazi Xiang,liang jia zi,liang jia zi xiang,两家子,两家子乡', 42.7783500, 123.4853800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23469, 'Xiguantun Muguzu Manzuxiang', 'Xiguantun Muguzu Manzuxiang', 'Xiguantun,Xiguantun Muguzu Manzuxiang,xi guan tun,xi guan tun meng gu zu man zu xiang,西关屯,西关屯蒙古族满族乡', 42.5749500, 123.1652500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23470, 'Xizhahaqi', 'Xizhahaqi', 'Shajintai Muguzu Manzuxiang,Xizhahaqi,sha jin tai meng gu zu man zu xiang,xi zha ha qi,沙金台蒙古族满族乡,西扎哈气', 42.6760300, 122.8861900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23471, 'Zhangqiang', 'Zhangqiang', 'Zhangqiang,Zhangqiang Zhen,zhang qiang,zhang qiang zhen,张强,张强镇', 42.6834800, 122.9914500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23472, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Manzu Muguzu Xiang,dong sheng,dong sheng man zu meng gu zu xiang,东升,东升满族蒙古族乡', 42.6523200, 123.1307700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23473, 'Haizhouwobao', 'Haizhouwobao', 'Haizhouwobao,Haizhouwobao Xiang,hai zhou wo bao,hai zhou wo bao xiang,海州窝堡,海州窝堡乡', 42.9382300, 123.3708100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23474, 'Dongguantun', 'Dongguantun', 'Dongguantun,Dongguantun Zhen,dong guan tun,dong guan tun zhen,东关屯,东关屯镇', 42.6924900, 123.3490900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23475, 'Hedong', 'Hedong', 'Hedong,Hedong Zhen,he dong,河东', 22.9795600, 115.6486600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23476, 'Neihu', 'Neihu', 'Neihu,Neihu Zhen,nei hu,nei hu zhen,内湖,内湖镇', 22.9788200, 115.8240300, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23477, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,cheng nan,城南', 23.2721700, 116.6050200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23478, 'Longxiang', 'Longxiang', 'Longxiang,Longxiang Jiedao,long xiang,龙祥', 23.4107700, 116.7208700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23479, 'Dongzhou', 'Dongzhou', 'Dongzhou,Dongzhou Jiedao,dong zhou,东洲', 22.7130400, 115.5270600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23480, 'Nianpan', 'Nianpan', 'Nianpan,Nianpan Xiang,nian pan,nian pan xiang,碾盘,碾盘乡', 32.3660300, 106.8463200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23481, 'Heitan', 'Heitan', 'Heitan,Heitan Xiang,hei tan,hei tan xiang,黑潭乡,黒潭', 32.0336100, 106.6526700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23482, 'Heping', 'Heping', 'Heping,Heping Xiang,he ping,he ping xiang,和平,和平乡', 32.0462000, 106.5570200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23483, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Xiang,gao qiao,gao qiao xiang,高桥,高桥乡', 32.0928300, 106.8369700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23484, 'Pinggang', 'Pinggang', 'Pinggang,Pinggang Xiang,ping gang,ping gang xiang,平岗,平岗乡', 32.0944000, 106.8884200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23485, 'Dongyu', 'Dongyu', 'Dongyu,Dongyu Zhen,dong yu,dong yu zhen,东榆,东榆镇', 32.3116000, 106.8198500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23486, 'Zhaipo', 'Zhaipo', 'Zhaipo,Zhaipo Xiang,zhai po,zhai po xiang,寨坡,寨坡乡', 32.5964300, 106.8323300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23487, 'Guanba', 'Guanba', 'Guanba,Guanba Xiang,guan ba,guan ba xiang,关坝,关坝乡', 32.5968400, 106.9589000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23488, 'Qiaoting', 'Qiaoting', 'Qiaoting,Qiaoting Xiang,qiao ting,qiao ting xiang,桥亭,桥亭乡', 32.4649200, 106.8982300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23489, 'Tuanjie', 'Tuanjie', 'Tuanjie,Tuanjie Xiang,tuan jie,tuan jie xiang,团结,团结乡', 32.2884100, 106.7404600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23490, 'Leba', 'Leba', 'Leba,Leba Zhen,le ba,le ba zhen,乐坝,乐坝镇', 32.2655000, 106.6780900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23491, 'Guanlu', 'Guanlu', 'Guanlu,Guanlu Xiang,guan lu,guan lu xiang,关路,关路乡', 32.3364600, 106.9745200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23492, 'Xingma', 'Xingma', 'Xingma,Xingma Xiang,xing ma,xing ma xiang,兴马,兴马乡', 32.2478500, 106.9713300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23493, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃园,桃园镇', 32.6689600, 106.7999800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23494, 'Qiaodong', 'Qiaodong', 'Qiaodong,Qiaodong Jiedao,qiao dong,桥东', 23.6639500, 116.6556000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23495, 'Yujiao', 'Yujiao', 'Yujiao,Yujiao Zhen,yu jiao,yu jiao zhen,玉滘,玉滘镇', 23.6137900, 116.5164500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23496, 'Yongchang', 'Yongchang', 'Beichuan Xian,Yongchang,yong chang,永昌', 31.6657400, 104.4372600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23497, 'Yanzhou', 'Yanzhou', 'Yanzhou,yan zhou,盐洲', 22.7257200, 114.9386600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23498, 'Xiaomo', 'Xiaomo', 'Xiaomo,xiao mo,小漠', 22.7769000, 115.0338000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23499, 'Chigang', 'Chigang', 'Chigang,Chigang Zhen,chi gang,赤岗', 23.4355000, 116.1688300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23500, 'Hongyang', 'Hongyang', 'Hongyang,Hongyang Zhen,hong yang,hong yang zhen,洪阳,洪阳镇', 23.4308900, 116.2141700, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23501, 'Gaotuo', 'Gaotuo', 'Gaotuo,Gaotuo Zhen,gao tuo,gao tuo zhen,高坨,高坨镇', 41.1340200, 122.6597200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23502, 'Haizhou', 'Haizhou', 'Haizhou,Haizhou Jiedao,hai zhou,hai zhou jie dao,海州,海州街道', 40.8486300, 122.7415100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23503, 'Tangnan', 'Tangnan', 'Tangnan,Tangnan Zhen,tang nan,tang nan zhen,塘南,塘南镇', 31.4142300, 118.6580200, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23504, 'Baitugang', 'Baitugang', 'Baitugang,Baitugang Zhen,bai tu gang,bai tu gang zhen,白土岗,白土岗镇', 33.4470100, 112.3665300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23505, 'Danyang', 'Danyang', 'Danyang,Danyang Zhen,dan yang,dan yang zhen,丹阳,丹阳镇', 31.6263800, 118.7155600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23506, 'Yuxikou', 'Yuxikou', 'Yuxikou,Yuxikou Jiedao,yu xi kou,yu xi kou jie dao,裕溪口,裕溪口街道', 31.4311900, 118.3055700, 'CN', '2012-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23507, 'Zhangzhen', 'Zhangzhen', 'Zhangzhen,Zhangzhen Jiedao,zhang zhen,zhang zhen jie dao,张镇,张镇街道', 31.3064600, 118.5308200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23508, 'Xiexiang', 'Xiexiang', 'Xiexiang,Zhaozheng Zhen,xie ji,zhao zheng zhen,昭郑镇,谢集', 31.8246900, 118.0453700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23509, 'Shanhou', 'Shanhou', 'Shanhou,Shanhou Zhen,shan hou,shan hou zhen,善厚,善厚镇', 31.8749300, 118.1559400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23510, 'Limiao', 'Limiao', 'Limiao,li miao,李庙', 34.0525400, 109.8986600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23511, 'Xiwang', 'Xiwang', 'Xiwang,xi wang,席王', 34.2876800, 109.0567700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23512, 'Dongyang', 'Dongyang', 'Dongyang,dong yang,东阳', 34.3842800, 109.6276600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23513, 'Daming', 'Daming', 'Daming,Daming Zhen,da ming,大明', 34.4294400, 109.6723000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23514, 'Jinhui', 'Jinhui', 'Jinhui,jin hui,金惠', 34.4307900, 109.7000800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23515, 'Xinglin', 'Xinglin', 'Xinglin,Xinglin Zhen,xing lin,杏林', 34.4937100, 109.7607000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23516, 'Longbei', 'Longbei', 'Longbei,long bei,龙背', 34.5437700, 109.5716900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23517, 'Bijia', 'Bijia', 'Bijia,bi jia,毕家', 34.5824400, 109.8384500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23518, 'Nanshi', 'Nanshi', 'Nanshi,nan shi,南师', 34.6509700, 109.6277800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23519, 'Dongshangguan', 'Dongshangguan', 'Dongshangguan,dong shang guan,东上官', 34.7298400, 109.2164300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23520, 'Dongyang', 'Dongyang', 'Dongyang,dong yang,东杨', 34.9275200, 109.6299300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23521, 'Sanshan', 'Sanshan', 'Sanshan,Sanshan Jiedao,Sanshan Zhen,san shan,san shan jie dao,san shan zhen,三山,三山街道,三山镇', 31.2124400, 118.2298700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23522, 'Jinjiazhuang', 'Jinjiazhuang', 'Jinjiazhuang,Jinjiazhuang Jiedao,Jinjiazhuang Qu,jin jia zhuang,jin jia zhuang jie dao,jin jia zhuang qu,金家庄,金家庄区,金家庄街道', 31.7201200, 118.4895300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23523, 'Jinping', 'Jinping', 'Jinping,Jinping Xiang,jin ping,jin ping xiang,金坪,金坪乡', 29.2471100, 110.9583400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23524, 'Yanghe', 'Yanghe', 'Yanghe,Yanghe Tujiazuxiang,yang he,yang he tu jia zu xiang,阳和,阳和土家族乡', 29.2650200, 110.7041000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23525, 'Xilian', 'Xilian', 'Xilian,Xilian Xiang,xi lian,xi lian xiang,西莲,西莲乡', 29.6791800, 110.7286000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23526, 'Yujiazui', 'Yujiazui', 'Suoxiyu,Suoxiyu Tujiazuxiang,Yujiazui,suo xi yu,suo xi yu tu jia zu xiang,yu jia zi,喻家觜,索溪峪,索溪峪土家族乡', 29.3533700, 110.5626900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23527, 'Liulang', 'Liulang', 'Liulang,Xiehe,Xiehe Xiang,liu lang,xie he,xie he xiang,协合,协合乡,柳榔', 29.2930600, 110.5094700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23528, 'Jianxin', 'Jianxin', 'Jianxin,Yanghuping,Yanghuping Zhen,jian xin,yang hu ping,yang hu ping zhen,建新,阳湖坪,阳湖坪镇', 29.1431500, 110.5502300, 'CN', '2011-08-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23529, 'Huancheng', 'Huancheng', 'Huancheng,huan cheng,环城', 33.0145300, 112.5394700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23530, 'Pushan', 'Pushan', 'Pushan,Pushan Zhen,pu shan,pu shan zhen,蒲山,蒲山镇', 33.1197000, 112.5947900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23531, 'Zheshan', 'Zheshan', 'Zheshan,Zheshan Zhen,zhe shan,zhe shan zhen,遮山,遮山镇', 33.0446400, 112.3516700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23532, 'Taishanmiao', 'Taishanmiao', 'Taishanmiao,tai shan miao,太山庙', 33.3963700, 112.6431300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23533, 'Longxing', 'Longxing', 'Longxing,long xing,龙兴', 33.1973700, 112.4064700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23534, 'Yaoshan', 'Yaoshan', 'Yaoshan,Yaoshan Zhen,yao shan,yao shan zhen,尧山,尧山镇', 33.7526300, 112.3837300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23535, 'Kuzhuping', 'Kuzhuping', 'Kuzhuping,Kuzhuping Xiang,ku zhu ping,ku zhu ping xiang,苦竹坪,苦竹坪乡', 29.6470800, 110.0841300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23536, 'Suoziqiu', 'Suoziqiu', 'Mahekou,Mahekou Baizuxiang,Suoziqiu,ma he kou,ma he kou bai zu xiang,suo zi qiu,梭子丘,马合口,马合口白族乡', 29.5432400, 110.3662000, 'CN', '2011-08-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23537, 'Zoumaping', 'Zoumaping', 'Zoumaping,Zoumaping Baizuxiang,zou ma ping,zou ma ping bai zu xiang,走马坪,走马坪白族乡', 29.4718900, 110.4415000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23538, 'Huochiyu', 'Huochiyu', 'Guhuxiang,Huochiyu,huo chi yu,yu hu xiang,或池峪,汩湖乡', 29.4628400, 110.4718500, 'CN', '2011-08-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23539, 'Guluoshan', 'Guluoshan', 'Guluoshan,Guluoshan Xiang,gu luo shan,gu luo shan xiang,谷罗山,谷罗山乡', 29.5880100, 110.1919600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23540, 'Xiaobutou', 'Xiaobutou', 'Daguquan,Daguquan Xiang,Xiaobutou,da gu quan,da gu quan xiang,xiao bu tou,小埠头,打鼓泉,打鼓泉乡', 29.4607300, 110.0975100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23541, 'Kongkeshu', 'Kongkeshu', 'Kongkeshu,Kongkeshu Xiang,kong ke shu,kong ke shu xiang,空壳数,空壳树乡', 29.4399500, 110.3443200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23542, 'Zouma', 'Zouma', 'Zouma,Zouma Zhen,zou ma,zou ma zhen,走马,走马镇', 29.8299300, 110.4283600, 'CN', '2011-08-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23543, 'Baiguo', 'Baiguo', 'Baiguo,Baiguo Zhen,bai guo,bai guo zhen,白果,白果镇', 29.8841000, 110.4561500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23544, 'Fengxianggang', 'Fengxianggang', 'Fengxianggang,Fengxianggang Xiang,feng xiang gang,feng xiang gang xiang,枫香岗,枫香岗乡', 29.1100700, 110.3938800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23545, 'Xiangjiazhai', 'Xiangjiazhai', 'Sanjiatian,Sanjiatian Xiang,Xiangjiazhai,san jia tian,san jia tian xiang,xiang jia zhai,三家田,三家田乡,向家寨', 29.2068500, 110.0050800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23546, 'Shadi', 'Shadi', 'Shadi,Shadi Xiang,sha di,sha di xiang,沙堤,沙堤乡', 29.1899800, 110.4629200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23547, 'Yinjiaxi', 'Yinjiaxi', 'Yinjiaxi,Yinjiaxi Zhen,yin jia xi,yin jia xi zhen,尹家溪,尹家溪镇', 29.1371700, 110.4092500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23548, 'Qingping', 'Qingping', 'Qingping,Qingping Zhen,qing ping,qing ping zhen,青坪,青坪镇', 29.0282400, 110.2280800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23549, 'Xiheshan', 'Xiheshan', 'Xiheshan,Xiheshan Jiedao,xi he shan,xi he shan jie dao,西褐山,西褐山街道', 31.4430200, 118.3489300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23550, 'Jinghu', 'Jinghu', 'Jinghu,Jinghu Qu,jing hu,jing hu qu,镜湖,镜湖区', 31.3475800, 118.3682900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23551, 'Yijiang', 'Yijiang', 'Yijiang,Yijiang Qu,yi jiang,yi jiang qu,弋江,弋江区', 31.3154600, 118.3605300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23552, 'Louziqiu', 'Louziqiu', 'lou zi qiu,楼子丘', 29.5432400, 110.3662000, 'CN', '2009-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23553, 'Wuli', 'Wuli', 'Wuli Xiang,wu li,wu li xiang,五里,五里乡', 29.8964600, 110.3449800, 'CN', '2009-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23554, 'Cangtou', 'Cangtou', 'Cangtou,cang tou,仓头', 33.8759800, 112.7915600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23555, 'Zhanbei', 'Zhanbei', 'Zhanbei,zhan bei,湛北', 33.7779300, 113.4440700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23556, 'Ziyun', 'Ziyun', 'Ziyun,Ziyun Zhen,zi yun,zi yun zhen,紫云,紫云镇', 33.8197400, 113.4294600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23557, 'Fenchen', 'Fenchen', 'Fenchen,fen chen,汾陈', 33.9707100, 113.5307600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23558, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,lian hua,lian hua zhen,莲花,莲花镇', 33.5976800, 113.8196600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23559, 'Tianzhuang', 'Tianzhuang', 'Tianzhuang,tian zhuang,田庄', 33.5674700, 113.3537200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23560, 'Sipo', 'Sipo', 'Sipo,si po,寺坡', 33.2809700, 113.5171800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23561, 'Yuanling', 'Yuanling', 'Yuanling,yuan ling,院岭', 33.2823400, 113.4596000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23562, 'Zhulan', 'Zhulan', 'Zhulan,zhu lan,朱兰', 33.3191200, 113.5294600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23563, 'Kuangshan', 'Kuangshan', 'Kuangshan,kuang shan,矿山', 33.3787400, 113.4957300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23564, 'Zaolin', 'Zaolin', 'Zaolin,zao lin,枣林', 33.3657500, 113.5844000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23565, 'Zhuyu', 'Zhuyu', 'Zhuyu,zhu yu,竹峪', 34.1356100, 108.0390200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23566, 'Diantou', 'Diantou', 'Diantou,Diantou Zhen,dian tou,dian tou zhen,店头,店头镇', 34.5402600, 108.0100000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23567, 'Xujia', 'Xujia', 'Xujia,Xujia Jieban,xu jia,xu jia jie ban,徐家,徐家街办', 34.3400000, 108.9625000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23568, 'Xinjiamiao', 'Xinjiamiao', 'Xinjiamiao,Xinjiamiao Jieban,xin jia miao,xin jia miao jie ban,辛家庙,辛家庙街办', 34.3055000, 108.9883200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23569, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Jieban,xi cheng,xi cheng jie ban,西城,西城街办', 34.3080500, 108.4416800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23570, 'Gudu', 'Gudu', 'Gudu,Gudu Jieban,gu du,gu du jie ban,古渡,古渡街办', 34.3456000, 108.6931300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23571, 'Weiyang', 'Weiyang', 'Weiyang,Weiyang Jieban,wei yang,wei yang jie ban,渭阳,渭阳街办', 34.3548700, 108.7394900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23572, 'Weicheng', 'Weicheng', 'Weicheng,Weicheng Qu,wei cheng,wei cheng qu,渭城,渭城区', 34.3314000, 108.7169100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23573, 'Qindu', 'Qindu', 'Qindu,Qindu Qu,qin dou,qin dou qu,秦都,秦都区', 34.3418600, 108.7082400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23574, 'Weiyang', 'Weiyang', 'Weiyang,Weiyang Qu,wei yang,wei yang qu,未央,未央区', 34.2906000, 108.9355400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23575, 'Xincheng', 'Xincheng', 'Xincheng,Xincheng Qu,xin cheng,xin cheng qu,新城,新城区', 34.2632100, 108.9495400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23576, 'Beilin', 'Beilin', 'Beilin,Beilin Qu,bei lin,bei lin qu,碑林,碑林区', 34.2284600, 108.9156600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23577, 'Wangsi', 'Wangsi', 'Wangsi,Wangsi Jieban,wang si,wang si jie ban,王寺,王寺街办', 34.2506500, 108.7938100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23578, 'Tongchuan', 'Tongchuan', 'Tongchuan,Tongchuan Shi,tong chuan,tong chuan shi,铜川,铜川市', 34.8988000, 108.9505600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23579, 'Zhangjiabao', 'Zhangjiabao', 'Zhangjiabao,Zhangjiabao Jieban,zhang jia bao,zhang jia bao jie ban,张家堡,张家堡街办', 34.3291300, 108.9370300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23580, 'Dianzicheng', 'Dianzicheng', 'Dianzicheng,Dianzicheng Jieban,dian zi cheng,dian zi cheng jie ban,电子城,电子城街办', 34.1917200, 108.9041300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23581, 'Changyanbao', 'Changyanbao', 'Changyanbao,Changyanbao Jieban,zhang yan bao,zhang yan bao jie ban,长延堡,长延堡街办', 34.1935200, 108.9498900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23582, 'Lianhu', 'Lianhu', 'Lianhu,Lianhu Qu,lian hu,lian hu qu,连湖,连湖区', 34.2584800, 108.9242100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23583, 'Longmenfan', 'Longmenfan', 'Longmenfan,Longmenfan Xiang,long men fan,long men fan xiang,龙门畈,龙门畈乡', 28.5004600, 117.6511300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23584, 'Qingban', 'Qingban', 'Qingban,Qingban Xiang,qing ban,qing ban xiang,青板,青板乡', 28.5095400, 117.5720200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23585, 'Qinghu', 'Qinghu', 'Qinghu,Qinghu Xiang,qing hu,qing hu xiang,清湖,清湖乡', 28.3453200, 117.3516300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23586, 'Nanyan', 'Nanyan', 'Nanyan,Nanyan Zhen,nan yan,nan yan zhen,南岩,南岩镇', 28.3993900, 117.4477800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23587, 'Guifeng', 'Guifeng', 'Guifeng,Guifeng Zhen,gui feng,gui feng zhen,圭峰,圭峰镇', 28.3257000, 117.3740900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23588, 'Zhukeng', 'Zhukeng', 'Zhukeng,Zhukeng Zhen,zhu keng,zhu keng zhen,朱坑,朱坑镇', 28.3926300, 117.5127500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23589, 'Lianhe', 'Lianhe', 'Lianhe,Lianhe Xiang,lian he,lian he xiang,莲荷,莲荷乡', 28.3891500, 117.6310700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23590, 'Sipu', 'Sipu', 'Sipu,Sipu Xiang,si pu,si pu xiang,司铺,司铺乡', 28.4366300, 117.7086800, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23591, 'Bangluo', 'Bangluo', 'Bangluo,Bangluo Xiang,bang luo,bang luo xiang,傍罗,傍罗乡', 28.3057500, 117.7937800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23592, 'Qingxi', 'Qingxi', 'Qingxi,Qingxi Zhen,qing xi,qing xi zhen,青溪,青溪镇', 28.3044700, 117.8639100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23593, 'Yongping', 'Yongping', 'Yongping,Yongping Zhen,yong ping,yong ping zhen,永平,永平镇', 28.2155400, 117.7777000, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23594, 'Dieshan', 'Dieshan', 'Dieshan,Dieshan Zhen,die shan,die shan zhen,叠山,叠山镇', 28.2142100, 117.5086600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23595, 'Liukou', 'Liukou', 'Liukou,Liukou Zhen,liu kou,liu kou zhen,流口,流口镇', 28.2815000, 117.2570200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23596, 'Jianzhu', 'Jianzhu', 'Jianzhu,Jianzhu Xiang,jian zhu,jian zhu xiang,箭竹,箭竹乡', 28.2641300, 117.3257900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23597, 'Yanglin', 'Yanglin', 'Yanglin,Yanglin Xiang,yang lin,yang lin xiang,杨林,杨林乡', 28.1411700, 117.6918800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23598, 'Hufang', 'Hufang', 'Hufang,Hufang Zhen,hu fang,hu fang zhen,湖坊,湖坊镇', 28.1612500, 117.5535700, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23599, 'Chenfang', 'Chenfang', 'Chenfang,Chenfang Xiang,chen fang,chen fang xiang,陈坊,陈坊乡', 28.0527700, 117.5439200, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23600, 'Zixi', 'Zixi', 'Zixi,Zixi Xiang,zi xi,zi xi xiang,紫溪,紫溪乡', 28.0694900, 117.7840000, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23601, 'Sanxianling', 'Sanxianling', 'Sanxianling,Sanxianling Xiang,san xian ling,san xian ling xiang,三县岭,三县岭乡', 28.6704900, 117.3269200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23602, 'Zhongfan', 'Zhongfan', 'Zhongfan,Zhongfan Xiang,zhong fan,zhong fan xiang,中畈,中畈乡', 28.5403800, 117.3782000, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23603, 'Xinhuang', 'Xinhuang', 'Xinhuang,Xinhuang Xiang,xin huang,xin huang xiang,新篁,新篁乡', 28.7135400, 117.6013800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23604, 'Wanli', 'Wanli', 'Wanli,Wanli Xiang,wan li,wan li xiang,湾里,湾里乡', 28.4536400, 117.3731400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23605, 'Gexi', 'Gexi', 'Gexi,Gexi Xiang,ge xi,ge xi xiang,葛溪,葛溪乡', 28.4642400, 117.4587700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23606, 'Xintan', 'Xintan', 'Xintan,Xintan Xiang,xin tan,xin tan xiang,新滩,新滩乡', 28.3331900, 117.6794100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23607, 'Xuguang', 'Xuguang', 'Xuguang,Xuguang Xiang,xu guang,xu guang xiang,旭光,旭光乡', 28.2682900, 117.4245800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23608, 'Jiaxuan', 'Jiaxuan', 'Jiaxuan,Jiaxuan Xiang,jia xuan,jia xuan xiang,稼轩,稼轩乡', 28.1883600, 117.8247200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23609, 'Huatanshan', 'Huatanshan', 'Huatanshan,Huatanshan Zhen,hua tan shan,hua tan shan zhen,华坛山,华坛山镇', 28.7109000, 117.8150800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23610, 'Shiren', 'Shiren', 'Shiren,Shiren Xiang,shi ren,shi ren xiang,石人,石人乡', 28.6559500, 117.8978100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23611, 'Wangcun', 'Wangcun', 'Wangcun,Wangcun Xiang,wang cun,wang cun xiang,汪村,汪村乡', 28.5969600, 117.9649700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23612, 'Qingshui', 'Qingshui', 'Qingshui,Qingshui Xiang,qing shui,qing shui xiang,清水,清水乡', 28.5464600, 117.8853900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23613, 'Huanggu', 'Huanggu', 'Huanggu,Huanggu Zhen,huang gu,huang gu zhen,煌固,煌固镇', 28.5808300, 117.9809500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23614, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Xiang,chao yang,chao yang xiang,朝阳,朝阳乡', 28.4439200, 118.0695900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23615, 'Lingxi', 'Lingxi', 'Lingxi,Lingxi Zhen,ling xi,ling xi zhen,灵溪,灵溪镇', 28.4989900, 118.0257500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23616, 'Shishi', 'Shishi', 'Shishi,Shishi Xiang,shi shi,shi shi xiang,石狮,石狮乡', 28.5018000, 117.9734800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23617, 'Chating', 'Chating', 'Chating,Chating Zhen,cha ting,cha ting zhen,茶亭,茶亭镇', 28.3566800, 117.8879800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23618, 'Huangshaling', 'Huangshaling', 'Huangshaling,Huangshaling Xiang,huang sha ling,huang sha ling xiang,黄沙岭,黄沙岭乡', 28.2435800, 117.9528100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23619, 'Sishiba', 'Sishiba', 'Sishiba,Sishiba Zhen,si shi ba,si shi ba zhen,四十八,四十八镇', 28.2299100, 118.0276200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23620, 'Sanqing', 'Sanqing', 'Sanqing,Sanqing Xiang,san qing,san qing xiang,三清,三清乡', 28.9258100, 118.0931500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23621, 'Zihu', 'Zihu', 'Zihu,Zihu Zhen,zi hu,zi hu zhen,紫湖,紫湖镇', 28.9056200, 118.1545800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23622, 'Nanshan', 'Nanshan', 'Nanshan,Nanshan Xiang,nan shan,nan shan xiang,南山,南山乡', 28.8034400, 118.0854100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23623, 'Danan', 'Danan', 'Danan,Danan Zhen,da nan,da nan zhen,大南,大南镇', 28.5485200, 118.2440400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23624, 'Huacun', 'Huacun', 'Huacun,Huacun Xiang,hua cun,hua cun xiang,华村,华村乡', 28.5877500, 118.2945100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23625, 'Gaozhou', 'Gaozhou', 'Gaozhou,Gaozhou Xiang,gao zhou,gao zhou xiang,高洲,高洲乡', 28.1285100, 118.0740200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23626, 'Wufushan', 'Wufushan', 'Wufushan,Wufushan Zhen,wu fu shan,wu fu shan zhen,五府山,五府山镇', 28.1433000, 118.0474300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23627, 'Baitian', 'Baitian', 'Baitian,Baitian Xiang,bai tian,bai tian xiang,白田,白田乡', 28.5096000, 117.2563300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23628, 'Zhiguang', 'Zhiguang', 'Zhiguang,Zhiguang Zhen,zhi guang,志光', 28.3610000, 117.0772300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23629, 'Binjiang', 'Binjiang', 'Binjiang,Binjiang Xiang,bin jiang,bin jiang xiang,滨江,滨江乡', 28.2952600, 117.1844400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23630, 'Luohe', 'Luohe', 'Luohe,Luohe Zhen,luo he,luo he zhen,罗河,罗河镇', 28.2101700, 117.1773700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23631, 'Jintun', 'Jintun', 'Jintun,Jintun Zhen,jin tun,jin tun zhen,金屯,金屯镇', 28.1257100, 117.2277800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23632, 'Tangwan', 'Tangwan', 'Tangwan,Tangwan Zhen,tang wan,tang wan zhen,塘湾,塘湾镇', 28.0768700, 117.2256300, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23633, 'Yujia', 'Yujia', 'Yujia,Yujia Xiang,yu jia,yu jia xiang,余家,余家乡', 28.1753800, 117.0241200, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23634, 'Huaqiao', 'Huaqiao', 'Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,画桥,画桥镇', 28.5161400, 117.0428800, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23635, 'Dayuan', 'Dayuan', 'Dayuan,Dayuan Zhen,da yuan,da yuan zhen,大源,大源镇', 28.7382500, 117.1774100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23636, 'Longtoushan', 'Longtoushan', 'Longtoushan,Longtoushan Xiang,long tou shan,long tou shan xiang,龙头山,龙头山乡', 28.9479300, 117.8396400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23637, 'Zhenqiao', 'Zhenqiao', 'Zhenqiao,Zhenqiao Zhen,zhen qiao,zhen qiao zhen,镇桥,镇桥镇', 28.8980900, 117.0354800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23638, 'Wuyishan', 'Wuyishan', 'Wuyishan,Wuyishan Zhen,wu yi shan,wu yi shan zhen,武夷山,武夷山镇', 28.0047300, 117.8113800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23639, 'Huanggangshan', 'Huanggangshan', 'Huanggangshan,Huanggangshan Zhen,huang gang shan,huang gang shan zhen,黄岗山,黄岗山镇', 28.0106300, 117.7414500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23640, 'Tongfan', 'Tongfan', 'Tongfan,Tongfan Zhen,tong fan,tong fan zhen,桐畈,桐畈镇', 28.3081700, 118.3104200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23641, 'Xiatang', 'Xiatang', 'Xiatang,Xiatang Xiang,xia tang,xia tang xiang,下塘,下塘乡', 28.6153100, 118.0991500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23642, 'Bimu', 'Bimu', 'Bimu,Bimu Zhen,bi mu,bi mu zhen,妼姆,妼姆镇', 28.6766200, 118.0989600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23643, 'Songfeng', 'Songfeng', 'Songfeng,Songfeng Xiang,song feng,song feng xiang,嵩峰,嵩峰乡', 28.3599100, 118.3938400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23644, 'Quanbo', 'Quanbo', 'Quanbo,Quanbo Zhen,quan bo zhen,quan po,泉波镇,泉破', 28.3807700, 118.3342100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23645, 'Xiaxi', 'Xiaxi', 'Xiaxi,Xiaxi Zhen,xia xi,xia xi zhen,下溪,下溪镇', 28.4597900, 118.1866900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23646, 'Guancun', 'Guancun', 'Guancun,Guancun Xiang,guan cun,guan cun xiang,管村,管村乡', 28.4758500, 118.4244900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23647, 'Lingyang', 'Lingyang', 'Lingyang,Lingyang Zhen,ling yang,ling yang zhen,岺阳,岺阳镇', 28.4234100, 117.6085400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23648, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,he kou,he kou zhen,河口,河口镇', 28.3195800, 117.7143700, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23649, 'Yiyang', 'Yiyang', 'Yiyang,Yiyang Zhen,yi yang,yi yang zhen,弋阳,弋阳镇', 28.4052100, 117.4321600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23650, 'Chenying', 'Chenying', 'Chenying,Chenying Zhen,chen ying,chen ying zhen,陈营,陈营镇', 28.6944100, 117.0671200, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23651, 'Zhushan', 'Zhushan', 'Zhushan,Zhushan Xiang,zhu shan,zhu shan xiang,珠山,珠山乡', 28.7057300, 117.0659000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23652, 'Zhiyang', 'Zhiyang', 'Zhiyang,Zhiyang Zhen,zhi yang zhen,滍阳镇', 33.7868400, 113.1350200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23653, 'Nanguzhuang', 'Nanguzhuang', 'Nanguzhuang,Nanguzhuang Jiedao,nan gu zhuang,nan gu zhuang jie dao,南顾庄,南顾庄街道', 33.9001900, 112.8765700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23654, 'Geyang', 'Geyang', 'Geyang,Geyang Zhen,ge yang,ge yang zhen,各羊,各羊镇', 24.9312500, 102.8032600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23655, 'Jiujie', 'Jiujie', 'Jiujie,Jiujie Zhen,jiu jie,jiu jie zhen,九街,九街镇', 24.1090800, 102.6842800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23656, 'Xuzhen', 'Xuzhen', 'Xuzhen,Xuzhen Zhen,xu zhen,xu zhen zhen,许镇,许镇镇', 31.0630700, 118.4036200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23657, 'Liqiao', 'Liqiao', 'Liqiao,Liqiao Zhen,li qiao,li qiao zhen,狸桥,狸桥镇', 31.2211200, 118.9202300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23658, 'Liulang', 'Liulang', 'Liulang,Liulang Zhen,liu lang,liu lang zhen,六郎,六郎镇', 31.2428500, 118.5404900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23659, 'Baiqiao', 'Baiqiao', 'Baiqiao,Baiqiao Zhen,bai qiao,bai qiao zhen,白桥,白桥镇', 31.5376600, 118.3082000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23660, 'Laoqiao', 'Laoqiao', 'Laoqiao,Laoqiaozhen,lao qiao,lao qiao zhen,姥桥,姥桥镇', 31.6090600, 118.3037000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23661, 'Zhishan', 'Zhishan', 'Zhishan,Zhishan Jiedao,zhi shan,zhi shan jie dao,芝山,芝山街道', 27.0437300, 118.3252300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23662, 'Shunyang', 'Shunyang', 'Shunyang,Shunyang Xiang,shun yang,shun yang xiang,顺阳,顺阳乡', 27.0953800, 118.5882600, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23663, 'Wuhu', 'Wuhu', 'Wuhu,Wuhu Xian,wu hu,wu hu xian,芜湖,芜湖县', 31.1463000, 118.5646500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23664, 'Dongzhou', 'Dongzhou', 'Dongzhou,dong zhou,董周', 33.7844100, 112.8070500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23665, 'Huayuan', 'Huayuan', 'Huayuan,hua yuan,花园', 32.7223900, 113.3196400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23666, 'Tongshan', 'Tongshan', 'Tongshan,tong shan,铜山', 32.7726000, 113.5569300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23667, 'Taishanmiao', 'Taishanmiao', 'Taishanmiao,tai shan miao,泰山庙', 32.8692400, 113.2083400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23668, 'Cuizhuang', 'Cuizhuang', 'Cuizhuang,Cuizhuang Xiang,cui zhuang,cui zhuang xiang,崔庄,崔庄乡', 33.5305800, 112.3934500, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23669, 'Chengjiao', 'Chengjiao', 'Chengjiao,cheng jiao,城郊', 33.4875600, 112.4404200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23670, 'Huanghou', 'Huanghou', 'Huanghou,huang hou,皇后', 33.4800400, 112.7569700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23671, 'Yangji', 'Yangji', 'Yangji,yang ji,杨集', 33.3272100, 112.9925700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23672, 'Qinghe', 'Qinghe', 'Qinghe,qing he,清河', 33.2506800, 112.9053100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23673, 'Wuxiang', 'Wuxiang', 'Wuxiang,Wuxiang Zhen,wu xiang,wu xiang zhen,五乡,五乡镇', 29.8460300, 121.6873500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23674, 'Liu’ao', 'Liu''ao', 'Liu''ao,Liu''ao Zhen,Liu’ao,Liu’ao Zhen,liu ao,liu ao zhen,六敖,六敖镇', 29.0852000, 121.5901300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23675, 'Minggang', 'Minggang', 'Minggang,Minggang Zhen,ming gang,ming gang zhen,明港,明港镇', 29.1913200, 121.6377500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23676, 'Duantang', 'Duantang', 'Duantang,Duantang Jiedao,duan tang,duan tang jie dao,段塘,段塘街道', 29.8506300, 121.5245400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23677, 'Dongqianhu', 'Dongqianhu', 'Dongqianhu,Dongqianhu Zhen,dong qian hu,dong qian hu zhen,东钱湖,东钱湖镇', 29.7914700, 121.6321600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23678, 'Tangtou', 'Tangtou', 'Tangtou,Tangxi,Tangxi Zhen,tang tou,tang xi,tang xi zhen,塘头,塘溪,塘溪镇', 29.6698900, 121.7134400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23679, 'Yongjiang', 'Yongjiang', 'Yongjiang,Yongjiang Zhen,yong jiang,yong jiang zhen,甬江,甬江镇', 29.9038700, 121.5786500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23680, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Jiedao,dong jiao,dong jiao jie dao,东郊,东郊街道', 29.8752000, 121.5866100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23681, 'Daying', 'Daying', 'Daying,Daying Zhen,da ying,da ying zhen,大营,大营镇', 33.9339000, 112.8938200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23682, 'Qianying', 'Qianying', 'Qianying,qian ying,前营', 33.9796500, 112.9092600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23683, 'Jingang', 'Jingang', 'Jingang,Jingang Jiedao,jin gang,jin gang jie dao,靳岗,靳岗街道', 33.0148500, 112.4959400, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23684, 'Chengjiao', 'Chengjiao', 'Chengjiao,cheng jiao,城郊', 33.0417800, 112.2547200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23685, 'Choujiang', 'Choujiang', 'Choujiang,Choujiang Zhen,chou jiang,chou jiang zhen,稠江,稠江镇', 29.2833900, 120.0275600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23686, 'Dachen', 'Dachen', 'Dachen,Dachen Zhen,da chen,da chen zhen,大陈,大陈镇', 29.4521000, 120.1252700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23687, 'Longshan', 'Longshan', 'Longshan,Longshan Zhen,long shan,long shan zhen,龙山,龙山镇', 29.0232100, 120.1820400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23688, 'Chenzhai', 'Chenzhai', 'Chenzhai,Chenzhai Zhen,chen zhai,chen zhai zhen,陈宅,陈宅镇', 29.4976300, 120.3365800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23689, 'Nanshi', 'Nanshi', 'Nanshi,Nanshi Jiedao,nan shi,nan shi jie dao,南市,南市街道', 29.1487500, 120.2297400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23690, 'Wuning', 'Wuning', 'Wuning,Wuning Jiedao,wu ning,wu ning jie dao,吴宁,吴宁街道', 29.2588700, 120.2310800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23691, 'Jiangbei', 'Jiangbei', 'Jiangbei,Jiangbei Jiedao,jiang bei,jiang bei jie dao,江北,江北街道', 29.3002800, 120.2322200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23692, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 29.2864600, 120.3228100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23693, 'Haoba', 'Haoba', 'Haoba,Haoba Zhen,hao ba,hao ba zhen,蒿坝,蒿坝镇', 29.9553000, 120.8477500, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23694, 'Zhutiantou', 'Zhutiantou', 'Jidong,Jidong Zhen,Zhutiantou,ji dong zhen,zhu tian tou,稽东镇,竹田头', 29.7764600, 120.5783300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23695, 'Fushan', 'Fushan', 'Fushan,Fushan Jiedao,fu shan,fu shan jie dao,府山,府山街道', 29.9982000, 120.5591200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23696, 'Jianhu', 'Jianhu', 'Jianhu,Jianhu Zhen,jian hu,jian hu zhen,鉴湖,鉴湖镇', 29.9798600, 120.5712400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23697, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,cheng nan,cheng nan jie dao,城南,城南街道', 29.9723700, 120.5674400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23698, 'Jishan', 'Jishan', 'Jishan,Jishan Jiedao,ji shan,ji shan jie dao,稽山,稽山街道', 29.9702600, 120.6050800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23699, 'Yongheshi', 'Yongheshi', 'Yonghe,Yonghe Zhen,Yongheshi,yong he shi,yong he zhen,永和市,永和镇', 29.9727000, 121.0454100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23700, 'Dongqiao', 'Dongqiao', 'Dongqiao,Dongqiao Zhen,dong qiao,dong qiao zhen,洞桥,洞桥镇', 29.7807400, 121.4029600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23701, 'Jinping', 'Jinping', 'Jinping,Jinping Jiedao,jin ping,jin ping jie dao,锦屏,锦屏街道', 29.6629500, 121.4022600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23702, 'Chengguan', 'Chengguan', 'Chengguan Zhen,cheng guan,cheng guan zhen,城关,城关镇', 29.2874600, 121.4315000, 'CN', '2009-11-28', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23703, 'Zhu’ao', 'Zhu''ao', 'Zhu''ao,Zhu''ao Zhen,Zhu’ao,Zhu’ao Zhen,zhu ao,zhu ao zhen,朱岙,朱岙镇', 29.0697200, 121.2859000, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23704, 'Meizhu', 'Meizhu', 'Meizhu,Meizhu Zhen,mei zhu,mei zhu zhen,梅渚,梅渚镇', 29.4771500, 120.7977900, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23705, 'Dacun', 'Dacun', 'Dacun,Hongtao,Hongtao Zhen,da cun,hong tao zhen,大村,洪涛镇', 29.0557400, 121.1979100, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23706, 'Pan’an', 'Pan''an', 'Pan''an,Pan’an,pan an,磐安', 29.0536800, 120.4375800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23707, 'Muzhijie', 'Muzhijie', 'Muzhijie,Muzhijie Xiang,mu zhi jie,mu zhi jie xiang,木植街,木植街乡', 33.9622100, 112.1652400, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23708, 'Arzak', 'Arzak', 'Arzak,Arzak Xiang,Azhake Xiang,a zha ke,a zha ke xiang,阿扎克,阿扎克乡', 39.6761600, 76.1201700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23709, 'Tangzhuang', 'Tangzhuang', 'Tangzhuang,Tangzhuang Xiang,tang zhuang,tang zhuang xiang,唐庄,唐庄乡', 33.1034200, 112.9482200, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23710, 'Chengjiao', 'Chengjiao', 'Chengjiao,cheng jiao,城郊', 33.0493500, 112.9258600, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23711, 'Liujia', 'Liujia', 'Liujia,Liujia Xiang,liu jia,liu jia xiang,柳家,柳家乡', 41.5000800, 122.1132800, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23712, 'Wujia', 'Wujia', 'Wujia,Wujia Xiang,wu jia,wu jia xiang,吴家,吴家乡', 41.4587400, 121.9987300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23713, 'Baojia', 'Baojia', 'Baojia,Baojia Zhen,bao jia,鲍家', 41.4998100, 121.7113300, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23714, 'Beizhen', 'Beizhen', 'Beizhen,Beizhen Shi,bei zhen,bei zhen shi,北镇,北镇市', 41.5958400, 121.7966400, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23715, 'Shanxi', 'Shanxi', 'Shanshenmiao Xiang,Shanxi,shan shen miao xiang,shan xi,山神庙乡,山西', 40.9378900, 120.5429200, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23716, 'Baimashi', 'Baimashi', 'Baimashi,Baimashi Xiang,bai ma shi,bai ma shi xiang,白马石,白马石乡', 40.9156700, 120.3501700, 'CN', '2012-01-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23717, 'Heiiyugou', 'Heiiyugou', 'Heiiyugou,Yangjiao Xiang,hei yu gou,yang jiao xiang,杨郊乡,黑鱼沟', 40.8043000, 120.5536800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23718, 'Jinjiao', 'Jinjiao', 'Jinjiao,Jinjiao Jiedao,jin jiao,jin jiao jie dao,锦郊,锦郊街道', 40.7447800, 120.8465200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23719, 'Yuhuang', 'Yuhuang', 'Yuhuang,Yuhuang Jiedao,yu huang,yu huang jie dao,玉皇,玉皇街道', 40.7317000, 120.8851700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23720, 'Longgang', 'Longgang', 'Longgang,Longgang Qu,long gang,long gang qu,龙港,龙港区', 40.7214600, 120.9255800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23721, 'Cishan', 'Cishan', 'Cishan,Lianwan Jiedao,ci shan,lian wan jie dao,茨山,连湾街道', 40.7444500, 120.9008500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23722, 'Dabaimashi', 'Dabaimashi', 'Beigang Jiedao,Dabaimashi,bei gang jie dao,da bai ma shi,北港街道,大白马石', 40.7652200, 120.9043000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23723, 'Donglinxi', 'Donglinxi', 'Donglinxi,Donglinxi Zhen,dong lin xi,dong lin xi zhen,东临溪,东临溪镇', 29.6759400, 118.2916900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23724, 'Fengjia', 'Fengjia', 'Fengjia,Fengjia Zhen,feng jia,feng jia zhen,封家,封家镇', 29.0158200, 118.4146500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23725, 'Xikou', 'Xikou', 'Linshan,Xikou,lin shan,xi kou,林山,溪口', 29.1462400, 118.4971500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23726, 'Jincun', 'Jincun', 'Jincun,Jincun Xiang,jin cun,jin cun xiang,金村,金村乡', 29.1818500, 118.4721900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23727, 'Yinkeng', 'Yinkeng', 'Xiayinkeng,Yinkeng,Yinkeng Xiang,xia yin keng,yin keng,yin keng xiang,下音坑,音坑,音坑乡', 29.1991300, 118.3987300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23728, 'Maotan', 'Maotan', 'Maotan,Suzhuang,Suzhuang Zhen,mao tan,su zhuang,su zhuang zhen,毛坦,苏庄,苏庄镇', 29.1781400, 118.1223500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23729, 'Jiukeng', 'Jiukeng', 'Jiukeng,jiu keng,鸠坑', 29.6801600, 118.7434300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23730, 'Shandi', 'Shandi', 'Diben,Shandi,di ben,shan di,山底,底本', 29.2432500, 118.4379700, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23731, 'Changshu City', 'Changshu City', '', 31.6461500, 120.7422100, 'CN', '2010-03-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23732, 'Shixing', 'Shixing', '', 24.9482400, 114.0657200, 'CN', '2010-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23733, 'Jiashan', 'Jiashan', '', 30.8491800, 120.9258300, 'CN', '2010-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23734, 'Fenghuang', 'Fenghuang', 'Fenkhuan'',Фенхуань', 27.9355700, 109.5996100, 'CN', '2010-07-26', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23735, 'Dehang', 'Dehang', 'Dekhang,Деханг', 28.3071000, 109.7966800, 'CN', '2010-07-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23736, 'Ma’qun', 'Ma''qun', 'Ma''qun,Ma''qun Jiedao,Ma’qun,Ma’qun Jiedao,ma qun,ma qun jie dao,马群,马群街道', 32.0552200, 118.8879700, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23737, 'Xiamazhuang', 'Xiamazhuang', 'Xiamazhuang,Yangkou Zhen,xia ma zhuang,yang kou zhen,下马庄,洋口镇', 32.5316400, 120.9479300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23738, 'Xujia Changzhuang', 'Xujia Changzhuang', 'Linghe,Linghe Zhen,Xujia Changzhuang,ling he,ling he zhen,xu jia zhang zhuang,凌河,凌河镇,徐家长庄', 32.4320100, 121.0788500, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23739, 'Dayu', 'Dayu', 'Dayu,Dayu Zhen,da yu,da yu zhen,大豫,大豫镇', 32.3112700, 121.2966300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23740, 'Guanyinshan', 'Guanyinshan', 'Guanyinshan,Guanyinshan Zhen,guan yin shan,guan yin shan zhen,观音山,观音山镇', 32.0095000, 120.9343000, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23741, 'Dongyuan', 'Dongyuan', 'Dongyuan,dong yuan,东元', 31.9796200, 121.7280400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23742, 'Luoda', 'Luoda', 'Luoda,luo da,洛大', 33.9861900, 103.9808100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23743, 'Nanhe', 'Nanhe', 'Nanhe,nan he,南河', 34.0951100, 104.2471600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23744, 'Hejiabao', 'Hejiabao', 'Hejiabao,he jia bao,何家堡', 34.0365900, 104.3158600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23745, 'Jiahe', 'Jiahe', 'Jiahe,gu he,贾河', 34.0918700, 104.3797400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23746, 'Jiangtai', 'Jiangtai', 'Jiangtai,jiang tai,将台', 34.0893200, 104.4070000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23747, 'Guan’e', 'Guan''e', 'Guan''e,Guan''e Zangzuxiang,Guan’e,Guan’e Zangzuxiang,guan e,guan e cang zu xiang,官鹅,官鹅藏族乡', 34.0111700, 104.3946500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23748, 'Chela', 'Chela', 'Chela,che la,车拉', 34.0689700, 104.4618900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23749, 'Xinchengzi', 'Xinchengzi', 'Xinchengzi,Xinchengzi Zangzuxiang,xin cheng zi,xin cheng zi cang zu xiang,新城子,新城子藏族乡', 34.0166300, 104.4422600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23750, 'Xinghua', 'Xinghua', 'Xinghua,xing hua,兴化', 34.0802600, 104.5840200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23751, 'Ganjiangtou', 'Ganjiangtou', 'Ganjiangtou,gan jiang tou,甘江头', 33.9272300, 104.5222300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23752, 'Linjiang', 'Linjiang', 'Linjiang,lin jiang,临江', 33.9610500, 104.5095100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23753, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 33.9570500, 104.6432700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23754, 'Zhuyuan', 'Zhuyuan', 'Zhuyuan,zhu yuan,竹院', 33.8854600, 104.7032500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23755, 'Hanyuan', 'Hanyuan', 'Hanyuan,han yuan,韩院', 33.9548900, 104.6887100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23756, 'Haoli', 'Haoli', 'Haoli,hao li,蒿里', 33.9836200, 104.8101200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23757, 'Baiguan', 'Baiguan', 'Baiguan,bai guan,白关', 33.9661700, 104.9144400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23758, 'Zhongba', 'Zhongba', 'Zhongba,zhong ba,中坝', 34.0351100, 105.0328600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23759, 'Yangzizhou', 'Yangzizhou', 'Yangzizhou,yang zi zhou,扬子洲', 28.7221900, 115.9059400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23760, 'Taiping', 'Taiping', 'Taiping,tai ping,太平', 28.8047600, 115.7136800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23761, 'Huyunxiang', 'Huyunxiang', 'Huyunxiang,hu yun xiang,湖云乡', 28.7934100, 116.8104400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23762, 'Wuleixiang', 'Wuleixiang', 'Wuleixiang,wu lei xiang,五雷乡', 28.5819100, 116.8411600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23763, 'Suqiaoxiang', 'Suqiaoxiang', 'Suqiaoxiang,su qiao xiang,苏桥乡', 28.5859500, 116.9290700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23764, 'Honghuxiang', 'Honghuxiang', 'Honghuxiang,hong hu xiang,洪湖乡', 28.2196900, 116.9183600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23765, 'Tangnanzhen', 'Tangnanzhen', 'Tangnanzhen,tang nan zhen,塘南镇', 28.6582800, 116.1364200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23766, 'Zhoushang', 'Zhoushang', 'Zhoushang,Zhoushang Xiang,zhou shang,zhou shang xiang,洲上,洲上乡', 28.0048900, 115.4091600, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23767, 'Yanghuxiang', 'Yanghuxiang', 'Yanghuxiang,yang hu xiang,洋湖乡', 28.0229000, 115.4932500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23768, 'Dengjiaxiang', 'Dengjiaxiang', 'Dengjiaxiang,deng jia xiang,邓家乡', 28.2520400, 116.5612500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23769, 'Dongyangzhen', 'Dongyangzhen', 'Dongyangzhen,dong yang zhen,东阳镇', 28.8705800, 115.6368400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23770, 'Lutianxiang', 'Lutianxiang', 'Lutianxiang,lu tian xiang,芦田乡', 28.9475900, 116.9254700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23771, 'Nanxinxiang', 'Nanxinxiang', 'Nanxinxiang,nan xin xiang,南新乡', 28.8006900, 116.0634000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23772, 'Liduzhen', 'Liduzhen', 'Liduzhen,li du zhen,李渡镇', 28.2236000, 116.1564200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23773, 'Jiangxiangzhen', 'Jiangxiangzhen', 'Jiangxiangzhen,jiang xiang zhen,蒋巷镇', 28.7606500, 116.0167700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23774, 'Chuntaoxiang', 'Chuntaoxiang', 'Chuntaoxiang,chun tao xiang,春涛乡', 28.3490200, 116.8314600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23775, 'Xinminxiang', 'Xinminxiang', 'Xinminxiang,xin min xiang,新民乡', 28.9332500, 115.5582900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23776, 'Pingdingxiang', 'Pingdingxiang', 'Pingdingxiang,ping ding xiang,平定乡', 28.2925400, 116.8808500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23777, 'Xinjiezhen', 'Xinjiezhen', 'Xinjiezhen,xin jie zhen,新街镇', 28.2326500, 115.4084100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23778, 'Lanfangzhen', 'Lanfangzhen', 'Lanfangzhen,lan fang zhen,蓝坊镇', 28.3957700, 115.4671100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23779, 'Maquanzhen', 'Maquanzhen', 'Maquanzhen,ma quan zhen,马荃镇', 28.1583100, 116.8640100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23780, 'Zhaoxian', 'Zhaoxian', 'Wanli Qu,Zhaoxian,Zhaoxian Zhen,wan li qu,zhao xian,zhao xian zhen,招贤,招贤镇,湾里区', 28.7061800, 115.7361700, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23781, 'Tongshanxiang', 'Tongshanxiang', 'Tongshanxiang,tong shan xiang,桐山乡', 28.8398500, 116.7957200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23782, 'Tongtianxiang', 'Tongtianxiang', 'Tongtianxiang,tong tian xiang,同田乡', 28.3314400, 115.8097600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23783, 'Lefengzhen', 'Lefengzhen', 'Lefengzhen,le feng zhen,乐丰镇', 28.8634300, 116.7788900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23784, 'Leiba', 'Leiba', 'Leiba,lei ba,雷坝', 33.7908600, 105.0379500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23785, 'Wangba', 'Wangba', 'Wangba,wang ba,王坝', 33.7428800, 105.0103200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23786, 'Tanping', 'Tanping', 'Tanping,tan ping,滩坪', 33.8112200, 104.9754300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23787, 'Baihe', 'Baihe', 'Baihe,bai he,白河', 33.8697400, 104.8522100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23788, 'Sanyu', 'Sanyu', 'Sanyu,san yu,三峪', 33.6992800, 105.0201400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23789, 'Caoping', 'Caoping', 'Caoping,cao ping,草坪', 33.6796500, 104.8082300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23790, 'Quanshui', 'Quanshui', 'Quanshui,quan shui,铨水', 33.8501300, 104.7871400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23791, 'Shizi', 'Shizi', 'Shizi,shi zi,狮子', 33.7440100, 104.6802800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23792, 'Taiyu', 'Taiyu', 'Taiyu,tai yu,泰峪', 33.7887400, 104.5316200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23793, 'Quwa', 'Quwa', 'Quwa,qu wa,曲瓦', 33.9188500, 103.9934100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23794, 'Bazang', 'Bazang', 'Bazang,ba cang,巴藏', 33.9014000, 104.0370300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23795, 'Lijie', 'Lijie', 'Lijie,li jie,立节', 33.9021300, 104.0715600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23796, 'Dayu', 'Dayu', 'Dayu,da yu,大峪', 33.8312500, 104.0395700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23797, 'Hanban', 'Hanban', 'Hanban,han ban,憨班', 33.8727000, 104.1842400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23798, 'Pingding', 'Pingding', 'Pingding,ping ding,坪定', 33.8254500, 104.3107300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23799, 'Jiangpan', 'Jiangpan', 'Jiangpan,jiang pan,江盘', 33.7787200, 104.3645900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23800, 'Gongzishi', 'Gongzishi', 'Gongzishi,gong zi shi,弓子石', 33.7583600, 104.4343900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23801, 'Zhongpai', 'Zhongpai', 'Zhongpai,zhong pai,中牌', 33.7354600, 104.5001800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23802, 'Dachuan', 'Dachuan', 'Dachuan,da chuan,大川', 33.7162000, 104.4362000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23803, 'Nanyu', 'Nanyu', 'Nanyu,nan yu,南峪', 33.7183800, 104.4133000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23804, 'Sanjiaoping', 'Sanjiaoping', 'Sanjiaoping,san jiao ping,三角坪', 33.6489500, 104.4318400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23805, 'Chigan', 'Chigan', 'Chigan,chi gan,池干', 33.6365900, 104.4482000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23806, 'Wuping', 'Wuping', 'Wuping,wu ping,武坪', 33.6285900, 104.3362400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23807, 'Chagang', 'Chagang', 'Chagang,cha gang,插岗', 33.5820800, 104.3442400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23808, 'Baleng', 'Baleng', 'Baleng,ba leng,八楞', 33.6071700, 104.5129000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23809, 'Boyu', 'Boyu', 'Boyu,bo yu,博峪', 33.4322400, 104.3915700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23810, 'Danian', 'Danian', 'Danian,da nian,大年', 33.4289700, 104.6303900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23811, 'Tieba', 'Tieba', 'Tieba,tie ba,铁坝', 33.3624500, 104.6173000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23812, 'Maying', 'Maying', 'Maying,ma ying,马营', 33.1361000, 104.4168100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23813, 'Tunzhai', 'Tunzhai', 'Tunzhai,tun zhai,屯寨', 33.1630300, 104.7813900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23814, 'Sheshu', 'Sheshu', 'Sheshu,she shu,舍书', 33.2004900, 104.9362400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23815, 'Liping', 'Liping', 'Liping,li ping,梨坪', 33.1855900, 104.8839000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23816, 'Jianshan', 'Jianshan', 'Jianshan,jian shan,尖山', 33.0280300, 104.8552600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23817, 'Baoziba', 'Baoziba', 'Baoziba,bao zi ba,堡子坝', 33.0803800, 104.6411700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23818, 'Shijiba', 'Shijiba', 'Shijiba,shi ji ba,石鸡坝', 33.0669400, 104.4528200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23819, 'Liutan', 'Liutan', 'Liutan,Liutan Jiedao,liu tan,liu tan jie dao,刘潭,刘潭街道', 31.6201500, 120.2920600, 'CN', '2012-07-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23820, 'Koutouba', 'Koutouba', 'Koutouba,kou tou ba,口头坝', 32.9399900, 104.9422400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23821, 'Pingya', 'Pingya', 'Pingya,Pingya Zangzuxiang,ping ya,ping ya cang zu xiang,坪垭,坪垭藏族乡', 33.5088300, 104.6691500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23822, 'Puchi', 'Puchi', 'Puchi,pu chi,蒲池', 33.5346600, 104.8141800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23823, 'Hanlin', 'Hanlin', 'Hanlin,han lin,汉林', 33.4754100, 104.9021500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23824, 'Maying', 'Maying', 'Maying,ma ying,马营', 33.5964500, 104.8461700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23825, 'Jinchang', 'Jinchang', 'Jinchang,jin chang,金厂', 33.6168100, 104.8963300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23826, 'Longfeng', 'Longfeng', 'Longfeng,long feng,龙凤', 33.3958400, 105.0457200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23827, 'Jiegan', 'Jiegan', 'Jiegan,jie gan,秸柑', 33.2893400, 105.0955200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23828, 'Hanwang', 'Hanwang', 'Hanwang,Hanwang Zhen,han wang,han wang zhen,汉王,汉王镇', 33.3431300, 105.0104600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23829, 'Majie', 'Majie', 'Majie,ma jie,马街', 33.4594500, 104.9577500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23830, 'Moba', 'Moba', 'Moba,Moba Zangzuxiang,mo ba,mo ba cang zu xiang,磨坝,磨坝藏族乡', 33.2287600, 105.0179300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23831, 'Sangba', 'Sangba', 'Sangba,sang ba,桑坝', 34.0390700, 103.7904400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23832, 'Dianga', 'Dianga', 'Dianga,Diangacun,Diebu,Diebu Xian,dian ga,dian ga cun,die bu,die bu xian,电尕,电尕村,迭部,迭部县', 34.0636300, 103.2135800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23833, 'Yiwa', 'Yiwa', 'Yiwa,yi wa,益哇', 34.1374400, 103.1689400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23834, 'Qinxu', 'Qinxu', 'Qinxu,qin xu,秦许', 34.3676800, 103.9944100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23835, 'Minshan', 'Minshan', 'Minshan,Minshanxiang,min shan,min shan xiang,岷山,岷山乡', 34.4372500, 103.9759100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23836, 'Qingshui', 'Qingshui', 'Qingshui,Qingshuicun,qing shui,qing shui cun,青水,青水村', 34.4595800, 103.9027500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23837, 'Niba', 'Niba', 'Niba,Niba Xiang,Nibaxiang,ni ba,ni ba xiang,尼巴,尼巴乡', 34.4577400, 103.0845800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23838, 'Xizhai', 'Xizhai', 'Xizhai,xi zhai,西寨', 34.4936600, 103.8017500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23839, 'Zongzhai', 'Zongzhai', 'Zongzhai,Zongzhaixiang,zong zhai,zong zhai xiang,总寨,总寨乡', 34.5527100, 103.6887300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23840, 'Mu’er', 'Mu''er', 'Mu''er,Mu''er Xiang,Mu’er,Mu’er Xiang,mu er,mu er xiang,木耳,木耳乡', 34.5661200, 103.5854500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23841, 'Dazu', 'Dazu', 'Dazu,Dazuxiang,da zu,da zu xiang,大族,大族乡', 34.5829800, 103.4217100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23842, 'Kache', 'Kache', 'Kache,Kache Xiang,Kachexiang,ka che,ka che xiang,卡车,卡车乡', 34.6016100, 103.3501200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23843, 'Dianzi', 'Dianzi', 'Dianzi,Dianzi Xiang,Dianzixiang,dian zi,dian zi xiang,店子,店子乡', 34.6313200, 103.6648200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23844, 'Biandu', 'Biandu', 'Biandu,Biandu Xiang,bian dou,bian dou xiang,扁都,扁都乡', 34.6576800, 103.6400600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23845, 'Baozi', 'Baozi', 'Baozi,bao zi,堡子', 34.6710500, 103.8799600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23846, 'Chenqi', 'Chenqi', 'Chenqi,Chenqi Xiang,Chenqixiang,chen qi,chen qi xiang,陈旗,陈旗乡', 34.6863600, 103.8427100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23847, 'Guzhan', 'Guzhan', 'Guzhan,Guzhan Huizuxiang,Guzhan Xiang,Guzhanxiang,gu zhan,gu zhan hui zu xiang,gu zhan xiang,古战,古战乡,古战回族乡', 34.6946100, 103.2966000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23848, 'Lexiu', 'Lexiu', 'Lexiu,lei xiu,勒秀', 34.7085900, 103.0038600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23849, 'Changchuan', 'Changchuan', 'Changchuan,Changchuan Huizuxiang,zhang chuan,zhang chuan hui zu xiang,长川,长川回族乡', 34.7154300, 103.4297000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23850, 'Zhuolu', 'Zhuolu', 'Zhuolu,Zhuoluo Huizuxiang,zhuo luo,zhuo luo hui zu xiang,卓洛,卓洛回族乡', 34.7321200, 103.3397400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23851, 'Shencang', 'Shencang', 'Shencang,Shencang Xiang,Shencangxiang,shen cang,shen cang xiang,申藏,申藏乡', 34.7346500, 103.3803500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23852, 'Shimen', 'Shimen', 'Shimen,shi men,石门', 34.7360200, 103.7014800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23853, 'Jiamaogong', 'Jiamaogong', 'Jiamaogong,jia mao gong,加茂贡', 34.7412900, 103.0987600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23854, 'Bailin', 'Bailin', 'Bailin,bai lin,柏林', 34.7629800, 103.9396300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23855, 'Zangbawa', 'Zangbawa', 'Cangbawa,Zangbawa,cang ba wa,藏巴哇', 34.8772500, 103.8617000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23856, 'Shaowa', 'Shaowa', 'Shaowa,Shaowa Tuzuxiang,Shaowatuzuxiang,shao wa,shao wa tu zu xiang,勺哇,勺哇土族乡', 34.9782800, 103.5620700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23857, 'Zuogaimanma', 'Zuogaimanma', 'Zuogaimanma,Zuogaimanmaxiang,zuo gai man ma,zuo gai man ma xiang,佐盖曼玛,佐盖曼玛乡', 34.9974400, 103.0486400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23858, 'Caohe', 'Caohe', 'Caohe,cao he,草河', 32.9330800, 105.0819400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23859, 'Wuku', 'Wuku', 'Wuku,wu ku,五库', 33.0287900, 105.0137500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23860, 'Dongjiang', 'Dongjiang', 'Dongjiang,Dongjiang Zhen,dong jiang,dong jiang zhen,东江,东江镇', 33.3792300, 104.9506600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23861, 'Jinping', 'Jinping', 'Jinping,jin ping,锦屏', 33.4060900, 104.7819700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23862, 'Lianhua', 'Lianhua', 'Lianhua,lian hua,莲花', 35.0616000, 105.7910800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23863, 'Liangshan', 'Liangshan', 'Liangshan,liang shan,梁山', 35.0731900, 105.9740000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23864, 'Jichuan', 'Jichuan', 'Jichuan,ji chuan,鸡川', 35.1507500, 105.4652000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23865, 'Zhongchuan', 'Zhongchuan', 'Zhongchuan,Zhongchuanxiang,zhong chuan,中川', 35.4979300, 105.0780300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23866, 'Yuan’an', 'Yuan''an', 'Yuan''an,Yuan’an,yuan an,原安', 35.7016600, 105.6339600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23867, 'Hanjiaji', 'Hanjiaji', 'Hanjiaji,han jia ji,韩家集', 35.8768800, 105.1297200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23868, 'Hongtu', 'Hongtu', 'Ebao Zhen,Hongtu,Hongtu Cheng,e bao zhen,hong tu,hong tu cheng,峨堡镇,红土,红土城', 37.9682000, 100.9332000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23869, 'Tuohua', 'Tuohua', 'Tuohua,Tuole Mengguzu Xiang,tuo hua,tuo lei meng gu zu xiang,托勒蒙古族乡,托华', 37.0813900, 100.6835800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23870, 'Shibao', 'Shibao', 'Shibao,shi bao,石堡', 34.0916700, 105.2977100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23871, 'Xiji', 'Xiji', 'Xiji,Xiji Xiang,xi ji,xi ji xiang,喜集,喜集乡', 33.7819800, 105.2762700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23872, 'Shoushan', 'Shoushan', 'Mei Xian,Shoushan,mei xian,shou shan,眉县,首善', 34.2777100, 107.7461900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23873, 'Sancang', 'Sancang', 'Sancang,san cang,三仓', 33.0137800, 105.1150700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23874, 'Fengxiang Chengguanzhen', 'Fengxiang Chengguanzhen', 'Fengxiang,Fengxiang Chengguanzhen,Fengxiang Xian,feng xiang,feng xiang cheng guan zhen,feng xiang xian,凤翔,凤翔县,凤翔城关镇', 34.5230100, 107.3912700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23875, 'Tangyu', 'Tangyu', 'Tangyu,Tangyu Zhen,tang yu,tang yu zhen,汤峪,汤峪镇', 34.1492000, 107.8732000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23876, 'Shangsong', 'Shangsong', 'Shangsong,shang song,上宋', 34.2653400, 107.8759500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23877, 'Diaowei', 'Diaowei', 'Diaowei,Diaowei Zhen,diao wei,diao wei zhen,钓渭,钓渭镇', 34.2905700, 107.5158300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23878, 'Wuquan', 'Wuquan', 'Wuquan,Wuquan Zhen,wu quan,wu quan zhen,五泉,五泉镇', 34.3004500, 107.9932600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23879, 'Duanjia', 'Duanjia', 'Duanjia,Duanjia Zhen,duan jia,duan jia zhen,段家,段家镇', 34.3099400, 107.9062100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23880, 'Bayu', 'Bayu', 'Bayu,Bayu Zhen,ba yu,ba yu zhen,八鱼,八鱼镇', 34.3366900, 107.2767500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23881, 'Shigu', 'Shigu', 'Shigu,Shigu Zhen,shi gu,shi gu zhen,石鼓,石鼓镇', 34.3515300, 107.1431800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23882, 'Gaojia', 'Gaojia', 'Gaojia,Gaojia Zhen,gao jia,gao jia zhen,高家,高家镇', 34.3604800, 107.0677400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23883, 'Taibai', 'Taibai', 'Taibai,tai bai,太白', 34.3605700, 107.9633300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23884, 'Chencang', 'Chencang', 'Chencang,Chencang Zhen,chen cang,chen cang zhen,陈仓,陈仓镇', 34.3686300, 107.2075100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23885, 'Xiashixiang', 'Xiashixiang', 'Xiashixiang,xia shi xiang,硖石乡', 34.3800200, 107.0684300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23886, 'Guowang', 'Guowang', 'Guowang,Guowang Zhen,guo wang,guo wang zhen,虢王,虢王镇', 34.3841800, 107.5261000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23887, 'Muyi', 'Muyi', 'Muyi,Muyi Zhen,mu yi,mu yi zhen,慕仪,慕仪镇', 34.3884200, 107.4385600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23888, 'Qianhe', 'Qianhe', 'Qianhe,Qianhe Zhen,qian he,qian he zhen,千河,千河镇', 34.3935500, 107.3024300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23889, 'Zhouyuan', 'Zhouyuan', 'Zhouyuan,Zhouyuan Zhen,zhou yuan,zhou yuan zhen,周原,周原镇', 34.3955000, 107.3764700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23890, 'Lingyuan', 'Lingyuan', 'Lingyuan,ling yuan,陵原', 34.4012000, 107.1189500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23891, 'Daying', 'Daying', 'Daying,da ying,大营', 34.4087600, 107.6680600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23892, 'Panlong', 'Panlong', 'Panlong,Panlong Zhen,pan long,pan long zhen,蟠龙,蟠龙镇', 34.4181100, 107.1982700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23893, 'Gujun', 'Gujun', 'Gujun,gu jun,故郡', 34.4394200, 107.6892800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23894, 'Jinhe', 'Jinhe', 'Jinhe,jin he,金河', 34.4412900, 107.1309100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23895, 'Nanzhihui', 'Nanzhihui', 'Nanzhihui,Nanzhihui Zhen,nan zhi hui,nan zhi hui zhen,南指挥,南指挥镇', 34.4708000, 107.3558900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23896, 'Pucun', 'Pucun', 'Pucun,Pucun Zhen,pu cun,pu cun zhen,蒲村,蒲村镇', 34.4732900, 107.7522500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23897, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 34.4875800, 107.9303100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23898, 'Tangcun', 'Tangcun', 'Tangcun,tang cun,唐村', 34.5248600, 107.3081500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23899, 'Dongjiahe', 'Dongjiahe', 'Dongjiahe,dong jia he,董家河', 34.5859900, 107.3591500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23900, 'Nanzhai', 'Nanzhai', 'Nanzhai,Nanzhai Zhen,nan zhai,nan zhai zhen,南寨,南寨镇', 34.6571400, 107.1736600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23901, 'Shajia’ao', 'Shajia''ao', 'Shajia''ao,Shajia’ao,sha jia ao,沙家坳', 34.6727400, 107.2302900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23902, 'Sangshuyuan', 'Sangshuyuan', 'Sangshuyuan,sang shu yuan,桑树塬', 34.7340700, 107.8193600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23903, 'Chejiazhuang', 'Chejiazhuang', 'Chejiazhuang,che jia zhuang,车家庄', 34.9892400, 107.9002700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23904, 'Puwo', 'Puwo', 'Puwo,pu wo,蒲窝', 34.9737900, 107.5217900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23905, 'Yongchuan', 'Yongchuan', 'Yongchuan,Yongchuan Zhen,yong chuan,yong chuan zhen,雍川,雍川镇', 34.3655600, 107.6370600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23906, 'Shennong', 'Shennong', 'Shennong,Shennong Zhen,shen nong,shen nong zhen,神农,神农镇', 34.3391100, 107.1169100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23907, 'Panxi', 'Panxi', 'Panxi,Panxi Zhen,pan xi,pan xi zhen,潘溪,潘溪镇', 34.3230800, 107.4034300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23908, 'Guodian', 'Guodian', 'Guodian,Guodian Zhen,guo dian,guo dian zhen,郭店,郭店镇', 34.4563600, 107.4254300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23909, 'Zhongshan Donglu', 'Zhongshan Donglu', 'Zhongshan Donglu,Zhongshan Donglu Jiedao,zhong shan dong lu,zhong shan dong lu jie dao,中山东路,中山东路街道', 34.3796400, 107.1463800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23910, 'Jinling', 'Jinling', 'Jinling,Jinling Jiedao,jin ling,jin ling jie dao,金陵,金陵街道', 34.3692500, 107.1499700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23911, 'Chaka', 'Chaka', 'Chaka,Chaka Zhen,cha ka,cha ka zhen,茶卡,茶卡镇', 36.7921900, 99.0737200, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23912, 'Qiecha', 'Qiecha', 'Qiecha,Shinaihai Xiang,qie cha,shi nai hai xiang,切查,石乃亥乡', 36.9951200, 99.5985900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23913, 'Dongke', 'Dongke', 'Dongke,Qieji Xiang,dong ke,qie ji xiang,东科,切吉乡', 36.3349000, 99.6667600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23914, 'Cangdu', 'Cangdu', 'Cangdu,cang du,苍杜', 33.0913700, 105.9747700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23915, 'Taiyangling', 'Taiyangling', 'Taiyangling,tai yang ling,太阳岭', 33.0364800, 106.0031200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23916, 'Weihe', 'Weihe', 'Weihe,wei he,渭河', 32.9952200, 105.3246500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23917, 'Yuhe', 'Yuhe', 'Yuhe,yu he,裕河', 32.9990700, 105.4861400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23918, 'Tuohe', 'Tuohe', 'Tuohe,tuo he,托河', 33.0141100, 105.8593500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23919, 'Pandi', 'Pandi', 'Pandi,pan di,盘底', 33.0160400, 105.1839100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23920, 'Xizhi', 'Xizhi', 'Xizhi,xi zhi,西支', 33.0767300, 105.3564000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23921, 'Luotang', 'Luotang', 'Luotang,Luotang Zhen,luo tang,luo tang zhen,洛塘,洛塘镇', 33.0677500, 105.2648500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23922, 'Lianghe', 'Lianghe', 'Lianghe,Lianghe Zhen,liang he,liang he zhen,两河,两河镇', 33.1216800, 105.9194700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23923, 'Yuezhao', 'Yuezhao', 'Yuezhao,yue zhao,月照', 33.1405900, 105.1610800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23924, 'Sanheba', 'Sanheba', 'Sanheba,san he ba,三河坝', 33.1418800, 105.6829800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23925, 'Pipa', 'Pipa', 'Pipa,pi pa,琵琶', 33.1663500, 105.3134400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23926, 'Dianzi', 'Dianzi', 'Dianzi,dian zi,店子', 33.2204100, 105.5012700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23927, 'Jia’an', 'Jia''an', 'Jia''an,Jia’an,gu an,贾安', 33.2617600, 105.7224100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23928, 'Yuhuang', 'Yuhuang', 'Yuhuang,yu huang,玉皇', 33.2922700, 105.2246700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23929, 'Nianba', 'Nianba', 'Nianba,nian ba,碾坝', 33.3063700, 105.4693600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23930, 'Huangping', 'Huangping', 'Huangping,huang ping,黄坪', 33.3215500, 105.3322000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23931, 'Guohe', 'Guohe', 'Guohe,guo he,郭河', 33.3511300, 105.1487100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23932, 'Sanguan', 'Sanguan', 'Sanguan,san guan,三官', 33.3558300, 105.6033900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23933, 'Xiongchi', 'Xiongchi', 'Xiongchi,xiong chi,熊池', 33.4057500, 105.3303300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23934, 'Changba', 'Changba', 'Changba,Changba Zhen,zhang ba,zhang ba zhen,长坝,长坝镇', 33.4284300, 105.4345800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23935, 'Dananyu', 'Dananyu', 'Dananyu,da nan yu,大南峪', 33.4311200, 105.7584300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23936, 'Foya', 'Foya', 'Foya,fu ya,佛崖', 33.4378000, 105.2733300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23937, 'Ganquan', 'Ganquan', 'Ganquan,gan quan,甘泉', 33.4417800, 105.1597800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23938, 'Gongji', 'Gongji', 'Gongji,gong ji,巩集', 33.4503800, 105.5259700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23939, 'Dabao', 'Dabao', 'Dabao,Dabao Zhen,da bao,da bao zhen,大堡,大堡镇', 33.4706000, 105.5765400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23940, 'Sitai', 'Sitai', 'Sitai,si tai,寺台', 33.4864100, 105.6100000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23941, 'Yulong', 'Yulong', 'Yulong,yu long,鱼龙', 33.5100300, 105.1812000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23942, 'Douping', 'Douping', 'Douping,dou ping,豆坪', 33.5165000, 105.4646200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23943, 'Chanhe', 'Chanhe', 'Chanhe,chan he,镡河', 33.5366700, 105.6566600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23944, 'Miba', 'Miba', 'Miba,mi ba,迷坝', 33.5427200, 105.7819000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23945, 'Lishan', 'Lishan', 'Lishan,li shan,李山', 33.5497300, 105.5683100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23946, 'Chanba', 'Chanba', 'Chanba,chan ba,镡坝', 33.5827900, 105.7584600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23947, 'Huangchen', 'Huangchen', 'Huangchen,huang chen,黄陈', 33.5831200, 105.6015900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23948, 'Longxing', 'Longxing', 'Longxing,long xing,隆兴', 33.5986400, 105.1929000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23949, 'Songping', 'Songping', 'Songping,song ping,宋坪', 33.6025100, 105.9105400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23950, 'Taishi', 'Taishi', 'Taishi,tai shi,太石', 33.6165700, 105.4516300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23951, 'Longba', 'Longba', 'Longba,long ba,龙坝', 33.6247600, 105.2944700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23952, 'Suochi', 'Suochi', 'Suochi,suo chi,索池', 33.6458600, 105.5136300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23953, 'Daping', 'Daping', 'Daping,da ping,大坪', 33.6503100, 105.7204000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23954, 'Huaya', 'Huaya', 'Huaya,hua ya,化垭', 33.6574400, 105.6528900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23955, 'Nankang', 'Nankang', 'Nankang,nan kang,南康', 33.6583000, 105.8850800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23956, 'Suyuan', 'Suyuan', 'Suyuan,su yuan,苏园', 33.6734800, 105.4527400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23957, 'Taishihe', 'Taishihe', 'Taishihe,tai shi he,太石河', 33.7057800, 105.1812200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23958, 'Paosha', 'Paosha', 'Paosha,Paosha Zhen,pao sha,pao sha zhen,抛沙,抛沙镇', 33.7235300, 105.6757200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23959, 'Zhifang', 'Zhifang', 'Zhifang,Zhifang Zhen,zhi fang,zhi fang zhen,纸坊,纸坊镇', 33.7259800, 105.4835800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23960, 'Shaba', 'Shaba', 'Shaba,sha ba,沙坝', 33.7311500, 105.5641200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23961, 'Xigaoshan', 'Xigaoshan', 'Xigaoshan,xi gao shan,西高山', 33.7347500, 105.3881700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23962, 'Zhiqi', 'Zhiqi', 'Zhiqi,zhi qi,支旗', 33.7486400, 105.7436800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23963, 'Diancun', 'Diancun', 'Diancun,dian cun,店村', 33.7710500, 105.8180900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23964, 'Chenyuan', 'Chenyuan', 'Chenyuan,chen yuan,陈院', 33.7642700, 105.6760100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23965, 'Haolin', 'Haolin', 'Haolin,hao lin,蒿林', 33.7679100, 105.2134500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23966, 'Suchuan', 'Suchuan', 'Suchuan,su chuan,粟川', 33.7888400, 105.9490100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23967, 'Liuxiang', 'Liuxiang', 'Liuxiang,liu xiang,六巷', 33.7993700, 105.4444700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23968, 'Yinxingshu', 'Yinxingshu', 'Yinxingshu,yin xing shu,银杏树', 33.8049700, 106.0379300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23969, 'Shuiquan', 'Shuiquan', 'Shuiquan,shui quan,水泉', 33.8110100, 105.7226700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23970, 'Luoyu', 'Luoyu', 'Luoyu,luo yu,洛峪', 33.8410300, 105.2311700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23971, 'Wangmo', 'Wangmo', 'Wangmo,wang mo,王磨', 33.8507400, 105.6764100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23972, 'Hekou', 'Hekou', 'Hekou,he kou,河口', 33.8754800, 105.1529200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23973, 'Youlongchuan', 'Youlongchuan', 'Youlongchuan,you long chuan,游龙川', 33.8887200, 105.8820500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23974, 'Shili', 'Shili', 'Shili,shi li,十里', 33.9518200, 105.2924700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23975, 'Yushu', 'Yushu', 'Yushu,yu shu,榆树', 33.9597800, 106.0057100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23976, 'Huangzhu', 'Huangzhu', 'Huangzhu,Huangzhu Zhen,huang zhu,huang zhu zhen,黄渚,黄渚镇', 33.9675500, 105.6826600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23977, 'Zhaowu', 'Zhaowu', 'Zhaowu,zhao wu,赵五', 33.9853000, 105.3096200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23978, 'Shaijing', 'Shaijing', 'Shaijing,shai jing,晒经', 33.9833200, 105.4888500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23979, 'Jiangxi', 'Jiangxi', 'Jiangxi,jiang xi,姜席', 33.9993400, 105.1999400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23980, 'Luhe', 'Luhe', 'Luhe,lu he,卢河', 34.0091800, 105.3402100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23981, 'Mayuan', 'Mayuan', 'Mayuan,ma yuan,马元', 34.0539700, 105.5227800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23982, 'Shijiayuan', 'Shijiayuan', 'Shijiayuan,shi jia yuan,史家院', 33.2897000, 106.0053200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23983, 'Taiping', 'Taiping', 'Taiping,tai ping,太平', 32.9540900, 105.6967600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23984, 'Sangdang', 'Sangdang', 'Sangdang,Sangdang Xiang,sang dang,sang dang xiang,桑当,桑当乡', 35.5210300, 100.0124900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23985, 'Longcang', 'Longcang', 'Longcang,Longcang Xiang,Nimai,long cang,long cang xiang,ni mai,尼买,龙藏,龙藏乡', 35.2799700, 100.0708600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23986, 'Tangnaihai', 'Tangnaihai', 'Tangnaihai,Tangnaihai Xiang,Zhongcun,tang nai hai,tang nai hai xiang,zhong cun,中村,唐乃亥,唐乃亥乡', 35.5140700, 100.1311500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23987, 'Qushi’an', 'Qushi''an', 'Dongda Mitan,Qushi''an,Qushi''an Xiang,Qushi’an,Qushi’an Xiang,dong da mi tan,qu shen an,qu shen an xiang,东大米滩,曲什安,曲什安乡', 35.3259600, 100.2326000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23988, 'Xiuma', 'Xiuma', 'Jiangqun,Xiuma,Xiuma Xiang,jiang qun,xiu ma,xiu ma xiang,江群,秀麻,秀麻乡', 35.0553800, 100.3328300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23989, 'Tanggan', 'Tanggan', 'Tanggan,Tanggan Xiang,tang gan,tang gan xiang,唐干,唐干乡', 35.2041500, 100.4122500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23990, 'Taxiu', 'Taxiu', 'Qubucangka,Taxiu,Taxiu Xiang,qu bu cang ka,ta xiu,ta xiu xiang,塔秀,塔秀乡,曲布藏卡', 35.5979100, 100.4414500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23991, 'Mangqu', 'Mangqu', 'Guinan,Guinan Xian,Mangqu,Mangqu Zhen,gui nan,gui nan xian,mang qu,mang qu zhen,芒曲,芒曲镇,贵南,贵南县', 35.5857000, 100.7523700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23992, 'Wangjia', 'Wangjia', 'Riqiong Quka,Wangjia,Wangjia Xiang,ri qiong qu ka,wang jia,wang jia xiang,日穷曲卡,王加,王加乡', 35.3915000, 100.9533200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23993, 'Heka', 'Heka', 'Heka,he ka,河卡', 35.8933200, 100.0001300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23994, 'Liangshan', 'Liangshan', 'Liangshan,Liangshan Zhen,liang shan,liang shan zhen,梁山,梁山镇', 33.0862600, 106.9426300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23995, 'Shangma', 'Shangma', 'Shangma,Shangma Xiang,shang ma,shang ma xiang,上马,上马乡', 41.7813500, 124.1500500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23996, 'Bahechuan', 'Bahechuan', 'Bahechuan,Bahechuan Zhen,Luoquanjia,ba he chuan,ba he chuan zhen,luo quan jia,八河川,八河川镇,罗圈夹', 41.0271300, 124.8104600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23997, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 40.3059400, 123.2854900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23998, 'Zhoujiashan', 'Zhoujiashan', 'Zhoujiashan,Zhoujiashan Zhen,zhou jia shan,zhou jia shan zhen,周家山,周家山镇', 33.1714500, 106.7277900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(23999, 'Lijiaping', 'Lijiaping', 'Gangou Xiang,Lijiaping,gan gou xiang,li jia ping,李家坪,甘沟乡', 35.9813600, 102.7660800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24000, 'Jiuzhongjin', 'Jiuzhongjin', 'Jiuzhongjin,jiu zhong jin,九中金', 33.5247000, 106.2158600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24001, 'Xiangcunxiang', 'Xiangcunxiang', 'Xiangcunxiang,xiang cun xiang,翔村乡', 35.0069900, 109.5861100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24002, 'Biashizang', 'Biashizang', 'Biashizang,bai zha cang,白扎藏', 35.6005800, 102.9402900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24003, 'Shiyuan', 'Shiyuan', 'Shiyuan,shi yuan,石塬', 35.7527500, 102.8072600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24004, 'Dongguan', 'Dongguan', 'Dongguan,Dongguang Huizuxiang,dong guan,dong guan hui zu xiang,东关,东关回族乡', 33.7799200, 106.1064000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24005, 'Yuguan', 'Yuguan', 'Yuguan,yu guan,虞关', 33.6353900, 106.1671600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24006, 'Guangjin', 'Guangjin', 'Guangjin,guang jin,广金', 33.6565800, 106.4914800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24007, 'Yunping', 'Yunping', 'Yunping,yun ping,云屏', 33.6984700, 106.4140400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24008, 'Jialing', 'Jialing', 'Jialing,Jialing Zhen,jia ling,jia ling zhen,嘉陵,嘉陵镇', 33.6992700, 106.1962900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24009, 'Shuiyang', 'Shuiyang', 'Shuiyang,shui yang,水阳', 33.7484400, 106.1027800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24010, 'Taishan', 'Taishan', 'Taishan,tai shan,太山', 33.7729700, 106.4576100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24011, 'Xianlong', 'Xianlong', 'Xianlong,xian long,显龙', 33.8142000, 106.2447600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24012, 'Yuchi', 'Yuchi', 'Yuchi,yu chi,鱼池', 33.8342700, 106.2716600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24013, 'Xinghua', 'Xinghua', 'Xinghua,xing hua,兴化', 33.8615100, 106.3617600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24014, 'Liulin', 'Liulin', 'Liulin,Liulin Zhen,liu lin,liu lin zhen,柳林,柳林镇', 33.8743700, 106.1696000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24015, 'Jindong', 'Jindong', 'Jindong,jin dong,金洞', 33.9060400, 106.3087000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24016, 'Zuojia', 'Zuojia', 'Zuojia,zuo jia,左家', 33.9676200, 106.4052500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24017, 'Taiyang', 'Taiyang', 'Taiyang,tai yang,太阳', 34.0788100, 106.2948900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24018, 'Gaojialing', 'Gaojialing', 'Gaojialing,gao jia ling,高家岭', 32.9345800, 107.0330400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24019, 'Qingshu', 'Qingshu', 'Qingshu,Qingshu Zhen,qing shu,qing shu zhen,青树,青树镇', 32.9362900, 106.9032400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24020, 'Qishuba', 'Qishuba', 'Qishuba,qi shu ba,漆树坝', 32.9579500, 106.5928500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24021, 'Xieshui', 'Xieshui', 'Xieshui,Xieshui Zhen,xie shui,xie shui zhen,协税,协税镇', 33.0043000, 106.9093200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24022, 'Nanping', 'Nanping', 'Nanping,nan ping,南屏', 33.0149900, 106.3902300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24023, 'Gaotai', 'Gaotai', 'Gaotai,Gaotaizhen,gao tai,gao tai zhen,高台,高台镇', 33.0189100, 106.8548400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24024, 'Renshui', 'Renshui', 'Renshui,ren shui,忍水', 33.0360400, 106.8121400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24025, 'Hujiaying', 'Hujiaying', 'Hujiaying,hu jia ying,胡家营', 33.0239100, 107.0240700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24026, 'Yangchun', 'Yangchun', 'Yangchun,Yangchun Zhen,yang chun,yang chun zhen,阳春,阳春镇', 33.0332400, 106.9014800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24027, 'Guotan', 'Guotan', 'Guotan,guo tan,郭滩', 33.0392900, 106.9344700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24028, 'Qili', 'Qili', 'Qili,Qili Zhen,qi li,qi li zhen,七里,七里镇', 33.0792600, 107.0562300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24029, 'Zhenchuan', 'Zhenchuan', 'Zhenchuan,zhen chuan,镇川', 33.0873200, 106.7253000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24030, 'Donghuanggou', 'Donghuanggou', 'Donghuanggou,dong huang gou,东皇沟', 33.1041600, 106.2279900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24031, 'Gongjiahe', 'Gongjiahe', 'Gongjiahe,gong jia he,巩家河', 33.1133800, 106.1849100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24032, 'Zengjiahe', 'Zengjiahe', 'Zengjiahe,ceng jia he,曾家河', 33.1209600, 106.1265000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24033, 'Laojun', 'Laojun', 'Laojun,Laojun Zhen,lao jun,lao jun zhen,老君,老君镇', 33.1219900, 107.0435900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24034, 'Longjiang', 'Longjiang', 'Longjiang,Longjiang Zhen,long jiang,long jiang zhen,龙江,龙江镇', 33.1229600, 106.9593000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24035, 'Tuguanpu', 'Tuguanpu', 'Tuguanpu,tu guan pu,土关铺', 33.1303700, 106.5500500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24036, 'Dingjunshan', 'Dingjunshan', 'Dingjunshan,Dingjunshan Zhen,ding jun shan,ding jun shan zhen,定军山,定军山镇', 33.1393100, 106.6590900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24037, 'Jinquan', 'Jinquan', 'Jinquan,Jinquan Zhen,jin quan,jin quan zhen,金泉,金泉镇', 33.1460700, 106.8444400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24038, 'Wuhou', 'Wuhou', 'Wuhou,Wuhou Zhen,wu hou,wu hou zhen,武候,武候镇', 33.1502900, 106.6146300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24039, 'Xinjiezi', 'Xinjiezi', 'Xinjiezi,Xinjiezi Zhen,xin jie zi,xin jie zi zhen,新街子,新街子镇', 33.1609200, 106.8250600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24040, 'Tonggousi', 'Tonggousi', 'Tonggousi,Tonggousi Zhen,tong gou si,tong gou si zhen,同沟寺,同沟寺镇', 33.1709900, 106.7486900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24041, 'Heiheba', 'Heiheba', 'Heiheba,hei he ba,黑河坝', 33.2136500, 106.4439200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24042, 'Xiaobianhe', 'Xiaobianhe', 'Xiaobianhe,xiao bian he,小砭河', 33.2325500, 106.4898700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24043, 'Erdaohe', 'Erdaohe', 'Erdaohe,er dao he,二道河', 33.2514100, 106.8302600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24044, 'Wuguanyi', 'Wuguanyi', 'Wuguanyi,Wuguanyi Zhen,wu guan yi,wu guan yi zhen,武关驿,武关驿镇', 33.5517300, 106.9781000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24045, 'Liuhou', 'Liuhou', 'Liuhou,Liuhou Zhen,liu hou,liu hou zhen,留侯,留侯镇', 33.6921100, 106.8498900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24046, 'Huangbao', 'Huangbao', 'Huangbao,huang bao,黄堡', 35.0037700, 109.0249400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24047, 'Huangnaihai', 'Huangnaihai', 'Huangnaihai,Huangnaihai Xiang,Rixiuma,huang nai hai,huang nai hai xiang,ri xiu ma,日秀玛,黄乃亥,黄乃亥乡', 35.6157000, 102.0054600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24048, 'Nianduhu', 'Nianduhu', 'Nianduhu,Nianduhu Xiang,nian dou hu,nian dou hu xiang,年都乎,年都乎乡', 35.5332800, 102.0212600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24049, 'Dangshun', 'Dangshun', 'Dangshun,Dangshun Xiang,Xianggan,dang shun,dang shun xiang,xiang gan,当顺,当顺乡,香干', 35.8464400, 102.0265500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24050, 'Angla', 'Angla', 'Angla,Angla Xiang,Jianbaang,ang la,ang la xiang,jian ba ang,尖巴昂,昂拉,昂拉乡', 35.8891600, 102.0395800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24051, 'Jiawu', 'Jiawu', 'Jiawu,Jiawu Xiang,Xiezhi,jia wu,jia wu xiang,xie zhi,加吾,加吾乡,协知', 35.4918100, 102.0477600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24052, 'Sangke', 'Sangke', 'Sangke,Sangkexiang,sang ke,sang ke xiang,桑科,桑科乡', 35.1033800, 102.1088400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24053, 'Shuangpengxi', 'Shuangpengxi', 'Shuangpengxi,Shuangpengxi Xiang,shuang peng xi,shuang peng xi xiang,双朋西,双朋西乡', 35.5606800, 102.1989100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24054, 'Galengkou', 'Galengkou', 'Galengkou,Gangcha Zangzu Xiang,ga leng kou,gang cha cang zu xiang,尕楞口,岗察藏族乡', 35.6990000, 102.2267300, 'CN', '2013-09-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24055, 'Duowa', 'Duowa', 'Duowa,duo wa,多哇', 35.1963600, 102.2491700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24056, 'Yaga', 'Yaga', 'Galeng Cangzuxiang,Galeng Zangzuxiang,Yaga,ga leng cang zu xiang,ya ga,尕楞藏族乡,牙尕', 35.7655600, 102.2765400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24057, 'Tawa', 'Tawa', 'Guashize,Guashizexiang,Tawa,gua shen ze,gua shen ze xiang,ta wa,塔哇,瓜什则,瓜什则乡', 35.4944700, 102.2812100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24058, 'Xiazhuang', 'Xiazhuang', 'Chahandusi,Chahandusixiang,Xiazhuang,cha han dou si,cha han dou si xiang,xia zhuang,下庄,查汗都斯,查汗都斯乡', 35.8515000, 102.2956300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24059, 'Sanlanbahai', 'Sanlanbahai', 'Jiezi,Jiezixiang,Sanlanbahai,jie zi,jie zi xiang,san lan ba hai,三兰巴海,街子,街子乡', 35.8554300, 102.4332300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24060, 'Baijiaji', 'Baijiaji', 'Baijiaji,Tajiazangzu,Tajiazangzuxiang,bai jia ji,ta jia cang zu,ta jia cang zu xiang,塔加藏族,塔加藏族乡,白加集', 35.9702900, 102.6377200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24061, 'Mengdadazhuang', 'Mengdadazhuang', 'Mengda,Mengdadazhuang,Mengdaxiang,meng da,meng da da zhuang,meng da xiang,孟达,孟达乡,孟达大庄', 35.8333900, 102.6395000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24062, 'Wangjia', 'Wangjia', 'Qianhexiang,Wangjia,qian he xiang,wang jia,前河乡,王家', 36.0083600, 102.8117900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24063, 'Xinjia', 'Xinjia', 'Xinjia,Zhongchuanxiang,xin jia,zhong chuan xiang,中川乡,辛家', 35.8770000, 102.8395500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24064, 'Kajiadao', 'Kajiadao', 'Kajiadao,ka jia dao,卡加道', 35.1171800, 102.9935100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24065, 'Tangga’an', 'Tangga''an', 'Tangga''an,Tangga’an,tang ga ang,唐尕昂', 35.1431600, 102.8502700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24066, 'Jiujia', 'Jiujia', 'Jiujia,jiu jia,九甲', 35.1901100, 102.5346100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24067, 'Madang', 'Madang', 'Madang,ma dang,麻当', 35.3244200, 102.7854000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24068, 'Qu’ao', 'Qu''ao', 'Qu''ao,Qu’ao,qu ao,曲奥', 35.3664900, 102.8784500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24069, 'Maji', 'Maji', 'Maji,ma ji,马集', 35.4473400, 102.9894300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24070, 'Monigou', 'Monigou', 'Monigou,mo ni gou,漠泥沟', 35.4672800, 102.9497100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24071, 'Manisi', 'Manisi', 'Manisi,ma ni si,麻尼寺', 35.5103500, 102.9269900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24072, 'Zhangzigou', 'Zhangzigou', 'Zhangzigou,zhang zi gou,掌子沟', 35.5240700, 102.9696600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24073, 'Yingtan', 'Yingtan', 'Yingtan,ying tan,营滩', 35.5734700, 102.9711800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24074, 'Xiaoguan', 'Xiaoguan', 'Xiaoguan,xiao guan,小关', 35.5843900, 102.8917100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24075, 'Zhongzuiling', 'Zhongzuiling', 'Zhongzuiling,zhong ju ling,中咀岭', 35.6305800, 102.9267300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24076, 'Juiji', 'Juiji', 'Juiji,ju ji,居集', 35.6499900, 102.9312200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24077, 'Guogan', 'Guogan', 'Guogan,guo gan,郭干', 35.6520700, 102.9921000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24078, 'Xuhujia', 'Xuhujia', 'Xuhujia,xu hu jia,徐扈家', 35.6644200, 102.9517300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24079, 'Zhaizigou', 'Zhaizigou', 'Zhaizigou,zhai zi gou,寨子沟', 35.6788100, 102.8891900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24080, 'Hulinjia', 'Hulinjia', 'Hulinjia,hu lin jia,胡林家', 35.7254200, 102.9377800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24081, 'Liugou', 'Liugou', 'Liugou,liu gou,柳沟', 35.7439900, 102.8534300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24082, 'Guanjiachuan', 'Guanjiachuan', 'Guanjiachuan,guan jia chuan,关家川', 35.7648500, 102.9329100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24083, 'Liuji', 'Liuji', 'Liuji,liu ji,刘集', 35.7705400, 102.7897000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24084, 'Sibaozi', 'Sibaozi', 'Sibaozi,si bao zi,四堡子', 35.8392900, 102.7704500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24085, 'Xiaoling', 'Xiaoling', 'Xiaoling,Xiaolingxiang,xiao ling,xiao ling xiang,小岭,小岭乡', 35.8948400, 102.9956300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24086, 'Qianyang Chengguanzhen', 'Qianyang Chengguanzhen', 'Qianyang,Qianyang Chengguanzhen,Qianyang Xian,qian yang,qian yang cheng guan zhen,qian yang xian,千阳,千阳县,千阳城关镇', 34.6420900, 107.1301900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24087, 'Yangyong', 'Yangyong', 'Yangyong,yang yong,羊永', 34.6459000, 103.4719800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24088, 'Huayuan', 'Huayuan', 'Huayuan,hua yuan,花园', 33.9660700, 103.7676600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24089, 'Kuzhu', 'Kuzhu', 'Kuzhu,Kuzhu Zhen,ku zhu,ku zhu zhen,苦竹,苦竹镇', 26.9028700, 116.2122800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24090, 'Xinyuan', 'Xinyuan', 'Xinyuan,Xinyuan Jiedao,xin yuan,xin yuan jie dao,鑫源,鑫源街道', 33.1251600, 106.9810700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24091, 'Shaliangzi', 'Shaliangzi', 'Shaliangzi,Shaliangzi Xiang,sha liang zi,sha liang zi xiang,沙梁子,沙梁子乡', 33.8928400, 108.0104300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24092, 'Wangcang', 'Wangcang', 'Wangcang,wang cang,旺藏', 33.9507200, 103.5999500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24093, 'Ni’ao', 'Ni''ao', 'Ni''ao,Ni’ao,ni ao,尼傲', 33.9608300, 103.5505200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24094, 'Kaba', 'Kaba', 'Kaba,ka ba,卡坝', 33.9803500, 103.4948400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24095, 'Sigou', 'Sigou', 'Sigou,si gou,寺沟', 34.3656200, 104.0794800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24096, 'Shili', 'Shili', 'Shili,shi li,十里', 34.4230100, 103.9531300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24097, 'Chabu', 'Chabu', 'Chabu,cha bu,茶埠', 34.4870600, 104.0951600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24098, 'Daogao', 'Daogao', 'Daogao,Daogaoxiang,dao gao,dao gao xiang,刀告,刀告乡', 34.5026700, 103.1242200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24099, 'Nalang', 'Nalang', 'Nalang,Nalangxiang,na lang,na lang xiang,纳浪,纳浪乡', 34.5154000, 103.7005200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24100, 'Xijiang', 'Xijiang', 'Xijiang,xi jiang,西江', 34.5659000, 104.0034000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24101, 'Chubu', 'Chubu', 'Chubu,Chubuxiang,chu bu,chu bu xiang,初步,初步乡', 34.6180800, 103.2918500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24102, 'Xiaozhai', 'Xiaozhai', 'Xiaozhai,xiao zhai,小寨', 34.6391400, 104.0130800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24103, 'Yangyong', 'Yangyong', 'Yangyong,Yangyongxiang,yang yong,yang yong xiang,羊永,羊永乡', 34.6485300, 103.4780800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24104, 'Liushun', 'Liushun', 'Liushun,liu shun,流顺', 34.6492000, 103.5413900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24105, 'Longyuan', 'Longyuan', 'Longyuan,Longyuanxiang,long yuan,long yuan xiang,龙元,龙元乡', 34.6544700, 103.7761600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24106, 'Nawu', 'Nawu', 'Nawu,na wu,那吾', 34.9540300, 102.9133700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24107, 'Lianlu', 'Lianlu', 'Lianlu,lian lu,莲麓', 35.0143600, 103.7456000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24108, 'Bajiao', 'Bajiao', 'Bajiao,ba jiao,八角', 35.0282500, 103.6969300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24109, 'Kangduo', 'Kangduo', 'Kangduo,kang duo,康多', 35.0343100, 103.5245100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24110, 'Zuogaiduoma', 'Zuogaiduoma', 'Zuogaiduoma,Zuogaiduomaxiang,zuo gai duo ma,zuo gai duo ma xiang,佐盖多玛,佐盖多玛乡', 35.0558700, 103.1259900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24111, 'Tianjiahe', 'Tianjiahe', 'Tianjiahe,tian jia he,田家河', 35.0619100, 103.9413700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24112, 'Yangzhuang', 'Yangzhuang', 'Yangzhuang,yang zhuang,杨庄', 35.0671800, 104.0392000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24113, 'Zhiping Shezu', 'Zhiping Shezu', 'Zhiping Shezu,Zhiping Shezu Xiang,zhi ping she zu,zhi ping she zu xiang,治平畲族,治平畲族乡', 26.0390200, 116.5169100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24114, 'Xianan', 'Xianan', 'Chengjiao,Xianan,cheng jiao,xia nan,下南,城郊', 26.2666300, 116.6589700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24115, 'Yangxi', 'Yangxi', 'Yangxi,Yangxi Xiang,yang xi,yang xi xiang,杨溪,杨溪乡', 26.6219100, 116.3925400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24116, 'Toupi', 'Toupi', 'Toupi,Toupi Zhen,tou bei,tou bei zhen,头陂,头陂镇', 26.7560500, 116.1926800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24117, 'Gaolong', 'Gaolong', 'Gaolong,Gaolong Xiang,gao long,gao long xiang,高龙,高龙乡', 26.0562500, 115.7219500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24118, 'Fenkeng', 'Fenkeng', 'Fenkeng,Fenkeng Xiang,fen keng,fen keng xiang,汾坑,汾坑乡', 26.1285900, 115.6655500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24119, 'Meiyao', 'Meiyao', 'Meiyao,Meiyao Zhen,mei yao,mei yao zhen,梅窑,梅窑镇', 26.3986000, 115.7576300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24120, 'Dagu', 'Dagu', 'Dagu,Dagu Xiang,da gu,da gu xiang,大沽,大沽乡', 26.7344900, 115.7861600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24121, 'Chexi', 'Chexi', 'Chexi,Chexi Xiang,che xi,che xi xiang,车溪,车溪乡', 26.0478300, 115.5813600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24122, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Xiang,Ma’an,Ma’an Xiang,ma an,ma an xiang,马安,马安乡', 26.2088300, 115.5476800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24123, 'Ge’ao', 'Ge''ao', 'Ge''ao,Ge''ao Xiang,Ge’ao,Ge’ao Xiang,ge ao,ge ao xiang,葛坳,葛坳乡', 26.2623500, 115.7234800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24124, 'Gangmian', 'Gangmian', 'Gangmian,Gangmian Xiang,gang mian,gang mian xiang,冈面,冈面乡', 26.0878200, 115.8638900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24125, 'Dingbei', 'Dingbei', 'Dingbei,Dingbei Xiang,ding bei,ding bei xiang,丁陂,丁陂乡', 26.2592400, 115.8535000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24126, 'Shenkou', 'Shenkou', 'Shenkou,shen kou,莘口', 26.1642400, 117.5363700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24127, 'Qiujiang', 'Qiujiang', 'Qiujiang,Qiujiang Xiang,qiu jiang,qiu jiang xiang,虬江,虬江乡', 26.3926700, 117.7748800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24128, 'Yuanqian', 'Yuanqian', 'Yuanqian,Yuanqian Zhen,yuan qian,yuan qian zhen,苑前,苑前镇', 26.8010400, 115.1669900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24129, 'Shunfeng', 'Shunfeng', 'Shunfeng,Shunfeng Xiang,shun feng,shun feng xiang,顺峰,顺峰乡', 26.1890400, 115.0292700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24130, 'Zhonglong', 'Zhonglong', 'Zhonglong,Zhonglong Xiang,zhong long,zhong long xiang,中龙,中龙乡', 26.7071800, 115.1689800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24131, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Xiang,bao shan,bao shan xiang,宝山,宝山乡', 26.3484800, 115.0067800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24132, 'Sanxixiang', 'Sanxixiang', 'Sanxixiang,san xi xiang,三溪乡', 26.1005400, 115.2997200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24133, 'Shangyi', 'Shangyi', 'Shangyi,Shangyi Xiang,shang yi,shang yi xiang,上圯,上圯乡', 26.5981300, 115.1229000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24134, 'Zhangcaizhuang', 'Zhangcaizhuang', 'Zhangcaizhuang,Zhangcaizhuang Xiang,zhang cai zhuang,zhang cai zhuang xiang,张蔡庄,张蔡庄乡', 39.2879600, 112.3271000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24135, 'Shanpan', 'Shanpan', 'Shanpan,Shanpan Jiedao,shan pan,shan pan jie dao,山潘,山潘街道', 32.2332100, 118.7512400, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24136, 'Xichangmen', 'Xichangmen', 'Xichangmen,Xichangmen Jiedao,xi chang men,xi chang men jie dao,西厂门,西厂门街道', 32.2241700, 118.7580700, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24137, 'Baotaqiao', 'Baotaqiao', 'Baotaqiao,Baotaqiao Jiedao,bao ta qiao,bao ta qiao jie dao,宝塔桥,宝塔桥街道', 32.1145200, 118.7533000, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24138, 'Mufushan', 'Mufushan', 'Mufushan,Mufushan Jiedao,mu fu shan,mu fu shan jie dao,幕府山,幕府山街道', 32.1144400, 118.7727000, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24139, 'Xiejiadian', 'Xiejiadian', 'Xiejiadian,Xiejiadian Jiedao,xie jia dian,xie jia dian jie dao,卸甲甸,卸甲甸街道', 32.2110700, 118.7416400, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24140, 'Xintang', 'Xintang', 'Xintang,Xintang Jiedao,xin tang,xin tang jie dao,新塘,新塘街道', 23.1625700, 113.4068500, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24141, 'Shibi', 'Shibi', 'Shibi,Shibi Jiedao,shi bi,shi bi jie dao,石壁,石壁街道', 22.9774400, 113.2759600, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24142, 'Yayao', 'Yayao', 'Yayao,Yayao Zhen,ya yao,ya yao zhen,雅瑶,雅瑶镇', 23.3644100, 113.2155000, 'CN', '2012-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24143, 'Xingjiang', 'Xingjiang', 'Xingjiang,Xingjiang Xiang,xing jiang,xing jiang xiang,兴江,兴江乡', 26.4909500, 115.7717700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24144, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Xiang,cheng dong,cheng dong xiang,城东,城东乡', 26.2456300, 117.6190300, 'CN', '2013-07-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24145, 'Fenghuangcheng', 'Fenghuangcheng', 'Fenghuangcheng,Fenghuangcheng Zhen,feng huang cheng,feng huang cheng zhen,凤凰城,凤凰城镇', 39.7572400, 112.1758500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24146, 'Hougaoshizhuang', 'Hougaoshizhuang', 'Gaoshizhuang Xiang,Hougaoshizhuang,gao shi zhuang xiang,hou gao shi zhuang,后高石庄,高石庄乡', 39.8272000, 112.0802900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24147, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Zhen,gu cheng,gu cheng zhen,古城,古城镇', 39.4404000, 112.9341500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24148, 'Dongpu', 'Dongpu', 'Dongpu,Dongpu Zhen,dong bu,dong bu zhen,东埔,东埔镇', 23.7519000, 114.6929400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24149, 'Lakou', 'Lakou', 'Lakou,Lakou Zhen,lan kou,lan kou zhen,蓝口,蓝口镇', 23.9503800, 115.0802100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24150, 'Yuannan', 'Yuannan', 'Yuannan,Yuannan Zhen,yuan nan,yuan nan zhen,源南,源南镇', 23.7461300, 114.6873600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24151, 'Fucheng', 'Fucheng', 'Fucheng,Fucheng Zhen,fu cheng,fu cheng zhen,附城,附城镇', 23.6438000, 115.1624600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24152, 'Dongpu', 'Dongpu', 'Dongpu,Dongpu Jiedao,Dongpu Zhen,dong bu,dong bu jie dao,dong bu zhen,东埔,东埔街道,东埔镇', 23.7462600, 114.6849800, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24153, 'Shangcheng', 'Shangcheng', 'Shangcheng,Shangcheng Jiedao,shang cheng,shang cheng jie dao,上城,上城街道', 23.7403400, 114.6981600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24154, 'Changqiao', 'Changqiao', 'Changqiao,Changqiao Zhen,zhang qiao,zhang qiao zhen,长桥,长桥镇', 33.9368900, 113.3482600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24155, 'Longcheng', 'Longcheng', 'Longcheng,Longcheng Zhen,long cheng,long cheng zhen,龙城,龙城镇', 33.6071900, 113.9153300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24156, 'Jiangguanchi', 'Jiangguanchi', 'Jiangguanchi,Jiangguanchi Zhen,jiang guan chi,jiang guan chi zhen,将官池,将官池镇', 34.0006300, 113.8691400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24157, 'Lujiawan', 'Lujiawan', 'Lujiawan,Lujiawan Xiang,lu jia wan,lu jia wan xiang,芦家湾,芦家湾乡', 36.3744100, 106.5834800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24158, 'Chedao', 'Chedao', 'Chedao,Chedao Xiang,che dao,che dao xiang,车道,车道乡', 36.4007700, 106.7351200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24159, 'Yuanmao', 'Yuanmao', 'Yuanmao,Yuanmao Zhen,yuan mao,yuan mao zhen,原峁,原峁镇', 36.4463500, 106.7384300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24160, 'Luoshanchuan', 'Luoshanchuan', 'Luoshanchuan,Luoshanchuan Xiang,luo shan chuan,luo shan chuan xiang,罗山川,罗山川乡', 36.7962100, 106.9472700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24161, 'Pengbao', 'Pengbao', 'Pengbao,Pengbao Xiang,peng bao,peng bao xiang,彭堡,彭堡乡', 36.0918700, 106.1463100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24162, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Xiang,dong jiao,dong jiao xiang,东郊,东郊乡', 36.0045800, 106.2887600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24163, 'Gaotai', 'Gaotai', 'Gaotai,Gaotai Xiang,gao tai,gao tai xiang,高台,高台乡', 36.4487500, 106.3775700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24164, 'Shicha', 'Shicha', 'Shicha,Shicha Xiang,shi cha,shi cha xiang,石岔,石岔乡', 36.0079400, 106.5497800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24165, 'Gongbailiang', 'Gongbailiang', 'Gongbailiang,Gongbailiang Xiang,gong bai liang,gong bai liang xiang,拱拜梁,拱拜梁乡', 36.3754600, 106.3082100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24166, 'Jiaocha', 'Jiaocha', 'Jiaocha,Jiaocha Xiang,jiao cha,jiao cha xiang,交岔,交岔乡', 36.1466600, 106.5101000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24167, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Xiang,cheng jiao,cheng jiao xiang,城郊,城郊乡', 36.0080700, 106.2961500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24168, 'Gonghe', 'Gonghe', 'Gonghe,Gonghe Xiang,gong he,gong he xiang,共和,共和乡', 36.0695600, 106.3665000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24169, 'Maqu', 'Maqu', 'Maqu,Maqu Xiang,ma qu,ma qu xiang,马渠,马渠乡', 36.3960500, 106.4681800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24170, 'Magaozhuang', 'Magaozhuang', 'Magaozhuang,Magaozhuang Xiang,ma gao zhuang,ma gao zhuang xiang,马高庄,马高庄乡', 36.8739500, 106.4415700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24171, 'Heiquan', 'Heiquan', 'Heiquan,Heiquan Zhen,hei quan,hei quan zhen,黑泉,黑泉镇', 36.1055300, 106.1865100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24172, 'Xinshan', 'Xinshan', 'Xinshan,Xinshancun Xiang,xin shan,xin shan xiang,新山,新山乡', 36.3548700, 106.3785900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24173, 'Yanglu', 'Yanglu', 'Yanglu,Yanglu Xiang,yang lu,yang lu xiang,羊路,羊路乡', 36.6365500, 106.1416400, 'CN', '2010-08-14', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24174, 'Baitouli', 'Baitouli', 'Baitouli,Baitouli Xiang,bai tou li,bai tou li xiang,白头里,白头里乡', 39.9033800, 112.4914500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24175, 'Yangqianhe', 'Yangqianhe', 'Yangqianhe,Yangqianhe Xiang,yang qian he,yang qian he xiang,杨千河,杨千河乡', 40.1012900, 112.3050100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24176, 'Youwei', 'Youwei', 'Youwei,Youwei Zhen,you wei,you wei zhen,右卫,右卫镇', 40.1626500, 112.3461800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24177, 'Shuiyao', 'Shuiyao', 'Shuiyao,Shuiyao Xiang,shui yao,shui yao xiang,水窑,水窑乡', 39.9063300, 112.8805100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24178, 'Dianwan', 'Dianwan', 'Dianwan,Dianwan Zhen,dian wan,dian wan zhen,店湾,店湾镇', 39.9866500, 112.8654900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24179, 'Que’ershan', 'Que''ershan', 'Que''ershan,Que''ershan Zhen,Que’ershan,Que’ershan Zhen,que r shan,que r shan zhen,鹊儿山,鹊儿山镇', 40.1191400, 112.9432800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24180, 'Hadapu Zhen', 'Hadapu Zhen', 'Hadapu Zhen,ha da pu zhen,哈达铺镇', 34.2313200, 104.2230100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24181, 'Lichuan Zhen', 'Lichuan Zhen', 'Lichuan Zhen,li chuan zhen,理川镇', 34.2484500, 104.3194700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24182, 'Lujing Zhen', 'Lujing Zhen', 'Lujing Zhen,lu jing zhen,闾井镇', 34.3197800, 104.5572400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24183, 'Chengjiao Zhen', 'Chengjiao Zhen', 'Chengjiao Zhen,cheng jiao zhen,城郊镇', 34.4351600, 104.0398600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24184, 'Tange Zhen', 'Tange Zhen', 'Tange Zhen,tan ge zhen,滩歌镇', 34.6276400, 104.8406200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24185, 'Xinsi Zhen', 'Xinsi Zhen', 'Xinsi Zhen,xin si zhen,新寺镇', 34.6495600, 104.6298800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24186, 'Yuanyang Zhen', 'Yuanyang Zhen', 'Yuanyang Zhen,yuan yang zhen,鸳鸯镇', 34.7876800, 104.7753100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24187, 'Santai Zhen', 'Santai Zhen', 'Santai Zhen,san tai zhen,三台镇', 34.9493100, 104.7258400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24188, 'Wenfeng Zhen', 'Wenfeng Zhen', 'Wenfeng Zhen,wen feng zhen,文峰镇', 34.9517900, 104.6980600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24189, 'Caizi Zhen', 'Caizi Zhen', 'Caizi Zhen,cai zi zhen,菜子镇', 34.9884800, 104.4716200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24190, 'Gongchang Zhen', 'Gongchang Zhen', 'Gongchang Zhen,gong chang zhen,巩昌镇', 34.9988100, 104.6400000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24191, 'Tongchuan', 'Tongchuan', 'Tongchuan,Tongchuan Xiang,tong chuan,tong chuan xiang,桐川,桐川乡', 36.0157700, 107.5179700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24192, 'Binglincha', 'Binglincha', 'Binglincha,Binglincha Xiang,bing lin cha,bing lin cha xiang,冰淋岔,冰淋岔乡', 36.0404300, 107.3726400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24193, 'Nanzhuang', 'Nanzhuang', 'Nanzhuang,Nanzhuang Xiang,nan zhuang,nan zhuang xiang,南庄,南庄乡', 36.0685100, 107.9817100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24194, 'Xuanma', 'Xuanma', 'Xuanma,Xuanma Xiang,xuan ma,xuan ma xiang,玄马,玄马乡', 36.0769500, 107.8912500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24195, 'Wuchengzi', 'Wuchengzi', 'Wuchengzi,Wuchengzi Xiang,wu cheng zi,wu cheng zi xiang,吴城子,吴城子乡', 36.0992400, 107.2647100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24196, 'Caikouji', 'Caikouji', 'Caikouji,Caikouji Xiang,cai kou ji,cai kou ji xiang,蔡口集,蔡口集乡', 36.1351200, 107.3704100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24197, 'Dijiahe', 'Dijiahe', 'Dijiahe,Dijiahe Xiang,di jia he,di jia he xiang,翟家河,翟家河乡', 36.1368600, 107.6322800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24198, 'Wangzuizi', 'Wangzuizi', 'Wangzuizi,Wangzuizi Xiang,wang ju zi,wang ju zi xiang,王咀子,王咀子乡', 36.2230400, 107.7772000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24199, 'Shangliyuan', 'Shangliyuan', 'Shangliyuan,Shangliyuan Xiang,shang li yuan,shang li yuan xiang,上里塬,上里塬乡', 36.2876800, 107.7172500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24200, 'Hedao', 'Hedao', 'Hedao,Hedao Xiang,he dao,he dao xiang,合道,合道乡', 36.2971800, 107.1877800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24201, 'Heping', 'Heping', 'Heping,Heping Xiang,he ping,he ping xiang,何坪,何坪乡', 36.3342600, 107.1155100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24202, 'Xujiahe', 'Xujiahe', 'Xujiahe,Xujiahe Xiang,xu jia he,xu jia he xiang,许家河,许家河乡', 36.3434700, 107.5932000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24203, 'Luping', 'Luping', 'Luping,Luping Xiang,lu ping,lu ping xiang,路坪,路坪乡', 36.3543500, 107.0568700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24204, 'Wentai', 'Wentai', 'Wentai,Wentai Xiang,wen tai,wen tai xiang,温台,温台乡', 36.3647600, 107.9074800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24205, 'Liliangzi', 'Liliangzi', 'Liliangzi,Liliangzi Xiang,li liang zi,li liang zi xiang,李良子,李良子乡', 36.3810800, 107.8181800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24206, 'Xichuan', 'Xichuan', 'Xichuan,Xichuan Xiang,xi chuan,xi chuan xiang,西川,西川乡', 36.4956200, 107.1500800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24207, 'Miaoxiang', 'Miaoxiang', 'Miaoxiang,Miaoxiang Xiang,miao xiang,miao xiang xiang,庙巷,庙巷乡', 36.5285000, 107.9868800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24208, 'Bazhu', 'Bazhu', 'Bazhu,Bazhu Xiang,ba zhu,ba zhu xiang,八珠,八珠乡', 36.5543100, 107.5749800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24209, 'Qiaochuan', 'Qiaochuan', 'Qiaochuan,Qiaochuan Xiang,qiao chuan,qiao chuan xiang,乔川,乔川乡', 36.7637300, 107.6696900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24210, 'Siheyuan', 'Siheyuan', 'Siheyuan,Siheyuan Xiang,si he yuan,si he yuan xiang,四合塬,四合塬乡', 36.8519700, 107.3955400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24211, 'Xingyuan', 'Xingyuan', 'Xingyuan,Xingyuan Xiang,xing yuan,xing yuan xiang,杏园,杏园乡', 39.1692700, 113.2688400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24212, 'Qianfoling', 'Qianfoling', 'Qianfoling,Qianfoling Zhen,qian fu ling,qian fu ling zhen,千佛岭,千佛岭镇', 39.5347900, 113.8253200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24213, 'Nanyulin', 'Nanyulin', 'Nanyulin,Nanyulin Xiang,nan yu lin,nan yu lin xiang,南榆林,南榆林乡', 39.7411900, 113.5658900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24214, 'Zonghan', 'Zonghan', 'Zonghan,Zonghan Jiedao,zong han,zong han jie dao,宗汉,宗汉街道', 30.1922200, 121.2252000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24215, 'Sanbei', 'Sanbei', 'Sanbei,Sanbei Zhen,san bei,san bei zhen,三北,三北镇', 30.0948700, 121.4982200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24216, 'Beiwa', 'Beiwa', 'Beiwa,Wangwa Zhen,bei wa,wang wa zhen,北洼,王洼镇', 36.1388400, 106.6093200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24217, 'Dongjiao', 'Dongjiao', 'Dongjiao,dong jiao,东郊', 32.5030200, 119.9337500, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24218, 'Shuangqiao', 'Shuangqiao', 'Shuangqiao,Shuangqiao Zhen,shuang qiao,shuang qiao zhen,双桥,双桥镇', 30.0588000, 122.0114400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24219, 'Pingan', 'Pingan', 'Ping''an Zhen,Pingan,Ping’an Zhen,ping an,ping an zhen,平安,平安镇', 30.8997300, 121.7259500, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24220, 'Qianxu Zhen', 'Qianxu Zhen', 'Qianxu Zhen,qian wei zhen,钱圩镇', 30.7767200, 121.2419400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24221, 'Shaochang Zhen', 'Shaochang Zhen', 'Shaochang Zhen,shao chang zhen,邵厂镇', 30.9084000, 121.7529400, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24222, 'Shuyuan Zhen', 'Shuyuan Zhen', 'Shuyuan Zhen,shu yuan zhen,书院镇', 30.9315900, 121.8601900, 'CN', '2011-05-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24223, 'Daotouzui', 'Daotouzui', 'Daotouzui,Fodu,dao tou zui,fu du,佛渡,道头嘴', 29.7427600, 122.0216500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24224, 'Heshi', 'Heshi', 'Heshi,Heshi Zhen,he shi,he shi zhen,河失,河失镇', 32.2066500, 120.1362600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24225, 'Xiqiao', 'Xiqiao', 'Xiqiao,Xiqiao Zhen,xi qiao,xi qiao zhen,溪桥,溪桥镇', 32.2257600, 120.1821800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24226, 'Yaosai', 'Yaosai', 'Yaosai,Yaosai Zhen,yao sai,yao sai zhen,要塞,要塞镇', 31.9054300, 120.2821000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24227, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 31.8639000, 119.9542100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24228, 'Jishi', 'Jishi', 'Jishi,Jishi Zhen,ji shi,ji shi zhen,季市,季市镇', 32.1353900, 120.3059800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24229, 'Qixu', 'Qixu', 'Dongtouxu,Qixu,Qixu Zhen,dong tou wei,qi wei,qi wei zhen,七圩,七圩镇,东头圩', 32.0273900, 120.0146700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24230, 'Lianyi', 'Lianyi', 'Lianyi,Lianyi Zhen,lian yi,lian yi zhen,廉贻,廉贻镇', 32.8994700, 120.2391200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24231, 'Wulie', 'Wulie', 'Wulie,Wulie Zhen,wu lie,wu lie zhen,五烈,五烈镇', 32.8590600, 120.2420600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24232, 'Guangshan', 'Guangshan', 'Guangshan,Guangshan Zhen,guang shan,guang shan zhen,广山,广山镇', 32.8047000, 120.2097300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24233, 'Chaoqiao', 'Chaoqiao', 'Chaoqiao,Chaoqiao Zhen,chao qiao,chao qiao zhen,潮桥,潮桥镇', 32.5503100, 120.6737100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24234, 'Xinqiao', 'Xinqiao', 'Xinqiao,Xinqiao Zhen,xin qiao,xin qiao zhen,新桥,新桥镇', 32.9457000, 120.7933600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24235, 'Yangjialusanqiu', 'Yangjialusanqiu', 'Xiaocao''e Zhen,Xiaocao’e Zhen,Yangjialusanqiu,xiao cao e zhen,yang jia lu san qiu,小曹娥镇,杨家路三丘', 30.2196400, 121.0679500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24236, 'Saga', 'Saga', 'Kyakyaru,Saga,Сага', 29.3236700, 85.2260100, 'CN', '2010-10-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24237, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Zhen,Chang’an,Chang’an Zhen,zhang an,zhang an zhen,长安,长安镇', 43.0271900, 129.6685500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24238, 'Huangni', 'Huangni', 'Huangni,Xintunzi Zhen,huang ni,xin tun zi zhen,新屯子镇,黄泥', 42.5563900, 127.2965000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24239, 'Xianpudong', 'Xianpudong', 'Baijin Xiang,Xianpudong,bai jin xiang,xian pu dong,咸朴洞,白金乡', 42.4503400, 129.4028700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24240, 'Chongmin', 'Chongmin', 'Chongmin,Dexin Xiang,chong min,de xin xiang,崇民,德新乡', 42.7283900, 129.5993500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24241, 'Minzhu', 'Minzhu', 'Minzhu,Taiwang,Taiwang Xiang,Taiwang Zhen,min zhu,tai wang,tai wang xiang,tai wang zhen,太王,太王乡,太王镇,民主', 41.1321500, 126.2018100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24242, 'Hulutao', 'Hulutao', 'Hulutao,Hulutao Xiang,hu lu tao,hu lu tao xiang,葫芦套,葫芦套乡', 41.7933100, 125.9397600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24243, 'Jindou', 'Jindou', 'Jindou,Jindou Chaoxianzu Manzu Xiang,jin dou,jin dou chao xian zu man zu xiang,金斗,金斗朝鲜族满族乡', 41.7047700, 125.6909400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24244, 'Jiangdianzi', 'Jiangdianzi', 'Jiangdian Zhen,Jiangdianzi,jiang dian zhen,jiang dian zi,江甸子,江甸镇', 41.4689500, 125.7131900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24245, 'Dachuan', 'Dachuan', 'Dachuan,Dachuan Xiang,da chuan,da chuan xiang,大川,大川乡', 41.5477700, 125.5390200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24246, 'Chisong', 'Chisong', 'Chisong,Chisong Xiang,chi song,chi song xiang,赤松,赤松乡', 42.5799600, 127.0056200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24247, 'Dujia', 'Dujia', 'Dujia,Xinancha,Xinancha Zhen,du jia,xi nan cha,xi nan cha zhen,杜家,西南岔,西南岔镇', 42.6508600, 126.8933300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24248, 'Yanping', 'Yanping', 'Yanping,Yanping Xiang,yan ping,yan ping xiang,燕平,燕平乡', 42.2686800, 126.9112200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24249, 'Sanchakou Chaoxianzu', 'Sanchakou Chaoxianzu', 'Sanchakou Chaoxianzu,Sanchakou Chaoxianzu Zhen,san cha kou chao xian zu,san cha kou chao xian zu zhen,三岔口朝鲜族,三岔口朝鲜族镇', 44.0169500, 131.2363900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24250, 'Gongji', 'Gongji', 'Gongji,Gongjixiang,gong ji,gong ji xiang,公吉,公吉乡', 42.9950500, 126.8867900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24251, 'Zhu Cheng City', 'Zhu Cheng City', '', 35.9950200, 119.4025900, 'CN', '2010-11-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24252, 'Mangdang', 'Mangdang', 'Mangdang,Mangdang Zhen,mang dang,mang dang zhen,茫荡,茫荡镇', 26.6877800, 118.1562300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24253, 'Nanzheng Chengguanzhen', 'Nanzheng Chengguanzhen', 'Chengguan Zhen,Nanzheng,Nanzheng Chengguanzhen,Nanzheng Xian,cheng guan zhen,nan zheng,nan zheng cheng guan zhen,nan zheng xian,南郑,南郑县,南郑城关镇,城关镇', 33.0045200, 106.9346600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24254, 'Minyue', 'Minyue', 'Minyue,Minyue Chaoxianzuxiang,min le,min le chao xian zu xiang,民乐,民乐朝鲜族乡', 45.0518000, 127.0489000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24255, 'Ashihe', 'Ashihe', 'Ashihe,Ashihe Jiedao,a shen he,a shen he jie dao,阿什河,阿什河街道', 45.5358000, 126.9737000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24256, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Xiang,yong he,yong he xiang,永和,永和乡', 45.8278100, 127.1064700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24257, 'Guang’en', 'Guang''en', 'Guang''en,Guang''en Xiang,Guang’en,Guang’en Xiang,guang en,guang en xiang,光恩,光恩乡', 45.6477700, 127.8162600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24258, 'Yanhe', 'Yanhe', 'Yanhe,Yanhe Chaoxianzuxiang,yan he,yan he chao xian zu xiang,延和,延和朝鲜族乡', 45.1158600, 126.9197500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24259, 'Songhuajiang', 'Songhuajiang', 'Songhuajiang,Songhuajiang Xiang,song hua jiang,song hua jiang xiang,松花江,松花江乡', 46.0371600, 127.3255100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24260, 'Xiaoshanzi', 'Xiaoshanzi', 'Xiaoshanzi,Xiaoshanzi Zhen,xiao shan zi,xiao shan zi zhen,小山子,小山子镇', 44.9071100, 127.6024000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24261, 'Hedong', 'Hedong', 'Hedong,Hedong Chaoxianzu Xiang,Hedong Zhen,he dong,he dong chao xian zu xiang,he dong zhen,河东,河东朝鲜族乡,河东镇', 45.2566800, 128.0309700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24262, 'Jiaojie', 'Jiaojie', 'Jiaojie,Jiaojie Zhen,jiao jie,jiao jie zhen,交界,交界镇', 45.3472400, 127.0887500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24263, 'Songfengshan', 'Songfengshan', 'Songfengshan,Songfengshan Zhen,song feng shan,song feng shan zhen,松峰山,松峰山镇', 45.4020900, 127.4306800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24264, 'Shuangfeng', 'Shuangfeng', 'Shuangfeng,Shuangfeng Zhen,shuang feng,shuang feng zhen,双丰,双丰镇', 45.4413800, 126.9666500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24265, 'Pingfang', 'Pingfang', 'Pingfang,Pingfang Zhen,ping fang,ping fang zhen,平坊,平坊镇', 45.5541500, 127.4640900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24266, 'Ningyuan', 'Ningyuan', 'Ningyuan,Ningyuan Zhen,ning yuan,ning yuan zhen,宁远,宁远镇', 45.7308700, 127.9162000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24267, 'Feiketu', 'Feiketu', 'Feiketu,Feiketu Zhen,fei ke tu,fei ke tu zhen,蜚克图,蜚克图镇', 45.7469400, 127.1451900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24268, 'Juren', 'Juren', 'Juren,Juren Zhen,ju ren,ju ren zhen,居仁,居仁镇', 45.7607500, 127.2797600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24269, 'Yongyuan', 'Yongyuan', 'Yongyuan,Yongyuan Zhen,yong yuan,yong yuan zhen,永源,永源镇', 45.7738700, 127.0081700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24270, 'Tangfang', 'Tangfang', 'Tangfang,Tangfang Zhen,tang fang,tang fang zhen,糖坊,糖坊镇', 45.9094300, 127.0572900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24271, 'Zhiguang', 'Zhiguang', 'Zhiguang,Zhiguang Xiang,zhi guang,zhi guang xiang,志广,志广乡', 44.9713300, 127.4611700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24272, 'Weiguo', 'Weiguo', 'Weiguo,Weiguo Xiang,wei guo,wei guo xiang,卫国,卫国乡', 45.0237600, 127.3483200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24273, 'Changbao', 'Changbao', 'Changbao,Changbao Xiang,chang bao,chang bao xiang,常堡,常堡乡', 45.0351900, 127.2093200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24274, 'Yingchengzi', 'Yingchengzi', 'Yingchengzi,Yingchengzi Manzuxiang,ying cheng zi,ying cheng zi man zu xiang,营城子,营城子满族乡', 45.1677800, 126.9558800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24275, 'Bajiazi', 'Bajiazi', 'Bajiazi,Bajiazi Xiang,ba jia zi,ba jia zi xiang,八家子,八家子乡', 45.2292800, 127.0415100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24276, 'Changshou', 'Changshou', 'Changshou,Changshou Xiang,zhang shou,zhang shou xiang,长寿,长寿乡', 45.2696000, 127.9329300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24277, 'Daling', 'Daling', 'Daling,Daling Xiang,da ling,da ling xiang,大岭,大岭乡', 45.5063000, 127.1126600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24278, 'Sheli', 'Sheli', 'Sheli,Sheli Xiang,she li,she li xiang,舍利,舍利乡', 45.5641700, 126.9278300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24279, 'Hongxing', 'Hongxing', 'Hongxing,Hongxing Xiang,hong xing,hong xing xiang,红星,红星乡', 45.5657600, 127.1112600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24280, 'Xiangyang', 'Xiangyang', 'Xiangyang,Xiangyang Xiang,xiang yang,xiang yang xiang,向阳,向阳乡', 45.7529700, 126.9230400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24281, 'Sanbao', 'Sanbao', 'Sanbao,Sanbao Xiang,san bao,san bao xiang,三宝,三宝乡', 45.7559500, 127.6684100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24282, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Xiang,Chang’an,Chang’an Xiang,chang an,chang an xiang,常安,常安乡', 45.7635200, 127.8380000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24283, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Xiang,yong he,yong he xiang,永和,永和乡', 45.8398900, 127.0873700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24284, 'Niaohe', 'Niaohe', 'Niaohe,Niaohe Xiang,niao he,niao he xiang,鸟河,鸟河乡', 45.9022300, 127.4577000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24285, 'Minhe', 'Minhe', 'Minhe,Minhe Xiang,min he,min he xiang,民和,民和乡', 45.9058700, 127.5619600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24286, 'Manjing', 'Manjing', 'Manjing,Manjing Xiang,man jing,man jing xiang,满井,满井乡', 45.9093100, 127.2720200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24287, 'Jianguo', 'Jianguo', 'Jianguo,Jianguo Xiang,jian guo,jian guo xiang,建国,建国乡', 45.9928600, 128.0670500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24288, 'Jixing', 'Jixing', 'Jixing,Jixing Xiang,ji xing,ji xing xiang,吉兴,吉兴乡', 46.0060400, 127.9115800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24289, 'Fujiang', 'Fujiang', 'Fujiang,Fujiang Xiang,fu jiang,fu jiang xiang,富江,富江乡', 46.0326700, 127.4563800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24290, 'Yanglin', 'Yanglin', 'Yanglin,Yanglin Xiang,yang lin,yang lin xiang,杨林,杨林乡', 46.0776000, 127.1315500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24291, 'Haitangwan', 'Haitangwan', 'Haitangwan,Haitangwan Zhen,hai tang wan,hai tang wan zhen,海棠湾,海棠湾镇', 18.4033700, 109.7500300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24292, 'Donghe', 'Donghe', 'Donghe,Donghe Zhen,dong he,dong he zhen,东河,东河镇', 19.0508000, 108.9376700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24293, 'Yelin', 'Yelin', 'Lingshui Lizu Zizhixian,Yelin,Yelin Zhen,ling shui li zu zi zhi xian,ye lin,ye lin zhen,椰林,椰林镇,陵水黎族自治县', 18.5209900, 110.0397000, 'CN', '2013-10-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24294, 'Taipinghu', 'Taipinghu', 'Taipinghu,Taipinghu Zhen,tai ping hu,tai ping hu zhen,太平湖,太平湖镇', 30.3672700, 118.0397400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24295, 'Haoshan', 'Haoshan', 'Haoshan,Haoshan Xiang,hao shan,hao shan xiang,浩山,浩山乡', 29.8845400, 116.7905900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24296, 'Chengshan', 'Chengshan', 'Chengshan,Chengshan Zhen,cheng shan,cheng shan zhen,城山,城山镇', 29.6015000, 116.2570800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24297, 'Wushan', 'Wushan', 'Wushan,Wushan Zhen,wu shan,wu shan zhen,武山,武山镇', 29.5834800, 116.3309200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24298, 'Shishan', 'Shishan', 'Shishan,Shishan Xiang,shi shan,shi shan xiang,狮山,狮山乡', 29.3609700, 116.4829300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24299, 'Yaquehu', 'Yaquehu', 'Yaquehu,Yaquehu Xiang,ya que hu,ya que hu xiang,鸦鹊湖,鸦鹊湖乡', 29.3239000, 116.6294000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24300, 'Dingshan', 'Dingshan', 'Dingshan,Dingshan Zhen,ding shan,ding shan zhen,定山,定山镇', 29.8235600, 116.4099200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24301, 'Liaohua', 'Liaohua', 'Liaohua,Liaohua Zhen,liao hua,liao hua zhen,蓼花,蓼花镇', 29.3930800, 115.9961000, 'CN', '2011-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24302, 'Changyi', 'Changyi', 'Changyi,Changyi Xiang,chang yi,chang yi xiang,昌邑,昌邑乡', 29.0244300, 116.0606000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24303, 'Yujiahe', 'Yujiahe', 'Yujiahe,Yujiahe Xiang,yu jia he,yu jia he xiang,虞家河,虞家河乡', 29.6851600, 116.0462400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24304, 'Mingshan', 'Mingshan', 'Mingshan,Mingshan Xiang,ming shan,ming shan xiang,鸣山,鸣山乡', 29.4210300, 116.4635900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24305, 'Baishazhou', 'Baishazhou', 'Baishazhou,Baishazhou Xiang,bai sha zhou,bai sha zhou xiang,白沙洲,白沙洲乡', 29.1602600, 116.6144800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24306, 'Huanghua', 'Huanghua', 'Huanghua,Huanghua Xiang,Huanghua Zhen,huang hua,huang hua xiang,huang hua zhen,黄花,黄花乡,黄花镇', 29.8625600, 116.5947000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24307, 'Maying', 'Maying', 'Maying,Maying Zhen,ma ying,ma ying zhen,马影,马影镇', 29.7246300, 116.2920400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24308, 'Tuanlin', 'Tuanlin', 'Tuanlin,Tuanlin Xiang,tuan lin,tuan lin xiang,团林,团林乡', 29.0720300, 116.7027400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24309, 'Tianhong', 'Tianhong', 'Tianhong,Tianhong Zhen,tian hong,tian hong zhen,天红,天红镇', 29.6845600, 116.4381100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24310, 'Xiangxi', 'Xiangxi', 'Xiangxi,Xiangxi Xiang,xiang xi,xiang xi xiang,芗溪,芗溪乡', 29.2407300, 116.5482400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24311, 'Yangfeng', 'Yangfeng', 'Yangfeng,Yangfeng Xiang,yang feng,yang feng xiang,阳峰,阳峰乡', 29.2910800, 116.3776500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24312, 'Dagang', 'Dagang', 'Dagang,Dagang Zhen,da gang,da gang zhen,大港,大港镇', 29.5466100, 116.4823500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24313, 'Cailing', 'Cailing', 'Cailing,Cailing Zhen,cai ling,cai ling zhen,蔡岭,蔡岭镇', 29.4998500, 116.3810900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24314, 'Fulong', 'Fulong', 'Fulong,Fulong Xiang,fu long,fu long xiang,付垄,付垄乡,付垅乡,傅垄乡', 29.6600700, 116.3375200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24315, 'Beishan', 'Beishan', 'Beishan,Beishan Xiang,bei shan,bei shan xiang,北山,北山乡', 29.2925800, 116.1952700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24316, 'Bailu', 'Bailu', 'Bailu,Bailu Zhen,bai lu,bai lu zhen,白鹿,白鹿镇', 29.4861900, 116.0393900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24317, 'Yinbaohu', 'Yinbaohu', 'Yinbaohu,Yinbaohu Xiang,yin bao hu,yin bao hu xiang,银宝湖,银宝湖乡', 29.2909400, 116.5795000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24318, 'Shuanggang', 'Shuanggang', 'Shuanggang,Shuanggang Zhen,shuang gang,shuang gang zhen,双港,双港镇', 29.0751100, 116.6155900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24319, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Zhen,dong sheng,dong sheng zhen,东升,东升镇', 29.8304100, 116.6955200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24320, 'Hehe', 'Hehe', 'Hehe,Hehe Xiang,he he,he he xiang,和合,和合乡', 29.2306800, 116.2949000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24321, 'Xiyuan', 'Xiyuan', 'Xiyuan,Xiyuan Xiang,xi yuan,xi yuan xiang,西源,西源乡', 29.2160800, 116.4230100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24322, 'Huangcun', 'Huangcun', 'Huangcun,Huangcun Xiang,huang cun,huang cun xiang,凰村,凰村乡', 29.7708100, 116.3199600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24323, 'Furongdun', 'Furongdun', 'Furongdun,Furongdun Zhen,fu rong dun,fu rong dun zhen,芙蓉墩,芙蓉墩镇', 29.8594300, 116.4932200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24324, 'Dasha', 'Dasha', 'Dasha,Dasha Zhen,da sha,da sha zhen,大沙,大沙镇', 29.2646500, 116.3274900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24325, 'Dashu', 'Dashu', 'Dashu,Dashu Xiang,da shu,da shu xiang,大树,大树乡', 29.2780800, 116.2619200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24326, 'Duobao', 'Duobao', 'Duobao,Duobao Xiang,duo bao,duo bao xiang,多宝,多宝乡', 29.4036700, 116.1234000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24327, 'Chunqiao', 'Chunqiao', 'Chunqiao,Chunqiao Xiang,chun qiao,chun qiao xiang,春桥,春桥乡', 29.5374100, 116.2792500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24328, 'Zhangqing', 'Zhangqing', 'Zhangqing,Zhangqing Xiang,zhang qing,zhang qing xiang,张青,张青乡', 29.7151000, 116.3322300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24329, 'Zuoli', 'Zuoli', 'Zuoli,Zuoli Zhen,zuo li,zuo li zhen,左里,左里镇', 29.4240000, 116.1966700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24330, 'Dalong', 'Dalong', 'Dalong,Dalong Xiang,da long,da long xiang,大垄,大垄乡,大垅乡', 29.7441300, 116.3843300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24331, 'Zhegang', 'Zhegang', 'Zhegang,Zhegang Xiang,zhe gang,zhe gang xiang,柘港,柘港乡', 29.3455000, 116.7308100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24332, 'Zhuhu', 'Zhuhu', 'Zhuhu,Zhuhu Xiang,zhu hu,zhu hu xiang,珠湖,珠湖乡', 29.1864700, 116.6704400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24333, 'Sushan', 'Sushan', 'Sushan,Sushan Xiang,su shan,su shan xiang,苏山,苏山乡', 29.5010800, 116.2062500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24334, 'Zhongguan', 'Zhongguan', 'Zhongguan,Zhongguan Zhen,zhong guan,zhong guan zhen,中馆,中馆镇', 29.3837900, 116.5326400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24335, 'Sixi', 'Sixi', 'Sixi,Sixi Xiang,si xi,si xi xiang,泗溪,泗溪乡', 30.0186600, 118.0564600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24336, 'Yingzhou', 'Yingzhou', 'Yingzhou,Yingzhou Xiang,ying zhou,ying zhou xiang,瀛洲,瀛洲乡', 30.0617300, 118.6443400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24337, 'Xiancun', 'Xiancun', 'Xiancun,Xiancun Xiang,xian cun,xian cun xiang,贤村,贤村乡', 30.1366500, 118.0145800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24338, 'Jiapeng', 'Jiapeng', 'Jiapeng,Jiapeng Xiang,jia peng,jia peng xiang,家朋,家朋乡', 30.2402700, 118.8090900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24339, 'Taohuatan', 'Taohuatan', 'Taohuatan,Taohuatan Zhen,tao hua tan,tao hua tan zhen,桃花潭,桃花潭镇', 30.4886900, 118.1455000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24340, 'Yangong', 'Yangong', 'Yangong,Yangong Zhen,yan gong,yan gong zhen,晏公,晏公镇', 30.6506200, 118.4501900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24341, 'Changqiao', 'Changqiao', 'Changqiao,Changqiao Xiang,chang qiao,chang qiao xiang,昌桥,昌桥乡', 30.7600000, 118.4054400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24342, 'Sanli', 'Sanli', 'Sanli,Sanli Zhen,san li,san li zhen,三里,三里镇', 30.7754500, 118.2547600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24343, 'Daihui', 'Daihui', 'Dahui Zhen,Daihui,dai hui,dai hui zhen,戴汇,戴汇镇', 30.8908900, 118.1830700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24344, 'Tianhu', 'Tianhu', 'Tianhu,Tianhu Zhen,tian hu,tian hu zhen,天湖,天湖镇', 30.9167400, 118.5968600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24345, 'Hanlin', 'Hanlin', 'Hanlin,Hanlin Zhen,han lin,han lin zhen,翰林,翰林镇', 19.3338700, 110.2582600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24346, 'Fuwen', 'Fuwen', 'Fuwen,Fuwen Zhen,fu wen,fu wen zhen,富文,富文镇', 19.5513700, 110.2554000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24347, 'Xiaxin', 'Xiaxin', 'Xiaxin,Xiaxin Zhen,xia xin,xia xin zhen,下新,下新镇', 29.9897100, 116.0067400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24348, 'Liuzuo', 'Liuzuo', 'Liuzuo,Liuzuo Xiang,liu zuo,liu zuo xiang,刘佐,刘佐乡', 29.8229600, 116.0973000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24349, 'Tielu', 'Tielu', 'Tielu,Tielu Xiang,tie lu,tie lu xiang,铁炉,铁炉乡', 29.6082600, 116.7087900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24350, 'Longquan', 'Longquan', 'Longquan,Longquanzhen,long quan,long quan zhen,龙泉,龙泉镇', 29.6400700, 116.8135300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24351, 'Huangbai', 'Huangbai', 'Huangbai,Huangbai Xiang,huang bai,huang bai xiang,黄柏,黄柏乡', 25.9553000, 116.0059600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24352, 'Zeqin', 'Zeqin', 'Zeqin,Zeqin Xiang,ze qin,ze qin xiang,泽覃,泽覃乡', 25.8435600, 116.0154500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24353, 'Chengmen', 'Chengmen', 'Chengmen,Chengmen Xiang,cheng men,cheng men xiang,城门,城门乡', 29.6435300, 115.8123700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24354, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,lian hua,lian hua zhen,莲花,莲花镇', 29.6409500, 115.9793000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24355, 'Shizi', 'Shizi', 'Shizi,Shizi Zhen,shi zi,shi zi zhen,狮子,狮子镇', 29.6028400, 115.8362400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24356, 'Jinhu', 'Jinhu', 'Jinhu,Jinhu Xiang,jin hu,jin hu xiang,金湖,金湖乡', 29.2898400, 115.8146300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24357, 'Jiangshang', 'Jiangshang', 'Jiangshang,Jiangshang Xiang,jiang shang,jiang shang xiang,江上,江上乡', 29.1641800, 115.5948400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24358, 'Xiafan', 'Xiafan', 'Xiafan,Xiafan Zhen,xia fan,xia fan zhen,夏畈,夏畈镇', 29.7674700, 115.5421600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24359, 'Lixin', 'Lixin', 'Lixin,Lixin Xiang,li xin,li xin xiang,立新,立新乡', 29.0222400, 115.7411100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24360, 'Zequan', 'Zequan', 'Zequan,Zequan Xiang,ze quan,ze quan xiang,泽泉,泽泉乡', 29.3243300, 115.8470200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24361, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Zhen,bai yang,bai yang zhen,白杨,白杨镇', 29.7333300, 115.6494200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24362, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Xiang,nan yang,nan yang xiang,南阳,南阳乡', 29.7348500, 115.5156400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24363, 'Liaonan', 'Liaonan', 'Liaonan,Liaonan Xiang,liao nan,liao nan xiang,蓼南,蓼南乡', 29.3012600, 115.9687900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24364, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Xiang,Yong’an,Yong’an Xiang,yong an,yong an xiang,永安,永安乡', 29.7653400, 115.7897300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24365, 'Linquan', 'Linquan', 'Linquan,Linquan Xiang,lin quan,lin quan xiang,林泉,林泉乡', 29.4608000, 115.7270900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24366, 'Chengzi', 'Chengzi', 'Chengzi,Chengzi Zhen,cheng zi,cheng zi zhen,城子,城子镇', 29.8376200, 115.6883900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24367, 'Wujiao', 'Wujiao', 'Wujiao,Wujiao Xiang,wu jiao,wu jiao xiang,武蛟,武蛟乡', 29.7688100, 115.6224500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24368, 'Meitang', 'Meitang', 'Meitang,Meitang Zhen,mei tang,mei tang zhen,梅棠,梅棠镇', 29.2445200, 115.6280800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24369, 'Gaotang', 'Gaotang', 'Gaotang,Gaotang Xiang,gao tang,gao tang xiang,高塘,高塘乡', 29.4146500, 115.7749100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24370, 'Wushan', 'Wushan', 'Wushan,Wushan Xiang,wu shan,wu shan xiang,吴山,吴山乡', 29.4517600, 115.6562800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24371, 'Xinhe', 'Xinhe', 'Xinhe,Xinhe Zhen,xin he,xin he zhen,新合,新合镇', 29.6196400, 115.7690600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24372, 'Sujiadang', 'Sujiadang', 'Sujiadang,Sujiadang Xiang,su jia dang,su jia dang xiang,苏家垱,苏家垱乡', 29.2761500, 115.8719800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24373, 'Fenglin', 'Fenglin', 'Fenglin,Fenglin Zhen,feng lin,feng lin zhen,丰林,丰林镇', 29.3929300, 115.7177100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24374, 'Jiuhe', 'Jiuhe', 'Jiuhe,Jiuhe Xiang,jiu he,jiu he xiang,九合,九合乡', 29.0557900, 115.8182700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24375, 'Tiehe', 'Tiehe', 'Tiehe,Tiehe Xiang,tie he,tie he xiang,铁河,铁河乡', 29.0270300, 115.9710300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24376, 'Sanjiao', 'Sanjiao', 'Sanjiao,Sanjiao Xiang,san jiao,san jiao xiang,三角,三角乡', 29.0498200, 115.8439200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24377, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Zhen,gao feng,gao feng zhen,高丰,高丰镇', 29.6427300, 115.5555700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24378, 'Yanfang', 'Yanfang', 'Yanfang,Yanfang Zhen,yan fang,yan fang zhen,燕坊,燕坊镇', 29.2236900, 115.7007600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24379, 'Hedong', 'Hedong', 'Hedong,Hedong Xiang,he dong,he dong xiang,河东,河东乡', 29.3382600, 115.7662700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24380, 'Yongquan', 'Yongquan', 'Yongquan,Yongquan Xiang,yong quan,yong quan xiang,涌泉,涌泉乡', 29.6172000, 115.6691000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24381, 'Hualin', 'Hualin', 'Hualin,Hualin Zhen,hua lin,hua lin zhen,华林,华林镇', 29.3687000, 115.9511200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24382, 'Minshan', 'Minshan', 'Minshan,Minshan Xiang,min shan,min shan xiang,岷山,岷山乡', 29.5058300, 115.7488300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24383, 'Baota', 'Baota', 'Baota,Baota Xiang,bao ta,bao ta xiang,宝塔,宝塔乡', 29.3242800, 115.7525800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24384, 'Saiyang', 'Saiyang', 'Saiyang,Saiyang Zhen,sai yang,sai yang zhen,赛阳,赛阳镇', 29.5788500, 115.9245400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24385, 'Aimin', 'Aimin', 'Aimin,Aimin Xiang,ai min,ai min xiang,爱民,爱民乡', 29.4409100, 115.5416400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24386, 'Xianggui', 'Xianggui', 'Xianggui,Xianggui Zhen,xiang gui,xiang gui zhen,象贵,象贵镇', 24.0788900, 113.7608300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24387, 'Yinghua', 'Yinghua', 'Yinghua,Yinghua Zhen,ying hua,ying hua zhen,英华,英华镇', 24.2255600, 113.6633300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24388, 'Caishan', 'Caishan', 'Caishan,Caishan Zhen,cai shan,cai shan zhen,蔡山,蔡山镇', 29.8836600, 115.7868400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24389, 'Xinkai', 'Xinkai', 'Xinkai,Xinkai Zhen,xin kai,xin kai zhen,新开,新开镇', 29.8124600, 115.8104600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24390, 'Dajin', 'Dajin', 'Dajin,Dajin Zhen,da jin,da jin zhen,大金,大金镇', 29.9978500, 115.6121000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24391, 'Zhanghekou', 'Zhanghekou', 'Zhanghekou,Zhanghekou Xiang,zhang he kou,zhang he kou xiang,张河口,张河口乡', 29.9951000, 115.7489300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24392, 'Xiangshan', 'Xiangshan', 'Xiangshan,Xiangshan Xiang,xiang shan,xiang shan xiang,项山,项山乡', 24.9387400, 115.8091300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24393, 'Huanglin', 'Huanglin', 'Huanglin,Huanglin Xiang,huang lin,huang lin xiang,黄麟,黄麟乡', 25.9179700, 115.6209300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24394, 'Yunshishan', 'Yunshishan', 'Yunshishan,Yunshishan Xiang,yun shi shan,yun shi shan xiang,云石山,云石山乡', 25.8641100, 115.8633200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24395, 'Zhongshi', 'Zhongshi', 'Zhongshi,Zhongshi Xiang,zhong shi,zhong shi xiang,重石,重石乡', 25.3874600, 115.4167800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24396, 'Lianjiang', 'Lianjiang', 'Lianjiang,Lianjiang Xiang,lian jiang,lian jiang xiang,濂江,濂江乡', 25.1314100, 115.3928600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24397, 'Xinlong', 'Xinlong', 'Xinlong,Xinlong Xiang,xin long,xin long xiang,新龙,新龙乡', 25.1451500, 115.3267700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24398, 'Gaoyunshan', 'Gaoyunshan', 'Gaoyunshan,Gaoyunshan Xiang,gao yun shan,gao yun shan xiang,高云山,高云山乡', 25.1690200, 115.5219100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24399, 'Hushan', 'Hushan', 'Hushan,Hushan Xiang,hu shan,hu shan xiang,虎山,虎山乡', 25.0671400, 115.1093600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24400, 'Jingshi', 'Jingshi', 'Jingshi,Jingshi Xiang,jing shi,jing shi xiang,靖石,靖石乡', 25.6686300, 115.4967200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24401, 'Shuiyuan', 'Shuiyuan', 'Shuiyuan,Shuiyuan Xiang,shui yuan,shui yuan xiang,水源,水源乡', 25.1261400, 115.6376300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24402, 'Changsha', 'Changsha', 'Changsha,Changsha Xiang,zhang sha,zhang sha xiang,长沙,长沙乡', 25.4749600, 115.5227400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24403, 'Fucha', 'Fucha', 'Fucha,Fucha Xiang,fu cha,fu cha xiang,浮槎,浮槎乡', 25.5411300, 115.4321300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24404, 'Zhuangkou', 'Zhuangkou', 'Zhuangkou,Zhuangkou Zhen,zhuang kou,zhuang kou zhen,庄口,庄口镇', 25.7388700, 115.6556600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24405, 'Wenwuba', 'Wenwuba', 'Wenwuba,Wenwuba Zhen,wen wu ba,wen wu ba zhen,文武坝,文武坝镇', 25.6031700, 115.7962900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24406, 'Xingangshan', 'Xingangshan', 'Xingangshan,Xingangshan Zhen,xin gang shan,xin gang shan zhen,新岗山,新岗山镇', 29.1048600, 117.9429800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24407, 'Zheyuan', 'Zheyuan', 'Zheyuan,Zheyuan Xiang,zhe yuan,zhe yuan xiang,浙源,浙源乡', 29.4723500, 117.8657400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24408, 'Hetang', 'Hetang', 'Hetang,Hetang Xiang,he tang,he tang xiang,荷塘,荷塘乡', 29.1775300, 117.1384400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24409, 'Dongxi', 'Dongxi', 'Dongxi,Dongxi Xiang,dong xi,dong xi xiang,东溪,东溪乡', 29.1356600, 117.0126600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24410, 'Hongyan', 'Hongyan', 'Hongyan,Hongyan Zhen,hong yan,hong yan zhen,洪岩,洪岩镇', 29.0399700, 117.4629900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24411, 'Tuochuan', 'Tuochuan', 'Tuochuan,Tuochuan Xiang,tuo chuan,tuo chuan xiang,沱川,沱川乡', 29.5193200, 117.8159200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24412, 'Wanggang', 'Wanggang', 'Wanggang,Wanggang Xiang,wang gang,wang gang xiang,王港,王港乡', 29.3887500, 117.3142700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24413, 'Shuangtian', 'Shuangtian', 'Shuangtian,Shuangtian Zhen,shuang tian,shuang tian zhen,双田,双田镇', 29.0565400, 117.1557700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24414, 'Fengzhou', 'Fengzhou', 'Fengzhou,Fengzhou Xiang,feng zhou,feng zhou xiang,凤洲,凤洲乡', 29.0764300, 117.5545000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24415, 'Jingcheng', 'Jingcheng', 'Jingcheng,Jingcheng Zhen,jing cheng,jing cheng zhen,竟成,竟成镇', 29.2843700, 117.2181600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24416, 'Zhangshan', 'Zhangshan', 'Zhangshan,Zhangshan Xiang,zhang shan,zhang shan xiang,鄣山,鄣山乡', 29.4533100, 117.7283100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24417, 'Hecheng', 'Hecheng', 'Hecheng,Hecheng Xiang,he cheng,he cheng xiang,鹤城,鹤城乡', 29.6573800, 117.7186500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24418, 'Qiaoshan', 'Qiaoshan', 'Qiaoshan,Qiaoshan Xiang,qiao shan,qiao shan xiang,乔山,乔山乡', 29.7639900, 117.7192700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24419, 'Henglian', 'Henglian', 'Henglian,Henglian Xiang,heng lian,heng lian xiang,横联,横联乡', 29.8489600, 117.8722000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24420, 'Dengta', 'Dengta', 'Dengta,Dengta Xiang,deng ta,deng ta xiang,灯塔,灯塔乡', 29.8691000, 117.6655600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24421, 'Yandian', 'Yandian', 'Yandian,Yandian Zhen,yan dian,yan dian zhen,烟店,烟店镇', 31.3351700, 113.5665200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24422, 'Huaxi', 'Huaxi', 'Huaxi,Huaxi Xiang,hua xi,hua xi xiang,花西,花西乡', 31.1992300, 113.8595000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24423, 'Fengjiang', 'Fengjiang', 'Fengjiang,Fengjiang Xiang,feng jiang,feng jiang xiang,封江,封江乡', 31.9737200, 113.3376400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24424, 'Taiping', 'Taiping', 'Taiping,Taiping Xiang,tai ping,tai ping xiang,太平,太平乡', 31.4552000, 113.9208900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24425, 'Qingminghe', 'Qingminghe', 'Qingminghe,Qingminghe Xiang,qing ming he,qing ming he xiang,清明河,清明河乡', 31.0353700, 113.6891700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24426, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Jiedaobanshichu,nan cheng,nan cheng jie dao ban shi chu,南城,南城街道办事处', 31.2079900, 113.6969200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24427, 'Wupu', 'Wupu', 'Wupu,Wupu Zhen,wu pu,wu pu zhen,吴铺,吴铺镇', 31.0395600, 113.8007600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24428, 'Xinzha', 'Xinzha', 'Xinzha,Xinzha Xiang,xin zha,xin zha xiang,辛榨,辛榨乡', 31.1166600, 113.6293500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24429, 'Nanjiao', 'Nanjiao', 'Nanjiao,Nanjiao Jiedaobanshichu,nan jiao,nan jiao jie dao ban shi chu,南郊,南郊街道办事处', 31.7132600, 113.3496000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24430, 'Beifan', 'Beifan', 'Beifan,Beifan Zhen,bei fan,bei fan zhen,孛畈,孛畈镇', 31.3837800, 113.5228500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24431, 'Dougang', 'Dougang', 'Dougang,Dougang Zhen,dou gang,dou gang zhen,陡岗,陡岗镇', 31.0402500, 113.8509400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24432, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 31.8185400, 113.2117600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24433, 'Fuhe', 'Fuhe', 'Fuhe,Fuhe Zhen,fu he,fu he zhen,府河,府河镇', 31.5095900, 113.5664500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24434, 'Dayanpo', 'Dayanpo', 'Dayanpo,Dayanpo Xiang,da yan po,da yan po xiang,大堰坡,大堰坡乡', 31.6089000, 113.4375000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24435, 'Xihe', 'Xihe', 'Xihe,Xihe Zhen,xi he,xi he zhen,西河,西河镇', 31.0084300, 114.0096000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24436, 'Lülin', 'Lulin', 'Lulin,Lulin Zhen,Lülin,Lülin Zhen,lu lin,lu lin zhen,绿林,绿林镇', 31.3135400, 113.0767600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24437, 'Doushan', 'Doushan', 'Doushan,Doushan Xiang,dou shan,dou shan xiang,陡山,陡山乡', 31.2024700, 114.0030500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24438, 'Daodian', 'Daodian', 'Daodian,Daodian Xiang,dao dian,dao dian xiang,倒店,倒店乡', 31.1849000, 113.7262500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24439, 'Baimiao', 'Baimiao', 'Baimiao,Baimiao Jiedao,bai miao,bai miao jie dao,白庙,白庙街道', 31.0348500, 112.2211500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24440, 'Wenji', 'Wenji', 'Wenji,Wenji Zhen,wen ji,wen ji zhen,文集,文集镇', 31.1587500, 112.5286700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24441, 'Zhengji', 'Zhengji', 'Zhengji,Zhengji Zhen,zheng ji,zheng ji zhen,郑集,郑集镇', 31.6481200, 112.3010000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24442, 'Xingqiao', 'Xingqiao', 'Xingqiao,Xingqiao Zhen,xing qiao,xing qiao zhen,兴桥,兴桥镇', 27.1401700, 114.8742600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24443, 'Lucun', 'Lucun', 'Lucun,Lucun Xiang,lu cun,lu cun xiang,芦村,芦村乡', 27.9275100, 114.4554100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24444, 'Chigu', 'Chigu', 'Chigu,Chigu Xiang,chi gu,chi gu xiang,赤谷,赤谷乡', 27.5497600, 114.6526600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24445, 'Shangxian', 'Shangxian', 'Shangxian,Shangxian Xiang,shang xian,shang xian xiang,尚贤,尚贤乡', 27.3606400, 114.9610000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24446, 'Hushang', 'Hushang', 'Hushang,Hushang Xiang,hu shang,hu shang xiang,湖上,湖上乡', 27.2650700, 114.0484800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24447, 'Chuntai', 'Chuntai', 'Chuntai,Chuntai Xiang,chun tai,chun tai xiang,春台,春台乡', 27.8022700, 114.3834100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24448, 'Dagangshan', 'Dagangshan', 'Dagangshan,Dagangshan Xiang,da gang shan,da gang shan xiang,大岗山,大岗山乡', 27.6556000, 114.5881400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24449, 'Tailing', 'Tailing', 'Tailing,Tailing Xiang,tai ling,tai ling xiang,台岭,台岭乡', 27.0686500, 114.1112400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24450, 'Yuannan', 'Yuannan', 'Yuannan,Yuannan Xiang,yuan nan,yuan nan xiang,源南,源南乡', 27.6709300, 114.0315000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24451, 'Denglong', 'Denglong', 'Denglong,Denglong Xiang,deng long,deng long xiang,登龙,登龙乡', 27.0122100, 114.7509600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24452, 'Ouli', 'Ouli', 'Ouli,Ouli Zhen,ou li,ou li zhen,欧里,欧里镇', 27.9266000, 114.8335200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24453, 'Jinjiang', 'Jinjiang', 'Jinjiang,Jinjiang Xiang,jin jiang,jin jiang xiang,金江,金江乡', 27.5855700, 114.9855000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24454, 'Yuanzhou', 'Yuanzhou', 'Yuanzhou,Yuanzhou Qu,yuan zhou,yuan zhou qu,袁州,袁州区', 27.7984600, 114.3760800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24455, 'Huze', 'Huze', 'Huze,Huze Zhen,hu ze,hu ze zhen,湖泽,湖泽镇', 27.8656400, 114.7507400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24456, 'Tiantai', 'Tiantai', 'Tiantai,Tiantai Zhen,tian tai,tian tai zhen,天台,天台镇', 27.8297600, 114.0194700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24457, 'Hebu', 'Hebu', 'Hebu,Hebu Xiang,he bu,he bu xiang,禾埠,禾埠乡', 27.1013800, 114.9669600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24458, 'Shanshi', 'Shanshi', 'Shanshi,Shanshi Xiang,shan shi,shan shi xiang,闪石,闪石乡', 27.2904000, 114.0571700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24459, 'Gaoqiaolou', 'Gaoqiaolou', 'Gaoqiaolou,Gaoqiaolou Zhen,gao qiao lou,gao qiao lou zhen,高桥楼,高桥楼镇', 27.0196900, 114.3650600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24460, 'Matian', 'Matian', 'Matian,Matian Xiang,ma tian,ma tian xiang,麻田,麻田乡', 27.4986800, 114.1017100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24461, 'Longmen', 'Longmen', 'Longmen,Longmen Zhen,long men,long men zhen,龙门,龙门镇', 27.0902700, 114.1430700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24462, 'Huayun', 'Huayun', 'Huayun,Huayun Xiang,hua yun,hua yun xiang,华云,华云乡', 27.5760600, 114.1350200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24463, 'Yinhe', 'Yinhe', 'Yinhe,Yinhe Zhen,yin he,yin he zhen,银河,银河镇', 27.6998800, 114.1177700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24464, 'Xiangxing', 'Xiangxing', 'Xiangxing,Xiangxing Xiang,xiang xing,xiang xing xiang,象形,象形乡', 27.1299400, 114.2258700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24465, 'Zhangjiafang', 'Zhangjiafang', 'Zhangjiafang,Zhangjiafang Xiang,zhang jia fang,zhang jia fang xiang,张佳坊,张佳坊乡', 27.5151600, 114.0093100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24466, 'Lianzhou', 'Lianzhou', 'Lianzhou,Lianzhou Xiang,lian zhou,lian zhou xiang,莲洲,莲洲乡', 27.0457300, 114.2575400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24467, 'Dachong', 'Dachong', 'Dachong,Dachong Xiang,da chong,da chong xiang,大冲,大冲乡', 27.3345800, 114.8465100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24468, 'Henglong', 'Henglong', 'Henglong,Henglong Zhen,heng long,heng long zhen,横龙,横龙镇', 27.3912700, 114.5510600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24469, 'Guashe', 'Guashe', 'Guashe,Guashe Xiang,gua she,gua she xiang,瓜畲,瓜畲乡', 27.4127400, 114.7201900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24470, 'Longtian', 'Longtian', 'Longtian,Longtian Xiang,long tian,long tian xiang,龙田,龙田乡', 27.0200100, 114.0306700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24471, 'Nanmu', 'Nanmu', 'Nanmu,Nanmu Xiang,nan mu,nan mu xiang,楠木,楠木乡', 27.9878000, 114.1662800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24472, 'Yuankeng', 'Yuankeng', 'Yuankeng,Yuankeng Xiang,yuan keng,yuan keng xiang,苑坑,苑坑乡', 27.6488700, 114.7274600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24473, 'Jiulongshan', 'Jiulongshan', 'Jiulongshan,Jiulongshan Xiang,jiu long shan,jiu long shan xiang,九龙山,九龙山乡', 27.6452100, 114.8394100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24474, 'Liaotang', 'Liaotang', 'Liaotang,Liaotang Xiang,liao tang,liao tang xiang,寮塘,寮塘乡', 27.2752200, 114.5931900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24475, 'Antang', 'Antang', 'Antang,Antang Xiang,an tang,an tang xiang,安塘,安塘乡', 27.0012600, 114.6809500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24476, 'Taishan', 'Taishan', 'Taishan,Taishan Xiang,tai shan,tai shan xiang,泰山,泰山乡', 27.4435900, 114.2696100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24477, 'Gaoshi', 'Gaoshi', 'Gaoshi,Gaoshi Xiang,gao shi,gao shi xiang,高市,高市乡', 27.0332800, 114.2035400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24478, 'Tiantaishan', 'Tiantaishan', 'Tiantaishan,Tiantaishan Xiang,tian tai shan,tian tai shan xiang,天台山,天台山乡', 27.8853400, 114.0008300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24479, 'Wanlongshan', 'Wanlongshan', 'Wanlongshan,Wanlongshan Xiang,wan long shan,wan long shan xiang,万龙山,万龙山乡', 27.6014200, 114.1679400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24480, 'Wojiang', 'Wojiang', 'Wojiang,Wojiang Xiang,wo jiang,wo jiang xiang,渥江,渥江乡', 27.8405700, 114.4369400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24481, 'Zhushan', 'Zhushan', 'Zhushan,Zhushan Zhen,zhu shan,zhu shan zhen,珠珊,珠珊镇', 27.7774800, 114.9426300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24482, 'Hutian', 'Hutian', 'Hutian,Hutian Xiang,hu tian,hu tian xiang,湖田,湖田乡', 27.8227600, 114.3471200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24483, 'Xinquan', 'Xinquan', 'Xinquan,Xinquan Xiang,xin quan,xin quan xiang,新泉,新泉乡', 27.5217300, 114.0692700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24484, 'Yangmen', 'Yangmen', 'Yangmen,Yangmen Xiang,yang men,yang men xiang,洋门,洋门乡', 27.1354700, 114.3971000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24485, 'Pengfang', 'Pengfang', 'Pengfang,Pengfang Xiang,peng fang,peng fang xiang,彭坊,彭坊乡', 27.2338600, 114.3168100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24486, 'Ganluo', 'Ganluo', 'Ganluo,Ganluo Xiang,gan luo,gan luo xiang,甘洛,甘洛乡', 27.2084700, 114.5861500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24487, 'Xiaoying', 'Xiaoying', 'Xiaoying,Xiaoying Zhen,xiao ying,xiao ying zhen,小营,小营镇', 42.9120600, 129.5206600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24488, 'Yingcheng', 'Yingcheng', 'Yingcheng,Yingcheng Zhen,ying cheng,ying cheng zhen,郢城,郢城镇', 30.3685900, 112.1994400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24489, 'Gaoshibei', 'Gaoshibei', 'Gaoshibei,Gaoshibei Zhen,gao shi bei,gao shi bei zhen,高石碑,高石碑镇', 30.5516400, 112.6690700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24490, 'Yangshi', 'Yangshi', 'Yangshi,Yangshi Jiedao,yang shi,yang shi jie dao,杨市,杨市街道', 30.3697800, 112.8999800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24491, 'Yanmenkou', 'Yanmenkou', 'Yanmenkou,Yanmenkou Zhen,yan men kou,yan men kou zhen,雁门口,雁门口镇', 30.8347300, 112.9746900, 'CN', '2013-04-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24492, 'Huangxiekou', 'Huangxiekou', 'Huangxiekou,Huangxiekou Zhen,huang xie kou,huang xie kou zhen,黄歇口,黄歇口镇', 30.0329900, 112.8525600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24493, 'Jiyukou', 'Jiyukou', 'Jiyukou,Jiyukou Zhen,ji yu kou,ji yu kou zhen,积玉口,积玉口镇', 30.4553400, 112.5902500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24494, 'Luochang', 'Luochang', 'Luochang,Luochang Zhen,luo chang,luo chang zhen,锣场,锣场镇', 30.3597000, 112.3347100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24495, 'Zhouji', 'Zhouji', 'Zhouji,Zhouji Jiedao,zhou ji,zhou ji jie dao,周矶,周矶街道', 30.4121000, 112.7807200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24496, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 30.3510400, 112.1882400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24497, 'Wangchang', 'Wangchang', 'Wangchang,Wangchang Zhen,wang chang,wang chang zhen,王场,王场镇', 30.5084000, 112.7675500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24498, 'Zhoulaozui', 'Zhoulaozui', 'Zhoulaozui,Zhoulaozui Zhen,zhou lao ju,zhou lao ju zhen,周老咀,周老咀镇', 30.0338500, 112.9804300, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24499, 'Jiangchang', 'Jiangchang', 'Jiangchang,Jiangchang Zhen,jiang chang,jiang chang zhen,蒋场,蒋场镇', 30.6092800, 112.9336600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24500, 'Gaoyang', 'Gaoyang', 'Gaoyang,Gaoyang Zhen,gao yang,gao yang zhen,高阳,高阳镇', 30.7661400, 112.5124500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24501, 'Jishan', 'Jishan', 'Jishan,Jishan Zhen,ji shan,ji shan zhen,纪山,纪山镇', 30.5393200, 112.1769900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24502, 'Guanghua', 'Guanghua', 'Guanghua,Guanghua Jiedao,guang hua,guang hua jie dao,广华,广华街道', 30.4437800, 112.6844600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24503, 'Jinan', 'Jinan', 'Jinan,Jinan Zhen,ji nan,ji nan zhen,纪南,纪南镇', 30.4473800, 112.2003100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24504, 'Lishi', 'Lishi', 'Lishi,Lishi Zhen,li shi,li shi zhen,李市,李市镇', 30.5894600, 112.5677400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24505, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Jiedao,xi cheng,xi cheng jie dao,西城,西城街道', 30.3590400, 112.1802600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24506, 'Zhanghe', 'Zhanghe', 'Zhanghe,Zhanghe Zhen,zhang he,zhang he zhen,漳河,漳河镇', 30.9569800, 112.0707600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24507, 'Tuoshi', 'Tuoshi', 'Tuoshi,Tuoshi Zhen,tuo shi,tuo shi zhen,拖市,拖市镇', 30.7278800, 112.8269700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24508, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,cheng nan,cheng nan jie dao,城南,城南街道', 30.3483500, 112.1764900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24509, 'Zhugentan', 'Zhugentan', 'Zhugentan,Zhugentan Zhen,zhu gen tan,zhu gen tan zhen,竹根滩,竹根滩镇', 30.4977600, 112.9023700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24510, 'Bengkouling', 'Bengkouling', 'Bengkouling,Lucun,beng kou ling,lu cun,卢村,崩口岭', 30.8198400, 119.4228500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24511, 'Liudong', 'Liudong', 'Liudong,Liudong Zhen,liu dong,liu dong zhen,流洞,流洞镇', 31.0314500, 119.5187200, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24512, 'Feili', 'Feili', 'Feili,Feili Xiang,fei li,fei li xiang,飞鲤,飞鲤乡', 31.0713000, 119.0920700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24513, 'Yalukou', 'Yalukou', 'Fancun,Yalukou,fan cun,ya lu kou,哑路口,畈村', 30.6615500, 119.0147600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24514, 'Yutiao', 'Yutiao', 'Yutiao,yu tiao,鱼跳', 30.2897100, 119.0220400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24515, 'Zhoupu', 'Zhoupu', 'Zhoupu,Zhoupu Xiang,zhou pu,zhou pu xiang,周浦,周浦乡', 30.0925400, 120.0663300, 'CN', '2011-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24516, 'Dongqiao', 'Dongqiao', 'Dongqiao,Dongqiao Zhen,dong qiao,dong qiao zhen,洞桥,洞桥镇', 30.0760500, 119.5830800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24517, 'Gaohong', 'Gaohong', 'Gaohong,gao hong,高虹', 30.3203500, 119.7214600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24518, 'Xitianmu', 'Xitianmu', 'Xitianmu,Xitianmu Xiang,xi tian mu,xi tian mu xiang,西天目,西天目乡', 30.2657700, 119.4722300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24519, 'Zhongtai', 'Zhongtai', 'Zhongtai,Zhongtai Xiang,zhong tai,zhong tai xiang,中泰,中泰乡', 30.2409400, 119.9269500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24520, 'Chunjian', 'Chunjian', 'Chunjian,Chunjian Xiang,chun jian,chun jian xiang,春建,春建乡', 30.0763900, 119.8265300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24521, 'Kuntong', 'Kuntong', 'Kuntong,Kuntong Xiang,kun tong,kun tong xiang,昆铜,昆铜乡', 30.7613600, 119.7884700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24522, 'Jiangcun', 'Jiangcun', 'Jiangcun,Jiangcun Xiang,jiang cun,jiang cun xiang,蒋村,蒋村乡', 30.2856700, 120.0647100, 'CN', '2011-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24523, 'Chengguan', 'Chengguan', 'Chengguan,Chengguan Zhen,cheng guan,cheng guan zhen,城关,城关镇', 30.5481600, 120.0798000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24524, 'Baique', 'Baique', 'Baique,bai que,白雀', 30.9207100, 120.0979500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24525, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Xiang,san he,san he xiang,三合,三合乡', 30.4795800, 120.0327900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24526, 'Yushan', 'Yushan', 'Yushan,Yushan Xiang,yu shan,yu shan xiang,渔山,渔山乡', 30.0658600, 120.0876700, 'CN', '2011-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24527, 'Qianhong', 'Qianhong', 'Qianhong,Qianhong Xiang,qian hong,qian hong xiang,千洪,千洪乡', 30.2606500, 119.3961600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24528, 'Lishan', 'Lishan', 'Lishan,Lishan Zhen,li shan,li shan zhen,里山,里山镇', 30.0503300, 120.0620600, 'CN', '2011-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24529, 'Maxiao', 'Maxiao', 'Maxiao,ma xiao,马啸', 30.1484600, 118.9633000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24530, 'Yaoshan', 'Yaoshan', 'Yaoshan,Yaoshan Xiang,yao shan,yao shan xiang,瑶山,瑶山乡', 29.9644400, 119.0665300, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24531, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Xiang,shui kou,shui kou xiang,水口,水口乡', 31.0982700, 119.8646000, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24532, 'Daochang', 'Daochang', 'Daochang,dao chang,道场', 30.8484900, 120.0926200, 'CN', '2011-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24533, 'Yihe', 'Yihe', 'Yihe,yi he,怡合', 29.9600900, 119.3547100, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24534, 'Erjieling', 'Erjieling', 'Erjieling,Erjieling Xiang,er jie ling,er jie ling xiang,二界岭,二界岭乡', 30.9482900, 119.6136100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24535, 'Shanggan', 'Shanggan', 'Shanggan,Shanggan Jiedao,Shanggan Xiang,shang gan,shang gan jie dao,shang gan xiang,上甘,上甘乡,上甘街道', 30.1730600, 119.7113500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24536, 'Qingliangfeng', 'Qingliangfeng', 'Qingliangfeng,qing liang feng,清凉峰', 30.1393300, 119.0283100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24537, 'Qianchuan', 'Qianchuan', 'Qianchuan,qian chuan,潜川', 30.0911400, 119.3902700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24538, 'Jinzhu', 'Jinzhu', 'Jinzhu,Jinzhu Xiang,jin zhu,jin zhu xiang,金竹,金竹乡', 27.0220700, 115.8914900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24539, 'Tielu', 'Tielu', 'Tielu,Tielu Zhen,tie lu,tie lu zhen,铁路,铁路镇', 27.8722900, 115.7881100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24540, 'Zhongzhou', 'Zhongzhou', 'Zhongzhou,Zhongzhou Xiang,zhong zhou,zhong zhou xiang,中洲,中洲乡', 27.9292300, 115.1563100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24541, 'Shenzhengqiao', 'Shenzhengqiao', 'Shenzhengqiao,Shenzhengqiao Xiang,shen zheng qiao,shen zheng qiao xiang,神政桥,神政桥乡', 27.7102200, 115.4630300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24542, 'Nan’an', 'Nan''an', 'Nan''an,Nan''an Xiang,Nan’an,Nan’an Xiang,nan an,nan an xiang,南安,南安乡', 27.8131500, 115.2285900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24543, 'Shuitian', 'Shuitian', 'Shuitian,Shuitian Xiang,shui tian,shui tian xiang,水田,水田乡', 27.4220700, 115.1476400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24544, 'Yijiang', 'Yijiang', 'Yijiang,Yijiang Xiang,yi jiang,yi jiang xiang,沂江,沂江乡', 27.7017800, 115.3539100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24545, 'Dongbian', 'Dongbian', 'Dongbian,Dongbian Xiang,dong bian,dong bian xiang,东边,东边乡', 27.7772200, 115.1262500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24546, 'Pangu', 'Pangu', 'Pangu,Pangu Zhen,pan gu,pan gu zhen,盘谷,盘谷镇', 27.4321200, 115.0069000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24547, 'Xinxi', 'Xinxi', 'Xinxi,Xinxi Xiang,xin xi,xin xi xiang,新溪,新溪乡', 27.8687000, 115.3266600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24548, 'Yicheng', 'Yicheng', 'Yicheng,Yicheng Zhen,yi cheng,yi cheng zhen,义成,义成镇', 27.9854300, 115.1743900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24549, 'Tianyu', 'Tianyu', 'Tianyu,Tianyu Zhen,tian yu,tian yu zhen,天玉,天玉镇', 27.1408000, 115.0533700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24550, 'Zhangfang', 'Zhangfang', 'Zhangfang,Zhangfang Xiang,zhang fang,zhang fang xiang,张坊,张坊乡', 27.6205800, 115.9779900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24551, 'Licun', 'Licun', 'Licun,Licun Zhen,li cun,li cun zhen,丽村,丽村镇', 27.9950400, 115.6989800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24552, 'Changfu', 'Changfu', 'Changfu,Changfu Zhen,chang fu,chang fu zhen,昌傅,昌傅镇', 27.9200300, 115.3064600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24553, 'Fumin', 'Fumin', 'Fumin,Fumin Xiang,fu min,fu min xiang,福民,福民乡', 27.5729700, 115.2112300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24554, 'Xiwang', 'Xiwang', 'Xiwang,Xiwang Xiang,xi wang,xi wang xiang,希望,希望乡', 27.8937900, 115.7033200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24555, 'Taotang', 'Taotang', 'Taotang,Taotang Xiang,tao tang,tao tang xiang,陶唐,陶唐乡', 27.0678700, 115.6916400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24556, 'Xintong', 'Xintong', 'Xintong,xin tong,新桐', 29.9066400, 119.8147400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24557, 'Chunjing', 'Chunjing', 'Chunjiang Jiedao,Chunjing,chun jiang,chun jiang jie dao,春江,春江街道', 30.0332800, 119.9640500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24558, 'Dongzhou', 'Dongzhou', 'Dongzhou,Dongzhou Jiedao,dong zhou,dong zhou jie dao,东洲,东洲街道', 30.0783000, 119.9847800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24559, 'Lushan', 'Lushan', 'Lushan,Lushan Jiedao,lu shan,lu shan jie dao,鹿山,鹿山街道', 30.0089900, 119.9038100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24560, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,da qiao,da qiao zhen,大桥,大桥镇', 28.9599400, 114.1087200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24561, 'Luzhou', 'Luzhou', 'Luzhou,Luzhou Xiang,lu zhou,lu zhou xiang,芦洲,芦洲乡', 28.2069700, 114.8378900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24562, 'Shangfeng', 'Shangfeng', 'Shangfeng,Shangfeng Zhen,shang feng,shang feng zhen,上奉,上奉镇', 28.7386300, 114.6770600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24563, 'Luocheng', 'Luocheng', 'Luocheng,Luocheng Zhen,luo cheng,luo cheng zhen,罗城,罗城镇', 28.2870300, 114.5536600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24564, 'Shishi', 'Shishi', 'Shishi,Shishi Zhen,shi shi,shi shi zhen,石市,石市镇', 28.2591400, 114.7713400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24565, 'Shangganshan', 'Shangganshan', 'Shangganshan,Shangganshan Xiang,shang gan shan,shang gan shan xiang,上甘山,上甘山乡', 28.2070700, 114.9696800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24566, 'Yuduan', 'Yuduan', 'Yuduan,Yuduan Xiang,yu duan,yu duan xiang,余塅,余塅乡', 28.8540400, 114.0691100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24567, 'Zhendu', 'Zhendu', 'Zhendu,Zhendu Xiang,zhen du,zhen du xiang,镇渡,镇渡乡', 28.2034800, 114.5996400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24568, 'Shangshan', 'Shangshan', 'Shangshan,Shangshan Xiang,shang shan,shang shan xiang,上衫,上衫乡', 28.9505100, 114.1591300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24569, 'Aoqiao', 'Aoqiao', 'Aoqiao,Aoqiao Xiang,ao qiao,ao qiao xiang,敖桥,敖桥乡', 28.3996800, 114.8041500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24570, 'Cheshang', 'Cheshang', 'Cheshang,Cheshang Xiang,che shang,che shang xiang,车上,车上乡', 28.4263700, 114.5544600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24571, 'Zaoxi', 'Zaoxi', 'Zaoxi,Zaoxi Xiang,zao xi,zao xi xiang,澡溪,澡溪乡', 28.7515800, 114.9614300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24572, 'Shixi', 'Shixi', 'Shixi,Shixi Xiang,shi xi,shi xi xiang,石溪,石溪乡', 28.7400200, 114.9095800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24573, 'Renhe', 'Renhe', 'Renhe,Renhe Xiang,ren he,ren he xiang,人和,人和乡', 28.0251100, 114.9381800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24574, 'Fuyuan', 'Fuyuan', 'Fuyuan,Fuyuan Xiang,fu yuan,fu yuan xiang,复原,复原乡', 28.7384700, 114.3261900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24575, 'Shuiyuan', 'Shuiyuan', 'Shuiyuan,Shuiyuan Xiang,shui yuan,shui yuan xiang,水源,水源乡', 28.9985300, 114.0346600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24576, 'Zhaixia', 'Zhaixia', 'Zhaixia,Zhaixia Xiang,zhai xia,zhai xia xiang,寨下,寨下乡', 28.0107100, 114.4964900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24577, 'Efeng', 'Efeng', 'Efeng,Efeng Xiang,e feng,e feng xiang,鹅峰,鹅峰乡', 28.1117500, 114.4524000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24578, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Xiang,gao qiao,gao qiao xiang,高桥,高桥乡', 28.6075600, 114.2072800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24579, 'Shuangqiao', 'Shuangqiao', 'Shuangqiao,Shuangqiao Zhen,shuang qiao,shuang qiao zhen,双桥,双桥镇', 28.1834800, 114.3121700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24580, 'Baimu', 'Baimu', 'Baimu,Baimu Xiang,bai mu,bai mu xiang,柏木,柏木乡', 28.0012800, 114.4320900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24581, 'Lingdong', 'Lingdong', 'Lingdong,Lingdong Xiang,ling dong,ling dong xiang,岭东,岭东乡', 28.0648900, 114.2420900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24582, 'Chengfang', 'Chengfang', 'Chengfang,Chengfang Xiang,cheng fang,cheng fang xiang,程坊,程坊乡', 28.9770400, 114.3484900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24583, 'Wenquan', 'Wenquan', 'Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 28.5374600, 114.3488100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24584, 'Dongcun', 'Dongcun', 'Dongcun,Dongcun Xiang,dong cun,dong cun xiang,洞村,洞村乡', 28.0144800, 114.8148500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24585, 'Zhongyuan', 'Zhongyuan', 'Zhongyuan,Zhongyuan Xiang,zhong yuan,zhong yuan xiang,中源,中源乡', 28.8624800, 114.9843800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24586, 'Jinjiang', 'Jinjiang', 'Jinjiang,Jinjiang Zhen,jin jiang,jin jiang zhen,锦江,锦江镇', 28.2327200, 114.9007800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24587, 'Jiaohu', 'Jiaohu', 'Jiaohu,Jiaohu Xiang,jiao hu,jiao hu xiang,茭湖,茭湖乡', 28.2580300, 114.3832900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24588, 'Aoshan', 'Aoshan', 'Aoshan,Aoshan Xiang,ao shan,ao shan xiang,敖山,敖山乡', 28.2617400, 114.9786400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24589, 'Qiaoxi', 'Qiaoxi', 'Qiaoxi,Qiaoxi Xiang,qiao xi,qiao xi xiang,桥西,桥西乡', 28.3881400, 114.7695700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24590, 'Chixing', 'Chixing', 'Chixing,Chixing Xiang,chi xing,chi xing xiang,赤兴,赤兴乡', 28.2101300, 114.2383100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24591, 'Shihuajian', 'Shihuajian', 'Shihuajian,Shihuajian Xiang,shi hua jian,shi hua jian xiang,石花尖,石花尖乡', 28.4764600, 114.5416800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24592, 'Taxia', 'Taxia', 'Taxia,Taxia Xiang,ta xia,ta xia xiang,塔下,塔下乡', 28.2204200, 114.9508300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24593, 'Daixi', 'Daixi', 'Daixi,Daixi Xiang,dai xi,dai xi xiang,带溪,带溪乡', 28.6742800, 114.6263300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24594, 'Fengdingshan', 'Fengdingshan', 'Fengdingshan,Fengdingshan Xiang,feng ding shan,feng ding shan xiang,丰顶山,丰顶山乡', 28.0109700, 114.2837800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24595, 'Mabu', 'Mabu', 'Mabu,Mabu Xiang,ma bu,ma bu xiang,马步,马步乡', 28.1003700, 114.4376000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24596, 'Yeshi', 'Yeshi', 'Yeshi,Yeshi Xiang,ye shi,ye shi xiang,野市,野市乡', 28.3092300, 114.9336900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24597, 'Nangang', 'Nangang', 'Nangang,Nangang Zhen,nan gang,nan gang zhen,南港,南港镇', 28.0900100, 114.8423500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24598, 'Liutou', 'Liutou', 'Liutou,Liutou Xiang,liu tou,liu tou xiang,溜头,溜头乡', 28.6809800, 114.8728500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24599, 'Bailiang', 'Bailiang', 'Bailiang,Bailiang Xiang,bai liang,bai liang xiang,白良,白良乡', 28.2009500, 114.4117900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24600, 'Tianbao', 'Tianbao', 'Tianbao,Tianbao Xiang,tian bao,tian bao xiang,天宝,天宝乡', 28.5300800, 114.7611300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24601, 'Nanqiao', 'Nanqiao', 'Nanqiao,Nanqiao Xiang,nan qiao,nan qiao xiang,南桥,南桥乡', 28.7376800, 114.0715300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24602, 'Gaobazhou', 'Gaobazhou', 'Gaobazhou,Gaobazhou Zhen,gao ba zhou,gao ba zhou zhen,高坝洲,高坝洲镇', 30.4378400, 111.4182300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24603, 'Qixingtai', 'Qixingtai', 'Qixingtai,Qixingtai Zhen,qi xing tai,qi xing tai zhen,七星台,七星台镇', 30.4135500, 111.8873900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24604, 'Xiannü', 'Xiannu', 'Xiannu,Xiannu Zhen,Xiannü,Xiannü Zhen,xian nu,xian nu zhen,仙女,仙女镇', 30.5269300, 111.7399200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24605, 'Nanhai', 'Nanhai', 'Nanhai,Nanhai Zhen,nan hai,nan hai zhen,南海,南海镇', 30.1281900, 111.7783700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24606, 'Miaoqian', 'Miaoqian', 'Miaoqian,Miaoqian Zhen,miao qian,miao qian zhen,庙前,庙前镇', 30.8918200, 111.8711800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24607, 'Lianpeng', 'Lianpeng', 'Lianpeng,Lianpeng Xiang,lian peng,lian peng xiang,联棚,联棚乡', 30.6551900, 111.2688200, 'CN', '2012-02-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24608, 'Hualinsi', 'Hualinsi', 'Hualinsi,Hualinsi Zhen,hua lin si,hua lin si zhen,花林寺,花林寺镇', 31.0038300, 111.6099100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24609, 'Huya', 'Huya', 'Huya,Huya Jiedao,hu ya,hu ya jie dao,虎牙,虎牙街道', 30.5708800, 111.3954300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24610, 'Baling', 'Baling', 'Baling,Baling Jiedao,ba ling,ba ling jie dao,坝陵,坝陵街道', 30.8429700, 111.7925300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24611, 'Yuquan', 'Yuquan', 'Yuquan,Yuquan Jiedao,yu quan,yu quan jie dao,玉泉,玉泉街道', 30.8296900, 111.7742300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24612, 'Hengjingqiao', 'Hengjingqiao', 'Hengjingqiao,Honghe,Honghe Zhen,heng jing qiao,hong he,hong he zhen,横泾桥,洪合,洪合镇', 30.6827800, 120.6586500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24613, 'Heshan', 'Heshan', 'Heshan,Heshan Zhen,he shan,he shan zhen,河山,河山镇', 30.6353000, 120.3561300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24614, 'Xin’an', 'Xin''an', 'Gouli Zhen,Xin''an,Xin''an Zhen,Xin’an,Xin’an Zhen,gou li zhen,xin an,xin an zhen,勾里镇,新安,新安镇', 30.5337300, 120.2190400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24615, 'Chongxian', 'Chongxian', 'Chongxian,Chongxian Zhen,chong xian,chong xian zhen,崇贤,崇贤镇', 30.3882900, 120.1711700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24616, 'Gudang', 'Gudang', 'Gudang,Gudang Jiedao,Gudang Zhen,gu dang,gu dang jie dao,gu dang zhen,古荡,古荡街道,古荡镇', 30.2784000, 120.1184200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24617, 'Huangjiabu', 'Huangjiabu', 'Huangjiabu,Huangjiabu Zhen,huang jia bu,huang jia bu zhen,黄家埠,黄家埠镇', 30.1435900, 120.9556600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24618, 'Huashe', 'Huashe', 'Huashe,Huashe Jiedao,Huashe Zhen,hua she,hua she jie dao,hua she zhen,华舍,华舍街道,华舍镇', 30.1127600, 120.4822800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24619, 'Xialu', 'Xialu', 'Xialu,Xialu Zhen,xia lu,xia lu zhen,夏履,夏履镇', 30.0659000, 120.3557900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24620, 'Jinhua', 'Jinhua', 'Jinhua,Jinhua Zhen,jin hua,jin hua zhen,进化,进化镇', 30.0134700, 120.2886600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24621, 'Balidian', 'Balidian', 'Balidian,Balidian Zhen,ba li dian,ba li dian zhen,八里店,八里店镇', 30.8428300, 120.1528800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24622, 'Hezhuang', 'Hezhuang', 'Hezhuang,Hezhuang Zhen,he zhuang,he zhuang zhen,河庄,河庄镇', 30.3001500, 120.4610700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24623, 'Jiabei', 'Jiabei', 'Jiabei,Jiabei Jiedao,Jiabei Xiang,jia bei,jia bei jie dao,jia bei xiang,嘉北,嘉北乡,嘉北街道', 30.7795900, 120.7117700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24624, 'Xingqiao', 'Xingqiao', 'Xingqiao,Xingqiao Jiedao,Xingqiao Zhen,xing qiao,xing qiao jie dao,xing qiao zhen,星桥,星桥街道,星桥镇', 30.3994300, 120.2517100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24625, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 30.2626800, 120.4425700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24626, 'Yinong', 'Yinong', 'Yinong,Yinong Zhen,yi nong,yi nong zhen,益农,益农镇', 30.1968200, 120.5857600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24627, 'Daoxu', 'Daoxu', 'Daoxu,Daoxu Zhen,dao xu,dao xu zhen,道墟,道墟镇', 30.0460900, 120.7676200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24628, 'Tongfu', 'Tongfu', 'Tongfu,Tongfu Xiang,tong fu,tong fu xiang,同福,同福乡', 30.5763700, 120.4648300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24629, 'Xiaohe', 'Xiaohe', 'Xiaohe,Xiaohe Jiedao,xiao he,xiao he jie dao,小河,小河街道', 30.3099700, 120.1350500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24630, 'Jiubao', 'Jiubao', 'Jiubao,Jiubao Zhen,jiu bao,jiu bao zhen,九堡,九堡镇', 30.3192300, 120.2656200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24631, 'Puyan', 'Puyan', 'Puyan,Puyan Jiedao,Puyan Zhen,pu yan,pu yan jie dao,pu yan zhen,浦沿,浦沿街道,浦沿镇', 30.1573000, 120.1466600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24632, 'Ningwei', 'Ningwei', 'Ningwei,Ningwei Zhen,ning wei,ning wei zhen,宁围,宁围镇', 30.2151900, 120.2765200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24633, 'Hutang', 'Hutang', 'Hutang,Hutang Jiedao,Hutang Zhen,hu tang,hu tang jie dao,hu tang zhen,湖塘,湖塘街道,湖塘镇', 30.0748900, 120.4210300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24634, 'Longquan', 'Longquan', 'Longquan,Longquan Jiedao,long quan,long quan jie dao,龙泉,龙泉街道', 30.8692000, 120.1038600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24635, 'Huimin', 'Huimin', 'Huimin,Huimin Zhen,hui min,hui min zhen,惠民,惠民镇', 30.8390900, 120.9698900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24636, 'Caoqiao', 'Caoqiao', 'Caoqiao,Caoqiao Jiedao,Caoqiao Xiang,cao qiao,cao qiao jie dao,cao qiao xiang,曹桥,曹桥乡,曹桥街道', 30.6723400, 120.9687000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24637, 'Xiangfu', 'Xiangfu', 'Xiangfu,Xiangfu Zhen,xiang fu,xiang fu zhen,祥符,祥符镇', 30.3297600, 120.0992200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24638, 'Suoqian', 'Suoqian', 'Suoqian,Suoqian Zhen,suo qian,suo qian zhen,所前,所前镇', 30.1135600, 120.2769200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24639, 'Qianjin', 'Qianjin', 'Qianjin,Qianjin Zhen,qian jin,qian jin zhen,千金,千金镇', 30.6777000, 120.2378400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24640, 'Renhe', 'Renhe', 'Renhe,Renhe Zhen,Zhangshan Zhen,ren he,ren he zhen,zhang shan zhen,仁和,仁和镇,獐山镇', 30.4460900, 120.0753500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24641, 'Gaibei', 'Gaibei', 'Gaibei,Gaibei Xiang,Gaibei Zhen,gai bei,gai bei xiang,gai bei zhen,盖北,盖北乡,盖北镇', 30.1403300, 120.8878000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24642, 'Banshan', 'Banshan', 'Banshan,Banshan Zhen,ban shan,ban shan zhen,半山,半山镇', 30.3516300, 120.1780800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24643, 'Yaozhuang', 'Yaozhuang', 'Yaozhuang,Yaozhuang Zhen,yao zhuang,yao zhuang zhen,姚庄,姚庄镇', 30.9139900, 120.9565100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24644, 'Kangqiao', 'Kangqiao', 'Kangqiao,Kangqiao Zhen,kang qiao,kang qiao zhen,康桥,康桥镇', 30.3648900, 120.1441000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24645, 'Sujiazhuang', 'Sujiazhuang', 'Longxi Xiang,Sujiazhuang,Yangjiabu Zhen,long xi xiang,su jia zhuang,yang jia bu zhen,杨家埠镇,苏家庄,龙溪乡', 30.8732300, 120.0704200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24646, 'Daicun', 'Daicun', 'Daicun,Daicun Zhen,dai cun,dai cun zhen,戴村,戴村镇', 30.0175900, 120.1959400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24647, 'Xindong', 'Xindong', 'Shiqiao Zhen,Xindong,Xindong Jiedao,shi qiao zhen,xin dong,xin dong jie dao,新东,新东街道,石桥镇', 30.3064600, 120.1727200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24648, 'Dingzha', 'Dingzha', 'Dingzha,Dingzha Zhen,ding shan,ding shan zhen,丁栅,丁栅镇', 30.9945100, 120.9444800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24649, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 30.1918300, 120.3330700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24650, 'Shangtang', 'Shangtang', 'Shangtang,Shangtang Jiedao,Shangtang Zhen,shang tang,shang tang jie dao,shang tang zhen,上塘,上塘街道,上塘镇', 30.3156600, 120.1503300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24651, 'Yangxunqiao', 'Yangxunqiao', 'Yangxunqiao,Yangxunqiao Zhen,yang xun qiao,yang xun qiao zhen,杨汛桥,杨汛桥镇', 30.1432800, 120.3559400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24652, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,Nanhu Xiang,cheng nan,cheng nan jie dao,nan hu xiang,南湖乡,城南,城南街道', 30.7371100, 120.7293700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24653, 'Xiasha', 'Xiasha', 'Xiasha,Xiasha Jiedao,Xiasha Zhen,xia sha,xia sha jie dao,xia sha zhen,下沙,下沙街道,下沙镇', 30.3102300, 120.3171800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24654, 'Sijiqing', 'Sijiqing', 'Sijiqing,Sijiqing Jiedao,Sijiqing Zhen,si ji qing,si ji qing jie dao,si ji qing zhen,四季青,四季青街道,四季青镇', 30.2494400, 120.1849300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24655, 'Lingzhi', 'Lingzhi', 'Lingzhi,Lingzhi Xiang,Lingzhi Zhen,ling zhi,ling zhi xiang,ling zhi zhen,灵芝,灵芝乡,灵芝镇', 30.0285000, 120.5741900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24656, 'Tianshengjie', 'Tianshengjie', 'Huanzhu Xiang,Tianshengjie,huan zhu xiang,tian sheng jie,环渚乡,田盛街', 30.8778300, 120.1123000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24657, 'Pengbu', 'Pengbu', 'Pengbu,Pengbu Zhen,peng bu,peng bu zhen,彭埠,彭埠镇', 30.2911100, 120.2202100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24658, 'Dangwan', 'Dangwan', 'Dangwan,Dangwan Zhen,dang wan,dang wan zhen,党湾,党湾镇', 30.2295100, 120.5437100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24659, 'Shuangpu', 'Shuangpu', 'Shuangpu,Shuangpu Zhen,Yuanpu Zhen,shuang pu,shuang pu zhen,yuan pu zhen,双浦,双浦镇,袁浦镇', 30.1150300, 120.1176400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24660, 'Dingqiao', 'Dingqiao', 'Dingqiao,Dingqiao Zhen,ding qiao,ding qiao zhen,丁桥,丁桥镇', 30.3517500, 120.2228000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24661, 'Qinshan', 'Qinshan', 'Qinshan,Qinshan Zhen,qin shan,qin shan zhen,秦山,秦山镇', 30.4345700, 120.9230600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24662, 'Yaqian', 'Yaqian', 'Yaqian,Yaqian Zhen,ya qian,ya qian zhen,衙前,衙前镇', 30.1621000, 120.4036600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24663, 'Yipeng', 'Yipeng', 'Yipeng,Yipeng Zhen,yi peng,yi peng zhen,义蓬,义蓬镇', 30.2615800, 120.4888400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24664, 'Dayun', 'Dayun', 'Dayun,Dayun Zhen,da yun,da yun zhen,大云,大云镇', 30.7827800, 120.9460800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24665, 'Qixing', 'Qixing', 'Qixing,Qixing Xiang,qi xing,qi xing xiang,七星,七星乡', 30.8135500, 120.8120600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24666, 'Daqiao', 'Daqiao', 'Daqiao,Daqiao Zhen,da qiao,da qiao zhen,大桥,大桥镇', 30.7475100, 120.8568400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24667, 'Jiefang', 'Jiefang', 'Jiefang,Jiefang Jiedao,jie fang,jie fang jie dao,解放,解放街道', 30.7781700, 120.7632800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24668, 'Youchegang', 'Youchegang', 'Youchegang,Youchegang Zhen,you che gang,you che gang zhen,油车港,油车港镇', 30.8288800, 120.7480900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24669, 'Yunhe', 'Yunhe', 'Yunhe,Yunhe Zhen,yun he,yun he zhen,运河,运河镇', 30.4749600, 120.2960200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24670, 'Xintang', 'Xintang', 'Xintang,Xintang Jiedao,xin tang,xin tang jie dao,新塘,新塘街道', 30.1507000, 120.3043400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24671, 'Huwan', 'Huwan', 'Huwan,Huwan Zhen,hu wan,hu wan zhen,浒湾,浒湾镇', 27.9208600, 116.5482700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24672, 'Qiaodong', 'Qiaodong', 'Qiaodong,Qiaodong Jiedao,Yangzhou Zhen,qiao dong,qiao dong jie dao,yang zhou zhen,桥东,桥东街道,洋洲镇', 27.9997600, 116.3619800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24673, 'Qingyun', 'Qingyun', 'Qingyun,Qingyun Jiedao,qing yun,qing yun jie dao,清云,清云街道', 27.9853800, 116.3564600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24674, 'Liujiaqiao', 'Liujiaqiao', 'Liujiaqiao,Liujiaqiao Xiang,liu jia qiao,liu jia qiao xiang,六家桥,六家桥乡', 27.8086900, 116.1742900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24675, 'Zhongling', 'Zhongling', 'Zhongling,Zhongling Jiedao,Zhongling Xiang,zhong ling,zhong ling jie dao,zhong ling xiang,钟岭,钟岭乡,钟岭街道', 27.9562700, 116.3828200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24676, 'Tanxi', 'Tanxi', 'Tanxi,Tanxi Xiang,tan xi,tan xi xiang,潭溪,潭溪乡', 27.2891300, 116.9374900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24677, 'Wanfang', 'Wanfang', 'Wanfang,Wanfang Xiang,Wanfang Zhen,wan fang,wan fang xiang,wan fang zhen,万坊,万坊乡,万坊镇', 27.6159300, 116.6160100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24678, 'Jinggonglu', 'Jinggonglu', 'Jinggonglu,Jinggonglu Jiedao,jing gong lu,jing gong lu jie dao,荆公路,荆公路街道', 27.9960700, 116.3550900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24679, 'Heshang', 'Heshang', 'Heshang,Heshang Zhen,he shang,he shang zhen,河上,河上镇', 27.8663500, 116.0167600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24680, 'Shazhou', 'Shazhou', 'Shazhou,Shazhou Zhen,sha zhou,sha zhou zhen,沙洲,沙洲镇', 27.7290000, 116.8257800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24681, 'Laixi', 'Laixi', 'Laixi,Laixi Xiang,lai xi,lai xi xiang,莱溪,莱溪乡', 27.2102400, 116.5772300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24682, 'Heyuan', 'Heyuan', 'Heyuan,Heyuan Xiang,Heyuan Zhen,he yuan,he yuan xiang,he yuan zhen,何源,何源乡,何源镇', 27.9952200, 116.9524900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24683, 'Xidajie', 'Xidajie', 'Fuzhou Shi,Xidajie,Xidajie Jiedao,fu zhou shi,xi da jie,xi da jie jie dao,抚州市,西大街,西大街街道', 27.9966200, 116.3529000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24684, 'Gangkou', 'Gangkou', 'Gangkou,Gangkou Xiang,gang kou,gang kou xiang,港口,港口乡', 29.4399600, 114.2019400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24685, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Zhen,qing shan,qing shan zhen,青山,青山镇', 29.4388800, 114.0192800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24686, 'Honggangshan', 'Honggangshan', 'Honggangshan,Honggangshan Zhen,hong gang shan,hong gang shan zhen,洪港山,洪港山镇', 29.5187800, 114.8686100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24687, 'Fushan', 'Fushan', 'Fushan,Fushan Jiedao,fu shan,fu shan jie dao,浮山,浮山街道', 29.8663000, 114.3113100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24688, 'Guihua', 'Guihua', 'Guihua,Guihua Zhen,gui hua,gui hua zhen,桂花,桂花镇', 29.7178500, 114.3446500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24689, 'Damu', 'Damu', 'Damu,Damu Xiang,da mu,da mu xiang,大幕,大幕乡', 29.8087700, 114.5391200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24690, 'Xiangyanghu', 'Xiangyanghu', 'Xiangyanghu,Xiangyanghu Zhen,xiang yang hu,xiang yang hu zhen,向阳湖,向阳湖镇', 29.9055400, 114.1639100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24691, 'Dalu', 'Dalu', 'Dalu,Dalu Xiang,da lu,da lu xiang,大路,大路乡', 29.5993800, 114.4317900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24692, 'Jiugongshan', 'Jiugongshan', 'Jiugongshan,Jiugongshan Zhen,jiu gong shan,jiu gong shan zhen,九宫山,九宫山镇', 29.5188000, 114.6814000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24693, 'Tongzhong', 'Tongzhong', 'Tongzhong,Tongzhong Xiang,tong zhong,tong zhong xiang,铜钟,铜钟乡', 29.4758900, 114.1060700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24694, 'Baini', 'Baini', 'Baini,Baini Zhen,bai ni,bai ni zhen,白霓,白霓镇', 29.5349500, 114.1294500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24695, 'Chuangwang', 'Chuangwang', 'Chuangwang,Chuangwang Zhen,chuang wang,chuang wang zhen,闯王,闯王镇', 29.4953800, 114.6193800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24696, 'Wangying', 'Wangying', 'Wangying,Wangying Zhen,wang ying,wang ying zhen,王英,王英镇', 29.8041000, 114.8285500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24697, 'Gaojian', 'Gaojian', 'Gaojian,Gaojian Xiang,gao jian,gao jian xiang,高枧,高枧乡', 29.2786700, 114.0677800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24698, 'Xinwan', 'Xinwan', 'Xinwan,Xinwan Xiang,xin wan,xin wan xiang,新湾,新湾乡', 29.1933100, 114.4535300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24699, 'Shanghang', 'Shanghang', 'Shanghang,Shanghang Xiang,shang hang,shang hang xiang,上杭,上杭乡', 29.1068600, 114.4376400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24700, 'Shangtang', 'Shangtang', 'Shangtang,Shangtang Xiang,shang tang,shang tang xiang,上汤,上汤乡', 29.3130300, 114.6415000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24701, 'Zhuping', 'Zhuping', 'Zhuping,Zhuping Xiang,zhu ping,zhu ping xiang,竹坪,竹坪乡', 29.0116100, 114.4748200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24702, 'Quanfeng', 'Quanfeng', 'Quanfeng,Quanfeng Zhen,quan feng,quan feng zhen,全丰,全丰镇', 29.1287900, 114.0701400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24703, 'Huanglong', 'Huanglong', 'Huanglong,Huanglong Xiang,huang long,huang long xiang,黄龙,黄龙乡', 29.0280500, 114.0318400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24704, 'Miaoling', 'Miaoling', 'Miaoling,Miaoling Xiang,miao ling,miao ling xiang,庙岭,庙岭乡', 29.1044500, 114.7042600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24705, 'Shi’ao', 'Shi''ao', 'Shi''ao,Shi''ao Xiang,Shi’ao,Shi’ao Xiang,shi ao,shi ao xiang,石坳,石坳乡', 29.0027900, 114.1867200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24706, 'Bailing', 'Bailing', 'Bailing,Bailing Zhen,bai ling,bai ling zhen,白岭,白岭镇', 29.0799500, 114.0214000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24707, 'Dachun', 'Dachun', 'Dachun,Dachun Xiang,da chun,da chun xiang,大椿,大椿乡', 29.1186700, 114.2504300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24708, 'Bujia', 'Bujia', 'Bujia,Bujia Xiang,bu jia,bu jia xiang,布甲,布甲乡', 29.2859700, 114.4098800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24709, 'Lukou', 'Lukou', 'Lukou,Lukou Xiang,lu kou,lu kou xiang,路口,路口乡', 29.0807600, 114.0884600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24710, 'Donglin', 'Donglin', 'Donglin,Donglin Xiang,dong lin,dong lin xiang,东林,东林乡', 29.2338100, 114.5384400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24711, 'Futu', 'Futu', 'Futu,Futu Zhen,fu tu,fu tu zhen,浮屠,浮屠镇', 29.9047800, 115.0822000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24712, 'Dafasi', 'Dafasi', 'Dafasi,Dafasi Zhen,da fa si,da fa si zhen,大法寺,大法寺镇', 29.9496800, 115.4766300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24713, 'Tianzhen', 'Tianzhen', 'Tianzhen,Tianzhencun,tian zhen,田镇', 29.8672000, 115.4717400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24714, 'Fuchi', 'Fuchi', 'Fuchi,Fuchi Zhen,Fuchihkow,fu chi,fu chi zhen,富池,富池镇', 29.8550500, 115.4379500, 'CN', '2016-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24715, 'Huangjin', 'Huangjin', 'Huangjin,Huangjin Xiang,huang jin,huang jin xiang,黄金,黄金乡', 29.7767300, 115.4818400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24716, 'Zhaomin', 'Zhaomin', 'Zhaomin,Zhaomin Zhen,zhao min,zhao min zhen,兆民,兆民镇', 32.0110700, 121.5858900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24717, 'Quankou', 'Quankou', 'Quankou,Quankou Zhen,quan kou,quan kou zhen,泉口,泉口镇', 29.4985600, 115.0275100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24718, 'Songxi', 'Songxi', 'Songxi,Songxi Zhen,song xi,zhen xi zhen,宋溪,镇溪镇', 29.3068400, 115.1071100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24719, 'Yanyang', 'Yanyang', 'Yanyang,Yanyang XIang,yan yang,yan yang xiang,严阳,严阳乡', 29.1207600, 115.1245000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24720, 'Guanlian', 'Guanlian', 'Guanlian,Guanlian Xiang,guan lian,guan lian xiang,官连,官连乡', 29.3751600, 115.3130800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24721, 'Luxi', 'Luxi', 'Luxi,Luxi Zhen,lu xi,lu xi zhen,鲁溪,鲁溪镇', 29.4348000, 115.2331800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24722, 'Baofeng', 'Baofeng', 'Baofeng,Baofeng Zhen,bao feng,bao feng zhen,宝峰,宝峰镇', 29.0068700, 115.4023500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24723, 'Hongyi', 'Hongyi', 'Hongyi,Hongyi Xiang,hong yi,hong yi xiang,洪一,洪一乡', 29.6235700, 115.1987900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24724, 'Nanyi', 'Nanyi', 'Nanyi,Nanyi Zhen,nan yi,nan yi zhen,南义,南义镇', 29.4481600, 115.3260400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24725, 'Cheqiao', 'Cheqiao', 'Cheqiao,Cheqiao Zhen,che qiao,che qiao zhen,车桥,车桥镇', 29.3608200, 115.4609500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24726, 'Tangshan', 'Tangshan', 'Tangshan,Tangshan Xiang,tang shan,tang shan xiang,塘山,塘山乡', 29.4960900, 115.4966600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24727, 'Huayuan', 'Huayuan', 'Huayuan,Huayuan Xiang,hua yuan,hua yuan xiang,花园,花园乡', 29.5963800, 115.3205200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24728, 'Zhaochen', 'Zhaochen', 'Zhaochen,Zhaochen Zhen,zhao chen,zhao chen zhen,肇陈,肇陈镇', 29.5821200, 115.1856100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24729, 'Leyuan', 'Leyuan', 'Leyuan,Leyuan Xiang,le yuan,le yuan xiang,乐园,乐园乡', 29.5144200, 115.2186900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24730, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Zhen,feng shan,feng shan zhen,凤山,凤山镇', 30.7884800, 115.3921400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24731, 'Henglishan', 'Henglishan', 'Henglishan,Henglishan Xiang,heng li shan,heng li shan xiang,横立山,横立山乡', 29.7004200, 115.4345400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24732, 'Sanzhaolun', 'Sanzhaolun', 'Sanzhaolun,Sanzhaolun Xiang,san zhao lun,san zhao lun xiang,三爪仑,三爪仑乡', 29.0623900, 115.2212400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24733, 'Cengjia', 'Cengjia', 'Cengjia,ceng jia,曾家', 29.0198100, 115.2225500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24734, 'Ruanyitu', 'Ruanyitu', 'Ruanyitu,ruan yi tu,阮宜堍', 29.9265700, 115.1890000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24735, 'Xingguo', 'Xingguo', 'Xingguo,Xingguo Zhen,xing guo,xing guo zhen,兴国,兴国镇', 29.8337500, 115.2086600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24736, 'Neihu', 'Neihu', 'Neihu,Neihu Zhen,nei hu,nei hu zhen,内胡,内胡镇', 29.7187200, 115.4055200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24737, 'Leshan', 'Leshan', 'Leshan,Leshan Xiang,le shan,le shan xiang,乐山,乐山乡', 29.5928200, 115.4737700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24738, 'Xinzhuang', 'Xinzhuang', 'Xinzhuang,Xinzhuang Zhen,xin zhuang,xin zhuang zhen,新庄,新庄镇', 28.4586100, 115.0796900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24739, 'Shuikou', 'Shuikou', 'Shuikou,Shuikou Xiang,shui kou,shui kou xiang,水口,水口乡', 28.8860000, 115.2902600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24740, 'Chi’an', 'Chi''an', 'Chi''an,Chi''an Zhen,Chi’an,Chi’an Zhen,chi an,chi an zhen,赤岸,赤岸镇', 28.6921800, 115.3691200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24741, 'Leigongjian', 'Leigongjian', 'Leigongjian,Leigongjian Xiang,lei gong jian,lei gong jian xiang,雷公尖,雷公尖乡', 28.8862200, 115.3396800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24742, 'Macaomiao', 'Macaomiao', 'Macaomiao,Macaomiao Zhen,ma cao miao,ma cao miao zhen,马曹庙,马曹庙镇', 30.6573900, 115.0176400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24743, 'Fuzihe', 'Fuzihe', 'Fuzihe,Fuzihe Zhen,fu zi he,fu zi he zhen,夫子河,夫子河镇', 30.9581900, 115.0245500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24744, 'Tuanbei', 'Tuanbei', 'Tuanbei,Tuanbei Zhen,tuan bei,tuan bei zhen,团陂,团陂镇', 30.7286900, 115.2276800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24745, 'Hekou', 'Hekou', 'Hekou,Hekou Zhen,he kou,he kou zhen,河口,河口镇', 30.1497800, 115.2207400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24746, 'Sanhua', 'Sanhua', 'Sanhua,Sanhua Zhen,san hua,san hua zhen,散花,散花镇', 30.2423800, 115.1085900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24747, 'Bahe', 'Bahe', 'Bahe,Bahe Zhen,Paho,ba he,ba he zhen,巴河,巴河镇', 30.4288300, 115.0229100, 'CN', '2015-01-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24748, 'Chencelou', 'Chencelou', 'Chencelou,Chencelou Zhen,chen ce lou,chen ce lou zhen,陈策楼,陈策楼镇', 30.5984600, 115.0461500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24749, 'Dupi', 'Dupi', 'Dupi,Dupi Xiang,du pi,du pi xiang,杜皮,杜皮乡', 30.7956500, 115.0507400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24750, 'Bailian', 'Bailian', 'Bailian,Bailian Zhen,bai lian,bai lian zhen,白莲,白莲镇', 30.5951000, 115.4419400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24751, 'Dawang', 'Dawang', 'Dawang,Dawang Zhen,da wang,da wang zhen,大王,大王镇', 30.0387100, 115.1181200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24752, 'Dalukou', 'Dalukou', 'Dalukou,Huahu,Huahu Jiedao,Huahu Zhen,da lu kou,hua hu,hua hu jie dao,hua hu zhen,大路口,花湖,花湖街道,花湖镇', 30.2742000, 114.9990400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24753, 'Yantianhe', 'Yantianhe', 'Yantianhe,Yantianhe Zhen,yan tian he,yan tian he zhen,盐田河,盐田河镇', 30.9697300, 115.1713000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24754, 'Dajipu', 'Dajipu', 'Dajipu,Dajipu Zhen,da ji pu,da ji pu zhen,大箕铺,大箕铺镇', 30.0441300, 115.0136700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24755, 'Tuanchengshan', 'Tuanchengshan', 'Tuanchengshan,Tuanchengshan Jiedao,tuan cheng shan,tuan cheng shan jie dao,团城山,团城山街道', 30.2019200, 115.0286800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24756, 'Hengche', 'Hengche', 'Hengche,Hengche Zhen,heng che,heng che zhen,横车,横车镇', 30.3079200, 115.3655700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24757, 'Guanyao', 'Guanyao', 'Guanyao,Guanyao Zhen,guan yao,guan yao zhen,管窑,管窑镇', 30.1503500, 115.2779600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24758, 'Yangye', 'Yangye', 'Yangye,Yangye Zhen,yang ye,yang ye zhen,杨叶,杨叶镇', 30.3150600, 115.0664100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24759, 'Dengyue', 'Dengyue', 'Dengyue,Dengyue Jiedao,cheng yue,cheng yue jie dao,澄月,澄月街道', 30.1863500, 115.0498300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24760, 'Haixiu', 'Haixiu', 'Haixiu,Haixiu Zhen,hai xiu,hai xiu zhen,海秀,海秀镇', 20.0109600, 110.2760700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24761, 'Shangshuai', 'Shangshuai', 'Shangshuai,Shangshuai Zhen,shang shuai,shang shuai zhen,上帅,上帅镇', 24.2516700, 112.0366700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24762, 'Daping', 'Daping', 'Daping,Daping Zhen,da ping,da ping zhen,大平,大平镇', 24.6513600, 112.1578000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24763, 'Shizikeng', 'Shizikeng', 'Shizikeng,Shizikeng Zhen,shi zi keng,shi zi keng zhen,石子坑,石子坑镇', 24.0863900, 115.4033300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24764, 'Guzhai', 'Guzhai', 'Guzhai,Guzhai Zhen,gu zhai,gu zhai zhen,古寨,古寨镇', 24.3908300, 115.1483300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24765, 'Shitang', 'Shitang', 'Shitang,Shitang Zhen,shi tang,shi tang zhen,石塘,石塘镇', 25.0749100, 113.5672300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24766, 'Baihe', 'Baihe', 'Baihe,Baihe Zhen,bai he,bai he zhen,白鹤,白鹤镇', 31.2561600, 121.1365300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24767, 'Changzheng', 'Changzheng', 'Changzheng,Changzheng Zhen,zhang zheng,zhang zheng zhen,长征,长征镇', 31.2391300, 121.3677900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24768, 'Huaxin', 'Huaxin', 'Huaxin,Huaxin Zhen,hua xin,hua xin zhen,华新,华新镇', 31.2469500, 121.2182400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24769, 'Jiuting', 'Jiuting', 'Jiuting,Jiuting Zhen,jiu ting,jiu ting zhen,九亭,九亭镇', 31.1305500, 121.3162800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24770, 'Dongjing', 'Dongjing', 'Dongjing,Dongjing Zhen,dong jing,dong jing zhen,洞泾,洞泾镇', 31.0867000, 121.2630000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24771, 'Pujiang', 'Pujiang', 'Pujiang,Pujiang Zhen,pu jiang,pu jiang zhen,浦江,浦江镇', 31.0935700, 121.4958100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24772, 'Kangqiao', 'Kangqiao', 'Kangqiao,Kangqiao Zhen,kang qiao,kang qiao zhen,康桥,康桥镇', 31.1293100, 121.5685600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24773, 'Lühua', 'Luhua', 'Luhua,Luhua Zhen,Lühua,Lühua Zhen,lu hua,lu hua zhen,绿华,绿华镇', 31.7668300, 121.2146200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24774, 'Yongxing', 'Yongxing', 'Qilong,Yongxing,Yongxing Zhen,qi long,yong xing,yong xing zhen,启隆,永兴,永兴镇', 31.7760700, 121.4544000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24775, 'Xingang', 'Xingang', 'Xingang,Xingang Zhen,xin gang,xin gang zhen,新港,新港镇', 31.7251100, 120.9201100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24776, 'Dianshanhu', 'Dianshanhu', 'Dianshanhu,Dianshanhu Zhen,Yangxiang,Yangxiang Zhen,dian shan hu,dian shan hu zhen,yang xiang,yang xiang zhen,杨湘,杨湘镇,淀山湖,淀山湖镇', 31.1841500, 121.0247300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24777, 'Yueyang', 'Yueyang', 'Yueyang,Yueyang Jiedao,yue yang,yue yang jie dao,岳阳,岳阳街道', 31.0098300, 121.2150000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24778, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Jiedao,yong feng,yong feng jie dao,永丰,永丰街道', 31.0062700, 121.2016400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24779, 'Yingpu', 'Yingpu', 'Yingpu,Yingpu Jiedao,ying pu,ying pu jie dao,盈浦,盈浦街道', 31.1552700, 121.1057500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24780, 'Xiayang', 'Xiayang', 'Qingpu Qu,Xiayang,Xiayang Jiedao,qing pu qu,xia yang,xia yang jie dao,夏阳,夏阳街道,青浦区', 31.1496700, 121.1158800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24781, 'Xinchenglu', 'Xinchenglu', 'Jiading Qu,Xinchenglu,Xinchenglu Jiedao,jia ding qu,xin cheng lu,xin cheng lu jie dao,嘉定区,新成路,新成路街道', 31.3886400, 121.2630500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24782, 'Fangsong', 'Fangsong', 'Fangsong,Fangsong Jiedao,Songjiang Qu,fang song,fang song jie dao,song jiang qu,方松,方松街道,松江区', 31.0328500, 121.1894300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24783, 'Jiangchuanlu', 'Jiangchuanlu', 'Jiangchuanlu,Jiangchuanlu Jiedao,jiang chuan lu,jiang chuan lu jie dao,江川路,江川路街道', 31.0139200, 121.4074200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24784, 'Zhenxin', 'Zhenxin', 'Zhenxin,Zhenxin Jiedao,zhen xin,zhen xin jie dao,真新,真新街道', 31.2461000, 121.3540900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24785, 'Peimei', 'Peimei', 'Peimei,Peimei Zhen,pei mei,pei mei zhen,裴梅,裴梅镇', 28.6395300, 117.1036900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24786, 'Shiligang', 'Shiligang', 'Shiligang,Shiligang Xiang,shi li gang,shi li gang xiang,十里岗,十里岗乡', 28.8717500, 117.4938100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24787, 'Zhongshan', 'Zhongshan', 'Zhongshan,Zhongshan Jiedao,Zhongshan Jiedao Banshichu,zhong shan,zhong shan jie dao,zhong shan jie dao ban shi chu,中山,中山街道,中山街道办事处', 31.0360100, 121.2441400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24788, 'Changqiao', 'Changqiao', 'Changqiao,Changqiao Jiedao,Changqiao Jiedao Banshichu,zhang qiao,zhang qiao jie dao,zhang qiao jie dao ban shi chu,长桥,长桥街道,长桥街道办事处', 31.1419400, 121.4340000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24789, 'Huangling', 'Huangling', 'Huangling,Huangling Jiedao,huang ling,huang ling jie dao,荒岭,荒岭街道', 40.8474500, 122.7254400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24790, 'Qianliu', 'Qianliu', 'Qianliu,Qianliu Jiedao,qian liu,qian liu jie dao,前柳,前柳街道', 40.8417100, 122.6344000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24791, 'Xinxing', 'Xinxing', 'Xinxing,Xinxing Jiedao,xin xing,xin xing jie dao,新兴,新兴街道', 40.7184100, 122.2562400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24792, 'Gulou', 'Gulou', 'Gulou,Gulou Jiedao,gu lou,gu lou jie dao,鼓楼,鼓楼街道', 40.3989300, 122.3623500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24793, 'Jianfeng', 'Jianfeng', 'Jianfeng,Jianfeng Jiedao,jian feng,jian feng jie dao,建丰,建丰街道', 40.6693900, 122.2388000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24794, 'Shengli', 'Shengli', 'Shengli,Shengli Jiedao,sheng li,sheng li jie dao,胜利,胜利街道', 40.6740600, 122.2183200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24795, 'Qinghua', 'Qinghua', 'Qinghua,Qinghua Jiedao,qing hua,qing hua jie dao,清华,清华街道', 40.6643100, 122.2117800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24796, 'Ancun', 'Ancun', 'Ancun,Ancun Jiedao,an cun,an cun jie dao,安村,安村街道', 40.8709900, 122.7081700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24797, 'Haixing', 'Haixing', 'Haixing,Haixing Jiedao,hai xing,hai xing jie dao,海星,海星街道', 40.2760800, 122.1303400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24798, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 40.4053500, 122.3719700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24799, 'Yuejin', 'Yuejin', 'Yuejin,Yuejin Jiedao,yue jin,yue jin jie dao,跃进,跃进街道', 40.6733900, 122.2568800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24800, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 40.6584600, 122.4032500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24801, 'Xinghai', 'Xinghai', 'Xinghai,Xinghai Jiedao,xing hai,xing hai jie dao,兴海,兴海街道', 40.8615900, 122.7280900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24802, 'Xinjian', 'Xinjian', 'Xinjian,Xinjian Jiedao,xin jian,xin jian jie dao,新建,新建街道', 40.8502900, 122.3591200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24803, 'Honghai', 'Honghai', 'Honghai,Honghai Jiedao,hong hai,hong hai jie dao,红海,红海街道', 40.2409800, 122.1116200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24804, 'Guoyuan', 'Guoyuan', 'Guoyuan,Guoyuan Xiang,Xiongyueguoyuan Xiang,guo yuan,guo yuan xiang,xiong yue guo yuan xiang,果园,果园乡,熊岳果园乡', 40.1804900, 122.1394200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24805, 'Shiqiao', 'Shiqiao', 'Shiqiao,Shiqiao Jiedao,shi qiao,shi qiao jie dao,石桥,石桥街道', 40.6360700, 122.4975400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24806, 'Gangdu', 'Gangdu', 'Gangdu,Gangdu Jiedao,gang dou,gang dou jie dao,钢都,钢都街道', 40.6391800, 122.5125500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24807, 'Biru', 'Biru', 'Biru,Biru Zhen,Biruxiong,bi ru,bi ru xiong,bi ru zhen,比如,比如镇,比如雄', 31.4831900, 93.6774100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24808, 'Biruxong', 'Biruxong', 'Biru Xian,Biruxiong,Biruxong,bi ru xian,bi ru xiong,比如县,比如雄', 31.4010000, 93.6010000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24809, 'Bianba', 'Bianba', 'Benba,Bianba,Bianba Xiang,Bênba,Xuema,bian ba,bian ba xiang,xue ma,边巴,边巴乡,雪玛', 28.1880200, 91.2732200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24810, 'Ducheng', 'Ducheng', 'Ducheng,Ducheng Zhen,du cheng,du cheng zhen,堵城,堵城镇', 30.5448900, 114.8961600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24811, 'Niaojin', 'Niaojin', 'Niaojin,Niaojin Jiedao,niao jin,niao jin jie dao,鸟金,鸟金街道', 30.3482200, 114.0511400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24812, 'Sheshan', 'Sheshan', 'Sheshan,Sheshan Jiedao,zha shan,zha shan jie dao,奓山,奓山街道', 30.4475900, 114.0060100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24813, 'Zoumaling', 'Zoumaling', 'Zoumaling,Zoumaling Jiedao,zou ma ling,zou ma ling jie dao,走马岭,走马岭街道', 30.6530500, 114.0159100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24814, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Jiedao,dong shan,dong shan jie dao,东山,东山街道', 30.7763500, 114.0143400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24815, 'Mintian', 'Mintian', 'Jinghe,Jinghe Jiedao,Mintian,jing he,jing he jie dao,min tian,民田,经河,经河街道', 30.6830900, 114.1591200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24816, 'Sandian', 'Sandian', 'Sandian,san dian,三店', 30.6517000, 114.1521400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24817, 'Moluo', 'Moluo', 'Agar,Aka,Gongjue Xian,Moluo,Moluo Zhen,a ka,gong jue xian,mo luo,mo luo zhen,莫洛,莫洛镇,贡觉县,阿卡', 30.8039200, 98.1003800, 'CN', '2014-04-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24818, 'Changqing', 'Changqing', 'Changqing,Changqing Jiedao,zhang qing,zhang qing jie dao,长青,长青街道', 30.6144700, 114.1171600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24819, 'Tianhe', 'Tianhe', 'Tianhe,tian he,天河', 30.8039000, 114.2142800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24820, 'Tianxing', 'Tianxing', 'Tianxing,Tianxing Xiang,tian xing,tian xing xiang,天兴,天兴乡', 30.6690000, 114.4145600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24821, 'Wutongkou', 'Wutongkou', 'Wuhu,Wuhu Nongchang,Wutongkou,wu hu,wu tong kou,五湖,五通口', 30.6926000, 114.4034900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24822, 'Qianquan', 'Qianquan', 'Huangbei,Huangbei Qu,Qianquan,Qianquan Jiedao,huang bei,huang bei qu,qian chuan,qian chuan jie dao,前川,前川街道,黄陂,黄陂区', 30.8712600, 114.3725800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24823, 'Jiaomingsi', 'Jiaomingsi', 'Jiaomingsi,Sanli,Sanli Zhen,jiao ming si,san li,san li zhen,三里,三里镇,教命寺', 30.7833000, 114.4114400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24824, 'Zhangduhu', 'Zhangduhu', 'Zhangduhu,Zhangduhu Jiedao,Zhangduhu Nongchang,zhang du hu,zhang du hu jie dao,zhang du hu nong chang,涨渡湖,涨渡湖农场,涨渡湖街道', 30.6732500, 114.7901700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24825, 'Jiangti', 'Jiangti', 'Jiangti,Jiangti Jiedao,jiang ti,jiang ti jie dao,江提,江提街道', 30.5233300, 114.2379300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24826, 'Zhangjiawan', 'Zhangjiawan', 'Jiangjiawan Jiedao,Zhangjiawan,zhang jia wan,zhang jia wan jie dao,张家湾,张家湾街道', 30.4786400, 114.2716000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24827, 'Changfeng', 'Changfeng', 'Changfeng,Changfeng Jiedao,zhang feng,zhang feng jie dao,长丰,长丰街道', 30.6070400, 114.2074900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24828, 'Houhu', 'Houhu', 'Houhu,Houhu Jiedao,hou hu,hou hu jie dao,后湖,后湖街道', 30.6596800, 114.3255300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24829, 'Yongfeng', 'Yongfeng', 'Yongfeng,Yongfeng Jiedao,yong feng,yong feng jie dao,永丰,永丰街道', 30.5654900, 114.2202600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24830, 'Shilipu', 'Shilipu', 'Qianduankou Jiedao,Qinduankou,Shilipu,qin duan kou,qin duan kou jie dao,shi li pu,十里铺,琴断口,琴断口街道', 30.5617200, 114.2135600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24831, 'Guanshan', 'Guanshan', 'Guanshan,Guanshan Jiedao,guan shan,guan shan jie dao,关山,关山街道', 30.5065800, 114.4033900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24832, 'Wangdian', 'Wangdian', 'Jiufeng,Jiufeng Xiang,Wangdian,jiu feng,jiu feng xiang,wang dian,九峰,九峰乡,王店', 30.5085600, 114.4771700, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24833, 'Huashan', 'Huashan', 'Huashan,Huashan Zhen,hua shan,hua shan zhen,花山,花山镇', 30.5427800, 114.5141100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24834, 'Zuoling', 'Zuoling', 'Zuoling,Zuoling Zhen,zuo ling,zuo ling zhen,左岭,左岭镇', 30.5328400, 114.6003400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24835, 'Baiyushan', 'Baiyushan', 'Baiyushan,Baiyushan Jiedao,bai yu shan,bai yu shan jie dao,百玉山,百玉山街道', 30.6047400, 114.4875300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24836, 'Wudong', 'Wudong', 'Wudong,Wudong Jiedao,wu dong,wu dong jie dao,武东,武东街道', 30.5823400, 114.4545600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24837, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Jiedao,hong qi,hong qi jie dao,红旗,红旗街道', 30.6059900, 114.4318500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24838, 'Heping', 'Heping', 'Heping,Heping Jiedao,he ping,he ping jie dao,和平,和平街道', 30.6290700, 114.3884200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24839, 'Dujiajing', 'Dujiajing', 'Dujiajing,Jianshe,Jianshe Xiang,du jia jing,jian she,jian she xiang,建设,建设乡,杜家井', 30.6621200, 114.4562300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24840, 'Shizishan', 'Shizishan', 'Shizishan,Shizishan Jiedao,shi zi shan,shi zi shan jie dao,狮子山,狮子山街道', 30.4857300, 114.3291900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24841, 'Minji', 'Minji', 'Minji,Minji Xiang,min ji,min ji xiang,闵集,闵集乡', 30.8414500, 114.1302500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24842, 'Zhuzhan', 'Zhuzhan', 'Zhuzhan,Zhuzhan Zhen,zhu zhan,zhu zhan zhen,祝站,祝站镇', 30.9267600, 114.1552000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24843, 'Sancha', 'Sancha', 'Sancha,Sancha Zhen,san cha,san cha zhen,三汊,三汊镇', 30.9449400, 114.0592900, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24844, 'Dongfenglu', 'Dongfenglu', 'Dongfenglu,Dongfenglu Jiedao,dong feng lu,dong feng lu jie dao,东风路,东风路街道', 30.0927100, 114.9638200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24845, 'Majiao', 'Majiao', 'Jinhu,Jinhu Jiedao,Majiao,jin hu,jin hu jie dao,ma jiao,金湖,金湖街道,马叫', 30.0635900, 114.9294800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24846, 'Mingshan', 'Mingshan', 'Mingshan,Mingshan Xiang,ming shan,ming shan xiang,茗山,茗山乡', 30.0604400, 114.7593800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24847, 'Laoxialu', 'Laoxialu', 'Laoxialu,Laoxialu Jiedao,lao xia lu,lao xia lu jie dao,老下陆,老下陆街道', 30.1869800, 114.9742500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24848, 'Xinmiao', 'Xinmiao', 'Xinmiao,Xinmiao Zhen,xin miao,xin miao zhen,新庙,新庙镇', 30.3878700, 114.9260600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24849, 'Liufang', 'Liufang', 'Liufang,Liufang Jiedao,liu fang,liu fang jie dao,流芳,流芳街道', 30.4452300, 114.4486000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24850, 'Shangri-La', 'Shangri-La', 'Shangelila,Shangri-La,Шангри-Ла', 27.8251100, 99.7077900, 'CN', '2013-11-20', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24851, 'Jishi', 'Jishi', 'Jishi,Jishi Zhen,Xunhua Salazu Zizhixian,ji shi,ji shi zhen,sa la zu zi zhi xian,xun hua sa la zu zi zhi xian,循化撒拉族自治县,撒拉族自治县,积石,积石镇', 35.8461300, 102.4817100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24852, 'Guanyinge', 'Guanyinge', 'Guanyinge,Guanyinge Jiedao,guan yin ge,guan yin ge jie dao,观音阁,观音阁街道', 41.3133300, 124.1146100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24853, 'Zhangdian', 'Zhangdian', 'Zhangdian,Zhangdian Jiedao,zhang dian,zhang dian jie dao,张甸,张甸街道', 41.8172000, 124.0413500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24854, 'Heigou', 'Heigou', 'Heigou,Heigou Zhen,hei gou,hei gou zhen,黑沟,黑沟镇', 40.0817700, 123.6069600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24855, 'Bahui', 'Bahui', 'Bahui,Bahui Zhen,ba hui,ba hui zhen,八会,八会镇', 40.9318700, 123.2003600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24856, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Xiang,chao yang,chao yang xiang,朝阳,朝阳乡', 40.4574200, 123.5506300, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24857, 'Gaoguan', 'Gaoguan', 'Gaoguan,Gaoguan Zhen,gao guan,gao guan zhen,高莞,高莞镇', 24.2583400, 114.7176100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24858, 'Sanjiao', 'Sanjiao', 'Sanjiao,Sanjiao Zhen,san jiao,san jiao zhen,三角,三角镇', 24.2070100, 114.8043200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24859, 'Jinlong', 'Jinlong', 'Jinlong,Jinlong Zhen,jin long,jin long zhen,金龙,金龙镇', 24.7505300, 114.5330400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24860, 'Guanxi', 'Guanxi', 'Guanxi,Guanxi Zhen,guan xi,guan xi zhen,关西,关西镇', 24.8408700, 114.9422600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24861, 'Dengmu', 'Dengmu', 'Dem,Dengmu,Dengmu Xiang,Dêm,deng mu,deng mu xiang,登木,登木乡', 28.8877700, 92.8354300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24862, 'Diyag', 'Diyag', 'Diya,Diya Xiang,Diyag,di ya,di ya xiang,底雅,底雅乡', 31.7000000, 78.8000000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24863, 'Dingqing', 'Dingqing', 'Dengqen,Dingqing,Dingqing Zhen,Dêngqên,Jiamotang,ding qing,ding qing zhen,jia mo tang,丁青,丁青镇,加莫塘', 31.4115300, 95.5841800, 'CN', '2013-09-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24864, 'Douyu', 'Douyu', 'Douyu,Douyu Xiang,Doyu,Doyü,dou yu,dou yu xiang,斗玉,斗玉乡', 28.4068900, 92.9852000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24865, 'Towa', 'Towa', 'Dadu,Duwa,Duwa Xiang,Towa,da dou,dou wa,dou wa xiang,达都,都瓦,都瓦乡', 31.0071100, 94.9209300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24866, 'Dopozhang', 'Dopozhang', 'Dopozhang,Duopozhang,Duopozhang Xiang,Sangdong,duo po zhang,duo po zhang xiang,sang dong,多颇章,多颇章乡,桑东', 29.3165200, 91.6846700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24867, 'Camgyai', 'Camgyai', 'Camgyai,Cangmujie,Cangmujie Xiang,Rongxia Qu,cang mu jie,cang mu jie xiang,rong xia qu,仓木结,仓木结乡,绒辖区', 28.0000000, 86.3000000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24868, 'Car', 'Car', 'Car,Cha''er,Cha''er Xiang,Cha’er,Cha’er Xiang,Quelong,cha er,cha er xiang,que long,确隆,茶尔,茶尔乡', 29.3890100, 89.3140500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24869, 'Caqu', 'Caqu', 'Caqu,Chaqu,Chaqu Xiang,Tangguochong,cha qu,cha qu xiang,tang guo chong,唐郭冲,茶曲,茶曲乡', 31.5257000, 93.2814200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24870, 'Changzhug', 'Changzhug', 'Changzhu,Changzhu Zhen,Changzhug,chang zhu,chang zhu zhen,昌珠,昌珠镇', 29.1933200, 91.7720100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24871, 'Cola', 'Cola', 'Cola,Cuola,Cuola Xiang,Cuonai,cuo la,cuo la xiang,cuo nai,措乃,措拉,措拉乡', 31.0802600, 92.8600700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24872, 'Dagsar', 'Dagsar', 'Caqupaduo,Dagsar,Dasa,Dasa Xiang,ca qu pa duo,da sa,da sa xiang,擦曲帕多,达撒,达萨乡', 31.2727800, 92.2884500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24873, 'Dazi', 'Dazi', 'Dagze,Dagzê,Dazi,Dazi Xiang,Wuyu Qu,da zi,da zi xiang,wu yu qu,乌郁区,达孜,达孜乡', 29.6019900, 89.6196800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24874, 'Dazi', 'Dazi', 'Dagze,Dagzê,Dazi,Dazi Xiang,da zi,da zi xiang,达孜,达孜乡', 29.0705500, 89.4373900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24875, 'Damnyain', 'Damnyain', 'Damnyain,Danniang,Danniang Zhen,dan niang,dan niang zhen,丹娘,丹娘镇', 29.4454800, 94.7050400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24876, 'Dejilin', 'Dejilin', 'De''gyiling,Dejilin,Dejilin Zhen,Dê’gyiling,Rena,de ji lin,de ji lin zhen,ren a,仁阿,德吉林,德吉林镇', 29.1961600, 89.8684400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24877, 'Gapu', 'Gapu', 'Gapu,Gapu Xiang,Ledian,ga pu,ga pu xiang,lei dian,勒典,嘎普,嘎普乡', 28.7651800, 89.1398700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24878, 'Garmo', 'Garmo', 'Gamu,Gamu Xiang,Garmo,Jia''erjie,Jia’erjie,ga mu,ga mu xiang,jia er jie,嘎木乡,噶木,甲尔杰', 31.2605400, 94.9163000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24879, 'Goqung', 'Goqung', 'Dongqiongduo,Gequn,Gequn Xiang,Goqung,dong qiong duo,ge qun,ge qun xiang,东穹多,鸽群,鸽群乡', 30.8433900, 93.3769200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24880, 'Konggar', 'Konggar', 'Gongga,Gongga Zhen,Guka,Konggar,gong ga,gong ga zhen,gu ka,谷卡,贡嘎镇,贡噶', 29.2938900, 90.9870800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24881, 'Ximi', 'Ximi', 'Ximi,Ximixiang,xi mi,xi mi xiang,西米,西米乡', 28.9123500, 110.0068600, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24882, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Xiang,Yanping,chao yang,chao yang xiang,yan ping,岩坪,朝阳,朝阳乡', 29.3351500, 111.0307400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24883, 'Yanliupu', 'Yanliupu', 'Yangliupu Xiang,Yanliupu,yang liu pu,yang liu pu xiang,杨柳铺,杨柳铺乡', 29.5691900, 111.1281400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24884, 'Jiru', 'Jiru', 'Gyeru,Gyêru,Jiru,Jiru Xiang,ji ru,ji ru xiang,吉汝,吉汝乡', 28.1783400, 89.0485900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24885, 'Jiaqin', 'Jiaqin', 'Gyaiqen,Gyaiqên,Jiaqin,Jiaqin Xiang,Qiongkuoxue,jia qin,jia qin xiang,qiong kuo xue,加勤,加勤乡,琼括学', 31.6454700, 94.2743200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24886, 'Jiakexi', 'Jiakexi', 'Jaggye,Jaggyê,Jiakexi,Jiakexi Xiang,jia ke xi,jia ke xi xiang,加克西,加克西乡', 28.5926500, 89.2024000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24887, 'Jaggong', 'Jaggong', 'Jaggong,Jiagong,Jiagong Xiang,jia gong,jia gong xiang,加贡,加贡乡', 30.6953000, 93.9531800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24888, 'Wangying', 'Wangying', 'Wangying,Wangying Zhen,wang ying,wang ying zhen,王营,王营镇', 33.0316700, 119.5185800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24889, 'Huying', 'Huying', 'Huying,Huying Zhen,hu ying,hu ying zhen,胡营,胡营镇', 33.0723700, 119.4450000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24890, 'Qinggou', 'Qinggou', 'Qinggou,Qinggou Zhen,qing gou,qing gou zhen,青沟,青沟镇', 33.7040100, 119.3988500, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24891, 'Jangra', 'Jangra', 'Banjuelongbu,Jangra,Jiangre,Jiangre Xiang,ban jue long bu,jiang re,jiang re xiang,江热,江热乡,班觉隆布', 28.9029900, 89.5733100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24892, 'Jiling', 'Jiling', 'Jiling,Jinling,Jinling Xiang,Yugongguo,jin ling,jin ling xiang,yu gong guo,于公果,金岭,金岭乡', 30.7281600, 94.3711800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24893, 'Kazi', 'Kazi', 'Karze,Karzê,Kazi,Kazi Xiang,ka zi,ka zi xiang,卡孜,卡孜乡', 29.5807300, 89.0764300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24894, 'Lhabupu', 'Lhabupu', 'Labupu,Labupu Xiang,Lhabupu,Sega,la bu pu,la bu pu xiang,se ga,拉布普,拉布普乡,色嘎', 29.8637800, 89.3826800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24895, 'Laxi', 'Laxi', 'Bacanggongba,Laxi,Laxi Zhen,ba cang gong ba,la xi,la xi zhen,巴仓贡巴,拉西,拉西镇', 31.9212500, 94.0475700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24896, 'Lainqu', 'Lainqu', 'Lainqu,Liangqu,Liangqu Xiang,Palachong,liang qu,liang qu xiang,pa la chong,帕拉冲,良曲,良曲乡', 31.5231500, 93.5161300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24897, 'Lumaka', 'Lumaka', 'Longmenka,Lumaka,Rebang Qu,long men ka,re bang qu,热帮区,龙门卡', 33.0861600, 80.3678400, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24898, 'Gongbuxue', 'Gongbuxue', 'Gongbuxue,Gongbuxue Xiang,Lhunboxoi,Lhünboxoi,gong bu xue,gong bu xue xiang,工布学,工布学乡', 28.8507900, 91.0123300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24899, 'Lomai', 'Lomai', 'Lomai,Luomai,Luomai Xiang,Nianpu,luo mai,luo mai xiang,nian pu,年普,洛麦,落麦乡', 31.2549200, 92.6361100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24900, 'Marxog', 'Marxog', 'Marxog,Maxiu,Maxiu Xiang,ma xiu,ma xiu xiang,马秀,马秀乡', 30.9851400, 94.6582400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24901, 'Maiba', 'Maiba', 'Maiba,Maiba Xiang,Nizhi,mai ba,mai ba xiang,ni zhi,买巴,买巴乡,尼支', 31.0092100, 89.0965900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24902, 'Maintang', 'Maintang', 'Maintang,Mendang,Mendang Xiang,Mendangrezi,men dang,men dang re zi,men dang xiang,门当,门当乡,门当惹孜', 31.4132800, 89.7558200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24903, 'Mainling', 'Mainling', 'Bangjia,Mainling,Milin,Milin Zhen,bang jia,mi lin,mi lin zhen,米林,米林镇,邦加', 29.2176700, 94.2132500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24904, 'Mainri', 'Mainri', 'Mainri,Mirui,Mirui Xiang,mi rui,mi rui xiang,米瑞,米瑞乡', 29.4981300, 94.6115600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24905, 'Namaqie', 'Namaqie', 'Kasuonangba,Namaqie,Namaqie Xiang,Namarqe,Namarqê,ka suo nang ba,na ma qie,na ma qie xiang,喀索囊巴,那玛切,那玛切 乡', 31.5335700, 91.4169200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24906, 'Nagqu', 'Nagqu', 'Nagqu,Nagqu Zhen,Naqu Zhen,na qu,na qu zhen,那曲,那曲镇', 31.4030000, 92.0030000, 'CN', '2014-04-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24907, 'Nanni', 'Nanni', 'Nai''nying,Nai’nying,Nanni,Nanni Xiang,nan ni,nan ni xiang,南尼,南尼乡', 28.8240000, 89.6512300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24908, 'Nyima', 'Nyima', 'Nima,Nima Xiang,Ningde,Nyima,ni ma,ni ma xiang,ning de,宁德,尼玛,尼玛乡', 31.0773700, 91.0582400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24909, 'Nyinmo', 'Nyinmo', 'Nimu,Nimu Xiang,Nyinmo,Xueba,ni mu,ni mu xiang,xue ba,尼木,尼木乡,雪巴', 31.2485800, 94.3381100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24910, 'Nubma', 'Nubma', 'Nubma,Numa,Numa Xiang,nu ma,nu ma xiang,奴玛,奴玛乡', 29.4644000, 89.6362400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24911, 'Norbusa', 'Norbusa', 'Luobusha,Luobusha Zhen,Norbusa,Wangga,luo bu sha,luo bu sha zhen,wang ga,旺嘎,罗布沙,罗布沙镇', 29.2178300, 92.2022600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24912, 'Partang', 'Partang', 'Padang,Padang Xiang,Partang,pa dang,pa dang xiang,帕当,帕当乡', 29.2843500, 90.2513700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24913, 'Pundam', 'Pundam', 'Pudang,Pudang Xiang,Pundam,pu dang,pu dang xiang,普当,普当乡', 29.9040600, 89.1165900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24914, 'Qiewa', 'Qiewa', 'Qecun,Qiewa,Qiewa Xiang,Qêcun,qie wa,qie wa xiang,切娃,切娃乡', 29.3260700, 89.7407800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24915, 'Qum', 'Qum', 'Baiduo,Qiumu,Qiumu Xiang,Qum,bai duo,qiu mu,qiu mu xiang,白多,秋木,秋木乡', 29.6346400, 89.0161800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24916, 'Qumudi', 'Qumudi', 'Qumode,Qumodê,Qumudi,Sangang,qu mu di,san gang,三岗,曲木底', 32.2007600, 79.1844700, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24917, 'Ratang', 'Ratang', 'Labu Qu,Ratang,Redang,Redang Xiang,la bu qu,re dang,re dang xiang,拉布区,热当,热当乡', 29.7181000, 89.3683000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24918, 'Ralung', 'Ralung', 'Ralung,Relong,Relong Xiang,re long,re long xiang,热龙,热龙乡', 28.8224400, 90.0465100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24919, 'Rasog', 'Rasog', 'Rasog,Resuo,Resuo Xiang,re suo,re suo xiang,热索,热索乡', 29.0482200, 89.4285900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24920, 'Rawa', 'Rawa', 'Rawa,Rewa,Rewa Xiang,re wa,re wa xiang,热瓦,热瓦乡', 31.7215800, 93.8185400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24921, 'Renwu', 'Renwu', 'Nanmulin Xian,Renwu,Ri''ngoin,Ri’ngoin,nan mu lin xian,ren wu,仁伍,南木林县', 29.6050000, 89.0050000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24922, 'Rinang', 'Rinang', 'Dongfanghong Gongshe,Rilang,Rilang Xiang,Rinang,dong fang hong gong she,ri lang,ri lang xiang,东方红公社,日朗,日朗乡', 29.0080000, 92.6080000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24923, 'Rixing', 'Rixing', 'Rixing,Rixing Xiang,Shengli Gongshe,ri xing,ri xing xiang,sheng li gong she,日星,日星乡,胜利公社', 28.9019600, 89.2748100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24924, 'Rongdoi', 'Rongdoi', 'Rongdoi,Rongduo,Rongduo Xiang,Sidu,rong duo,rong duo xiang,si dou,斯都,绒多,绒多乡', 30.4407600, 92.0492400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24925, 'Rogda', 'Rogda', 'Rogda,Ruoda,Ruoda Xiang,Songka,ruo da,ruo da xiang,song ka,松喀,若达,若达乡', 31.6788200, 93.8609100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24926, 'Samdo', 'Samdo', 'Rezhaka,Samdo,Samdo Zhen,Sangduo,Seda Gongshe,re zha ka,sang duo,sang duo zhen,se da gong she,桑多,桑多镇,热扎卡,色达公社', 31.2143000, 96.5994000, 'CN', '2014-04-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24927, 'Xuejiawan', 'Xuejiawan', 'Jungar Qi,Xuejiawan,Xuejiawan Zhen,Zhunge''er Qi,Zhunge’er Qi,xue jia wan,xue jia wan zhen,zhun ge er qi,准格尔旗,薛家湾,薛家湾镇', 39.8667800, 111.2208000, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24928, 'Galutu', 'Galutu', 'Galutu,Galutu Zhen,Uxin Qi,Wushen Qi,ga lu tu,ga lu tu zhen,嘎鲁图,嘎鲁图镇', 38.6008600, 108.8474200, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24929, 'Aletengxire', 'Aletengxire', 'Aletengxire,Aletengxire Zhen,a lei teng xi re,a lei teng xi re zhen,阿勒腾席热,阿勒腾席热镇', 39.5799300, 109.7582100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24930, 'Dabagou', 'Dabagou', 'Dabagou,Dabagou Zhen,Horqin Youyi Qianqi,Ke''erqin Youyi Qianqi,Ke’erqin Youyi Qianqi,da ba gou,da ba gou zhen,ke er qin you yi qian qi,大坝沟,大坝沟镇,科尔沁右翼前旗', 46.0694600, 121.9163200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24931, 'Liuxiang', 'Liuxiang', 'Liuxiang,Liuxiang Jiedao,Yingze Qu,liu xiang,liu xiang jie dao,ying ze qu,柳巷,柳巷 街道,迎泽区', 37.8714300, 112.5605400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24932, 'Julun', 'Julun', 'Julun,Julun Jiedao,Xinghualing Qu,ju lun,ju lun jie dao,xing hua ling qu,巨轮,巨轮街道,杏花岭区', 37.9074000, 112.5577400, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24933, 'Qianfeng', 'Qianfeng', 'Qianfeng,Qianfeng Jiedao,Wanbailin Qu,qian feng,qian feng jie dao,wan bai lin qu,万柏林区,千峰,千峰街道', 37.8494200, 112.5208100, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24934, 'Dongqu', 'Dongqu', 'Dongqu,Dongqu Jiedao,Gujiao Shi,dong qu,dong qu jie dao,gu jiao shi,东曲,东曲街道,古交市', 37.9202100, 112.2001800, 'CN', '2012-01-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24935, 'Bala Ga’er Gaole', 'Bala Ga''er Gaole', 'Bala Ga''er Gaole,Bala Ga''er Gaole Zhen,Bala Ga’er Gaole,Bala Ga’er Gaole Zhen,Xi Ujimqin Qi,Xiwuzhumuqin Qi,ba la ga er gao lei,ba la ga er gao lei zhen,xi wu zhu mu qin qi,巴拉嘎尔高勒,巴拉嘎尔高勒镇,西乌珠穆沁旗', 44.5914900, 117.6237000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24936, 'Bieligutai', 'Bieligutai', 'Abag Qi,Abaga Qi,Bieligutai,Bieligutai Zhen,a ba ga qi,bie li gu tai,bie li gu tai zhen,别力古台,别力古台镇,阿巴嘎旗', 44.0303000, 114.9803600, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24937, 'Tianjiao', 'Tianjiao', 'Dongsheng Qu,Tianjiao,Tianjiao Jiedao,dong sheng qu,tian jiao,tian jiao jie dao,东胜区,天骄,天骄街道', 39.8255300, 109.9995300, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24938, 'Heping', 'Heping', 'Heping,Heping Jiedao,Ulanhot Shi,Wulanhaote Shi,he ping,he ping jie dao,wu lan hao te shi,乌兰浩特市,和平,和平街道', 46.0862600, 122.0770800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24939, 'Mositai', 'Mositai', 'Huolin Gol,Huolinguole Shi,Mositai,Mositai Jiedao,huo lin guo lei shi,mo si tai,mo si tai jie dao,莫斯台,莫斯台街道,霍林郭勒市', 45.5363200, 119.6697200, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24940, 'Shangdu', 'Shangdu', 'Shangdu,Shangdu Zhen,Zhenglan Qi,shang dou,shang dou zhen,zheng lan qi,上都,上都镇,正蓝旗', 42.2500500, 116.0079800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24941, 'Wenquan', 'Wenquan', 'A''ershan Shi,Arxan,A’ershan Shi,Wenquan,Wenquan Jiedao,YIE,a er shan shi,wen quan,wen quan jie dao,温泉,温泉街道,阿尔山市', 47.1756000, 119.9480900, 'CN', '2017-03-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24942, 'Tongyangdao', 'Tongyangdao', 'Baiyun''ebo Kuangqu,Baiyun’ebo Kuangqu,Bayan Obo,Tongyangdao,Tongyangdao Jiedao,bai yun e bo,bai yun e bo kuang qu,tong yang dao,tong yang dao jie dao,白云鄂博,白云鄂博矿区,通阳道,通阳道街道', 41.7703100, 109.9698700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24943, 'Bayinsai', 'Bayinsai', 'Bayinsai,Bayinsai Jiedao,Wuda Qu,ba yin sai,ba yin sai jie dao,wu da qu,乌达区,巴音赛,巴音赛街道', 39.5002200, 106.7202100, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24944, 'Xingong', 'Xingong', 'Xingong,Xingong Jiedao,Yakeshi Shi,xin gong,xin gong jie dao,ya ke shi shi,新工,新工街道,牙克石市', 49.2903100, 120.7060900, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24945, 'Xiritala', 'Xiritala', 'Xilin Hot,Xilinhaote Shi,Xiritala,Xiritala Jiedao,xi lin hao te,xi lin hao te shi,xi ri ta la,xi ri ta la jie dao,希日塔拉,希日塔拉街道,锡林浩特,锡林浩特市', 43.9388900, 116.0702100, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24946, 'Xinghua', 'Xinghua', 'Xinghua,Xinghua Jiedao,Zhalantun Shi,xing hua,xing hua jie dao,zha lan tun shi,兴华,兴华街道,扎兰屯市', 48.0144900, 122.6983900, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24947, 'Tarma', 'Tarma', 'Lere,Ta''erma,Ta''erma Xiang,Tarma,Ta’erma,Ta’erma Xiang,lei re,ta er ma,ta er ma xiang,勒惹,塔尔玛,塔尔玛乡', 30.6817700, 89.1100300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24948, 'Xagqu', 'Xagqu', 'Bang''ousang,Bang’ousang,Xagqu,Xiaqu,Xiaqu Zhen,bang ou sang,xia qu,xia qu zhen,夏曲,夏曲镇,邦欧桑', 31.8077100, 92.8262900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24949, 'Xarma', 'Xarma', 'Xarma,Xiama,Xiama Xiang,xia ma,xia ma xiang,夏玛,夏玛乡', 30.7979200, 92.6812400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24950, 'Xagmakajor', 'Xagmakajor', 'Xagmakajor,Xiamakajiao,Xiamakajiu,Yare Qu,xia ma ka jiao,xia ma ka jiu,ya re qu,亚热区,夏玛咔久,夏玛喀角', 31.4944000, 82.3324000, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24951, 'Xarlung', 'Xarlung', 'Gongbujiangda Xian,Xarlung,Xialong,gong bu jiang da xian,xia long,峡龙,工布江达县', 29.9000000, 93.3000000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24952, 'Xomong', 'Xomong', 'Nakajue,Xiangmao,Xiangmao Xiang,Xomong,na ka jue,xiang mao,xiang mao xiang,纳喀觉,香茂,香茂乡', 31.0226000, 91.6742600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24953, 'Xamqu', 'Xamqu', 'Bangmuqie,Xamqu,Xiangqu,Xiangqu Xiang,bang mu qie,xiang qu,xiang qu xiang,邦木切,香曲,香曲乡', 31.4846000, 93.7884500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24954, 'Xiongzhang', 'Xiongzhang', 'Xiongzhang,Xiongzhang Xiang,Xoincheng,Xoinchêng,xiong zhang,xiong zhang xiang,雄章,雄章乡', 28.6176300, 89.3619700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24955, 'Xoixar', 'Xoixar', 'Cuona Xian,Xoixar,Xuexia,cuo na xian,xue xia,错那县,雪下', 27.9030000, 91.9030000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24956, 'Zhaxirabdain', 'Zhaxirabdain', 'Zhaxirabdain,Zhaxiraodeng,Zhaxiraodeng Xiang,zha xi rao deng,zha xi rao deng xiang,扎西绕登,扎西绕登乡', 29.2298300, 94.0644500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24957, 'Zhomda', 'Zhomda', 'Gurulangjie Qu,Zhomda,Zhongda,Zhongda Xiang,gu ru lang jie qu,zhong da,zhong da xiang,仲达,仲达乡,古如朗杰区', 29.0699900, 92.8314600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24958, 'Zhongzi', 'Zhongzi', 'Zhongze,Zhongzi,Zhongzi Xiang,Zhongzê,zhong zi,zhong zi xiang,重孜,重孜乡', 29.0226800, 89.4603200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24959, 'Naidong', 'Naidong', 'Chetang,Chethang,Naidong,Naidong Zhen,Nedong,Nêdong,Tse-tang,Tsethang,Zedang,Zetang,Zêtang,nai dong,nai dong zhen,ze dang,乃东,乃东镇,泽当', 29.2430100, 91.7723900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24960, 'Keluke', 'Keluke', 'Keluke,Keluke Zhen,ke lu ke,ke lu ke zhen,柯鲁柯,柯鲁柯镇', 37.3212900, 97.1345700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24961, 'Orong', 'Orong', 'Orong,Wolong,Wolong Zhen,wo long,wo long zhen,卧龙,卧龙镇', 29.1208000, 93.7152100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24962, 'Yag La', 'Yag La', 'Yag La,Yala,Yala Zhen,ya la,ya la zhen,亚拉,亚拉镇', 31.8946000, 93.7755900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24963, 'Yangxoi', 'Yangxoi', 'Shanzha Qu,Yangxiu,Yangxiu Xiang,Yangxoi,shan zha qu,yang xiu,yang xiu xiang,山扎区,羊秀,羊秀乡', 31.2099700, 93.9677000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24964, 'Yoiqag', 'Yoiqag', 'Gedeng''ema,Gedeng’ema,Yoiqag,Youqia,Youqia Xiang,ge deng e ma,you qia,you qia xiang,格登俄马,油恰,油恰乡', 30.6113600, 91.8593900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24965, 'Zangka', 'Zangka', 'Zanggai,Zanggai Xiang,Zangka,cang gai,cang gai xiang,藏改,藏改乡', 28.9996100, 89.5200300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24966, 'Zuobude', 'Zuobude', 'Zhobde,Zhobdê,Zuobude,Zuobude Xiang,zuo bu de,zuo bu de xiang,左布德,左布德乡', 28.0030000, 86.3030000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24967, 'Karru', 'Karru', 'Karru,Karu,Karu Xiang,ka ru,ka ru xiang,卡如,卡如乡', 29.3519300, 90.0940300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24968, 'Wanjia', 'Wanjia', 'Wanjia,Wanjia Xiang,wan jia,wan jia xiang,万家,万家乡', 29.9684100, 111.6952500, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24969, 'Zhangzhuangpu', 'Zhangzhuangpu', 'Zhangzhuangpu,Zhangzhuangpu Zhen,zhang zhuang pu,zhang zhuang pu zhen,章庄铺,章庄铺镇', 29.8939500, 111.9297300, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24970, 'Weishui', 'Weishui', 'Weishui,Weishui Zhen,wei shui,wei shui zhen,洈水,洈水镇', 29.9870900, 111.6114600, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24971, 'Chehuyuan', 'Chehuyuan', 'Chehuyuan,Chehuyuan Xiang,Jiaoyansi,che hu yuan,che hu yuan xiang,jiao yan si,交岩寺,车湖垸,车湖垸乡', 28.9570700, 111.5100700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24972, 'Ludishan', 'Ludishan', 'Ludishan,Ludishan Xiang,Xiongjiaping,lu di shan,lu di shan xiang,xiong jia ping,熊家坪,芦荻山,芦荻山乡', 29.0048800, 111.7354900, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24973, 'Danzhou', 'Danzhou', 'Danzhou,Danzhou Xiang,Jiajiesi,dan zhou,dan zhou xiang,jia jie si,丹洲,丹洲乡,夹街寺', 29.0096000, 111.6349400, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24974, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Xiang,Ganlusi,dong jiao,dong jiao xiang,gan lu si,东郊,东郊乡,甘露寺', 29.0210500, 111.7100700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24975, 'Dongjiang', 'Dongjiang', 'Dongjiang,Dongjiang Xiang,Qingnian Beilu,dong jiang,dong jiang xiang,qing nian bei lu,东江,东江乡,青年北路', 29.0340600, 111.7466400, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24976, 'Hucheng', 'Hucheng', 'Huajiekou,Hucheng,Hucheng Xiang,hu cheng,hu cheng xiang,hua jie kou,护城,护城乡,骅街口', 29.0416200, 111.6860600, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24977, 'Nanpinggang', 'Nanpinggang', 'Nanpinggang,Nanpinggang Xiang,nan ping gang,nan ping gang xiang,南坪岗,南坪岗乡', 29.0653100, 111.6852100, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24978, 'Anyu', 'Anyu', 'Anyu,Anyu Xiang,an yu,an yu xiang,安裕,安裕乡', 29.3758500, 112.0916800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24979, 'Anfeng', 'Anfeng', 'Anfeng,Anfeng Xiang,an feng,an feng xiang,安丰,安丰乡', 29.4177300, 112.0665300, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24980, 'Anning', 'Anning', 'Anning,Anning Xiang,an ning,an ning xiang,安凝,安凝乡', 29.5012900, 112.0731900, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24981, 'Jiashan', 'Jiashan', 'Jiashan,Jiashan Zhen,Yangping,jia shan,jia shan zhen,yang ping,夹山,夹山镇,杨坪', 29.5093700, 111.4385100, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24982, 'Erdu', 'Erdu', 'Erdu,Erdu Xiang,Zhongdu,er dou,er dou xiang,zhong du,中渡,二都,二都乡', 29.5908500, 111.4041800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24983, 'Lidong', 'Lidong', 'Dengjiatan,Lidong,Lidong Xiang,deng jia tan,li dong,li dong xiang,澧东,澧东乡,邓家滩', 29.6428600, 111.8221000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24984, 'Guanting', 'Guanting', 'Guanting,Guanting Xiang,Pengshipu,guan ting,guan ting xiang,peng shi pu,官亭,官亭乡,彭市铺', 29.7107400, 111.5446800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24985, 'Yiwan', 'Yiwan', 'Caijiapo,Yiwan,Yiwan Xiang,cai jia po,yi wan,yi wan xiang,宜万,宜万乡,蔡家坡', 29.8673500, 111.6814000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24986, 'Taiqing', 'Taiqing', 'Taiqing,Taiqing Xiang,Tanyu,tai qing,tai qing xiang,tan yu,太青,太青乡,探峪', 29.8753500, 111.3133600, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24987, 'Wangcheng', 'Wangcheng', 'Tonghuan,Wangcheng,Wangcheng Xiang,tong huan,wang cheng,wang cheng xiang,同欢,望城,望城乡', 29.4152500, 111.6500700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24988, 'Hucheng', 'Hucheng', 'Hucheng,Hucheng Xiang,hu cheng,hu cheng xiang,护城,护城乡', 29.0449700, 111.6587600, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24989, 'Zhufeng', 'Zhufeng', 'Zhufeng,Zhufeng Zhen,zhu feng,zhu feng zhen,祝丰,祝丰镇', 29.2108700, 111.9729200, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24990, 'Yuefeng', 'Yuefeng', 'Yuefeng,Yuefeng Zhen,yue feng,yue feng zhen,岳峰,岳峰镇', 26.0928400, 119.3193800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24991, 'Guxi', 'Guxi', 'Guxi,Guxi Jiedao,gu xi,gu xi jie dao,鼓西,鼓西街道', 26.0897100, 119.2843800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24992, 'Nanjie', 'Nanjie', 'Nanjie,Nanjie Jiedao,nan jie,nan jie jie dao,南街,南街街道', 26.0870000, 119.2900000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24993, 'Antai', 'Antai', 'Antai,Antai Jiedao,an tai,an tai jie dao,安泰,安泰街道', 26.0823000, 119.2934700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24994, 'Gudong', 'Gudong', 'Gudong,Gudong Jiedao,gu dong,gu dong jie dao,鼓东,鼓东街道', 26.0931800, 119.2962800, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24995, 'Wenquan', 'Wenquan', 'Wenquan,Wenquan Jiedao,wen quan,wen quan jie dao,温泉,温泉街道', 26.0999200, 119.3034300, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24996, 'Wufeng', 'Wufeng', 'Wufeng,Wufeng Jiedao,wu feng,wu feng jie dao,五凤,五凤街道', 26.1051800, 119.2784000, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24997, 'Huada', 'Huada', 'Huada,Huada Jiedao,hua da,hua da jie dao,华大,华大街道', 26.1007400, 119.2872400, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24998, 'Dongjie', 'Dongjie', 'Dongjie,Dongjie Jiedao,dong jie,dong jie jie dao,东街,东街街道', 26.0882300, 119.2944900, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(24999, 'Chayuan', 'Chayuan', 'Chayuan,Chayuan Jiedao,cha yuan,cha yuan jie dao,茶园,茶园街道', 26.1141700, 119.3150700, 'CN', '2012-01-22', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25000, 'Huaping', 'Huaping', 'Huaping,Huaping Zhen,hua ping,hua ping zhen,花坪,花坪镇', 25.0130100, 113.5728500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25001, 'Sicong', 'Sicong', 'Laohutian,Sicong,Sicong Xiang,lao hu tian,si cong,si cong xiang,思聪,思聪乡,老虎田', 26.8137100, 113.5438100, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25002, 'Mijiang', 'Mijiang', 'Mijiang,Mijiang Xiang,Nanshuizhou,mi jiang,mi jiang xiang,nan shui zhou,南水洲,洣江,洣江乡', 26.7921900, 113.5555200, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25003, 'Xiadong', 'Xiadong', 'Xiadong,Xiadong Xiang,Xiaoche,xia dong,xia dong xiang,xiao che,下东,下东乡,小车', 26.7741900, 113.5312200, 'CN', '2012-02-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25004, 'Dongji', 'Dongji', 'Dongji,dong ji,东极', 30.1959000, 122.6807000, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25005, 'Longqiu', 'Longqiu', 'Longqiu,Longqiu Zhen,long qiu,long qiu zhen,龙虬,龙虬镇', 32.8291900, 119.5127400, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25006, 'Situ', 'Situ', 'Situ,Situ Zhen,si tu,si tu zhen,司徒,司徒镇', 32.8885300, 119.6377800, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25007, 'Jiulonghu', 'Jiulonghu', 'Jiulonghu,jiu long hu,九龙湖', 30.0428100, 121.5603600, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25008, 'Xinshao', 'Xinshao', 'Xinshao,Xinshao Zhen,xin shao,xin shao zhen,新韶,新韶镇', 24.8222000, 113.6057700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25009, 'Yangshan', 'Yangshan', 'Yangshan,yang shan,洋山', 30.5941600, 122.0768500, 'CN', '2012-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25010, 'Xijiao', 'Xijiao', 'Xijiao,Xijiao Zhen,xi jiao,xi jiao zhen,西郊,西郊镇', 32.9630900, 119.7371500, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25011, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Zhen,cheng dong,cheng dong zhen,城东,城东镇', 32.9838600, 119.9133300, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25012, 'Shaoyang', 'Shaoyang', 'Shaoyang,Shaoyang Zhen,shao yang,shao yang zhen,邵阳,邵阳镇', 32.9233100, 119.8079200, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25013, 'Shaoyang', 'Shaoyang', 'Shaoyang,Xinghua Shi,shao yang,xing hua shi,兴化市,邵阳', 32.9295800, 119.8357600, 'CN', '2012-05-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25014, 'Huagang', 'Huagang', 'Huagang,Huagang Zhen,hua gang,hua gang zhen,华港,华港镇', 32.6102300, 119.8632800, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25015, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,cheng nan,cheng nan jie dao,城南,城南街道', 32.4699700, 119.9176900, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25016, 'Chengzhong', 'Chengzhong', 'Chengzhong,Chengzhong Jiedao,cheng zhong,cheng zhong jie dao,城中,城中街道', 32.4821300, 119.9130800, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25017, 'Chengxi', 'Chengxi', 'Chengxi,Chengxi Jiedao,cheng xi,cheng xi jie dao,城西,城西街道', 32.4943000, 119.8923600, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25018, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Jiedao,cheng bei,cheng bei jie dao,城北,城北街道', 32.5038500, 119.9164700, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25019, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 32.4991200, 119.9234300, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25020, 'Guyang', 'Guyang', 'Guyang,Guyang Zhen,gu yang,gu yang zhen,谷阳,谷阳镇', 32.1052900, 119.4390900, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25021, 'Guyang', 'Guyang', 'Dantu Qu,Guyang,dan tu qu,gu yang,丹徒区,谷阳', 32.1353800, 119.4420900, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25022, 'Zhengdonglu', 'Zhengdonglu', 'Jingkou Qu,Zhengdonglu,Zhengdonglu Jiedao,jing kou qu,zheng dong lu,zheng dong lu jie dao,京口区,正东路,正东路街道', 32.1927800, 119.4705000, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25023, 'Pingshan', 'Pingshan', 'Pingshan,Pingshan Xiang,ping shan,ping shan xiang,平山,平山乡', 32.4277000, 119.4045000, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25024, 'Shouxihu', 'Shouxihu', 'Shouxihu,Shouxihu Jiedao,Weiyang Qu,shou xi hu,shou xi hu jie dao,wei yang qu,瘦西湖,瘦西湖街道,维扬区', 32.4208900, 119.4043500, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25025, 'Hanshang', 'Hanshang', 'Hanjiang Qu,Hanshang,Hanshang Jiedao,han jiang qu,han shang,han shang jie dao,邗上,邗上街道,邗江区', 32.3774400, 119.3930200, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25026, 'Wenhe', 'Wenhe', 'Guangling Qu,Wenhe,Wenhe Jiedao,guang ling qu,wen he,wen he jie dao,广陵区,汶河,汶河街道', 32.3952300, 119.4268800, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25027, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Xiang,cheng bei,cheng bei xiang,城北,城北乡', 32.4216600, 119.4425100, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25028, 'Biancheng', 'Biancheng', 'Biancheng,Biancheng Zhen,bian cheng,bian cheng zhen,边城,边城镇', 32.0550500, 119.2994100, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25029, 'Wulaocun', 'Wulaocun', 'Baixia Qu,Wulaocun,Wulaocun Jiedao,bai xia qu,wu lao cun,wu lao cun jie dao,五老村,五老村街道,白下区', 32.0343700, 118.7957500, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25030, 'Qinhong', 'Qinhong', 'Qinhong,Qinhong Jiedao,Qinhuai Qu,qin hong,qin hong jie dao,qin huai qu,秦淮区,秦虹,秦虹街道', 32.0113500, 118.7965500, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25031, 'Binhu', 'Binhu', 'Binhu,Binhu Jiedao,Jianye Qu,bin hu,bin hu jie dao,jian ye qu,建邺区,滨湖,滨湖街道', 32.0300800, 118.7576800, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25032, 'Meiyuan Xincun', 'Meiyuan Xincun', 'Meiyuan Xincun,Meiyuan Xincun Jiedao,Xuanwu Qu,mei yuan xin cun,mei yuan xin cun jie dao,xuan wu qu,梅园新村,梅园新村街道,玄武区', 32.0542100, 118.7927500, 'CN', '2014-03-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25033, 'Dingshan', 'Dingshan', 'Dingshan,Dingshan Jiedao,ding shan,ding shan jie dao,顶山,顶山街道', 32.1157500, 118.6811000, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25034, 'Xiongzhou', 'Xiongzhou', 'Liuhe Qu,Xiongxhou Jiedao,Xiongzhou,liu he qu,xiong zhou,xiong zhou jie dao,六合区,雄州,雄州街道', 32.3435900, 118.8498600, 'CN', '2012-05-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25035, 'Zhenziliang', 'Zhenziliang', 'Zhenziliang,Zhenziliang Xiang,zhen zi liang,zhen zi liang xiang,镇子梁,镇子梁乡', 39.5714200, 113.2745300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25036, 'Shangwu', 'Shangwu', 'Shangwu,Shangwu Zhen,shang wu,shang wu zhen,尚武,尚武镇', 32.2184000, 106.1433900, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25037, 'Tian’an', 'Tian''an', 'Tian''an,Tian''an Xiang,Tian’an,Tian’an Xiang,tian an,tian an xiang,天安,天安乡', 19.0198700, 108.9088400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25038, 'Moushan', 'Moushan', 'Moushan,Moushan Zhen,mou shan,mou shan zhen,牟山,牟山镇', 30.0751400, 120.9902700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25039, 'Hefu', 'Hefu', 'Hefu,Hefu Zhen,he fu,he fu zhen,和孚,和孚镇', 30.7801600, 120.1580700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25040, 'Xihu', 'Xihu', 'Xihu,Xihu Jiedao,Xihu Xiang,xi hu,xi hu jie dao,xi hu xiang,西湖,西湖乡,西湖街道', 30.2416400, 120.1188700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25041, 'Duanshen', 'Duanshen', 'Duanshen,Duanshen Xiang,duan shen,duan shen xiang,段莘,段莘乡', 29.5059300, 117.9707600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25042, 'Feijiantan', 'Feijiantan', 'Feijiantan,Feijiantan Xiang,fei jian tan,fei jian tan xiang,飞剑潭,飞剑潭乡', 27.8964600, 114.1145700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25043, 'Jizhou', 'Jizhou', 'Jizhou,Jizhou Qu,ji zhou,ji zhou qu,吉州,吉州区', 27.1440900, 114.9959600, 'CN', '2013-06-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25044, 'Gaotian', 'Gaotian', 'Gaotian,Gaotian Xiang,Ouxi Xiang,gao tian,gao tian xiang,ou xi xiang,欧溪乡,高田,高田乡', 27.7627800, 116.8483400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25045, 'Luowan', 'Luowan', 'Luowan,Luowan Xiang,luo wan,luo wan xiang,罗湾,罗湾乡', 28.9464500, 115.0684200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25046, 'Xisaishan', 'Xisaishan', 'Xisaishan,Xisaishan Jiedao,xi sai shan,xi sai shan jie dao,西塞山,西塞山街道', 30.2104100, 115.1686600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25047, 'Sheshan', 'Sheshan', 'Sheshan,Sheshan Zhen,she shan,she shan zhen,佘山,佘山镇', 31.1011100, 121.1793800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25048, 'Paicun', 'Paicun', 'Duoxiong,Pai Zhen,Paicun,duo xiong,pai cun,pai zhen,多雄,派村,派镇', 29.5081800, 94.8479800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25049, 'Pozhang', 'Pozhang', 'Pozhang,Pozhang Xiang,Xiangyang,po zhang,po zhang xiang,xiang yang,向阳,颇章,颇章乡', 29.1138100, 91.8339300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25050, 'Chaqi', 'Chaqi', 'Chaqi,Congdui,Zhaqi,Zhaqi Xiang,cong dui,zha qi,zha qi xiang,丛堆,扎其乡,札其', 29.2518600, 91.4020700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25051, 'Zangkaxa', 'Zangkaxa', 'Duoma Qu,Zanggaxia,Zangkaxa,cang ga xia,duo ma qu,多玛区,藏嘎夏', 33.7129400, 80.3768200, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25052, 'Gulou', 'Gulou', 'Fuzhou Shi,Gulou,Gulou Qu,fu zhou shi,gu lou,gu lou qu,福州市,鼓楼,鼓楼区', 26.0865300, 119.2979800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25053, 'Gouqi', 'Gouqi', 'Gouqi,gou qi,枸杞', 30.7117400, 122.7693500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25054, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Jiedao,qing long,qing long jie dao,青龙,青龙街道', 31.7866900, 120.0068300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25055, 'Yugang', 'Yugang', 'Yugang,Yugang Jiedao,yu gang,yu gang jie dao,渔港,渔港街道', 31.5446900, 120.1922300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25056, 'Nanchansi', 'Nanchansi', 'Nanchang Qu,Nanchansi,Nanchansi Jiedao,nan chan si,nan chan si jie dao,nan zhang qu,南禅寺,南禅寺街道,南长区', 31.5624200, 120.3002100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25057, 'Beidajie', 'Beidajie', 'Beidajie,Beidajie Jiedao,Beitang Qu,bei da jie,bei da jie jie dao,bei tang qu,北塘区,北大街,北大街街道', 31.5852800, 120.2900400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25058, 'Changjianglu', 'Changjianglu', 'Changjianglu,Changjianglu Jiedao,zhang jiang lu,zhang jiang lu jie dao,长江路,长江路街道', 31.5653500, 120.3421300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25059, 'Lihu', 'Lihu', 'Lihu,Lihu Jiedao,li hu,li hu jie dao,蠡湖,蠡湖街道', 31.5256900, 120.2628200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25060, 'Wangzhuang', 'Wangzhuang', 'Wangzhuang,Wangzhuang Jiedao,wang zhuang,wang zhuang jie dao,旺庄,旺庄街道', 31.5447700, 120.3485600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25061, 'Chong’ansi', 'Chong''ansi', 'Chong''an Qu,Chong''ansi,Chong''ansi Jiedao,Chong’an Qu,Chong’ansi,Chong’ansi Jiedao,chong an qu,chong an si,chong an si jie dao,崇安区,崇安寺,崇安寺街道', 31.5798700, 120.2951800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25062, 'Binhu', 'Binhu', 'Binhu,Binhu Jiedao,bin hu,bin hu jie dao,滨湖,滨湖街道', 31.4332900, 120.2605000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25063, 'Xuxiake', 'Xuxiake', 'Xuxiake,Xuxiake Zhen,xu xia ke,xu xia ke zhen,徐霞客,徐霞客镇', 31.7623600, 120.3374100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25064, 'Jingang', 'Jingang', 'Jingang,Jingang Zhen,jin gang,jin gang zhen,金港,金港镇', 31.9552400, 120.4007800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25065, 'Shanghu', 'Shanghu', 'Shanghu,Shanghu Zhen,shang hu,shang hu zhen,尚湖,尚湖镇', 31.6691700, 120.6279700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25066, 'Jinxi', 'Jinxi', 'Jinxi,Jinxi Zhen,jin xi,jin xi zhen,锦溪,锦溪镇', 31.1793000, 120.8933000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25067, 'Songlong', 'Songlong', 'Songlong,Songlong Zhen,Wujiang Shi,song long,song long zhen,wu jiang shi,吴江市,松隆,松隆镇', 31.1624000, 120.6384000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25068, 'Fenhu', 'Fenhu', 'Fenhu,Fenhu Zhen,fen hu,fen hu zhen,汾湖,汾湖镇', 31.0135200, 120.8369600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25069, 'Yangdenghu', 'Yangdenghu', 'Yangdenghu,Yangdenghu Zhen,yang cheng hu,yang cheng hu zhen,阳澄湖,阳澄湖镇', 31.4935800, 120.7235000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25070, 'Yuanhe', 'Yuanhe', 'Xiangcheng Qu,Yuanhe,Yuanhe Jiedao,xiang cheng qu,yuan he,yuan he jie dao,元和,元和街道,相城区', 31.3992900, 120.6144500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25071, 'Xiangshan', 'Xiangshan', 'Xiangshan,Xiangshan Jiedao,xiang shan,xiang shan jie dao,香山,香山街道', 31.2324000, 120.3980300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25072, 'Loufeng', 'Loufeng', 'Loufeng,Loufeng Zhen,lou feng,lou feng zhen,娄葑,娄葑镇', 31.2906800, 120.6587200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25073, 'Baiyangwan', 'Baiyangwan', 'Baiyangwan,Baiyangwan Jiedao,bai yang wan,bai yang wan jie dao,白洋湾,白洋湾街道', 31.3480200, 120.5422200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25074, 'Shishan', 'Shishan', 'Huqiu Qu,Shishan,Shishan Jiedao,hu qiu qu,shi shan,shi shan jie dao,狮山,狮山街道,虎丘区', 31.2988300, 120.5651600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25075, 'Shuangta', 'Shuangta', 'Canglang Qu,Shuangta,Shuangta Jiedao,cang lang qu,shuang ta,shuang ta jie dao,双塔,双塔街道,沧浪区', 31.3040800, 120.6296800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25076, 'Pingjianglu', 'Pingjianglu', 'Pingjiang Qu,Pingjianglu,Pingjianglu Jiedao,ping jiang lu,ping jiang lu jie dao,ping jiang qu,平江区,平江路,平江路街道', 31.3146900, 120.6297800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25077, 'Shilu', 'Shilu', 'Jinchang Qu,Shilu,Shilu Jiedao,jin chang qu,shi lu,shi lu jie dao,石路,石路街道,金阊区', 31.3116900, 120.5940900, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25078, 'Xiaguo', 'Xiaguo', 'Xiaguo,Xiaguo Jiedao,xia guo,xia guo jie dao,下郭,下郭街道', 21.6391200, 110.6323500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25079, 'Yangqiao', 'Yangqiao', 'Yangqiao,Yangqiao Zhen,yang qiao,yang qiao zhen,杨侨,杨侨镇', 23.4443600, 114.4796700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25080, 'Xinmin', 'Xinmin', 'Xinmin,Xinmin Zhen,xin min,xin min zhen,新民,新民镇', 21.5253500, 110.1953100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25081, 'Suidong', 'Suidong', 'Suidong,Suidong Jiedao,sui dong,sui dong jie dao,穗东,穗东街道', 23.0845800, 113.5063400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25082, 'Lilian', 'Lilian', 'Lilian,Lilian Jiedao,li lian,li lian jie dao,荔联,荔联街道', 23.1168900, 113.5409600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25083, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Jiedao,hong shan,hong shan jie dao,红山,红山街道', 23.1025300, 113.4658100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25084, 'Yongping', 'Yongping', 'Yongping,Yongping Jiedao,yong ping,yong ping jie dao,永平,永平街道', 23.2333400, 113.3010700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25085, 'Huangshi', 'Huangshi', 'Huangshi,Huangshi Jiedao,huang shi,huang shi jie dao,黄石,黄石街道', 23.2096900, 113.2632800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25086, 'Tongde', 'Tongde', 'Tongde,Tongde Jiedao,tong de,tong de jie dao,同德,同德街道', 23.1678800, 113.2387400, 'CN', '2014-06-27', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25087, 'Jiulong', 'Jiulong', 'Jiulong,Jiulong Zhen,jiu long,jiu long zhen,九龙,九龙镇', 23.3622100, 113.5113300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25088, 'Junhe', 'Junhe', 'Junhe,Junhe Jiedao,jun he,jun he jie dao,均禾,均禾街道', 23.2594800, 113.2543200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25089, 'Huadi', 'Huadi', 'Huadi,Huadi Jiedao,hua de,hua de jie dao,花地,花地街道', 23.0977200, 113.2223600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25090, 'Dongsha', 'Dongsha', 'Dongsha,Dongsha Jiedao,dong sha,dong sha jie dao,东沙,东沙街道', 23.0675100, 113.2495200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25091, 'Changxing', 'Changxing', 'Changxing,Changxing Jiedao,zhang xing,zhang xing jie dao,长兴,长兴街道', 23.1783700, 113.3465200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25092, 'Longdong', 'Longdong', 'Longdong,Longdong Jiedao,long dong,long dong jie dao,龙洞,龙洞街道', 23.2005400, 113.3720200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25093, 'Huangcun', 'Huangcun', 'Huangcun,Huangcun Jiedao,huang cun,huang cun jie dao,黄村,黄村街道', 23.1290400, 113.4077700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25094, 'Lianzhou', 'Lianzhou', 'Lianzhou,Lianzhou Zhen,lian zhou,lian zhou zhen,莲洲,莲洲镇', 22.3186500, 113.2072800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25095, 'Zhenshan', 'Zhenshan', 'Zhenshan,Zhenshan Jiedao,zhen shan,zhen shan jie dao,贞山,贞山街道', 23.3358100, 112.6748300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25096, 'Jiangnan', 'Jiangnan', 'Jiangnan,Jiangnan Jiedao,jiang nan,jiang nan jie dao,江南,江南街道', 22.5913100, 113.0967200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25097, 'Jiaobei', 'Jiaobei', 'Jiaobei,Jiaobei Jiedao,jiao bei,jiao bei jie dao,滘北,滘北街道', 22.5965300, 113.1026600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25098, 'Jiaotou', 'Jiaotou', 'Jiaotou,Jiaotou Jiedao,jiao tou,jiao tou jie dao,滘头,滘头街道', 22.5749200, 113.0929200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25099, 'Wushan', 'Wushan', 'Wushan,Wushan Jiedao,wu shan,wu shan jie dao,五山,五山街道', 23.1588800, 113.3468400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25100, 'Tidong', 'Tidong', 'Tidong,Tidong Jiedao,di dong,di dong jie dao,堤东,堤东街道', 22.5953000, 113.0907800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25101, 'Canghou', 'Canghou', 'Canghou,Canghou Jiedao,cang hou,cang hou jie dao,仓後,仓後街道', 22.5912400, 113.0668600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25102, 'Baisha', 'Baisha', 'Baisha,Baisha Jiedao,bai sha,bai sha jie dao,白沙,白沙街道', 22.5760700, 113.0726400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25103, 'Zumiao', 'Zumiao', 'Zumiao,Zumiao Jiedao,zu miao,zu miao jie dao,祖庙,祖庙街道', 23.0254400, 113.1302600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25104, 'Longfeng', 'Longfeng', 'Longfeng,Longfeng Jiedao,long feng,long feng jie dao,龙丰,龙丰街道', 23.0731100, 114.3815700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25105, 'Liuzu', 'Liuzu', 'Liuzu,Liuzu Zhen,liu zu,liu zu zhen,六祖,六祖镇', 22.5982500, 112.2137600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25106, 'Nanshan', 'Nanshan', 'Nanshan,Nanshan Zhen,nan shan,nan shan zhen,南山,南山镇', 20.3126100, 110.1643900, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25107, 'Tangjiawan', 'Tangjiawan', 'Tangjiawan,Tangjiawan Zhen,tang jia wan,tang jia wan zhen,唐家湾,唐家湾镇', 22.3606200, 113.5962400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25108, 'Shuangdong', 'Shuangdong', 'Shuangdong,Shuangdong Jiedao,shuang dong,shuang dong jie dao,双东,双东街道', 22.7934800, 111.5959700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25109, 'Feilaixia', 'Feilaixia', 'Feilaixia,Feilaixia Zhen,fei lai xia,fei lai xia zhen,飞来峡,飞来峡镇', 23.7592600, 113.2350200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25110, 'Huangca', 'Huangca', 'Huangca,Huangca Zhen,huang ca,huang ca zhen,黄礤,黄礤镇', 24.1722200, 114.2236500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25111, 'Tangtuzhui', 'Tangtuzhui', 'Tangtuzhui,Tangtuzhui Zhen,tang zhui,tang zhui zhen,塘缀,塘缀镇', 21.4742200, 110.5378600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25112, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 23.0452300, 113.7853000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25113, 'Gongnong', 'Gongnong', 'Gongnong,Gongnong Jiedao,gong nong,gong nong jie dao,工农,工农街道', 21.1929300, 110.3948000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25114, 'Nanqiao', 'Nanqiao', 'Nanqiao,Nanqiao Jiedao,nan qiao,nan qiao jie dao,南桥,南桥街道', 21.2676000, 110.3591100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25115, 'Dalang', 'Dalang', 'Dalang,Dalang Jiedao,da lang,da lang jie dao,大浪,大浪街道', 22.6775300, 114.0086000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25116, 'Minzhi', 'Minzhi', 'Minzhi,Minzhi Jiedao,min zhi,min zhi jie dao,民治,民治街道', 22.6244700, 114.0376300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25117, 'Longcheng', 'Longcheng', 'Longcheng,Longcheng Jiedao,long cheng,long cheng jie dao,龙城,龙城街道', 22.7024100, 114.2152000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25118, 'Nandiao', 'Nandiao', 'Nandiao,Nandiao Jiedao,nan diao,nan diao jie dao,南调,南调街道', 21.2516900, 110.4458500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25119, 'Luopu', 'Luopu', 'Luopu,Luopu Jiedao,luo pu,luo pu jie dao,洛浦,洛浦街道', 23.0432000, 113.2902300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25120, 'Donghuan', 'Donghuan', 'Donghuan,Donghuan Jiedao,dong huan,dong huan jie dao,东环,东环街道', 22.9446600, 113.3677600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25121, 'Xiaoguwei', 'Xiaoguwei', 'Xiaoguwei,Xiaoguwei Jiedao,xiao gu wei,xiao gu wei jie dao,小谷围,小谷围街道', 23.0391500, 113.3627400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25122, 'Nanwan', 'Nanwan', 'Nanwan,Nanwan Jiedao,nan wan,nan wan jie dao,南湾,南湾街道', 22.5988200, 114.1304000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25123, 'Haishan', 'Haishan', 'Haishan,Haishan Jiedao,hai shan,hai shan jie dao,海山,海山街道', 22.5573300, 114.2117000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25124, 'Qiaonan', 'Qiaonan', 'Qiaonan,Qiaonan Jiedao,qiao nan,qiao nan jie dao,桥南,桥南街道', 22.9253700, 113.3666000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25125, 'Longwan', 'Longwan', 'Longwan,Longwan Zhen,long wan,long wan zhen,龙湾,龙湾镇', 22.6888400, 111.1868400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25126, 'Bingtang', 'Bingtang', 'Bingtang,Bingtang Zhen,bing tang,bing tang zhen,苪塘,苪塘镇', 22.6231200, 111.7054500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25127, 'Chengxi', 'Chengxi', 'Chengxi,Chengxi Jiedao,cheng xi,cheng xi jie dao,城西,城西街道', 22.7520700, 111.5261000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25128, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 22.7570300, 111.6023300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25129, 'Fucheng', 'Fucheng', 'Fucheng,Fucheng Jiedao,fu cheng,fu cheng jie dao,附城,附城街道', 22.7825600, 111.5704200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25130, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 23.0441000, 112.4747800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25131, 'Chengxi', 'Chengxi', 'Chengxi,Chengxi Jiedao,cheng xi,cheng xi jie dao,城西,城西街道', 23.0427900, 112.4502300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25132, 'Fengcheng', 'Fengcheng', 'Fengcheng,Fengcheng Jiedao,feng cheng,feng cheng jie dao,凤城,凤城街道', 23.7350600, 113.0302100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25133, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Jiedao,cheng bei,cheng bei jie dao,城北,城北街道', 23.0514600, 112.4580400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25134, 'Kengkou', 'Kengkou', 'Kengkou,Kengkou Jiedao,keng kou,keng kou jie dao,坑口,坑口街道', 23.1535700, 112.5583200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25135, 'Chuandao', 'Chuandao', 'Chuandao,Chuandao Zhen,chuan dao,chuan dao zhen,川岛,川岛镇', 21.8540300, 112.6798600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25136, 'Huanghua', 'Huanghua', 'Huanghua,Huanghua Zhen,huang hua,huang hua zhen,黄花,黄花镇', 24.2091700, 112.9009700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25137, 'HanHuang', 'HanHuang', 'HanHuang,HanHuang Zhen,han guang,han guang zhen,浛洸,浛洸镇', 24.2688900, 113.1247400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25138, 'Donghua', 'Donghua', 'Donghua,Donghua Zhen,dong hua,dong hua zhen,东华,东华镇', 24.2312200, 113.6654500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25139, 'Xiashitai', 'Xiashitai', 'Xiashitai,Xiashitai Zhen,xia shi tai,xia shi tai zhen,下石太,下石太镇', 24.0200900, 113.4221000, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25140, 'Hedong', 'Hedong', 'Hedong,Hedong Jiedao,he dong,he dong jie dao,河东,河东街道', 21.6670700, 110.9278500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25141, 'Hexi', 'Hexi', 'Hexi,Hexi Jiedao,he xi,he xi jie dao,河西,河西街道', 21.6819600, 110.9002500, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25142, 'Gaodi', 'Gaodi', 'Gaodi,Gaodi Jiedao,gao de,gao de jie dao,高地,高地街道', 21.4980600, 110.9846600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25143, 'Yuncheng', 'Yuncheng', 'Yuncheng,Yuncheng Jiedao,yun cheng,yun cheng jie dao,云城,云城街道', 22.9419900, 112.0493200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25144, 'Xihe', 'Xihe', 'Xihe,Xihe Zhen,xi he,xi he zhen,西河,西河镇', 24.8032300, 113.5611300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25145, 'Panzhou', 'Panzhou', 'Panzhou,Panzhou Jiedao,pan zhou,pan zhou jie dao,潘州,潘州街道', 21.9262600, 110.8492700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25146, 'Baoguang', 'Baoguang', 'Baoguang,Baoguang Jiedao,bao guang,bao guang jie dao,宝光,宝光街道', 21.9285600, 110.8388900, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25147, 'Yanghe', 'Yanghe', 'Yanghe,Yanghe Zhen,yang he,yang he zhen,杨和,杨和镇', 22.8682800, 112.7921300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25148, 'Genghe', 'Genghe', 'Genghe,Genghe Zhen,geng he,geng he zhen,更合,更合镇', 22.7835400, 112.5783100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25149, 'Longtian', 'Longtian', 'Longtian,Longtian Zhen,long tian,long tian zhen,龙田,龙田镇', 23.7507000, 114.2499200, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25150, 'Xili', 'Xili', 'Xili,Xili Jiedao,xi li,xi li jie dao,西丽,西丽街道', 22.5880900, 113.9478600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25151, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Jiedao,tao yuan,tao yuan jie dao,桃源,桃源街道', 22.5804100, 113.9612100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25152, 'Zengjiang', 'Zengjiang', 'Zengjiang,Zengjiang Jiedao,zeng jiang,zeng jiang jie dao,增江,增江街道', 23.3192100, 113.8600100, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25153, 'Dongqu', 'Dongqu', 'Dongqu,Dongqu Jiedao,dong qu,dong qu jie dao,东区,东区街道', 22.5169400, 113.4042600, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25154, 'Xiqu', 'Xiqu', 'Xiqu,Xiqu Jiedao,xi qu,xi qu jie dao,西区,西区街道', 22.5209800, 113.3565900, 'CN', '2012-12-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25155, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Jiedao,feng shan,feng shan jie dao,凤山,凤山街道', 22.7538400, 115.3508900, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25156, 'Longtian', 'Longtian', 'Longtian,Longtian Zhen,long tian,long tian zhen,陇田,陇田镇', 23.1701400, 116.5014700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25157, 'Gaopu', 'Gaopu', 'Gaopu,Gaopu Zhen,gao bu,gao bu zhen,高埔,高埔镇', 23.1566100, 115.9664800, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25158, 'Tiangan', 'Tiangan', 'Tiangan,Tiangan Jiedao,tian gan,tian gan jie dao,田乾,田乾街道', 22.7263200, 115.5082300, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25159, 'Hepu', 'Hepu', 'Hepu,Hepu Jiedao,he pu,he pu jie dao,河浦,河浦街道', 23.2924300, 116.6544400, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25160, 'Didou', 'Didou', 'Didou,Didou Zhen,de dou,de dou zhen,地都,地都镇', 23.4613600, 116.5659700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25161, 'Hengpi', 'Hengpi', 'Hengpi,Hengpi Zhen,heng bei,heng bei zhen,横陂,横陂镇', 23.8891600, 115.7216700, 'CN', '2012-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25162, 'Rezhe', 'Rezhe', 'Rezhe,Rezhe Zhen,re zhe,re zhe zhen,热柘,热柘镇', 24.5355300, 115.9804500, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25163, 'Nanqi', 'Nanqi', 'Nanqi,Nanqi Zhen,nan qi,nan qi zhen,南磜,南磜镇', 24.7246100, 116.3136800, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25164, 'Xiangcheng Qu', 'Xiangcheng Qu', '', 31.9366700, 111.9177800, 'CN', '2012-06-18', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25165, 'Ordos', 'Ordos', 'DSN,Erdos,Ordos,Ordos khot,e er duo si shi,eoeoldwosseu si,orudosu shi,Ордос,Ордос хот,オルドス市,鄂尔多斯市,어얼둬쓰 시', 39.6086000, 109.7815700, 'CN', '2017-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25166, 'Zhouwang', 'Zhouwang', 'Zhouwang,Zhouwang Zhen,zhou wang,zhou wang zhen,周王,周王镇', 30.7603800, 118.6823900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25167, 'Chixi', 'Chixi', 'Chixi,Chixi Zhen,chi xi,chi xi zhen,赤溪,赤溪镇', 21.9687000, 112.8922900, 'CN', '2012-08-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25168, 'Zari', 'Zari', 'Majidun,Zari,Zari Xiang,Zhari,ma ji dun,zha ri,zha ri xiang,扎日,扎日乡,马及墩', 28.6733800, 93.3690500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25169, 'Xingfu', 'Xingfu', 'Xingfu,Xingfu Xiang,xing fu,xing fu xiang,幸福,幸福乡', 32.0886100, 120.8355800, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25170, 'Haifeng', 'Haifeng', 'Haifeng,Haifeng Zhen,hai feng,hai feng zhen,海丰,海丰镇', 32.9028700, 120.4494200, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25171, 'Zhendong', 'Zhendong', 'Zhendong,Zhendong Zhen,qin dong,qin dong zhen,溱东,溱东镇', 32.6505500, 120.1534200, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25172, 'Dongsha', 'Dongsha', 'Dongsha,dong sha,东沙', 23.0659900, 113.2492900, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25173, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Zhen,cheng dong,cheng dong zhen,城东,城东镇', 32.5321100, 120.4999300, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25174, 'Sunzhuang', 'Sunzhuang', 'Sunzhuang,Sunzhuang Zhen,sun zhuang,sun zhuang zhen,孙庄,孙庄镇', 32.4383400, 120.3923600, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25175, 'Eshan', 'Eshan', 'Eshan,Eshan Shezuxiang,e shan,e shan she zu xiang,莪山,莪山畲族乡', 29.8010000, 119.5715700, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25176, 'Tongjia', 'Tongjia', 'Tongjia,Tongjia Xiang,tong jia,tong jia xiang,童家,童家乡', 29.4144500, 119.1441800, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25177, 'Qiubin', 'Qiubin', 'Qiubin,Qiubin Zhen,qiu bin,qiu bin zhen,秋滨,秋滨镇', 29.0734200, 119.6121500, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25178, 'Lanjiang', 'Lanjiang', 'Lanjiang,Lanjiang Jiedao,Lanxi Shi,lan jiang,lan jiang jie dao,lan xi shi,兰江,兰江街道,兰溪市', 29.2151100, 119.4612100, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25179, 'Chengzhong', 'Chengzhong', 'Chengzhong,Chengzhong Jiedao,Wucheng Qu,cheng zhong,cheng zhong jie dao,wu cheng qu,城中,城中街道,婺城区', 29.1064400, 119.6485500, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25180, 'Muyun', 'Muyun', 'Muyun,Muyun Shezu Xiang,mu yun,mu yun she zu xiang,穆云,穆云畲族乡', 27.0612500, 119.5414000, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25181, 'Sanbaishan', 'Sanbaishan', 'Sanbaishan,Sanbaishan Zhen,san bai shan,san bai shan zhen,三百山,三百山镇', 24.9507900, 115.3718900, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25182, 'Wenfeng', 'Wenfeng', 'Wenfeng,Wenfeng Xiang,wen feng,wen feng xiang,文峰,文峰乡', 24.9647100, 115.6335400, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25183, 'Jiefanglu', 'Jiefanglu', 'Huashan Qu,Jiefanglu,Jiefanglu Jiedao,hua shan qu,jie fang lu,jie fang lu jie dao,花山区,解放路,解放路街道', 31.7088600, 118.5090500, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25184, 'Xijiao', 'Xijiao', 'Xijiao,Xijiao Jiedao,xi jiao,xi jiao jie dao,西郊,西郊街道', 24.3148800, 116.1009800, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25185, 'Ningnan', 'Ningnan', 'Ningnan,Ningnan Jiedao,Yuhuatai Qu,ning nan,ning nan jie dao,yu hua tai qu,宁南,宁南街道,雨花台区', 31.9850400, 118.7814700, 'CN', '2012-08-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25186, 'Dongzaogang', 'Dongzaogang', 'Dongzaogang,Dongzaogang Zhen,dong zao gang,dong zao gang zhen,东灶港,东灶港镇', 32.0895000, 121.4866300, 'CN', '2012-09-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25187, 'Dashi', 'Dashi', 'Dashi,Dashi Jiedao,da shi,da shi jie dao,大石,大石街道', 23.0220700, 113.3045000, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25188, 'Yunxiang', 'Yunxiang', 'Yunxiang,Yunxiang Zhen,yun xiang,yun xiang zhen,云乡,云乡镇', 22.5653100, 112.7594200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25189, 'Dawan', 'Dawan', 'Dawan,Dawan Zhen,da wan,da wan zhen,大湾,大湾镇', 23.0450600, 112.3974700, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25190, 'Hualong', 'Hualong', 'Hualong,Hualong Zhen,hua long,hua long zhen,化龙,化龙镇', 23.0452500, 113.4488900, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25191, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Xiang,cheng jiao,cheng jiao xiang,城郊,城郊乡', 24.7234000, 116.7194300, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25192, 'Tianmuhu', 'Tianmuhu', 'Tianmuhu,Tianmuhu Zhen,tian mu hu,tian mu hu zhen,天目湖,天目湖镇', 31.3259300, 119.4390800, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25193, 'Chengbei', 'Chengbei', 'Changping Qu,Chengbei,Chengbei Jiedao,chang ping qu,cheng bei,cheng bei jie dao,城北,城北街道,昌平区', 40.2230300, 116.2458400, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25194, 'Chengnan', 'Chengnan', 'Chengnan,cheng nan,城南', 40.2083600, 116.2289200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25195, 'Huaibei', 'Huaibei', 'Huaibei,Huaibei Zhen,huai bei,huai bei zhen,怀北,怀北镇', 40.3917800, 116.6946300, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25196, 'Longshan', 'Longshan', 'Huairou Qu,Longshan,Longshan Jiedao,huai rou qu,long shan,long shan jie dao,怀柔区,龙山,龙山街道', 40.3201500, 116.6290900, 'CN', '2014-12-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25197, 'Dayu', 'Dayu', 'Dayu,Dayu Jiedao,Mentougou Qu,da yu,da yu jie dao,men tou gou qu,大峪,大峪街道,门头沟区', 39.9375000, 116.0966900, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25198, 'Guangning', 'Guangning', 'Guangning,Guangning Jiedao,guang ning,guang ning jie dao,广宁,广宁街道', 39.9270800, 116.1374200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25199, 'Babaoshan', 'Babaoshan', 'Babaoshan,Babaoshan Jiedao,ba bao shan,ba bao shan jie dao,八宝山,八宝山街道', 39.9006600, 116.2307500, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25200, 'Lugu', 'Lugu', 'Lugu,Lugu Jiedao,Shijingshan Qu,lu gu,lu gu jie dao,shi jing shan qu,石景山区,鲁谷,鲁谷街道', 39.8967200, 116.2203700, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25201, 'Jingshan', 'Jingshan', 'Dongcheng Qu,Jingshan,Jingshan Jiedao,dong cheng qu,jing shan,jing shan jie dao,东城区,景山,景山街道', 39.9252800, 116.4041100, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25202, 'Jinrongjie', 'Jinrongjie', 'Jinrongjie,Jinrongjie Jiedao,Xicheng Qu,jin rong jie,jin rong jie jie dao,xi cheng qu,西城区,金融街,金融街街道', 39.9122200, 116.3561500, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25203, 'Longtan', 'Longtan', 'Chongwen Qu,Longtan,Longtan Jiedao,chong wen qu,long tan,long tan jie dao,崇文区,龙潭,龙潭街道', 39.8837100, 116.4266800, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25204, 'Chaowai', 'Chaowai', 'Chaowai,Chaowai Jiedao,Chaoyang Qu,chao wai,chao wai jie dao,chao yang qu,朝外,朝外街道,朝阳区', 39.9181200, 116.4324200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25205, 'Gongchen', 'Gongchen', 'Fangshan Qu,Gongchen,Gongchen Jiedao,fang shan qu,gong chen,gong chen jie dao,房山区,拱辰,拱辰街道', 39.7279600, 116.1375600, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25206, 'Beiyuan', 'Beiyuan', 'Beiyuan,Beiyuan Jiedao,Tongzhou Qu,bei yuan,bei yuan jie dao,tong zhou qu,北苑,北苑街道,通州区', 39.9036200, 116.6466700, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25207, 'Shengli', 'Shengli', 'Shengli,Shengli Jiedao,Shunyi Qu,sheng li,sheng li jie dao,shun yi qu,胜利,胜利街道,顺义区', 40.1181800, 116.6429500, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25208, 'Xingfeng', 'Xingfeng', 'Daxing Qu,Xingfeng,Xingfeng Jiedao,da xing qu,xing feng,xing feng jie dao,兴丰,兴丰街道,大兴区', 39.7296500, 116.3366100, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25209, 'Binhe', 'Binhe', 'Binhe,Binhe Jiedao,Pinggu Qu,bin he,bin he jie dao,ping gu qu,平谷区,滨河,滨河街道', 40.1334700, 117.1085200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25210, 'Gulou', 'Gulou', 'Gulou,Gulou Jiedao,Miyun Qu,gu lou,gu lou jie dao,mi yun qu,密云区,鼓楼,鼓楼街道', 40.3699700, 116.8335200, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25211, 'Huaxiang', 'Huaxiang', 'Huaxiang,hua xiang,花乡', 39.8313900, 116.3252800, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25212, 'Xincun', 'Xincun', 'Xincun,Xincun Jiedao,xin cun,xin cun jie dao,新村,新村街道', 39.8389000, 116.3030800, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25213, 'Qinglonghu', 'Qinglonghu', 'Qinglonghu,Qinglonghu Zhen,qing long hu,qing long hu zhen,青龙湖,青龙湖镇', 39.7735600, 116.0342100, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25214, 'Jinhaihu', 'Jinhaihu', 'Jinhaihu,Jinhaihu Zhen,jin hai hu,jin hai hu zhen,金海湖,金海湖镇', 40.1810800, 117.2737600, 'CN', '2012-09-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25215, 'Huayang', 'Huayang', 'Huayang,Huayang Zhen,Jurong Shi,hua yang,hua yang zhen,ju rong shi,华阳,华阳镇,句容市', 31.9516500, 119.1628400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25216, 'Yunyang', 'Yunyang', 'Danyang Shi,Yunyang,Yunyang Zhen,dan yang shi,yun yang,yun yang zhen,丹阳市,云阳,云阳镇', 31.9956300, 119.5646300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25217, 'Liangpeng', 'Liangpeng', 'Liangpeng,Liangpeng Zhen,liang peng,liang peng zhen,凉棚,凉棚镇', 31.5714800, 119.7469000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25218, 'Yong’an', 'Yong''an', 'Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,yong an,yong an zhen,永安,永安镇', 31.6377700, 119.6339500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25219, 'Hehai', 'Hehai', 'Hehai,Hehai Jiedao,Xinbei Qu,he hai,he hai jie dao,xin bei qu,新北区,河海,河海街道', 31.8292100, 119.9778000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25220, 'Sanjiang', 'Sanjiang', 'Sanjiang,Sanjiang Jiedao,Sanjiang Qu,san jiang,san jiang jie dao,san jiang qu,三江,三江区,三江街道', 31.3481300, 118.3613200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25221, 'Xinfa', 'Xinfa', 'Beishantou,Xinfa,Xinfa Zhen,bei shan tou,xin fa,xin fa zhen,北山头,新发,新发镇', 31.2032600, 119.1037700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25222, 'Zuolan', 'Zuolan', 'Huoshidong,Zuolan,Zuolan Xiang,huo shi dong,zuo lan,zuo lan xiang,左岚,左岚乡,火石洞', 32.1478900, 108.4511200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25223, 'Gaonan', 'Gaonan', 'Gaonan,Gaonan Xiang,gao nan,gao nan xiang,高楠,高楠乡', 32.1328600, 108.5150400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25224, 'Beiping', 'Beiping', 'Beiping,Beiping Xiang,bei ping,bei ping xiang,北屏,北屏乡', 31.9738800, 108.7789700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25225, 'Lantian', 'Lantian', 'Lantian,Lantian Xiang,Lanxi,lan tian,lan tian xiang,lan xi,岚天,岚天乡,岚溪', 31.9240200, 108.8879000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25226, 'Heyu', 'Heyu', 'Heyu,Heyu Xiang,Zhongbazi,he yu,he yu xiang,zhong ba zi,中坝子,河鱼,河鱼乡', 31.8705800, 108.9492000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25227, 'Longtian', 'Longtian', 'Longtian,Longtian Xiang,Zhongbazi,long tian,long tian xiang,zhong ba zi,中坝子,龙田,龙田乡', 31.9742700, 108.6347400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25228, 'Gaoyan', 'Gaoyan', 'Dayuan,Gaoyan,Gaoyan Xiang,da yuan,gao yan,gao yan xiang,大园,高燕,高燕乡', 31.9356600, 108.6199000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25229, 'Shuanghe', 'Shuanghe', 'Shuanghe,Shuanghe Xiang,shuang he,shuang he xiang,双河,双河乡', 31.9421600, 108.3482100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25230, 'Zhouxi', 'Zhouxi', 'Zhouxi,Zhouxi Xiang,zhou xi,zhou xi xiang,周溪,周溪乡', 31.8166500, 108.4774100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25231, 'Jiwu', 'Jiwu', 'Jiwu,Jiwu Xiang,ji wu,ji wu xiang,鸡呜,鸡呜乡', 31.7144100, 108.5980700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25232, 'Xianyi', 'Xianyi', 'Xianjisi,Xianyi,Xianyi Xiang,xian ji si,xian yi,xian yi xiang,咸吉寺,咸宜,咸宜乡', 31.6893900, 108.6541400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25233, 'Houping', 'Houping', 'Houping,Houping Xiang,Yangjiaba,hou ping,hou ping xiang,yang jia ba,厚坪,厚坪乡,杨家坝', 31.7402100, 108.9365900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25234, 'Mingzhong', 'Mingzhong', 'Mingzhong,Mingzhong Xiang,ming zhong,ming zhong xiang,明中,明中乡', 31.7331300, 108.8151500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25235, 'Liaozi', 'Liaozi', 'Liaozi,Liaozi Xiang,Liaozikou,le zi kou,liao zi,liao zi xiang,了子口,廖子,廖子乡', 31.8137400, 108.6423000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25236, 'Fangyan', 'Fangyan', 'Fangyan,Fangyan Zhen,fang yan,fang yan zhen,方岩,方岩镇', 28.9384700, 120.1889000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25237, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Jiedao,xi cheng,xi cheng jie dao,西城,西城街道', 28.8957200, 120.0210300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25238, 'Jiangnan', 'Jiangnan', 'Jiangnan,Jiangnan Jiedao,jiang nan,jiang nan jie dao,江南,江南街道', 28.8911100, 120.0235800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25239, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,Yongkang Shi,dong cheng,dong cheng jie dao,yong kang shi,东城,东城街道,永康市', 28.8938100, 120.0402400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25240, 'Qiancang', 'Qiancang', 'Qiancang,Qiancang Zhen,qian cang,qian cang zhen,前仓,前仓镇', 28.8015800, 120.0883100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25241, 'Zhoushan', 'Zhoushan', 'Zhoushan,Zhoushan Zhen,zhou shan,zhou shan zhen,舟山,舟山镇', 28.8030000, 120.1742200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25242, 'Dadong', 'Dadong', 'Dadong,Dadong Xiang,Dingfengba,da dong,da dong xiang,ding feng ba,丁风坝,大洞,大洞乡', 31.5029400, 109.6179600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25243, 'Xujia', 'Xujia', 'Xujia,Xujia Zhen,xu jia,xu jia zhen,徐家,徐家镇', 31.6447600, 109.6713000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25244, 'Yulin', 'Yulin', 'Shangdimiao,Yulin,Yulin Xiang,shang di miao,yu lin,yu lin xiang,上帝庙,鱼鳞,鱼鳞乡', 31.6751700, 109.4863600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25245, 'Wulong', 'Wulong', 'Wanshougong,Wulong,Wulong Xiang,wan shou gong,wu long,wu long xiang,万寿宫,乌龙,乌龙乡', 31.6543900, 109.4308200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25246, 'Tucheng', 'Tucheng', 'Tangjiaba,Tucheng,Tucheng Xiang,tang jia ba,tu cheng,tu cheng xiang,土城,土城乡,汤家坝', 31.6340700, 109.2262400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25247, 'Changgui', 'Changgui', 'Changgui,Changgui Xiang,zhang gui,zhang gui xiang,长桂,长桂乡', 31.4940500, 109.3666600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25248, 'Shengli', 'Shengli', 'Qianchangba,Shengli,Shengli Xiang,qian chang ba,sheng li,sheng li xiang,堑场坝,胜利,胜利乡', 31.4341600, 109.4473300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25249, 'Fenghuang', 'Fenghuang', 'Fenghuang,Fenghuang Zhen,feng huang,feng huang zhen,凤凰,凤凰镇', 31.4016800, 109.5137700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25250, 'Tianxing', 'Tianxing', 'Shuangyuanxi,Tianxing,Tianxing Xiang,shuang yuan xi,tian xing,tian xing xiang,双源溪,天星,天星乡', 31.4708500, 109.5399000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25251, 'Chengxiang', 'Chengxiang', 'Chengxiang,Chengxiang Zhen,Wuxi Xian,cheng xiang,cheng xiang zhen,wu xi xian,城厢,城厢镇,巫溪县', 31.3986000, 109.6228400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25252, 'Zhonggang', 'Zhonggang', 'Zhonggang,Zhonggang Xiang,zhong gang,zhong gang xiang,中岗,中岗乡', 31.5240600, 108.8694000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25253, 'Tianba', 'Tianba', 'Gaolu,Tianba,Tianba Xiang,gao lu,tian ba,tian ba xiang,田坝,田坝乡,高炉', 31.4010800, 108.8631200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25254, 'Chaoyangdong', 'Chaoyangdong', 'Chaoyangdong,Chaoyangdong Xiang,chao yang dong,chao yang dong xiang,朝阳洞,朝阳洞乡', 31.4054900, 109.0574800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25255, 'Tangfang', 'Tangfang', 'Tangfang,Tangfang Xiang,tang fang,tang fang xiang,塘坊,塘坊乡', 31.3929200, 109.3091800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25256, 'Pulian', 'Pulian', 'Pulian,Pulian Xiang,Tanjiaping,pu lian,pu lian xiang,tan jia ping,蒲莲,蒲莲乡,谭家坪', 31.3008200, 109.5603500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25257, 'Fengling', 'Fengling', 'Fengling,Fengling Xiang,Tanjia Citang,feng ling,feng ling xiang,tan jia ci tang,峰灵,峰灵乡,谭家祠堂', 31.3194000, 109.5547400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25258, 'Huatai', 'Huatai', 'Huatai,Huatai Xiang,hua tai,hua tai xiang,花台,花台乡', 31.3053700, 109.6515200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25259, 'Tongcheng', 'Tongcheng', 'Gaobazi,Tongcheng,Tongcheng Xiang,gao ba zi,tong cheng,tong cheng xiang,通城,通城乡,高坝子', 31.3973300, 109.7350600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25260, 'Shuangyang', 'Shuangyang', 'Shuangyang,Shuangyang Xiang,Zhangjiaping,shuang yang,shuang yang xiang,zhang jia ping,双阳,双阳乡,张家坪', 31.4766000, 109.8230200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25261, 'Longjing', 'Longjing', 'Longjing,Longjing Xiang,long jing,long jing xiang,龙井,龙井乡', 31.0894300, 109.8872800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25262, 'Jianping', 'Jianping', 'Jianping,Jianping Xiang,jian ping,jian ping xiang,建平,建平乡', 31.0449000, 109.9248500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25263, 'Duping', 'Duping', 'Duping,Duping Xiang,du ping,du ping xiang,笃坪,笃坪乡', 30.9311700, 110.1041000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25264, 'Baolong', 'Baolong', 'Baolong,Baolong Zhen,bao long,bao long zhen,抱龙,抱龙镇', 30.9422900, 110.0058800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25265, 'Tonggu', 'Tonggu', 'Tonggu,Tonggu Zhen,tong gu,tong gu zhen,铜鼓,铜鼓镇', 30.9340900, 109.7311000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25266, 'Hongchun', 'Hongchun', 'Chunshubao,Hongchun,Hongchun Tujiazu Xiang,chun shu bao,hong chun,hong chun tu jia zu xiang,椿树包,红椿,红椿土家族乡', 30.8523900, 109.7121100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25267, 'Xinbi', 'Xinbi', 'Huangbijie,Xinbi,Xinbi Zhen,huang bi jie,xin bi,xin bi zhen,新碧,新碧镇,黄碧街', 28.7563300, 120.0878400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25268, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Xiang,Jingutang,cheng bei,cheng bei xiang,jin gu tang,今古塘,城北,城北乡', 28.7156200, 120.0695200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25269, 'Qili', 'Qili', 'Qili,Qili Xiang,qi li,qi li xiang,七里,七里乡', 28.6803300, 120.0587000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25270, 'Dongdu', 'Dongdu', 'Dongdu,Dongdu Zhen,dong du,dong du zhen,东渡,东渡镇', 28.6201900, 120.0541400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25271, 'Fangxi', 'Fangxi', 'Fangxi,Fangxi Xiang,fang xi,fang xi xiang,方溪,方溪乡', 28.5430800, 120.1398600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25272, 'Huyuan', 'Huyuan', 'Huyuan,Huyuan Xiang,Zhangcun,hu yuan,hu yuan xiang,zhang cun,章村,胡源,胡源乡', 28.6059200, 120.2016000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25273, 'Dongfang', 'Dongfang', 'Dongfang,Dongfang Zhen,dong fang,dong fang zhen,东方,东方镇', 28.7544800, 120.1653200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25274, 'Shuangxikou', 'Shuangxikou', 'Shuangxikou,Shuangxikou Xiang,shuang xi kou,shuang xi kou xiang,双溪口,双溪口乡', 28.6376500, 120.2575600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25275, 'Rongjiang', 'Rongjiang', 'Hongkengqiao,Rongjiang,Rongjiang Xiang,hong keng qiao,rong jiang,rong jiang xiang,洪坑桥,溶江,溶江乡', 28.6422000, 120.2239800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25276, 'Weixin', 'Weixin', 'Dingbutou,Weixin,Weixin Xiang,ding bu tou,wei xin,wei xin xiang,丁埠头,维新,维新乡', 28.9329000, 120.6138200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25277, 'Gao’er', 'Gao''er', 'Dazhekeng,Gao''er,Gao''er Xiang,Gao’er,Gao’er Xiang,da zhe keng,gao er,gao er xiang,大柘坑,高二,高二乡', 28.9235500, 120.5805100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25278, 'Guangdu', 'Guangdu', 'Guangdu,Guangdu Xiang,Shuikou,guang du,guang du xiang,shui kou,广度,广度乡,水口', 28.9521000, 120.7433200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25279, 'Anzhou', 'Anzhou', 'Anzhou,Anzhou Jiedao,an zhou,an zhou jie dao,安洲,安洲街道', 28.8770200, 120.7165200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25280, 'Fuying', 'Fuying', 'Fuying,Fuying Jiedao,Xianju Xian,fu ying,fu ying jie dao,xian ju xian,仙居县,福应,福应街道', 28.8626000, 120.7193000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25281, 'Nanfeng', 'Nanfeng', 'Nanfeng,Nanfeng Jiedao,nan feng,nan feng jie dao,南峰,南峰街道', 28.8585400, 120.7372400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25282, 'Shangzhang', 'Shangzhang', 'Shangzhang,Shangzhang Xiang,shang zhang,shang zhang xiang,上张,上张乡', 28.6670500, 120.7258100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25283, 'Danzhu', 'Danzhu', 'Danzhu,Danzhu Xiang,Shangren,dan zhu,dan zhu xiang,shang ren,尚仁,淡竹,淡竹乡', 28.6731400, 120.5715900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25284, 'Butou', 'Butou', 'Butou,Butou Zhen,bu tou,bu tou zhen,埠头,埠头镇', 28.7535600, 120.5201200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25285, 'Qiushan', 'Qiushan', 'Qiushan,Qiushan Xiang,Xikouhu,qiu shan,qiu shan xiang,xi kou hu,溪口湖,秋山,秋山乡', 28.6982400, 120.4163100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25286, 'Anling', 'Anling', 'Anling,Anling Xiang,Shangmenlou,an ling,an ling xiang,shang men lou,上门楼,安岭,安岭乡', 28.5646300, 120.3476400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25287, 'Dangyang', 'Dangyang', 'Dangyang,Dangyang Xiang,Reshuiba,dang yang,dang yang xiang,re shui ba,当阳,当阳乡,热水坝', 31.4056000, 109.9778100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25288, 'Miaotang', 'Miaotang', 'Miaotang,Miaotang Xiang,Wenchanggong,miao tang,miao tang xiang,wen chang gong,庙堂,庙堂乡,文昌宫', 31.3618700, 110.1022600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25289, 'Zhuxian', 'Zhuxian', 'Maoziya,Zhuxian,Zhuxian Xiang,mao zi ya,zhu xian,zhu xian xiang,猫子垭,竹贤,竹贤乡', 31.2828400, 110.0698300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25290, 'Sanxi', 'Sanxi', 'Sanxi,Sanxi Xiang,san xi,san xi xiang,三溪,三溪乡', 31.1320200, 110.0940300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25291, 'Liangping', 'Liangping', 'Hualishu,Liangping,Liangping Xiang,hua li shu,liang ping,liang ping xiang,两坪,两坪乡,花栗树', 31.1213600, 109.9690900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25292, 'Jinping', 'Jinping', 'Huanglongdong,Jinping,Jinping Xiang,huang long dong,jin ping,jin ping xiang,金坪,金坪乡,黄龙洞', 31.2084200, 109.9353700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25293, 'Pinghe', 'Pinghe', 'Pinghe,Pinghe Xiang,Yanchibang,ping he,ping he xiang,yan chi bang,平河,平河乡,燕翅塝', 31.2599900, 109.9476700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25294, 'Longxi', 'Longxi', 'Changxihe,Longxi,Longxi Zhen,long xi,long xi zhen,zhang xi he,长溪河,龙溪,龙溪镇', 31.3022300, 109.6355200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25295, 'Futian', 'Futian', 'Futian,Futian Zhen,Qiaotouxi,fu tian,fu tian zhen,qiao tou xi,桥头溪,福田,福田镇', 31.2220100, 109.7106800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25296, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Xiang,Ping’an,Ping’an Xiang,ping an,ping an xiang,平安,平安乡', 31.3496200, 109.1558900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25297, 'Dashu', 'Dashu', 'Dashu,Dashu Zhen,Sandonghe,da shu,da shu zhen,san dong he,三洞河,大树,大树镇', 31.2109300, 109.3215400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25298, 'Xinzheng', 'Xinzheng', 'Xinzheng,Xinzheng Xiang,xin zheng,xin zheng xiang,新政,新政乡', 31.2374300, 109.1106700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25299, 'Hongtu', 'Hongtu', 'Hongtu,Hongtu Xiang,hong tu,hong tu xiang,红土,红土乡', 31.1246400, 109.0974200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25300, 'Yanwan', 'Yanwan', 'Congmuling,Yanwan,Yanwan Xiang,cong mu ling,yan wan,yan wan xiang,丛木岭,岩湾,岩湾乡', 31.1957000, 109.5301000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25301, 'Kangle', 'Kangle', 'Guojiagou,Kangle,Kangle Zhen,guo jia gou,kang le,kang le zhen,康乐,康乐镇,郭家沟', 31.1127800, 109.4296400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25302, 'Fenhe', 'Fenhe', 'Fenhe,Fenhe Zhen,fen he,fen he zhen,汾河,汾河镇', 31.1372300, 109.5220600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25303, 'Baidi', 'Baidi', 'Baidi,Baidi Zhen,Huanhuaxi,bai di,bai di zhen,huan hua xi,浣花溪,白帝,白帝镇', 31.0576100, 109.5908800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25304, 'Caotang', 'Caotang', 'Caotang,Caotang Zhen,cao tang,cao tang zhen,草堂,草堂镇', 31.0902300, 109.6239700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25305, 'Yongle', 'Yongle', 'Yongle,Yongle Zhen,yong le,yong le zhen,永乐,永乐镇', 31.0104800, 109.5047900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25306, 'Jiagao', 'Jiagao', 'Jiagao,Jiagao Zhen,Wanjiazui,jia gao,jia gao zhen,wan jia zui,万家嘴,甲高,甲高镇', 30.8892200, 109.1759600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25307, 'Yunwu', 'Yunwu', 'Dongyuemiao,Yunwu,Yunwu Tujizu Xiang,dong yue miao,yun wu,yun wu tu jia zu xiang,东岳庙,云雾,云雾土家族乡', 30.6006000, 109.1253700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25308, 'Taihe', 'Taihe', 'Taihe,Taihe Tujiazu Xiang,tai he,tai he tu jia zu xiang,太和,太和土家族乡', 30.6415400, 109.2617500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25309, 'Longqiao', 'Longqiao', 'Longqiao,Longqiao Tujiazu Xiang,long qiao,long qiao tu jia zu xiang,龙桥,龙桥土家族乡', 30.6153000, 109.3644500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25310, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Zhen,qing long,qing long zhen,青龙,青龙镇', 30.7797700, 109.2564100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25311, 'Wuma', 'Wuma', 'Wuma,Wuma Xiang,wu ma,wu ma xiang,五马,五马乡', 30.8540500, 109.3764500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25312, 'Fengping', 'Fengping', 'Fengping,Fengping Xiang,Miaoba,feng ping,feng ping xiang,miao ba,冯坪,冯坪乡,庙坝', 30.8348100, 109.5049900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25313, 'Chang’an', 'Chang''an', 'Chang''an,Chang''an Tujiazu Xiang,Chang’an,Chang’an Tujiazu Xiang,zhang an,zhang an tu jia zu xiang,长安,长安土家族乡', 30.8308500, 109.5581200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25314, 'Nongba', 'Nongba', 'Nongba,Nongba Zhen,nong ba,nong ba zhen,农坝,农坝镇', 31.3777000, 108.7395800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25315, 'Houye', 'Houye', 'Houye,Houye Xiang,Xiniubei,hou ye,hou ye xiang,xi niu bei,后叶,后叶乡,犀牛背', 31.2888400, 108.6770200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25316, 'Luyang', 'Luyang', 'Longwangqiao,Luyang,Luyang Zhen,long wang qiao,lu yang,lu yang zhen,路阳,路阳镇,龙王桥', 31.2361300, 108.6897600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25317, 'Shuanglong', 'Shuanglong', 'Shuanghekou,Shuanglong,Shuanglong Xiang,shuang he kou,shuang long,shuang long xiang,双河口,双龙,双龙乡', 31.1719500, 108.6194400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25318, 'Quma', 'Quma', 'Quma,Quma Zhen,qu ma,qu ma zhen,渠马,渠马镇', 31.1348800, 108.6159700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25319, 'Ping’an', 'Ping''an', 'Ciguba,Ping''an,Ping''an Zhen,Ping’an,Ping’an Zhen,ci gu ba,ping an,ping an zhen,平安,平安镇,茨菇坝', 31.0357100, 108.5033600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25320, 'Bayang', 'Bayang', 'Bayang,Bayang Zhen,ba yang,ba yang zhen,巴阳,巴阳镇', 30.9331200, 108.5881300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25321, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Jiedao,qing long,qing long jie dao,青龙,青龙街道', 30.9330000, 108.6969900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25322, 'Renhe', 'Renhe', 'Muguba,Renhe,Renhe Zhen,mu gu ba,ren he,ren he zhen,人和,人和镇,木古坝', 30.9839400, 108.6603800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25323, 'Huangshi', 'Huangshi', 'Huangshi,Huangshi Zhen,huang shi,huang shi zhen,黄石,黄石镇', 31.0001500, 108.7185900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25324, 'Shuikou', 'Shuikou', 'Gongkuan,Shuikou,Shuikou Xiang,gong kuan,shui kou,shui kou xiang,公款,水口,水口乡', 31.0058800, 108.7639700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25325, 'Yuquan', 'Yuquan', 'Yuquan,Yuquan Zhen,yu quan,yu quan zhen,鱼泉,鱼泉镇', 31.2850300, 108.8494600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25326, 'Tuba', 'Tuba', 'Shiliangzi,Tuba,Tuba Xiang,shi liang zi,tu ba,tu ba xiang,土坝,土坝乡,石梁子', 31.3724700, 108.9077900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25327, 'Sangping', 'Sangping', 'Sangping,Sangping Zhen,sang ping,sang ping zhen,桑坪,桑坪镇', 31.2181700, 109.0442600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25328, 'Taiyang', 'Taiyang', 'Ranfang Wuji,Taiyang,Taiyang Xiang,ran fang wu ji,tai yang,tai yang xiang,太阳,太阳乡,染房屋基', 31.1634500, 109.0101700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25329, 'Shimen', 'Shimen', 'Shimen,Shimen Xiang,Wangjia''ao,Wangjia’ao,shi men,shi men xiang,wang jia ao,王家坳,石门,石门乡', 31.1322200, 109.0367000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25330, 'Donglu', 'Donglu', 'Donglu,Donglu Xiang,dong lu,dong lu xiang,洞鹿,洞鹿乡', 31.0891400, 109.0395700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25331, 'Pu’an', 'Pu''an', 'Ma''anshan,Ma’anshan,Pu''an,Pu''an Xiang,Pu’an,Pu’an Xiang,ma an shan,pu an,pu an xiang,普安,普安乡,马鞍山', 30.8688000, 108.9255800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25332, 'Baoping', 'Baoping', 'Baoping,Baoping Zhen,Xinchang,bao ping,bao ping zhen,xin chang,宝坪,宝坪镇,新场', 30.8837600, 108.8510200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25333, 'Fengwu', 'Fengwu', 'Erdeng,Fengwu,Fengwu Zhen,er deng,feng wu,feng wu zhen,二嶝,凤呜,凤呜镇', 30.8704900, 108.7481100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25334, 'Wailang', 'Wailang', 'Wailang,Wailang Xiang,wai lang,wai lang xiang,外朗,外朗乡', 30.7746700, 108.7661100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25335, 'Nixi', 'Nixi', 'Nixi,Nixi Xiang,ni xi,ni xi xiang,泥溪,泥溪乡', 30.7435800, 108.8804100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25336, 'Qingshui', 'Qingshui', 'Qingshui,Qingshui Tujiazu Xiang,qing shui,qing shui tu jia zu xiang,清水,清水土家族乡', 30.7050800, 108.9680900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25337, 'Yaoling', 'Yaoling', 'Daxingchang,Yaoling,Yaoling Xiang,da xing chang,yao ling,yao ling xiang,大兴场,耀灵,耀灵乡', 30.6584300, 108.8974300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25338, 'Piaocao', 'Piaocao', 'Piaocao,Piaocao Xiang,piao cao,piao cao xiang,票草,票草乡', 30.7912400, 108.9525400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25339, 'Baiquan', 'Baiquan', 'Baiquan,Baiquan Xiang,bai quan,bai quan xiang,白泉,白泉乡', 31.5944500, 108.7831600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25340, 'Guanmian', 'Guanmian', 'Guanmian,Guanmian Xiang,guan mian,guan mian xiang,关面,关面乡', 31.5517100, 108.6703900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25341, 'Manyue', 'Manyue', 'Dianziping,Manyue,Manyue Xiang,dian zi ping,man yue,man yue xiang,店子坪,满月,满月乡', 31.6194100, 108.5640600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25342, 'Heqian', 'Heqian', 'Heqian,Heqian Zhen,he qian,he qian zhen,和谦,和谦镇', 31.4149700, 108.4697300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25343, 'Maliu', 'Maliu', 'Maliu,Maliu Xiang,ma liu,ma liu xiang,麻柳,麻柳乡', 31.4342100, 108.2446300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25344, 'Heyan', 'Heyan', 'Heyan,Heyan Zhen,he yan,he yan zhen,河堰,河堰镇', 31.3563900, 108.6704500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25345, 'Baiqiao', 'Baiqiao', 'Baiqiao,Baiqiao Xiang,Yaodianzi,bai qiao,bai qiao xiang,yao dian zi,幺店子,白桥,白桥乡', 31.2819200, 108.5937500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25346, 'Guojia', 'Guojia', 'Guojia,Guojia Zhen,Huapingba,guo jia,guo jia zhen,hua ping ba,花坪坝,郭家,郭家镇', 31.2952800, 108.4810400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25347, 'Baihe', 'Baihe', 'Baihe,Baihe Jiedao,bai he,bai he jie dao,白鹤,白鹤街道', 31.2634800, 108.4637200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25348, 'Dunhao', 'Dunhao', 'Dunhao,Dunhao Zhen,Luwu,dui hao,dui hao zhen,lu wu,敦好,敦好镇,鹿呜', 31.3330100, 108.3582000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25349, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,gao qiao,gao qiao zhen,高桥,高桥镇', 31.3687600, 108.2421500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25350, 'Tianhe', 'Tianhe', 'Dahe,Tianhe,Tianhe Xiang,da he,tian he,tian he xiang,大和,天和,天和乡', 31.2876100, 108.1934100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25351, 'Sanhuikou', 'Sanhuikou', 'Dashibao,Sanhuikou,Sanhuikou Xiang,da shi bao,san hui kou,san hui kou xiang,三汇口,三汇口乡,大石包', 31.2550700, 108.1002500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25352, 'Yihe', 'Yihe', 'Yihe,Yihe Zhen,yi he,yi he zhen,义和,义和镇', 31.1573400, 108.0825600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25353, 'Jiulongshan', 'Jiulongshan', 'Guangfosi,Jiulongshan,Jiulongshan Zhen,guang fu si,jiu long shan,jiu long shan zhen,九龙山,九龙山镇,广佛寺', 31.1944500, 108.2509400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25354, 'Zhen’an', 'Zhen''an', 'Zhen''an,Zhen''an Zhen,Zhen’an,Zhen’an Zhen,zhen an,zhen an zhen,镇安,镇安镇', 31.1522600, 108.3167500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25355, 'Dade', 'Dade', 'Dade,Dade Xiang,Tudiya,da de,da de xiang,tu de ya,土地垭,大德,大德乡', 31.2128800, 108.3402600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25356, 'Fengle', 'Fengle', 'Fengle,Fengle Jiedao,feng le,feng le jie dao,丰乐,丰乐街道', 31.1897500, 108.4146100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25357, 'Zhendong', 'Zhendong', 'Zhendong,Zhendong Jiedao,zhen dong,zhen dong jie dao,镇东,镇东街道', 31.1851700, 108.3954400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25358, 'Houba', 'Houba', 'Houba,hou ba,厚坝', 31.2050900, 108.5062800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25359, 'Jinfeng', 'Jinfeng', 'Doutizi,Jinfeng,Jinfeng Xiang,dou ti zi,jin feng,jin feng xiang,金峰,金峰乡,陡梯子', 31.1935800, 108.5614600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25360, 'Qukou', 'Qukou', 'Qukou,Qukou Zhen,qu kou,qu kou zhen,渠口,渠口镇', 31.1380400, 108.4790700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25361, 'Changsha', 'Changsha', 'Changsha,Changsha Zhen,zhang sha,zhang sha zhen,长沙,长沙镇', 30.9999700, 108.3046300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25362, 'Nanmen', 'Nanmen', 'Nanmen,Nanmen Zhen,nan men,nan men zhen,南门,南门镇', 30.9618700, 108.2432700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25363, 'Wutong', 'Wutong', 'Wutong,Wutong Xiang,wu tong,wu tong xiang,五通,五通乡', 30.8896200, 108.0565800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25364, 'Wushan', 'Wushan', 'Wushan,Wushan Xiang,wu shan,wu shan xiang,巫山,巫山乡', 30.9372500, 107.9466000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25365, 'Nanya', 'Nanya', 'Nanya,Nanya Zhen,nan ya,nan ya zhen,南雅,南雅镇', 31.0843400, 108.0866400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25366, 'Zhuxi', 'Zhuxi', 'Zhuxi,Zhuxi Zhen,zhu xi,zhu xi zhen,竹溪,竹溪镇', 31.1244300, 108.2906500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25367, 'Yutou', 'Yutou', 'Yutou,Yutou Xiang,yu tou,yu tou xiang,屿头,屿头乡', 28.6422500, 121.0038100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25368, 'Pingtian', 'Pingtian', 'Pingtian,Pingtian Xiang,Tiandengyang,ping tian,ping tian xiang,tian deng yang,天灯垟,平田,平田乡', 28.5433100, 121.0721800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25369, 'Maoshe', 'Maoshe', 'Maoshe,Maoshe Xiang,mao she,mao she xiang,茅畲,茅畲乡', 28.5767300, 121.1232300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25370, 'Beiyang', 'Beiyang', 'Beiyang,Beiyang Zhen,bei yang,bei yang zhen,北洋,北洋镇', 28.6163700, 121.1070300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25371, 'Xinqian', 'Xinqian', 'Xinqian,Xinqian Jiedao,xin qian,xin qian jie dao,新前,新前街道', 28.6579400, 121.2081100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25372, 'Dengjiang', 'Dengjiang', 'Dengjiang,Dengjiang Jiedao,cheng jiang,cheng jiang jie dao,澄江,澄江街道', 28.6298000, 121.2039100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25373, 'Shabu', 'Shabu', 'Shabu,Shabu Zhen,sha bu,sha bu zhen,沙埠,沙埠镇', 28.5641200, 121.1941300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25374, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Jiedao,nan cheng,nan cheng jie dao,南城,南城街道', 28.6115600, 121.2632600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25375, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Jiedao,xi cheng,xi cheng jie dao,西城,西城街道', 28.6433300, 121.2572300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25376, 'Beicheng', 'Beicheng', 'Beicheng,Beicheng Jiedao,bei cheng,bei cheng jie dao,北城,北城街道', 28.6745100, 121.2579000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25377, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,Huangyan Qu,dong cheng,dong cheng jie dao,huang yan qu,东城,东城街道,黄岩区', 28.6473000, 121.2710600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25378, 'Lubei', 'Lubei', 'Lubei,Lubei Jiedao,Luqiao Qu,lu bei,lu bei jie dao,lu qiao qu,路北,路北街道,路桥区', 28.5863300, 121.3699800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25379, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Jiedao,bai yun,bai yun jie dao,白云,白云街道', 28.6782700, 121.4060400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25380, 'Taizhou', 'Taizhou', 'Tai-chiu-chhi,Taitsjou,Taizhou,Taizhou Shi,Taizhou i Zhejiang,Tajchzhou,Tchaj-cou,Tchaj-čou,Thai Chau,Thai Châu,Thoi-chu-su,Thòi-chû-sṳ,Tâi-chiu-chhī,tai zhou,tai zhou shi,taijeou si,Тайчжоу,تەيجۇ شەھىرى,台州,台州市,타이저우 시', 28.6626600, 121.4331200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25381, 'Huixi', 'Huixi', 'Huixi,Huixi Zhen,Juntou,hui xi,hui xi zhen,jun tou,汇溪,汇溪镇,浚头', 28.9599500, 121.2114800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25382, 'Yongfeng', 'Yongfeng', 'Liuxian,Yongfeng,Yongfeng Zhen,liu xian,yong feng,yong feng zhen,永丰,永丰镇,留贤', 28.8958100, 121.0684300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25383, 'Dayang', 'Dayang', 'Dayang,Dayang Jiedao,da yang,da yang jie dao,大洋,大洋街道', 28.8677300, 121.1525300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25384, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Jiedao,Linhai Qu,gu cheng,gu cheng jie dao,lin hai qu,临海区,古城,古城街道', 28.8485600, 121.1161000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25385, 'Jiangnan', 'Jiangnan', 'Jiangnan,Jiangnan Jiedao,jiang nan,jiang nan jie dao,江南,江南街道', 28.8311300, 121.1240300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25386, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Jiedao,cheng bei,cheng bei jie dao,城北,城北街道', 28.4423800, 121.3774100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25387, 'Chengxi', 'Chengxi', 'Chengxi,Chengxi Jiedao,cheng xi,cheng xi jie dao,城西,城西街道', 28.3842500, 121.3541100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25388, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 28.3998000, 121.3805500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25389, 'Taiping', 'Taiping', 'Taiping,Taiping Jiedao,Wenling Shi,tai ping,tai ping jie dao,wen ling shi,太平,太平街道,温岭市', 28.3687700, 121.3617100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25390, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Zhen,cheng nan,cheng nan zhen,城南,城南镇', 28.3264100, 121.3997600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25391, 'Zhiren', 'Zhiren', 'Lingdian,Zhiren,Zhiren Xiang,ling dian,zhi ren,zhi ren xiang,令店,智仁,智仁乡', 28.4914400, 121.1174300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25392, 'Yanhu', 'Yanhu', 'Danzaoli,Yanhu,Yanhu Xiang,dan zao li,yan hu,yan hu xiang,丹灶里,雁湖,雁湖乡', 28.3103400, 121.0041800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25393, 'Fuxi', 'Fuxi', 'Fuxi,Fuxi Xiang,Guwan,fu xi,fu xi xiang,gu wan,福溪,福溪乡,谷湾', 28.4646600, 121.0181700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25394, 'Zhugang', 'Zhugang', 'Yuhuan Xian,Zhugang,Zhugang Zhen,yu huan xian,zhu gang,zhu gang zhen,玉环县,珠港,珠港镇', 28.1383200, 121.2262100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25395, 'Houshan', 'Houshan', 'Houshan,Houshan Zhen,hou shan,hou shan zhen,后山,后山镇', 30.8258900, 108.0286600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25396, 'Sunjia', 'Sunjia', 'Sunjia,Sunjia Zhen,sun jia,sun jia zhen,孙家,孙家镇', 30.7297700, 108.0137400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25397, 'Lihe', 'Lihe', 'Lihe,Lihe Zhen,li he,li he zhen,李河,李河镇', 30.8160900, 108.2621600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25398, 'Tiefeng', 'Tiefeng', 'Tiefeng,Tiefeng Xiang,Zhongxinchang,tie feng,tie feng xiang,zhong xin chang,中心场,铁峰,铁峰乡', 30.9676800, 108.3953200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25399, 'Xiongjia', 'Xiongjia', 'Xiongjia,Xiongjia Zhen,xiong jia,xiong jia zhen,熊家,熊家镇', 30.9015500, 108.4336700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25400, 'Tiancheng', 'Tiancheng', 'Tangfangchang,Tiancheng,Tiancheng Zhen,tang fang chang,tian cheng,tian cheng zhen,塘坊场,天城,天城镇', 30.8676100, 108.3696900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25401, 'Zhoujiaba', 'Zhoujiaba', 'Zhoujiaba,Zhoujiaba Jiedao,zhou jia ba,zhou jia ba jie dao,周家坝,周家坝街道', 30.8434900, 108.3664200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25402, 'Taibai', 'Taibai', 'Taibai,Taibai Jiedao,tai bai,tai bai jie dao,太白,太白街道', 30.8248200, 108.3578300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25403, 'Gaoliang', 'Gaoliang', 'Gaoliang,Gaoliang Zhen,gao liang,gao liang zhen,高粱,高粱镇', 30.8239400, 108.3022400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25404, 'Zhonggulou', 'Zhonggulou', 'Zhonggulou,Zhonggulou Jiedao,zhong gu lou,zhong gu lou jie dao,钟鼓楼,钟鼓楼街道', 30.8249100, 108.3841300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25405, 'Jiuchi', 'Jiuchi', 'Jiuchi,Jiuchi Xiang,jiu chi,jiu chi xiang,九池,九池乡', 30.7983400, 108.3708900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25406, 'Pailou', 'Pailou', 'Pailou,Pailou Jiedao,pai lou,pai lou jie dao,牌楼,牌楼街道', 30.7964100, 108.3858000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25407, 'Chenjiaba', 'Chenjiaba', 'Chenjiaba,Chenjiaba Jiedao,Wanzhou Qu,chen jia ba,chen jia ba jie dao,wan zhou qu,万州区,陈家坝,陈家坝街道', 30.8138600, 108.3732600, 'CN', '2014-08-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25408, 'Bai’anba', 'Bai''anba', 'Bai''anba,Bai''anba Jiedao,Bai’anba,Bai’anba Jiedao,bai an ba,bai an ba jie dao,百安坝,百安坝街道', 30.7628300, 108.4371700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25409, 'Shuanghekou', 'Shuanghekou', 'Shuanghekou,Shuanghekou Jiedao,shuang he kou,shuang he kou jie dao,双河口,双河口街道', 30.7539800, 108.3695800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25410, 'Zhushan', 'Zhushan', 'Zhushan,Zhushan Xiang,zhu shan,zhu shan xiang,柱山,柱山乡', 30.7329400, 108.2741900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25411, 'Danzi', 'Danzi', 'Danzi,Danzi Zhen,dan zi,dan zi zhen,弹子,弹子镇', 30.8570000, 108.0059200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25412, 'Huangbo', 'Huangbo', 'Huangbo,Huangbo Xiang,huang bai,huang bai xiang,黄柏,黄柏乡', 30.9130200, 108.5824900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25413, 'Changtan', 'Changtan', 'Changtan,Changtan Zhen,zhang tan,zhang tan zhen,长滩,长滩镇', 30.7391600, 108.5997600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25414, 'Tai’an', 'Tai''an', 'Tai''an,Tai''an Zhen,Tai’an,Tai’an Zhen,Xinchang,tai an,tai an zhen,xin chang,太安,太安镇,新场', 30.7955400, 108.6592100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25415, 'Lishu', 'Lishu', 'Lishu,Lishu Xiang,li shu,li shu xiang,梨树,梨树乡', 30.6643800, 108.7475800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25416, 'Dibao', 'Dibao', 'Dibao,Dibao Tujiazu Xiang,de bao,de bao tu jia zu xiang,地宝,地宝土家族乡', 30.6582400, 108.8954000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25417, 'Henghe', 'Henghe', 'Henghe,Henghe Tujiazu Xiang,heng he,heng he tu jia zu xiang,恒合,恒合土家族乡', 30.5314700, 108.7541500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25418, 'Luotian', 'Luotian', 'Luotian,Luotian Zhen,luo tian,luo tian zhen,罗田,罗田镇', 30.5156000, 108.5594800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25419, 'Guocun', 'Guocun', 'Guocun,Guocun Zhen,guo cun,guo cun zhen,郭村,郭村镇', 30.5661800, 108.1693300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25420, 'Xinxiang', 'Xinxiang', 'Xinxiang,Xinxiang Zhen,xin xiang,xin xiang zhen,新乡,新乡镇', 30.4999900, 108.2727800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25421, 'Changping', 'Changping', 'Changping,Changping Xiang,Wuyangba,wu yang ba,zhang ping,zhang ping xiang,乌杨坝,长坪,长坪乡', 30.4427400, 108.2484100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25422, 'Rangdu', 'Rangdu', 'Rangdu,Rangdu Zhen,rang du,rang du zhen,瀼渡,瀼渡镇', 30.5929200, 108.3055800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25423, 'Longsha', 'Longsha', 'Longsha,Longsha Zhen,Shabaozi,long sha,long sha zhen,sha bao zi,沙包子,龙沙,龙沙镇', 30.6396500, 108.2370100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25424, 'Ganning', 'Ganning', 'Ganning,Ganning Zhen,gan ning,gan ning zhen,甘宁,甘宁镇', 30.6691100, 108.2805000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25425, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Zhen,gao feng,gao feng zhen,高峰,高峰镇', 30.7127700, 108.3418700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25426, 'Hezui', 'Hezui', 'Hezui,Hezui Xiang,he zui,he zui xiang,河嘴,河嘴乡', 30.5119700, 108.3985000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25427, 'Linxi', 'Linxi', 'Linxi,Linxi Zhen,lin xi,lin xi zhen,临溪,临溪镇', 30.4064400, 108.3502000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25428, 'Wangjia', 'Wangjia', 'Wangjia,Wangjia Xiang,wang jia,wang jia xiang,王家,王家乡', 30.3459900, 108.3120700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25429, 'Fengmu', 'Fengmu', 'Fengmu,Fengmu Xiang,feng mu,feng mu xiang,枫木,枫木乡', 30.2471200, 108.4833600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25430, 'Lengshui', 'Lengshui', 'Lengshui,Lengshui Xiang,leng shui,leng shui xiang,冷水,冷水乡', 30.1298800, 108.5463100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25431, 'Longsha', 'Longsha', 'Longsha,Longsha Zhen,Youzuofang,long sha,long sha zhen,you zha fang,油柞房,龙沙,龙沙镇', 30.1347100, 108.1839400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25432, 'Wanchao', 'Wanchao', 'Wanchao,Wanchao Xiang,wan chao,wan chao xiang,万朝,万朝乡', 30.1923500, 108.1470600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25433, 'Yuchi', 'Yuchi', 'Yuchi,Yuchi Zhen,yu chi,yu chi zhen,鱼池,鱼池镇', 30.2657700, 108.2235400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25434, 'Yanxi', 'Yanxi', 'Yanxi,Yanxi Zhen,yan xi,yan xi zhen,沿溪,沿溪镇', 30.2970500, 108.1268200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25435, 'Wangchang', 'Wangchang', 'Wangchang,Wangchang Zhen,wang chang,wang chang zhen,王场,王场镇', 30.3244100, 108.1821200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25436, 'Lichang', 'Lichang', 'Lichang,Lichang Xiang,li chang,li chang xiang,黎场,黎场乡', 30.3490900, 108.1412700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25437, 'Huangshui', 'Huangshui', 'Huangshui,Huangshui Zhen,huang shui,huang shui zhen,黄水,黄水镇', 30.2448700, 108.3895400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25438, 'Zhongyi', 'Zhongyi', 'Zhongyi,Zhongyi Xiang,zhong yi,zhong yi xiang,中益,中益乡', 30.0944900, 108.3309000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25439, 'Sanyi', 'Sanyi', 'Sanyi,Sanyi Xiang,san yi,san yi xiang,三益,三益乡', 30.1480100, 108.2762700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25440, 'Jinling', 'Jinling', 'Jinling,Jinling Xiang,jin ling,jin ling xiang,金铃,金铃乡', 29.9926500, 108.4951000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25441, 'Xinle', 'Xinle', 'Bangshang,Xinle,Xinle Xiang,bang shang,xin le,xin le xiang,塝上,新乐,新乐乡', 29.9267900, 108.4677000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25442, 'Xixin', 'Xixin', 'Xijiaoxi,Xixin,Xixin Xiang,xi jiao xi,xi xin,xi xin xiang,洗新,洗新乡,洗脚溪', 29.9189000, 108.3953300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25443, 'Huanghe', 'Huanghe', 'Huanghe,Huanghe Xiang,huang he,huang he xiang,黄鹤,黄鹤乡', 29.8400300, 108.3645200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25444, 'Longtan', 'Longtan', 'Longtan,Longtan Xiang,long tan,long tan xiang,龙谭,龙谭乡', 29.8391200, 108.2660900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25445, 'Sanxing', 'Sanxing', 'Sanxing,Sanxing Xiang,san xing,san xing xiang,三星,三星乡', 29.8966100, 108.1077600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25446, 'Xialu', 'Xialu', 'Xialu,Xialu Zhen,xia lu,xia lu zhen,下路,下路镇', 29.9416700, 108.0844200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25447, 'Liutang', 'Liutang', 'Liutang,Liutang Xiang,liu tang,liu tang xiang,六塘,六塘乡', 29.9324400, 108.2773300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25448, 'Jinji', 'Jinji', 'Jinji,Jinji Zhen,jin ji,jin ji zhen,金鸡,金鸡镇', 30.4772900, 107.7310400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25449, 'Tujing', 'Tujing', 'Tujing,Tujing Xiang,tu jing,tu jing xiang,涂井,涂井乡', 30.4135400, 108.1149300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25450, 'Yehe', 'Yehe', 'Yehe,Yehe Zhen,ye he,ye he zhen,野鹤,野鹤镇', 30.5369600, 108.1252000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25451, 'Jinsheng', 'Jinsheng', 'Jinsheng,Jinsheng Xiang,jin sheng,jin sheng xiang,金声,金声乡', 30.5253400, 107.9892200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25452, 'Xingfeng', 'Xingfeng', 'Xingfeng,Xingfeng Xiang,xing feng,xing feng xiang,兴峰,兴峰乡', 30.4655000, 107.9463500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25453, 'Huangjin', 'Huangjin', 'Huangjin,Huangjin Zhen,huang jin,huang jin zhen,黄金,黄金镇', 30.3786100, 108.0016000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25454, 'Dongxi', 'Dongxi', 'Dongxi,Dongxi Zhen,dong xi,dong xi zhen,东溪,东溪镇', 30.2718600, 108.0676200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25455, 'Mozi', 'Mozi', 'Mozi,Mozi Tujiazu Xiang,mo zi,mo zi tu jia zu xiang,磨子,磨子土家族乡', 30.1927600, 108.0622500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25456, 'Shizi', 'Shizi', 'Shizi,Shizi Xiang,shi zi,shi zi xiang,石子,石子乡', 30.1128800, 108.0488400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25457, 'Yangdu', 'Yangdu', 'Yangdu,Yangdu Zhen,yang du,yang du zhen,洋渡,洋渡镇', 30.1296600, 107.9281400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25458, 'Renjia', 'Renjia', 'Renjia,Renjia Zhen,ren jia,ren jia zhen,任家,任家镇', 30.1429500, 107.8738600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25459, 'Shanguang', 'Shanguang', 'Shanguang,Shanguang Xiang,shan guang,shan guang xiang,善广,善广乡', 30.2072500, 107.8387200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25460, 'Shuanggui', 'Shuanggui', 'Shuanggui,Shuanggui Zhen,shuang gui,shuang gui zhen,双桂,双桂镇', 30.2427600, 107.5880200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25461, 'Baishi', 'Baishi', 'Baishi,Baishi Zhen,bai shi,bai shi zhen,白石,白石镇', 30.3166600, 107.8824700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25462, 'Huaqiao', 'Huaqiao', 'Huangqiaosi,Huaqiao,Huaqiao Zhen,hua qiao,hua qiao zhen,huang qiao si,花桥,花桥镇,黄桥寺', 30.3604100, 107.6947600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25463, 'Maguan', 'Maguan', 'Maguan,Maguan Zhen,ma guan,ma guan zhen,马灌,马灌镇', 30.3935000, 107.7363300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25464, 'Caohui', 'Caohui', 'Caohui,Caohui Xiang,Huilongchang,cao hui,cao hui xiang,hui long chang,回龙场,曹回,曹回乡', 30.3973300, 107.4695300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25465, 'Xinmin', 'Xinmin', 'Xinmin,Xinmin Zhen,xin min,xin min zhen,新民,新民镇', 30.3975900, 107.3895000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25466, 'Changlong', 'Changlong', 'Changlong,Changlong Xiang,Gaoqiaoba,gao qiao ba,zhang long,zhang long xiang,长龙,长龙乡,高桥坝', 30.3061800, 107.4129600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25467, 'Yong’an', 'Yong''an', 'Meijiachang,Yong''an,Yong''an Zhen,Yong’an,Yong’an Zhen,mei jia chang,yong an,yong an zhen,梅家场,永安,永安镇', 30.3531000, 107.5128900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25468, 'Pushun', 'Pushun', 'Pushun,Pushun Zhen,pu shun,pu shun zhen,普顺,普顺镇', 30.4724100, 107.6032600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25469, 'Gangjia', 'Gangjia', 'Gangjia,Gangjia Xiang,gang jia,gang jia xiang,杠家,杠家乡', 30.2205500, 107.5040300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25470, 'Dashi', 'Dashi', 'Dashi,Dashi Xiang,da shi,da shi xiang,大石,大石乡', 30.1995200, 107.5362200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25471, 'Huangsha', 'Huangsha', 'Huangsha,Huangsha Xiang,huang sha,huang sha xiang,黄沙,黄沙乡', 30.2636400, 107.3762500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25472, 'Gaofeng', 'Gaofeng', 'Gaofeng,Gaofeng Zhen,gao feng,gao feng zhen,高峰,高峰镇', 30.2196800, 107.4078800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25473, 'Peixing', 'Peixing', 'Peixing,Peixing Xiang,pei xing,pei xing xiang,裴兴,裴兴乡', 30.1260900, 107.5178900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25474, 'Pingshan', 'Pingshan', 'Pingshan,Pingshan Zhen,ping shan,ping shan zhen,坪山,坪山镇', 30.0965500, 107.4243900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25475, 'Baojia', 'Baojia', 'Baojia,Baojia Xiang,bao jia,bao jia xiang,包家,包家乡', 30.0767300, 107.2837100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25476, 'Baijia', 'Baijia', 'Baijia,Baijia Xiang,bai jia,bai jia xiang,白家,白家乡', 30.0170400, 107.3257600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25477, 'Sanxi', 'Sanxi', 'Sanxi,Sanxi Xiang,san xi,san xi xiang,三溪,三溪乡', 30.0638700, 107.4535900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25478, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Xiang,Liaoyehe,cheng dong,cheng dong xiang,liao ye he,城东,城东乡,蓼叶河', 30.7201400, 107.8918000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25479, 'Shi’an', 'Shi''an', 'Shi''an,Shi''an Zhen,Shijiachang,Shi’an,Shi’an Zhen,shi an,shi an zhen,shi jia chang,石安,石安镇,石家场', 30.5902800, 107.9765700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25480, 'Baijia', 'Baijia', 'Baijia,Baijia Zhen,bai jia,bai jia zhen,柏家,柏家镇', 30.5929500, 107.9038300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25481, 'Zizhao', 'Zizhao', 'Zizhao,Zizhao Xiang,zi zhao,zi zhao xiang,紫照,紫照乡', 30.5325200, 107.9377500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25482, 'Daguan', 'Daguan', 'Daguan,Daguan Zhen,Guanyinyan,da guan,da guan zhen,guan yin yan,大观,大观镇,观音岩', 30.5547000, 107.8060300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25483, 'Tiemen', 'Tiemen', 'Shiziba,Tiemen,Tiemen Xiang,shi zi ba,tie men,tie men xiang,狮子坝,铁门,铁门乡', 30.5024900, 107.7107400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25484, 'Panlong', 'Panlong', 'Panlong,Panlong Zhen,pan long,pan long zhen,蟠龙,蟠龙镇', 30.6350400, 107.8502000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25485, 'Yinping', 'Yinping', 'Maliuchang,Yinping,Yinping Zhen,ma liu chang,yin ping,yin ping zhen,荫平,荫平镇,麻柳场', 30.5419700, 107.5751800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25486, 'Jindai', 'Jindai', 'Jindai,Jindai Zhen,Shiguiping,jin dai,jin dai zhen,shi gui ping,石桂坪,金带,金带镇', 30.6017700, 107.6978900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25487, 'Jukui', 'Jukui', 'Huangtukan,Jukui,Jukui Zhen,huang tu kan,ju kui,ju kui zhen,聚奎,聚奎镇,黄土坎', 30.6358800, 107.5963300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25488, 'Qixing', 'Qixing', 'Qixing,Qixing Zhen,qi xing,qi xing zhen,七星,七星镇', 30.6804100, 107.4819500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25489, 'Bishan', 'Bishan', 'Bishan,Bishan Zhen,Yejiawan,bi shan,bi shan zhen,ye jia wan,叶家湾,碧山,碧山镇', 30.7707500, 107.4571000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25490, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 30.5295600, 107.4810200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25491, 'Ansheng', 'Ansheng', 'Ansheng,Ansheng Xiang,Xinglongchang,an sheng,an sheng xiang,xing long chang,兴隆场,安胜,安胜乡', 30.6902300, 107.7208700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25492, 'Mingda', 'Mingda', 'Mingda,Mingda Zhen,Yangjiazui,ming da,ming da zhen,yang jia ju,明达,明达镇,杨家咀', 30.7263000, 107.6572600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25493, 'Lirang', 'Lirang', 'Laoyingchang,Lirang,Lirang Zhen,lao ying chang,li rang,li rang zhen,礼让,礼让镇,老营场', 30.6849400, 107.6314500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25494, 'Zhushan', 'Zhushan', 'Wenjiaba,Zhushan,Zhushan Zhen,wen jia ba,zhu shan,zhu shan zhen,文家坝,竹山,竹山镇', 30.7175200, 107.5746100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25495, 'Longsheng', 'Longsheng', 'Kunniuping,Longsheng,Longsheng Xiang,kun niu ping,long sheng,long sheng xiang,困牛坪,龙胜,龙胜乡', 30.7753700, 107.5500100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25496, 'Hucheng', 'Hucheng', 'Hucheng,Hucheng Zhen,hu cheng,hu cheng zhen,虎城,虎城镇', 30.8147900, 107.5418000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25497, 'Xinsheng', 'Xinsheng', 'Xinsheng,Xinsheng Zhen,xin sheng,xin sheng zhen,新盛,新盛镇', 30.8436700, 107.7241300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25498, 'Wenhua', 'Wenhua', 'Luosidian,Wenhua,Wenhua Zhen,luo si dian,wen hua,wen hua zhen,文化,文化镇,螺蛳店', 30.8143600, 107.7743600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25499, 'Xiaping', 'Xiaping', 'Fuyaozi,Xiaping,Xiaping Xiang,fu yao zi,xia ping,xia ping xiang,凫鹞子,夏平,夏平乡', 30.7719800, 107.8800300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25500, 'Hexing', 'Hexing', 'Hexing,Hexing Zhen,he xing,he xing zhen,合兴,合兴镇', 30.7448500, 107.8197700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25501, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Xiang,cheng bei,cheng bei xiang,城北,城北乡', 30.7210500, 107.7847000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25502, 'Chongxing', 'Chongxing', 'Chongxing,Chongxing Xiang,Linjiamiao,chong xing,chong xing xiang,lin jia miao,崇兴,崇兴乡,林家庙', 29.9954500, 107.5094200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25503, 'Baohe', 'Baohe', 'Baohe,Baohe Xiang,Hejiachang,bao he,bao he xiang,he jia chang,何家场,保合,保合乡', 30.0608400, 107.7017200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25504, 'Xumingsi', 'Xumingsi', 'Xumingsi,Xumingsi Zhen,xu ming si,xu ming si zhen,许明寺,许明寺镇', 30.1618000, 107.5816300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25505, 'Dongjia', 'Dongjia', 'Dongjia,Dongjia Zhen,dong jia,dong jia zhen,董家,董家镇', 30.2235200, 107.7057400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25506, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Xiang,Taipingchang,qing long,qing long xiang,tai ping chang,太平场,青龙,青龙乡', 30.1668300, 107.7847000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25507, 'Shuanglongchang', 'Shuanglongchang', 'Shuanglongchang,Shuanglongchang Xiang,shuang long chang,shuang long chang xiang,双龙场,双龙场乡', 30.1322400, 107.7207100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25508, 'Shizhi', 'Shizhi', 'Shizhi,Shizhi Zhen,Shizilu,shi zhi,shi zhi zhen,shi zi lu,十字路,十直,十直镇', 30.0530400, 107.7942600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25509, 'Huwei', 'Huwei', 'Dachi,Huwei,Huwei Zhen,da chi,hu wei,hu wei zhen,大池,虎威,虎威镇', 29.9056500, 107.6385300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25510, 'Zhanpu', 'Zhanpu', 'Zhanpu,Zhanpu Zhen,Zhujiazui,zhan pu,zhan pu zhen,zhu jia zui,朱家嘴,湛普,湛普镇', 29.8444100, 107.6365300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25511, 'Sanhe', 'Sanhe', 'Fengdu Xian,Sanhe,Sanhe Zhen,feng dou xian,san he,san he zhen,三合,三合镇,丰都县', 29.8686400, 107.7302700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25512, 'Sanba', 'Sanba', 'Sanba,Sanba Xiang,san ba,san ba xiang,三坝,三坝乡', 29.6723800, 107.7584100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25513, 'Xingyi', 'Xingyi', 'Nibaxi,Xingyi,Xingyi Zhen,ni ba xi,xing yi,xing yi zhen,兴义,兴义镇,泥巴溪', 29.9555200, 107.8164600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25514, 'Longkong', 'Longkong', 'Longkong,Longkong Xiang,long kong,long kong xiang,龙孔,龙孔乡', 30.0447700, 107.9149000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25515, 'Jiangchi', 'Jiangchi', 'Jiangchi,Jiangchi Zhen,jiang chi,jiang chi zhen,江池,江池镇', 29.9136900, 108.0271100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25516, 'Longhe', 'Longhe', 'Guanyinsi,Longhe,Longhe Zhen,guan yin si,long he,long he zhen,观音寺,龙河,龙河镇', 29.8395700, 107.9850800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25517, 'Wuping', 'Wuping', 'Modaodong,Wuping,Wuping Zhen,mo dao dong,wu ping,wu ping zhen,武平,武平镇,磨刀洞', 29.7962800, 108.0854800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25518, 'Taipingba', 'Taipingba', 'Fenghuangshan,Taipingba,Taipingba Xiang,feng huang shan,tai ping ba,tai ping ba xiang,凤凰山,太平坝,太平坝乡', 29.7297900, 108.1518800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25519, 'Jilong', 'Jilong', 'Jilong,Jilong Xiang,ji long,ji long xiang,暨龙,暨龙乡', 29.7228400, 108.0051900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25520, 'Nantianhu', 'Nantianhu', 'Nantianhu,Nantianhu Zhen,nan tian hu,nan tian hu zhen,南天湖,南天湖镇', 29.7009800, 107.9205300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25521, 'Sanjian', 'Sanjian', 'Liaojiaba,Sanjian,Sanjian Xiang,liao jia ba,san jian,san jian xiang,三建,三建乡,廖家坝', 29.8052000, 107.8636700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25522, 'Dudu', 'Dudu', 'Dudu,Dudu Xiang,dou du,dou du xiang,都督,都督乡', 29.6326400, 108.1144700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25523, 'Xiaoxi', 'Xiaoxi', 'Banbianjie,Xiaoxi,Xiaoxi Xiang,ban bian jie,xiao xi,xiao xi xiang,半边街,孝溪,孝溪乡', 28.3803700, 108.9106800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25524, 'Qingxichang', 'Qingxichang', 'Qingxichang,Qingxichang Zhen,qing xi chang,qing xi chang zhen,清溪场,清溪场镇', 28.4041700, 108.9044200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25525, 'Pingkai', 'Pingkai', 'Pingkai,Pingkai Zhen,ping kai,ping kai zhen,平凯,平凯镇', 28.4259500, 108.9959400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25526, 'Zhongping', 'Zhongping', 'Maopingcun,Zhongping,Zhongping Xiang,mao ping cun,zhong ping,zhong ping xiang,中平,中平乡,毛坪村', 28.4160900, 109.1292700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25527, 'Yajiang', 'Yajiang', 'Yajiang,Yajiang Zhen,ya jiang,ya jiang zhen,雅江,雅江镇', 28.4593500, 109.1775300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25528, 'Cenxi', 'Cenxi', 'Cenxi,Cenxi Xiang,cen xi,cen xi xiang,岑溪,岑溪乡', 28.3380300, 109.1087800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25529, 'Bajia', 'Bajia', 'Bajia,Bajia Xiang,ba jia,ba jia xiang,巴家,巴家乡', 28.2174200, 109.0646600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25530, 'Lanqiao', 'Lanqiao', 'Lanqiao,Lanqiao Zhen,lan qiao,lan qiao zhen,兰桥,兰桥镇', 28.1881500, 108.9934300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25531, 'Zhongling', 'Zhongling', 'Malukou,Zhongling,Zhongling Xiang,ma lu kou,zhong ling,zhong ling xiang,钟灵,钟灵乡,马路口', 28.2967500, 108.9584100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25532, 'Pingma', 'Pingma', 'Pingma,Pingma Xiang,ping ma,ping ma xiang,平马,平马乡', 28.5248800, 109.1802600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25533, 'Erong', 'Erong', 'Erong,Erong Zhen,e rong,e rong zhen,峨溶,峨溶镇', 28.5712800, 109.2883700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25534, 'Liren', 'Liren', 'Liren,Liren Xiang,li ren,li ren xiang,里仁,里仁乡', 28.6826400, 109.1797400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25535, 'Bao’an', 'Bao''an', 'Bao''an,Bao''an Xiang,Bao’an,Bao’an Xiang,Xiazhai,bao an,bao an xiang,xia zhai,下寨,保安,保安乡', 28.7294200, 109.2430300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25536, 'Daxi', 'Daxi', 'Daxi,Daxi Xiang,da xi,da xi xiang,大溪,大溪乡', 28.8018600, 109.1683700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25537, 'Haiyang', 'Haiyang', 'Dazhai,Haiyang,Haiyang Xiang,da zhai,hai yang,hai yang xiang,大寨,海洋,海洋乡', 28.7363200, 109.1236700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25538, 'Songnong', 'Songnong', 'Songnong,Songnong Xiang,song nong,song nong xiang,宋农,宋农乡', 28.6755700, 109.1047300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25539, 'Yongdong', 'Yongdong', 'Yongdong,Yongdong Xiang,yong dong,yong dong xiang,涌洞,涌洞乡', 28.6110800, 109.1221900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25540, 'Ganchuan', 'Ganchuan', 'Ganchuan,Ganchuan Xiang,gan chuan,gan chuan xiang,干川,干川乡', 28.5775000, 109.0972700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25541, 'Guanzhou', 'Guanzhou', 'Guanzhou,Guanzhou Xiang,Xiaba,guan zhou,guan zhou xiang,xia ba,下坝,官舟,官舟乡', 28.4155900, 109.0184300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25542, 'Guanzhuang', 'Guanzhuang', 'Guanzhuang,Guanzhuang Zhen,guan zhuang,guan zhuang zhen,官庄,官庄镇', 28.5078100, 109.0113900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25543, 'Miaoquan', 'Miaoquan', 'Miaoquan,Miaoquan Xiang,miao quan,miao quan xiang,妙泉,妙泉乡', 28.6403700, 109.0039900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25544, 'Xikou', 'Xikou', 'Xikou,Xikou Xiang,xi kou,xi kou xiang,溪口,溪口乡', 28.6005900, 108.9185300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25545, 'Gaotian', 'Gaotian', 'Gaotian,Gaotian Xiang,gao tian,gao tian xiang,膏田,膏田乡', 28.4900700, 108.8406700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25546, 'Tang’ao', 'Tang''ao', 'Pengganxi,Tang''ao,Tang''ao Xiang,Tang’ao,Tang’ao Xiang,peng gan xi,tang ao,tang ao xiang,塘坳,塘坳乡,蓬干溪', 28.3933500, 108.8132200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25547, 'Nanyaojie', 'Nanyaojie', 'Nanyaojie,Nanyaojie Xiang,nan yao jie,nan yao jie xiang,南腰界,南腰界乡', 28.3995700, 108.6448400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25548, 'Nanmu', 'Nanmu', 'Ganjiaxi,Nanmu,Nanmu Xiang,gan jia xi,nan mu,nan mu xiang,楠木,楠木乡,赶家溪', 28.6034800, 108.7639300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25549, 'Jiangfeng', 'Jiangfeng', 'Jiangfeng,Jiangfeng Xiang,jiang feng,jiang feng xiang,江丰,江丰乡', 28.6355200, 108.9285500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25550, 'Houxi', 'Houxi', 'Houxi,Houxi Zhen,hou xi,hou xi zhen,后溪,后溪镇', 28.8925900, 109.1272200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25551, 'Banxi', 'Banxi', 'Banxi,Banxi Xiang,Shiyazi,ban xi,ban xi xiang,shi ya zi,板溪,板溪乡,石垭子', 28.7342800, 108.8170800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25552, 'Huatian', 'Huatian', 'Huatian,Huatian Xiang,hua tian,hua tian xiang,花田,花田乡', 28.9538300, 108.7045700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25553, 'Shuangquan', 'Shuangquan', 'Shuangquan,Shuangquan Xiang,shuang quan,shuang quan xiang,双泉,双泉乡', 29.0298200, 108.6465200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25554, 'Langping', 'Langping', 'Langping,lang ping,浪坪', 29.0809000, 108.5455300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25555, 'Liangzeng', 'Liangzeng', 'Liangzeng,Liangzeng Xiang,liang zeng,liang zeng xiang,两罾,两罾乡', 28.8836500, 108.3916200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25556, 'Tianguan', 'Tianguan', 'Tianguan,tian guan,天馆', 28.8388200, 108.4602600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25557, 'Qingshui', 'Qingshui', 'Qingshui,Qingshui Xiang,qing shui,qing shui xiang,清水,清水乡', 28.7986800, 108.3856100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25558, 'Houpingba', 'Houpingba', 'Houpingba,Houpingba Xiang,hou ping ba,hou ping ba xiang,后坪坝,后坪坝乡', 28.6957600, 108.3981700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25559, 'Wanmu', 'Wanmu', 'Tunshang,Wanmu,Wanmu Xiang,tun shang,wan mu,wan mu xiang,万木,万木乡,屯上', 28.6327500, 108.5002400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25560, 'Xiaohe', 'Xiaohe', 'Xiaohe,Xiaohe Zhen,xiao he,xiao he zhen,小河,小河镇', 28.6585200, 108.6365500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25561, 'Guanqing', 'Guanqing', 'Guanqing,Guanqing Xiang,Jinjiaba,guan qing,guan qing xiang,jin jia ba,官清,官清乡,金家坝', 28.6194600, 108.6867400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25562, 'Banqiao', 'Banqiao', 'Banqiao,Banqiao Xiang,ban qiao,ban qiao xiang,板桥,板桥乡', 28.7030400, 108.7192500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25563, 'Tonggu', 'Tonggu', 'Tonggu,Tonggu Xiang,tong gu,tong gu xiang,铜鼓,铜鼓乡', 28.7816900, 108.6825800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25564, 'Yiju', 'Yiju', 'Yiju,Yiju Xiang,yi ju,yi ju xiang,宜居,宜居乡', 28.8765600, 108.5911000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25565, 'Ganxi', 'Ganxi', 'Ganxi,Ganxi Zhen,gan xi,gan xi zhen,泔溪,泔溪镇', 28.9810800, 108.9600600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25566, 'Muye', 'Muye', 'Muye,Muye Xiang,mu ye,mu ye xiang,木叶,木叶乡', 29.2555400, 108.9883200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25567, 'Maoba', 'Maoba', 'Maoba,Maoba Xiang,mao ba,mao ba xiang,毛坝,毛坝乡', 29.1052100, 108.9000600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25568, 'Tushi', 'Tushi', 'Heshaba,Tushi,Tushi Xiang,he sha ba,tu shi,tu shi xiang,河沙坝,涂市,涂市乡', 28.9174600, 108.8670400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25569, 'Yudi', 'Yudi', 'Yudi,Yudi Xiang,yu de,yu de xiang,腴地,腴地乡', 29.0032600, 108.9154500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25570, 'Apengjiang', 'Apengjiang', 'Apengjiang,Apengjiang Zhen,a peng jiang,a peng jiang zhen,阿蓬江,阿蓬江镇', 29.1519600, 108.7428900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25571, 'Echi', 'Echi', 'Echi,Echi Zhen,e chi,e chi zhen,鹅池,鹅池镇', 29.1380300, 108.5900300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25572, 'Jindong', 'Jindong', 'Jindong,Jindong Xiang,Yangjia''ao,Yangjia’ao,jin dong,jin dong xiang,yang jia ao,杨家坳,金洞,金洞乡', 29.2033500, 108.8472800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25573, 'Mala', 'Mala', 'Mala,Mala Zhen,ma la,ma la zhen,马喇,马喇镇', 29.2826200, 108.8504400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25574, 'Shuishi', 'Shuishi', 'Shuishi,shui shi,水市', 29.2434700, 108.6984300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25575, 'Shuishi', 'Shuishi', 'Laochangba,Shuishi,Shuishi Xiang,lao chang ba,shui shi,shui shi xiang,水市,水市乡,老场坝', 29.2433900, 108.6995000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25576, 'Xinhua', 'Xinhua', 'Tianjiacun,Xinhua,Xinhua Xiang,tian jia cun,xin hua,xin hua xiang,新华,新华乡,田家村', 29.3236300, 108.6039500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25577, 'Daji', 'Daji', 'Daji,Daji Xiang,da ji,da ji xiang,大极,大极乡', 29.3290900, 108.6621900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25578, 'Wuli', 'Wuli', 'Ganxi,Wuli,Wuli Xiang,gan xi,wu li,wu li xiang,五里,五里乡,干溪', 29.3587500, 108.8754400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25579, 'Pengdong', 'Pengdong', 'Huocaoba,Pengdong,Pengdong Xiang,huo cao ba,peng dong,peng dong xiang,火草坝,蓬东,蓬东乡', 29.3862100, 108.8230500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25580, 'Shuitian', 'Shuitian', 'Shuitian,Shuitian Xiang,shui tian,shui tian xiang,水田,水田乡', 29.4005700, 108.7362300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25581, 'Jinxi', 'Jinxi', 'Jinxi,Jinxi Zhen,jin xi,jin xi zhen,金溪,金溪镇', 29.3921700, 108.6869700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25582, 'Baitu', 'Baitu', 'Baitu,Baitu Xiang,bai tu,bai tu xiang,白土,白土乡', 29.3795400, 108.6415900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25583, 'Zhengyang', 'Zhengyang', 'Zhaojiaping,Zhengyang,Zhengyang Jiedao,zhao jia ping,zheng yang,zheng yang jie dao,正阳,正阳街道,赵家坪', 29.4587300, 108.7873000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25584, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Jiedao,cheng nan,cheng nan jie dao,城南,城南街道', 29.5208600, 108.7814900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25585, 'Chengdong', 'Chengdong', 'Chengdong,Chengdong Jiedao,cheng dong,cheng dong jie dao,城东,城东街道', 29.5251000, 108.7869000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25586, 'Qianjiang', 'Qianjiang', 'Chengxi,Chengxi Jiedao,JIQ,Qianjiang,cheng xi,cheng xi jie dao,qian jiang qu,城西,城西街道,黔江区', 29.5328400, 108.7747800, 'CN', '2013-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25587, 'Zhoubai', 'Zhoubai', 'Zhoubai,Zhoubai Jiedao,zhou bai,zhou bai jie dao,舟白,舟白街道', 29.5294900, 108.8226700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25588, 'Shaba', 'Shaba', 'Heshangbao,Shaba,Shaba Xiang,he shang bao,sha ba,sha ba xiang,和尚堡,沙坝,沙坝乡', 29.4901900, 108.5824000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25589, 'Heixi', 'Heixi', 'Heixi,Heixi Zhen,Shengdiba,hei xi,hei xi zhen,sheng de ba,胜地坝,黑溪,黑溪镇', 29.6206400, 108.5407500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25590, 'Zhongtang', 'Zhongtang', 'Zhongba,Zhongtang,Zhongtang Xiang,zhong ba,zhong tang,zhong tang xiang,中坝,中塘,中塘乡', 29.6110700, 108.8254600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25591, 'Xiaonanhai', 'Xiaonanhai', 'Xiaonanhai,Xiaonanhai Zhen,Xinchang,xiao nan hai,xiao nan hai zhen,xin chang,小南海,小南海镇,新场', 29.6614700, 108.7625100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25592, 'Shanling', 'Shanling', 'Shanling,Shanling Xiang,Wuguibao,shan ling,shan ling xiang,wu gui bao,乌龟堡,杉岭,杉岭乡', 29.7362700, 108.6197800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25593, 'Baishi', 'Baishi', 'Baishi,Baishi Xiang,bai shi,bai shi xiang,白石,白石乡', 29.6838700, 108.5626300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25594, 'Huangxi', 'Huangxi', 'Huangxi,Huangxi Zhen,Yuquanba,huang xi,huang xi zhen,yu quan ba,鱼泉坝,黄溪,黄溪镇', 29.7678000, 108.5997400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25595, 'Lishui', 'Lishui', 'Lishui,Lishui Zhen,li shui,li shui zhen,黎水,黎水镇', 29.8304800, 108.6435500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25596, 'Daya', 'Daya', 'Daya,Daya Xiang,Taoziwan,da ya,da ya xiang,tao zi wan,大垭,大垭乡,桃子湾', 29.0256400, 107.8860100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25597, 'Runxi', 'Runxi', 'Qianxichang,Runxi,Runxi Xiang,qian xi chang,run xi,run xi xiang,千溪场,润溪,润溪乡', 29.0795400, 107.9176600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25598, 'Longtang', 'Longtang', 'Longtang,Longtang Xiang,long tang,long tang xiang,龙塘,龙塘乡', 29.0681600, 107.9868100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25599, 'Langxi', 'Langxi', 'Langxi,Langxi Xiang,lang xi,lang xi xiang,郎溪,郎溪乡', 29.0713400, 108.1380400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25600, 'Shuanglong', 'Shuanglong', 'Shuanglong,Shuanglong Xiang,shuang long,shuang long xiang,双龙,双龙乡', 29.0895300, 108.2577300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25601, 'Shipan', 'Shipan', 'Dongshang,Shipan,Shipan Xiang,dong shang,shi pan,shi pan xiang,洞上,石盘,石盘乡', 29.1392100, 108.2041300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25602, 'Dianshui', 'Dianshui', 'Dianshui,Dianshui Xiang,dian shui,dian shui xiang,靛水,靛水乡', 29.2833900, 108.0890000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25603, 'Shangan', 'Shangan', 'Shangan,Shangan Xiang,Shicaoba,shan gan,shan gan xiang,shi cao ba,善感,善感乡,石槽坝', 29.0826600, 108.3547800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25604, 'Anzi', 'Anzi', 'Anzi,Anzi Xiang,an zi,an zi xiang,鞍子,鞍子乡', 29.1278900, 108.4704300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25605, 'Meiziya', 'Meiziya', 'Meiziya,Meiziya Xiang,mei zi ya,mei zi ya xiang,梅子垭,梅子垭乡', 29.1607600, 108.5186000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25606, 'Zhufo', 'Zhufo', 'Zhufo,Zhufo Xiang,zhu fu,zhu fu xiang,诸佛,诸佛乡', 29.2215300, 108.4969400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25607, 'Tonglou', 'Tonglou', 'Tonglou,Tonglou Xiang,Tongmuxi,tong lou,tong lou xiang,tong mu xi,桐木溪,桐楼,桐楼乡', 29.2895200, 108.5519900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25608, 'Xiaochang', 'Xiaochang', 'Dachang,Xiaochang,Xiaochang Xiang,da chang,xiao chang,xiao chang xiang,大厂,小厂,小厂乡', 29.3427200, 108.5123100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25609, 'Longxi', 'Longxi', 'Longxi,Longxi Xiang,Zhoujiaba,long xi,long xi xiang,zhou jia ba,周家坝,龙溪,龙溪乡', 29.4696300, 108.5155400, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25610, 'Qiaozi', 'Qiaozi', 'Hexinchang,Qiaozi,Qiaozi Xiang,he xin chang,qiao zi,qiao zi xiang,合心场,桥梓,桥梓乡', 29.4122100, 108.3912300, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25611, 'Qianqiao', 'Qianqiao', 'Qianqiao,Qianqiao Xiang,Shuitianchang,qian qiao,qian qiao xiang,shui tian chang,水田场,迁乔,迁乔乡', 29.3555400, 108.3197700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25612, 'Yandong', 'Yandong', 'Dayantang,Yandong,Yandong Xiang,da yan tang,yan dong,yan dong xiang,大堰塘,岩东,岩东乡', 29.2857600, 108.2380900, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25613, 'Wanzu', 'Wanzu', 'Wanzu,Wanzu Zhen,wan zu,wan zu zhen,万足,万足镇', 29.2135500, 108.2137100, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25614, 'Xintian', 'Xintian', 'Toudangba,Xintian,Xintian Xiang,tou dang ba,xin tian,xin tian xiang,头党坝,新田,新田乡', 29.1963400, 108.2705000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25615, 'Luwu', 'Luwu', 'Luwu,Luwu Xiang,lu wu,lu wu xiang,鹿呜,鹿呜乡', 29.4485800, 108.0819000, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25616, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Xiang,Ping’an,Ping’an Xiang,ping an,ping an xiang,平安,平安乡', 29.4669500, 108.1440500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25617, 'Longshe', 'Longshe', 'Longshe,Longshe Zhen,Zhangjiaba,long she,long she zhen,zhang jia ba,张家坝,龙射,龙射镇', 29.5308600, 108.2112600, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25618, 'Lutang', 'Lutang', 'Banliping,Lutang,Lutang Xiang,ban li ping,lu tang,lu tang xiang,板栗坪,芦塘,芦塘乡', 29.5179800, 108.3294200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25619, 'Ditang', 'Ditang', 'Ditang,Ditang Xiang,Huaditang,di tang,di tang xiang,hua di tang,棣棠,棣棠乡,花棣棠', 29.6053900, 108.2171200, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25620, 'Changtan', 'Changtan', 'Changtan,Changtan Xiang,Mayoukou,ma you kou,zhang tan,zhang tan xiang,长滩,长滩乡,麻油口', 29.3465900, 108.2202700, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25621, 'Lianhe', 'Lianhe', 'Caijiaba,Lianhe,Lianhe Xiang,cai jia ba,lian he,lian he xiang,联合,联合乡,蔡家坝', 29.5932400, 108.4266500, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25622, 'Lianhu', 'Lianhu', 'Lianhu,Lianhu Zhen,lian hu,lian hu zhen,连湖,连湖镇', 29.6980800, 108.4352800, 'CN', '2012-10-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25623, 'Hutang', 'Hutang', 'Hutang,Hutang Zhen,Wujin Qu,hu tang,hu tang zhen,wu jin qu,武进区,湖塘,湖塘镇', 31.7158100, 119.9445800, 'CN', '2012-11-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25624, 'Changhongjie', 'Changhongjie', 'Changhongjie,Changhongjie Jiedao,Nankai,Nankai Qu,nan kai,nan kai qu,zhang hong jie,zhang hong jie jie dao,南开,南开区,长虹街,长虹街街道', 39.1372700, 117.1474800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25625, 'Xiangyanglu', 'Xiangyanglu', 'Xiangyanglu,Xiangyanglu Jiedao,xiang yang lu,xiang yang lu jie dao,向阳路,向阳路街道', 39.1345300, 117.1254700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25626, 'Guangkai', 'Guangkai', 'Guangkai,Guangkai Jiedao,guang kai,guang kai jie dao,广开,广开街道', 39.1347400, 117.1620900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25627, 'Gulou', 'Gulou', 'Gulou,Gulou Jiedao,gu lou,gu lou jie dao,鼓楼,鼓楼街道', 39.1386800, 117.1777300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25628, 'Xingnan', 'Xingnan', 'Xingnan,Xingnan Jiedao,xing nan,xing nan jie dao,兴南,兴南街道', 39.1253800, 117.1706000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25629, 'Xuefu', 'Xuefu', 'Xuefu,Xuefu Jiedao,xue fu,xue fu jie dao,学府,学府街道', 39.1121800, 117.1601700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25630, 'Wanxing', 'Wanxing', 'Wanxing,Wanxing Jiedao,wan xing,wan xing jie dao,万兴,万兴街道', 39.1219700, 117.1575100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25631, 'Balitai', 'Balitai', 'Balitai,Balitai Jiedao,ba li tai,ba li tai jie dao,八里台,八里台街道', 39.0962100, 117.1668800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25632, 'Tiyu Zhongxin', 'Tiyu Zhongxin', 'Tiyu Zhongxin,Tiyu Zhongxin Jiedao,ti yu zhong xin,ti yu zhong xin jie dao,体育中心,体育中心街道', 39.0671500, 117.1685800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25633, 'Nanshi', 'Nanshi', 'Nanshi,Nanshi Jiejao,nan shi,nan shi jie dao,南市,南市街道', 39.1266500, 117.1815600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25634, 'Nanyingmen', 'Nanyingmen', 'Nanyingmen,Nanyingmen Jiedao,nan ying men,nan ying men jie dao,南营门,南营门街道', 39.1170700, 117.1788000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25635, 'Xinxing', 'Xinxing', 'Xinxing,Xinxing Jiedao,xin xing,xin xing jie dao,新兴,新兴街道', 39.1042000, 117.1808200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25636, 'Machang', 'Machang', 'Machang,Machang Jiedao,ma chang,ma chang jie dao,马场,马场街道', 39.0985500, 117.1925300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25637, 'Tianta', 'Tianta', 'Tianta,Tianta Jiedao,tian ta,tian ta jie dao,天塔,天塔街道', 39.0818400, 117.1807100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25638, 'Youyilu', 'Youyilu', 'Youyilu,Youyilu Jiedao,you yi lu,you yi lu jie dao,友谊路,友谊路街道', 39.0767300, 117.1982700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25639, 'Lingdangge', 'Lingdangge', 'Lingdangge,Lingdangge Jiedao,ling dang ge,ling dang ge jie dao,铃铛阁,铃铛阁街道', 39.1442200, 117.1415400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25640, 'Huayuandao', 'Huayuandao', 'Huayuandao,Huayuandao Jiedao,hua yuan dao,hua yuan dao jie dao,花园道,花园道街道', 39.1484700, 117.1422900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25641, 'Shaogongzhuang', 'Shaogongzhuang', 'Shaogongzhuang,Shaogongzhuang Jiedao,shao gong zhuang,shao gong zhuang jie dao,邵公庄,邵公庄街道', 39.1549700, 117.1546300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25642, 'Dahutong', 'Dahutong', 'Dahutong,Dahutong Jiedao,da hu tong,da hu tong jie dao,大湖同,大湖同街道', 39.1462400, 117.1816700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25643, 'Santiaoshi', 'Santiaoshi', 'Santiaoshi,Santiaoshi Jiedao,san tiao shi,san tiao shi jie dao,三条石,三条石街道', 39.1558200, 117.1757100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25644, 'Xigu', 'Xigu', 'Xigu,Xigu Jiedao,xi gu,xi gu jie dao,西沽,西沽街道', 39.1647600, 117.1689000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25645, 'Hongshunli', 'Hongshunli', 'Hongshunli,Hongshunli Jiedao,hong shun li,hong shun li jie dao,鸿顺里,鸿顺里街道', 39.1575200, 117.1880600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25646, 'Xinkaihe', 'Xinkaihe', 'Xinkaihe,Xinkaihe Jiedao,xin hai he jie dao,xin kai he,新开河,新海河街道', 39.1754000, 117.1779400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25647, 'Wanghailou', 'Wanghailou', 'Hebei,Hebei Qu,Wanghailou,Wanghailou Jiedao,he bei,he bei qu,wang hai lou,wang hai lou jie dao,望海楼,望海楼街道,河北,河北区', 39.1595400, 117.2033800, 'CN', '2014-09-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25648, 'Wangchuanchang', 'Wangchuanchang', 'Wangchuanchang,Wangchuanchang Jiedao,wang chuan chang,wang chuan chang jie dao,王串场,王串场街道', 39.1534800, 117.2147700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25649, 'Guangfudao', 'Guangfudao', 'Guangfudao,Guangfudao Jiedao,guang fu dao,guang fu dao jie dao,光复道,光复道街道', 39.1463500, 117.2007800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25650, 'Chunhua', 'Chunhua', 'Chunhua,Chunhua Jiedao,chun hua,chun hua jie dao,春华,春华街道', 39.1400700, 117.2025900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25651, 'Changzhoudao', 'Changzhoudao', 'Changzhoudao,Changzhoudao Jiedao,chang zhou dao,chang zhou dao jie dao,常州道,常州道街道', 39.1473100, 117.2330300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25652, 'Jiangdulu', 'Jiangdulu', 'Jiangdulu,Jiangdulu Jiedao,jiang dou lu,jiang dou lu jie dao,江都路,江都路街道', 39.1559300, 117.2394100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25653, 'Ningyuan', 'Ningyuan', 'Ningyuan,Ningyuan Jiedao,ning yuan,ning yuan jie dao,宁园,宁园街道', 39.1631600, 117.2095000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25654, 'Yueyahe', 'Yueyahe', 'Yueyahe,Yueyahe Jiedao,yue ya he,yue ya he jie dao,月牙河,月牙河街道', 39.1625300, 117.2414400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25655, 'Jianchangdao', 'Jianchangdao', 'Jianchangdao,Jianchangdao Jiedao,jian chang dao,jian chang dao jie dao,建昌道,建昌道街道', 39.1687000, 117.2228100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25656, 'Tiedonglu', 'Tiedonglu', 'Tiedonglu,Tiedonglu Jiedao,tie dong lu,tie dong lu jie dao,铁东路,铁东路街道', 39.1900900, 117.1978000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25657, 'Xianyang Beilu', 'Xianyang Beilu', 'Xianyang Beilu,Xianyang Beilu Jiedao,xian yang bei lu,xian yang bei lu jie dao,咸阳北路,咸阳北路街道', 39.1839200, 117.1400000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25658, 'Dingzigu', 'Dingzigu', 'Dingzigu,Dingzigu Jiedao,ding zi gu,ding zi gu jie dao,丁字沽,丁字沽街道', 39.1740200, 117.1574600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25659, 'Xiyuzhuang', 'Xiyuzhuang', 'Hongqiao,Hongqiao Qu,Xiyuzhuang,Xiyuzhuang Jiedao,hong qiao,hong qiao qu,xi yu zhuang,xi yu zhuang jie dao,红桥,红桥区,西于庄,西于庄街道', 39.1663100, 117.1567900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25660, 'Chenglin', 'Chenglin', 'Chenglin,Chenglin Jiedao,cheng lin,cheng lin jie dao,程林,程林街道', 39.1146800, 117.2738700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25661, 'Huaming', 'Huaming', 'Huaming,Huaming Zhen,hua ming,hua ming zhen,华明,华明镇', 39.1617300, 117.3118700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25662, 'Dongxin', 'Dongxin', 'Dongxin,Dongxin Jiedao,dong xin,dong xin jie dao,东新,东新街道', 39.1416100, 117.2711100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25663, 'Xiangyanglou', 'Xiangyanglou', 'Xiangyanglou,Xiangyanglou Jiedao,xiang yang lou,xiang yang lou jie dao,向阳楼,向阳楼街道', 39.1350100, 117.2410900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25664, 'Tangjiakou', 'Tangjiakou', 'Tangjiakou,Tangjiakou Jiedao,tang jia kou,tang jia kou jie dao,唐家口,唐家口街道', 39.1267100, 117.2366200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25665, 'Erhaoqiao', 'Erhaoqiao', 'Erhaoqiao,Erhaoqiao Jiedao,er hao qiao,er hao qiao jie dao,二号桥,二号桥街道', 39.0964800, 117.2905800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25666, 'Zhongshanmen', 'Zhongshanmen', 'Zhongshanmen,Zhongshanmen Jiedao,zhong shan men,zhong shan men jie dao,中山门,中山门街道', 39.1001000, 117.2649300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25667, 'Fuminlu', 'Fuminlu', 'Fuminglu Jiedao,Fuminlu,fu min lu,fu min lu jie dao,富民路,富民路街道', 39.0882800, 117.2513100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25668, 'Dazhigu', 'Dazhigu', 'Dazhigu,Dazhigu Jiedao,da zhi gu,da zhi gu jie dao,大直沽,大直沽街道', 39.1087200, 117.2385400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25669, 'Shangkenglu', 'Shangkenglu', 'Shangkenglu,Shangkenglu Jiedao,shang keng lu,shang keng lu jie dao,上坑路,上坑路街道', 39.1268200, 117.2546100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25670, 'Dawangzhuang', 'Dawangzhuang', 'Dawangzhuang,Dawangzhuang Jiedao,Hedong,Hedong Qu,da wang zhuang,da wang zhuang jie dao,he dong,he dong qu,大王庄,大王庄街道,河东,河东区', 39.1270300, 117.2161800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25671, 'Yuexiulu', 'Yuexiulu', 'Yuexiulu,Yuexiulu Jiedao,yue xiu lu,yue xiu lu jie dao,越秀路,越秀路街道', 39.0911600, 117.2233100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25672, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Jiedao,tao yuan,tao yuan jie dao,桃园,桃园街道', 39.0957400, 117.2228900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25673, 'Dayingmen', 'Dayingmen', 'Dayingmen,Dayingmen Jiedao,Hexi,Hexi Qu,da ying men,da ying men jie dao,he xi,he xi qu,大营门,大营门街道,河西,河西区', 39.1073400, 117.2095800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25674, 'Guajiasi', 'Guajiasi', 'Guajiasi,Guajiasi Jiedao,gua jia si,gua jia si jie dao,挂甲寺,挂甲寺街道', 39.0910500, 117.2261900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25675, 'Jianshan', 'Jianshan', 'Jianshan,Jianshan Jiedao,jian shan,jian shan jie dao,尖山,尖山街道', 39.0872200, 117.2241700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25676, 'Donghai', 'Donghai', 'Donghai,Donghai Jiedao,dong hai,dong hai jie dao,东海,东海街道', 39.0521000, 117.2470500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25677, 'Chentangzhuang', 'Chentangzhuang', 'Chentangzhuang,Chentangzhuang Jiedao,chen tang zhuang,chen tang zhuang jie dao,陈塘庄,陈塘庄街道', 39.0671000, 117.2591900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25678, 'Liulin', 'Liulin', 'Liulin,Liulin Jiedao,liu lin,liu lin jie dao,柳林,柳林街道', 39.0640200, 117.2653600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25679, 'Xiaobailou', 'Xiaobailou', 'Heping,Heping Qu,Xiaobailou,Xiaobailou Jiedao,he ping,he ping qu,xiao bai lou,xiao bai lou jie dao,和平,和平区,小白楼,小白楼街道', 39.1176600, 117.2056500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25680, 'Tiyuguan', 'Tiyuguan', 'Tiyuguan,Tiyuguan Jiedao,ti yu guan,ti yu guan jie dao,体育馆,体育馆街道', 39.1092500, 117.1929800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25681, 'Quanyechang', 'Quanyechang', 'Quanyechang,Quanyechang Jiedao,quan ye chang,quan ye chang jie dao,劝业场,劝业场街道', 39.1212800, 117.1930900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25682, 'Fengniancun', 'Fengniancun', 'Fengniancun,Fengniancun Jiedao,feng nian cun,feng nian cun jie dao,丰年村,丰年村街道', 39.0822200, 117.3283700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25683, 'Yaoliuqiao', 'Yaoliuqiao', 'Yaoliuqiao,Yaoliuqiao Xiang,yao liu qiao,yao liu qiao xiang,幺六桥,幺六桥乡', 39.1003100, 117.3811600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25684, 'Wuxia', 'Wuxia', 'Wuxia,Wuxia Jiedao,wu xia,wu xia jie dao,无暇街道,无瑕', 39.0364500, 117.5071900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25685, 'Guoyuan Xincun', 'Guoyuan Xincun', 'Beichen,Beichen Qu,Guoyuan Xincun,Guoyuan Xincun Jiedao,bei chen,bei chen qu,guo yuan xin cun,guo yuan xin cun jie dao,北辰,北辰区,果园新村,果园新村街道', 39.2218700, 117.1301800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25686, 'Shuangjie', 'Shuangjie', 'Shuangjie,Shuangjie Zhen,shuang jie,shuang jie zhen,双街,双街镇', 39.2604700, 117.0972900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25687, 'Xikou', 'Xikou', 'Xikou,Xikou Xiang,xi kou,xi kou xiang,溪口,溪口乡', 28.4322200, 120.7171700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25688, 'Biaoshan', 'Biaoshan', 'Biaoshan,Biaoshan Xiang,biao shan,biao shan xiang,表山,表山乡', 28.3952000, 120.6519100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25689, 'Qukou', 'Qukou', 'Qukou,Qukou Xiang,qu kou,qu kou xiang,渠口,渠口乡', 28.2653400, 120.7212300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25690, 'Kunyang', 'Kunyang', 'Kunyang,Kunyang Xiang,kun yang,kun yang xiang,昆阳,昆阳乡', 28.2522600, 120.5646500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25691, 'Shijian', 'Shijian', 'Shijian,shi jian,石笕', 28.4832300, 120.1472200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25692, 'Shuqiao', 'Shuqiao', 'Shuqiao,Shuqiao Xiang,shu qiao,shu qiao xiang,舒桥,舒桥乡', 28.4280800, 120.0634700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25693, 'Haixi', 'Haixi', 'Haixi,Haixi Xiang,Zhengjiaosi,hai xi,hai xi xiang,zheng jiao si,正教寺,海溪,海溪乡', 28.3986400, 120.0878000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25694, 'Gaohu', 'Gaohu', 'Gaohu,Gaohu Zhen,gao hu,gao hu zhen,高湖,高湖镇', 28.3367300, 120.2178200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25695, 'Dongyuan', 'Dongyuan', 'Dongyuan,Dongyuan Zhen,dong yuan,dong yuan zhen,东源,东源镇', 28.3189600, 120.2320500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25696, 'Daruoyan', 'Daruoyan', 'Daruoyan,Daruoyan Zhen,da ruo yan,da ruo yan zhen,大箬岩,大箬岩镇', 28.2831800, 120.6143300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25697, 'Pankeng', 'Pankeng', 'Pankeng,Pankeng Xiang,pan keng,pan keng xiang,潘坑,潘坑乡', 28.4530600, 120.5857100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25698, 'Da’ao', 'Da''ao', 'Da''ao,Da''ao Xiang,Da’ao,Da’ao Xiang,da ao,da ao xiang,大岙,大岙乡', 28.4391300, 120.5306200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25699, 'Xixia', 'Xixia', 'Xixia,xi xia,溪下', 28.4989900, 120.4853400, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25700, 'Shankeng', 'Shankeng', 'Shankeng,Shankeng Xiang,shan keng,shan keng xiang,山坑,山坑乡', 28.3486100, 120.5173900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25701, 'Ming’ao', 'Ming''ao', 'Ming''ao,Ming''ao Xiang,Ming’ao,Ming’ao Xiang,ming ao,ming ao xiang,茗岙,茗岙乡', 28.2817600, 120.5220700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25702, 'Xixi', 'Xixi', 'Wuzhai,Xixi,Xixi Xiang,wu zhai,xi xi,xi xi xiang,吴宅,西溪,西溪乡', 28.2134800, 120.5232200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25703, 'Xi’ao', 'Xi''ao', 'Xi''ao,Xi''ao Xiang,Xi’ao,Xi’ao Xiang,xi ao,xi ao xiang,西岙,西岙乡', 28.4227800, 120.3919200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25704, 'Wuma', 'Wuma', 'Lucheng Qu,Wuma,Wuma Jiedao,lu cheng qu,wu ma,wu ma jie dao,五马,五马街道,鹿城区', 28.0173100, 120.6659500, 'CN', '2014-02-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25705, 'Bushan', 'Bushan', 'Bushan,Bushan Xiang,Wangfeitan,bu shan,bu shan xiang,wang fei tan,埠山,埠山乡,王费潭', 28.0813900, 120.1787700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25706, 'Beishan', 'Beishan', 'Beishan,Beishan Zhen,bei shan,bei shan zhen,北山,北山镇', 28.0797300, 120.0190100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25707, 'Jupu', 'Jupu', 'Jupu,Jupu Xiang,ju pu,ju pu xiang,巨浦,巨浦乡', 28.1337900, 120.0687700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25708, 'Gaoshi', 'Gaoshi', 'Dicun,Gaoshi,Gaoshi Xiang,di cun,gao shi,gao shi xiang,底村,高市,高市乡', 28.2642100, 120.1255800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25709, 'Rengong', 'Rengong', 'Rengong,Rengong Xiang,ren gong,ren gong xiang,仁宫,仁宫乡', 28.1695100, 120.1731800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25710, 'Zhangdan', 'Zhangdan', 'Guibei,Zhangdan,Zhangdan Xiang,gui bei,zhang dan,zhang dan xiang,章旦,章旦乡,龟背', 28.1270200, 120.2533500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25711, 'Shiqiao', 'Shiqiao', 'Shatian,Shiqiao,Shiqiao Xiang,sha tian,shi qiao,shi qiao xiang,沙田,石桥,石桥乡', 29.1983100, 107.8288700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25712, 'Wenfu', 'Wenfu', 'Luobuya,Wenfu,Wenfu Xiang,luo bo ya,wen fu,wen fu xiang,文复,文复乡,萝卜垭', 29.2790800, 107.9521500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25713, 'Heshun', 'Heshun', 'Heshun,Heshun Xiang,he shun,he shun xiang,和顺,和顺乡', 29.4123000, 107.4235200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25714, 'Fenglai', 'Fenglai', 'Fenglai,Fenglai Xiang,feng lai,feng lai xiang,凤来,凤来乡', 29.3998600, 107.2965200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25715, 'Pingqiao', 'Pingqiao', 'Pingqiao,Pingqiao Zhen,ping qiao,ping qiao zhen,平桥,平桥镇', 29.3737600, 107.3379300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25716, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Xiang,Shangdacao,bai yun,bai yun xiang,shang da cao,上大槽,白云,白云乡', 29.3131200, 107.4184500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25717, 'Tiekuang', 'Tiekuang', 'Tiejianggou,Tiekuang,Tiekuang Xiang,tie jiang gou,tie kuang,tie kuang xiang,铁匠沟,铁矿,铁矿乡', 29.2396900, 107.4381500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25718, 'Zhaojia', 'Zhaojia', 'Gaoyan,Zhaojia,Zhaojia Xiang,gao yan,zhao jia,zhao jia xiang,赵家,赵家乡,高岩', 29.2661600, 107.5495400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25719, 'Huangying', 'Huangying', 'Huangying,Huangying Xiang,Qiaoshang,huang ying,huang ying xiang,qiao shang,桥上,黄莺,黄莺乡', 29.2139000, 107.6853300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25720, 'Canggou', 'Canggou', 'Canggou,Canggou Xiang,cang gou,cang gou xiang,沧沟,沧沟乡', 29.4465500, 107.9699800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25721, 'Jielong', 'Jielong', 'Jielong,Jielong Xiang,jie long,jie long xiang,接龙,接龙乡', 29.5962400, 107.8946700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25722, 'Houping', 'Houping', 'Houping,Houping Xiang,hou ping,hou ping xiang,后坪,后坪乡', 29.6019900, 108.0295100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25723, 'Tudi', 'Tudi', 'Tudi,Tudi Xiang,tu de,tu de xiang,土地,土地乡', 29.5049400, 107.8999800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25724, 'Zili', 'Zili', 'Zili,Zili Xiang,zi li,zi li xiang,梓里,梓里乡', 29.5662700, 107.3713200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25725, 'Taihe', 'Taihe', 'Taihe,Taihe Xiang,tai he,tai he xiang,太和,太和乡', 29.5239900, 107.3143900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25726, 'Jubao', 'Jubao', 'Jubao,Jubao Xiang,ju bao,ju bao xiang,聚宝,聚宝乡', 29.4086800, 107.2098800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25727, 'Tongle', 'Tongle', 'Tongle,Tongle Xiang,tong le,tong le xiang,同乐,同乐乡', 29.4612100, 107.1970300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25728, 'Xincun', 'Xincun', 'Xincun,Xincun Xiang,xin cun,xin cun xiang,新村,新村乡', 29.4069900, 107.0652600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25729, 'Mingjia', 'Mingjia', 'Mingjia,Mingjia Xiang,ming jia,ming jia xiang,明家,明家乡', 29.5036100, 107.0594700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25730, 'Zengfu', 'Zengfu', 'Zengfu,Zengfu Xiang,zeng fu,zeng fu xiang,增福,增福乡', 29.5106600, 106.9857700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25731, 'Shihe', 'Shihe', 'Shihe,Shihe Xiang,shi he,shi he xiang,石和,石和乡', 29.7312700, 107.0509000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25732, 'Huimin', 'Huimin', 'Huimin,Huimin Xiang,hui min,hui min xiang,惠民,惠民乡', 29.6156000, 107.2328600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25733, 'Baozi', 'Baozi', 'Baozi,bao zi,堡子', 29.6070300, 107.1754400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25734, 'Longqiao', 'Longqiao', 'Longqiao,long qiao,龙桥', 29.7103400, 107.2943700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25735, 'Lizhi', 'Lizhi', 'Fuling Qu,Lizhi,Lizhi Jiedao,fu ling qu,li zhi,li zhi jie dao,涪陵区,荔枝,荔枝街道', 29.7031700, 107.3952100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25736, 'Wulongshan', 'Wulongshan', 'Wulongshan,wu long shan,武隆山', 29.5303800, 107.5596700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25737, 'Shanwo', 'Shanwo', 'Changlinggang,Shanwo,Shanwo Xiang,shan wo,shan wo xiang,zhang ling gang,山窝,山窝乡,长岭杠', 29.6105900, 107.5675100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25738, 'Damu', 'Damu', 'Damu,Damu Xiang,da mu,da mu xiang,大木,大木乡', 29.6190400, 107.6631600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25739, 'Luoyun', 'Luoyun', 'Luoyun,Luoyun Xiang,luo yun,luo yun xiang,罗云,罗云乡', 29.7807200, 107.5979000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25740, 'Nantuo', 'Nantuo', 'Nantuo,Nantuo Zhen,nan tuo,nan tuo zhen,南沱,南沱镇', 29.8604500, 107.5187800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25741, 'Qingxi', 'Qingxi', 'Qingxi,Qingxi Zhen,qing xi,qing xi zhen,清溪,清溪镇', 29.7984600, 107.4578700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25742, 'Tiantai', 'Tiantai', 'Tiantai,Tiantai Xiang,Tiantaisi,tian tai,tian tai si,tian tai xiang,天台,天台乡,天台寺', 29.6543800, 107.4557600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25743, 'Baisheng', 'Baisheng', 'Baijiachang,Baisheng,Baisheng Zhen,bai jia chang,bai sheng,bai sheng zhen,百家场,百胜,百胜镇', 29.8135100, 107.3926100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25744, 'Renyi', 'Renyi', 'Renyi,Renyi Xiang,Yihechang,ren yi,ren yi xiang,yi he chang,义和场,仁义,仁义乡', 29.8856100, 107.5921300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25745, 'Conglin', 'Conglin', 'Conglin,Conglin Xiang,Zhongxinchang,cong lin,cong lin xiang,zhong xin chang,丛林,丛林乡,中心场', 29.8695200, 107.3466500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25746, 'Shilong', 'Shilong', 'Shilong,Shilong Xiang,shi long,shi long xiang,石龙,石龙乡', 29.8152300, 107.2949600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25747, 'Zhihan', 'Zhihan', 'Zhihan,Zhihan Zhen,zhi han,zhi han zhen,致韩,致韩镇', 29.7972700, 107.2713700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25748, 'Yihe', 'Yihe', 'Yihe,Yihe Zhen,yi he,yi he zhen,义和,义和镇', 29.7373400, 107.2191800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25749, 'Yunji', 'Yunji', 'Huazhongcun,Yunji,Yunji Zhen,hua zhong cun,yun ji,yun ji zhen,云集,云集镇,华中村', 29.9194300, 107.3404100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25750, 'Dandu', 'Dandu', 'Dandu,dan du,但渡', 29.8367000, 107.1464600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25751, 'Changshouhu', 'Changshouhu', 'Changshouhu,Changshouhu Zhen,zhang shou hu,zhang shou hu zhen,长寿湖,长寿湖镇', 29.9053600, 107.2378900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25752, 'Haitang', 'Haitang', 'Haitang,Haitang Zhen,hai tang,hai tang zhen,海棠,海棠镇', 30.1717300, 107.2299100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25753, 'Shiyan', 'Shiyan', 'Shiyan,Shiyan Zhen,shi yan,shi yan zhen,石堰,石堰镇', 30.0834500, 107.1722100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25754, 'Longhe', 'Longhe', 'Longhe,Longhe Zhen,long he,long he zhen,龙河,龙河镇', 30.0175300, 107.1804400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25755, 'Fengcheng', 'Fengcheng', 'Changshou Qu,Fengcheng,Fengcheng Jiedao,feng cheng,feng cheng jie dao,zhang shou qu,凤城,凤城街道,长寿区', 29.8281100, 107.0637900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25756, 'Jiangnan', 'Jiangnan', 'Jiangnan,Jiangnan Zhen,Xinchang,jiang nan,jiang nan zhen,xin chang,新场,江南,江南镇', 29.7931300, 107.0371500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25757, 'Bake', 'Bake', 'Bake,Bake Zhen,ba ke,ba ke zhen,八颗,八颗镇', 29.9005900, 107.0229000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25758, 'Dawan', 'Dawan', 'Dawan,da wan,大湾', 30.0196300, 106.8202300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25759, 'Gulu', 'Gulu', 'Gulu,Gulu Zhen,gu lu,gu lu zhen,古路,古路镇', 29.8388500, 106.7426000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25760, 'Jindaoxia', 'Jindaoxia', 'Jindaoxia,Jindaoxia Zhen,jin dao xia,jin dao xia zhen,金刀峡,金刀峡镇', 30.0052800, 106.6518700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25761, 'Dazhulin', 'Dazhulin', 'Dashichang,Dazhulin,Dazhulin Jiedao,da shi chang,da zhu lin,da zhu lin jie dao,大石场,大竹林,大竹林街道', 29.6277400, 106.4626900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25762, 'Lijia', 'Lijia', 'Lijia,Lijia Zhen,li jia,li jia zhen,礼嘉,礼嘉镇', 29.6787800, 106.4931200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25763, 'Shuangfengqiao', 'Shuangfengqiao', 'Shuangfengqiao,Shuangfengqiao Jiedao,Yubei Qu,shuang feng qiao,shuang feng qiao jie dao,yu bei qu,双凤桥,双凤桥街道,渝北区', 29.7185900, 106.6271200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25764, 'Huixing', 'Huixing', 'Huanggeping,Huixing,Huixing Jiedao,huang ge ping,hui xing,hui xing jie dao,回兴,回兴街道,黄葛坪', 29.6840300, 106.6148600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25765, 'Tianfu', 'Tianfu', 'Tianfu,Tianfu Zhen,tian fu,tian fu zhen,天府,天府镇', 29.8740500, 106.4981600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25766, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Zhen,Fuxingchang,fu xing,fu xing chang,fu xing zhen,复兴,复兴场,复兴镇', 29.8190500, 106.5571400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25767, 'Shijialiang', 'Shijialiang', 'Shijialiang,Shijialiang Zhen,Xinhualu,shi jia liang,shi jia liang zhen,xin hua lu,新华路,施家梁,施家梁镇', 29.7878800, 106.4724400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25768, 'Dongyang', 'Dongyang', 'Dongyang,Dongyang Jiedao,dong yang,dong yang jie dao,东阳,东阳街道', 29.8329100, 106.4506600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25769, 'Chaoyang', 'Chaoyang', 'Chaoyang,Chaoyang Jiedao,chao yang,chao yang jie dao,朝阳,朝阳街道', 29.8306000, 106.4404200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25770, 'Longfeng', 'Longfeng', 'Longfeng,Longfeng Jiedao,long feng,long feng jie dao,龙凤,龙凤街道', 29.8152700, 106.4290600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25771, 'Dongmugou', 'Dongmugou', 'Dongmugou,Xiaogangfang,dong mu gou,xiao gang fang,小缸房,栋木沟', 39.8565600, 111.4756600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25772, 'Beibao', 'Beibao', 'Beibao,bei bao,北堡', 39.6501900, 111.8368300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25773, 'Shuanghuai', 'Shuanghuai', 'Shuanghuai,Shuanghuai Zhen,Weixichang,shuang huai,shuang huai zhen,wei xi chang,双槐,双槐镇,渭溪场', 30.1841600, 106.5558000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25774, 'Shuangfeng', 'Shuangfeng', 'Shuangfeng,Shuangfeng Zhen,shuang feng,shuang feng zhen,双凤,双凤镇', 30.0233300, 106.4296300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25775, 'Shitan', 'Shitan', 'Shitan,Shitan Zhen,shi tan,shi tan zhen,狮滩,狮滩镇', 30.0689600, 106.5029100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25776, 'Xiaojia', 'Xiaojia', 'Xiaojia,Xiaojia Zhen,xiao jia,xiao jia zhen,肖家,肖家镇', 30.2883800, 106.4703100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25777, 'Laitan', 'Laitan', 'Laitan,Laitan Zhen,Shanglaitan,lai tan,lai tan zhen,shang lai tan,上涞滩,涞滩,涞滩镇', 30.1758200, 106.4862400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25778, 'Shayu', 'Shayu', 'Shayu,Shayu Zhen,sha yu,sha yu zhen,沙鱼,沙鱼镇', 30.2428300, 106.3673300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25779, 'Qiantang', 'Qiantang', 'Qiantang,Qiantang Zhen,qian tang,qian tang zhen,钱塘,钱塘镇', 30.1842400, 106.3165000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25780, 'Dashi', 'Dashi', 'Dashi,Dashi Zhen,da shi,da shi zhen,大石,大石镇', 30.0937200, 106.2222700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25781, 'Gulou', 'Gulou', 'Gulou,Gulou Zhen,gu lou,gu lou zhen,古楼,古楼镇', 30.1759900, 106.1716800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25782, 'Yanwo', 'Yanwo', 'Wanguchang,Yanwo,Yanwo Zhen,wan gu chang,yan wo,yan wo zhen,万古场,燕窝,燕窝镇', 30.3317800, 106.0735700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25783, 'Erlang', 'Erlang', 'Erlang,Erlang Zhen,er lang,er lang zhen,二郎,二郎镇', 30.3626400, 105.9921300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25784, 'Longfeng', 'Longfeng', 'Longfeng,Longfeng Zhen,long feng,long feng zhen,龙凤,龙凤镇', 30.2681600, 106.0228200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25785, 'Longxing', 'Longxing', 'Longxing,Longxing Zhen,Nu''erbei,Nü’erbei,long xing,long xing zhen,nu r bei,女儿碑,隆兴,隆兴镇', 30.1919100, 106.0588000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25786, 'Yangcheng', 'Yangcheng', 'Yangcheng,Yangcheng Jiedao,yang cheng,yang cheng jie dao,阳城,阳城街道', 29.9996800, 106.2560400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25787, 'Diaoyucheng', 'Diaoyucheng', 'Diaoyucheng,Diaoyucheng Jiedao,diao yu cheng,diao yu cheng jie dao,钓鱼城,钓鱼城街道', 29.9987800, 106.2661300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25788, 'Nanjin', 'Nanjin', 'Hechuan Qu,Nanjin,Nanjin Jiedao,he chuan qu,nan jin,nan jin jie dao,南津,南津街道,合川区', 29.9849700, 106.2652900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25789, 'Mixin', 'Mixin', 'Mixin,Mixin Zhen,mi xin,mi xin zhen,米心,米心镇', 30.3798500, 105.7678100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25790, 'Baolong', 'Baolong', 'Baolong,Baolong Zhen,bao long,bao long zhen,宝龙,宝龙镇', 30.3549800, 105.9203400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25791, 'Qunli', 'Qunli', 'Lixiangsi,Qunli,Qunli Zhen,li xiang si,qun li,qun li zhen,利相寺,群力,群力镇', 30.3009300, 105.8376600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25792, 'Huayan', 'Huayan', 'Huayan,Huayan Zhen,hua yan,hua yan zhen,花岩,花岩镇', 30.2568100, 105.6423400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25793, 'Biekou', 'Biekou', 'Biekou,Biekou Xiang,bie kou,bie kou xiang,别口,别口乡', 30.1165600, 105.9584300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25794, 'Longshi', 'Longshi', 'Longshi,Longshi Zhen,Shilongchang,long shi,long shi zhen,shi long chang,石龙场,龙石,龙石镇', 29.5591300, 105.6169500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25795, 'Lijia', 'Lijia', 'Lijia,Lijia Zhen,li jia,li jia zhen,李家,李家镇', 29.6320100, 105.5349100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25796, 'Gaoping', 'Gaoping', 'Gaoping,Gaoping Xiang,Qinglongchang,gao ping,qing long chang,青龙场,高坪', 29.8410200, 105.6666100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25797, 'Baoding', 'Baoding', 'Baoding,bao ding,宝顶', 29.7488000, 105.7584300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25798, 'Gulong', 'Gulong', 'Gulong,Gulong Xiang,Longjia Shuijing Wuji,gu long,gu long xiang,long jia shui jing wu ji,古龙,古龙乡,龙家水井屋基', 29.7047200, 106.0038300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25799, 'Zhifeng', 'Zhifeng', 'Zhifeng,Zhifeng Zhen,zhi feng,zhi feng zhen,智凤,智凤镇', 29.6544000, 105.7841600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25800, 'Shiwan', 'Shiwan', 'Shiwan,shi wan,拾万', 29.6147500, 105.8946300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25801, 'Yulong', 'Yulong', 'Yulong,Yulong Zhen,yu long,yu long zhen,玉龙,玉龙镇', 29.5461500, 105.8104400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25802, 'Tongqiao', 'Tongqiao', 'Chadianzi,Tongqiao,Tongqiao Zhen,cha dian zi,tong qiao,tong qiao zhen,茶店子,通桥,通桥镇', 29.5215500, 105.7670800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25803, 'Longtanzi', 'Longtanzi', 'Longtanzi,Longtanzi Jiedao,long tan zi,long tan zi jie dao,龙滩子,龙滩子街道', 29.5008100, 105.7971500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25804, 'Shuanglu', 'Shuanglu', 'Shuanglu,Shuanglu Jiedao,Shuangqiao Qu,shuang lu,shuang lu jie dao,shuang qiao qu,双桥区,双路,双路街道', 29.4854300, 105.7629000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25805, 'Tangxiang', 'Tangxiang', 'Dazu Xian,Tangxiang,Tangxiang Jiedao,da zu xian,tang xiang,tang xiang jie dao,大足县,棠香,棠香街道', 29.7022600, 105.7236300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25806, 'Qingliu', 'Qingliu', 'Qingliu,Qingliu Zhen,Tonggu,qing liu,qing liu zhen,tong gu,清流,清流镇,铜鼓', 29.5910500, 105.3273400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25807, 'Longji', 'Longji', 'Gaolongchang,Longji,Longji Zhen,gao long chang,long ji,long ji zhen,高龙场,龙集,龙集镇', 29.4619600, 105.4047300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25808, 'Guchang', 'Guchang', 'Guchang,Guchang Zhen,Liangjiachang,gu chang,gu chang zhen,liang jia chang,古昌,古昌镇,梁家场', 29.4868400, 105.5886300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25809, 'Yangjiayao', 'Yangjiayao', 'Yangjiayao,yang jia yao,杨家窑', 39.9699300, 111.7958700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25810, 'Qingjiang', 'Qingjiang', 'Qingjiang,Qingjiang Zhen,qing jiang,qing jiang zhen,清江,清江镇', 29.2834300, 105.4734300, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25811, 'Qingsheng', 'Qingsheng', 'Huoshaodian,Qingsheng,Qingsheng Zhen,huo shao dian,qing sheng,qing sheng zhen,清升,清升镇,火烧店', 29.3183400, 105.5109600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25812, 'Yongrong', 'Yongrong', 'Yongrong,Yongrong Zhen,Yongxingchang,yong rong,yong rong zhen,yong xing chang,永兴场,永荣,永荣镇', 29.3389800, 105.6577800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25813, 'Shenglilu', 'Shenglilu', 'Shenglilu,Shenglilu Jiedao,sheng li lu,sheng li lu jie dao,胜利路,胜利路街道', 29.3504800, 105.8775000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25814, 'Nandajie', 'Nandajie', 'Nandajie,Nandajie Jiedao,nan da jie,nan da jie jie dao,南大街,南大街街道', 29.3377300, 105.8923700, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25815, 'Zhongshanlu', 'Zhongshanlu', 'Yongchuan Qu,Zhongshanlu,Zhongshanlu Jiedao,yong chuan qu,zhong shan lu,zhong shan lu jie dao,中山路,中山路街道,永川区', 29.3569500, 105.9043500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25816, 'Gaolou', 'Gaolou', 'Gaolou,Gaolou Zhen,gao lou,gao lou zhen,高楼,高楼镇', 30.0476700, 105.9792100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25817, 'Weixin', 'Weixin', 'Weixin,Weixin Zhen,wei xin,wei xin zhen,维新,维新镇', 30.0468000, 105.8914600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25818, 'Shaoyun', 'Shaoyun', 'Shaoyun,Shaoyun Zhen,shao yun,shao yun zhen,少云,少云镇', 29.9845800, 105.9842100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25819, 'Erping', 'Erping', 'Erlangchang,Erping,Erping Zhen,er lang chang,er ping,er ping zhen,二坪,二坪镇,二郎场', 29.8989200, 106.1567900, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25820, 'Dongcheng', 'Dongcheng', 'Dongcheng,Dongcheng Jiedao,dong cheng,dong cheng jie dao,东城,东城街道', 29.8477500, 106.0732600, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25821, 'Nancheng', 'Nancheng', 'Nancheng,Nancheng Jiedao,nan cheng,nan cheng jie dao,南城,南城街道', 29.8354800, 106.0517200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25822, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Xiang,qing long,qing long xiang,庆隆,庆隆乡', 29.7777400, 106.1368200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25823, 'Xihe', 'Xihe', 'Xihe,Xihe Zhen,xi he,xi he zhen,西河,西河镇', 29.5742300, 105.9227500, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25824, 'Weilong', 'Weilong', 'Weilong,Weilong Zhen,Zhuanlongchang,wei long,wei long zhen,zhuan long chang,围龙,围龙镇,转龙场', 29.6231700, 106.0067000, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25825, 'Qinggang', 'Qinggang', 'Dazihao,Qinggang,Qinggang Jiedao,da zi hao,qing gang,qing gang jie dao,大字号,青杠,青杠街道', 29.4677000, 106.2361800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25826, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Zhen,Xinchang,san he,san he zhen,xin chang,三合,三合镇,新场', 29.3483200, 106.1002800, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25827, 'Jianlong', 'Jianlong', 'Jianlong,Jianlong Xiang,jian long,jian long xiang,健龙,健龙乡', 29.3586000, 106.1852200, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25828, 'Shuangfu', 'Shuangfu', 'Shuangfu,Shuangfu Zhen,Shuanghechang,shuang fu,shuang fu zhen,shuang he chang,双河场,双福,双福镇', 29.4135900, 106.2701400, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25829, 'Xingbin', 'Xingbin', 'Xingbin,Xingbin Jiedao,xing bin,xing bin jie dao,杏滨,杏滨街道', 24.5690900, 118.0345100, 'CN', '2012-11-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25830, 'Gangwan', 'Gangwan', 'Gangwan,Gangwan Jieodao,gang wan,gang wan jie dao,港湾,港湾街道', 36.8803000, 122.4245100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25831, 'Hushan', 'Hushan', 'Hushan,Hushan Zhen,hu shan,hu shan zhen,虎山,虎山镇', 36.9534100, 122.2354300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25832, 'Huancuilou', 'Huancuilou', 'Huancui,Huancui Qu,Huancuilou,Huancuilou Jiedao,huan cui,huan cui lou,huan cui lou jie dao,huan cui qu,环翠,环翠区,环翠楼,环翠楼街道', 37.5004100, 122.1139800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25833, 'Wenquan', 'Wenquan', 'Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 37.3760000, 122.1640700, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25834, 'Xiyuan', 'Xiyuan', 'Xiyuan,Xiyuan Jiedao,xi yuan,xi yuan jie dao,西苑,西苑街道', 37.4120000, 122.1470300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25835, 'Huangguan', 'Huangguan', 'Huangguan,Huangguan Jiedao,huang guan,huang guan jie dao,皇冠,皇冠街道', 37.4433100, 122.1473500, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25836, 'Jieshi', 'Jieshi', 'Jieshi,Jieshi Zhen,jie shi,jie shi zhen,界石,界石镇', 37.2744200, 121.8667300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25837, 'Dagushan', 'Dagushan', 'Dagushan,Dagushan Zhen,da gu shan,da gu shan zhen,大孤山,大孤山镇', 36.9173300, 121.6283000, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25838, 'Xujia', 'Xujia', 'Xujia,Xujia Zhen,xu jia,xu jia zhen,徐家,徐家镇', 36.9083100, 121.7492600, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25839, 'Xiachu', 'Xiachu', 'Xiachu,Xiachu Zhen,xia chu,xia chu zhen,下初,下初镇', 37.0329600, 121.6076300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25840, 'Wenhua', 'Wenhua', 'Mouping,Mouping Qu,Wenhua,Wenhua Jiedao,mou ping,mou ping qu,wen hua,wen hua jie dao,文化,文化街道,牟平,牟平区', 37.3910600, 121.5895900, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25841, 'Yangmadao', 'Yangmadao', 'Yangmadao,Yangmadao Jiedao,yang ma dao,yang ma dao jie dao,养马岛,养马岛街道', 37.4567600, 121.6100200, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25842, 'Jiejiazhuang', 'Jiejiazhuang', 'Jiejiazhuang,Jiejiazhuang Zhen,jie jia zhuang,jie jia zhuang zhen,解甲庄,解甲庄镇', 37.3933600, 121.4879400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25843, 'Huanghai', 'Huanghai', 'Huanghai,Huanghai Jiedao,Laishan,Laishan Qu,huang hai,huang hai jie dao,lai shan,lai shan qu,莱山,莱山区,黄海,黄海街道', 37.4887000, 121.4403800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25844, 'Xiangyang', 'Xiangyang', 'Xiangyang,Xiangyang Jiedao,Zhifu,Zhifu Qu,xiang yang,xiang yang jie dao,zhi fu,zhi fu qu,向阳,向阳街道,芝罘,芝罘区', 37.5315700, 121.3938800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25845, 'Binhailu', 'Binhailu', 'Binhailu,Binhailu Jiedao,bin hai lu,bin hai lu jie dao,滨海路,滨海路街道', 37.4408100, 121.4305100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25846, 'Wanggezhuang', 'Wanggezhuang', 'Wanggezhuang,Wanggezhuang Zhen,wang ge zhuang,wang ge zhuang zhen,王格庄,王格庄镇', 37.1698700, 121.4021600, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25847, 'Xinfu', 'Xinfu', 'Xinfu,Xinfu Jiedao,xin fu,xin fu jie dao,辛福,辛福街道', 37.5679100, 121.3436800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25848, 'Fenghuangtai', 'Fenghuangtai', 'Fenghuangtai,Fenghuangtai Jiedao,feng huang tai,feng huang tai jie dao,凤凰台,凤凰台街道', 37.5394600, 121.3266100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25849, 'Zhichu', 'Zhichu', 'Zhichu,Zhichu Jiedao,zhi chu,zhi chu jie dao,芝楚,芝楚街道', 37.5176900, 121.3086700, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25850, 'Shihuiyao', 'Shihuiyao', 'Shihuiyao,Shihuiyao Jiedao,shi hui yao,shi hui yao jie dao,世回尧,世回尧街道', 37.5092600, 121.3680800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25851, 'Zhanggezhuang', 'Zhanggezhuang', 'Zhanggezhuang,Zhanggezhuang Zhen,zhang ge zhuang,zhang ge zhuang zhen,张格庄,张格庄镇', 37.3752900, 121.1864300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25852, 'Menlou', 'Menlou', 'Menlou,Menlou Zhen,men lou,men lou zhen,门楼,门楼镇', 37.4172300, 121.2321900, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25853, 'Fuxin', 'Fuxin', 'Fuxin,Fuxin Jiedao,fu xin,fu xin jie dao,福新,福新街道', 37.5286600, 121.1976300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25854, 'Xingang', 'Xingang', 'Xingang,Xingang Jiedao,xin gang,xin gang jie dao,新港,新港街道', 37.7941300, 120.8719600, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25855, 'Nanwang', 'Nanwang', 'Nanwang,Nanwang Zhen,nan wang,nan wang zhen,南王,南王镇', 37.7633900, 120.7928900, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25856, 'Xiaomenjia', 'Xiaomenjia', 'Xiaomenjia,Xiaomenjia Zhen,xiao men jia,xiao men jia zhen,小门家,小门家镇', 37.6271900, 120.7968100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25857, 'Sujiadian', 'Sujiadian', 'Sujiadian,Sujiadian Zhen,su jia dian,su jia dian zhen,苏家店,苏家店镇', 37.4208000, 120.6758900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25858, 'Gedaliang', 'Gedaliang', 'Gedaliang,Gedaliang Xiang,ge da liang,ge da liang xiang,格达良,格达良乡', 39.7698000, 76.6480300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25859, 'Alage’er', 'Alage''er', 'Alage''er,Alage''er Xiang,Alage’er,Alage’er Xiang,a la ge er,a la ge er xiang,阿拉格尔,阿拉格尔乡', 39.3429500, 77.9005500, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25860, 'Yingwusitang', 'Yingwusitang', 'Yingwusitang,Yingwusitang Xiang,ying wu si tang,ying wu si tang xiang,英吾斯唐,英吾斯唐乡', 39.1653800, 77.6203500, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25861, 'Ahonglukumu', 'Ahonglukumu', 'Ahonglukumu,Ahonglukumu Xiang,a hong lu ku mu,a hong lu ku mu xiang,阿洪鲁库木,阿洪鲁库木乡', 39.1936500, 77.3260500, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25862, 'Tajike’abati', 'Tajike''abati', 'Tajike''abati,Tajike''abati Zhen,Tajike’abati,Tajike’abati Zhen,ta ji ke a ba ti,ta ji ke a ba ti zhen,塔吉克阿巴提,塔吉克阿巴提镇', 39.0763000, 77.1181400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25863, 'Bayi’awati', 'Bayi''awati', 'Bayi''awati,Bayi''awati Xiang,Bayi’awati,Bayi’awati Xiang,ba yi a wa ti,ba yi a wa ti xiang,巴依阿瓦提,巴依阿瓦提乡', 39.0902900, 77.0841300, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25864, 'Tieremu', 'Tieremu', 'Tieremu,Tieremu Xiang,tie re mu,tie re mu xiang,铁热木,铁热木乡', 39.1303900, 76.9940400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25865, 'Seyeke', 'Seyeke', 'Seyeke,Seyeke Xiang,se ye ke,se ye ke xiang,色也克,色也克乡', 39.2125200, 76.6649400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25866, 'Aiximan', 'Aiximan', 'Aiximan,Aiximan Zhen,ai xi man,ai xi man zhen,艾西曼,艾西曼镇', 39.2771100, 76.5147800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25867, 'Yekexianbaibazha', 'Yekexianbaibazha', 'Yekexianbaibazha,Yekexianbaibazha Xiang,ye ke xian bai ba zha,ye ke xian bai ba zha xiang,也克先拜巴扎,也克先拜巴扎乡', 39.2737400, 76.5844800, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25868, 'Yudaikelike', 'Yudaikelike', 'Yudaikelike,Yudaikelike Xiang,yu dai ke li ke,yu dai ke li ke xiang,玉代克力克,玉代克力克乡', 39.7118400, 77.7460100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25869, 'Wolituogelake', 'Wolituogelake', 'Wolituogelake,Wolituogelake Xiang,wo li tuo ge la ke,wo li tuo ge la ke xiang,卧里托格拉克,卧里托格拉克乡', 39.6917900, 77.2784600, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25870, 'Kezileboyi', 'Kezileboyi', 'Kezileboyi,Kezileboyi Xiang,ke zi lei bo yi,ke zi lei bo yi xiang,克孜勒博依,克孜勒博依乡', 39.3853300, 76.5470100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25871, 'Jiangbazi', 'Jiangbazi', 'Jiangbazi,Jiangbazi Xiang,jiang ba zi,jiang ba zi xiang,江巴孜,江巴孜乡', 39.4472400, 76.7028700, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25872, 'Guleluke', 'Guleluke', 'Guleluke,Guleluke Xiang,gu lei lu ke,gu lei lu ke xiang,古勒鲁克,古勒鲁克乡', 39.7734500, 76.9726700, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25873, 'Hexia’awati', 'Hexia''awati', 'Hexia''awati,Hexia''awati Xiang,Hexia’awati,Hexia’awati Xiang,he xia a wa ti,he xia a wa ti xiang,和夏阿瓦提,和夏阿瓦提乡', 39.6193500, 76.7913400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25874, 'Yingmaili', 'Yingmaili', 'Yingmaili,Yingmaili Xiang,ying mai li,ying mai li xiang,英买里,英买里乡', 39.5106800, 76.8014400, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25875, 'Xiaputule', 'Xiaputule', 'Xiaputule,xia pu tu lei,夏普吐勒', 39.4683100, 76.6177000, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25876, 'Tierimu', 'Tierimu', 'Tierimu,tie ri mu,铁日木', 39.5106800, 76.7325100, 'CN', '2012-12-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25877, 'Geluwan', 'Geluwan', 'Geluwan,Shangjiang,Shangjiang Xiang,ge lu wan,shang jiang,shang jiang xiang,上江,上江乡,格鲁湾', 27.3737400, 99.6560700, 'CN', '2015-04-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25878, 'Wuji', 'Wuji', 'Wuji,Wuji Zhen,wu ji,wu ji zhen,午极,午极镇', 37.0664600, 121.4841500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25879, 'Huo’erqi', 'Huo''erqi', 'Huo''erqi,Huo''erqi Zhen,Huo’erqi,Huo’erqi Zhen,huo er qi,huo er qi zhen,霍尔奇,霍尔奇镇', 48.3376100, 123.3264300, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25880, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,gu shan,gu shan zhen,孤山,孤山镇', 48.3313200, 123.7680400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25881, 'Sanchahe', 'Sanchahe', 'Sanchahe,Sanchahe Zhen,san cha he,san cha he zhen,三岔河,三岔河镇', 48.6886500, 123.4423500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25882, 'Sandaogou', 'Sandaogou', 'Sandaogou,Sandaogou Xiang,san dao gou,san dao gou xiang,三道沟,三道沟乡', 48.0118800, 123.3942000, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25883, 'Liuhe', 'Liuhe', 'Liuhe,Liuhe Xiang,liu he,liu he xiang,六合,六合乡', 48.4017700, 123.9467700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25884, 'Fuxing', 'Fuxing', 'Fuxing,Fuxing Zhen,fu xing,fu xing zhen,复兴,复兴镇', 48.1990100, 123.2573400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25885, 'Honghualiangzi', 'Honghualiangzi', 'Honghualiangzi,Honghualiangzi Zhen,hong hua liang zi,hong hua liang zi zhen,红花梁子,红花梁子镇', 48.1131200, 123.2463800, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25886, 'Taipingzhuang', 'Taipingzhuang', 'Taipingzhuang,Taipingzhuang Zhen,tai ping zhuang,tai ping zhuang zhen,太平庄,太平庄镇', 48.4459000, 123.6119500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25887, 'Yinhedahan’er', 'Yinhedahan''er', 'Yinhedahan''er,Yinhedahan''er Ewenkeminzu Xiang,Yinhedahan’er,Yinhedahan’er Ewenkeminzu Xiang,yin he da han er,yin he da han er e wen ke min zu xiang,音河达翰尔,音河达翰尔鄂温克民族乡', 48.0265700, 123.0108800, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25888, 'Naketa', 'Naketa', 'Naketa,Naketa Zhen,na ke ta,na ke ta zhen,那克塔,那克塔镇', 48.4024800, 123.2086400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25889, 'Baorixile', 'Baorixile', 'Baorixile,Baorixile Zhen,bao ri xi lei,bao ri xi lei zhen,宝日希勒,宝日希勒镇', 49.3467900, 119.7845900, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25890, 'Wangong', 'Wangong', 'Wangong,Wangong Zhen,wan gong,wan gong zhen,完工,完工镇', 49.1895300, 118.8900700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25891, 'Enhe Hada', 'Enhe Hada', 'Enhe Hada,Enhe Hada Zhen,en he ha da,en he ha da zhen,恩和哈达,恩和哈达镇', 53.3194600, 121.4344500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25892, 'Nuomin', 'Nuomin', 'Nuomin,Nuomin Zhen,nuo min,nuo min zhen,诺敏,诺敏镇', 49.1954600, 123.7320900, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25893, 'Yili', 'Yili', 'Yili,Yili Zhen,yi li,yi li zhen,宜里,宜里镇', 49.5603300, 124.2094400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25894, 'Guli', 'Guli', 'Guli,Guli Xiang,gu li,gu li xiang,古里,古里乡', 50.0669000, 124.9117400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25895, 'Kuleqi', 'Kuleqi', 'Kuleqi,Kuleqi Zhen,ku lei qi,ku lei qi zhen,库勒奇,库勒奇镇', 49.6675900, 124.5527400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25896, 'Bayin Tala Dahan’er Minzu', 'Bayin Tala Dahan''er Minzu', 'Bayin Tala Dahan''er Minzu,Bayin Tala Dahan''er Minzu Xiang,Bayin Tala Dahan’er Minzu,Bayin Tala Dahan’er Minzu Xiang,ba yin ta la da han er min zu,ba yin ta la da han er min zu xiang,巴音塔拉达翰尔民族,巴音塔拉达翰尔民族乡', 49.0163900, 119.7263700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25897, 'Honghua’erji', 'Honghua''erji', 'Honghua''erji,Honghua''erji Zhen,Honghua’erji,Honghua’erji Zhen,hong hua er ji,hong hua er ji zhen,红花尔基,红花尔基镇', 48.2708000, 119.9799400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25898, 'Yiminhe', 'Yiminhe', 'Yiminhe,Yiminhe Zhen,yi min he,yi min he zhen,伊敏河,伊敏河镇', 48.5866900, 119.7731700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25899, 'Haolibao', 'Haolibao', 'Haolibao,Haolibao Zhen,hao li bao,hao li bao zhen,好力堡,好力堡镇', 50.7351800, 121.4695400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25900, 'Fendou', 'Fendou', 'Fendou,Fendou Xiang,fen dou,fen dou xiang,奋斗,奋斗乡', 49.1972800, 119.7691300, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25901, 'Hake', 'Hake', 'Hake,Hake Xiang,ha ke,ha ke xiang,哈克,哈克乡', 49.1867600, 120.0697700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25902, 'Xie’ertala', 'Xie''ertala', 'Xie''ertala,Xie''ertala Zhen,Xie’ertala,Xie’ertala Zhen,xie er ta la,xie er ta la zhen,谢尔塔拉,谢尔塔拉镇', 49.3014200, 119.9086200, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25903, 'Jianshe', 'Jianshe', 'Jianshe,Jianshe Xiang,jian she,jian she xiang,建设,建设乡', 49.2552900, 119.7738500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25904, 'Xiwa’ertu', 'Xiwa''ertu', 'Xiwa''ertu,Xiwa''ertu Zhen,Xiwa’ertu,Xiwa’ertu Zhen,xi wa er tu,xi wa er tu zhen,西瓦尔图,西瓦尔图镇', 48.6654200, 124.2692600, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25905, 'Dula’er Ewenke Minzu', 'Dula''er Ewenke Minzu', 'Dula''er Ewenke Minzu,Dula''er Ewenke Minzu Xiang,Dula’er Ewenke Minzu,Dula’er Ewenke Minzu Xiang,du la er e wen ke min zu,du la er e wen ke min zu xiang,杜拉尔鄂温克民族,杜拉尔鄂温克民族乡', 48.8496900, 123.8017000, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25906, 'E’erhe', 'E''erhe', 'E''erhe,E''erhe Xiang,E’erhe,E’erhe Xiang,e er he,e er he xiang,额尔河,额尔河乡', 49.2069100, 125.0870400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25907, 'Tawen Aobao', 'Tawen Aobao', 'Tawen Aobao,Tawen Aobao Zhen,ta wen ao bao,ta wen ao bao zhen,塔温敖宝,塔温敖宝镇', 49.0571700, 124.1132800, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25908, 'Hangu Erhe', 'Hangu Erhe', 'Hangu Erhe,Hangu Erhe Zhen,han gu er he,han gu er he zhen,汉古尔河,汉古尔河镇', 48.2599600, 124.4623500, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25909, 'Dengteke', 'Dengteke', 'Dengteke,Dengteke Xiang,deng te ke,deng te ke xiang,登特科,登特科乡', 48.5979400, 124.5360900, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25910, 'Wu’erke', 'Wu''erke', 'Wu''erke,Wu''erke Xiang,Wu’erke,Wu’erke Xiang,wu er ke,wu er ke xiang,乌尔科,乌尔科乡', 48.5355200, 124.2933700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25911, 'Kuilehe', 'Kuilehe', 'Kuilehe,Kuilehe Zhen,kui lei he,kui lei he zhen,奎勒河,奎勒河镇', 49.5446500, 124.4563700, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25912, 'Woluohe', 'Woluohe', 'Woluohe,Woluohe Xiang,wo luo he,wo luo he xiang,卧罗河,卧罗河乡', 49.3107900, 124.0312300, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25913, 'Kunmi Erdi', 'Kunmi Erdi', 'Kunmi Erdi,Kunmi Erdi Xiang,kun mi er di,kun mi er di xiang,坤密尔堤,坤密尔堤乡', 48.8602000, 124.1228000, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25914, 'A’erla', 'A''erla', 'A''erla,A''erla Zhen,A’erla,A’erla Zhen,a er la,a er la zhen,阿尔拉,阿尔拉镇', 48.6799500, 124.1003400, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25915, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Zhen,bao shan,bao shan zhen,宝山,宝山镇', 48.5997800, 124.1036000, 'CN', '2013-01-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25916, 'Hulun', 'Hulun', 'Hulun,Hulun Sumu,hu lun,hu lun su mu,呼伦,呼伦苏木', 48.6490700, 116.9454800, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25917, 'A’ershan', 'A''ershan', 'A''ershan,A''ershan Sumu,A’ershan,A’ershan Sumu,a er shan,a er shan su mu,阿尔山,阿尔山苏木', 48.7013100, 116.9261100, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25918, 'Dalaidong', 'Dalaidong', 'Dalaidong,Dalaidong Sumu,da lai dong,da lai dong su mu,达来东,达来东苏木', 49.3804600, 117.1099800, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25919, 'E’erdun Wula', 'E''erdun Wula', 'E''erdun Wula,E''erdun Wula Sumu,E’erdun Wula,E’erdun Wula Sumu,e er dui wu la,e er dui wu la su mu,额尔敦乌拉,额尔敦乌拉苏木', 48.9269200, 116.7656700, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25920, 'Bei’er', 'Bei''er', 'Bei''er,Bei''er Sumu,Bei’er,Bei’er Sumu,bei er,bei er su mu,贝尔,贝尔苏木', 48.0266700, 117.4707400, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25921, 'Ke’erlun', 'Ke''erlun', 'Ke''erlun,Ke''erlun Sumu,Ke’erlun,Ke’erlun Sumu,ke er lun,ke er lun su mu,克尔伦,克尔伦苏木', 48.1644500, 115.8568200, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25922, 'Baogede Wula', 'Baogede Wula', 'Baogede Wula,Baogede Wula Sumu,bao ge de wu la,bao ge de wu la su mu,宝格德乌拉,宝格德乌拉苏木', 48.4564200, 117.2475800, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25923, 'Hangwula', 'Hangwula', 'Hangwula,Hangwula Sumu,hang wu la,hang wu la su mu,杭乌拉,杭乌拉苏木', 48.4685200, 116.4618000, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25924, 'Dalai', 'Dalai', 'Dalai,Dalai Sumu,da lai,da lai su mu,达来,达来苏木', 49.1267300, 116.9710600, 'CN', '2013-01-13', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25925, 'Aduo', 'Aduo', 'Aduo,Aduo Xiang,a duo,a duo xiang,阿多,阿多乡', 32.9399900, 95.0494300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25926, 'Linxin', 'Linxin', 'Linxin,Lixin Xiang,Yongkeda,li xin,li xin xiang,yong ke da,永科达,立新,立新乡', 33.6018000, 96.0621600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25927, 'Wa’eryi', 'Wa''eryi', 'Mange Ertang,Wa''eryi,Wa''eryi Xiang,Wa’eryi,Wa’eryi Xiang,man ge er tang,wa er yi,wa er yi xiang,哇尔依,哇尔依乡,满格尔塘', 33.3239000, 100.5425200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25928, 'Suohurima', 'Suohurima', 'Duda,Suohurima,Suohurima Xiang,dou da,suo hu ri ma,suo hu ri ma xiang,索乎日麻,索乎日麻乡,都达', 33.5291500, 100.9303900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25929, 'Zhalinghu', 'Zhalinghu', 'Hamei Chaka,Zhalinghu,Zhalinghu Xiang,ha mei cha ka,zha ling hu,zha ling hu xiang,哈美茶卡,扎陵湖,扎陵湖乡', 35.0852400, 97.9080700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25930, 'Heihe', 'Heihe', 'Heihe,Heihe Xiang,Zuowei Longwa,hei he,hei he xiang,zuo wei long wa,作维隆哇,黑河,黑河乡', 34.7967700, 98.1292300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25931, 'Tehetu', 'Tehetu', 'Chamu Jueda,Tehetu,Tehetu Xiang,cha mu jue da,te he tu,te he tu xiang,查木觉达,特合土,特合土乡', 33.8951300, 99.1308300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25932, 'Changmahe', 'Changmahe', 'Changmahe,Changmahe Xiang,chang ma he,chang ma he xiang,昌麻河,昌麻河乡', 34.4863900, 99.1815300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25933, 'Moba', 'Moba', 'Moba,Moba Xiang,Sanani Jiangda,mo ba,mo ba xiang,sa na ni jiang da,莫坝,莫坝乡,萨那尼江达', 33.2684300, 99.6317500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25934, 'Jimai', 'Jimai', 'Dari,Dari Xian,Jimai,Jimai Zhen,da ri,da ri xian,ji mai,ji mai zhen,吉迈,吉迈镇,达日,达日县', 33.7515500, 99.6482100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25935, 'Dongqinggou', 'Dongqinggou', 'Dongqinggou,Dongqinggou Xiang,Quru Matang,dong qing gou,dong qing gou xiang,qu ru ma tang,东倾沟,东倾沟乡,曲如麻堂', 34.5238400, 99.9680400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25936, 'Dawu', 'Dawu', 'Dawu,Dawu Xiang,Sangduo,da wu,da wu xiang,sang duo,大武,大武乡,桑多', 34.4930500, 100.2156600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25937, 'Wutumeiren', 'Wutumeiren', 'Wutumeiren,Wutumeiren Xiang,wu tu mei ren,wu tu mei ren xiang,乌图美仁,乌图美仁乡', 36.9093400, 93.1611300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25938, 'Haquxiang', 'Haquxiang', 'Haquxiang,ha qu xiang,哈区乡', 36.4313000, 94.8228500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25939, 'Dongfeng', 'Dongfeng', 'Dongfeng,Dongfeng Xiang,dong feng,dong feng xiang,东风,东风乡', 34.0896000, 96.2265400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25940, 'Gaduo', 'Gaduo', 'Gaduo,Gaduo Xiang,Kalong,ga duo,ga duo xiang,ka long,卡龙,尕朵,尕朵乡', 33.6748200, 96.6965200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25941, 'Xiangjia', 'Xiangjia', 'Lixin,Xiangjia,Xiangjia Xiang,li xin,xiang jia,xiang jia xiang,立新,香加,香加乡', 35.9387100, 97.9290900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25942, 'Sulu', 'Sulu', 'Pusaima,Sulu,Sulu Xiang,pu sai ma,su lu,su lu xiang,普赛玛,苏鲁,苏鲁乡', 32.4994100, 95.2858000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25943, 'Jieduo', 'Jieduo', 'Chaqugao,Jieduo,Jieduo Xiang,cha qu gao,jie duo,jie duo xiang,查曲高,结多,结多乡', 32.6007300, 95.3043000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25944, 'Zhiqin', 'Zhiqin', 'Chimida,Zhiqin,Zhiqin Xiang,chi mi da,zhi qin,zhi qin xiang,知钦,知钦乡,赤米达', 32.6606900, 100.4947800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25945, 'Duogongma', 'Duogongma', 'Duogongma,Duogongma Xiang,Suohuatang,duo gong ma,duo gong ma xiang,suo hua tang,多贡麻,多贡麻乡,索华塘', 33.0959600, 100.5952900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25946, 'Jiangritang', 'Jiangritang', 'Beizha Gongba,Jiangritang,Jiangritang Xiang,bei zha gong ba,jiang ri tang,jiang ri tang xiang,江日堂,江日堂乡,贝扎贡巴', 32.9191800, 100.7719800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25947, 'Qiakeri', 'Qiakeri', 'Qiakeri,Qiakeri Xiang,Xiaderi,qia ke ri,qia ke ri xiang,xia de ri,夏德日,恰科日,恰科日乡', 35.0416100, 101.4715300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25948, 'Xibusha', 'Xibusha', 'Garuo Rensong,Xibusha,Xibusha Xiang,ga ruo ren song,xi bo sha,xi bo sha xiang,尕若任宋,西卜沙,西卜沙乡', 35.0304100, 101.6989100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25949, 'Duofudu', 'Duofudu', 'Duofudu,Duofudu Xiang,duo fu dun,duo fu dun xiang,多福顿,多福顿乡', 35.2004800, 101.7852500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25950, 'Duosong', 'Duosong', 'Duosong,Duosong Xiang,Shangduosong,duo song,duo song xiang,shang duo song,上多松,多松,多松乡', 34.3299700, 101.3212200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25951, 'Ningmute', 'Ningmute', 'Ningmute,Ningmute Xiang,ning mu te,ning mu te xiang,宁木特,宁木特乡', 34.5933300, 101.3342600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25952, 'Tuoyema', 'Tuoyema', 'Tuoyema,Tuoyema Xiang,tuo ye ma,tuo ye ma xiang,托叶玛,托叶玛乡', 34.5990900, 101.5314300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25953, 'Kesheng', 'Kesheng', 'Kesheng,Kesheng Xiang,Xiangzasi,ke sheng,ke sheng xiang,xiang zha si,柯生,柯生乡,香扎寺', 34.2088600, 101.5528800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25954, 'Youganning', 'Youganning', 'Henan Menggu Zu,Henan Menggu Zu Zizhi Xian,Youganning,Youganning Zhen,he nan meng gu zu,he nan meng gu zu zi zhi xian,you gan ning,you gan ning zhen,优干宁,优干宁镇,河南蒙古族,河南蒙古族自治县', 34.7356400, 101.6114100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25955, 'Sai’erlong Xiang', 'Sai''erlong Xiang', 'Sai''erlong,Sai''erlong Xiang,Sai’erlong,Sai’erlong Xiang,Yatang,sai er long,sai er long xiang,ya tang,牙塘,赛尔龙,赛尔龙乡', 34.4857300, 102.1364400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25956, 'Anchong', 'Anchong', 'Anchong,Anchong Xiang,Laze,an chong,an chong xiang,la ze,安冲,安冲乡,拉则', 33.4655900, 96.6332800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25957, 'Zhexiao', 'Zhexiao', 'Quguo Chawu,Zhexiao,Zhexiao Xiang,qu guo cha wu,zhe xiao,zhe xiao xiang,曲果岔吾,着晓,着晓乡', 32.5199400, 95.7332600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25958, 'Awancang', 'Awancang', 'Awancang,Awancang Xiang,a wan cang,a wan cang xiang,阿万仓,阿万仓乡', 33.7709300, 101.6971600, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25959, 'Oula Xiuma', 'Oula Xiuma', 'Oula Xiuma,Oula Xiuma Xiang,ou la xiu ma,ou la xiu ma xiang,欧拉秀玛,欧拉秀玛乡', 34.2425600, 101.1197300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25960, 'Muxihe', 'Muxihe', 'Muxihe,Muxihe Xiang,mu xi he,mu xi he xiang,木西合,木西合乡', 33.7572000, 101.2453300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25961, 'Lancai', 'Lancai', 'Kanglaka,Lancai,Lancai Xiang,kang la ka,lan cai,lan cai xiang,兰采,兰采乡,康拉卡', 35.6589200, 101.8186100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25962, 'Yalang', 'Yalang', 'Yalang,Yalang Xiang,ya lang,ya lang xiang,牙浪,牙浪乡', 35.4939900, 101.9514500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25963, 'Zhamao', 'Zhamao', 'Mashedang,Zhamao,Zhamao Xiang,ma shen dang,zha mao,zha mao xiang,扎毛,扎毛乡,麻什当', 35.3442800, 101.9001400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25964, 'Hexi', 'Hexi', 'Ge''erjia,Ge’erjia,Hexi,Hexi Xiang,ge er jia,he xi,he xi xiang,格尔加,河西,河西乡', 36.0326400, 101.3821900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25965, 'Hedong', 'Hedong', 'Hedong,Hedong Xiang,Majiaxi,he dong,he dong xiang,ma jia xi,河东,河东乡,马家西', 36.0459200, 101.4596900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25966, 'Changmu', 'Changmu', 'Changmu,Changmu Xiang,chang mu,chang mu xiang,常牧,常牧乡', 35.8055900, 101.6055400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25967, 'Jibu Hulangtu', 'Jibu Hulangtu', 'Jibu Hulangtu,Jibu Hulangtu Sumu,ji bu hu lang tu,ji bu hu lang tu su mu,吉布胡郎图,吉布胡郎图苏木', 48.9662000, 117.7602900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25968, 'Xinbaoli Gedong', 'Xinbaoli Gedong', 'Xinbaoli Gedong,Xinbaoli Gedong Sumu,xin bao li ge dong,xin bao li ge dong su mu,新宝力格东,新宝力格东苏木', 48.7225000, 118.7812400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25969, 'Amu Gulang Baolige', 'Amu Gulang Baolige', 'Amu Gulang Baolige,Amu Gulang Baolige Sumu,a mu gu lang bao li ge,a mu gu lang bao li ge su mu,阿木古郎宝力格,阿木古郎宝力格苏木', 48.3587400, 118.1406500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25970, 'Alatan Hada', 'Alatan Hada', 'Alatan Hada,Alatan Hada Sumu,a la tan ha da,a la tan ha da su mu,阿拉坦哈达,阿拉坦哈达苏木', 47.9576400, 119.5958300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25971, 'Wu’erbu Baolige', 'Wu''erbu Baolige', 'Wu''erbu Baolige,Wu''erbu Baolige Sumu,Wu’erbu Baolige,Wu’erbu Baolige Sumu,wu er bu bao li ge,wu er bu bao li ge su mu,乌尔布宝力格,乌尔布宝力格苏木', 48.0674900, 119.0438200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25972, 'Xinbaoli Gexi', 'Xinbaoli Gexi', 'Xinbaoli Gexi,Xinbaoli Gexi Sumu,xin bao li ge xi,xin bao li ge xi su mu,新宝力格西,新宝力格西苏木', 48.3242400, 118.5477700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25973, 'Cuogang', 'Cuogang', 'Cuogang,Cuogang Zhen,cuo gang,cuo gang zhen,嵯岗,嵯岗镇', 49.2578500, 118.1017400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25974, 'Jiajia', 'Jiajia', 'Hayu,Jiajia,Jiajia Xiang,gu jia,gu jia xiang,ha yu,哈玉,贾加,贾加乡', 35.9844100, 101.8635200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25975, 'Jianzhatan', 'Jianzhatan', 'Jianzhatan,Jianzhatan Xiang,Qiazang,jian zha tan,jian zha tan xiang,qia cang,尖扎滩,尖扎滩乡,恰藏', 35.7670600, 101.8662500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25976, 'Kangyang', 'Kangyang', 'Kangjia,Kangyang,Kangyang Zhen,kang jia,kang yang,kang yang zhen,康家,康扬,康扬镇', 36.0590400, 101.9152800, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25977, 'Cuozhou', 'Cuozhou', 'Cuozhou,Cuozhou Xiang,Huo''er Waxi,Huo’er Waxi,cuo zhou,cuo zhou xiang,huo er wa xi,措周,措周乡,霍尔瓦西', 35.9535300, 101.9107700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25978, 'Nengke', 'Nengke', 'Mani Duoleng,Nengke,Nengke Xiang,ma ni duo leng,neng ke,neng ke xiang,能科,能科乡,麻尼多楞', 35.8721800, 101.9636500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25979, 'Kanbula', 'Kanbula', 'Kanbula,Kanbula Zhen,Niutan,kan bu la,kan bu la zhen,niu tan,坎布拉,坎布拉镇,牛滩', 36.1137100, 101.8491000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25980, 'Shalianbao', 'Shalianbao', 'Guanbawan,Shalianbao,Shalianbao Xiang,guan ba wan,sha lian bao,sha lian bao xiang,关巴湾,沙连堡,沙连堡乡', 36.0096400, 102.1114300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25981, 'Chuoyuan', 'Chuoyuan', 'Chuoyuan,Chuoyuan Zhen,chao yuan,chao yuan zhen,绰源,绰源镇', 48.3037300, 121.3141300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25982, 'Kudu’er', 'Kudu''er', 'Kudu''er,Kudu''er Zhen,Kudu’er,Kudu’er Zhen,ku dou er,ku dou er zhen,库都尔,库都尔镇', 50.0296300, 121.6139100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25983, 'Ta’erqi', 'Ta''erqi', 'Ta''erqi,Ta''erqi Zhen,Ta’erqi,Ta’erqi Zhen,ta er qi,ta er qi zhen,塔尔气,塔尔气镇', 47.9784700, 121.1977700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25984, 'Meitian', 'Meitian', 'Meitian,Meitian Zhen,mei tian,mei tian zhen,煤田,煤田镇', 49.5013000, 121.4503100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25985, 'Wu’erqihan', 'Wu''erqihan', 'Wu''erqihan,Wu''erqihan Zhen,Wu’erqihan,Wu’erqihan Zhen,wu er qi han,wu er qi han zhen,乌尔其汉,乌尔其汉镇', 49.5784300, 121.3885900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25986, 'Wunu’er', 'Wunu''er', 'Wunu''er,Wunu''er Zhen,Wunu’er,Wunu’er Zhen,wu nu er,wu nu er zhen,乌奴耳,乌奴耳镇', 48.8636300, 121.2404500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25987, 'Yashiga', 'Yashiga', 'Yashiga,Yashiga Zhen,ya shen ga,ya shen ga zhen,牙什尕,牙什尕镇', 36.0713200, 101.9356500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25988, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,hong qi,hong qi zhen,红旗,红旗镇', 47.0315300, 124.6731900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25989, 'Huayuan', 'Huayuan', 'Huayuan,Huayuan Xiang,hua yuan,hua yuan xiang,花园,花园乡', 46.9771900, 124.9104100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25990, 'Liming', 'Liming', 'Liming,Liming Xiang,li ming,li ming xiang,黎明,黎明乡', 47.1337000, 125.0067000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25991, 'Hongwei', 'Hongwei', 'Hongwei,Hongwei Xiang,hong wei,hong wei xiang,宏伟,宏伟乡', 47.2189800, 124.9121500, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25992, 'Sihe', 'Sihe', 'Sihe,Sihe Xiang,si he,si he xiang,四合,四合乡', 47.3078200, 124.8754200, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25993, 'Haoraoshan', 'Haoraoshan', 'Haoraoshan,Haoraoshan Xiang,hao rao shan,hao rao shan xiang,浩饶山,浩饶山乡', 47.2102000, 121.6345100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25994, 'Halasu', 'Halasu', 'Halasu,Halasu Zhen,ha la su,ha la su zhen,哈拉苏,哈拉苏镇', 48.1121800, 122.4193000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25995, 'Samajie Ewenkeminzu', 'Samajie Ewenkeminzu', 'Samajie Ewenkeminzu,Samajie Ewenkeminzu Xiang,sa ma jie e wen ke min zu,sa ma jie e wen ke min zu xiang,萨马街鄂温克民族,萨马街鄂温克民族乡', 47.5304400, 122.2255100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25996, 'Zhonghe', 'Zhonghe', 'Zhonghe,Zhonghe Zhen,zhong he,zhong he zhen,中和,中和镇', 47.6666500, 122.6084900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25997, 'Haduohe', 'Haduohe', 'Haduohe,Haduohe Zhen,ha duo he,ha duo he zhen,哈多河,哈多河镇', 47.2294900, 122.0047000, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25998, 'Dawo’er Minzu', 'Dawo''er Minzu', 'Dawo''er Minzu,Dawo''er Minzu Xiang,Dawo’er Minzu,Dawo’er Minzu Xiang,da wo er min zu,da wo er min zu xiang,达斡尔民族,达斡尔民族乡', 48.0147200, 123.0001700, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(25999, 'Ya’ergenchu', 'Ya''ergenchu', 'Ya''ergenchu,Ya''ergenchu Zhen,Ya’ergenchu,Ya’ergenchu Zhen,ya er gen chu,ya er gen chu zhen,雅尔根楚,雅尔根楚镇', 47.7460300, 122.6080900, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26000, 'Guanmenshan', 'Guanmenshan', 'Guanmenshan,Guanmenshan Xiang,guan men shan,guan men shan xiang,关门山,关门山乡', 47.3896300, 122.3313400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26001, 'Wadi', 'Wadi', 'Wadi,Wadi Xiang,wa di,wa di xiang,洼堤,洼堤乡', 47.2726000, 122.1880300, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26002, 'Elunchun Minzu', 'Elunchun Minzu', 'Elunchun Minzu,Elunchun Minzu Xiang,e lun chun min zu,e lun chun min zu xiang,鄂伦春民族,鄂伦春民族乡', 48.1739300, 122.3633100, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26003, 'Dahewan', 'Dahewan', 'Dahewan,Dahewan Zhen,da he wan,da he wan zhen,大河湾,大河湾镇', 47.8493600, 123.1277400, 'CN', '2013-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26004, 'Miaogou', 'Miaogou', 'Miaogou,Miaogou Xiang,Xiamiaogou,miao gou,miao gou xiang,xia miao gou,下庙沟,庙沟,庙沟乡', 40.8715100, 110.8530900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26005, 'Nalinggou', 'Nalinggou', 'Jiuguan,Nalinggou,Nalinggou Xiang,jiu guan,na ling gou,na ling gou xiang,纳令沟,纳令沟乡,酒馆', 40.9984900, 111.1616900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26006, 'Donghongsheng', 'Donghongsheng', 'Donghongsheng,Donghongsheng Xiang,dong hong sheng,dong hong sheng xiang,东红胜,东红胜乡', 41.3321000, 110.8836800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26007, 'Zhonghouhe', 'Zhonghouhe', 'Zhonghouhe,Zhonghouhe Xiang,zhong hou he,zhong hou he xiang,中后河,中后河乡', 41.1853000, 111.0667500, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26008, 'Changhan Mutai', 'Changhan Mutai', 'Changhan Mutai,Changhan Mutai Xiang,Dongchanghan Mutai,chang han mu tai,chang han mu tai xiang,dong chang han mu tai,东厂汉木台,厂汉木台,厂汉木台乡', 41.2608900, 111.3376400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26009, 'Haolaishan', 'Haolaishan', 'Haolaishan,Haolaishan Xiang,hao lai shan,hao lai shan xiang,壕赖山,壕赖山乡', 41.3077500, 111.5453600, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26010, 'Erdaowan', 'Erdaowan', 'Erdaowan,Erdaowan Zhen,er dao wan,er dao wan zhen,二道湾,二道湾镇', 47.9588200, 124.5325300, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26011, 'Fanrong', 'Fanrong', 'Fanrong,Fanrong Xiang,fan rong,fan rong xiang,繁荣,繁荣乡', 47.3877100, 124.6038300, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26012, 'Zhonghou', 'Zhonghou', 'Zhonghou,Zhonghou Xiang,zhong hou,zhong hou xiang,忠厚,忠厚乡', 47.9543700, 124.8223600, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26013, 'Dadoupu', 'Dadoupu', 'Dadoupu,Dadoupu Xiang,da dou pu,da dou pu xiang,大豆铺,大豆铺乡', 41.1626800, 111.6001800, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26014, 'Dalanqi', 'Dalanqi', 'Dalanqi,Dalanqi Xiang,da lan qi,da lan qi xiang,大兰旗,大兰旗乡', 41.1470500, 111.7459700, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26015, 'Daqingshan', 'Daqingshan', 'Daqingshan,Daqingshan Xiang,Wulan Bulang,da qing shan,da qing shan xiang,wu lan bu lang,乌兰不浪,大青山,大青山乡', 40.9997600, 111.4440100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26016, 'Moguyao', 'Moguyao', 'Houyingzi,Moguyao,Moguyao Xiang,hou ying zi,mo gu yao,mo gu yao xiang,后营子,蘑菇窑,蘑菇窑乡', 40.9973300, 111.2178200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26017, 'Anzihao', 'Anzihao', 'Anzihao,Anzihao Xiang,Dahebian,an zi hao,an zi hao xiang,da he bian,大河边,安字号,安字号乡', 41.1181900, 111.4343000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26018, 'Xihong Shanzi', 'Xihong Shanzi', 'Hongshanzi,Xihong Shanzi,Xihongshanzi Xiang,hong shan zi,xi hong shan zi,xi hong shan zi xiang,红山子,西红山子,西红山子乡', 41.1952100, 110.6811400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26019, 'Jinshan', 'Jinshan', 'Jinshan,Jinshan Xiang,jin shan,jin shan xiang,金山,金山乡', 52.1455400, 126.5069900, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26020, 'Yinhe', 'Yinhe', 'Yinhe,Yinhe Zhen,yin he,yin he zhen,音河,音河镇', 47.9529900, 123.6508100, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26021, 'Zhongxing', 'Zhongxing', 'Zhongxing,Zhongxing Xiang,zhong xing,zhong xing xiang,中兴,中兴乡', 47.7010700, 123.2317300, 'CN', '2013-03-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26022, 'Wenshan City', 'Wenshan City', 'WNH,Wenshan,Wenshan City,Wénshān,wen shan,wen shan shi,wonsan si,文山,文山市,원산 시', 23.3630600, 104.2504700, 'CN', '2013-04-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26023, 'Bacun', 'Bacun', 'Ba Xiang,Bacun,ba cun,ba xiang,坝乡,坝村', 29.4792000, 92.9314600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26024, 'Halahai', 'Halahai', 'Halahai,Halahai Xiang,ha la hai,ha la hai xiang,哈拉海,哈拉海乡', 47.4290000, 123.4015200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26025, 'Guanghou', 'Guanghou', 'Guanghou,guang hou,广厚', 47.0808700, 123.3884300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26026, 'Duibao', 'Duibao', 'Duibao,Duibao Xiang,dui bao,dui bao xiang,对宝,对宝乡', 47.2797000, 123.0585000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26027, 'Heshan', 'Heshan', 'Heshan,Heshan Xiang,he shan,he shan xiang,合山,合山乡', 47.3478800, 123.1165300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26028, 'Nanhang', 'Nanhang', 'Longsha,Longsha Qu,Nanhang,Nanhang Jiedao,long sha,long sha qu,nan hang,nan hang jie dao,南航,南航街道,龙沙,龙沙区', 47.3146900, 123.9479600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26029, 'Bukui', 'Bukui', 'Bukui,Bukui Jiedao,Jianhua,Jianhua Qu,bo kui,bo kui jie dao,jian hua,jian hua qu,卜奎,卜奎街道,建华,建华区', 47.3550300, 123.9517200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26030, 'Longhua', 'Longhua', 'Longhua,Longhua Jiedao,Tiefeng,Tiefeng Qu,long hua,long hua jie dao,tie feng,tie feng qu,铁锋,铁锋区,龙华,龙华街道', 47.3384700, 123.9791900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26031, 'Shuishiying', 'Shuishiying', 'Shuishiying,Shuishiying Manzu Zhen,shui shi ying,shui shi ying man zu,水师营,水师营满族', 47.2476200, 123.9899300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26032, 'Damin', 'Damin', 'Damin,Damin Zhen,da min,da min zhen,大民,大民镇', 47.2663800, 123.9031500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26033, 'Du’ermenqin', 'Du''ermenqin', 'Du''ermenqin,Du''ermenqin Dawo''erzu Xiang,Du’ermenqin,Du’ermenqin Dawo’erzu Xiang,du er men qin,du er men qin da wo er zu xiang,杜尔门沁,杜尔门沁达斡尔族乡', 47.1389500, 123.5416500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26034, 'Changqing', 'Changqing', 'Changqing,Changqing Xiang,zhang qing,zhang qing xiang,长青,长青乡', 47.2192500, 123.6016700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26035, 'Hali', 'Hali', 'Hali,Hali Xiang,ha li,ha li xiang,哈力,哈力乡', 47.3272300, 123.6542900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26036, 'Ya’ersai', 'Ya''ersai', 'Ya''ersai,Ya''ersai Zhen,Ya’ersai,Ya’ersai Zhen,ya er sai,ya er sai zhen,雅尔塞,雅尔塞镇', 47.4465400, 123.9006800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26037, 'Haoxin', 'Haoxin', 'Haoxin,Haoxin Mengguzu Xiang,hao xin,hao xin meng gu zu xiang,好新,好新蒙古族乡', 46.3162200, 123.5609400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26038, 'Hongsheng', 'Hongsheng', 'Hongsheng,Hongsheng Xiang,hong sheng,hong sheng xiang,宏升,宏升乡', 46.3325500, 123.3124500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26039, 'Heping', 'Heping', 'Heping,Heping Xiang,he ping,he ping xiang,和平,和平乡', 46.5189200, 123.1465400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26040, 'Siliwu', 'Siliwu', 'Siliwu,Siliwu Xiang,si li wu,si li wu xiang,四里五,四里五乡', 46.5700100, 123.2612400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26041, 'Baiyinnuole', 'Baiyinnuole', 'Baiyinnuole,Baiyinnuole Xiang,bai yin nuo lei,bai yin nuo lei xiang,白音诺勒,白音诺勒乡', 46.7588500, 124.2228400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26042, 'Jiangwan', 'Jiangwan', 'Jiangwan,Jiangwan Xiang,jiang wan,jiang wan xiang,江湾,江湾乡', 46.5823500, 123.9029200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26043, 'Yixin', 'Yixin', 'Yixin,Yixin Xiang,yi xin,yi xin xiang,一心,一心乡', 46.8103600, 124.3920300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26044, 'Jubao', 'Jubao', 'Jubao,Jubao Zhen,ju bao,ju bao zhen,巨宝,巨宝镇', 47.8944700, 124.1833200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26045, 'Haolibao', 'Haolibao', 'Haolibao,Haolibao Xiang,hao li bao,hao li bao xiang,好力保,好力保乡', 46.7116700, 123.2649900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26046, 'Nuwen Muren', 'Nuwen Muren', 'Nuwen Muren,Nuwen Muren Xiang,nu wen mu ren,nu wen mu ren xiang,努文木仁,努文木仁乡', 46.7513200, 123.6008100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26047, 'Jiefang', 'Jiefang', 'Jiefang,Jiefang Xiang,jie fang,jie fang xiang,解放,解放乡', 47.6499100, 125.4916700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26048, 'Xinfa', 'Xinfa', 'Xinfa,Xinfa Xiang,xin fa,xin fa xiang,新发,新发乡', 47.8381300, 125.4696100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26049, 'Yangchun', 'Yangchun', 'Yangchun,Yangchun Xiang,yang chun,yang chun xiang,阳春,阳春乡', 47.7634500, 125.4917900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26050, 'Shangyou', 'Shangyou', 'Shangyou,Shangyou Xiang,shang you,shang you xiang,上游,上游乡', 47.9631500, 125.3181100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26051, 'Hongxing', 'Hongxing', 'Hongxing,Hongxing Xiang,hong xing,hong xing xiang,红星,红星乡', 47.9510600, 125.2250700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26052, 'Xinxing', 'Xinxing', 'Xinxing,Xinxing Xiang,xin xing,xin xing xiang,新兴,新兴乡', 47.7345300, 125.0128200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26053, 'Dong’an', 'Dong''an', 'Dong''an,Dong''an Jiedao,Dong’an,Dong’an Jiedao,Sa''ertu,Sa''ertu Qu,Sa’ertu,Sa’ertu Qu,dong an,dong an jie dao,sa er tu,sa er tu qu,东安,东安街道,萨尔图,萨尔图区', 46.5940500, 125.0787800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26054, 'Xingshugang', 'Xingshugang', 'Xingshugang,Xingshugang Zhen,xing shu gang,xing shu gang zhen,杏树岗,杏树岗镇', 46.3197600, 124.8918900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26055, 'Gaotaizi', 'Gaotaizi', 'Gaotaizi,Gaotaizi Zhen,gao tai zi,gao tai zi zhen,高台子,高台子镇', 46.1318500, 124.7942400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26056, 'Shuangyushu', 'Shuangyushu', 'Shuangyushu,Shuangyushu Xiang,shuang yu shu,shuang yu shu xiang,双榆树,双榆树乡', 46.1378300, 124.6040800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26057, 'Bajingzi', 'Bajingzi', 'Bajingzi,Bajingzi Xiang,ba jing zi,ba jing zi xiang,八井子,八井子乡', 46.0221900, 124.7290800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26058, 'Wanbaoshan', 'Wanbaoshan', 'Wanbaoshan,Wanbaoshan Zhen,wan bao shan,wan bao shan zhen,万宝山,万宝山镇', 46.3925800, 125.2040700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26059, 'Zhongben', 'Zhongben', 'Zhongben,Zhongben Zhen,zhong ben,zhong ben zhen,中本,中本镇', 46.5806400, 125.4660600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26060, 'Xianyuan', 'Xianyuan', 'Xianyuan,Xianyuan Xiang,xian yuan,xian yuan xiang,先源,先源乡', 46.4866600, 125.4456300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26061, 'Laohugang', 'Laohugang', 'Laohugang,Laohugang Zhen,lao hu gang,lao hu gang zhen,老虎岗,老虎岗镇', 46.7443700, 125.5810300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26062, 'Changde', 'Changde', 'Changde,Changde Zhen,chang de,chang de zhen,昌德,昌德镇', 46.1417200, 125.0158900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26063, 'Yangjingziwan', 'Yangjingziwan', 'Yangjingziwan,Yangjingziwan Xiang,yang jing zi wan,yang jing zi wan xiang,羊井子湾,羊井子湾乡', 40.0221900, 98.9964400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26064, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Xiang,san he,san he xiang,三合,三合乡', 40.1049100, 98.9379400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26065, 'Zhongdong', 'Zhongdong', 'Zhongdong,Zhongdong Zhen,zhong dong,zhong dong zhen,中东,中东镇', 40.1189900, 98.8171600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26066, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Xiang,gu cheng,gu cheng xiang,古城,古城乡', 40.1379700, 98.8609100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26067, 'Jiji', 'Jiji', 'Jiji,Jiji Xiang,ji ji,ji ji xiang,芨芨,芨芨乡', 40.1455700, 99.3981800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26068, 'Sanwei', 'Sanwei', 'Sanwei,Sanwei Xiang,san wei,san wei xiang,三危,三危乡', 40.1511100, 94.7011000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26069, 'Suzhou', 'Suzhou', 'Suzhou,Suzhou Zhen,su zhou,su zhou zhen,肃州,肃州镇', 40.1637500, 94.6398900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26070, 'Xiba', 'Xiba', 'Xiba,Xiba Xiang,xi ba,xi ba xiang,西坝,西坝乡', 40.1645500, 98.7520800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26071, 'Lüjiabao', 'Lujiabao', 'Lujiabao,Lujiabao Xiang,Lüjiabao,Lüjiabao Xiang,lu jia bao,lu jia bao xiang,吕家堡,吕家堡乡', 40.1895300, 94.7017500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26072, 'Guojiabao', 'Guojiabao', 'Guojiabao,Guojiabao Xiang,guo jia bao,guo jia bao xiang,郭家堡,郭家堡乡', 40.1962400, 94.7654800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26073, 'Zhuanqukou', 'Zhuanqukou', 'Zhuanqukou,Zhuanqukou Xiang,zhuan qu kou,zhuan qu kou xiang,转渠口,转渠口乡', 40.2471000, 94.7415000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26074, 'Qiaozi', 'Qiaozi', 'Qiaozi,Qiaozi Xiang,qiao zi,qiao zi xiang,桥子,桥子乡', 40.3240200, 96.2014200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26075, 'Huangzhawan', 'Huangzhawan', 'Huangzhawan,Huangzhawan Xiang,huang zha wan,huang zha wan xiang,黄闸湾,黄闸湾乡', 40.3837200, 97.0625800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26076, 'Liuhe', 'Liuhe', 'Liuhe,Liuhe Xiang,liu he,liu he xiang,柳河,柳河乡', 40.4088800, 96.9365300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26077, 'Nancha', 'Nancha', 'Nancha,Nancha Xiang,nan cha,nan cha xiang,南岔,南岔乡', 40.4099700, 95.6629600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26078, 'Sandaogou', 'Sandaogou', 'Sandaogou,Sandaogou Zhen,san dao gou,san dao gou zhen,三道沟,三道沟镇', 40.4346400, 96.8650400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26079, 'Yaozhanzi', 'Yaozhanzi', 'Yaozhanzi,Yaozhanzi Xiang,yao zhan zi,yao zhan zi xiang,腰站子,腰站子乡', 40.4765700, 96.7209800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26080, 'Hedong', 'Hedong', 'Hedong,Hedong Xiang,he dong,he dong xiang,河东,河东乡', 40.5040800, 96.7713100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26081, 'Huancheng', 'Huancheng', 'Huancheng,Huancheng Xiang,huan cheng,huan cheng xiang,环城,环城乡', 40.5280500, 95.7658600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26082, 'Mazongshan', 'Mazongshan', 'Mazongshan,Mazongshan Zhen,ma zong shan,ma zong shan zhen,马鬃山,马鬃山镇', 41.8088500, 97.0265500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26083, 'Xuanhua', 'Xuanhua', 'Xuanhua,Xuanhua Xiang,xuan hua,xuan hua xiang,宣化,宣化乡', 46.2693200, 125.6641300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26084, 'Anmin', 'Anmin', 'Anmin,Anmin Xiang,an min,an min xiang,安民,安民乡', 46.1768900, 125.4772200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26085, 'Mingjiu', 'Mingjiu', 'Mingjiu,Mingjiu Xiang,ming jiu,ming jiu xiang,明久,明久乡', 46.1147300, 125.5201700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26086, 'Liaoyuan', 'Liaoyuan', 'Liaoyuan,Liaoyuan Xiang,liao yuan,liao yuan xiang,燎原,燎原乡', 46.5446500, 125.8279500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26087, 'Xinghuo', 'Xinghuo', 'Xinghuo,Xinghuo Xiang,xing huo,xing huo xiang,星火,星火乡', 46.4639100, 125.7714300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26088, 'Bei’an', 'Bei''an', 'Bei''an,Bei''an Xiang,Bei’an,Bei’an Xiang,bei an,bei an xiang,北安,北安乡', 46.4414200, 126.2402400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26089, 'Hongguang', 'Hongguang', 'Hongguang,Hongguang Xiang,hong guang,hong guang xiang,红光,红光乡', 46.3435400, 126.2869500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26090, 'Hongxing', 'Hongxing', 'Hongxing,Hongxing Xiang,hong xing,hong xing xiang,红星,红星乡', 46.2943800, 126.2042300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26091, 'Yuanda', 'Yuanda', 'Yuanda,Yuanda Xiang,yuan da,yuan da xiang,远大,远大乡', 46.4719800, 126.0524900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26092, 'Linjiang', 'Linjiang', 'Linjiang,Linjiang Zhen,lin jiang,lin jiang zhen,临江,临江镇', 46.4413200, 126.4666300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26093, 'Changjiang', 'Changjiang', 'Changjiang,Changjiang Xiang,zhang jiang,zhang jiang xiang,长江,长江乡', 46.3005300, 126.5219500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26094, 'Kangrong', 'Kangrong', 'Kangrong,Kangrong Xiang,kang rong,kang rong xiang,康荣,康荣乡', 46.1940500, 126.2504600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26095, 'Yulin', 'Yulin', 'Yulin,Yulin Zhen,yu lin,yu lin zhen,榆林,榆林镇', 46.1099500, 126.2779800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26096, 'Lanhe', 'Lanhe', 'Lanhe,Lanhe Xiang,lan he,lan he xiang,兰河,兰河乡', 46.2126600, 126.4422400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26097, 'Zhagang', 'Zhagang', 'Zhagang,Zhagang Xiang,zha gang,zha gang xiang,柞岗,柞岗乡', 46.6448300, 126.1169300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26098, 'Changsheng', 'Changsheng', 'Changsheng,Changsheng Xiang,chang sheng,chang sheng xiang,昌盛,昌盛乡', 46.5649600, 126.2666000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26099, 'Minzheng', 'Minzheng', 'Minzheng,Minzheng Xiang,min zheng,min zheng xiang,民政,民政乡', 46.7204900, 126.1740200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26100, 'Desheng', 'Desheng', 'Desheng,Desheng Xiang,de sheng,de sheng xiang,德胜,德胜乡', 46.8664000, 126.1240800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26101, 'Yingchun', 'Yingchun', 'Yingchun,Yingchun Xiang,ying chun,ying chun xiang,迎春,迎春乡', 47.0372800, 125.9467300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26102, 'Lianfeng', 'Lianfeng', 'Lianfeng,Lianfeng Xiang,lian feng,lian feng xiang,连丰,连丰乡', 46.8961800, 125.8787400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26103, 'Jianshe', 'Jianshe', 'Jianshe,Jianshe Xiang,jian she,jian she xiang,建设,建设乡', 46.7597500, 125.8467000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26104, 'Laodong', 'Laodong', 'Laodong,Laodong Xiang,lao dong,lao dong xiang,劳动,劳动乡', 46.7549400, 125.9319900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26105, 'Yulin', 'Yulin', 'Yulin,Yulin Xiang,yu lin,yu lin xiang,育林,育林乡', 47.1297800, 125.6302100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26106, 'Yongxing', 'Yongxing', 'Yongxing,Yongxing Zhen,yong xing,yong xing zhen,永兴,永兴镇', 47.2588400, 126.0779700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26107, 'Fanrong', 'Fanrong', 'Fanrong,Fanrong Xiang,fan rong,fan rong xiang,繁荣,繁荣乡', 47.3038300, 126.2425300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26108, 'Guangrong', 'Guangrong', 'Guangrong,Guangrong Xiang,guang rong,guang rong xiang,光荣,光荣乡', 47.3174100, 126.3187800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26109, 'Yongjiu', 'Yongjiu', 'Yongjiu,Yongjiu Xiang,yong jiu,yong jiu xiang,永久,永久乡', 47.1274800, 126.0097900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26110, 'Shuren', 'Shuren', 'Shuren,Shuren Xiang,shu ren,shu ren xiang,树人,树人乡', 47.1606800, 126.2204800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26111, 'Shuanghe', 'Shuanghe', 'Shuanghe,Shuanghe Xiang,shuang he,shuang he xiang,双河,双河乡', 47.9465200, 125.8899300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26112, 'Henan', 'Henan', 'Henan,Henan Xiang,he nan,he nan xiang,河南,河南乡', 47.9658000, 126.0195800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26113, 'Aiguo', 'Aiguo', 'Aiguo,Aiguo Xiang,ai guo,ai guo xiang,爱国,爱国乡', 47.7663500, 126.4030400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26114, 'Changsheng', 'Changsheng', 'Changsheng,Changsheng Xiang,chang sheng,chang sheng xiang,昌盛,昌盛乡', 47.8294500, 126.4049100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26115, 'Runjin', 'Runjin', 'Runjin,Runjin Xiang,run jin,run jin xiang,润津,润津乡', 47.9485000, 126.2753200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26116, 'Shuangqing', 'Shuangqing', 'Shuangqing,Shuangqing Xiang,shuang qing,shuang qing xiang,双庆,双庆乡', 47.9619300, 126.3957300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26117, 'Zhuxing Chaoxianzu', 'Zhuxing Chaoxianzu', 'Zhuxing Chaoxianzu,Zhuxing Chaoxianzu Xiang,zhu xing chao xian zu,zhu xing chao xian zu xiang,主星朝鲜族,主星朝鲜族乡', 47.7255900, 126.9687500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26118, 'Yangjia', 'Yangjia', 'Yangjia,Yangjia Xiang,yang jia,yang jia xiang,杨家,杨家乡', 47.8381200, 126.7456200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26119, 'Shiquan', 'Shiquan', 'Shiquan,Shiquan Zhen,shi quan,shi quan zhen,石泉,石泉镇', 47.6825600, 126.6197900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26120, 'Jiuhu', 'Jiuhu', 'Jiuhu,Jiuhu Xiang,jiu hu,jiu hu xiang,九湖,九湖乡', 31.4634800, 110.0984600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26121, 'Muyu', 'Muyu', 'Muyu,Muyu Zhen,mu yu,mu yu zhen,木鱼,木鱼镇', 31.4720200, 110.3871700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26122, 'Hongping', 'Hongping', 'HPG,Hongping,hong ping,hong ping zhen,红坪,红坪镇', 31.6692700, 110.4242700, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26123, 'Mengusi', 'Mengusi', 'Mengusi,Mengusi Zhen,men gu si,men gu si zhen,门古寺,门古寺镇', 32.0084000, 110.4498600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26124, 'Guanshan', 'Guanshan', 'Guanshan,Guanshan Zhen,guan shan,guan shan zhen,官山,官山镇', 32.3734900, 110.8617000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26125, 'Zhenzi', 'Zhenzi', 'Zhenzi,Zhenzi Xiang,zhen zi,zhen zi xiang,榛子,榛子乡', 31.4518600, 110.9785700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26126, 'Guoduwan', 'Guoduwan', 'Guoduwan,Guoduwan Zhen,guo du wan,guo du wan zhen,过渡湾,过渡湾镇', 31.9939300, 111.2575800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26127, 'Langhe', 'Langhe', 'Langhe,Langhe Zhen,lang he,lang he zhen,浪河,浪河镇', 32.4245600, 111.2603200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26128, 'Huangbao', 'Huangbao', 'Huangbao,Huangbao Zhen,huang bao,huang bao zhen,黄堡,黄堡镇', 31.8273600, 111.3397900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26129, 'Wushan', 'Wushan', 'Wushan,Wushan Zhen,wu shan,wu shan zhen,五山,五山镇', 32.3079500, 111.3561400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26130, 'Shihua', 'Shihua', 'Shihua,Shihua Zhen,shi hua,shi hua zhen,石花,石花镇', 32.2784500, 111.4561700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26131, 'Longping', 'Longping', 'Longping,Longping Zhen,long ping,long ping zhen,龙坪,龙坪镇', 31.6574400, 111.4964500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26132, 'Hongshanzui', 'Hongshanzui', 'Hongshanzui,Hongshanzui Jiedao,hong shan ju,hong shan ju jie dao,洪山咀,洪山咀街道', 32.4545300, 111.6602800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26133, 'Chengguan', 'Chengguan', 'Chengguan,Chengguan Zhen,cheng guan,cheng guan zhen,城关,城关镇', 31.7826200, 111.8434400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26134, 'Leye', 'Leye', 'Leye,Leye Xiang,le ye,le ye xiang,乐业,乐业乡', 47.2922600, 126.9468700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26135, 'Hainan', 'Hainan', 'Hainan,Hainan Xiang,hai nan,hai nan xiang,海南,海南乡', 47.2322300, 126.9809300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26136, 'Gongrong', 'Gongrong', 'Gongrong,Gongrong Xiang,gong rong,gong rong xiang,共荣,共荣乡', 47.1651700, 126.8519200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26137, 'Fumin', 'Fumin', 'Fumin,Fumin Xiang,fu min,fu min xiang,福民,福民乡', 47.1537900, 126.7125900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26138, 'Haixing', 'Haixing', 'Haixing,Haixing Zhen,hai xing,hai xing zhen,海兴,海兴镇', 47.1885900, 126.6699100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26139, 'Fengshan', 'Fengshan', 'Fengshan,Fengshan Xiang,feng shan,feng shan xiang,丰山,丰山乡', 47.1718800, 126.5763500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26140, 'Baixiang', 'Baixiang', 'Baixiang,Baixiang Xiang,bai xiang,bai xiang xiang,百祥,百祥乡', 47.2230800, 126.4525600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26141, 'Yongfu', 'Yongfu', 'Yongfu,Yongfu Xiang,yong fu,yong fu xiang,永富,永富乡', 47.0457500, 126.4234000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26142, 'Lianfa', 'Lianfa', 'Lianfa,Lianfa Xiang,lian fa,lian fa xiang,联发,联发乡', 47.3176000, 126.4893900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26143, 'Yonghe', 'Yonghe', 'Yonghe,Yonghe Xiang,yong he,yong he xiang,永和,永和乡', 47.4439400, 126.5892300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26144, 'Aimin', 'Aimin', 'Aimin,Aimin Xiang,ai min,ai min xiang,爱民,爱民乡', 47.5878500, 126.6797000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26145, 'Qianjin', 'Qianjin', 'Qianjin,Qianjin Xiang,qian jin,qian jin xiang,前进,前进乡', 47.3970500, 126.8121200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26146, 'Xiangrong', 'Xiangrong', 'Xiangrong,Xiangrong Xiang,xiang rong,xiang rong xiang,向荣,向荣乡', 47.5116000, 126.8141200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26147, 'Donglin', 'Donglin', 'Donglin,Donglin Xiang,dong lin,dong lin xiang,东林,东林乡', 47.5051500, 127.0195700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26148, 'Kaoshan', 'Kaoshan', 'Kaoshan,Kaoshan Xiang,kao shan,kao shan xiang,靠山,靠山乡', 47.2241000, 127.1381400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26149, 'Houtou', 'Houtou', 'Houtou,Houtou Xiang,hou tou,hou tou xiang,后头,后头乡', 47.1750300, 127.1380300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26150, 'Keyinhe', 'Keyinhe', 'Keyinhe,Keyinhe Zhen,ke yin he,ke yin he zhen,克音河,克音河镇', 47.3199000, 127.1673000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26151, 'Suizhong', 'Suizhong', 'Suizhong,Suizhong Xiang,sui zhong,sui zhong xiang,绥中,绥中乡', 47.3273500, 127.3007800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26152, 'Shuangchahe', 'Shuangchahe', 'Shuangchahe,Shuangchahe Zhen,shuang cha he,shuang cha he zhen,双岔河,双岔河镇', 47.4567800, 127.2619300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26153, 'Housan', 'Housan', 'Housan,Housan Xiang,hou san,hou san xiang,后三,后三乡', 46.9245800, 126.3517600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26154, 'Lingshan', 'Lingshan', 'Lingshan,Lingshan Xiang,ling shan,ling shan xiang,灵山,灵山乡', 46.9325600, 126.4434100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26155, 'Xiangbai', 'Xiangbai', 'Xiangbai,Xiangbai Manzu Xiang,xiang bai,xiang bai man zu xiang,厢白,厢白满族乡', 46.9369300, 126.6230800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26156, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Xiang,dong sheng,dong sheng xiang,东升,东升乡', 47.0035600, 126.8849200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26157, 'Gongliu', 'Gongliu', 'Gongliu,Gongliu Xiang,gong liu,gong liu xiang,恭六,恭六乡', 47.0997800, 126.8621400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26158, 'Huiqi', 'Huiqi', 'Huiqi,Huiqi Manzu Zhen,hui qi,hui qi man zu zhen,惠七,惠七满族镇', 47.0594400, 126.6697000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26159, 'Huojian', 'Huojian', 'Huojian,Huojian Xiang,huo jian,huo jian xiang,火箭,火箭乡', 46.7535300, 126.5023700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26160, 'Weixing', 'Weixing', 'Weixing,Weixing Zhen,wei xing,wei xing zhen,卫星,卫星镇', 46.7183000, 126.6579900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26161, 'Dengta', 'Dengta', 'Dengta,Dengta Xiang,deng ta,deng ta xiang,灯塔,灯塔乡', 46.9003100, 126.7812400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26162, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Manzu Xiang,hong qi,hong qi man zu xiang,红旗,红旗满族乡', 46.5013800, 126.5707100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26163, 'Taipingchuan', 'Taipingchuan', 'Taipingchuan,Taipingchuan Zhen,tai ping chuan,tai ping chuan zhen,太平川,太平川镇', 46.6267600, 126.7377100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26164, 'Dongfu', 'Dongfu', 'Dongfu,Dongfu Xiang,dong fu,dong fu xiang,东富,东富乡', 46.6622100, 127.0114700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26165, 'Xingfu', 'Xingfu', 'Xingfu,Xingfu Xiang,xing fu,xing fu xiang,兴福,兴福乡', 46.6786000, 127.1165300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26166, 'Xinhua', 'Xinhua', 'Xinhua,Xinhua Xiang,xin hua,xin hua xiang,新华,新华乡', 46.6432600, 126.8412800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26167, 'Suisheng', 'Suisheng', 'Suisheng,Suisheng Manzu Zhen,sui sheng,sui sheng man zu zhen,绥胜,绥胜满族镇', 46.5360800, 126.7765600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26168, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Zhen,bao shan,bao shan zhen,宝山,宝山镇', 46.5257500, 126.9052500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26169, 'Longtai', 'Longtai', 'Longtai,Longtai Xiang,long tai,long tai xiang,隆太,隆太乡', 46.6870100, 127.2203100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26170, 'Dongjin', 'Dongjin', 'Dongjin,Dongjin Zhen,dong jin,dong jin zhen,东津,东津镇', 46.7395900, 127.2089200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26171, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Zhen,san he,san he zhen,三河,三河镇', 47.0016400, 127.2826800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26172, 'Wuying', 'Wuying', 'Wuying,Wuying Xiang,wu ying,wu ying xiang,五营,五营乡', 46.9382100, 127.2277600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26173, 'Xinghe', 'Xinghe', 'Xinghe,Xinghe Chaoxianzu Xiang,xing he,xing he chao xian zu xiang,兴和,兴和朝鲜族乡', 46.8854100, 127.1001400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26174, 'Zhangxiong', 'Zhangxiong', 'Zhangxiong,Zhangxiong Zhen,zhang xiong,zhang xiong zhen,张雄,张雄镇', 47.0599700, 127.0020000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26175, 'Sanjing', 'Sanjing', 'Sanjing,Sanjing Xiang,san jing,san jing xiang,三井,三井乡', 47.1090400, 127.0253100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26176, 'Dayou', 'Dayou', 'Beilin Qu,Dayou,Dayou Jiedao,bei lin qu,da you,da you jie dao,北林区,大有,大有街道', 46.6361600, 126.9875300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26177, 'Shangsheng', 'Shangsheng', 'Shangsheng,Shangsheng Xiang,shang sheng,shang sheng xiang,上升,上升乡', 47.6442600, 126.2285100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26178, 'Guofu', 'Guofu', 'Guofu,Guofu Zhen,guo fu,guo fu zhen,国富,国富镇', 47.6488400, 126.3946600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26179, 'Huaguang', 'Huaguang', 'Huaguang,Huaguang Xiang,hua guang,hua guang xiang,华光,华光乡', 47.5229200, 126.4211600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26180, 'Xinsheng', 'Xinsheng', 'Xinsheng,Xinsheng Xiang,xin sheng,xin sheng xiang,新生,新生乡', 47.4386200, 126.1573000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26181, 'Longquan', 'Longquan', 'Longquan,Longquan Zhen,long quan,long quan zhen,龙泉,龙泉镇', 47.4142400, 125.9604900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26182, 'Xingquan', 'Xingquan', 'Xingquan,Xingquan Xiang,xing quan,xing quan xiang,兴泉,兴泉乡', 47.3710300, 125.9591100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26183, 'Ainong', 'Ainong', 'Ainong,Ainong Xiang,ai nong,ai nong xiang,爱农,爱农乡', 47.3749700, 125.7173800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26184, 'Yongqin', 'Yongqin', 'Yongqin,Yongqin Xiang,yong qin,yong qin xiang,永勤,永勤乡', 47.5410100, 125.7982800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26185, 'Shizhong', 'Shizhong', 'Shizhong,Shizhong Xiang,shi zhong,shi zhong xiang,时中,时中乡', 47.5260000, 125.9601700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26186, 'Xinjian', 'Xinjian', 'Xinjian,Xinjian Xiang,xin jian,xin jian xiang,新建,新建乡', 47.8016800, 125.6624600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26187, 'Dazhong', 'Dazhong', 'Dazhong,Dazhong Xiang,da zhong,da zhong xiang,大众,大众乡', 47.7931700, 125.8692700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26188, 'Jianguo', 'Jianguo', 'Jianguo,Jianguo Xiang,jian guo,jian guo xiang,建国,建国乡', 47.8205200, 126.0808700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26189, 'Magang', 'Magang', 'Magang,Magang Zhen,ma gang,ma gang zhen,马港,马港镇', 29.1840600, 113.7733700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26190, 'Tanghu', 'Tanghu', 'Tanghu,Tanghu Zhen,tang hu,tang hu zhen,塘湖,塘湖镇', 29.2135300, 113.9826900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26191, 'Guandao', 'Guandao', 'Guandao,Guandao Zhen,guan dao,guan dao zhen,关刀,关刀镇', 29.2174500, 113.9001200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26192, 'Wuli', 'Wuli', 'Wuli,Wuli Zhen,wu li,wu li zhen,五里,五里镇', 29.2200800, 113.7814300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26193, 'Sizhuang', 'Sizhuang', 'Sizhuang,Sizhuang Xiang,si zhuang,si zhuang xiang,四庄,四庄乡', 29.3240000, 113.9487200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26194, 'Daping', 'Daping', 'Daping,Daping Xiang,da ping,da ping xiang,大坪,大坪乡', 29.3297100, 113.6901200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26195, 'Xiaoling', 'Xiaoling', 'Xiaoling,Xiaoling Xiang,xiao ling,xiao ling xiang,肖岭,肖岭乡', 29.3499600, 113.8053600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26196, 'Shicheng', 'Shicheng', 'Shicheng,Shicheng Zhen,shi cheng,shi cheng zhen,石城,石城镇', 29.4655100, 113.9268300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26197, 'Sanzhou', 'Sanzhou', 'Sanzhou,Sanzhou Zhen,san zhou,san zhou zhen,三洲,三洲镇', 29.5490700, 112.9423100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26198, 'Guihuaquan', 'Guihuaquan', 'Guihuaquan,Guihuaquan Zhen,gui hua quan,gui hua quan zhen,桂花泉,桂花泉镇', 29.5591800, 113.8729400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26199, 'Chiba', 'Chiba', 'Chiba,Chiba Zhen,chi ba,chi ba zhen,尺八,尺八镇', 29.5900400, 113.0119700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26200, 'Jiuheyuan', 'Jiuheyuan', 'Jiuheyuan,Jiuheyuan Xiang,jiu he yuan,jiu he yuan xiang,久合垸,久合垸乡', 29.6057000, 112.3790800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26201, 'Cha’anling', 'Cha''anling', 'Cha''anling,Cha''anling Zhen,Cha’anling,Cha’anling Zhen,cha an ling,cha an ling zhen,茶庵岭,茶庵岭镇', 29.6297300, 113.7876000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26202, 'Gaojimiao', 'Gaojimiao', 'Gaojimiao,Gaojimiao Zhen,gao ji miao,gao ji miao zhen,高基庙,高基庙镇', 29.6416900, 112.4256600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26203, 'Taohuashan', 'Taohuashan', 'Taohuashan,Taohuashan Zhen,tao hua shan,tao hua shan zhen,桃花山,桃花山镇', 29.6547800, 112.6875900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26204, 'Jiaoshanhe', 'Jiaoshanhe', 'Jiaoshanhe,Jiaoshanhe Xiang,jiao shan he,jiao shan he xiang,焦山河,焦山河乡', 29.6560300, 112.5657800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26205, 'Diaoguan', 'Diaoguan', 'Diaoguan,Diaoguan Zhen,diao guan,diao guan zhen,调关,调关镇', 29.6912700, 112.6265600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26206, 'Qiaoshi', 'Qiaoshi', 'Qiaoshi,Qiaoshi Zhen,qiao shi,qiao shi zhen,桥市,桥市镇', 29.7074900, 113.1764800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26207, 'Dongsheng', 'Dongsheng', 'Dongsheng,Dongsheng Zhen,dong sheng,dong sheng zhen,东升,东升镇', 29.7168300, 112.5228500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26208, 'Gaoling', 'Gaoling', 'Gaoling,Gaoling Zhen,gao ling,gao ling zhen,高陵,高陵镇', 29.7352200, 112.3111800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26209, 'Qipan', 'Qipan', 'Qipan,Qipan Xiang,qi pan,qi pan xiang,棋盘,棋盘乡', 29.7498600, 113.1519500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26210, 'Nankou', 'Nankou', 'Nankou,Nankou Zhen,nan kou,nan kou zhen,南口,南口镇', 29.7513600, 112.3307000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26211, 'Ouchi', 'Ouchi', 'Ouchi,Ouchi Zhen,ou chi,ou chi zhen,藕池,藕池镇', 29.7517300, 112.3161100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26212, 'Xiaohekou', 'Xiaohekou', 'Xiaohekou,Xiaohekou Zhen,xiao he kou,xiao he kou zhen,小河口,小河口镇', 29.7785400, 112.6207700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26213, 'Renmindayuan', 'Renmindayuan', 'Renmindayuan,Renmindayuan Xiang,ren min da yuan,ren min da yuan xiang,人民大垸,人民大垸乡', 29.8351100, 112.4702000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26214, 'Hongcheng', 'Hongcheng', 'Hongcheng,Hongcheng Xiang,hong cheng,hong cheng xiang,红城,红城乡', 29.8432800, 112.8890000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26215, 'Zhangtiansi', 'Zhangtiansi', 'Zhangtiansi,Zhangtiansi Xiang,zhang tian si,zhang tian si xiang,章田寺,章田寺乡', 29.8534900, 112.2047700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26216, 'Gaotieling', 'Gaotieling', 'Gaotieling,Gaotieling Zhen,gao tie ling,gao tie ling zhen,高铁岭,高铁岭镇', 29.8616700, 113.7927400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26217, 'Liushanhu', 'Liushanhu', 'Liushanhu,Liushanhu Zhen,liu shan hu,liu shan hu zhen,柳山湖,柳山湖镇', 29.8625300, 113.6474000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26218, 'Zhouhe', 'Zhouhe', 'Zhouhe,Zhouhe Xiang,zhou he,zhou he xiang,周河,周河乡', 29.8956700, 113.2153700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26219, 'Futiansi', 'Futiansi', 'Futiansi,Futiansi Zhen,fu tian si,fu tian si zhen,福田寺,福田寺镇', 29.8989900, 113.0791200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26220, 'Hengshi', 'Hengshi', 'Hengshi,Hengshi Zhen,heng shi,heng shi zhen,横市,横市镇', 29.9028400, 112.5503700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26221, 'Wulin', 'Wulin', 'Wulin,Wulin Zhen,wu lin,wu lin zhen,乌林,乌林镇', 29.9128900, 113.5953300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26222, 'Luxi', 'Luxi', 'Lu Tsi Kau,Luxi,Luxi Zhen,lu xi,lu xi zhen,陆溪,陆溪镇', 29.9171800, 113.6792200, 'CN', '2015-01-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26223, 'Guanqiao', 'Guanqiao', 'Guanqiao,Guanqiao Zhen,guan qiao,guan qiao zhen,官桥,官桥镇', 29.9223400, 113.9419200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26224, 'Chengji', 'Chengji', 'Chengji,Chengji Zhen,cheng ji,cheng ji zhen,程集,程集镇', 29.9369600, 112.6356600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26225, 'Qujiawan', 'Qujiawan', 'Qujiawan,Qujiawan Zhen,ju jia wan,ju jia wan zhen,瞿家湾,瞿家湾镇', 29.9676400, 113.1885700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26226, 'Qinshi', 'Qinshi', 'Qinshi,Qinshi Xiang,qin shi,qin shi xiang,秦市,秦市乡', 29.9692600, 112.6001600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26227, 'Mahaokou', 'Mahaokou', 'Mahaokou,Mahaokou Zhen,ma hao kou,ma hao kou zhen,麻豪口,麻豪口镇', 29.9748700, 112.3026100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26228, 'Chahe', 'Chahe', 'Chahe,Chahe Zhen,cha he,cha he zhen,汊河,汊河镇', 29.9990200, 113.4663700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26229, 'Chahe', 'Chahe', 'Chahe,Chahe Zhen,cha he,cha he zhen,汊河,汊河镇', 30.0020900, 113.4647300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26230, 'Wanquan', 'Wanquan', 'Wanquan,Wanquan Zhen,wan quan,wan quan zhen,万全,万全镇', 30.0291600, 113.3858300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26231, 'Daijiachang', 'Daijiachang', 'Daijiachang,Daijiachang Zhen,dai jia chang,dai jia chang zhen,戴家场,戴家场镇', 30.0312800, 113.2222200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26232, 'Huangjiakou', 'Huangjiakou', 'Huangjiakou,Huangjiakou Zhen,huang jia kou,huang jia kou zhen,黄家口,黄家口镇', 30.0693100, 113.5497500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26233, 'Caoshi', 'Caoshi', 'Caoshi,Caoshi Zhen,cao shi,cao shi zhen,曹市,曹市镇', 30.0922100, 113.2147700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26234, 'Wangshi', 'Wangshi', 'Wangshi,Wangshi Zhen,wang shi,wang shi zhen,网市,网市镇', 30.1116500, 113.1055100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26235, 'Xintan', 'Xintan', 'Xintan,Xintan Zhen,xin tan,xin tan zhen,新滩,新滩镇', 30.1686700, 113.8888000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26236, 'Xingfu', 'Xingfu', 'Xingfu,Xingfu Zhen,xing fu,xing fu zhen,幸福,幸福镇', 30.1879100, 113.0142900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26237, 'Mianchenghuizu', 'Mianchenghuizu', 'Mianchenghuizu,Mianchenghuizu Zhen,mian cheng hui zu,mian cheng hui zu zhen,沔城回族,沔城回族镇', 30.1988100, 113.2244600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26238, 'Chenchang', 'Chenchang', 'Chenchang,Chenchang Zhen,chen chang,chen chang zhen,陈场,陈场镇', 30.2397300, 113.0773400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26239, 'Yinlianhu', 'Yinlianhu', 'Yinlianhu,Yinlianhu Jiedao,yin lian hu,yin lian hu jie dao,银莲湖,银莲湖街道', 30.2426300, 113.7729900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26240, 'Guohe', 'Guohe', 'Guohe,Guohe Zhen,guo he,guo he zhen,郭河,郭河镇', 30.2457600, 113.2902300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26241, 'Zhanggou', 'Zhanggou', 'Zhanggou,Zhanggou Zhen,zhang gou,zhang gou zhen,张沟,张沟镇', 30.2495300, 113.3726400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26242, 'Pengchang', 'Pengchang', 'Pengchang,Pengchang Zhen,peng chang,peng chang zhen,彭场,彭场镇', 30.2509500, 113.5132800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26243, 'Hannan', 'Hannan', 'Hannan,Hannan Jiedao,han nan,han nan jie dao,汉南,汉南街道', 30.2658800, 113.8435000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26244, 'Dengnan', 'Dengnan', 'Dengnan,Dengnan Zhen,deng nan,deng nan zhen,邓南,邓南镇', 30.3029800, 113.9770600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26245, 'Xiaosi', 'Xiaosi', 'Xiaosi,Xiaosi Xiang,xiao si,xiao si xiang,消泗,消泗乡', 30.3171400, 113.7728900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26246, 'Dongchengyuan', 'Dongchengyuan', 'Dongchengyuan,Dongchengyuan Jiedao,dong cheng yuan,dong cheng yuan jie dao,东城垸,东城垸街道', 30.3470900, 113.9090100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26247, 'Shazui', 'Shazui', 'Shazui,Shazui Jiedao,sha zui,sha zui jie dao,沙嘴,沙嘴街道', 30.3590800, 113.4457300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26248, 'Longhuashan', 'Longhuashan', 'Longhuashan,Longhuashan Jiedao,long hua shan,long hua shan jie dao,龙华山,龙华山街道', 30.3720700, 113.4543700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26249, 'Sanfutan', 'Sanfutan', 'Sanfutan,Sanfutan Zhen,san fu tan,san fu tan zhen,三伏潭,三伏潭镇', 30.3761300, 113.1950600, 'CN', '2013-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26250, 'Ganhe', 'Ganhe', 'Ganhe,Ganhe Jiedao,gan he,gan he jie dao,干河,干河街道', 30.3769700, 113.4196400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26251, 'Chenggong', 'Chenggong', 'Chenggong,Chenggong Xiang,cheng gong,cheng gong xiang,成功,成功乡', 30.4051700, 113.7158600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26252, 'Duoxiang', 'Duoxiang', 'Duoxiang,Duoxiang Zhen,duo xiang,duo xiang zhen,多祥,多祥镇', 30.4277400, 113.3601100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26253, 'Zhuru', 'Zhuru', 'Zhuru,Zhuru Jiedao,zhu ru,zhu ru jie dao,侏儒,侏儒街道', 30.4416900, 113.8358200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26254, 'Chenhu', 'Chenhu', 'Chenhu,Chenhu Zhen,Shang lao tsei,chen hu,chen hu zhen,沉湖,沉湖镇', 30.4499500, 113.5285500, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26255, 'Xijiang', 'Xijiang', 'Xijiang,Xijiang Xiang,xi jiang,xi jiang xiang,西江,西江乡', 30.4812300, 113.6667700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26256, 'Zhengchang', 'Zhengchang', 'Zhengchang,Zhengchang Zhen,zheng chang,zheng chang zhen,郑场,郑场镇', 30.4926500, 113.0279700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26257, 'Nanhe', 'Nanhe', 'Nanhe,Nanhe Xiang,nan he,nan he xiang,南河,南河乡', 30.4926500, 113.7737000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26258, 'Lijiazui', 'Lijiazui', 'Lijiajzui Xiang,Lijiazui,li jia ju,li jia ju xiang,李家咀,李家咀乡', 30.5080400, 113.0549600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26259, 'Huilong', 'Huilong', 'Huilong,Huilong Zhen,hui long,hui long zhen,回龙,回龙镇', 30.5091700, 113.5118100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26260, 'Suohe', 'Suohe', 'Suohe,Suohe Zhen,suo he,suo he zhen,索河,索河镇', 30.5215100, 113.8974000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26261, 'Yuxian', 'Yuxian', 'Yuxian,Yuxian Zhen,yu xian,yu xian zhen,玉贤,玉贤镇', 30.5251700, 113.9785100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26262, 'Henglin', 'Henglin', 'Henglin,Henglin Zhen,heng lin,heng lin zhen,横林,横林镇', 30.5339300, 113.1802200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26263, 'Mawan', 'Mawan', 'Mawan,Mawan Zhen,ma wan,ma wan zhen,马湾,马湾镇', 30.5754600, 113.3277500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26264, 'Litan', 'Litan', 'Litan,Litan Xiang,li tan,li tan xiang,里潭,里潭乡', 30.5803500, 113.5631900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26265, 'Wantan', 'Wantan', 'Wantan,Wantan Xiang,wan tan,wan tan xiang,湾潭,湾潭乡', 30.5815700, 113.6786200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26266, 'Fenshui', 'Fenshui', 'Fengshuitsui,Fenshui,Fenshui Zhen,fen shui,fen shui zhen,分水,分水镇', 30.5836100, 113.6493300, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26267, 'Zhangwan', 'Zhangwan', 'Zhangwan,Zhangwan Jiedao,zhang wan,zhang wan jie dao,张湾,张湾街道', 30.5842200, 113.9756200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26268, 'Miaotou', 'Miaotou', 'Mia tau,Miaotou,Miaotou Zhen,miao tou,miao tou zhen,庙头,庙头镇', 30.5933800, 113.7798900, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26269, 'Ma’an', 'Ma''an', 'Ma''an,Ma''an Xiang,Ma’an,Ma’an Xiang,ma an,ma an xiang,马鞍,马鞍乡', 30.6055700, 113.8676200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26270, 'Chenghuang', 'Chenghuang', 'Chenghuang,Chenghuang Zhen,Shih zhe king,cheng huang,cheng huang zhen,城隍,城隍镇', 30.6221500, 113.7616100, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26271, 'Houkou', 'Houkou', 'Houkou,Houkou Jiedao,hou kou,hou kou jie dao,候口,候口街道', 30.6250500, 113.1398300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26272, 'Yanglin', 'Yanglin', 'Yanglin,Yanglin Jiedao,yang lin,yang lin jie dao,杨林,杨林街道', 30.6412500, 113.1876300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26273, 'Xiannüshan', 'Xiannushan', 'Hanchwanhsien,Xiannushan,Xiannushan Jiedao,Xiannüshan,Xiannüshan Jiedao,xian nu shan,xian nu shan jie dao,仙女山,仙女山街道', 30.6426100, 113.8288000, 'CN', '2016-04-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26274, 'Jingtan', 'Jingtan', 'Jingtan,Jingtan Xiang,jing tan,jing tan xiang,净潭,净潭乡', 30.6555400, 113.3905600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26275, 'Hanji', 'Hanji', 'Hanji,Hanji Xiang,han ji,han ji xiang,韩集,韩集乡', 30.6721700, 113.6021300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26276, 'Xinhe', 'Xinhe', 'Xinhe,Xinhe Zhen,xin he,xin he zhen,新河,新河镇', 30.6891900, 113.9332600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26277, 'Hebaohu', 'Hebaohu', 'Hebaohu,Hebaohu Jiedao,he bao hu,he bao hu jie dao,荷苞湖,荷苞湖街道', 30.7012800, 113.9722800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26278, 'Xinyan', 'Xinyan', 'Xinyan,Xinyan Zhen,xin yan,xin yan zhen,新堰,新堰镇', 30.7113100, 113.5141800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26279, 'Sihe', 'Sihe', 'Sihe,Sihe Zhen,si he,si he zhen,四合,四合镇', 30.7256600, 113.3163000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26280, 'Xin’andu', 'Xin''andu', 'Xin''andu,Xin''andu Jiedao,Xin’andu,Xin’andu Jiedao,xin an du,xin an du jie dao,辛安渡,辛安渡街道', 30.7438100, 113.9271000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26281, 'Fozishan', 'Fozishan', 'Fozishan,Fozishan Zhen,fu zi shan,fu zi shan zhen,佛子山,佛子山镇', 30.7556000, 113.0013100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26282, 'Yihe', 'Yihe', 'Yihe,Yihe Zhen,yi he,yi he zhen,义和,义和镇', 30.7556900, 113.5052300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26283, 'Dongzhong', 'Dongzhong', 'Dongzhong,Dongzhong Zhen,dong zhong,dong zhong zhen,垌冢,垌冢镇', 30.7739200, 113.4308600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26284, 'Hushi', 'Hushi', 'Hushi,Hushi Zhen,hu shi,hu shi zhen,胡市,胡市镇', 30.7761900, 113.3849100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26285, 'Mahe', 'Mahe', 'Mahe,Mahe Zhen,ma he,ma he zhen,麻河,麻河镇', 30.7805700, 113.6875800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26286, 'Daoqiao', 'Daoqiao', 'Daoqiao,Daoqiao Zhen,dao qiao,dao qiao zhen,道桥,道桥镇', 30.8191900, 113.7533100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26287, 'Liuhe', 'Liuhe', 'Liuhe,Liuhe Zhen,liu he,liu he zhen,六合,六合镇', 30.8252700, 113.3938200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26288, 'Xiaxindian', 'Xiaxindian', 'Xiaxindian,Xiaxindian Zhen,xia xin dian,xia xin dian zhen,下辛店,下辛店镇', 30.8337300, 113.8358600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26289, 'Qianchang', 'Qianchang', 'Qianchang,Qianchang Zhen,qian chang,qian chang zhen,钱场,钱场镇', 30.8402000, 113.0935500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26290, 'Changjiangbu', 'Changjiangbu', 'Changjiangbu,Changjiangbu Jiedao,zhang jiang bu,zhang jiang bu jie dao,长江埠,长江埠街道', 30.8610500, 113.7260800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26291, 'Chenhe', 'Chenhe', 'Chenhe,Chenhe Zhen,chen he,chen he zhen,陈河,陈河镇', 30.8613700, 113.4711000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26292, 'Maochen', 'Maochen', 'Maochen,Maochen Zhen,mao chen,mao chen zhen,毛陈,毛陈镇', 30.8644700, 113.9677500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26293, 'Huzhen', 'Huzhen', 'Huzhen,hu zhen,护镇', 30.8897900, 113.7667400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26294, 'Langjun', 'Langjun', 'Langjun,Langjun Zhen,lang jun,lang jun zhen,郎君,郎君镇', 30.8984300, 113.6722100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26295, 'Yangling', 'Yangling', 'Yangling,Yangling Zhen,yang ling,yang ling zhen,杨岭,杨岭镇', 30.9021500, 113.3990700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26296, 'Tangchi', 'Tangchi', 'Tangchi,Tangchi Zhen,tang chi,tang chi zhen,汤池,汤池镇', 30.9102100, 113.3428700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26297, 'Langjun', 'Langjun', 'Langjun,Langjun Zhen,lang jun,lang jun zhen,郎君,郎君镇', 30.9112800, 113.6436500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26298, 'Xinhua', 'Xinhua', 'Xinhua,Xinhua Jiedao,xin hua,xin hua jie dao,新华,新华街道', 30.9149700, 113.9091700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26299, 'Dongmafang', 'Dongmafang', 'Dongmafang,Dongmafang Jiedao,dong ma fang,dong ma fang jie dao,东马坊,东马坊街道', 30.9188300, 113.6959600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26300, 'Shuyuan', 'Shuyuan', 'Shuyuan,Shuyuan Jiedao,shu yuan,shu yuan jie dao,书院,书院街道', 30.9214300, 113.9005100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26301, 'Guangchang', 'Guangchang', 'Guangchang,Guangchang Jiedao,guang chang,guang chang jie dao,广场,广场街道', 30.9245400, 113.9135000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26302, 'Wufu', 'Wufu', 'Wufu,Wufu Zhen,wu fu,wu fu zhen,五福,五福镇', 30.9278700, 113.2641600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26303, 'Shahe', 'Shahe', 'Shahe,Shahe Xiang,sha he,sha he xiang,沙河,沙河乡', 30.9351200, 113.8226700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26304, 'Yihe', 'Yihe', 'Yihe,Yihe Zhen,yi he,yi he zhen,义和,义和镇', 30.9376900, 113.1954900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26305, 'Geputan', 'Geputan', 'Geputan,Geputan Zhen,ge pu tan,ge pu tan zhen,隔蒲潭,隔蒲潭镇', 30.9405400, 113.7248700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26306, 'Silipeng', 'Silipeng', 'Silipeng,Silipeng Jiedao,si li peng,si li peng jie dao,四里棚,四里棚街道', 30.9454000, 113.6114000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26307, 'Chezhan', 'Chezhan', 'Chezhan,Chezhan Jiedao,che zhan,che zhan jie dao,车站,车站街道', 30.9514600, 113.9210500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26308, 'Chengbei', 'Chengbei', 'Chengbei,Chengbei Jiedao,cheng bei,cheng bei jie dao,城北,城北街道', 30.9646300, 113.5716400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26309, 'Pengxing', 'Pengxing', 'Pengxing,Pengxing Xiang,peng xing,peng xing xiang,朋兴,朋兴乡', 30.9657500, 113.9122600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26310, 'Caowu', 'Caowu', 'Caowu,Caowu Zhen,cao wu,cao wu zhen,曹武,曹武镇', 30.9711100, 113.3428200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26311, 'Xinpu', 'Xinpu', 'Xinpu,Xinpu Zhen,xin pu,xin pu zhen,新铺,新铺镇', 30.9822700, 113.9803500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26312, 'Xinghua', 'Xinghua', 'Xinghua,Xinghua Xiang,xing hua,xing hua xiang,兴华,兴华乡', 47.6959900, 126.0538400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26313, 'Dayong', 'Dayong', 'Dayong,Dayong Zhen,da yong,da yong zhen,大用,大用镇', 46.2840700, 126.7152500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26314, 'Lianhua', 'Lianhua', 'Lianhua,Lianhua Zhen,lian hua,lian hua zhen,莲花,莲花镇', 46.3367500, 126.7801800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26315, 'Xubao', 'Xubao', 'Xubao,Xubao Xiang,xu bao,xu bao xiang,许堡,许堡乡', 46.1631000, 126.6790100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26316, 'Erba', 'Erba', 'Erba,Erba Zhen,er ba,er ba zhen,二八,二八镇', 46.1128600, 127.0295200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26317, 'Shuangjing', 'Shuangjing', 'Shuangjing,Shuangjing Zhen,shuang jing,shuang jing zhen,双井,双井镇', 46.0370800, 126.7223300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26318, 'Changling', 'Changling', 'Changling,Changling Zhen,zhang ling,zhang ling zhen,长岭,长岭镇', 46.0466500, 126.6400500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26319, 'Mengjia', 'Mengjia', 'Mengjia,Mengjia Xiang,meng jia,meng jia xiang,孟家,孟家乡', 46.0599600, 126.5522400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26320, 'Fengle', 'Fengle', 'Fengle,Fengle Xiang,feng le,feng le xiang,丰乐,丰乐乡', 46.2417100, 127.1381900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26321, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 46.4406400, 127.1006200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26322, 'Hongguang', 'Hongguang', 'Hongguang,Hongguang Xiang,hong guang,hong guang xiang,红光,红光乡', 46.4238200, 126.9677800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26323, 'Wanfa', 'Wanfa', 'Wanfa,Wanfa Zhen,wan fa,wan fa zhen,万发,万发镇', 46.5345200, 127.1205200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26324, 'Dexiang', 'Dexiang', 'Dexiang,Dexiang Xiang,de xiang,de xiang xiang,德祥,德祥乡', 46.4913100, 127.1840700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26325, 'Longmiao', 'Longmiao', 'Longmiao,Longmiao Zhen,long miao,long miao zhen,龙庙,龙庙镇', 46.3511300, 127.2273900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26326, 'Wangying', 'Wangying', 'Wangying,Wangying Zhen,wang ying,wang ying zhen,汪营,汪营镇', 30.2718100, 108.6937900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26327, 'Shaxi', 'Shaxi', 'Shaxi,Shaxi Xiang,sha xi,sha xi xiang,沙溪,沙溪乡', 29.9097500, 108.7355000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26328, 'Liangwu', 'Liangwu', 'Liangwu,Liangwu Xiang,liang wu,liang wu xiang,凉雾,凉雾乡', 30.2680200, 108.8200400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26329, 'Baiyang', 'Baiyang', 'Baiyang,Baiyang Zhen,bai yang,bai yang zhen,柏杨,柏杨镇', 30.4735000, 108.9028700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26330, 'Chaoyangsi', 'Chaoyangsi', 'Chaoyangsi,Chaoyangsi Zhen,chao yang si,chao yang si zhen,朝阳寺,朝阳寺镇', 29.5917700, 108.9088700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26331, 'Yuanbao', 'Yuanbao', 'Yuanbao,Yuanbao Xiang,yuan bao,yuan bao xiang,元堡,元堡乡', 30.2358800, 109.0051400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26332, 'Tuanbao', 'Tuanbao', 'Tuanbao,Tuanbao Zhen,tuan bao,tuan bao zhen,团堡,团堡镇', 30.3367500, 109.1346500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26333, 'Baiguo', 'Baiguo', 'Baiguo,Baiguo Xiang,bai guo,bai guo xiang,白果,白果乡', 30.2277300, 109.3330500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26334, 'Liujiaoting', 'Liujiaoting', 'Liujiaoting,Liujiaoting Jiedao,liu jiao ting,liu jiao ting jie dao,六角亭,六角亭街道', 30.2619900, 109.4726300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26335, 'Xiaoduchuan', 'Xiaoduchuan', 'Xiaoduchuan,Xiaoduchuan Jiedao,xiao du chuan,xiao du chuan jie dao,小渡船,小渡船街道', 30.2911300, 109.4761600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26336, 'Wuyangba', 'Wuyangba', 'Wuyangba,Wuyangba Jiedao,wu yang ba,wu yang ba jie dao,舞阳坝,舞阳坝街道', 30.2738300, 109.4894300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26337, 'Nuoxizhi', 'Nuoxizhi', 'Nuoxizhi,Nuoxizhi Xiang,nuo xi zhi,nuo xi zhi xiang,傩戏之,傩戏之乡', 30.2785000, 109.6286600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26338, 'Shadi', 'Shadi', 'Shadi,Shadi Xiang,sha de,sha de xiang,沙地,沙地乡', 30.3374300, 109.7504400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26339, 'Chunmuying', 'Chunmuying', 'Chunmuying,Chunmuying Xiang,chun mu ying,chun mu ying xiang,椿木营,椿木营乡', 30.0560600, 109.8241800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26340, 'Heshuiping', 'Heshuiping', 'Heshuiping,Heshuiping Xiang,he shui ping,he shui ping xiang,河水坪,河水坪乡', 30.5785000, 109.8528700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26341, 'Sanli', 'Sanli', 'Sanli,Sanli Xiang,san li,san li xiang,三里,三里乡', 30.6235500, 109.9044100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26342, 'Hongtu', 'Hongtu', 'Hongtu,Hongtu Xiang,hong tu,hong tu xiang,红土,红土乡', 30.2637400, 109.9065600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26343, 'Shangcunba', 'Shangcunba', 'Shangcunba,Shangcunba Xiang,shang cun ba,shang cun ba xiang,上村坝,上村坝乡', 30.2820800, 109.9675600, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26344, 'Jingyang', 'Jingyang', 'Jingyang,Jingyang Zhen,jing yang,jing yang zhen,景阳,景阳镇', 30.3682200, 110.0027400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26345, 'Guandian', 'Guandian', 'Guandian,Guandian Zhen,guan dian,guan dian zhen,官店,官店镇', 30.2400400, 110.0442900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26346, 'Dazhiping', 'Dazhiping', 'Dazhiping,Dazhiping Zhen,da zhi ping,da zhi ping zhen,大支坪,大支坪镇', 30.6694300, 110.1319100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26347, 'Wuyang', 'Wuyang', 'Wuyang,Wuyang Xiang,wu yang,wu yang xiang,邬阳,邬阳乡', 30.1826800, 110.1621100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26348, 'Majiagou', 'Majiagou', 'Majiagou,Majiagou Xiang,ma jia gou,ma jia gou xiang,马家沟,马家沟乡', 30.2918900, 110.2222700, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26349, 'Jinguoping', 'Jinguoping', 'Jinguoping,Jinguoping Xiang,jin guo ping,jin guo ping xiang,金果坪,金果坪乡', 30.2919100, 110.2223000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26350, 'Shuibuya', 'Shuibuya', 'Shuibuya,Shuibuya Zhen,shui bu ya,shui bu ya zhen,水布垭,水布垭镇', 30.4427000, 110.3293400, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26351, 'Niuzhuang', 'Niuzhuang', 'Niuzhuang,Niuzhuang Xiang,niu zhuang,niu zhuang xiang,牛庄,牛庄乡', 30.2395100, 110.3604100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26352, 'Xiqiuwan', 'Xiqiuwan', 'Xiqiuwan,Xiqiuwan Xiang,xi qiu wan,xi qiu wan xiang,溪丘湾,溪丘湾乡', 31.1443100, 110.4427200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26353, 'Meijiahe', 'Meijiahe', 'Meijiahe,Meijiahe Xiang,mei jia he,mei jia he xiang,梅家河,梅家河乡', 30.9194000, 110.4859800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26354, 'Xietan', 'Xietan', 'Xietan,Xietan Xiang,xie tan,xie tan xiang,泄滩,泄滩乡', 31.0110500, 110.6182800, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26355, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 31.3146500, 110.6692000, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26356, 'Guizhou', 'Guizhou', 'Guizhou,Guizhou Zhen,gui zhou,gui zhou zhen,归州,归州镇', 30.9969500, 110.6897500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26357, 'Yanglinqiao', 'Yanglinqiao', 'Yanglinqiao,Yanglinqiao Zhen,yang lin qiao,yang lin qiao zhen,杨林桥,杨林桥镇', 30.7491100, 110.7591200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26358, 'Gaoyang', 'Gaoyang', 'Gaoyang,Gaoyang Zhen,gao yang,gao yang zhen,高阳,高阳镇', 31.2311400, 110.7620100, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26359, 'Xiakou', 'Xiakou', 'Xiakou,Xiakou Zhen,xia kou,xia kou zhen,峡口,峡口镇', 31.1206400, 110.7795500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26360, 'Zhouping', 'Zhouping', 'Zhouping,Zhouping Xiang,zhou ping,zhou ping xiang,周坪,周坪乡', 30.8433500, 110.7799200, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26361, 'Huangliang', 'Huangliang', 'Huangliang,Huangliang Zhen,huang liang,huang liang zhen,黄粮,黄粮镇', 31.2639200, 110.8255900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26362, 'Quyuan', 'Quyuan', 'Quyuan,Quyuan Zhen,qu yuan,qu yuan zhen,屈原,屈原镇', 30.9357500, 110.8288900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26363, 'Jianyangping', 'Jianyangping', 'Jianyangping,Jianyangping Xiang,jian yang ping,jian yang ping xiang,建阳坪,建阳坪乡', 31.1325600, 110.8310300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26364, 'Yazikou', 'Yazikou', 'Yazikou,Yazikou Xiang,ya zi kou,ya zi kou xiang,鸭子口,鸭子口乡', 30.4459700, 110.9262500, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26365, 'Duzhenwan', 'Duzhenwan', 'Duzhenwan,Duzhenwan Zhen,dou zhen wan,dou zhen wan zhen,都镇湾,都镇湾镇', 30.4146700, 110.9580900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26366, 'Hehua', 'Hehua', 'Hehua,Hehua Zhen,he hua,he hua zhen,荷花,荷花镇', 31.1921200, 111.4077300, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26367, 'Mahe', 'Mahe', 'Mahe,Mahe Zhen,ma he,ma he zhen,马河,马河镇', 31.1413700, 111.9353900, 'CN', '2013-04-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26368, 'Changshan', 'Changshan', 'Changshan,Changshan Xiang,zhang shan,zhang shan xiang,长山,长山乡', 47.2171400, 127.3848400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26369, 'Xuri', 'Xuri', 'Xuri,Xuri Jiedao,Yichun Qu,xu ri,xu ri jie dao,yi chun qu,伊春区,旭日,旭日街道', 47.7268500, 128.8999400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26370, 'Yingchun', 'Yingchun', 'Yingchun,Yingchun Xiang,ying chun,ying chun xiang,迎春,迎春乡', 47.1450300, 129.2336800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26371, 'Tangwang', 'Tangwang', 'Tangwang,Tangwang Chaoxianzu Xiang,tang wang,tang wang chao xian zu xiang,汤旺,汤旺朝鲜族乡', 46.6081100, 129.7420900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26372, 'Youyi', 'Youyi', 'Jiao Qu,Youyi,Youyi Jiedao,jiao qu,you yi,you yi jie dao,友谊,友谊街道,郊区', 46.8048500, 130.3192200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26373, 'Changqing', 'Changqing', 'Changqing,Changqing Xiang,zhang qing,zhang qing xiang,长青,长青乡', 46.8016800, 130.2901700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26374, 'Xigemu', 'Xigemu', 'Xigemu,Xigemu Xiang,xi ge mu,xi ge mu xiang,西格木,西格木乡', 46.7475700, 130.2653800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26375, 'Yanjiang', 'Yanjiang', 'Yanjiang,Yanjiang Xiang,yan jiang,yan jiang xiang,沿江,沿江乡', 46.7919000, 130.2104400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26376, 'Zhulian', 'Zhulian', 'Zhulian,Zhulian Zhen,zhu lian,zhu lian zhen,竹帘,竹帘镇', 46.6009900, 129.8653600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26377, 'Taipingchuan', 'Taipingchuan', 'Taipingchuan,Taipingchuan Xiang,tai ping chuan,tai ping chuan xiang,太平川,太平川乡', 46.8722400, 129.9922400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26378, 'Aoqi', 'Aoqi', 'Aoqi,Aoqi Zhen,ao qi,ao qi zhen,敖其,敖其镇', 46.7427500, 130.0931300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26379, 'Qiaonan', 'Qiaonan', 'Qiaonan,Qiaonan Jiedao,Xiangyang Qu,qiao nan,qiao nan jie dao,xiang yang qu,向阳区,桥南,桥南街道', 46.8036100, 130.3580500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26380, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Xiang,Ping’an,Ping’an Xiang,ping an,ping an xiang,平安,平安乡', 46.8770000, 130.3192100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26381, 'Zhanqian', 'Zhanqian', 'Qianjin Qu,Zhanqian,Zhanqian Jiedao,qian jin qu,zhan qian,zhan qian jie dao,前进区,站前,站前街道', 46.8001100, 130.3754700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26382, 'Jianguo', 'Jianguo', 'Dongfeng Qu,Jianguo,Jianguo Jiedao,dong feng qu,jian guo,jian guo jie dao,东风区,建国,建国街道', 46.8177000, 130.3961500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26383, 'Songjiang', 'Songjiang', 'Songjiang,Songjiang Xiang,song jiang,song jiang xiang,松江,松江乡', 46.8344300, 130.4316100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26384, 'Jianguo', 'Jianguo', 'Jianguo,Jianguo Xiang,jian guo,jian guo xiang,建国,建国乡', 46.8756800, 130.5484900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26385, 'Qunsheng', 'Qunsheng', 'Qunsheng,Qunsheng Xiang,qun sheng,qun sheng xiang,群胜,群胜乡', 46.6489200, 130.1504200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26386, 'Yongfa', 'Yongfa', 'Yongfa,Yongfa Xiang,yong fa,yong fa xiang,永发,永发乡', 47.0205800, 130.2394700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26387, 'Jixiang', 'Jixiang', 'Jixiang,Jixiang Xiang,ji xiang,ji xiang xiang,吉祥,吉祥乡', 47.0316100, 130.3902500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26388, 'Mingshan', 'Mingshan', 'Mingshan,Mingshan Xiang,ming shan,ming shan xiang,名山,名山乡', 48.0965900, 126.2360500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26389, 'Xing’an', 'Xing''an', 'Xing''an,Xing''an Jiedao,Xing''an Qu,Xing’an,Xing’an Jiedao,Xing’an Qu,xing an,xing an jie dao,xing an qu,兴安,兴安区,兴安街道', 47.2463000, 130.2203800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26390, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Xiang,hong qi,hong qi xiang,红旗,红旗乡', 47.2371800, 130.1909300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26391, 'Tiexi', 'Tiexi', 'Nanshan Qu,Tiexi,Tiexi Jiedao,nan shan qu,tie xi,tie xi jie dao,南山区,铁西,铁西街道', 47.3118700, 130.2802700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26392, 'Hongqi', 'Hongqi', 'Gongnong Qu,Hongqi,Hongqi Jiedao,gong nong qu,hong qi,hong qi jie dao,工农区,红旗,红旗街道', 47.3180000, 130.2679000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26393, 'Shuyuan', 'Shuyuan', 'Shuyuan,Shuyuan Xiang,shu yuan,shu yuan xiang,蔬园,蔬园乡', 47.3352900, 130.2704400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26394, 'Guangming', 'Guangming', 'Guangming,Guangming Jiedao,Xiangyang Qu,guang ming,guang ming jie dao,xiang yang qu,光明,光明街道,向阳区', 47.3397200, 130.2867900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26395, 'Dongshan', 'Dongshan', 'Dongshan,Dongshan Jiedao,Dongshan Qu,dong shan,dong shan jie dao,dong shan qu,东山,东山区,东山街道', 47.3427700, 130.3122200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26396, 'Gounan', 'Gounan', 'Gounan,Gounan Jiedao,Xingshan Qu,gou nan,gou nan jie dao,xing shan qu,兴山区,沟南,沟南街道', 47.3594100, 130.2974700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26397, 'Dongfanghong', 'Dongfanghong', 'Dongfanghong,Dongfanghong Xiang,dong fang hong,dong fang hong xiang,东方红,东方红乡', 47.3319500, 130.3306000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26398, 'Hebei', 'Hebei', 'Hebei,Hebei Zhen,he bei,he bei zhen,鹤北,鹤北镇', 47.5520900, 130.4488900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26399, 'Dongming', 'Dongming', 'Dongming,Dongming Chaoxian Xiang,dong ming,dong ming chao xian xiang,东明,东明朝鲜乡', 47.5747600, 130.8409400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26400, 'Huanshan', 'Huanshan', 'Huanshan,Huanshan Xiang,huan shan,huan shan xiang,环山,环山乡', 47.7242900, 130.6460700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26401, 'Chuangye', 'Chuangye', 'Chuangye,Chuangye Xiang,chuang ye,chuang ye xiang,创业,创业乡', 46.9159100, 130.6454700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26402, 'Xinghuo', 'Xinghuo', 'Xinghuo,Xinghuo Chaoxianzu Xiang,xing huo,xing huo chao xian zu xiang,星火,星火朝鲜族乡', 46.9108900, 130.6035000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26403, 'Simajia', 'Simajia', 'Simajia,Simajia Xiang,si ma jia,si ma jia xiang,四马架,四马架乡', 46.7704800, 130.6172300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26404, 'Hengtoushan', 'Hengtoushan', 'Dongchaoyang,Hengtoushan,Hengtoushan Zhen,dong chao yang,heng tou shan,heng tou shan zhen,东朝阳,横头山,横头山镇', 46.6689500, 130.5832000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26405, 'Fengle', 'Fengle', 'Fengle,Fengle Zhen,feng le,feng le zhen,丰乐,丰乐镇', 46.8145800, 130.8635200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26406, 'Lishu', 'Lishu', 'Lishu,Lishu Xiang,li shu,li shu xiang,梨树,梨树乡', 46.2228000, 130.3995100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26407, 'Qingfa', 'Qingfa', 'Qingfa,Qingfa Xiang,qing fa,qing fa xiang,庆发,庆发乡', 46.3359100, 130.1141200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26408, 'Jiangwan', 'Jiangwan', 'Jiangwan,Jiangwan Zhen,jiang wan,jiang wan zhen,江湾,江湾镇', 46.1584000, 129.6091700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26409, 'Xiangshun', 'Xiangshun', 'Xiangshun,Xiangshun Zhen,xiang shun,xiang shun zhen,祥顺,祥顺镇', 46.0654100, 129.1251900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26410, 'Xinmin', 'Xinmin', 'Xinmin,Xinmin Xiang,xin min,xin min xiang,新民,新民乡', 46.3190400, 127.8160300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26411, 'Dongfanghong', 'Dongfanghong', 'Dongfanghong,Dongfanghong Xiang,dong fang hong,dong fang hong xiang,东方红,东方红乡', 47.3243700, 130.3434800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26412, 'Huashan', 'Huashan', 'Huashan,Huashan Xiang,hua shan,hua shan xiang,华山,华山乡', 46.2270800, 127.3660000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26413, 'Zhendong', 'Zhendong', 'Zhendong,Zhendong Xiang,zhen dong,zhen dong xiang,镇东,镇东乡', 46.2898800, 127.5042700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26414, 'Heishan', 'Heishan', 'Heishan,Heishan Zhen,hei shan,hei shan zhen,黑山,黑山镇', 46.4427800, 127.4697300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26415, 'Huanshan', 'Huanshan', 'Huanshan,Huanshan Xiang,huan shan,huan shan xiang,环山,环山乡', 47.7249600, 130.6409300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26416, 'Shanhou', 'Shanhou', 'Shanhou,Shanhou Xiang,shan hou,shan hou xiang,山后,山后乡', 46.5896700, 127.4012300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26417, 'Fengshou', 'Fengshou', 'Fengshou,Fengshou Xiang,feng shou,feng shou xiang,丰收,丰收乡', 46.8750800, 127.5822300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26418, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Zhen,Ping’an,Ping’an Zhen,ping an,ping an zhen,平安,平安镇', 46.9404400, 127.6399200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26419, 'Liangli', 'Liangli', 'Liangli,Liangli Xiang,liang li,liang li xiang,两利,两利乡', 46.8642300, 127.7632900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26420, 'Xinsheng', 'Xinsheng', 'Xinsheng,Xinsheng Xiang,xin sheng,xin sheng xiang,新胜,新胜乡', 46.7592800, 127.7062400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26421, 'Jianmin', 'Jianmin', 'Jianmin,Jianmin Xiang,jian min,jian min xiang,建民,建民乡', 46.7689600, 127.5534900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26422, 'Hebei', 'Hebei', 'Hebei,Hebei Zhen,he bei,he bei zhen,鹤北,鹤北镇', 47.5522000, 130.4494400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26423, 'Huansheng', 'Huansheng', 'Huansheng,Huansheng Xiang,huan sheng,huan sheng xiang,欢胜,欢胜乡', 46.8120700, 127.3210300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26424, 'Jiusheng', 'Jiusheng', 'Jiusheng,Jiusheng Zhen,jiu sheng,jiu sheng zhen,久胜,久胜镇', 46.8784900, 127.3840400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26425, 'Jubaoshan', 'Jubaoshan', 'Jubaoshan,Jubaoshan Xiang,ju bao shan,ju bao shan xiang,巨宝山,巨宝山乡', 46.6468800, 127.5060200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26426, 'Zhifu', 'Zhifu', 'Zhifu,Zhifu Xiang,zhi fu,zhi fu xiang,致富,致富乡', 46.9904700, 127.4056500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26427, 'Fazhan', 'Fazhan', 'Fazhan,Fazhan Xiang,fa zhan,fa zhan xiang,发展,发展乡', 47.0863700, 127.6341700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26428, 'Nianfeng', 'Nianfeng', 'Nianfeng,Nianfeng Chaoxianzu Xiang,nian feng,nian feng chao xian zu xiang,年丰,年丰朝鲜族乡', 46.9633200, 128.0221500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26429, 'Dongming', 'Dongming', 'Dongming,Dongming Chaoxianzu Xiang,dong ming,dong ming chao xian zu xiang,东明,东明朝鲜族乡', 47.5630400, 130.8334900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26430, 'Wangyang', 'Wangyang', 'Wangyang,Wangyang Xiang,wang yang,wang yang xiang,王杨,王杨乡', 46.9674000, 127.9209500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26431, 'Gongnong', 'Gongnong', 'Gongnong,Gongnong Xiang,gong nong,gong nong xiang,工农,工农乡', 46.9882100, 127.9907300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26432, 'Weiguo', 'Weiguo', 'Weiguo,Weiguo Xiang,wei guo,wei guo xiang,卫国,卫国乡', 46.8942500, 127.8101500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26433, 'Jixing', 'Jixing', 'Jixing,Jixing Xiang,ji xing,ji xing xiang,吉兴,吉兴乡', 45.9938300, 130.4291200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26434, 'Qiangken', 'Qiangken', 'Qiangken,Qiangken Xiang,qiang ken,qiang ken xiang,抢垦,抢垦乡', 45.8923500, 130.6619900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26435, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Xiang,qing shan,qing shan xiang,青山,青山乡', 45.8264600, 130.6916400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26436, 'Beishan', 'Beishan', 'Beishan,Xinxing Qu,bei shan,xin xing qu,北山,新兴区', 45.8162000, 130.9283300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26437, 'Lanling', 'Lanling', 'Lanling,Lanling Xiang,lan ling,lan ling xiang,兰岭,兰岭乡', 45.2950800, 130.7006000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26438, 'Didaohe', 'Didaohe', 'Didaohe,Didaohe Xiang,di dao he,di dao he xiang,滴道河,滴道河乡', 45.3504400, 130.8421500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26439, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Zhen,hong qi,hong qi zhen,红旗,红旗镇', 45.8101100, 130.8692200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26440, 'Wanbaohe', 'Wanbaohe', 'Wanbaohe,Wanbaohe Zhen,wan bao he,wan bao he zhen,万宝河,万宝河镇', 45.7759800, 130.9685500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26441, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Xiang,hong qi,hong qi xiang,红旗,红旗乡', 45.2124400, 130.9248800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26442, 'Hongjunlu', 'Hongjunlu', 'Hongjunlu,Jiguan Qu,hong jun lu,ji guan qu,红军路,鸡冠区', 45.3034700, 130.9759600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26443, 'Hongxing', 'Hongxing', 'Hongxing,Hongxing Xiang,hong xing,hong xing xiang,红星,红星乡', 45.2742800, 130.9603600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26444, 'Xijiao', 'Xijiao', 'Xijiao,Xijiao Xiang,xi jiao,xi jiao xiang,西郊,西郊乡', 45.3196100, 130.9467700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26445, 'Xingyuan', 'Xingyuan', 'Xingyuan,Xingyuan Zhen,xing yuan,xing yuan zhen,兴源,兴源镇', 44.5926700, 130.3270000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26446, 'Hexi', 'Hexi', 'Hexi,Hexi Xiang,he xi,he xi xiang,河西,河西乡', 44.9269400, 130.4827900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26447, 'Fulu', 'Fulu', 'Fulu,Fulu Xiang,fu lu,fu lu xiang,福禄,福禄乡', 44.9356300, 130.5814000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26448, 'Yihantong', 'Yihantong', 'Yihantong,Yihantong Xiang,yi han tong,yi han tong xiang,伊汉通,伊汉通乡', 45.8762800, 128.8960900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26449, 'Baoxing', 'Baoxing', 'Baoxing,Baoxing Xiang,bao xing,bao xing xiang,宝兴,宝兴乡', 45.7527200, 128.7614900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26450, 'Songnan', 'Songnan', 'Songnan,Songnan Xiang,song nan,song nan xiang,松南,松南乡', 45.8767900, 128.8005000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26451, 'Bayanbaogede', 'Bayanbaogede', 'Bayanbaogede,Bayanbaogede Sumu,ba yan bao ge de,ba yan bao ge de su mu,巴彦宝格德,巴彦宝格德苏木', 41.2315500, 100.4776500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26452, 'Jirigalangtu', 'Jirigalangtu', 'Jirigalangtu,Jirigalangtu Sumu,ji ri ga lang tu,ji ri ga lang tu su mu,吉日嘎郎图,吉日嘎郎图苏木', 41.9444100, 101.1288200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26453, 'Wentugaole', 'Wentugaole', 'Wentugaole,Wentugaole Sumu,wen tu gao lei,wen tu gao lei su mu,温图高勒,温图高勒苏木', 41.4264600, 102.1158600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26454, 'Subonao’er', 'Subonao''er', 'Subonao''er,Subonao''er Sumu,Subonao’er,Subonao’er Sumu,su po nao er,su po nao er su mu,苏泊淖尔,苏泊淖尔苏木', 42.1283800, 101.0700100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26455, 'Gurinai', 'Gurinai', 'Gurinai,Gurinai Sumu,gu ri nai,gu ri nai su mu,古日乃,古日乃苏木', 40.6538000, 101.3998700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26456, 'Saihantaolai', 'Saihantaolai', 'Saihantaolai,Saihantaolai Sumu,sai han tao lai,sai han tao lai su mu,赛汉陶来,赛汉陶来苏木', 41.8802600, 100.6131300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26457, 'Mazongshan', 'Mazongshan', 'Mazongshan,Mazongshan Sumu,ma zong shan,ma zong shan su mu,马鬃山,马鬃山苏木', 40.9679800, 98.5367400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26458, 'Juwan', 'Juwan', 'Juwan,Juwan Zhen,ju wan,ju wan zhen,琚湾,琚湾镇', 32.0516500, 112.5913300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26459, 'Wangzha', 'Wangzha', 'Wangzha,Wangzhai Jiedao,wang zhai,wang zhai jie dao,王寨,王寨街道', 32.0546800, 112.1201100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26460, 'Tuanshan', 'Tuanshan', 'Tuanshan,Tuanshan Zhen,tuan shan,tuan shan zhen,团山,团山镇', 32.1029100, 112.1342900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26461, 'Dongxiang', 'Dongxiang', 'Dongxiang,dong xiang,东乡', 32.1214500, 112.4836500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26462, 'Fujia', 'Fujia', 'Fujia,Fujia Xiang,fu jia,fu jia xiang,付家,付家乡', 32.1399500, 113.2526700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26463, 'Qifang', 'Qifang', 'Qifang,Qifang Zhen,qi fang,qi fang zhen,七方,七方镇', 32.2036800, 112.5628400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26464, 'Longwang', 'Longwang', 'Longwang,Longwang Zhen,long wang,long wang zhen,龙王,龙王镇', 32.2118400, 111.9729200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26465, 'Changsheng', 'Changsheng', 'Changsheng,Changsheng Xiang,chang sheng,chang sheng xiang,常胜,常胜乡', 49.4078900, 129.5137600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26466, 'Wuyun', 'Wuyun', 'Wuyun,Wuyun Zhen,wu yun,wu yun zhen,乌云,乌云镇', 49.2781500, 129.6380900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26467, 'Hujia', 'Hujia', 'Hujia,Hujia Xiang,hu jia,hu jia xiang,沪嘉,沪嘉乡', 49.0935600, 129.4530500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26468, 'Xiangyang', 'Xiangyang', 'Xiangyang,Xiangyang Xiang,xiang yang,xiang yang xiang,向阳,向阳乡', 49.1808100, 129.7570600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26469, 'Hongguang', 'Hongguang', 'Hongguang,Hongguang Xiang,hong guang,hong guang xiang,红光,红光乡', 48.8076900, 130.5111100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26470, 'Yanhe', 'Yanhe', 'Yanhe,Yanhe Zhen,yan he,yan he zhen,延河,延河镇', 45.3878100, 128.1370200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26471, 'Qingchuan', 'Qingchuan', 'Qingchuan,Qingchuan Zhen,qing chuan,qing chuan zhen,青川,青川镇', 45.4442600, 128.1049400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26472, 'Yuhe', 'Yuhe', 'Yuhe,Yuhe Xiang,yu he,yu he xiang,玉河,玉河乡', 45.3925500, 128.3695100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26473, 'Shoushan', 'Shoushan', 'Shoushan,Shoushan Xiang,shou shan,shou shan xiang,寿山,寿山乡', 45.4463100, 128.4394400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26474, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Xiang,qing shan,qing shan xiang,青山,青山乡', 48.6419000, 129.8954700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26475, 'Zhenzhushan', 'Zhenzhushan', 'Zhenzhushan,Zhenzhushan Xiang,zhen zhu shan,zhen zhu shan xiang,珍珠山,珍珠山乡', 44.8924700, 128.3309600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26476, 'Qia’erlong', 'Qia''erlong', 'Qia''erlong,Qia''erlong Xiang,Qia’erlong,Qia’erlong Xiang,qia er long,qia er long xiang,恰尔隆,恰尔隆乡', 38.0459500, 75.9573700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26477, 'Ha’erlong', 'Ha''erlong', 'Ha''erlong,Ha''erlong Xiang,Ha’erlong,Ha’erlong Xiang,ke zi lei tao,ke zi lei tao xiang,克孜勒陶,克孜勒陶乡', 38.5564300, 76.0752500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26478, 'Yigezi Ye’er', 'Yigezi Ye''er', 'Yigezi Ye''er,Yigezi Ye''er Xiang,Yigezi Ye’er,Yigezi Ye’er Xiang,yi ge zi ye er,yi ge zi ye er xiang,依格孜也尔,依格孜也尔乡', 38.6427200, 76.1954000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26479, 'Tuopu Luke', 'Tuopu Luke', 'Tuopu Luke,Tuopu Luke Xiang,tuo pu lu ke,tuo pu lu ke xiang,托普鲁克,托普鲁克乡', 38.7682900, 76.3101200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26480, 'Sugaiti', 'Sugaiti', 'Sugaiti,Sugaiti Xiang,su gai ti,su gai ti xiang,苏盖提,苏盖提乡', 38.7840700, 76.2003300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26481, 'Maqia', 'Maqia', 'Maqia,Maqia Xiang,ma qia,ma qia xiang,马恰,马恰乡', 38.8419200, 76.0796900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26482, 'Longfu', 'Longfu', 'Longfu,Longfu Xiang,long fu,long fu xiang,龙甫,龙甫乡', 38.9425100, 76.0556900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26483, 'Mangxing', 'Mangxing', 'Mangxing,Mangxing Xiang,mang xin,mang xin xiang,芒辛,芒辛乡', 38.9260700, 76.1996700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26484, 'Yingye’er', 'Yingye''er', 'Yingye''er,Yingye''er Xiang,Yingye’er,Yingye’er Xiang,ying ye er,ying ye er xiang,英也尔,英也尔乡', 38.9734100, 76.2910600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26485, 'Saxin', 'Saxin', 'Saxin,Saxin Xiang,sa xin,sa xin xiang,萨辛,萨辛乡', 38.9382400, 76.3153800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26486, 'Qiaoleipan', 'Qiaoleipan', 'Qiaoleipan,Qiaoleipan Xiang,qiao lei pan,qiao lei pan xiang,乔勒潘,乔勒潘乡', 38.9359400, 76.1155200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26487, 'Chengguan', 'Chengguan', 'Chengguan,Chengguan Xiang,cheng guan,cheng guan xiang,城关,城关乡', 38.9135800, 76.1638400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26488, 'Kekeya’er Ke’erkezizu', 'Kekeya''er Ke''erkezizu', 'Kekeya''er Ke''erkeizuzi Zuxiang,Kekeya''er Ke''erkezizu,Kekeya’er Ke’erkeizuzi Zuxiang,Kekeya’er Ke’erkezizu,ke ke ya er ke er ke zi zu,ke ke ya er ke er ke zi zu xiang,科克亚尔柯尔克孜族,科克亚尔柯尔克孜族乡', 38.0351100, 75.0734800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26489, 'Qingsong', 'Qingsong', 'Qingsong,Qingsong Xiang,qing song,qing song xiang,青松,青松乡', 44.4142300, 127.3572000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26490, 'Jiujie', 'Jiujie', 'Jiujie,Jiujie Xiang,jiu jie,jiu jie xiang,旧街,旧街乡', 44.3885200, 129.0862300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26491, 'Hainan', 'Hainan', 'Hainan,Hainan Chaoxianzu Xiang,hai nan,hai nan chao xian zu xiang,海南,海南朝鲜族乡', 44.5636900, 129.4907800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26492, 'Fanjia', 'Fanjia', 'Fanjia,Fanjia Xiang,fan jia,fan jia xiang,范家,范家乡', 44.3784000, 129.4696200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26493, 'Wolong', 'Wolong', 'Wolong,Wolong Chaoxianzu Xiang,wo long,wo long chao xian zu xiang,卧龙,卧龙朝鲜族乡', 44.1659300, 129.4052700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26494, 'Ping’an', 'Ping''an', 'Ping''an,Ping''an Xiang,Ping’an,Ping’an Xiang,ping an,ping an xiang,平安,平安乡', 44.2081500, 129.2942200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26495, 'Xinghua', 'Xinghua', 'Xinghua,Xinghua Xiang,xing hua,xing hua xiang,兴华,兴华乡', 44.2213500, 129.1630800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26496, 'Sanling', 'Sanling', 'Sanling,Sanling Xiang,san ling,san ling xiang,三陵,三陵乡', 44.1660900, 129.1090500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26497, 'Xiangyang', 'Xiangyang', 'Aimin Qu,Xiangyang,ai min qu,xiang yang,向阳,爱民区', 44.5879900, 129.5797700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26498, 'Xianfeng', 'Xianfeng', 'Xi''an Qu,Xianfeng,Xi’an Qu,xi an qu,xian feng,先锋,西安区', 44.5750300, 129.6025500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26499, 'Xin’an', 'Xin''an', 'Dong''an Qu,Dong’an Qu,Xin''an,Xin’an,dong an qu,xin an,东安区,新安', 44.5803300, 129.6257200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26500, 'Xinglong', 'Xinglong', 'Xinglong,Xinglong Zhen,xing long,xing long zhen,兴隆,兴隆镇', 44.5403400, 129.6015200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26501, 'Yanjiang', 'Yanjiang', 'Yanjiang,Yanjiang Xiang,yan jiang,yan jiang xiang,沿江,沿江乡', 44.5665400, 129.5777200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26502, 'Yangming', 'Yangming', 'Yangming,Yangming Qu,yang ming,yang ming qu,阳明,阳明区', 44.5962900, 129.6208100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26503, 'Bei’an', 'Bei''an', 'Bei''an,Bei''an Xiang,Bei’an,Bei’an Xiang,bei an,bei an xiang,北安,北安乡', 44.6262400, 129.5778200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26504, 'Ruixi', 'Ruixi', 'Ruixi,Ruixi Zhen,Shuicheba,rui xi,rui xi zhen,shui che ba,水车把,瑞溪,瑞溪镇', 28.5710700, 107.3519300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26505, 'Qilong', 'Qilong', 'Qilong,Qilong Xiang,qi long,qi long xiang,骑龙,骑龙乡', 29.3549900, 107.2209400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26506, 'Zhongqiao', 'Zhongqiao', 'Zhongqiao,Zhongqiao Xiang,zhong qiao,zhong qiao xiang,中桥,中桥乡', 29.3279500, 107.3036900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26507, 'Tiecun', 'Tiecun', 'Tiecun,Tiecun Xiang,tie cun,tie cun xiang,铁村,铁村乡', 29.2378500, 107.1834200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26508, 'Shiqiang', 'Shiqiang', 'Shiqiang,Shiqiang Zhen,shi qiang,shi qiang zhen,石墙,石墙镇', 29.2742600, 107.2039300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26509, 'Fengyan', 'Fengyan', 'Fengyan,Fengyan Xiang,feng yan,feng yan xiang,峰岩,峰岩乡', 29.2973600, 107.1518900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26510, 'Fushou', 'Fushou', 'Fushou,Fushou Xiang,fu shou,fu shou xiang,福寿,福寿乡', 29.2721400, 107.0741500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26511, 'Shixi', 'Shixi', 'Shixi,Shixi Xiang,shi xi,shi xi xiang,石溪,石溪乡', 29.3352200, 107.0392900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26512, 'Hetu', 'Hetu', 'Hetu,Hetu Xiang,he tu,he tu xiang,河图,河图乡', 29.3089800, 107.0288500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26513, 'Muliang', 'Muliang', 'Muliang,Muliang Xiang,mu liang,mu liang xiang,木凉,木凉乡', 29.2162000, 107.0222900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26514, 'Minzhu', 'Minzhu', 'Minzhu,Minzhu Xiang,min zhu,min zhu xiang,民主,民主乡', 29.3630600, 107.1671400, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26515, 'Jinshan', 'Jinshan', 'Jinshan,Jinshan Zhen,jin shan,jin shan zhen,金山,金山镇', 28.9309600, 107.1043700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26516, 'Hexi', 'Hexi', 'Hexi,Hexi Zhen,he xi,he xi zhen,合溪,合溪镇', 28.8311600, 107.3130300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26517, 'Guhua', 'Guhua', 'Guhua,Guhua Xiang,gu hua,gu hua xiang,古花,古花乡', 28.8900300, 107.3356800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26518, 'Toudu', 'Toudu', 'Toudu,Toudu Zhen,tou du,tou du zhen,头渡,头渡镇', 28.9376700, 107.1820300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26519, 'Delong', 'Delong', 'Delong,Delong Xiang,de long,de long xiang,德隆,德隆乡', 28.9116700, 107.2613700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26520, 'Qingyuan', 'Qingyuan', 'Qingyuan,Qingyuan Xiang,qing yuan,qing yuan xiang,庆元,庆元乡', 28.9498300, 107.3570700, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26521, 'Sanquan', 'Sanquan', 'Sanquan,Sanquan Zhen,san quan,san quan zhen,三泉,三泉镇', 29.1323300, 107.2037500, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26522, 'Yuquan', 'Yuquan', 'Yuquan,Yuquan Xiang,yu quan,yu quan xiang,鱼泉,鱼泉乡', 29.1501900, 107.3072300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26523, 'Hekou', 'Hekou', 'Hekou,Hekou Xiang,he kou,he kou xiang,河口,河口乡', 28.9702800, 107.6353900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26524, 'Fenshui', 'Fenshui', 'Fenshui,Fenshui Xiang,fen shui,fen shui xiang,分水,分水乡', 28.8820100, 107.9545900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26525, 'Longquan', 'Longquan', 'Longquan,Longquan Tujiazu Xiang,long quan,long quan tu jia zu xiang,龙泉,龙泉土家族乡', 28.2556900, 108.0380900, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26526, 'Fengxiangxi', 'Fengxiangxi', 'Fengxiangxi,Fengxiangxi Zhen,feng xiang xi,feng xiang xi zhen,枫香溪,枫香溪镇', 28.1276700, 108.3241000, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26527, 'Zhongba', 'Zhongba', 'Zhongba,Zhongba Xiang,zhong ba,zhong ba xiang,中坝,中坝乡', 28.0257300, 108.3346200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26528, 'Dalu', 'Dalu', 'Dalu,Dalu Xiang,da lu,da lu xiang,大路,大路乡', 28.1426900, 108.9542200, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26529, 'Panshi', 'Panshi', 'Panshi,Panshi Zhen,pan shi,pan shi zhen,盘石,盘石镇', 28.2211700, 109.2950100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26530, 'Huoluping', 'Huoluping', 'Huoluping,Huoluping Xiang,huo lu ping,huo lu ping xiang,火炉坪,火炉坪乡', 28.1429900, 109.5109600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26531, 'Datian', 'Datian', 'Datian,Datian Xiang,da tian,da tian xiang,大田,大田乡', 28.1319000, 109.5771300, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26532, 'Taiping', 'Taiping', 'Taiping,Taping Xiang,tai ping,tai ping xiang,太平,太平乡', 28.3188200, 109.8408600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26533, 'Buchou', 'Buchou', 'Buchou,Buchou Xiang,bu chou,bu chou xiang,补抽,补抽乡', 28.2928900, 109.4203600, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26534, 'Qingshuiping', 'Qingshuiping', 'Qingshuiping,Qingshuiping Zhen,qing shui ping,qing shui ping zhen,清水坪,清水坪镇', 28.7729000, 109.2849100, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26535, 'Zhonghualu', 'Zhonghualu', 'Anding Qu,Zhonghualu,an ding qu,zhong hua lu,中华路,安定区', 35.6052500, 104.5966800, 'CN', '2013-05-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26536, 'Liupanshui', 'Liupanshui', 'LPF,Lek-buang-cui,Liou-pchan-suej,Liou-pchan-šuej,Lio̍k-poâⁿ-chúi-chhī,Liupanshui,Ljupan''shuj,Luc Ban Thuy,Lĕ̤k-buàng-cūi,Lục Bàn Thủy,liu pan shui,liu pan shui shi,lyupansu-i si,lywbanshyw,lywpanshay,lywpanshwyy,Люпаньшуй,ليوبانشيو,لیوپانشای,لیوپانشوئی,六盘水市,六盤水,六盤水市,류판수이 시', 26.5944400, 104.8333300, 'CN', '2014-02-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26537, 'Jieshipu', 'Jieshipu', 'Jieshipu,jie shi pu,界石铺', 35.6107300, 105.5378400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26538, 'Nanyang', 'Nanyang', 'Nanyang,Nanyang Zhen,nan yang,nan yang zhen,南阳,南阳镇', 33.1265100, 120.5855800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26539, 'Yiqian', 'Yiqian', 'Yiqian,Yiqian Zhen,yi qian,yi qian zhen,驿前,驿前镇', 26.5567700, 116.3201800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26540, 'Dongshao', 'Dongshao', 'Dongshao,Dongshao Xiang,dong shao,dong shao xiang,东韶,东韶乡', 26.9399000, 116.0039700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26541, 'Qinjiang', 'Qinjiang', 'Qinjiang,Qinjiang Zhen,Shicheng Xian,qin jiang,qin jiang zhen,shi cheng xian,琴江,琴江镇,石城县', 26.3299400, 116.3346700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26542, 'Gaotian', 'Gaotian', 'Gaotian,Gaotian Zhen,gao tian,gao tian zhen,高田,高田镇', 26.4712500, 116.4698200, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26543, 'Shishang', 'Shishang', 'Shishang,Shishang Zhen,shi shang,shi shang zhen,石上,石上镇', 26.6246300, 116.0581100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26544, 'Guhou', 'Guhou', 'Guhou,Guhou Xiang,gu hou,gu hou xiang,固厚,固厚乡', 26.3461800, 116.1099800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26545, 'Huitong', 'Huitong', 'Huitong,Huitong Xiang,hui tong,hui tong xiang,会同,会同乡', 26.5280300, 116.1025900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26546, 'Zhongcun', 'Zhongcun', 'Zhongcun,zhong cun,中村', 26.1747200, 117.6613300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26547, 'Peicheng', 'Peicheng', 'Peicheng,Peicheng Zhen,pei cheng,pei cheng zhen,裴城,裴城镇', 33.7073500, 113.7893900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26548, 'Meichuan Zhen', 'Meichuan Zhen', 'Meichuan Zhen,mei chuan zhen,梅川镇', 34.5407200, 104.0634500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26549, 'Jiyizhuang', 'Jiyizhuang', 'Jiyizhuang,Jiyizhuang Xiang,ji yi zhuang,ji yi zhuang xiang,集义庄,集义庄乡', 39.2369700, 113.4787600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26550, 'Machuanzi', 'Machuanzi', 'Machuanzi,Machuanzi Xiang,ma chuan zi,ma chuan zi xiang,马川子,马川子乡', 42.8619300, 130.3961300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26551, 'Tangkou', 'Tangkou', 'Tangkou,Tangkou Zhen,tang kou,tang kou zhen,汤口,汤口镇', 30.0811000, 118.1846700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26552, 'Yangmiao', 'Yangmiao', 'Yangmiao,Yangmiao Zhen,yang miao,yang miao zhen,杨庙,杨庙镇', 30.8548500, 120.8194000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26553, 'Huichang', 'Huichang', 'Huichang,Huichang Xian,hui chang,hui chang xian,会昌,会昌县', 25.6007400, 115.7779600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26554, 'Zhukou', 'Zhukou', 'Zhukou,Zhukou Xiang,zhu kou,zhu kou xiang,渚口,渚口乡', 29.8541700, 117.4835700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26555, 'Nanying', 'Nanying', 'Nanying,Nanying Jiedao,nan ying,nan ying jie dao,南营,南营街道', 31.7343600, 112.2914800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26556, 'Zuolong', 'Zuolong', 'Zuolong,Zuolong Xiang,zuo long,zuo long xiang,佐龙,佐龙乡', 27.3138800, 115.4090300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26557, 'Huangqiao', 'Huangqiao', 'Huangqiao,Huangqiao Zhen,huang qiao,huang qiao zhen,黄桥,黄桥镇', 27.3166800, 115.0435500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26558, 'Dianxia', 'Dianxia', 'Dianxia,Dianxia Zhen,dian xia,dian xia zhen,店下,店下镇', 27.9355700, 115.6002600, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26559, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃源,桃源镇', 30.8184700, 120.4948000, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26560, 'Yaowan', 'Yaowan', 'Yaowan,Yaowan Xiang,yao wan,yao wan xiang,窑湾,窑湾乡', 30.7142000, 111.3004400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26561, 'Lianghe', 'Lianghe', 'Lianghe,Lianghe Zhen,liang he,liang he zhen,两河,两河镇', 30.7043800, 111.9214500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26562, 'Guoxu', 'Guoxu', 'Guoxu,Guoxu Xiang,guo wei,guo wei xiang,郭圩,郭圩乡', 27.7041400, 116.1114400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26563, 'Wenquan', 'Wenquan', 'Wenquan,Wenquan Zhen,wen quan,wen quan zhen,温泉,温泉镇', 27.9640600, 116.2537300, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26564, 'Xuri', 'Xuri', 'Shangrao Xian,Xuri,shang rao xian,xu ri,上饶县,旭日', 28.4351100, 117.9197900, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26565, 'Huanggang', 'Huanggang', 'Chuang-kang,Hoang Cuong,Hoàng Cương,Huanggang,Huanggang Shi,Hwang Chau,Hwang Chow,Khuangan,Khuangang,Ng-kng-chhi,N̂g-kng-chhī,Uong-gong,Uòng-gŏng,Wangchau,huang gang,huang gang shi,hwang-gang si,hwangang,Хуанган,Хуанганг,هوانگانگ,ہوانگگانگ,ဟန်ကောင်မြို့,黃岡,黄冈,黄冈市,黄岡,黄岡市,황강 시', 30.4514300, 114.8703500, 'CN', '2017-07-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26566, 'Ngarrab', 'Ngarrab', 'Anrao,Anrao Zhen,Ngarrab,an rao,an rao zhen,安绕,安绕镇', 29.1447500, 92.5901000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26567, 'Qijiawan', 'Qijiawan', 'Qijiawan,qi jia wan,祁家湾', 30.8770800, 114.2275400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26568, 'Qianyingzi', 'Qianyingzi', 'Qianyingzi,Qianyingzi Zhen,qian ying zi,qian ying zi zhen,前营子,前营子镇', 40.2032300, 123.1826400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26569, 'Xiadahe', 'Xiadahe', 'Xiadahe,Xiadehe Xiang,xia da he,xia da he xiang,下达河,下达河乡', 40.9980400, 123.2753100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26570, 'Caina', 'Caina', 'Caina,Caina Xiang,cai na,cai na xiang,菜哪乡,菜纳', 29.4400100, 90.9544100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26571, 'Dagar', 'Dagar', 'Daga,Daga Xiang,Dagar,da ga,da ga xiang,达嘎,达嘎乡', 29.3373200, 90.6812200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26572, 'Karlung', 'Karlung', 'Dongga Qu,Kalong,Kalong Xiang,Karlung,dong ga qu,ka long,ka long xiang,东嘎区,卡龙,卡龙乡', 29.0358800, 90.4863100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26573, 'Layu', 'Layu', 'Layu,Layu Xiang,Lhayu,Lhayü,la yu,la yu xiang,拉玉,拉玉乡', 29.1471000, 91.6586000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26574, 'Nam', 'Nam', 'Nam,Nanmu,Nanmu Xiang,nan mu,nan mu xiang,南木,南木乡', 29.4681100, 90.9296500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26575, 'Pumaqangtang', 'Pumaqangtang', 'Pumajiangtang,Pumajiangtang Xiang,Pumaqangtang,Shangzang,pu ma jiang tang,pu ma jiang tang xiang,shang cang,上藏,普玛江塘乡,普马江塘', 28.6059200, 90.2016500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26576, 'Pusum', 'Pusum', 'Pusong,Pusong Xiang,Pusum,pu song,pu song xiang,普松,普松乡', 29.4992000, 90.1500100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26577, 'Quchomo', 'Quchomo', 'Quchomo,Quzhuomu,Quzhuomu Xiang,qu zhuo mu,qu zhuo mu xiang,曲卓木,曲卓木乡', 28.2565900, 91.7650100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26578, 'Sozhug', 'Sozhug', 'Dingna Qu,Sozhug,Suozhu,Suozhu Xiang,ding na qu,suo zhu,suo zhu xiang,丁那区,索珠,索珠乡', 29.4234400, 91.8729400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26579, 'Xumai', 'Xumai', 'Xumai,Xumai Xiang,xu mai,xu mai xiang,续迈,续迈乡', 29.4692100, 90.2642300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26580, 'Huanghuatang', 'Huanghuatang', 'Huanghuatang,Huanghuatang Zhen,huang hua tang,huang hua tang zhen,黄花塘,黄花塘镇', 32.9125100, 118.7797500, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26581, 'Chenqiao', 'Chenqiao', 'Chenqiao,Chenqiao Xiang,chen qiao,chen qiao xiang,陈桥,陈桥乡', 32.1032100, 120.8018400, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26582, 'Ganduo', 'Ganduo', 'Ganduo,Ganduo Zhen,gan duo,gan duo zhen,甘垛,甘垛镇', 32.8755900, 119.7613800, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26583, 'Tangzhuang', 'Tangzhuang', 'Tangzhuang,Tangzhuang Zhen,tang zhuang,tang zhuang zhen,汤庄,汤庄镇', 32.7691600, 119.7380700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26584, 'Gaoyou', 'Gaoyou', 'Gaoyou,Gaoyou Zhen,gao you,gao you zhen,高邮,高邮镇', 32.7761400, 119.4731100, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26585, 'Zhouzhuang', 'Zhouzhuang', 'Zhouzhuang,Zhouzhuang Zhen,zhou zhuang,zhou zhuang zhen,周庄,周庄镇', 32.7120600, 119.8817700, 'CN', '2013-06-05', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26586, 'Renheji', 'Renheji', 'Renheji,Renheji Zhen,ren he ji,ren he ji zhen,仁和集,仁和集镇', 32.6261500, 119.1150500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26587, 'Mashan', 'Mashan', 'Mashan,Mashan Zhen,ma shan,ma shan zhen,马山,马山镇', 31.4721900, 120.1239700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26588, 'Yanqiao', 'Yanqiao', 'Huishan Qu,Yanqiao,Yanqiao Jiedao,hui shan qu,yan qiao,yan qiao jie dao,堰桥,堰桥街道,惠山区', 31.6891800, 120.2780000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26589, 'Xibei', 'Xibei', 'Xibei,Xibei Zhen,xi bei,xi bei zhen,锡北,锡北镇', 31.6575900, 120.4322000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26590, 'Ehu', 'Ehu', 'Ehu,Ehu Zhen,e hu,e hu zhen,鹅湖,鹅湖镇', 31.5254600, 120.5428600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26591, 'Hongshan', 'Hongshan', 'Hongshan,Hongshan Zhen,hong shan,hong shan zhen,鸿山,鸿山镇', 31.4854100, 120.4919900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26592, 'Taihu', 'Taihu', 'Taihu,Taihu Jiedao,tai hu,tai hu jie dao,太湖,太湖街道', 31.4726200, 120.2829300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26593, 'Yuecheng', 'Yuecheng', 'Yuecheng,yue cheng,月城', 31.8123100, 120.2383700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26594, 'Fenghuang', 'Fenghuang', 'Fenghuang,Fenghuang Zhen,feng huang,feng huang zhen,凤凰,凤凰镇', 31.7914000, 120.6239500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26595, 'Haiyu', 'Haiyu', 'Haiyu,Haiyu Zhen,hai yu,hai yu zhen,海虞,海虞镇', 31.7522400, 120.8011700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26596, 'Shajiabang', 'Shajiabang', 'Shajiabang,Shajiabang Zhen,sha jia bang,sha jia bang zhen,沙家浜,沙家浜镇', 31.5486100, 120.8477800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26597, 'Xishan', 'Xishan', 'Xishan,Xishan Zhen,xi shan,xi shan zhen,西山,西山镇', 31.1345400, 120.3054200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26598, 'Shengpu', 'Shengpu', 'Shengpu,Shengpu Zhen,sheng pu,sheng pu zhen,胜浦,胜浦镇', 31.3054700, 120.8167100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26599, 'Weiting', 'Weiting', 'Weiting,Weiting Zhen,wei ting,wei ting zhen,唯亭,唯亭镇', 31.3465200, 120.6939900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26600, 'Malu', 'Malu', 'Malu,ma lu,马路', 31.3765000, 121.2939000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26601, 'Yuanqiao', 'Yuanqiao', 'Yuanqiao,Yuanqiao Zhen,yuan qiao,yuan qiao zhen,袁桥,袁桥镇', 32.3673200, 120.4739100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26602, 'Zuokou', 'Zuokou', 'Zuokou,Zuokou Xiang,zuo kou,zuo kou xiang,左口,左口乡', 29.7312600, 119.0454500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26603, 'Xinan', 'Xinan', 'Xinan,Xinan Jiedao,xi nan,xi nan jie dao,西南,西南街道', 23.1669700, 112.8285200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26604, 'Nansha', 'Nansha', 'Nansha,Nansha Jiedao,nan sha,nan sha jie dao,南沙,南沙街道', 22.8042300, 113.5682000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26605, 'Huancheng', 'Huancheng', 'Huancheng,Huancheng Jiedao,huan cheng,huan cheng jie dao,环城,环城街道', 22.4722900, 113.3725500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26606, 'Yingcheng', 'Yingcheng', 'Yingcheng,Yingcheng Jiedao,ying cheng,ying cheng jie dao,英城,英城街道', 24.2181400, 113.3503000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26607, 'Hexi', 'Hexi', 'Hexi,Hexi Jiedao,he xi,he xi jie dao,河西,河西街道', 21.6514200, 110.6208900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26608, 'Wancheng', 'Wancheng', 'Wancheng,Wancheng Jiedao,guan cheng,guan cheng jie dao,莞城,莞城街道', 23.0490400, 113.7522100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26609, 'Baxiangshan', 'Baxiangshan', 'Baxiangshan,Baxiangshan Zhen,ba xiang shan,ba xiang shan zhen,八乡山,八乡山镇', 23.7687500, 115.9720300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26610, 'Meixian', 'Meixian', 'Chengxiang,Meixian,cheng xiang,mei xian,梅县,程乡', 24.2838200, 116.0695300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26611, 'Chunjiang', 'Chunjiang', 'Chunjiang,Chunjiang Zhen,chun jiang,chun jiang zhen,春江,春江镇', 31.9471000, 119.9863500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26612, 'Beijinglu', 'Beijinglu', 'Beijinglu,Beijinglu Jiedao,Jinghu Qu,bei jing lu,bei jing lu jie dao,jing hu qu,北京路,北京路街道,镜湖区', 31.3226800, 118.3850500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26613, 'Mafang', 'Mafang', 'Mafang,Mafang Zhen,Yingcheng,ma fang,ma fang zhen,ying cheng,营城,马坊,马坊镇', 40.0799500, 117.0099200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26614, 'Wangxingzhuang', 'Wangxingzhuang', 'Wangxingzhuang,Wangxingzhuang Zhen,wang xing zhuang,wang xing zhuang zhen,王兴庄,王兴庄镇', 40.1589000, 117.1026400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26615, 'Chengqu', 'Chengqu', 'Chengqu,Chengqu Jiedao,Rushan,Rushan Shi,cheng qu,cheng qu jie dao,ru shan,ru shan shi,乳山,乳山市,城区,城区街道', 36.9106000, 121.5250400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26616, 'Louqiao', 'Louqiao', 'Louqiao,Louqiao Jiedao,Ouhai Qu,lou qiao,lou qiao jie dao,ou hai qu,娄桥,娄桥街道,瓯海区', 28.0106100, 120.6321800, 'CN', '2014-02-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26617, 'Haokou', 'Haokou', 'Haokou,Haokou Xiang,Liaoya,hao kou,hao kou xiang,liao ya,浩口,浩口乡,蓼垭', 29.0928700, 107.8310000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26618, 'Nuanquan', 'Nuanquan', 'Nuanquan,nuan quan,暖泉', 39.6978500, 111.7331800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26619, 'Yaogou', 'Yaogou', 'Yaogou,yao gou,窑沟', 39.8147300, 111.4326200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26620, 'Xiamei', 'Xiamei', 'Xiamei,Xiamei Zhen,xia mei,xia mei zhen,霞美,霞美镇', 24.9393300, 118.4787500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26621, 'Youyun', 'Youyun', 'Youyun,Youyun Xiang,Zhongxinzhan,you yun,you yun xiang,zhong xin zhan,中心站,优云,优云乡', 34.2714000, 99.1908800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26622, 'Saihan Tala', 'Saihan Tala', 'Saihan Tala,Saihan Tala Sumu,sai han ta la,sai han ta la su mu,赛汉塔拉,赛汉塔拉苏木', 48.3540800, 116.1648500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26623, 'Boketu', 'Boketu', 'Boketu,Boketu Zhen,bo ke tu,bo ke tu zhen,博克图,博克图镇', 48.7572300, 121.9099100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26624, 'Manggetu Dawo’er Zu', 'Manggetu Dawo''er Zu', 'Manggetu Dawo''er Zu,Manggetu Dawo''er Zu Xiang,Manggetu Dawo’er Zu,Manggetu Dawo’er Zu Xiang,mang ge tu da wo er zu,mang ge tu da wo er zu xiang,莽格吐达斡尔族,莽格吐达斡尔族乡', 47.7827800, 124.1359500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26625, 'Jinta', 'Jinta', 'Jinta,Jinta Xiang,jin ta,jin ta xiang,金塔,金塔乡', 39.9920700, 98.9022300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26626, 'Shazhou', 'Shazhou', 'Dunhuang Shi,Shazhou,Shazhou Zhen,dui huang shi,sha zhou,sha zhou zhen,敦煌市,沙州,沙州镇', 40.1379900, 94.6622700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26627, 'Geshan', 'Geshan', 'Geshan,Geshan Xiang,ge shan,ge shan xiang,阁山,阁山乡', 47.2978700, 127.3011000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26628, 'Xinjie', 'Xinjie', 'Xinjie,Xinjie Zhen,xin jie,xin jie zhen,新街,新街镇', 30.0137800, 113.9911800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26629, 'Wangchang', 'Wangchang', 'Wangchang,Wangchang Zhen,wang chang,wang chang zhen,汪场,汪场镇', 30.6160600, 113.0335600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26630, 'Xingou', 'Xingou', 'Xingou,Xingou Jiedao,xin gou,xin gou jie dao,新沟,新沟街道', 30.6382000, 113.9818200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26631, 'Jingling', 'Jingling', 'Jingling,Jingling Jiedao,jing ling,jing ling jie dao,竞陵,竞陵街道', 30.6474700, 113.1598200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26632, 'Baoquan', 'Baoquan', 'Baoquan,Baoquan Zhen,bao quan,bao quan zhen,宝泉,宝泉镇', 48.1588100, 126.2084600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26633, 'Taipinggou', 'Taipinggou', 'Taipinggou,Taipinggou Xiang,tai ping gou,tai ping gou xiang,太平沟,太平沟乡', 48.1272700, 130.6447700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26634, 'Changliang', 'Changliang', 'Changliang,Changliang Xiang,zhang liang,zhang liang xiang,长梁,长梁乡', 30.7023400, 109.7769700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26635, 'Lücongpo', 'Lucongpo', 'Lucongpo,Lucongpo Zhen,Lücongpo,Lücongpo Zhen,lu cong po,lu cong po zhen,绿葱坡,绿葱坡镇', 30.8189600, 110.2524600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26636, 'Chaoyang', 'Chaoyang', 'Chaoyang,Jiayin Xian,chao yang,jia yin xian,嘉荫县,朝阳', 48.8863800, 130.4032300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26637, 'Wulaga', 'Wulaga', 'Wulaga,Wulaga Zhen,wu la ga,wu la ga zhen,乌拉嘎,乌拉嘎镇', 48.3995000, 130.1358500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26638, 'Chengjiao', 'Chengjiao', 'Chengjiao,Chengjiao Xiang,cheng jiao,cheng jiao xiang,城郊,城郊乡', 48.2227500, 126.5070400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26639, 'Erjing', 'Erjing', 'Erjing,Erjing Zhen,er jing,er jing zhen,二井,二井镇', 48.3309800, 126.4143200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26640, 'Xiashihao', 'Xiashihao', 'Xiashihao,Xiashihao Zhen,xia shi hao,xia shi hao zhen,下湿壕,下湿壕镇', 40.8981200, 110.6028500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26641, 'Donggong Cilao', 'Donggong Cilao', 'Donggong Cilao,Xiyingzi,dong gong ci lao,xi ying zi,东公此老,西营子', 41.1997200, 110.4322100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26642, 'Xinjiang', 'Xinjiang', 'Xinjiang,xin jian,新建', 40.9190400, 110.3831100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26643, 'Dongcheng', 'Dongcheng', 'Dongcheng,Nanchuan Qu,dong cheng,nan chuan qu,东城,南川区', 29.1520100, 107.1033500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26644, 'Jihuluntu Sumu', 'Jihuluntu Sumu', 'Jihuluntu Sumu,Shalinqin,ji hu lun tu su mu,sha lin qin,吉忽伦图苏木,沙林沁', 40.7850200, 110.3092000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26645, 'Dongshengyong', 'Dongshengyong', 'Dongsanfenzi,Dongshengyong,dong san fen zi,dong sheng yong,东三分子,东胜永', 41.0423200, 110.1074400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26646, 'Butahai', 'Butahai', 'Butahai,Nanbu Tahai,bo ta hai,nan bo ta hai,南卜塔亥,卜塔亥', 41.2935500, 110.3126600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26647, 'Hongnijing', 'Hongnijing', 'Hongnijing,hong ni jing,红泥井', 41.3881700, 109.8078200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26648, 'Changfu', 'Changfu', 'Changfu,Changfu Zhen,zhang fu,zhang fu zhen,长福,长福镇', 49.1516100, 125.2950600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26649, 'Linjiang', 'Linjiang', 'Linjiang,Linjiang Xiang,lin jiang,lin jiang xiang,临江,临江乡', 49.0943900, 124.9669900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26650, 'Qianjin', 'Qianjin', 'Qianjin,Qianjin Zhen,qian jin,qian jin zhen,前进,前进镇', 49.0995500, 125.2090000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26651, 'Baiyun', 'Baiyun', 'Baiyun,Baiyun Xiang,bai yun,bai yun xiang,白云,白云乡', 49.1576000, 126.2341800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26652, 'Duobaoshan', 'Duobaoshan', 'Duobaoshan,Duobaoshan Zhen,duo bao shan,duo bao shan zhen,多宝山,多宝山镇', 50.1334600, 125.7762300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26653, 'Baoshan', 'Baoshan', 'Baoshan,Baoshan Xiang,bao shan,bao shan xiang,宝山,宝山乡', 49.0896800, 128.9311800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26654, 'Kelin', 'Kelin', 'Kelin,Kelin Xiang,ke lin,ke lin xiang,克林,克林乡', 48.7160300, 128.9422100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26655, 'Bianjiang', 'Bianjiang', 'Bianjiang,Bianjiang Zhen,bian jiang,bian jiang zhen,边疆,边疆镇', 49.5578000, 128.4730700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26656, 'Xiangba', 'Xiangba', 'Xiangba,Xiangba Xiang,xiang ba,xiang ba xiang,向坝,向坝乡', 31.7071100, 109.9226600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26657, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Xiang,tao yuan,tao yuan xiang,桃源,桃源乡', 31.7366100, 109.8188600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26658, 'Tianbao', 'Tianbao', 'Tianbao,Tianbao Xiang,tian bao,tian bao xiang,天宝,天宝乡', 32.0146400, 109.8433500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26659, 'Eping', 'Eping', 'Eping,Eping Xiang,e ping,e ping xiang,鄂坪,鄂坪乡', 32.1976000, 109.6720100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26660, 'Xianhe', 'Xianhe', 'Xianhe,Xianhe Zhen,xian he,xian he zhen,县河,县河镇', 32.2374400, 109.9030800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26661, 'Longba', 'Longba', 'Longba,Longba Xiang,long ba,long ba xiang,龙坝,龙坝乡', 32.3538100, 109.6550800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26662, 'Leigu', 'Leigu', 'Leigu,Leigu Zhen,lei gu,lei gu zhen,擂鼓,擂鼓镇', 32.3687400, 109.9243500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26663, 'Desheng', 'Desheng', 'Desheng,Desheng Zhen,de sheng,de sheng zhen,得胜,得胜镇', 32.4513800, 109.8459100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26664, 'Zhuping', 'Zhuping', 'Zhuping,Zhuping Xiang,zhu ping,zhu ping xiang,竹坪,竹坪乡', 32.4641500, 109.7136700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26665, 'Maota', 'Maota', 'Maota,Maota Xiang,mao ta,mao ta xiang,茅塔,茅塔乡', 32.5197800, 110.8204600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26666, 'Damiao', 'Damiao', 'Damiao,Damiao Xiang,da miao,da miao xiang,大庙,大庙乡', 32.5339100, 109.7318500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26667, 'Danzhaolu', 'Danzhaolu', 'Danzhaolu,Danzhaolu Jiedao,dan zhao lu,dan zhao lu jie dao,丹赵路,丹赵路街道', 32.5533200, 111.5276900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26668, 'Bailang', 'Bailang', 'Bailang,Bailang Jiedao,bai lang,bai lang jie dao,白浪,白浪街道', 32.5692600, 110.8856400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26669, 'Wudanglu', 'Wudanglu', 'Wudanglu,Wudanglu Jiedao,wu dang lu,wu dang lu jie dao,武当路,武当路街道', 32.5915100, 110.7977600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26670, 'Xigou', 'Xigou', 'Xigou,Xigou Xiang,xi gou,xi gou xiang,西沟,西沟乡', 32.6125800, 110.6184000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26671, 'Eryan', 'Eryan', 'Eryan,Eryan Jiedao,er yan,er yan jie dao,二堰,二堰街道', 32.6217700, 110.7755300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26672, 'Chechenglu', 'Chechenglu', 'Chechenglu,Chechenglu Jiedao,che cheng lu,che cheng lu jie dao,车城路,车城路街道', 32.6374500, 110.7574400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26673, 'Bailin', 'Bailin', 'Bailin,Bailin Zhen,bai lin,bai lin zhen,柏林,柏林镇', 32.6608300, 110.6102500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26674, 'Hanjianglu', 'Hanjianglu', 'Hanjianglu,Hanjianglu Jiedao,han jiang lu,han jiang lu jie dao,汉江路,汉江路街道', 32.6804600, 110.7920700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26675, 'Huanglong', 'Huanglong', 'Huanglong,Huanglong Zhen,huang long,huang long zhen,黄龙,黄龙镇', 32.6828100, 110.5649200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26676, 'Yuhuangding', 'Yuhuangding', 'Yuhuangding,Yuhuangding Xiang,yu huang ding,yu huang ding xiang,玉皇顶,玉皇顶乡', 32.7135700, 111.4466000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26677, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Zhen,qing shan,qing shan zhen,青山,青山镇', 32.7311100, 110.9136600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26678, 'Haoping', 'Haoping', 'Haoping,Haoping Zhen,hao ping,hao ping zhen,蒿坪,蒿坪镇', 32.7451800, 111.2592700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26679, 'Liubei', 'Liubei', 'Liubei,Liubei Zhen,liu bei,liu bei zhen,柳陂,柳陂镇', 32.8069200, 110.7559700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26680, 'Yangxipu', 'Yangxipu', 'Yangxipu,Yangxipu Zhen,yang xi pu,yang xi pu zhen,杨溪铺,杨溪铺镇', 32.8354300, 110.8766400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26681, 'Jingyang', 'Jingyang', 'Jingyang,Jingyang Xiang,jing yang,jing yang xiang,景阳,景阳乡', 32.9453700, 109.7972200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26682, 'Baisangguan', 'Baisangguan', 'Baisangguan,Baisangguan Zhen,bai sang guan,bai sang guan zhen,白桑关,白桑关镇', 32.9626100, 110.9910000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26683, 'Tanshan', 'Tanshan', 'Tanshan,Tanshan Zhen,tan shan,tan shan zhen,谭山,谭山镇', 33.0283300, 111.1222100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26684, 'Guanfang', 'Guanfang', 'Guanfang,Guanfang Xiang,guan fang,guan fang xiang,关防,关防乡', 33.1080700, 109.7618600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26685, 'Hubeikou', 'Hubeikou', 'Hubeikou,Hubeikou Huizuxiang,hu bei kou,hu bei kou hui zu xiang,湖北口,湖北口回族乡', 33.2011000, 109.5684700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26686, 'Bailang', 'Bailang', 'Bailang,Bailang Zhen,bai lang,bai lang zhen,白浪,白浪镇', 33.2353100, 110.9891100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26687, 'Qunshan', 'Qunshan', 'Qunshan,Qunshan Xiang,qun shan,qun shan xiang,群山,群山乡', 49.2166100, 127.5748000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26688, 'Zhengyangshan', 'Zhengyangshan', 'Zhengyangshan,Zhengyangshan Xiang,zheng yang shan,zheng yang shan xiang,正阳山,正阳山乡', 49.2417000, 126.9876800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26689, 'Hongqi', 'Hongqi', 'Hongqi,Hongqi Xiang,hong qi,hong qi xiang,红旗,红旗乡', 49.0665000, 127.1580800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26690, 'Chenqing', 'Chenqing', 'Chenqing,Chenqing Zhen,chen qing,chen qing zhen,晨清,晨清镇', 49.1411700, 127.2357900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26691, 'Xixing', 'Xixing', 'Xixing,Xixing Xiang,xi xing,xi xing xiang,西兴,西兴乡', 49.4104400, 127.2708900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26692, 'Baiyanghe', 'Baiyanghe', 'Baiyanghe,Baiyanghe Hasakezu,Baiyanghe Hasakezu Xiang,bai yang he,bai yang he ha sa ke zu,bai yang he ha sa ke zu xiang,柏杨河,柏杨河哈萨克族,柏杨河哈萨克族乡', 44.0188600, 87.7646400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26693, 'Bingchao', 'Bingchao', 'Bingchao,Bingchao Xiang,bin chao,bin chao xiang,滨潮,滨潮乡', 44.0902700, 87.3751900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26694, 'Hankazi', 'Hankazi', 'Hankazi,Hankazi Tanhasakeminzu,Hankazi Tanhasakeminzu Xiang,han ka zi,han ka zi tan ha sa ke min zu,han ka zi tan ha sa ke min zu xiang,旱卡子,旱卡子滩哈萨克民族,旱卡子滩哈萨克民族乡', 44.1035600, 86.1240200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26695, 'Guangdongdi', 'Guangdongdi', 'Guangdongdi,Guangdongdi Xiang,guang dong de,guang dong de xiang,广东地,广东地乡', 44.3498600, 86.2427800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26696, 'Beiquan', 'Beiquan', 'Beiquan,Beiquan Zhen,bei quan,bei quan zhen,北泉,北泉镇', 44.3366900, 86.0121200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26697, 'Sanping', 'Sanping', 'Sanping,Sanping Jiedao Banshichu,san ping,san ping jie dao ban shi chu,三平,三平街道办事处', 45.6189800, 85.0570300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26698, 'Jinlong', 'Jinlong', 'Jinlong,Jinlong Zhen,jin long,jin long zhen,金龙,金龙镇', 45.5771000, 84.9922200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26699, 'Kaiganqi', 'Kaiganqi', 'Kaiganqi,Kaiganqi Xiang,kai gan qi,kai gan qi xiang,开干齐,开干齐乡', 44.4218700, 85.1936300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26700, 'Dongtundu', 'Dongtundu', 'Dongtundu,Furong Qu,dong tun du,fu rong qu,东屯渡,芙蓉区', 28.1837100, 113.0320900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26701, 'Furong Beilu', 'Furong Beilu', 'Furong Beilu,Kaifu Qu,fu rong bei lu,kai fu qu,开福区,芙蓉北路', 28.2370700, 112.9807600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26702, 'Guitang', 'Guitang', 'Guitang,Yuhua Qu,gui tang,yu hua qu,圭塘,雨化区', 28.1399600, 113.0424600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26703, 'Qingyuan', 'Qingyuan', 'Qingyuan,Tianxin Qu,qing yuan,tian xin qu,天心区,青园', 28.1172000, 112.9984600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26704, 'Huochezhan', 'Huochezhan', 'Huochezhan,Huochezhan Jiedao Banshichu,huo che zhan,huo che zhan jie dao ban shi chu,火车站,火车站街道办事处', 44.4043600, 84.8964500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26705, 'Bashisihu', 'Bashisihu', 'Bashisihu,Bashisihu Xiang,ba shi si hu,ba shi si hu xiang,八十四户,八十四户乡', 44.4445400, 84.7132600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26706, 'Baiquan', 'Baiquan', 'Baiquan,Baiquan Zhen,bai quan,bai quan zhen,百泉,百泉镇', 44.4174000, 84.3452200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26707, 'Baiyanggou', 'Baiyanggou', 'Baiyanggou,Baiyanggou Zhen,bai yang gou,bai yang gou zhen,白杨沟,白杨沟镇', 44.1376900, 84.2935900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26708, 'Toutai', 'Toutai', 'Toutai,Toutai Xiang,tou tai,tou tai xiang,头台,头台乡', 44.7262600, 84.6337700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26709, 'Dongpaizi', 'Dongpaizi', 'Dongpaizi,Dongpaizi Zhen,dong pai zi,dong pai zi zhen,东排子,东排子镇', 44.9122700, 84.4738400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26710, 'Shiqiao', 'Shiqiao', 'Shiqiao,Shiqiao Zhen,shi qiao,shi qiao zhen,石桥,石桥镇', 45.0031800, 84.2916800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26711, 'Wangyue', 'Wangyue', 'Wangyue,Wangyue Xiang,Yuelu Qu,wang yue,wang yue xiang,yue lu qu,岳麓区,望岳,望岳乡', 28.2359000, 112.9170000, 'CN', '2014-02-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26712, 'Damatou', 'Damatou', 'Damatou,Ziyang Qu,da ma tou,zi yang qu,大码头,资阳区', 28.6175100, 112.3369500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26713, 'Queren', 'Queren', 'Queren,Queren Xiang,que ren,que ren xiang,雀仁,雀仁乡', 44.1332900, 90.1353200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26714, 'Jimusa’er', 'Jimusa''er', 'Jimusa''er,Jimusa''er Zhen,Jimusa’er,Jimusa’er Zhen,ji mu sa er,ji mu sa er zhen,吉木萨尔,吉木萨尔镇', 43.9929100, 89.1699500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26715, 'Abudula', 'Abudula', 'Abudula,Abudula Xiang,a bu dou la,a bu dou la xiang,阿不都拉,阿不都拉乡', 46.8463500, 83.2755200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26716, 'Marelesu', 'Marelesu', 'Marelesu,Marelesu Xiang,ma re lei su,ma re lei su xiang,玛热勒苏,玛热勒苏乡', 46.4668200, 83.7033100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26717, 'Jiaoqu', 'Jiaoqu', 'Jiaoqu,Jiaoqu Xiang,jiao qu,jiao qu xiang,郊区,郊区乡', 46.5347300, 83.6290000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26718, 'Kalayemule', 'Kalayemule', 'Kalayemule,Kalayemule Xiang,ka la ye mu lei,ka la ye mu lei xiang,喀拉也木勒,喀拉也木勒乡', 46.7548700, 84.3596000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26719, 'Lamazhao', 'Lamazhao', 'Lamazhao,Lamazhao Xiang,la ma zhao,la ma zhao xiang,喇嘛昭,喇嘛昭乡', 46.2559100, 84.3437900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26720, 'Shanghudi', 'Shanghudi', 'Shanghudi,Shanghudi Xiang,shang hu de,shang hu de xiang,商户地,商户地乡', 44.5322400, 85.8728900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26721, 'Bayinaobao', 'Bayinaobao', 'Bayinaobao,Bayinaobao Xiang,ba yin ao bao,ba yin ao bao xiang,巴音敖包,巴音敖包乡', 46.8446700, 86.1357100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26722, 'Tiebukenwusan', 'Tiebukenwusan', 'Tiebukenwusan,Tiebukenwusan Xiang,tie bu ken wu san,tie bu ken wu san xiang,铁布肯乌散,铁布肯乌散乡', 46.8038100, 85.4517200, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26723, 'A’erda', 'A''erda', 'A''erda,A''erda Xiang,A’erda,A’erda Xiang,a er da,a er da xiang,阿尔达,阿尔达乡', 47.1332600, 87.5080000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26724, 'Qiganjidie', 'Qiganjidie', 'Qiganjidie,Qiganjidie Xiang,qi gan ji die,qi gan ji die xiang,齐干吉迭,齐干吉迭乡', 46.8643600, 87.7160800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26725, 'Arele', 'Arele', 'Arele,Arele Xiang,a re lei,a re lei xiang,阿热勒,阿热勒乡', 46.7479600, 90.3116100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26726, 'Takeshiken', 'Takeshiken', 'Takeshiken,Takeshiken Zhen,ta ke shen ken,ta ke shen ken zhen,塔克什肯,塔克什肯镇', 46.1886900, 90.8058100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26727, 'Kalabulegen', 'Kalabulegen', 'Kalabulegen,Kalabulegen Xiang,ka la bu lei gen,ka la bu lei gen xiang,喀拉布勒根,喀拉布勒根乡', 46.4138300, 88.6848800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26728, 'Akebielidou', 'Akebielidou', 'Akebielidou,Akebielidou Xiang,a ke bie li dou,a ke bie li dou xiang,阿克别里斗,阿克别里斗乡', 46.2165900, 83.4332900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26729, 'Wuxuete', 'Wuxuete', 'Wuxuete,Wuxuete Xiang,wu xue te,wu xue te xiang,乌雪特,乌雪特乡', 46.0908200, 83.9613300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26730, 'Handegate', 'Handegate', 'Handegate,Handegate Mengguzu Xiang,Handegate Xiang,han de ga te,han de ga te meng gu zu xiang,han de ga te xiang,khandyghaty mwnggۇl yېzysy,خاندىغاتى موڭگۇل يېزىسى,ᠬᠠᠨᠳᠠᠭᠠᠲᠤ ᠮᠣᠩᠭ᠋ᠣᠯ ᠤᠨᠳᠤᠰᠤᠲᠡᠨ ᠤ ᠰᠤᠮᠤᠨ,ᠬᠠᠨᠳᠠᠭᠠᠲᠤ ᠮᠣᠩᠭᠣᠯ ᠤᠨᠳᠤᠰᠤᠲᠡᠨ ᠤ ᠰᠤᠮᠤᠨ,汗德尕特,汗德尕特乡,汗德尕特蒙古族乡', 47.7694100, 88.3800800, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26731, 'Lasite', 'Lasite', 'Lasite,Lasite Xiang,la si te,la si te xiang,lasty avyly,lasty yېzysy,لاستى اۋىلى,لاستى يېزىسى,拉斯特,拉斯特乡', 47.8902700, 88.1095600, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26732, 'Kalaxilike', 'Kalaxilike', 'Kalaxilike,Kalaxilike Xiang,ka la xi li ke,ka la xi li ke xiang,qarashylyk avyly,qarashylyk yېzysy,قاراشىلىك اۋىلى,قاراشىلىك يېزىسى,喀拉希力克,喀拉希力克乡', 47.7294500, 87.4589000, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26733, 'Jiahezi', 'Jiahezi', 'Jiahezi,jia he zi,夹河子', 44.4836600, 84.7878400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26734, 'Ji’ergele Teguoleng', 'Ji''ergele Teguoleng', 'Ji''ergele Teguoleng,Ji''ergele Teguoleng Mengguzu Xiang,Ji''ergele Teguoleng Xiang,Ji’ergele Teguoleng,Ji’ergele Teguoleng Mengguzu Xiang,Ji’ergele Teguoleng Xiang,ji er ge lei te guo leng,ji er ge lei te guo leng meng gu zu xiang,ji er ge lei te guo leng xiang,吉尔格勒特郭楞,吉尔格勒特郭楞乡,吉尔格勒特郭楞蒙古族乡', 44.3554200, 84.1791600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26735, 'Tabulehete', 'Tabulehete', 'Tabulehete,Tabulehete Mengguzu Xiang,Tabulehete Xiang,ta bu lei he te,ta bu lei he te meng gu zu xiang,ta bu lei he te xiang,塔布勒合特,塔布勒合特乡,塔布勒合特蒙古族乡', 44.2185200, 84.2670300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26736, 'Sa’erhusong', 'Sa''erhusong', 'Sa''erhusong,Sa''erhusong Xiang,Sa’erhusong,Sa’erhusong Xiang,sa er hu song,sa er hu song xiang,sarkhۇlsۇn yېzysy,sarʿvsyn avyly,سارخۇلسۇن يېزىسى,سارعۋسىن اۋىلى,萨尔胡松,萨尔胡松乡', 47.4937100, 87.5416100, 'CN', '2015-01-03', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26737, 'Anwen', 'Anwen', 'Anwen,Anwen Zhen,an wen,an wen zhen,安稳,安稳镇', 28.6800100, 106.7565100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26738, 'Datong', 'Datong', 'Datong,Datong Zhen,da tong,da tong zhen,打通,打通镇', 28.5964800, 106.6674900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26739, 'Hengshan', 'Hengshan', 'Hengshan,Hengshan Zhen,heng shan,heng shan zhen,横山,横山镇', 29.1135000, 106.6723700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26740, 'Guanba', 'Guanba', 'Guanba,Guanba Zhen,guan ba,guan ba zhen,关坝,关坝镇', 28.8019400, 106.8058900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26741, 'Shilin', 'Shilin', 'Shilin,Shilin Zhen,shi lin,shi lin zhen,石林,石林镇', 28.8763300, 106.9022300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26742, 'Jinqiao', 'Jinqiao', 'Jinqiao,Jinqiao Zhen,jin qiao,jin qiao zhen,金桥,金桥镇', 29.0482600, 106.8851500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26743, 'Nantong', 'Nantong', 'Nantong,Nantong Zhen,nan tong,nan tong zhen,南桐,南桐镇', 28.9281500, 106.8680800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26744, 'Maliuzui', 'Maliuzui', 'Maliuzui,Maliuzui Zhen,ma liu zui,ma liu zui zhen,麻柳嘴,麻柳嘴镇', 29.6928600, 106.9439900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26745, 'Jiguanshi', 'Jiguanshi', 'Jiguanshi,Jiguanshi Zhen,ji guan shi,ji guan shi zhen,鸡冠石,鸡冠石镇', 29.5947000, 106.6046900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26746, 'Yinglong', 'Yinglong', 'Yinglong,Yinglong Zhen,ying long,ying long zhen,迎龙,迎龙镇', 29.5198600, 106.7147400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26747, 'Wubao', 'Wubao', 'Wubao,Wubao Zhen,wu bao,wu bao zhen,五宝,五宝镇', 29.6323500, 106.8302800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26748, 'Fusheng', 'Fusheng', 'Fusheng,Fusheng Zhen,fu sheng,fu sheng zhen,复盛,复盛镇', 29.6472900, 106.7918700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26749, 'Jinfeng', 'Jinfeng', 'Jinfeng,Jinfeng Zhen,jin feng,jin feng zhen,金凤,金凤镇', 29.5062600, 106.3258000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26750, 'Qimantage', 'Qimantage', 'Qimantage,qi man ta ge,祁曼塔格', 37.3063600, 90.3417600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26751, 'Tieganlike', 'Tieganlike', 'Tieganlike,Tieganlike Xiang,tie gan li ke,tie gan li ke xiang,铁干里克,铁干里克乡', 39.0290900, 88.1903000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26752, 'Guolemude', 'Guolemude', 'Guolemude,Guolemude Zhen,guo lei mu de,guo lei mu de zhen,郭勒木德,郭勒木德镇', 36.4136200, 94.8157000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26753, 'Hongliuwan', 'Hongliuwan', 'Hongliuwan,Hongliuwan Zhen,hong liu wan,hong liu wan zhen,红柳湾,红柳湾镇', 39.6318700, 94.3369400, 'CN', '2016-04-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26754, 'Duobagou', 'Duobagou', 'Duobagou,Duobagou Xiang,duo ba gou,duo ba gou xiang,多坝沟,多坝沟乡', 39.7518100, 93.4819800, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26755, 'Bayin', 'Bayin', 'Bayin,Xishuiquan,ba yin,xi shui quan,巴音,西水泉', 41.6235700, 112.6321900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26756, 'Yifaquan', 'Yifaquan', 'Yifaquan,yi fa quan,义发泉', 41.6231500, 112.5268700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26757, 'Tuchengzi', 'Tuchengzi', 'Dongjia,Tuchengzi,dong jia,tu cheng zi,土城子,董家', 41.4994300, 112.3815000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26758, 'Bulianhe', 'Bulianhe', 'Bulianhe,Hongtu Geta,bu lian he,hong tu ge ta,布连河,红土圪塔', 41.4798800, 112.5075500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26759, 'Wusutu', 'Wusutu', 'Changdi,Wusutu,chang de,wu su tu,乌素图,常地', 41.6516100, 112.7416500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26760, 'Yuanshanzi', 'Yuanshanzi', 'Yuanshanzi,yuan shan zi,元山子', 41.2986200, 112.7151600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26761, 'Huangyangcheng', 'Huangyangcheng', 'Huangyangcheng,huang yang cheng,黄羊城', 41.4317000, 112.3844000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26762, 'Miliangju', 'Miliangju', 'Miliangju,mi liang ju,米粮局', 41.3337300, 112.4545300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26763, 'Guangchanglong', 'Guangchanglong', 'Guangchanglong,guang chang long,广昌隆', 41.4330600, 112.3498100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26764, 'Erhaodi', 'Erhaodi', 'Erhaodi,er hao de,二号地', 41.2810200, 112.4529700, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26765, 'Huashanzi', 'Huashanzi', 'Huashanzi,Xihezi,hua shan zi,xi he zi,花山子,西河子', 41.6266500, 112.2722100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26766, 'Wuhao', 'Wuhao', 'Weizi Cun,Wuhao,wei zi cun,wu hao,五号,围子村', 41.5333700, 112.2957900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26767, 'Kulun', 'Kulun', 'Hushaolin,Kulun,Kulun Sumu,hu shao lin,ku lun,ku lun su mu,库伦,库伦苏木,忽少林', 41.7574900, 112.6658500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26768, 'Wulan Haye', 'Wulan Haye', 'Wulan Haye,Wulanhaye Sumu,wu lan ha ye,wu lan ha ye su mu,乌兰哈页,乌兰哈页苏木', 41.1812400, 112.3761000, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26769, 'Qisumu', 'Qisumu', 'Qisumu,qi su mu,七苏木', 41.2261400, 112.4809500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26770, 'Bahaodi', 'Bahaodi', 'Bahaodi,Daiba Yingzi,ba hao de,dai ba ying zi,八号地,呆坝营子', 41.9114300, 112.9796400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26771, 'Jigun Tala', 'Jigun Tala', 'Jigun Tala,Sandaowan,ji gun ta la,san dao wan,三道湾,吉棍塔拉', 41.7973700, 112.9477100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26772, 'Danglang Hudong', 'Danglang Hudong', 'Danglang Hudong,Danglang Hudong Sumu,dang lang hu dong,dang lang hu dong su mu,当郎忽洞,当郎忽洞苏木', 41.6749400, 112.9110900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26773, 'Hongge’ertu', 'Hongge''ertu', 'Hongge''ertu,Hongge’ertu,Zhangjungou,hong ge er tu,zhang jun gou,张俊沟,红格尔图', 41.6949700, 113.1520100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26774, 'Chahannao', 'Chahannao', 'Chahannao,cha han nao,察汗淖', 41.6089300, 112.8635600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26775, 'Xilei', 'Xilei', 'Xilei,Yuanjiafang,xi lei,yuan jia fang,袁家坊,锡勒', 41.2836100, 112.9210400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26776, 'Xinlin', 'Xinlin', 'Xinlin,Xinlin Zhen,xin lin,xin lin zhen,新林,新林镇', 47.2554500, 122.4406900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26777, 'Tumuji', 'Tumuji', 'Tumuji,Tumuji Zhen,tu mu ji,tu mu ji zhen,图牧吉,图牧吉镇', 46.2717800, 122.9759100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26778, 'Shengli', 'Shengli', 'Dongyifang,Shengli,dong yi fang,sheng li,胜利,董义坊', 41.1567400, 112.8613500, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26779, 'Mingren', 'Mingren', 'Mingren,Taobei Qu,ming ren,tao bei qu,明仁,洮北区', 45.5931600, 122.8187900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26780, 'Qingshan', 'Qingshan', 'Qingshan,Qingshan Zhen,qing shan,qing shan zhen,青山,青山镇', 45.7372400, 122.8624300, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26781, 'Deshun', 'Deshun', 'Deshun,Deshun Mengguzu Xiang,de shun,de shun meng gu zu xiang,德顺,德顺蒙古族乡', 45.4135000, 122.8743400, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26782, 'Shiyaogou', 'Shiyaogou', 'Shiyaogou,shi yao gou,石窑沟', 41.2877600, 113.0702900, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26783, 'Shimenkou', 'Shimenkou', 'Shimenkou,shi men kou,石门口', 41.3724100, 113.3012100, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26784, 'Hayan Hudong', 'Hayan Hudong', 'Hayan Hudong,Hayan Hudong Sumu,ha yan hu dong,ha yan hu dong su mu,哈彦忽洞,哈彦忽洞苏木', 41.4458700, 113.3031600, 'CN', '2013-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26785, 'Cuijiu', 'Cuijiu', 'Cai''gyu,Cai’gyu,Cuijiu,Cuijiu Xiang,Qiongguojie,cui jiu,cui jiu xiang,qiong guo jie,催久乡,崔久,琼果介', 29.4465700, 92.7120300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26786, 'Niu', 'Niu', 'Liuwu,Liuwu Xiang,Niu,Sangjiegongba,liu wu,liu wu xiang,sang jie gong ba,柳梧,柳梧乡,桑杰贡巴', 29.5683800, 91.0301700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26787, 'Sechang', 'Sechang', 'Qianggen,Sechang,Sechang Xiang,Sercham,Sêrcham,qiang gen,se chang,se chang xiang,强根,色昌,色昌乡', 31.4868400, 94.6587800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26788, 'Sexiong', 'Sexiong', 'Naruduo,Serxong,Sexiong,Sexiong Xiang,Sêrxong,na ru duo,se xiong,se xiong xiang,纳汝多,色雄,色雄乡', 31.4007900, 92.8344600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26789, 'Zhongyu', 'Zhongyu', 'Chongyu,Chongyü,Qiayu,Zhongyu,Zhongyu Xiang,qia yu,zhong yu,zhong yu xiang,忠玉,忠玉乡,恰玉', 30.4901500, 94.0055700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26790, 'Zangbi', 'Zangbi', 'Dongboduo,Zangbi,Zangbi Xiang,cang bi,cang bi xiang,dong bo duo,东波多,藏比,藏比乡', 30.6664000, 92.3656300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26791, 'Meilu', 'Meilu', 'Meilu,Meilu Jiedao,mei lu,mei lu jie dao,梅菉,梅菉街道', 21.4341200, 110.7755500, 'CN', '2013-10-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26792, 'Nan’an', 'Nan''an', 'Nan''an,Nan''an Jiedao,Nan’an,Nan’an Jiedao,nan an,nan an jie dao,南岸,南岸街道', 23.0313600, 112.4510800, 'CN', '2013-10-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26793, 'Xinfu', 'Xinfu', 'Xinfu,Xinfu Xiang,xing fu,xing fu xiang,幸福,幸福乡', 50.2378400, 127.4899700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26794, 'Kunheda Woerzu Manzu', 'Kunheda Woerzu Manzu', 'Kunheda Woerzu Manzu,Kunheda Woerzu Manzu Xiang,kun he da wo er zu man zu,kun he da wo er zu man zu xiang,坤河达斡尔族满族,坤河达斡尔族满族乡', 49.8847700, 127.5032000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26795, 'Xing’an', 'Xing''an', 'Aihui Qu,Xing''an,Xing’an,ai hui qu,xing an,兴安,爱辉区', 50.2477000, 127.4932300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26796, 'Nierumai', 'Nierumai', 'Nierumai,Nierumai Xiang,nie ru mai,nie ru mai xiang,涅如麦,涅如麦乡', 28.7157100, 89.9407700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26797, 'Gengzhang', 'Gengzhang', 'Gengzhang,Gengzhang Menbaminzu Xiang,Gengzhang Xiang,geng zhang,geng zhang men ba min zu xiang,geng zhang xiang,更章,更章乡,更章门巴民族乡', 29.7278600, 94.0920500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26798, 'Yinla', 'Yinla', 'Yinla,Yinla Zhen,yin la,yin la zhen,音拉,音拉镇', 29.5773000, 94.4830100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26799, 'Mu', 'Mu', 'Mu,Mu Xiang,mu,mu xiang,母,母乡', 29.2870900, 89.7655300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26800, 'Lian', 'Lian', 'Lian,Lian Xiang,lian,lian xiang,联,联乡', 29.3046300, 89.5531100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26801, 'Chaba', 'Chaba', 'Chaba,Chaba Xiang,cha ba,cha ba xiang,查巴,查巴乡', 29.1858900, 89.9442700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26802, 'Bianxiong', 'Bianxiong', 'Bianxiong,Bianxiong Xiang,bian xiong,bian xiong xiang,边雄,边雄乡', 29.3190900, 89.0505400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26803, 'Nianmu', 'Nianmu', 'Nianmu,Nianmu Xiang,nian mu,nian mu xiang,年木,年木乡', 29.3217400, 89.4461200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26804, 'Narong', 'Narong', 'Narong,na rong,纳荣', 29.1429700, 89.6172100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26805, 'Cheren', 'Cheren', 'Cheren,Cheren Xiang,che ren,che ren xiang,车仁,车仁乡', 28.8623300, 89.6968900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26806, 'Niandui', 'Niandui', 'Niandui,nian dui,年堆', 28.8886100, 89.6603100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26807, 'Qiangdui', 'Qiangdui', 'Qiangdui,Qiangdui Xiang,qiang dui,qiang dui xiang,强堆,强堆乡', 29.0883400, 89.3657100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26808, 'Duqiong', 'Duqiong', 'Duqiong,Duqiong Xiang,du qiong,du qiong xiang,杜琼,杜琼乡', 29.0341600, 89.2482900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26809, 'Luojiang', 'Luojiang', 'Luojiang,Luojiang Zhen,luo jiang,luo jiang zhen,洛江,洛江镇', 29.1056800, 89.2644300, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26810, 'Bazha', 'Bazha', 'Bazha,Bazha Xiang,ba zha,ba zha xiang,巴扎,巴扎乡', 29.1848200, 89.1400300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26811, 'Ma Xiang', 'Ma Xiang', 'Ma Xiang,ma xiang,玛乡', 28.9853800, 89.1055500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26812, 'Zijin', 'Zijin', 'Zijin,Zijin Xiang,zi jin,zi jin xiang,紫金,紫金乡', 28.9201800, 89.5334500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26813, 'Kangzhuo', 'Kangzhuo', 'Kangzhuo,Kangzhuo Xiang,kang zhuo,kang zhuo xiang,康卓,康卓乡', 28.8885700, 89.4958800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26814, 'Nanyi', 'Nanyi', 'Nanyi,Nanyi Luoba Minzuxiang,Nanyi Xiang,nan yi,nan yi luo ba min zu xiang,nan yi xiang,南伊,南伊乡,南伊珞巴民族乡', 29.1828200, 94.1895800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26815, 'Beile', 'Beile', 'Beile,Beile Xiang,bei le,bei le xiang,北乐,北乐乡', 38.0048500, 114.6572700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26816, 'Shangzhuang', 'Shangzhuang', 'Shangzhuang,Shangzhuang Zhen,shang zhuang,shang zhuang zhen,上庄,上庄镇', 38.0313100, 114.3704600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26817, 'Liuying', 'Liuying', 'Liuying,Liuying Xiang,liu ying,liu ying xiang,留营,留营乡', 38.0530500, 114.4222700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26818, 'Beizheng', 'Beizheng', 'Beizheng,Beizheng Xiang,bei zheng,bei zheng xiang,北正,北正乡', 38.0604700, 114.0784900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26819, 'Hengbei', 'Hengbei', 'Hengbei,Hengbei Xiang,heng bei,heng bei xiang,横北,横北乡', 38.0642500, 114.0588400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26820, 'Bailuquan', 'Bailuquan', 'Bailuquan,Bailuquan Xiang,bai lu quan,bai lu quan xiang,白鹿泉,白鹿泉乡', 38.0709900, 114.2694000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26821, 'Haozhuang', 'Haozhuang', 'Haozhuang,Haozhuang Xiang,hao zhuang,hao zhuang xiang,郝庄,郝庄乡', 38.0788700, 114.8414300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26822, 'Taoyuan', 'Taoyuan', 'Taoyuan,Taoyuan Zhen,tao yuan,tao yuan zhen,桃园,桃园镇', 38.0820700, 114.5170000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26823, 'Shijing', 'Shijing', 'Shijing,Shijing Xiang,shi jing,shi jing xiang,石井,石井乡', 38.1059700, 114.2900400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26824, 'Jiumen', 'Jiumen', 'Jiumen,Jiumen Huizu Xiang,jiu men,jiu men hui zu xiang,九门,九门回族乡', 38.1072500, 114.7307400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26825, 'Beizaoxian', 'Beizaoxian', 'Beizaoxian,Beizaoxian Xiang,bei zao xian,bei zao xian xiang,北早现,北早现乡', 38.2311800, 114.5231800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26826, 'Xipingle', 'Xipingle', 'Xipingle,Xipingle Xiang,xi ping le,xi ping le xiang,西平乐,西平乐乡', 38.2725800, 114.6402300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26827, 'Xiguan', 'Xiguan', 'Xiguan,Xiguan Zhen,xi guan,xi guan zhen,西关,西关镇', 38.2735600, 114.7964100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26828, 'Xizhong', 'Xizhong', 'Xizhong,Xizhong Xiang,xi zhong,xi zhong xiang,息冢,息冢乡', 38.3103000, 114.9389200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26829, 'Goutai', 'Goutai', 'Goutai,Goutai Xiang,gou tai,gou tai xiang,狗台,狗台乡', 38.3302600, 114.3193800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26830, 'Gaopeng', 'Gaopeng', 'Gaopeng,Gaopeng Zhen,gao peng,gao peng zhen,高蓬,高蓬镇', 38.3536700, 114.9937700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26831, 'Xieshen', 'Xieshen', 'Xieshen,Xieshen Xiang,xie shen,xie shen xiang,协神,协神乡', 38.3538800, 114.5544500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26832, 'Lang', 'Lang', 'Lang,Lang Zhen,lang,lang zhen,朗,朗镇', 29.0356800, 92.9793300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26833, 'Laduo', 'Laduo', 'Laduo,Laduo Xiang,la duo,la duo xiang,拉多,拉多乡', 29.0057600, 93.0860200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26834, 'Nanzhai', 'Nanzhai', 'Nanzhai,Nanzhai Xiang,nan zhai,nan zhai xiang,南寨,南寨乡', 38.3704000, 114.3916400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26835, 'Pengjiazhuang', 'Pengjiazhuang', 'Pengjiazhuang,Pengjiazhuang Xiang,peng jia zhuang,peng jia zhuang xiang,彭家庄,彭家庄乡', 38.3721800, 114.7526600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26836, 'Qingtong', 'Qingtong', 'Qingtong,Qingtong Zhen,qing tong,qing tong zhen,青同,青同镇', 38.3827700, 114.3497100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26837, 'Anxiang', 'Anxiang', 'Anxiang,Anxiang Xiang,an xiang,an xiang xiang,安香,安香乡', 38.3833900, 114.5404600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26838, 'Tashang', 'Tashang', 'Tashang,Tashang Zhen,ta shang,ta shang zhen,塔上,塔上镇', 38.3948400, 114.2023300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26839, 'Cheng’an', 'Cheng''an', 'Cheng''an,Cheng''an Zhen,Cheng’an,Cheng’an Zhen,cheng an,cheng an zhen,承安,承安镇', 38.3981800, 114.7875900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26840, 'Zhili', 'Zhili', 'Zhili,Zhili Xiang,zhi li,zhi li xiang,只里,只里乡', 38.3998900, 114.5785700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26841, 'Zhoucun', 'Zhoucun', 'Zhoucun,Zhoucun Xiang,zhou cun,zhou cun xiang,周村,周村乡', 38.4185400, 114.9086100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26842, 'Shitong', 'Shitong', 'Shitong,Shitong Xiang,shi tong,shi tong xiang,市同,市同乡', 38.4290100, 114.5017600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26843, 'Diying', 'Diying', 'Diying,Diying Xiang,di ying,di ying xiang,翟营,翟营乡', 38.4347600, 114.4400400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26844, 'Duyanggang', 'Duyanggang', 'Duyanggang,Duyanggang Xiang,du yang gang,du yang gang xiang,独羊岗,独羊岗乡', 38.4526000, 114.5875800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26845, 'Xiaoyoucun', 'Xiaoyoucun', 'Xiaoyoucun,Xiaoyoucun Xiang,xiao you cun,xiao you cun xiang,小油村,小油村乡', 38.4713300, 114.8472900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26846, 'Dicun', 'Dicun', 'Dicun,Dicun Xiang,di cun,di cun xiang,邸村,邸村乡', 38.5089700, 114.7525100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26847, 'Beitanzhuang', 'Beitanzhuang', 'Beitanzhuang,Beitanzhuang Xiang,bei tan zhuang,bei tan zhuang xiang,北谭庄,北谭庄乡', 38.5132000, 114.2877500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26848, 'Chengzhai', 'Chengzhai', 'Chengzhai,Chengzhai Xiang,cheng zhai,cheng zhai xiang,城寨,城寨乡', 38.5306800, 114.3583100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26849, 'Yuting', 'Yuting', 'Yuting,Yuting Xiang,yu ting,yu ting xiang,玉亭,玉亭乡', 38.5360500, 114.5096400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26850, 'Chatou', 'Chatou', 'Chatou,Chatou Zhen,cha tou,cha tou zhen,岔头,岔头镇', 38.5608200, 114.2353100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26851, 'Wende', 'Wende', 'Wende,Wende Xiang,wen de,wen de xiang,文德,文德乡', 38.5761400, 114.7481700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26852, 'Shangyanzhuang', 'Shangyanzhuang', 'Shangyanzhuang,Shangyanzhuang Xiang,shang yan zhuang,shang yan zhuang xiang,上阎庄,上阎庄乡', 38.5811700, 114.2635200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26853, 'Dongwang', 'Dongwang', 'Dongwang,Dongwang Xiang,dong wang,dong wang xiang,东旺,东旺乡', 38.5867100, 114.8486700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26854, 'Luzhuangzi', 'Luzhuangzi', 'Luzhuangzi,Luzhuangzi Xiang,lu zhuang zi,lu zhuang zi xiang,路庄子,路庄子乡', 38.6044600, 114.6742400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26855, 'Xiaomu', 'Xiaomu', 'Xiaomu,Xiaomu Xiang,xiao mu,xiao mu xiang,孝墓,孝墓乡', 38.6785200, 114.6474100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26856, 'Zhuangke', 'Zhuangke', 'Zhuangke,Zhuangke Xiang,zhuang ke,zhuang ke xiang,庄窠,庄窠乡', 38.6941400, 114.6940900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26857, 'Qicun', 'Qicun', 'Qicun,Qicun Xiang,qi cun,qi cun xiang,齐村,齐村乡', 38.6945600, 114.5025400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26858, 'Luozhuang', 'Luozhuang', 'Luozhuang,Luozhuang Xiang,luo zhuang,luo zhuang xiang,罗庄,罗庄乡', 38.7012800, 114.7882300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26859, 'Duting', 'Duting', 'Duting,Duting Xiang,dou ting,dou ting xiang,都亭,都亭乡', 38.7310000, 114.9356400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26860, 'Micheng', 'Micheng', 'Micheng,Micheng Xiang,mi cheng,mi cheng xiang,迷城,迷城乡', 38.8636000, 114.7718700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26861, 'Dabei', 'Dabei', 'Dabei,Dabei Xiang,da bei,da bei xiang,大悲,大悲乡', 38.9733400, 114.9220500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26862, 'Mugala', 'Mugala', 'Mugala,Mugala Zhen,Yutian Xian,mu ga la,mu ga la zhen,yu tian xian,于田县,木尕拉,木尕拉镇', 36.8576000, 81.6684400, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26863, 'Ailan Mubage', 'Ailan Mubage', 'Ailan Mubage,Yining Shi,ai lan mu ba ge,yi ning shi,伊宁市,艾兰木巴格', 43.9084500, 81.3329900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26864, 'Dongla', 'Dongla', 'Dongla,Dongla Xiang,dong la,dong la xiang,东拉,东拉乡', 29.0748700, 90.7463000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26865, 'Tamutuo Gelake', 'Tamutuo Gelake', 'Tamutuo Gelake,Tamutuo Gelake Xiang,ta mu tuo ge la ke,ta mu tuo ge la ke xiang,塔木托格拉克,塔木托格拉克乡', 41.3399500, 82.4299100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26866, 'Youludu Sibage', 'Youludu Sibage', 'Youludu Sibage,Youludu Sibage Zhen,you lu dou si ba ge,you lu dou si ba ge zhen,尤鲁都斯巴格,尤鲁都斯巴格镇', 41.5524800, 82.3917900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26867, 'Bozidun', 'Bozidun', 'Bozidun,Bozidun Ke''erkezizu Xiang,Bozidun Ke’erkezizu Xiang,bo zi dun,bo zi dun ke er ke zi zu xiang,博孜墩,博孜墩柯尔克孜族乡', 41.7154300, 80.7695900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26868, 'Dana', 'Dana', 'Dagna,Dana,Dana Xiang,da na,da na xiang,达那,达那乡', 29.7051900, 89.2356700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26869, 'Suojin', 'Suojin', 'Suojin,Suojin Xiang,suo jin,suo jin xiang,索金,索金乡', 29.6360300, 89.5611900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26870, 'Yu’erhong', 'Yu''erhong', 'Yu''erhong,Yu`erhong Xiang,Yu‘erhong Xiang,Yu’erhong,yu r hong,yu r hong xiang,鱼儿红,鱼儿红乡', 39.7006800, 97.1986500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26871, 'Xishui', 'Xishui', 'Xishui,Xishui Mengguzu Xiang,xi shui,xi shui meng gu zu xiang,西水,西水蒙古族乡', 38.6364900, 100.1783800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26872, 'Baiyin', 'Baiyin', 'Baiyin,Baiyin Mengguzu Xiang,bai yin,bai yin meng gu zu xiang,白银,白银蒙古族乡', 38.9182400, 99.8885100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26873, 'Qinglong', 'Qinglong', 'Qinglong,Qinglong Xiang,qing long,qing long xiang,青龙,青龙乡', 38.8817600, 99.6959500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26874, 'Qiwen', 'Qiwen', 'Qiwen,Qiwen Zangzu Xiang,qi wen,qi wen cang zu xiang,祁文,祁文藏族乡', 39.6261100, 98.3267400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26875, 'Huangnibao', 'Huangnibao', 'Huangnibao,Huangnibao Yuguzu Xiang,huang ni bao,huang ni bao yu gu zu xiang,黄泥堡,黄泥堡裕固族乡', 39.7182100, 98.8195300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26876, 'Nanjie', 'Nanjie', 'Ganzhou Qu,Nanjie,gan zhou qu,nan jie,南街,甘州区', 38.9546200, 100.4723700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26877, 'Wenshu', 'Wenshu', 'Wenshu,Wenshu Zhen,wen shu,wen shu zhen,文殊,文殊镇', 39.6937800, 98.3722100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26878, 'Pingshanhu', 'Pingshanhu', 'Pingshanhu,Pingshanhu Mengguzu Xiang,ping shan hu,ping shan hu meng gu zu xiang,平山湖,平山湖蒙古族乡', 39.1637400, 100.8291800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26879, 'Sanzha', 'Sanzha', 'Sanzha,Sanzha Zhen,san zha,san zha zhen,三闸,三闸镇', 39.0029300, 100.4930700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26880, 'Huangmei', 'Huangmei', 'Huangmei,Huangmei Zhen,huang mei,huang mei zhen,黄梅,黄梅镇', 30.0789900, 115.9388400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26881, 'Yuchuan', 'Yuchuan', 'Yuchuan,Yuchuan Zhen,yu chuan,yu chuan zhen,余川,余川镇', 30.0877000, 115.7289600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26882, 'Dahe', 'Dahe', 'Dahe,Dahe Zhen,da he,da he zhen,大河,大河镇', 30.0941500, 115.8317400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26883, 'Shamu', 'Shamu', 'Shamu,Shamu Xiang,shan mu,shan mu xiang,杉木,杉木乡', 30.1063200, 115.9730100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26884, 'Kuzhu', 'Kuzhu', 'Kuzhu,Kuzhu Xiang,ku zhu,ku zhu xiang,苦竹,苦竹乡', 30.1331200, 115.8902000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26885, 'Wuzu', 'Wuzu', 'Wuzu,Wuzu Zhen,wu zu,wu zu zhen,五祖,五祖镇', 30.1726600, 115.9359500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26886, 'Liulin', 'Liulin', 'Liulin,Liulin Xiang,liu lin,liu lin xiang,柳林,柳林乡', 30.2693600, 115.9574000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26887, 'Qingshi', 'Qingshi', 'Qingshi,Qingshi Zhen,qing shi,qing shi zhen,青石,青石镇', 30.3111700, 115.6916600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26888, 'Xiangqiao', 'Xiangqiao', 'Xiangqiao,Xiangqiao Xiang,xiang qiao,xiang qiao xiang,向桥,向桥乡', 30.3351300, 115.7526600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26889, 'Shizi', 'Shizi', 'Shizi,Shizi Zhen,shi zi,shi zi zhen,狮子,狮子镇', 30.3875000, 115.6034100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26890, 'Zhangbang', 'Zhangbang', 'Zhangbang,Zhangbang Zhen,zhang bang,zhang bang zhen,张塝,张塝镇', 30.4244900, 115.7817200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26891, 'Datong', 'Datong', 'Datong,Datong Zhen,da tong,da tong zhen,大同,大同镇', 30.4969500, 115.8002300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26892, 'Tanlin', 'Tanlin', 'Tanlin,Tanlin Zhen,tan lin,tan lin zhen,檀林,檀林镇', 30.5211600, 115.8494700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26893, 'Lüyang', 'Luyang', 'Luyang,Luyang Xiang,Lüyang,Lüyang Xiang,lu yang,lu yang xiang,绿杨,绿杨乡', 30.5283300, 115.5339300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26894, 'Nanhe', 'Nanhe', 'Nanhe,Nanhe Zhen,nan he,nan he zhen,南河,南河镇', 30.5932900, 115.6300000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26895, 'Fangjiazui', 'Fangjiazui', 'Fangjiazui,Fangjiazui Xiang,fang jia ju,fang jia ju xiang,方家咀,方家咀乡', 30.6458000, 115.6075600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26896, 'Kongjiafang', 'Kongjiafang', 'Kongjiafang,Kongjiafang Xiang,kong jia fang,kong jia fang xiang,孔家坊,孔家坊乡', 30.8394500, 115.6288600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26897, 'Jinjiapu', 'Jinjiapu', 'Jinjiapu,Jinjiapu Zhen,jin jia pu,jin jia pu zhen,金家铺,金家铺镇', 30.8916500, 115.6361300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26898, 'Xintian', 'Xintian', 'Xintian,Xintian Zhen,xin tian,xin tian zhen,新天,新天镇', 38.5308600, 100.5469100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26899, 'Nanfeng', 'Nanfeng', 'Nanfeng,Nanfeng Xiang,nan feng,nan feng xiang,南丰,南丰乡', 38.3141500, 100.8837100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26900, 'Caijiazha', 'Caijiazha', 'Caijiazha,Caijiazha Zhen,cai jia zha,cai jia zha zhen,蔡家榨,蔡家榨镇', 30.9251000, 114.5311300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26901, 'Taipingqiao', 'Taipingqiao', 'Taipingqiao,Taipingqiao Zhen,tai ping qiao,tai ping qiao zhen,太平桥,太平桥镇', 30.9625900, 114.6413300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26902, 'Wangjiahe', 'Wangjiahe', 'Wangjiahe,Wangjiahe Zhen,wang jia he,wang jia he zhen,王家河,王家河镇', 30.9636100, 114.4132600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26903, 'Lijiaji', 'Lijiaji', 'Lijiaji,Lijiaji Zhen,li jia ji,li jia ji zhen,李家集,李家集镇', 31.0202900, 114.2329900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26904, 'Zhangjiafan', 'Zhangjiafan', 'Zhangjiafan,Zhangjiafan Zhen,zhang jia fan,zhang jia fan zhen,张家畈,张家畈镇', 31.0501400, 115.3114300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26905, 'Mulan', 'Mulan', 'Mulan,Mulan Xiang,mu lan,mu lan xiang,木兰,木兰乡', 31.0995100, 114.4546000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26906, 'Nanhu', 'Nanhu', 'Nanhu,Nanhu Jiedao,nan hu,nan hu jie dao,南湖,南湖街道', 31.1690100, 114.9982000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26907, 'Gulou', 'Gulou', 'Gulou,Gulou Jiedao,gu lou,gu lou jie dao,鼓楼,鼓楼街道', 31.1783000, 115.0347500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26908, 'Longchiqiao', 'Longchiqiao', 'Longchiqiao,Longchiqiao Jiedao,long chi qiao,long chi qiao jie dao,龙池桥,龙池桥街道', 31.1878400, 115.0216500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26909, 'Xiyang', 'Xiyang', 'Xiyang,Xiyang Zhen,xi yang,xi yang zhen,西杨,西杨镇', 31.1963800, 114.8601700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26910, 'Gaoqiao', 'Gaoqiao', 'Gaoqiao,Gaoqiao Zhen,gao qiao,gao qiao zhen,高桥,高桥镇', 31.2027900, 114.5643600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26911, 'Xinghua', 'Xinghua', 'Xinghua,Xinghua Xiang,xing hua,xing hua xiang,杏花,杏花乡', 31.2808500, 114.6246400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26912, 'Ercheng', 'Ercheng', 'Ercheng,Ercheng Zhen,er cheng,er cheng zhen,二程,二程镇', 31.2926100, 114.4978100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26913, 'Xiaowu', 'Xiaowu', 'Xiaowu,Xiaowu Xiang,xiao wu,xiao wu xiang,小悟,小悟乡', 31.2974000, 114.1139800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26914, 'Shunhe', 'Shunhe', 'Shunhe,Shunhe Zhen,shun he,shun he zhen,顺河,顺河镇', 31.3021400, 114.8275000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26915, 'Shangxinji', 'Shangxinji', 'Shangxinji,Shangxinji Zhen,shang xin ji,shang xin ji zhen,上新集,上新集镇', 31.3123200, 114.4383000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26916, 'Xiaohe', 'Xiaohe', 'Xiaohe,Xiaohe Zhen,xiao he,xiao he zhen,小河,小河镇', 31.3471000, 114.0535200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26917, 'Huajiahe', 'Huajiahe', 'Huajiahe,Huajiahe Zhen,hua jia he,hua jia he zhen,华家河,华家河镇', 31.4619300, 114.5293600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26918, 'Yangping', 'Yangping', 'Yangping,Yangping Zhen,yang ping,yang ping zhen,阳平,阳平镇', 31.4980600, 114.1110900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26919, 'Luwang', 'Luwang', 'Luwang,Luwang Zhen,lu wang,lu wang zhen,吕王,吕王镇', 31.5059500, 114.4758000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26920, 'Pengdian', 'Pengdian', 'Pengdian,Pengdian Xiang,peng dian,peng dian xiang,彭店,彭店乡', 31.5343600, 114.3635600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26921, 'Gaodian', 'Gaodian', 'Gaodian,Gaodian Xiang,gao dian,gao dian xiang,高店,高店乡', 31.5890000, 114.2282000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26922, 'Fengdian', 'Fengdian', 'Fengdian,Fengdian Zhen,feng dian,feng dian zhen,丰店,丰店镇', 31.6239900, 114.3804700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26923, 'Wushengguan', 'Wushengguan', 'Wushengguan,Wushengguan Zhen,wu sheng guan,wu sheng guan zhen,武胜关,武胜关镇', 31.6772500, 114.0399500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26924, 'Dongxin', 'Dongxin', 'Dongxin,Dongxin Xiang,dong xin,dong xin xiang,东新,东新乡', 31.7027100, 114.2078000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26925, 'Jiaqiong', 'Jiaqiong', 'Jiaqiong,Jiaqiong Zhen,jia qiong,jia qiong zhen,佳琼,佳琼镇', 31.6557000, 90.5756200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26926, 'Maqian', 'Maqian', 'Maqian,Maqian Xiang,ma qian,ma qian xiang,马前,马前乡', 31.6576700, 90.1912100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26927, 'Maying', 'Maying', 'Maying,Maying Xiang,ma ying,ma ying xiang,马营,马营乡', 37.9787300, 101.7139700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26928, 'Beitan', 'Beitan', 'Beitan,Beitan Xiang,bei tan,bei tan xiang,北滩,北滩乡', 37.9055700, 101.8216300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26929, 'Dongtan', 'Dongtan', 'Dongtan,Dongtan Xiang,dong tan,dong tan xiang,东滩,东滩乡', 37.8614000, 101.8064500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26930, 'Yangxiang', 'Yangxiang', 'Yangxiang,Yangxiang Zangzu Xiang,yang xiang,yang xiang cang zu xiang,泱翔,泱翔藏族乡', 37.9897700, 101.9927900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26931, 'Beila', 'Beila', 'Beila,Beila Zhen,bei la,bei la zhen,北拉,北拉镇', 31.4004500, 90.8283800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26932, 'Sanshandao', 'Sanshandao', 'Sanshandao,Sanshandao Jiedao,san shan dao,san shan dao jie dao,三山岛,三山岛街道', 37.4052100, 119.9528200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26933, 'Longhuya', 'Longhuya', 'Longhuya,Longhuya Zhen,long hu ya,long hu ya zhen,龙虎崖,龙虎崖镇', 37.1302600, 119.8693000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26934, 'Zuocun', 'Zuocun', 'Zuocun,Zuocun Zhen,zha cun,zha cun zhen,柞村,柞村镇', 37.0603900, 119.9417700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26935, 'Wenfenglu', 'Wenfenglu', 'Wenfenglu,Wenfenglu Jiedao,wen feng lu,wen feng lu jie dao,文峰路,文峰路街道', 37.1258900, 119.9283400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26936, 'Yangzi', 'Yangzi', 'Yangzi,Yangzi Zhen,yang zi,yang zi zhen,央子,央子镇', 37.0448700, 119.1543900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26937, 'Beichangshan', 'Beichangshan', 'Beichangshan,Beichangshan Xiang,bei zhang shan,bei zhang shan xiang,北长山,北长山乡', 37.9653000, 120.7219900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26938, 'Heishan', 'Heishan', 'Heishan,Heishan Xiang,hei shan,hei shan xiang,黑山,黑山乡', 37.9651300, 120.6203000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26939, 'Guandao', 'Guandao', 'Guandao,Guandao Zhen,guan dao,guan dao zhen,官道,官道镇', 37.2109800, 120.6212000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26940, 'Xicheng', 'Xicheng', 'Xicheng,Xicheng Zhen,xi cheng,xi cheng zhen,西城,西城镇', 37.3147300, 120.7527400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26941, 'Tangezhuang', 'Tangezhuang', 'Tangezhuang,Tangezhuang Zhen,tan ge zhuang,tan ge zhuang zhen,谭格庄,谭格庄镇', 37.1188800, 120.5920400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26942, 'Jincheng', 'Jincheng', 'Jincheng,Jincheng Zhen,jin cheng,jin cheng zhen,金城,金城镇', 37.4204800, 120.1058800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26943, 'Shengxin', 'Shengxin', 'Shengxin,Shengxin Zhen,sheng xin,sheng xin zhen,省新,省新镇', 25.0366600, 118.3826200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26944, 'Yuetang', 'Yuetang', 'Yuetang,Yuetang Xiang,yue tang,yue tang xiang,月塘,月塘乡', 25.2390500, 119.0921200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26945, 'Dongjiao', 'Dongjiao', 'Dongjiao,Dongjiao Zhen,dong jiao,dong jiao zhen,东峤,东峤镇', 25.2678000, 119.1672400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26946, 'Donghai', 'Donghai', 'Donghai,Donghai Zhen,dong hai,dong hai zhen,东海,东海镇', 25.2756600, 118.9174500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26947, 'Dongguan', 'Dongguan', 'Dongguan,dong guan,东关', 25.2947400, 118.3589400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26948, 'Chengnan', 'Chengnan', 'Chengnan,Chengnan Xiang,cheng nan,cheng nan xiang,城南,城南乡', 25.4297800, 119.0114400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26949, 'Chengxiao', 'Chengxiao', 'Chengxiao,Chengxiao Xiang,cheng xiao,cheng xiao xiang,城效,城效乡', 25.4431300, 119.0195500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26950, 'Fuquan', 'Fuquan', 'Fuquan,Fuquan Xiang,fu quan,fu quan xiang,富泉,富泉乡', 25.8410300, 118.8826100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26951, 'Gaishan', 'Gaishan', 'Gaishan,Gaishan Zhen,gai shan,gai shan zhen,盖山,盖山镇', 26.0244000, 119.3300600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26952, 'Cangshan', 'Cangshan', 'Cangshan,Cangshan Zhen,cang shan,cang shan zhen,仓山,仓山镇', 26.0384900, 119.3079100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26953, 'Jianxin', 'Jianxin', 'Jianxin,Jianxin Zhen,jian xin,jian xin zhen,建新,建新镇', 26.0702200, 119.2296700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26954, 'Gushan', 'Gushan', 'Gushan,Gushan Zhen,gu shan,gu shan zhen,鼓山,鼓山镇', 26.0739300, 119.3436000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26955, 'Jingxi', 'Jingxi', 'Jingxi,Jingxi Zhen,jing xi,jing xi zhen,荆溪,荆溪镇', 26.1293200, 119.1758900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26956, 'Jiangnan', 'Jiangnan', 'Jiangnan,Jiangnan Xiang,jiang nan,jiang nan xiang,江南,江南乡', 26.1933500, 119.5378500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26957, 'Aojiang', 'Aojiang', 'Aojiang,Aojiang Zhen,ao jiang,ao jiang zhen,敖江,敖江镇', 26.2014300, 119.5357200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26958, 'Xiaoruo', 'Xiaoruo', 'Xiaoruo,Xiaoruo Xiang,xiao ruo,xiao ruo xiang,小箬,小箬乡', 26.2775500, 118.8726200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26959, 'Ankai', 'Ankai', 'Ankai,Ankai Xiang,an kai,an kai xiang,安凯,安凯乡', 26.3421200, 119.8404500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26960, 'Toubao', 'Toubao', 'Toubao,Toubao Zhen,tou bao,tou bao zhen,透堡,透堡镇', 26.3486400, 119.6258200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26961, 'Tailu', 'Tailu', 'Tailu,Tailu Zhen,tai lu,tai lu zhen,苔菉,苔菉镇', 26.3595500, 119.9349400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26962, 'Jielin', 'Jielin', 'Jielin,Jielin Xiang,ju lin,ju lin xiang,桔林,桔林乡', 26.4014700, 118.7686900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26963, 'Xilan', 'Xilan', 'Xilan,Xilan Xiang,xi lan,xi lan xiang,西兰,西兰乡', 26.4661200, 119.3874100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26964, 'Xinjia', 'Xinjia', 'Longkou Shi,Xinjia,Xinjia Jiedao,long kou shi,xin jia,xin jia jie dao,新嘉,新嘉街道,龙口市', 37.6574000, 120.4850000, 'CN', '2014-03-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26965, 'Zhuyouguan', 'Zhuyouguan', 'Zhuyouguan,Zhuyouguan Zhen,zhu you guan,zhu you guan zhen,诸由观,诸由观镇', 37.6893900, 120.5824600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26966, 'Xufu', 'Xufu', 'Xufu,Xufu Zhen,xu fu,xu fu zhen,徐福,徐福镇', 37.6791100, 120.4816700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26967, 'Langao', 'Langao', 'Langao,Langao Zhen,lan gao,lan gao zhen,兰高,兰高镇', 37.6423300, 120.5863800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26968, 'Qijia', 'Qijia', 'Qijia,Qijia Zhen,qi jia,qi jia zhen,七甲,七甲镇', 37.5373500, 120.5926400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26969, 'Dongjiang', 'Dongjiang', 'Dongjiang,Dongjiang Zhen,dong jiang,dong jiang zhen,东江,东江镇', 37.6254200, 120.5116600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26970, 'Lutou', 'Lutou', 'Lutou,Lutou Zhen,lu tou,lu tou zhen,芦头,芦头镇', 37.6116500, 120.4592000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26971, 'Daqinjia', 'Daqinjia', 'Daqinjia,Daqinjia Zhen,da qin jia,da qin jia zhen,大秦家,大秦家镇', 37.3587900, 120.4568600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26972, 'Linglong', 'Linglong', 'Linglong,Linglong Zhen,ling long,ling long zhen,玲珑,玲珑镇', 37.4057900, 120.4709100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26973, 'Fushan', 'Fushan', 'Fushan,Fushan Zhen,fu shan,fu shan zhen,阜山,阜山镇', 37.3984800, 120.5577100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26974, 'Xiadian', 'Xiadian', 'Xiadian,Xiadian Zhen,xia dian,xia dian zhen,夏甸,夏甸镇', 37.1888400, 120.3774200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26975, 'Qicai', 'Qicai', 'Qicai,Qicai Zhen,qi cai,qi cai zhen,齐才,齐才镇', 37.2440200, 120.3525000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26976, 'Jinling', 'Jinling', 'Jinling,Jinling Zhen,jin ling,jin ling zhen,金岭,金岭镇', 37.3980700, 120.2970300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26977, 'Huanghuatala', 'Huanghuatala', 'Huanghuatala,Huanghuatala Zhen,huang hua ta la,huang hua ta la zhen,黄花塔拉,黄花塔拉镇', 42.6571600, 120.7768700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26978, 'Yilongyong', 'Yilongyong', 'Yilongyong,Yilongyong Zhen,yi long yong,yi long yong zhen,义隆永,义隆永镇', 42.6398300, 120.6475500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26979, 'Longmen', 'Longmen', 'Longmen,Longmen Xiang,long men,long men xiang,龙门,龙门乡', 37.8777600, 98.9231300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26980, 'Baga Borihe', 'Baga Borihe', 'Baga Borihe,Baga Borihe Sumu,ba ga bo ri he,ba ga bo ri he su mu,巴嘎波日和,巴嘎波日和苏木', 42.9255500, 120.5599000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26981, 'Kekeli', 'Kekeli', 'Kekeli,Kekeli Xiang,ke ke li,ke ke li xiang,柯柯里,柯柯里乡', 38.3834300, 99.3117900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26982, 'Yanglong', 'Yanglong', 'Yanglong,Yanglong Xiang,yang long,yang long xiang,央隆,央隆乡', 38.8076100, 98.4341800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26983, 'Longyangxia', 'Longyangxia', 'Longyangxia,Longyangxia Zhen,long yang xia,long yang xia zhen,龙羊峡,龙羊峡镇', 36.1282200, 100.8952100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26984, 'Tiegai', 'Tiegai', 'Tiegai,Tiegai Xiang,tie gai,tie gai xiang,铁盖,铁盖乡', 36.1828700, 100.6913900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26985, 'Gandi', 'Gandi', 'Gandi,Gandi Xiang,gan de,gan de xiang,甘地,甘地乡', 36.3994800, 100.3605600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26986, 'Yingde’er', 'Yingde''er', 'Yingde''er,Yingde''er Xiang,Yingde’er,Yingde’er Xiang,ying de er,ying de er xiang,英德尔,英德尔乡', 36.4063800, 100.1892300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26987, 'Qiangma', 'Qiangma', 'Qiangma,Qiangma Zhen,qiang ma,qiang ma zhen,强玛,强玛镇', 31.9764300, 90.8449500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26988, 'Riyue', 'Riyue', 'Riyue,Riyue Zangzu Xiang,ri yue,ri yue cang zu xiang,日月,日月藏族乡', 36.5378200, 101.1536700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26989, 'Tawan', 'Tawan', 'Tawan,Tawan Xiang,ta wan,ta wan xiang,塔湾,塔湾乡', 36.6894600, 101.1108400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26990, 'Dahua', 'Dahua', 'Dahua,Dahua Zhen,da hua,da hua zhen,大华,大华镇', 36.6929000, 101.2127500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26991, 'Dongxia', 'Dongxia', 'Dongxia,Dongxia Xiang,dong xia,dong xia xiang,东峡,东峡乡', 36.6820700, 101.3259800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26992, 'Heping', 'Heping', 'Heping,Heping Xiang,he ping,he ping xiang,和平,和平乡', 36.6348100, 101.2398300, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26993, 'Sizhai', 'Sizhai', 'Sizhai,Sizhai Xiang,si zhai,si zhai xiang,寺寨,寺寨乡', 36.7426300, 101.0271500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26994, 'Beihe', 'Beihe', 'Beihe,Beihe Zhen,bei he,bei he zhen,北和,北和镇', 36.5905000, 101.4274000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26995, 'Ganhetan', 'Ganhetan', 'Ganhetan,Ganhetan Zhen,gan he tan,gan he tan zhen,甘河滩,甘河滩镇', 36.5023800, 101.5042000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26996, 'Lanlongkou', 'Lanlongkou', 'Lanlongkou,Lanlongkou Zhen,lan long kou,lan long kou zhen,拦隆口,拦隆口镇', 36.7692100, 101.4746600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26997, 'Lijiashan', 'Lijiashan', 'Lijiashan,Lijiashan Zhen,li jia shan,li jia shan zhen,李家山,李家山镇', 36.7982600, 101.5494900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26998, 'Haizigou', 'Haizigou', 'Haizigou,Haizigou Xiang,hai zi gou,hai zi gou xiang,海子沟,海子沟乡', 36.7066900, 101.6381100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(26999, 'Xiaoxia', 'Xiaoxia', 'Xiaoxia,Xiaoxia Zhen,xiao xia,xiao xia zhen,小峡,小峡镇', 36.5309300, 101.9674600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27000, 'Sanhe', 'Sanhe', 'Sanhe,Sanhe Zhen,san he,san he zhen,三合,三合镇', 36.4224200, 101.9295500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27001, 'Sitai', 'Sitai', 'Sitai,Sitai Xiang,si tai,si tai xiang,寺台,寺台乡', 36.3675700, 101.9303500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27002, 'Shihuiyao', 'Shihuiyao', 'Shihuiyao,Shihuiyao Huizu Xiang,shi hui yao,shi hui yao hui zu xiang,石灰窑,石灰窑回族乡', 36.3828900, 101.8803400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27003, 'Hongshuiquan', 'Hongshuiquan', 'Hongshuiquan,Hongshuiquan Huizu Xiang,hong shui quan,hong shui quan hui zu xiang,洪水泉,洪水泉回族乡', 36.4643700, 101.8823500, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27004, 'Gucheng', 'Gucheng', 'Gucheng,Gucheng Huizu Xiang,gu cheng,gu cheng hui zu xiang,古城,古城回族乡', 36.3574800, 101.9948900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27005, 'Nanmenxia', 'Nanmenxia', 'Nanmenxia,Nanmenxia Zhen,nan men xia,nan men xia zhen,南门峡,南门峡镇', 36.9907700, 101.9073600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27006, 'Wufeng', 'Wufeng', 'Wufeng,Wufeng Xiang,wu feng,wu feng xiang,五峰,五峰乡', 36.8718800, 101.8498600, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27007, 'Xishan', 'Xishan', 'Xishan,Xishan Xiang,xi shan,xi shan xiang,西山,西山乡', 36.7755100, 101.8488400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27008, 'Jingyang', 'Jingyang', 'Jingyang,Jingyang Zhen,jing yang,jing yang zhen,景阳,景阳镇', 36.8171000, 101.6510100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27009, 'Changning', 'Changning', 'Changning,Changning Zhen,zhang ning,zhang ning zhen,长宁,长宁镇', 36.8292800, 101.7402900, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27010, 'Huangjiazhai', 'Huangjiazhai', 'Huangjiazhai,Huangjiazhai Zhen,huang jia zhai,huang jia zhai zhen,黄家寨,黄家寨镇', 36.8678300, 101.7129000, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27011, 'Duolin', 'Duolin', 'Duolin,Duolin Zhen,duo lin,duo lin zhen,多林,多林镇', 37.0717400, 101.4552200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27012, 'Sujitan', 'Sujitan', 'Sujitan,Sujitan Xiang,su ji tan,su ji tan xiang,苏吉滩,苏吉滩乡', 37.5211600, 101.1995700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27013, 'Huangcheng', 'Huangcheng', 'Huangcheng,Huangcheng Mengguzu Xiang,huang cheng,huang cheng meng gu zu xiang,皇城,皇城蒙古族乡', 37.6094200, 101.2005800, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27014, 'Mawu', 'Mawu', 'Mawu,Mawu Xiang,ma wu,ma wu xiang,马武,马武乡', 30.9122100, 95.1904400, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27015, 'Gamei', 'Gamei', 'Gamei,Gamei Xiang,ga mei,ga mei xiang,嘎美,嘎美乡', 31.7475900, 94.2836200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27016, 'Chiduo', 'Chiduo', 'Chiduo,Chiduo Xiang,chi duo,chi duo xiang,赤多,赤多乡', 31.5083600, 94.0606100, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27017, 'Nierong', 'Nierong', 'Nierong,Nierong Zhen,nie rong,nie rong zhen,聂荣,聂荣镇', 32.1130900, 92.2957200, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27018, 'Cuozheqiangma', 'Cuozheqiangma', 'Cuozheqiangma,cuo zhe qiang ma,措折强玛', 33.3098700, 87.7546700, 'CN', '2013-07-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27019, 'Xingcheng', 'Xingcheng', 'Xingcheng,Xingcheng Zhen,Xingning,Xingning Shi,xing cheng,xing cheng zhen,xing ning,xing ning shi,兴城,兴城镇,兴宁,兴宁市', 24.1483000, 115.7227200, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27020, 'Shangmachang', 'Shangmachang', 'Shangmachang,Shangmachang Xiang,shang ma chang,shang ma chang xiang,上马场,上马场乡', 50.3719100, 127.3271700, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27021, 'Yangping', 'Yangping', 'Yangping,Yangping Zhen,yang ping,yang ping zhen,羊平,羊平镇', 38.5281000, 114.7080200, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27022, 'Qijiazuo', 'Qijiazuo', 'Qijiazuo,Qijiazuo Xiang,qi jia zuo,qi jia zuo xiang,齐家佐,齐家佐乡', 38.9311300, 114.8389600, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27023, 'Anning Xilu', 'Anning Xilu', 'Anning Qu,Anning Xilu,an ning qu,an ning xi lu,安宁区,安宁西路', 36.1035000, 103.7192800, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27024, 'Zhangyelu', 'Zhangyelu', 'Chengguan Qu,Zhangyelu,cheng guan qu,zhang ye lu,城关区,张掖路', 36.0575200, 103.8226900, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27025, 'Xihu', 'Xihu', 'Qilihe Qu,Xihu,qi li he qu,xi hu,七里河区,西湖', 36.0673500, 103.7765400, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27026, 'Dongdajie', 'Dongdajie', 'Dongdajie,Liangzhou Qu,dong da jie,liang zhou qu,东大街,凉州区', 37.9268600, 102.6343000, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27027, 'Renminlu', 'Renminlu', 'Baiyin Qu,Renminlu,bai yin qu,ren min lu,人民路,白银区', 36.5512000, 104.1695200, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27028, 'Xingpinglu', 'Xingpinglu', 'Pingchuan Qu,Xingpinglu,ping chuan qu,xing ping lu,兴平路,平川区', 36.7275200, 104.8137900, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27029, 'Guangzhoulu', 'Guangzhoulu', 'Guangzhoulu,Jinchuan Qu,guang zhou lu,jin chuan qu,广州路,金川区', 38.4991500, 102.1680900, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27030, 'Binhe', 'Binhe', 'Binhe,Shapotou Qu,bin he,sha po tou qu,沙坡头区,滨河', 37.5108400, 105.1844500, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27031, 'Shengli', 'Shengli', 'Litong Qu,Shengli,li tong qu,sheng li,利通区,胜利', 37.9842500, 106.1965900, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27032, 'Beijie', 'Beijie', 'Beijie,Huinong Qu,bei jie,hui nong qu,北街,惠农区', 39.2226400, 106.7657900, 'CN', '2013-08-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27033, 'Sangpi', 'Sangpi', 'Sangpi,Sangpi Zhen,Xiangcheng,sang pi,sang pi zhen,xiang cheng,乡城,桑披,桑披镇', 28.9339100, 99.7999100, 'CN', '2013-09-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27034, 'Tantang', 'Tantang', 'Tantang,Tantang Zhen,qin tang,qin tang zhen,覃塘,覃塘镇', 23.1368400, 109.4131400, 'CN', '2013-10-11', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27035, 'Nanchangshan', 'Nanchangshan', 'Nanchangshan,Nanchangshan Zhen,nan zhang shan,nan zhang shan zhen,南长山,南长山镇', 37.9304900, 120.7290800, 'CN', '2014-10-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27036, 'Tianmen', 'Tianmen', 'TMV,Tianmen', 30.6588800, 113.1536900, 'CN', '2013-11-23', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27037, 'Zhijin', 'Zhijin', 'Zhijin,Zhijin Chengguanzhen,zhi jin,zhi jin cheng guan zhen,织锦,织锦城关镇', 26.6668000, 105.7680000, 'CN', '2014-02-16', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27038, 'Changjianglu Jiedao', 'Changjianglu Jiedao', 'Changjianglu Jiedao,zhang jiang lu jie dao,长江路街道', 35.9660000, 120.1731700, 'CN', '2014-02-17', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27039, 'Dongping', 'Dongping', 'Dongping,Dongping Zhen,dong ping,dong ping zhen,东坪,东坪镇', 36.4990000, 117.9960000, 'CN', '2014-10-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27040, 'Jianshelu', 'Jianshelu', 'Jianshelu,Zhongyuan,Zhongyuan Xiang,jian she lu,zhong yuan,zhong yuan xiang,中原,中原乡,建设路', 34.7534000, 113.6060000, 'CN', '2015-06-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27041, 'Ganhechen', 'Ganhechen', 'Ganhechen,Ganhechen Xiang,gan he chen,gan he chen xiang,干河陈,干河陈乡', 33.5582000, 114.0200000, 'CN', '2015-06-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27042, 'Dizhuang', 'Dizhuang', 'Dizhuang,Dizhuang Xiang,di zhuang,di zhuang xiang,翟庄,翟庄乡', 33.5645200, 114.0696500, 'CN', '2015-06-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27043, 'Chuansiba', 'Chuansiba', 'Chuansi,Chuansi Xiang,Chuansiba,chuan si ba,chuan si xiang,串丝乡,串丝坝', 28.3196500, 104.1295800, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27044, 'Zhonghechang', 'Zhonghechang', 'Zhonghe,Zhonghe Zhen,Zhonghechang,zhong he chang,zhong he zhen,中和场,中和镇', 28.1538000, 104.0983500, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27045, 'Tantouchang', 'Tantouchang', 'Tantou,Tantou Xiang,Tantouchang,tan tou chang,tan tou xiang,滩头乡,滩头场', 28.3092400, 104.2846700, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27046, 'Doushaguan', 'Doushaguan', 'Dousha,Dousha Zhen,Doushaguan,dou sha guan,dou sha zhen,豆沙关,豆沙镇', 28.0479700, 104.1271500, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27047, 'Shiziba', 'Shiziba', 'Shizi,Shizi Xiang,Shiziba,shi zi ba,shi zi xiang,柿子乡,柿子坝', 27.9796200, 104.1805900, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27048, 'Xinglongchang', 'Xinglongchang', 'Xinglong,Xinglong Xiang,Xinglongchang,xing long chang,xing long xiang,兴隆乡,兴隆场', 28.2663300, 104.3890500, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27049, 'Niupizhai', 'Niupizhai', 'Niupizhai,niu pi zhai,牛皮寨', 28.1115200, 104.3814100, 'CN', '2014-03-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27050, 'Gangba', 'Gangba', 'Gangba,Gangba Zhen,gang ba,gang ba zhen,岗巴,岗巴镇', 28.2166000, 88.4743000, 'CN', '2014-04-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27051, 'Jibenggang', 'Jibenggang', 'Jebumgang,Jibenggang,Jibenggang Jiedao,Jêbumgang,ji beng gang,ji beng gang jie dao,ར་འབམ་སང,རྗེ་འབུམ་སྒང,吉崩岗,吉崩岗街道', 29.6583000, 91.1276000, 'CN', '2015-01-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27052, 'Gangsha', 'Gangsha', 'Gangsha,gang sha,岗沙', 30.9770000, 81.2875000, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27053, 'Alatan''molezhen', 'Alatan''molezhen', 'Altan Emel', 48.6642600, 116.8112200, 'CN', '2016-08-21', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27054, 'Yulong', 'Yulong', 'Tinghu,Yulong,ting hu,yu long,亭湖,毓龙', 33.3832400, 120.1305800, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27055, 'Nu’erbage', 'Nu''erbage', 'Hetian Shi,Nu''erbage,Nu''erbage Jiedao,Nu’erbage,Nu’erbage Jiedao,he tian shi,nu er ba ge,nu er ba ge jie dao,努尔巴格,努尔巴格街道,和田市', 37.1134000, 79.9103400, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27056, 'Wanhechang', 'Wanhechang', 'Wanhe,Wanhe Xiang,Wanhechang,wan he,wan he chang,wan he xiang,万和,万和乡,万和场', 27.7759300, 103.5094600, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27057, 'Pengjia Zhaizi', 'Pengjia Zhaizi', 'Pengjia Zhaizi,Wuzhai,Wuzhai Yizu Miaozu Xiang,peng jia zhai zi,wu zhai,wu zhai yi zu miao zu xiang,伍寨,伍寨彝族苗族乡,彭家寨子', 27.6083000, 103.5271000, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27058, 'Shuizhulin', 'Shuizhulin', 'Shuizhu,Shuizhu Xiang,Shuizhulin,shui zhu,shui zhu lin,shui zhu xiang,水竹,水竹乡,水竹林', 27.9444900, 103.6744200, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27059, 'Moshiyi', 'Moshiyi', 'Mohan,Mohan Zhen,Moshiyi,mo han,mo han zhen,mo shi yi,墨石驿,墨翰,墨翰镇', 27.8277000, 103.7282800, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27060, 'Changping', 'Changping', 'Changping,Tuanjie,Tuanjie Xiang,tuan jie,tuan jie xiang,zhang ping,团结,团结乡,长坪', 28.2078300, 103.8549900, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27061, 'Xishaqiao', 'Xishaqiao', 'Xisha,Xisha Xiang,Xishaqiao,xi sha,xi sha qiao,xi sha xiang,细沙,细沙乔,细沙乡', 28.3025100, 103.9848200, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27062, 'Nahaping', 'Nahaping', 'Nahaping,Qingsheng,Qingsheng Xiang,na ha ping,qing sheng,qing sheng xiang,哪哈坪,青胜,青胜乡', 28.4317700, 103.8578300, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27063, 'Shangtianba', 'Shangtianba', 'Gaoqiao,Gaoqiao Xiang,Shangtianba,gao qiao,gao qiao xiang,shang tian ba,上田坝,高桥,高桥乡', 28.0312300, 103.8618300, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27064, 'Xincun', 'Xincun', 'Xincun,Yuwan,Yuwan Zhen,xin cun,yu wan,yu wan zhen,新村,玉碗,玉碗镇', 27.6717800, 103.8698900, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27065, 'Tianxingchang', 'Tianxingchang', 'Tianxing,Tianxing Zhen,Tianxingchang,tian xing,tian xing chang,tian xing zhen,天星,天星场,天星镇', 27.8422900, 103.9824200, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27066, 'Yuelejie', 'Yuelejie', 'Yuele,Yuele Xiang,Yuelejie,yue le,yue le jie,yue le xiang,悦乐,悦乐乡,悦乐街', 27.8269300, 103.7830700, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27067, 'Huanggexi', 'Huanggexi', 'Huangge,Huangge Xiang,Huanggexi,huang ge,huang ge xi,huang ge xiang,黄葛,黄葛乡,黄葛溪', 27.8541400, 103.8610500, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27068, 'Xiaohebian', 'Xiaohebian', 'Qinglong,Qinglong Xiang,Xiaohebian,qing long,qing long xiang,xiao he bian,小河边,青龙,青龙乡', 27.7276300, 103.9951400, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27069, 'Tiexianxi', 'Tiexianxi', 'Shoushan,Shoushan Xiang,Tiexianxi,shou shan,shou shan xiang,tie xian xi,寿山,寿山乡,铁线溪', 27.9119300, 103.8893900, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27070, 'Huangjingba', 'Huangjingba', 'Huangjingba,Jili,Jili Zhen,huang jing ba,ji li,ji li zhen,吉利,吉利镇,黄荆坝', 28.0136300, 103.9985500, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27071, 'Qiaoshang', 'Qiaoshang', 'Gaotian,Gaotian Xiang,Qiaoshang,gao tian,gao tian xiang,qiao shang,桥上,高田,高田乡', 27.9427400, 105.1648400, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27072, 'Zoumachang', 'Zoumachang', 'Shuanghe,Shuanghe Miaozu Yizu Xiang,Zoumachang,shuang he,shuang he miao zu yi zu xiang,zou ma chang,双河,双河苗族彝族乡,走马厂', 27.8713200, 105.2010500, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27073, 'Langjiu', 'Langjiu', 'Langjiu,lang jiu,朗久', 32.3594800, 80.4268000, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27074, 'Jisegumen', 'Jisegumen', 'Jisegumen,ji se gu men,吉色古门', 34.0642000, 80.7712000, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27075, 'Zhongba', 'Zhongba', 'Luobu,Luobu Xiang,Zhongba,luo bu,luo bu xiang,zhong ba,中坝,罗布,罗布乡', 27.9542600, 105.0403800, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27076, 'Shuiying', 'Shuiying', 'Miaogou,Miaogou Xiang,Shuiying,miao gou,miao gou xiang,shui ying,庙沟,庙沟乡,水营', 27.8101300, 104.7984000, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27077, 'Yujiazhai', 'Yujiazhai', 'Chang''an,Chang''an Xiang,Chang’an,Chang’an Xiang,Yujiazhai,yu jia zhai,zhang an,zhang an xiang,余家寨,长安,长安乡', 27.8415300, 104.8249100, 'CN', '2014-05-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27078, 'Sankoutang', 'Sankoutang', 'Sankoutang,Santao,Santao Xiang,san kou tang,san tao,san tao xiang,三口塘,三桃,三桃乡', 27.9127300, 104.9504700, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27079, 'Shuitianzhai', 'Shuitianzhai', 'Shuitian,Shuitian Xiang,Shuitianzhai,shui tian,shui tian xiang,shui tian zhai,水田,水田乡,水田寨', 27.7643300, 105.2515800, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27080, 'Qingfenglin', 'Qingfenglin', 'Qingfenglin,Shikan,Shikan Xiang,qing feng lin,shi kan,shi kan xiang,石坎,石坎乡,青枫林', 27.7877700, 105.1457300, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27081, 'Xiangyang', 'Xiangyang', 'Mashu,Mashu Zhen,Xiangyang,ma shu,ma shu zhen,xiang yang,向阳,马树,马树镇', 26.7599100, 103.2539500, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27082, 'Shanjiao', 'Shanjiao', 'Dongping,Dongping Xiang,Shanjiao,dong ping,dong ping xiang,shan jiao,东坪,东坪乡,山脚', 27.3223000, 103.0684400, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27083, 'Jiecun', 'Jiecun', 'Jiecun,Maozu,Maozu Xiang,jie cun,mao zu,mao zu xiang,茂租,茂租乡,街村', 27.3557200, 102.9827100, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27084, 'Shuigou', 'Shuigou', 'Shuigou,Zhongzhai,Zhongzhai Xiang,shui gou,zhong zhai,zhong zhai xiang,中寨,中寨乡,水沟', 26.9380900, 103.0395600, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27085, 'Laodianzi', 'Laodianzi', 'Laodian,Laodian Xiang,Laodianzi,lao dian,lao dian xiang,lao dian zi,老店,老店乡,老店子', 26.9308200, 103.2921700, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27086, 'Jiezi', 'Jiezi', 'Jiezi,Jintang,Jintang Xiang,jie zi,jin tang,jin tang xiang,街子,金塘,金塘乡', 26.7893500, 102.9918900, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27087, 'Laojiezi', 'Laojiezi', 'Chongxi,Chongxi Xiang,Laojiezi,chong xi,chong xi xiang,lao jie zi,崇溪,崇溪乡,老街子', 26.8646100, 103.1371200, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27088, 'Sanguanzhai', 'Sanguanzhai', 'Sanguanzhai,Xindian,Xindian Xiang,san guan zhai,xin dian,xin dian xiang,三官寨,新店,新店乡', 27.1076600, 103.2565700, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27089, 'Laofangzi', 'Laofangzi', 'Laofangzi,Lufang,Lufang Xiang,lao fang zi,lu fang,lu fang xiang,炉房,炉房乡,老房子', 26.6716500, 103.1882500, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27090, 'Laojie', 'Laojie', 'Laojie,Menggu,Menggu Xiang,lao jie,meng gu,meng gu xiang,老街,蒙姑,蒙姑乡', 26.5769600, 103.0469800, 'CN', '2014-05-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27091, 'Rizhao', 'Rizhao', 'Jit-chiau-chhi,Ji̍t-chiàu-chhī,Nhat Chieu,Nhật Chiếu,Nik-cieu,Nĭk-ciéu,RIZ,Rizhao,Rizhao Shi,Z''-cao,Zhichzhao,Zhidzao,Zhudzhao,leujao si,ri zhao,ri zhao shi,ryzhaw,Ž’-čao,Жичжао,Жиџао,Жъджао,ریژاو,日照,日照市,르자오 시', 35.3957900, 119.5321700, 'CN', '2016-03-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27092, 'Daliyuan', 'Daliyuan', 'Daliyuan,Xiaozhai,Xiaozhai Xiang,da li yuan,xiao zhai,xiao zhai xiang,大梨园,小寨,小寨乡', 27.1837100, 103.4864200, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27093, 'Guji', 'Guji', 'Guji,Lehong,Lehong Xiang,gu ji,le hong,le hong xiang,乐红,乐红乡,古吉', 27.1695600, 103.2843000, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27094, 'Shuigou’ao', 'Shuigou''ao', 'Cuiping,Cuiping Xiang,Shuigou''ao,Shuigou’ao,cui ping,cui ping xiang,shui gou ao,水沟坳,翠屏,翠屏乡', 27.1191300, 103.3533700, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27095, 'Xiaotiechang', 'Xiaotiechang', 'Luna,Luna Xiang,Xiaotiechang,lu na,lu na xiang,xiao tie chang,小铁厂,鲁纳,鲁纳乡', 26.2837700, 103.6386000, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27096, 'Dasongshu', 'Dasongshu', 'Dasongshu,Shangcun,Shangcun Xiang,da song shu,shang cun,shang cun xiang,上村,上村乡,大松树', 26.1368500, 103.5733600, 'CN', '2014-06-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27097, 'Shanzidi', 'Shanzidi', 'Shanzidi,Wuxing,Wuxing Xiang,shan zi de,wu xing,wu xing xiang,五星,五星乡,扇子地', 26.5538400, 103.2604500, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27098, 'Chenggan', 'Chenggan', 'Chenggan,Xueshan,Xueshan Xiang,cheng gan,xue shan,xue shan xiang,称杆,雪山,雪山乡', 26.1454300, 102.8030100, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27099, 'Pujiawan', 'Pujiawan', 'Pujiawan,Tanglang,Tanglang Xiang,pu jia wan,tang lang,tang lang xiang,普家湾,汤郎,汤郎乡', 26.1854800, 102.2914900, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27100, 'Jiaoxiyakou', 'Jiaoxiyakou', 'Jiaoxi,Jiaoxi Xiang,Jiaoxiyakou,jiao xi,jiao xi xiang,jiao xi ya kou,胶西,胶西乡,胶西垭口', 26.1282900, 102.4500300, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27101, 'Laojiezi', 'Laojiezi', 'Laojiezi,Malutang,Malutang Xiang,lao jie zi,ma lu tang,ma lu tang xiang,老街子,马鹿塘,马鹿塘乡', 26.1487000, 102.5592000, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27102, 'Kaji', 'Kaji', 'Kaji,Wumeng,Wumeng Xiang,ka ji,wu meng,wu meng xiang,乌蒙,乌蒙乡,卡机', 26.0284900, 102.7888400, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27103, 'Maoshanjie', 'Maoshanjie', 'Maoshan,Maoshan Xiang,Maoshanjie,mao shan,mao shan jie,mao shan xiang,茂山,茂山乡,茂山街', 25.6677600, 102.4990600, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27104, 'Xiaopingba', 'Xiaopingba', 'Chongde,Chongde Xiang,Xiaopingba,chong de,chong de xiang,xiao ping ba,小平坝,崇德,崇德乡', 25.4948600, 102.5122600, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27105, 'Muzeng', 'Muzeng', 'Muzeng,Shuanghua,Shuanghua Xiang,mu zeng,shuang hua,shuang hua xiang,双化,双化乡,木增', 26.0524100, 102.4792700, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27106, 'Machang', 'Machang', 'Dongshan,Dongshan Zhen,Machang,dong shan,dong shan zhen,ma chang,东山,东山镇,马场', 26.1079000, 104.2680200, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27107, 'Zhujiacun', 'Zhujiacun', 'Geyi,Geyi Zhen,Zhujiacun,ge yi,ge yi zhen,zhu jia cun,朱家村,格宜,格宜镇', 26.3204100, 104.3957100, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27108, 'Jianxincun', 'Jianxincun', 'Bole,Bole Xiang,Jianxincun,bo le,bo le xiang,jian xin cun,建新村,播乐,播乐乡', 25.8389200, 104.1195200, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27109, 'Zhabu', 'Zhabu', 'Zhabu,zha bu,扎布', 33.1189000, 83.3038000, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27110, 'Pingpo', 'Pingpo', 'Pingpo,ping po,平坡', 25.4283700, 103.7545500, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27111, 'Xicheng', 'Xicheng', 'Mudan,Xicheng,mu dan,xi cheng,牡丹,西城', 35.2461600, 115.4333600, 'CN', '2014-06-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27112, 'Puyang', 'Puyang', 'Boc Duong,Buk-iong,Bŭk-iòng,Bộc Dương,Pchu-jang,Phok-iong-chhi,Phok-iông-chhī,Pujan,Pujang,Puyang,pu yang,pu yang shi,puyang si,pwyang,Пуян,Пујанг,پویانگ,濮阳,濮阳市,濮陽,濮陽市,푸양 시', 35.7631800, 115.0172100, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27113, 'Fan Xian Chengguanzhen', 'Fan Xian Chengguanzhen', 'Fan Xian,Fan Xian Chengguanzhen,fan xian,fan xian cheng guan zhen,范县,范县城关镇', 35.8581300, 115.5005600, 'CN', '2015-06-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27114, 'Dong Liang’erzhuang', 'Dong Liang''erzhuang', 'Dong Liang''erzhuang,Dong Liang’erzhuang,Erzhuang,Erzhuang Xiang,dong liang er zhuang,er zhuang,er zhuang xiang,东梁二庄,二庄,二庄乡', 36.7271100, 115.2556800, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27115, 'Chensan', 'Chensan', 'Chencun,Chencun Huizu Xiang,Chensan,chen cun,chen cun hui zu xiang,chen san,陈三,陈村,陈村回族乡', 36.7366700, 115.1343200, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27116, 'Dongluqiao', 'Dongluqiao', 'Dongluqiao,Luqiao,Luqiao Xiang,dong lu qiao,lu qiao,lu qiao xiang,东路桥,路桥,路桥乡', 36.6814900, 115.3408500, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27117, 'Gulou', 'Gulou', 'Dongchangfu,Dongchangfu Qu,Gulou,dong chang fu,dong chang fu qu,gu lou,东昌府,东昌府区,古楼', 36.4441400, 115.9641800, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27118, 'Gaobeijie', 'Gaobeijie', 'Gaobeijie,Hexi,Hexi Zhen,gao bei jie,he xi,he xi zhen,河西,河西镇,高北街', 36.8579800, 115.6828200, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27119, 'Liuzhuang', 'Liuzhuang', 'Liuzhuang,liu zhuang,柳庄', 37.0042800, 115.7740000, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27120, 'Xiying', 'Xiying', 'Xiying,Yingzhen,Yingzhen Huizu Xiang,xi ying,ying zhen,ying zhen hui zu xiang,英镇,英镇回族乡,西营', 36.4487900, 115.2944500, 'CN', '2014-07-10', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27121, 'Gumudi', 'Gumudi', 'Gumudi,Midong,Midong Qu,gu mu de,mi dong,mi dong qu,古木地,米东,米东区', 43.9548600, 87.6730900, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27122, 'Huoche Xizhan', 'Huoche Xizhan', 'Huoche Xizhan,Toutunhe,Toutunhe Qu,huo che xi zhan,tou tun he,tou tun he qu,头屯河,头屯河区,火车西站', 43.8714100, 87.4201800, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27123, 'Xingfulu', 'Xingfulu', 'Tianshan,Tianshan Qu,Xingfulu,tian shan,tian shan qu,xing fu lu,天山,天山区,幸福路', 43.7824600, 87.6368200, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27124, 'Yangzi Jianglu', 'Yangzi Jianglu', 'Saybagh,Saybagh Qu,Shayibake,Yangzi Jianglu,sha yi ba ke,sha yi ba ke qu,yang zi jiang lu,扬子江路,沙依巴克,沙依巴克区', 43.7733200, 87.5887900, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27125, 'Beijinglu', 'Beijinglu', 'Beijinglu,Xinshi,Xinshi Qu,bei jing lu,xin shi,xin shi qu,北京路,新市,新市区', 43.8344500, 87.5765200, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27126, 'Hekou', 'Hekou', 'Hekou,he kou,河口', 37.8846400, 118.5266400, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27127, 'Xinhu', 'Xinhu', 'Decheng Qu,Xinhu,de cheng qu,xin hu,德城区,新湖', 37.4464200, 116.2972700, 'CN', '2014-08-07', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27128, 'Chengguan', 'Chengguan', 'Chengguan,Chengguan Zhen,cheng guan,cheng guan zhen,城关,城关镇', 35.3093500, 115.1188100, 'CN', '2014-10-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27129, 'Guangrao', 'Guangrao', 'Guangrao,Guangrao Xiang,guang rao,guang rao xiang,广饶,广饶乡', 37.2596900, 118.4634500, 'CN', '2014-10-04', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27130, 'Hujirti', 'Hujirti', 'Huji''erte Mengguzu Xiang,Qujirti,Qujırtı,hu ji er te meng gu zu xiang,呼吉尔特蒙古族乡', 43.2273200, 81.8920900, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27131, 'Xorbulak', 'Xorbulak', 'Sorbulaq,Xiao''erbulake,shwrbۇlaq,xiao er bu la ke,شوربۇلاق,肖尔布拉克', 43.4500500, 82.9591400, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27132, 'Türgen', 'Tuergen', 'Tu''ergen,tu er gen,tۈrgېn,تۈرگېن,吐尔根', 43.5107100, 83.4597000, 'CN', '2015-01-01', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27133, 'Zekti', 'Zekti', 'Zeketai,ze ke tai,zېkty,زېكتى,则克台', 43.5368200, 83.2786400, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27134, 'Taxkowrük', 'Taxkowruek', 'Tashikuleke,ta shen ku lei ke,tashkۆvrۈk,تاشكۆۋرۈك,塔什库勒克', 43.8925700, 81.3060400, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27135, 'Yengiyar', 'Yengiyar', 'Yingye''er,ying ye er,yېngyyەr,يېڭىيەر,英也尔', 43.9661200, 81.1550200, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27136, 'Turpanyüzi', 'Turpanyuezi', 'Tulufanyuzi,tu lu fan yu zi,tۇrpanyۈzy,تۇرپانيۈزى,吐鲁番于孜', 43.9987400, 81.4786400, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27137, 'Sadikyüzi', 'Sadikyuezi', 'Sadikeyuzi,sa de ke yu zi,sadyqyۈzy,سادىقيۈزى,萨地克于孜', 43.9281300, 81.5558900, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27138, 'Onyar', 'Onyar', 'Wenya''er,wen ya er,ywnyar,ئونيار,温亚尔', 43.8503700, 81.7830800, 'CN', '2015-01-02', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27139, 'Beidaihe', 'Beidaihe', 'BPE,Beidaihe,bei dai he,北戴河', 39.8322700, 119.4843900, 'CN', '2015-12-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27140, 'Bengshutang', 'Bengshutang', 'Bengshutang,Nixi,Nixi Xiang,beng shu tang,ni xi,ni xi xiang,尼西,尼西乡,崩书塘', 28.0366400, 99.5083500, 'CN', '2015-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27141, 'Lazanzhong', 'Lazanzhong', 'Gezan,Gezan Xiang,Lazanzhong,ge zan,ge zan xiang,la zan zhong,拉咱仲,格咱,格咱乡', 28.2212400, 99.7322400, 'CN', '2015-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27142, 'Baiyu', 'Baiyu', 'Baiyu,Dongwang,Dongwang Xiang,bai yu,dong wang,dong wang xiang,东旺,东旺乡,白玉', 28.5766300, 99.6720200, 'CN', '2015-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27143, 'Shuijia', 'Shuijia', 'Sanba,Sanba Naxizhu Xiang,Shuijia,san ba,san ba na xi zu xiang,shui jia,三坝,三坝纳西族乡,水甲', 27.4880900, 100.0632100, 'CN', '2015-02-08', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27144, 'Yanji', 'Yanji', 'Yanji,Yanji Zhen,yan ji,yan ji zhen,演集,演集镇', 33.9653000, 116.4510000, 'CN', '2015-06-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27145, 'Changyuan County', 'Changyuan County', '', 35.2125000, 114.7350000, 'CN', '2015-06-19', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27146, 'Xuzhou', 'Xuzhou', 'Pengcheng,Sjujchzhou,XUZ,Xuzhou,shwzhw,swijeou si,xu zhou,xu zhou shi,Сюйчжоу,شوژو,徐州,徐州市,쉬저우 시', 34.2044200, 117.2838600, 'CN', '2015-08-30', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27147, 'Lianyungang', 'Lianyungang', 'LYG,Lianyungang,Liányúngǎng,Ljan''jun''gan,lian yun gang,lyen-wingang si,Ляньюньган,连云港,連雲港,롄윈강 시', 34.5984500, 119.2155600, 'CN', '2015-10-25', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27148, 'Baoji', 'Baoji', 'Baoczi,Baoji,Bǎojī,PJI,bao ji,bao ji shi,baoji si,bawzhy,Баоцзи,باوژی,宝鶏市,宝鸡,寶雞,바오지 시', 34.3677500, 107.2370500, 'CN', '2016-07-29', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27149, 'Dongtaicun', 'Dongtaicun', 'Dongtaicun,Heishui Zhen,dong tai cun,hei shui zhen,东台村,黑水镇', 42.0716000, 119.4218300, 'CN', '2016-01-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27150, 'Miaodong', 'Miaodong', 'Lingbei Zhen,Miaodong,ling bei zhen,miao dong,凌北镇,庙东', 41.2807300, 119.4355300, 'CN', '2016-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27151, 'Nanjie', 'Nanjie', 'Nanjie,Sanshijiazi Zhen,nan jie,san shi jia zi zhen,三十家子镇,南街', 41.0179400, 119.0522300, 'CN', '2016-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27152, 'Beiyingzi', 'Beiyingzi', 'Beiyingzi,Dao''erdeng Zhen,Dao’erdeng Zhen,bei ying zi,dao er deng zhen,刀尔登镇,北营子', 40.7606900, 119.1178600, 'CN', '2016-04-12', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27153, 'Nongchangbalian', 'Nongchangbalian', 'Nongchangbalian,nong chang ba lian,农场八连', 36.3656300, 109.6224000, 'CN', '2017-01-06', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27154, 'Renhuai', 'Renhuai', 'Renhuai,WMT,ren huai shi,仁怀市', 27.7914000, 106.4010400, 'CN', '2017-07-09', 46);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27155, 'Zipaquirá', 'Zipaquira', 'Sipakira,Zipaquira,Zipaquirá,sipakila,sypagyra,xi pa ji la,Сипакира,سیپاگیرا,სიპაკირა,錫帕基拉,시파키라', 5.0220800, -74.0048100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27156, 'Zipacón', 'Zipacon', 'Zipacon,Zipacón', 4.7588100, -74.3801700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27157, 'Zetaquira', 'Zetaquira', 'Zetaquira', 5.2821500, -73.1689600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27158, 'Zarzal', 'Zarzal', 'Zarzal', 4.3946200, -76.0715000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27159, 'Zaragoza', 'Zaragoza', 'Zaragoza', 7.4897100, -74.8691900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27160, 'Zapatoca', 'Zapatoca', 'AZT,Zapatoca', 6.8153200, -73.2676800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27161, 'Zambrano', 'Zambrano', 'Zambrano', 9.7472400, -74.8153000, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27162, 'Yumbo', 'Yumbo', 'Yumbo', 3.5823400, -76.4914600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27163, 'Yotoco', 'Yotoco', 'Yataco,Yotoco', 3.8604800, -76.3836400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27164, 'Yopal', 'Yopal', 'EYP,El Yopal,Jopal'',Jopalis,Juopales,Juopalės,Marroquin,Marroquín,Yopal,yopal,yue pa er,ywpal,Йопаль,یوپال,約帕爾,요팔', 5.3377500, -72.3958600, 'CO', '2016-10-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27165, 'Yondó', 'Yondo', 'Casabe,Yondo,Yondó', 7.0062100, -73.9097200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27166, 'Yolombó', 'Yolombo', 'Yolombo,Yolombó', 6.5984100, -75.0114000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27167, 'Yarumal', 'Yarumal', '', 6.9632100, -75.4173800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27168, 'Yalí', 'Yali', 'Yali,Yalí', 6.6745700, -74.8343000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27169, 'Yaguará', 'Yaguara', 'Yaguara,Yaguará', 2.6635500, -75.5175300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27170, 'Yacuanquer', 'Yacuanquer', 'Yacauquer,Yacuanquer,Yaquanquer', 1.1157700, -77.4016900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27171, 'Yacopí', 'Yacopi', 'Yacopi,Yacopí', 5.4594800, -74.3382300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27172, 'Viterbo', 'Viterbo', 'Viterbo', 5.0624200, -75.8715900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27173, 'Vista Hermosa', 'Vista Hermosa', 'Vista Hermosa', 3.1242800, -73.7515600, 'CO', '2016-03-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27174, 'Viotá', 'Viota', 'Viota,Viotá', 4.4371300, -74.5215700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27175, 'Villeta', 'Villeta', 'Villeta', 5.0088600, -74.4722600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27176, 'Villavieja', 'Villavieja', 'Villa Vieja,Villavieja', 3.2205200, -75.2186400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27177, 'Villavicencio', 'Villavicencio', 'Cantarrana,Caserio Villavicencio,VVC,Vijavisensio,Vil''javisensio,Viljavisensijas,Viljavisensio,Villavicencio,Villavicêncio,bi ya wei sen xi ao,biryabisenshio,biyabisensio,viliavisensio,wlawyknsyw,Вильявисенсио,Вилявисенсио,Віявісенсіо,ولاویکنسیو,ვილიავისენსიო,ビリャビセンシオ,比亚维森西奥,비야비센시오', 4.1420000, -73.6266400, 'CO', '2015-04-04', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27178, 'Villarrica', 'Villarrica', 'Villarrica', 3.9350200, -74.6003600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27179, 'Villa del Rosario', 'Villa del Rosario', 'Rosario,Vil''ja-del''-Rosario,Villa Rosario,Villa del Rosario,Вилья-дель-Росарио', 7.8338900, -72.4741700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27180, 'Villapinzón', 'Villapinzon', 'Villapinzon,Villapinzón', 5.2161700, -73.5949000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27181, 'Villanueva', 'Villanueva', 'Villanueva', 10.6052800, -72.9800000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27182, 'Villanueva', 'Villanueva', 'San Juan de Tumuhuaco,San Juán de Tumuhuaco,Vil''januehva,Villanueva,Вильянуэва', 10.4436100, -75.2730600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27183, 'Villanueva', 'Villanueva', 'Villanueva', 6.6716900, -73.1742100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27184, 'Villanueva', 'Villanueva', '', 5.2833300, -71.9666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27185, 'Villamaría', 'Villamaria', 'Villamaria,Villamaría', 5.0449200, -75.5146000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27186, 'Villahermosa', 'Villahermosa', 'Villahermosa', 5.0306700, -75.1160700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27187, 'Villagarzón', 'Villagarzon', '', 1.0375000, -76.6266700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27188, 'Villa de Leiva', 'Villa de Leiva', 'Leiva,Villa de Leiva,Villa de Leyva', 5.6450000, -73.5666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27189, 'Vijes', 'Vijes', 'Vijes', 3.6993400, -76.4423000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27190, 'Vigía del Fuerte', 'Vigia del Fuerte', 'Guayabal,Vigia del Fuerte,Vigía del Fuerte', 6.5789100, -76.8862800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27191, 'Victoria', 'Victoria', 'Victoria', 5.3164800, -74.9110100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27192, 'Vianí', 'Viani', 'Viani,Vianí', 4.8738400, -74.5624400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27193, 'Vetas', 'Vetas', 'Vetas', 7.3091100, -72.8712200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27194, 'Versalles', 'Versalles', '', 4.5754400, -76.1981400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27195, 'Vergara', 'Vergara', 'Vergara', 5.1184100, -74.3454900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27196, 'Ventaquemada', 'Ventaquemada', 'Ventaquemada', 5.3675300, -73.5207500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27197, 'Venecia', 'Venecia', '', 5.9627800, -75.7380600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27198, 'Venecia', 'Venecia', 'Ospina Perez,Ospina Pérez,Venecia', 4.0880800, -74.4774600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27199, 'Venadillo', 'Venadillo', 'Venadillo', 4.7192900, -74.9291800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27200, 'Vélez', 'Velez', '', 6.0133500, -73.6735200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27201, 'Valparaíso', 'Valparaiso', 'Valparaiso,Valparaíso', 5.6150000, -75.6242200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27202, 'Valparaíso', 'Valparaiso', 'Valparaiso,Valparaíso', 1.1951200, -75.7070500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27203, 'Valledupar', 'Valledupar', 'VUP,Val''edupar,Valedupar,Valjeduparas,Valledupar,ba ye du pa er,bajedo~uparu,twrbw,wylydwpar,yedupaleu,Валедупар,Вальедупар,توربو,ویلیدوپار,ვალიედუპარი,バジェドゥパル,巴耶杜帕尔,예두파르', 10.4631400, -73.2532200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27204, 'Valle de San Juan', 'Valle de San Juan', 'El Valle,Valle,Valle de San Juan', 4.1986900, -75.1173300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27205, 'Valle de San José', 'Valle de San Jose', 'El Valle,Valle,Valle de San Jose,Valle de San José', 6.4475000, -73.1436100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27206, 'Valencia', 'Valencia', '', 8.2580100, -76.1492800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27207, 'Valdivia', 'Valdivia', 'Valdivia', 7.2888900, -75.3977800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27208, 'Utica', 'Utica', 'Utica', 5.1872700, -74.4810500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27209, 'Usiacurí', 'Usiacuri', 'Usiacuri,Usiacurí', 10.7500000, -74.9833300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27210, 'Urumita', 'Urumita', 'Orumito,Uramita,Urumita', 10.5589400, -73.0123200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27211, 'Urrao', 'Urrao', 'URR,Urrao', 6.3169600, -76.1342000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27212, 'Uribia', 'Uribia', '', 11.7139000, -72.2660400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27213, 'Uramita', 'Uramita', 'Uramita', 6.8994400, -76.1741700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27214, 'Ungia', 'Ungia', 'Arquia,Ungia,Unguia,Unguía', 8.0436400, -77.0913700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27215, 'Une', 'Une', 'Une', 4.4030600, -74.0252800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27216, 'Umbita', 'Umbita', 'Umbita', 5.2204100, -73.4569500, 'CO', '2012-08-05', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27217, 'Ulloa', 'Ulloa', 'Ulloa', 4.7044400, -75.7402800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27218, 'Ubaté', 'Ubate', 'Ubate,Ubaté', 5.3093300, -73.8157500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27219, 'Ubaque', 'Ubaque', 'Ubaque', 4.4866700, -73.9374800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27220, 'Ubalá', 'Ubala', 'Ubala,Ubalá', 4.7477800, -72.5369400, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27221, 'Tuta', 'Tuta', 'Tuta', 5.6896600, -73.2277900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27222, 'Turmequé', 'Turmeque', 'Turmeque,Turmequo,Turmequé,Turmequó', 5.3236000, -73.4906700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27223, 'Turbo', 'Turbo', 'TRB,Turbo', 8.0926300, -76.7282200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27224, 'Turbaná', 'Turbana', 'Turbana,Turbaná', 10.2716900, -75.4422200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27225, 'Turbaco', 'Turbaco', 'Turbaco', 10.3294400, -75.4113700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27226, 'Túquerres', 'Tuquerres', 'Tuquerres,Túquerres', 1.0887800, -77.6183100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27227, 'Tunja', 'Tunja', 'Toun''cha,Tuncha,Tunja,Tunkha,tnja,tong ha,to~unha,tunha,twnkha,Τούνχα,Тунха,تنجا,تونخا,トゥンハ,通哈,툰하', 5.5352800, -73.3677800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27228, 'Tumaco', 'Tumaco', 'San Andres de Tumaco,San Andrés de Tumaco,TCO,Tucano,Tumaco,Tumakas,Tumako,tu ma ke,Тумако,圖馬科', 1.7986100, -78.8155600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27229, 'Tuluá', 'Tulua', 'Tulua,Tuluá,Tulúa,tu lu a,twlwa,Тулуа,تولوآ,ტულუა,图卢阿', 4.0846600, -76.1953600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27230, 'Tubará', 'Tubara', 'Tubara', 10.8756200, -74.9787300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27231, 'Trujillo', 'Trujillo', 'Trujillo', 4.2121700, -76.3194500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27232, 'Trinidad', 'Trinidad', 'La Parroquia,Municipio Trinidad,Trinidad', 5.4305600, -71.6311100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27233, 'Totoró', 'Totoro', 'Totora,Totoro,Totoró', 2.5159200, -76.4044400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27234, 'Toro', 'Toro', 'Toro', 4.6116700, -76.0813900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27235, 'Toribío', 'Toribio', 'Toribio,Toribío', 2.9548100, -76.2683900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27236, 'Topaipí', 'Topaipi', 'Topaipi,Topaipí,tuo pai pi,ტოპაიპი,托派皮', 5.3345700, -74.3029200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27237, 'Tópaga', 'Topaga', 'Topaga,Tópaga', 5.7597900, -72.8258300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27238, 'Toluviejo', 'Toluviejo', 'Toluviejo', 9.4508200, -75.4386400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27239, 'Tolú', 'Tolu', 'Santiago de Tolu,Santiago de Tolú,TLU,Tol,Tolu,Tolú,tuo lu,twlw,Тол,تولو,ტოლუ,托盧', 9.5239200, -75.5813900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27240, 'Toledo', 'Toledo', 'Toledo', 7.3098400, -72.4829500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27241, 'Tocancipá', 'Tocancipa', 'Tocancipa,Tocancipá,tuo kan xi pa,twkansypa,توکانسیپا,ტოკანსიპა,托坎西帕', 4.9653100, -73.9130100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27242, 'Tocaima', 'Tocaima', '', 4.4582000, -74.6343400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27243, 'Toca', 'Toca', 'Toca', 5.5639300, -73.1839800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27244, 'Titiribí', 'Titiribi', 'Titiribi,Titiribí', 6.0627600, -75.7937000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27245, 'Tipacoque', 'Tipacoque', 'Tipacoque', 6.4203100, -72.6918400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27246, 'Timbiquí', 'Timbiqui', 'Santa Barbara,Santa Bárbara,TBD,Timbiqui,Timbiquí', 2.7717000, -77.6653600, 'CO', '2017-07-02', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27247, 'Timaná', 'Timana', 'Timana,Timaná', 1.9713600, -75.9312300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27248, 'Tierralta', 'Tierralta', 'Los Bongos,T''erral''ta,Tierra Alta,Tierralta,Тьерральта', 8.1736100, -76.0591700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27249, 'Tibú', 'Tibu', 'TIB,Tibu,Tibú', 8.6389500, -72.7358300, 'CO', '2017-06-25', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27250, 'Tibasosa', 'Tibasosa', 'Tibasosa', 5.7500000, -73.0000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27251, 'Tibaná', 'Tibana', 'Tibana,Tibaná', 5.3172800, -73.3965500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27252, 'Tesalia', 'Tesalia', 'Carnicerias,Carnicerías,Tesalia', 2.4858700, -75.7292100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27253, 'Teruel', 'Teruel', 'Retiro,Teruel', 2.7419300, -75.5673800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27254, 'Tenza', 'Tenza', 'Tensa,Tenza', 5.0766400, -73.4207700, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27255, 'Tenjo', 'Tenjo', 'Tenjo', 4.8727000, -74.1443500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27256, 'Tello', 'Tello', 'Tello', 3.0669400, -75.1377800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27257, 'Tauramena', 'Tauramena', 'TAU,Tauramena', 5.0183100, -72.7491900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27258, 'Tasco', 'Tasco', 'Tasco', 5.9104400, -72.7800100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27259, 'Tarso', 'Tarso', 'Tarso', 5.8646700, -75.8219200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27260, 'Tarqui', 'Tarqui', 'Tanqui,Tarqui', 2.1124800, -75.8241900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27261, 'Tarapacá', 'Tarapaca', 'TCD,Tarapaca,Tarapacá', -2.8920000, -69.7420000, 'CO', '2017-07-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27262, 'Tangua', 'Tangua', 'Tangua', 1.0947300, -77.3948200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27263, 'Taminango', 'Taminango', 'Taminango', 1.5749100, -77.2866600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27264, 'Támesis', 'Tamesis', 'Tamesis,Támesis', 5.6646200, -75.7133900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27265, 'Tame', 'Tame', 'TME,Tam,Tame,ta mei,tamh,Там,تامه,ტამე,塔梅', 6.4606500, -71.7361800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27266, 'Tamara', 'Tamara', 'Tamara', 5.8297200, -72.1633300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27267, 'Tamalameque', 'Tamalameque', '', 8.8522100, -73.8122900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27268, 'Talaigua Viejo', 'Talaigua Viejo', '', 9.3120600, -74.5854400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27269, 'Tadó', 'Tado', 'Tado,Tadó', 5.2659800, -76.5648700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27270, 'Tabio', 'Tabio', 'Tabio', 4.9172600, -74.0936400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27271, 'Sutatausa', 'Sutatausa', 'Sutatausa', 5.2477900, -73.8523800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27272, 'Sutamarchán', 'Sutamarchan', 'Sutamarchan,Sutamarchán', 5.6153800, -73.6170100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27273, 'Susacón', 'Susacon', 'Susacon,Susacón', 6.2297800, -72.6901000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27274, 'Susa', 'Susa', 'Susa', 5.4519000, -73.8143600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27275, 'Supía', 'Supia', 'Supia,Supía', 5.4530300, -75.6507200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27276, 'Supatá', 'Supata', 'Supata,Supatá', 5.0609700, -74.2372100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27277, 'Suesca', 'Suesca', 'Suesca', 5.1028900, -73.7984500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27278, 'Sucre', 'Sucre', 'Boca de Granada,Sucre,Sukre,Сукре', 8.8113600, -74.7208400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27279, 'Sucre', 'Sucre', 'Sucre,Sukre,Сукре', 5.9183300, -73.7910900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27280, 'Sucre', 'Sucre', 'Sucre', 2.0380500, -76.9244600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27281, 'Subachoque', 'Subachoque', 'Subachoque', 4.9261400, -74.1729900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27282, 'Suaza', 'Suaza', 'Suaza', 1.9761100, -75.7945400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27283, 'Suárez', 'Suarez', 'Santa Rosa,Suarez,Suárez', 4.0490600, -74.8319800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27284, 'Suárez', 'Suarez', 'Suarez,Suárez', 2.9539500, -76.6964400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27285, 'Suan', 'Suan', 'Suan', 10.3334700, -74.8801600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27286, 'Suaita', 'Suaita', '', 6.1014000, -73.4404100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27287, 'Sotomayor', 'Sotomayor', 'Los Andes,Sotomayor', 1.5146900, -77.5044400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27288, 'Sotaquirá', 'Sotaquira', 'Sotaquira,Sotaquirá', 5.7648300, -73.2475800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27289, 'Sopó', 'Sopo', 'Sopo,Sopó', 4.9075000, -73.9384000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27290, 'Soplaviento', 'Soplaviento', 'Soplaviento', 10.3930600, -75.1408300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27291, 'Sonsón', 'Sonson', 'Sonson,Sonsón', 5.7106200, -75.3106900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27292, 'Somondoco', 'Somondoco', 'Somondoco', 4.9877800, -73.4361100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27293, 'Soledad', 'Soledad', 'Soledad', 10.9184300, -74.7645900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27294, 'Solano', 'Solano', 'Puerto Solano,SQF,Solano', 0.6993700, -75.2535300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27295, 'Sogamoso', 'Sogamoso', 'SOX,Sogamosas,Sogamoso,suo jia mo suo,Согамосо,索加莫索', 5.7143400, -72.9339100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27296, 'Socotá', 'Socota', 'Socota,Socotá', 6.0402800, -72.6350900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27297, 'Socorro', 'Socorro', '', 6.4683800, -73.2602200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27298, 'Socha Viejo', 'Socha Viejo', 'Socha,Socha Viejo', 5.9817000, -72.7150300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27299, 'Soatá', 'Soata', 'Soata,Soatá', 6.3336900, -72.6828300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27300, 'Soacha', 'Soacha', 'Soacha,Soachu,Соачу', 4.5793700, -74.2168200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27301, 'Sitionuevo', 'Sitionuevo', 'Sitionuevo', 10.7773700, -74.7204900, 'CO', '2013-04-04', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27302, 'Sincelejo', 'Sincelejo', 'Cincelejo,Sincelejo,Sinselechas,Sinselekho,sinselekho,sinselleho,snsylkhw,snsylyw,synslkhw,xin sai lai huo,Синселехо,سنسیلخو,سنسیلیو,سینسلخو,სინსელეხო,辛塞萊霍,신셀레호', 9.3047200, -75.3977800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27303, 'Sincé', 'Since', 'Since,Sincé', 9.2439100, -75.1467500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27304, 'Simití', 'Simiti', 'Simiti,Simití', 7.9579000, -73.9436000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27305, 'Simijaca', 'Simijaca', 'Simijaca', 5.5029100, -73.8522700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27306, 'Simacota', 'Simacota', 'Simacota', 6.4429000, -73.3368800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27307, 'Silvia', 'Silvia', 'Silvia', 2.6155700, -76.3826100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27308, 'Silvania', 'Silvania', 'Silvania', 4.4036700, -74.3867000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27309, 'Silos', 'Silos', 'Silos', 7.2052400, -72.7563900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27310, 'Sibundoy', 'Sibundoy', 'Sibundoy', 1.2029600, -76.9227500, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27311, 'Sibaté', 'Sibate', 'Sibate,Sibaté', 4.4842500, -74.2449900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27312, 'Siachoque', 'Siachoque', 'Siachoque', 5.5123800, -73.2443600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27313, 'Sevilla', 'Sevilla', '', 4.2642500, -75.9308500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27314, 'Sesquilé', 'Sesquile', 'Sesquile,Sesquilé', 5.0446300, -73.7972400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27315, 'Segovia', 'Segovia', '', 7.0799300, -74.6989000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27316, 'Sasaima', 'Sasaima', 'Sasaima', 4.9670500, -74.4351200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27317, 'Sardinata', 'Sardinata', 'Sardinata', 8.0828900, -72.8007100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27318, 'Sapuyes', 'Sapuyes', 'Sapuyes', 1.0372800, -77.6209400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27319, 'San Zenón', 'San Zenon', 'San Cenon,San Sebastian,San Zenon,San Zenón', 9.2421700, -74.5003700, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27320, 'San Vicente de Chucurí', 'San Vicente de Chucuri', 'San Vicente,San Vicente de Chucuri,San Vicente de Chucurí', 6.8810000, -73.4097700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27321, 'San Vicente', 'San Vicente', 'San Vicente', 6.2327800, -75.3361100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27322, 'Santuario', 'Santuario', 'Santuario', 6.1383300, -75.2641700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27323, 'Santuario', 'Santuario', 'Santuario', 5.0723700, -75.9634100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27324, 'Santo Tomás', 'Santo Tomas', 'Santo Tomas,Santo Tomás', 10.7577300, -74.7545100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27325, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 6.4728200, -75.1654700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27326, 'Santiago', 'Santiago', '', 7.8643200, -72.7162000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27327, 'Santiago', 'Santiago', 'El Valle,Santiago', 1.1484400, -77.0045000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27328, 'Santa Sofía', 'Santa Sofia', '', 5.7090800, -73.6040400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27329, 'Santa Rosalia', 'Santa Rosalia', 'SSL,Santa Rosalia', 5.1335600, -70.8623300, 'CO', '2017-07-14', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27330, 'Santa Rosa de Viterbo', 'Santa Rosa de Viterbo', 'Santa Rosa,Santa Rosa de Viterbo', 5.8740100, -72.9821700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27331, 'Santa Rosa de Osos', 'Santa Rosa de Osos', 'Santa Rosa,Santa Rosa de Osos,Santa-Rosa-de-Osos,santa rwsa dh rwsws,sheng luo sha de ao suo si,Санта-Роса-де-Осос,سانتا روسا ده روسوس,სანტა-როსა-დე-ოსოსი,聖羅莎德奧索斯', 6.6473800, -75.4603100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27332, 'Santa Rosa de Cabal', 'Santa Rosa de Cabal', 'Santa Rosa,Santa Rosa Cabal,Santa Rosa de Cabal,Santa-Rosa-de-Kabal'',Санта-Роса-де-Кабаль', 4.8680600, -75.6213900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27333, 'Santa Rosa', 'Santa Rosa', 'El Uvero,Santa Rosa', 10.4447200, -75.3697200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27334, 'Santander de Quilichao', 'Santander de Quilichao', 'Quilichao,Santander,Santander de Quilichao', 3.0094500, -76.4849400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27335, 'Santana', 'Santana', 'Santana', 6.0575000, -73.4811200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27336, 'Santa Marta', 'Santa Marta', 'SMR,Santa Marta,santa marta,snth mrth,Санта Марта,סנטה מרתה,سانتا مارتا', 11.2407900, -74.1990400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27337, 'Santa María', 'Santa Maria', '', 4.8604800, -73.2623400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27338, 'Santa María', 'Santa Maria', 'Santa Maria,Santa María', 2.9500000, -75.6500000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27339, 'Santa Lucía', 'Santa Lucia', 'Corregimiento Santa Lucia,Santa Lucia,Santa Lucía', 10.3242000, -74.9601700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27340, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', 10.6036100, -75.2882400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27341, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara,Santa-Barbara,santa barbara,sheng ba ba la,Санта-Барбара,سانتا باربارا,სანტა-ბარბარა,聖芭芭拉', 5.8745800, -75.5670600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27342, 'Santa Ana', 'Santa Ana', '', 9.3212500, -74.5684800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27343, 'San Roque', 'San Roque', 'San Roque', 6.4851100, -75.0196000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27344, 'San Rafael', 'San Rafael', 'San Rafael', 6.2943600, -75.0258900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27345, 'San Pelayo', 'San Pelayo', 'San Pelayo', 8.9583300, -75.8362700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27346, 'San Pedro de Urabá', 'San Pedro de Uraba', 'San Pedro de Uraba,San Pedro de Urabá', 8.2751500, -76.3764100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27347, 'San Pedro', 'San Pedro', '', 9.3956000, -75.0647600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27348, 'San Pedro', 'San Pedro', 'San Pedro', 6.4645100, -75.5600200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27349, 'San Pedro', 'San Pedro', 'San Pedro', 3.9944500, -76.2288500, 'CO', '2015-06-24', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27350, 'San Pablo de Borbur', 'San Pablo de Borbur', 'Barbur,Borbur,San Pablo de Borbur', 5.6603400, -74.0621200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27351, 'San Pablo', 'San Pablo', 'Corregimiento San Pablo,San Pablo', 10.0515400, -75.2677500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27352, 'San Pablo', 'San Pablo', '', 1.6725000, -77.0138900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27353, 'San Onofre', 'San Onofre', 'San Onofre', 9.7358600, -75.5262600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27354, 'San Miguel', 'San Miguel', 'La Dorada,Nuevo San Miguel,Nuevo San Miguél,San Miguel,San Miguel Nuevo', 0.3431400, -76.9112400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27355, 'San Mateo', 'San Mateo', 'San Mateo', 6.4019500, -72.5531400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27356, 'San Martín', 'San Martin', 'San Martin,San Martín', 3.6963700, -73.6995700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27357, 'San Marcos', 'San Marcos', 'SRS,San Marcos', 8.6597200, -75.1280900, 'CO', '2017-07-16', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27358, 'San Luis de Palenque', 'San Luis de Palenque', 'Municipio de San Luis de Palenque,SQE,San Luis de Palenque,sheng lu yi si de pa lun ke,სან-ლუის-დე-პალენკე,聖路易斯德帕倫克', 5.4213900, -71.7316700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27359, 'San Luis de Gaceno', 'San Luis de Gaceno', 'Gaceno,Gazeno,San Luis Gaceno,San Luis de Gaceno', 4.8205200, -73.1685100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27360, 'Cubarral', 'Cubarral', 'Cubarral,San Luis de Cubarral', 3.7953600, -73.8406300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27361, 'San Luis', 'San Luis', '', 4.1325800, -75.0949900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27362, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 1.5062800, -77.2189800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27363, 'San Juan Nepomuceno', 'San Juan Nepomuceno', 'San Juan,San Juan Nepomuceno', 9.9515700, -75.0819800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27364, 'San Juan de Urabá', 'San Juan de Uraba', 'Coco,SJR,San Juan,San Juan de Uraba,San Juan de Urabá', 8.7592400, -76.5296900, 'CO', '2017-07-15', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27365, 'San Juan del Cesar', 'San Juan del Cesar', 'San Juan de Cesar,San Juan de César,San Juan del Cesar', 10.7710700, -73.0031400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27366, 'San Juan de Betulia', 'San Juan de Betulia', 'Betulia,San Juan de Betulia', 9.2734500, -75.2410300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27367, 'San Juan de Arama', 'San Juan de Arama', 'Municipio Juan de Arama,San Juan,San Juan de Arama', 3.3698500, -73.8726700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27368, 'San José de Miranda', 'San Jose de Miranda', 'Miranda,San Jose de Miranda,San José de Miranda', 6.6587000, -72.7334400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27369, 'San José del Palmar', 'San Jose del Palmar', 'San Jose del Palmar,San José del Palmar', 4.9741700, -76.2283300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27370, 'San José de La Montaña', 'San Jose de La Montana', 'San Jose,San Jose de La Montana,San José,San José de La Montaña', 6.8502800, -75.6833300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27371, 'San José', 'San Jose', 'San Jose,San José', 5.0858300, -75.7883300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27372, 'San José', 'San Jose', 'Roberto Payan,Roberto Payán,San Jose,San José', 1.6965900, -78.2448200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27373, 'San Jerónimo', 'San Jeronimo', 'San Jeronimo,San Jerónimo', 6.4434400, -75.7281500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27374, 'San Jacinto', 'San Jacinto', 'San Jacinto', 9.8276700, -75.1217000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27375, 'San Gil', 'San Gil', 'San Chilis,San Gil,san khyl,san-khili,sheng xi er,سان خیل,სან-ხილი,聖希爾', 6.5595200, -73.1363700, 'CO', '2015-01-13', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27376, 'San Francisco', 'San Francisco', '', 6.1166700, -75.9833300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27377, 'San Francisco', 'San Francisco', 'San Fracisco,San Francisco', 4.9787600, -74.2927000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27378, 'San Francisco', 'San Francisco', 'San Francisco', 1.1764400, -76.8783800, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27379, 'San Fernando', 'San Fernando', 'San Fernando', 9.2797200, -74.5338900, 'CO', '2012-05-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27380, 'San Estanislao', 'San Estanislao', 'Arenal,San Estanislao', 10.3983300, -75.1511100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27381, 'Sandoná', 'Sandona', 'Sandona,Sandoná', 1.2862600, -77.4692100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27382, 'San Diego', 'San Diego', 'Corregimiento San Diego,San Diego', 10.3362300, -73.1820300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27383, 'San Cristóbal', 'San Cristobal', 'Caserio San Cristobal,San Cristobal,San Cristóbal', 9.8780900, -75.2524800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27384, 'San Cayetano', 'San Cayetano', 'San Cayetano', 7.8770700, -72.6243000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27385, 'San Carlos de Guaroa', 'San Carlos de Guaroa', 'San Carlos de Guarda,San Carlos de Guaroa', 3.7116100, -73.2434400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27386, 'San Carlos', 'San Carlos', 'San Carlos', 8.7957700, -75.6994700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27387, 'San Carlos', 'San Carlos', '', 7.7917700, -74.7731600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27388, 'San Carlos', 'San Carlos', 'San Carlos', 6.1878900, -74.9931500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27389, 'San Calixto', 'San Calixto', 'San Calixto', 8.4021000, -73.2073700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27390, 'San Bernardo del Viento', 'San Bernardo del Viento', 'San Bernardo,San Bernardo del Viento', 9.3533000, -75.9524400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27391, 'San Bernardo', 'San Bernardo', 'San Bernardo', 1.5211900, -77.0309100, 'CO', '2012-05-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27392, 'San Benito Abad', 'San Benito Abad', 'San Benito Abab,San Benito Abad,Tocasman,Tocasmán', 8.9290100, -75.0270900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27393, 'San Antonio', 'San Antonio', 'Caserio San Antonio,San Antonio,Tenerife', 9.9330300, -74.6934600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27394, 'San Antonio', 'San Antonio', '', 3.9142300, -75.4800900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27395, 'San Antero', 'San Antero', 'San Antero', 9.3741000, -75.7589100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27396, 'San Andrés', 'San Andres', 'ADZ,San Andres,San Andrés', 12.5847200, -81.7005600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27397, 'San Andrés', 'San Andres', 'San Andres,San Andrés', 6.8114800, -72.8492900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27398, 'San Alberto', 'San Alberto', 'San Alberto', 7.7610700, -73.3922000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27399, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', 1.8788400, -76.2672200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27400, 'Sampués', 'Sampues', 'Sampues,Sampués', 9.1836100, -75.3816700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27401, 'Samaniego', 'Samaniego', 'Samaniego', 1.3384900, -77.5957000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27402, 'Samacá', 'Samaca', 'Samaca,Samacá', 5.4927300, -73.4853700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27403, 'Salgar', 'Salgar', 'Salgar', 5.9650200, -75.9654100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27404, 'Salento', 'Salento', 'Salento', 4.6375000, -75.5702800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27405, 'Saldaña', 'Saldana', 'Saldana,Saldaña', 3.9292300, -75.0151700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27406, 'Salamina', 'Salamina', '', 10.4902700, -74.7946300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27407, 'Salamina', 'Salamina', 'Salamina', 5.4073300, -75.4874900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27408, 'Saladoblanco', 'Saladoblanco', 'Saladoblanco', 1.9924400, -76.0433500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27409, 'Sahagún', 'Sahagun', 'Sahagun,Sahagún', 8.9461700, -75.4427500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27410, 'Sáchica', 'Sachica', 'Sachica,Sáchica', 5.5845300, -73.5418400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27411, 'Saboyá', 'Saboya', 'Saboya,Saboyá', 5.6963600, -73.7693200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27412, 'Sabaneta', 'Sabaneta', 'Sabaneta,Sabanetas,Сабанета', 6.1515300, -75.6165700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27413, 'Sabanalarga', 'Sabanalarga', 'Sabanalarga,Sabanalargo', 10.6296200, -74.9206300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27414, 'Sabanalarga', 'Sabanalarga', 'Sabanalarga', 6.8489300, -75.8171100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27415, 'Sabanagrande', 'Sabanagrande', '', 10.7911500, -74.7605900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27416, 'Sabana de Torres', 'Sabana de Torres', 'SNT,Sabana de Torres', 7.3915000, -73.4957400, 'CO', '2017-02-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27417, 'Rovira', 'Rovira', 'Rovira', 4.2392200, -75.2399600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27418, 'Rosas', 'Rosas', 'Dolores,Rosas', 2.2609300, -76.7398600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27419, 'Roncesvalles', 'Roncesvalles', 'Roncesvalles', 4.0108000, -75.6049300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27420, 'Roldanillo', 'Roldanillo', 'Roldanillo', 4.4125600, -76.1545700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27421, 'Rivera', 'Rivera', 'Rivera,San Mateo', 2.7771700, -75.2564200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27422, 'Risaralda', 'Risaralda', 'Risaral''da,Risaralda,Rizaralda,Рисаральда', 5.1664700, -75.7659500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27423, 'Río Viejo', 'Rio Viejo', 'Corregimiento Rio Viejo,Rio Viejo,Río Viejo', 8.5874000, -73.8390100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27424, 'Riosucio', 'Riosucio', 'Riosucio', 7.4434800, -77.1196400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27425, 'Riosucio', 'Riosucio', 'Riosucio,Ruiosucio', 5.4216400, -75.7031800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27426, 'Rionegro', 'Rionegro', 'Rionegro,li ao nei ge luo,lionegeulo,rionegro,rywngrw,Ριονέγρο,Рионегро,ریونگرو,რიონეგრო,里奧內格羅,리오네그로', 6.1551500, -75.3737100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27427, 'Ríohacha', 'Riohacha', 'RCH,Riochacha,Riohacha,Ríohacha', 11.5444400, -72.9072200, 'CO', '2017-02-05', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27428, 'Riofrío', 'Riofrio', 'Huasano,Huasanó,Palomino,Riofrio,Riofrío', 4.1571000, -76.2885200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27429, 'Río de Oro', 'Rio de Oro', 'Rio de Oro,Río de Oro', 8.2919000, -73.3848500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27430, 'Rioblanco', 'Rioblanco', '', 3.5308300, -75.6805600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27431, 'Ricaurte', 'Ricaurte', 'Ricaurte,Ricaute', 4.2807500, -74.7646900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27432, 'Ricaurte', 'Ricaurte', '', 1.1811200, -77.9612400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27433, 'El Retiro', 'El Retiro', 'El Retiro,Retiro', 6.0586100, -75.5030600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27434, 'Restrepo', 'Restrepo', 'Restrepo', 4.2583300, -73.5614200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27435, 'Restrepo', 'Restrepo', 'Conto,Restrepo', 3.8220300, -76.5224200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27436, 'Repelón', 'Repelon', 'Repelon,Repelón', 10.4919400, -75.1291700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27437, 'Remolino', 'Remolino', 'Jaguey,Remolino', 10.7019900, -74.7160200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27438, 'Remedios', 'Remedios', 'Remedios,lei mei di ao si,remediosi,rmdyws,Ремедиос,رمدیوس,რემედიოსი,雷梅迪奧斯', 7.0308300, -74.5333300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27439, 'Regidor', 'Regidor', 'Corregimiento Regidor,Regidor', 8.6656500, -73.8215100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27440, 'Ráquira', 'Raquira', 'Raquira,Ráquira', 5.5379300, -73.6320100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27441, 'Ramiriquí', 'Ramiriqui', 'Ramiriqui,Ramiriquí', 5.4002000, -73.3354400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27442, 'Ragonvalia', 'Ragonvalia', 'Ragonvalia,Rangovalia', 7.5774900, -72.4757400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27443, 'Apulo', 'Apulo', 'Apulo,Rafael Reyes', 4.5195200, -74.5929300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27444, 'Quipile', 'Quipile', 'Quipile', 4.7480600, -74.5630600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27445, 'Quinchía', 'Quinchia', 'Nazaret,Quinchia,Quinchía', 5.3395700, -75.7301800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27446, 'Quimbaya', 'Quimbaya', 'Quimbaya', 4.6230600, -75.7627800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27447, 'Quibdó', 'Quibdo', 'Kibdo,Kimpdo,Quibdo,Quibdó,UIB,ji bu duo,kib do,kibeudo,kwbdw,kybdw,qybdw,Κιμπδό,Кибдо,קיבדו,قیبدو,كيبدو,کوبدو,کیبدو,กิบโด,基布多,키브도', 5.6918800, -76.6583500, 'CO', '2015-08-30', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27448, 'Quetame', 'Quetame', 'Quetame,Quetarre', 4.3323400, -73.8614100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27449, 'Purísima', 'Purisima', 'Purisima,Purísima', 9.2365700, -75.7219100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27450, 'Purificación', 'Purificacion', 'Purificacion,Purificación', 3.8587100, -74.9312900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27451, 'Pupiales', 'Pupiales', 'Pupiales', 0.8713600, -77.6402700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27452, 'Puerto Wilches', 'Puerto Wilches', 'Puerto Wilches', 7.3482800, -73.8960100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27453, 'Puerto Triunfo', 'Puerto Triunfo', 'Puerto Triunfo', 5.8726200, -74.6402900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27454, 'Puerto Tejada', 'Puerto Tejada', '', 3.2311400, -76.4166800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27455, 'Puerto Santander', 'Puerto Santander', 'Puerto Santander,Santander', 8.3636100, -72.4063000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27456, 'Puerto Salgar', 'Puerto Salgar', 'Puerto Salgar,Salgar', 5.4630400, -74.6543600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27457, 'Puerto Rondón', 'Puerto Rondon', 'Corregimiento Puerto Rendon,Corregimiento Puerto Rendón,El Padre,Puerto Rendon,Puerto Rondon,Puerto Rondón,Rondon,Rondón', 6.2804800, -71.1000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27458, 'Puerto Yuca', 'Puerto Yuca', 'Puerto Rico,Puerto Yuca', 2.9383300, -73.2083300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27459, 'Puerto Rico', 'Puerto Rico', '', 1.9141700, -75.1450000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27460, 'Puerto Parra', 'Puerto Parra', 'Puerto Parra', 6.6514900, -74.0573400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27461, 'Puerto Nariño', 'Puerto Narino', 'Puerto Narino,Puerto Nariño', -3.7888900, -70.3558400, 'CO', '2015-06-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27462, 'Puerto López', 'Puerto Lopez', 'Puerto Lopez,Puerto López', 4.0991200, -72.9564700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27463, 'Puerto Lleras', 'Puerto Lleras', 'Puerto Chinatas,Puerto Lleras,Puerto Saiz,Puerto Saíz', 3.0222500, -73.4044000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27464, 'Puerto Leguízamo', 'Puerto Leguizamo', 'Caucaya,Caucayá,LQM,Leguizamo,Puerto Leguizamo,Puerto Leguízamo', -0.1933700, -74.7818900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27465, 'Inírida', 'Inirida', 'Inirida,Inírida,Obando,PDA,Puerto Inirida,Puerto Inírida,aynyrda,aynyryda  gwaynya,inlida,yi ni li da,Инирида,اینیردا,اینیریدا، گواینیا,伊尼里達,인리다', 3.8652800, -67.9238900, 'CO', '2017-02-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27466, 'Puerto Escondido', 'Puerto Escondido', 'Puerto Escondido,Puerto Escondito', 9.0181100, -76.2641300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27467, 'Puerto Colombia', 'Puerto Colombia', 'Puerto Colombia', 10.9877800, -74.9547200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27468, 'Puerto Carreño', 'Puerto Carreno', 'PCR,Puerto Carreno,Puerto Carreño', 6.1890300, -67.4858800, 'CO', '2017-07-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27469, 'Puerto Boyacá', 'Puerto Boyaca', 'Puerto Boyaca,Puerto Boyacá', 5.9758400, -74.5884500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27470, 'Puerto Berrío', 'Puerto Berrio', 'Puerto Berrio,Puerto Berrío', 6.4915600, -74.4032600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27471, 'Puerto Asís', 'Puerto Asis', 'PUU,Puehrto-Asis,Puerto Asis,Puerto Asís,Пуэрто-Асис', 0.5132800, -76.5007500, 'CO', '2016-09-30', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27472, 'Puerres', 'Puerres', '', 1.1937400, -77.2666100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27473, 'Puente Nacional', 'Puente Nacional', 'Puente Nacional', 5.8773900, -73.6781000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27474, 'Puebloviejo', 'Puebloviejo', '', 10.9937600, -74.2843900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27475, 'Pueblorrico', 'Pueblorrico', 'Pueblorico,Pueblorrico', 5.7917600, -75.8410100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27476, 'Pueblo Rico', 'Pueblo Rico', 'Pueblo Rico,Pueblorrico', 5.2383300, -76.0363900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27477, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Caserio Pueblonuevo,Pueblo Nuevo', 8.2411000, -74.9581500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27478, 'Providencia', 'Providencia', '', 1.5697600, -77.4640000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27479, 'Prado', 'Prado', 'Prado', 3.7511800, -74.9300400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27480, 'Pradera', 'Pradera', '', 3.4211100, -76.2447200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27481, 'Potosí', 'Potosi', '', 0.8073900, -77.5721600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27482, 'Pore', 'Pore', 'Municipio Pore,PRE,Pore', 5.7299200, -72.0015900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27483, 'Popayán', 'Popayan', 'PPN,Popajan,Popajanas,bo pa yang,popayan,pwpayan,Попаян,پوپایان,ポパヤン,波帕扬,포파얀', 2.4382300, -76.6131600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27484, 'Ponedera', 'Ponedera', 'Ponedera,Ponederas,Ponedero', 10.6410400, -74.7502600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27485, 'Polonuevo', 'Polonuevo', 'Polonuevo,Pueblonuevo', 10.7769700, -74.8534400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27486, 'Policarpa', 'Policarpa', 'Policarpa', 1.6323100, -77.4619900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27487, 'Planeta Rica', 'Planeta Rica', 'PLC,Planeta Rica,Planeta-Riki,Планета-Рики', 8.4115000, -75.5850800, 'CO', '2014-12-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27488, 'Planadas', 'Planadas', 'PLA,Planadas', 3.1969800, -75.6450600, 'CO', '2017-06-07', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27489, 'Pizarro', 'Pizarro', 'Bajo Baudo,Bajo Baudó,Baudo,Baudó,Pizarro,Puerto Pizarro', 4.9533400, -77.3659800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27490, 'Francisco Pizarro', 'Francisco Pizarro', 'Francisco Pizarro,Pizarro,Salahonda', 2.1019400, -78.7216700, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27491, 'Pivijay', 'Pivijay', 'Pivijay', 10.4616700, -74.6162100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27492, 'Pitalito', 'Pitalito', 'PTX,Pitalitas,Pitalito,pi ta li tuo,Питалито,პიტალიტო,皮塔利托', 1.8537100, -76.0507100, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27493, 'Pital', 'Pital', '', 2.2665000, -75.8044200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27494, 'Piojó', 'Piojo', 'Piojo,Piojó', 10.7484600, -75.1077600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27495, 'Pinillos', 'Pinillos', 'Pinillos', 8.9192500, -74.4677100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27496, 'Pijiño', 'Pijino', 'Corregimiento Pijino,Corregimiento Pijiño,Piginio,Pijinio,Pijino,Pijiño', 9.3290800, -74.4530200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27497, 'Pijao', 'Pijao', 'Pijao', 4.3341900, -75.7034800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27498, 'Piedras', 'Piedras', 'Pedregal,Piedras', 4.5383300, -74.8817500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27499, 'Piedrancha', 'Piedrancha', 'Mallama,Piedra Ancha,Piedrancha', 1.1374000, -77.8489000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27500, 'Pié de Pató', 'Pie de Pato', 'Alto Baudo,Alto Baudó,Pie de Pato,Pié de Pató,Puerto Yacup', 5.5160400, -76.9744900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27501, 'Piedecuesta', 'Piedecuesta', '', 6.9878900, -73.0495300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27502, 'Pesca', 'Pesca', '', 5.5500000, -73.0500000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27503, 'Pereira', 'Pereira', 'Antigua Cartago,Cartago Viejo,PEI,Pereira,Perejra,Villa de Robledo,Перейра', 4.8133300, -75.6961100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27504, 'Peque', 'Peque', 'Peque', 7.0212300, -75.9092600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27505, 'Pensilvania', 'Pensilvania', '', 5.3834600, -75.1612200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27506, 'Pelaya', 'Pelaya', 'Caserio Pelaya,Caserío Pelaya,Pelaya', 8.6881900, -73.6645100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27507, 'Pedraza', 'Pedraza', 'Pedraza', 10.1873900, -74.9150400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27508, 'Payán', 'Payan', 'Capital Payan,Capital Payán,Magui,Magüí,Mangui,Mangüi,Payan,Payán', 1.9350000, -78.2050000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27509, 'Pauna', 'Pauna', 'Pauna', 5.6586100, -73.9825000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27510, 'Patía', 'Patia', '', 2.0689500, -77.0527300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27511, 'Pasto', 'Pasto', 'PSO,Pastas,Pasto,San Juan de Pasto,Пасто', 1.2136100, -77.2811100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27512, 'Pasca', 'Pasca', 'Pasca', 4.3072200, -74.3005600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27513, 'Pandi', 'Pandi', 'Pandi', 4.1911100, -74.4875000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27514, 'Pamplona', 'Pamplona', 'Pamplona,Памплона', 7.3756500, -72.6479500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27515, 'Palocabildo', 'Palocabildo', 'Palocabildo', 5.1170500, -75.0173200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27516, 'Palmito', 'Palmito', 'Palmito,Palmitos', 9.3333300, -75.5500000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27517, 'Palmira', 'Palmira', 'Palmira', 3.5394400, -76.3036100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27518, 'Palmar de Varela', 'Palmar de Varela', 'Palma de Varela,Palmar,Palmar de Varela,Palmer', 10.7405500, -74.7544300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27519, 'Palestina', 'Palestina', '', 5.0194000, -75.6224200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27520, 'Palestina', 'Palestina', 'Palestina', 1.7236200, -76.1340300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27521, 'Palermo', 'Palermo', 'Palermo,Santa Rosalia de Guagua,Santa Rosalía de Guagua', 2.8916700, -75.4375000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27522, 'Pajarito', 'Pajarito', '', 5.2929000, -72.7027700, 'CO', '2011-10-11', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27523, 'Paispamba', 'Paispamba', 'Paispamba,Sotara,Sotará', 2.2546200, -76.6108600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27524, 'Paipa', 'Paipa', 'Paipa', 5.7801300, -73.1170800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27525, 'Pailitas', 'Pailitas', 'Pailitas', 8.9565200, -73.6254800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27526, 'Paicol', 'Paicol', 'Paicol', 2.4496200, -75.7750000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27527, 'Páez', 'Paez', 'Paez,Páez', 5.1011200, -73.0512300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27528, 'Belalcazar', 'Belalcazar', 'Belalcazar,Belalcazer,Belalcázar,Belalcázer,Paez,Páez', 2.6547200, -75.9927800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27529, 'Padilla', 'Padilla', 'Padilla', 3.2203800, -76.3138500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27530, 'Pácora', 'Pacora', 'Pacora,Pácora', 5.5270800, -75.4593000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27531, 'Pacho', 'Pacho', 'Pacho', 5.1327800, -74.1597700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27532, 'Ovejas', 'Ovejas', '', 9.5324800, -75.2238200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27533, 'Otanche', 'Otanche', '', 5.6567200, -74.1824900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27534, 'Ospina', 'Ospina', 'Ospina', 1.0595000, -77.5655400, 'CO', '2016-03-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27535, 'Ortega', 'Ortega', 'Ortega', 3.9361000, -75.2216900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27536, 'Orocué', 'Orocue', 'ORC,Orocue,Orocué', 4.7911700, -71.3354200, 'CO', '2017-05-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27537, 'Oporapa', 'Oporapa', 'Oporapa', 2.0501500, -75.9767500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27538, 'Onzaga', 'Onzaga', 'Onzaga', 6.3443400, -72.8172600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27539, 'Olaya Herrera', 'Olaya Herrera', 'Hatillo,Olaya Herrera', 1.2480300, -77.4908500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27540, 'Oiba', 'Oiba', 'Oiba', 6.2638700, -73.2987600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27541, 'Ocaña', 'Ocana', 'Ocana,Ocaña,Okan''ja,Okanja,ao ka ni ya,awkanya,Оканья,اوکانیا,ოკანია,奧卡尼亞', 8.2377300, -73.3560400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27542, 'Obando', 'Obando', '', 4.5758300, -75.9738900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27543, 'Nuquí', 'Nuqui', 'NQU,Nugui,Nugul,Nuqui,Nuquí', 5.7125000, -77.2708300, 'CO', '2017-05-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27544, 'Nunchía', 'Nunchia', 'Nunchia,Nunchía', 5.6405600, -72.1986100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27545, 'Nueva Granada', 'Nueva Granada', 'Corregimiento Nueva Granada,Nueva Granada', 9.8016800, -74.3930400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27546, 'Nóvita', 'Novita', 'Novita,Nóvita,San Jeronimo,San Jerónimo', 4.9551100, -76.6052600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27547, 'Norcasia', 'Norcasia', 'Norcacia,Norcasia', 5.5778200, -74.8852100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27548, 'Nocaima', 'Nocaima', 'Nocaima', 5.0669600, -74.3843900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27549, 'Nobsa', 'Nobsa', 'Nobsa', 5.7697800, -72.9409900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27550, 'Nilo', 'Nilo', 'Nilo', 4.3060400, -74.6208300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27551, 'Nemocón', 'Nemocon', 'Nemocon,Nemocón', 5.0500000, -73.8833300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27552, 'Neiva', 'Neiva', 'NVA,Neiva,Nejva,Нейва', 2.9273000, -75.2818900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27553, 'Neira', 'Neira', 'Neira', 5.1665000, -75.5200100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27554, 'Necoclí', 'Necocli', 'Necocli,Necoclí,Nicocli,Nicoclí', 8.4262700, -76.7892600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27555, 'Nechí', 'Nechi', 'Nechi,Nechí', 8.0941900, -74.7757300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27556, 'Natagaima', 'Natagaima', 'Matagaima,Natagaima', 3.6205700, -75.0941500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27557, 'Nátaga', 'Nataga', 'Nataga,Nataja,Nátaga,Nátaja', 2.5435900, -75.8085200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27558, 'Nariño', 'Narino', 'Narino,Nariño', 5.6089300, -75.1765600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27559, 'Nariño', 'Narino', '', 4.3978100, -74.8273100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27560, 'Nariño', 'Narino', 'Narino,Nariño', 1.2899500, -77.3572100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27561, 'Muzo', 'Muzo', 'Muzo', 5.5352800, -74.1077800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27562, 'Mutatá', 'Mutata', 'Mutata,Mutatá', 7.2440700, -76.4356400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27563, 'Murindó', 'Murindo', '', 6.9848100, -76.7543900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27564, 'Murillo', 'Murillo', '', 4.8739300, -75.1715100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27565, 'Mountain', 'Mountain', 'La Montana,La Montaña,Montana,Montaña,Mountain', 13.3666700, -81.3666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27566, 'Mosquera', 'Mosquera', '', 4.7059200, -74.2302100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27567, 'Mosquera', 'Mosquera', '', 2.5086100, -78.4511000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27568, 'Morroa', 'Morroa', 'Morroa', 9.3334800, -75.3054200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27569, 'Morelia', 'Morelia', 'Moralia,Morelia', 1.4874700, -75.7258100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27570, 'Morales', 'Morales', 'Corregimiento Morales,Morales', 8.2752000, -73.8688400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27571, 'Montería', 'Monteria', 'MTR,Monteria,Monterija,Montería,San Jeronimo de Buenavista,San Jerónimo de Buenavista,Монтерия', 8.7479800, -75.8814300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27572, 'Montenegro', 'Montenegro', '', 4.5663900, -75.7511100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27573, 'Montelíbano', 'Montelibano', 'MTB,Montelibano,Montelíbano', 7.9791700, -75.4202000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27574, 'Montecristo', 'Montecristo', 'Corregimiento Montecristo,Montecristo', 8.2971000, -74.4733000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27575, 'Montebello', 'Montebello', '', 5.9480600, -75.5275000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27576, 'Moñitos', 'Monitos', 'Monito,Monitos,Moñito,Moñitos', 8.2500000, -76.0500000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27577, 'Moniquirá', 'Moniquira', 'Moniquira,Moniquirá', 5.8763800, -73.5728400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27578, 'Monguí', 'Mongui', 'Mongui,Mongul,Monguí', 5.7215100, -72.8490800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27579, 'Mongua', 'Mongua', 'Mongua', 5.7508400, -72.8033900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27580, 'Mompós', 'Mompos', 'Mompos,Mompós', 9.2419400, -74.4266700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27581, 'Momil', 'Momil', 'Corregimiento Momil,Momil', 9.2376700, -75.6748900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27582, 'Molagavita', 'Molagavita', 'Molagavita', 6.6731500, -72.8087500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27583, 'Mogotes', 'Mogotes', 'Mogotes', 6.4755900, -72.9704600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27584, 'Mocoa', 'Mocoa', 'Mocoa,Mokoa,mo ke a,mokoa,mwkwa,Мокоа,موکوآ,موکوا,მოკოა,莫科阿,모코아', 1.1528400, -76.6520800, 'CO', '2015-11-25', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27585, 'Mitú', 'Mitu', 'MVP,Mitu,Mitú', 1.2577800, -70.2347200, 'CO', '2017-03-04', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27586, 'Mistrató', 'Mistrato', 'Mistrato,Mistrató', 5.2962200, -75.8839000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27587, 'Miranda', 'Miranda', '', 3.2499100, -76.2281400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27588, 'Miraflores', 'Miraflores', 'Miraflores', 5.1960800, -73.1450400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27589, 'Miraflores', 'Miraflores', 'MFS,Miraflores', 1.3366700, -71.9511100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27590, 'Milán', 'Milan', 'Milan,Milán', 1.2920500, -75.5116700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27591, 'Mercaderes', 'Mercaderes', 'Mercaderes', 1.8017500, -77.1703200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27592, 'Melgar', 'Melgar', 'Mel''gar,Melgar,Мельгар', 4.2047500, -74.6407500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27593, 'Medina', 'Medina', 'MND,Medina', 4.5100500, -73.3498200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27594, 'Medellín', 'Medellin', 'Gorad Medehl''in,MDE,Medegin,Medel''in,Medelim,Medelin,Medeljina,Medeljinas,Medeljino,Medellin,Medellín,mai de lin,mdlyn,mdyyn,me de yin,medein,medejin,medelini,medeyina,meteyin,mydyllyn,mydylyn,Μεδεγίν,Горад Медэльін,Меделин,Медельин,Медельїн,Медељин,מדיין,مدلین,ميديللين,ميديلين,میڈیلن,मेदेयीन,মেদেয়িন,ਮੇਦੇਯੀਨ,மெதெயின்,เมเดยิน,მედელინი,ទីក្រុងមេឌេយីណ,メデジン,麦德林,메데인', 6.2518400, -75.5635900, 'CO', '2016-03-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27595, 'Matanza', 'Matanza', '', 7.3223300, -73.0151600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27596, 'Marulanda', 'Marulanda', 'Marulanda', 5.2839300, -75.2601600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27597, 'Marsella', 'Marsella', 'Marsella,Segovia', 4.9372200, -75.7377800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27598, 'Marquetalia', 'Marquetalia', 'Marquetalia,Nunez,Núñez', 5.2965900, -75.0549600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27599, 'Marmato', 'Marmato', 'Marmato', 5.4784300, -75.5926700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27600, 'Mariquita', 'Mariquita', 'MQU,Mariquita', 5.1988900, -74.8929500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27601, 'Maripí', 'Maripi', 'Maripi,Maripí', 5.5519400, -74.0086100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27602, 'Marinilla', 'Marinilla', 'Marinilla', 6.1735800, -75.3362100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27603, 'María la Baja', 'Maria la Baja', 'Maria la Baja,María la Baja', 9.9832000, -75.3015500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27604, 'Margarita', 'Margarita', '', 9.1559600, -74.2661800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27605, 'Manzanares', 'Manzanares', '', 5.3247200, -75.1569400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27606, 'Manta', 'Manta', 'Manta', 5.0086400, -73.5411500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27607, 'Manizales', 'Manizales', 'MZL,Manisales,Manisalesas,Manizales,ma ni sa lai si,manisalesi,manisalleseu,manisaresu,manyzalys,mnyzals,Манисалес,Манісалес,مانيزاليس,منیزالس,მანისალესი,マニサレス,馬尼薩萊斯,마니살레스', 5.0688900, -75.5173800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27608, 'Maní', 'Mani', 'Mani,Maní', 4.8172200, -72.2886100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27609, 'Manaure', 'Manaure', 'Manare,Manaure', 11.7750500, -72.4444700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27610, 'Manatí', 'Manati', 'Manati,Manatí', 10.4458900, -74.9586900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27611, 'Malambo', 'Malambo', 'Malambo', 10.8595300, -74.7738600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27612, 'Málaga', 'Malaga', '', 6.6990300, -72.7323300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27613, 'Majagual', 'Majagual', 'Majagual,Majagul', 8.5388600, -74.6203800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27614, 'Maicao', 'Maicao', 'MCJ,Maicao', 11.3832100, -72.2432100, 'CO', '2016-08-25', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27615, 'Mahates', 'Mahates', 'Mahales,Mahates', 10.2329300, -75.1898500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27616, 'Magangué', 'Magangue', 'MGN,Magange,Magangue,Magangué,Magangė,Manague,Mangue,ma gan ge,magange,Маганге,მაგანგე,馬甘格', 9.2420200, -74.7546700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27617, 'Madrid', 'Madrid', 'Madrid,Serrezuela,Мадрид', 4.7324500, -74.2641900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27618, 'Machetá', 'Macheta', 'Macheta,Machetá', 5.0815400, -73.6076100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27619, 'Maceo', 'Maceo', 'Maceo', 6.5519600, -74.7874100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27620, 'Luruaco', 'Luruaco', 'Luruaco', 10.6171200, -75.1514600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27621, 'Lourdes', 'Lourdes', 'Concepcion,Concepción,Lourdes', 7.9441100, -72.8325300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27622, 'Los Patios', 'Los Patios', 'Los Patios', 7.8379300, -72.5037000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27623, 'Los Palmitos', 'Los Palmitos', 'Corregimiento Los Palmitos,Los Palmitos,Palmitos', 9.3789900, -75.2676900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27624, 'Los Córdobas', 'Los Cordobas', 'Cordoba,Córdoba,Los Cordobas,Los Córdobas,Ricaurte', 8.8940300, -76.3545500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27625, 'Lorica', 'Lorica', '', 9.2364800, -75.8135000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27626, 'López', 'Lopez', '', 2.4333300, -76.8000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27627, 'Lloró', 'Lloro', 'Lloro,Lloró', 5.4960500, -76.5494500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27628, 'Linares', 'Linares', 'Linares', 1.3578300, -77.5272500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27629, 'Liborina', 'Liborina', 'Liborina', 6.6779000, -75.8121800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27630, 'Líbano', 'Libano', 'Libano,Líbano', 4.9218000, -75.0623200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27631, 'Leticia', 'Leticia', 'LET,Leticia,Leticija,Letisi,Letisija,Letícia,lai di xi ya,letisia,ltysya,ltysyh,lytykya,lytysya,lytysya  aymazwnas,retishia,Летиси,Летисия,Летиция,לטיסיה,לעטיסיע,لتیسیا,ليتيسيا,لیتیسیا، ایمازوناس,لیتیکیا,レティシア,萊蒂西亞,레티시아', -4.2152800, -69.9405600, 'CO', '2016-03-01', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27632, 'Lérida', 'Lerida', 'Lerida,Lérida', 4.8624200, -74.9097700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27633, 'Lenguazaque', 'Lenguazaque', 'Lenguazaque', 5.3071100, -73.7115200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27634, 'Leiva', 'Leiva', 'Leiva', 1.9338900, -77.3025300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27635, 'Lebrija', 'Lebrija', 'Lebrija', 7.1131700, -73.2178000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27636, 'La Virginia', 'La Virginia', 'La Virginia', 4.8997200, -75.8825000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27637, 'La Victoria', 'La Victoria', 'La Victoria,Victoria', 4.5248300, -76.0392100, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27638, 'La Vega', 'La Vega', 'La Vega,Vega', 5.0017700, -74.3417400, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27639, 'La Vega', 'La Vega', 'La Vega', 2.0062800, -76.7802800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27640, 'La Uvita', 'La Uvita', 'La Uvita,Ubita', 6.3206400, -72.5628100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27641, 'La Unión', 'La Union', 'La Union,La Unión', 8.8605600, -75.2805600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27642, 'La Unión', 'La Union', 'La Union,La Unión', 5.9743100, -75.3619500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27643, 'La Unión', 'La Union', 'La Unicion,La Union,La Unión,Lemos', 4.5328200, -76.1031800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27644, 'La Unión', 'La Union', '', 1.6045000, -77.1315200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27645, 'La Tebaida', 'La Tebaida', 'La Tebaida,Tebaida', 4.4526500, -75.7874600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27646, 'La Sierra', 'La Sierra', '', 2.1783500, -76.7626500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27647, 'La Primavera', 'La Primavera', 'La Primavera', 5.4905600, -70.4091700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27648, 'La Playa', 'La Playa', 'La Playa', 8.2163900, -73.2413900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27649, 'La Plata', 'La Plata', 'La Plata', 2.3934100, -75.8923200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27650, 'La Pintada', 'La Pintada', 'La Pintada,La-Pintada,la ping ta da,Ла-Пинтада,لا پینٹاڈا، کولومبیا,ლა-პინტადა,拉平塔達', 5.7486700, -75.6062600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27651, 'La Peña', 'La Pena', '', 5.1984700, -74.3936800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27652, 'La Paz', 'La Paz', '', 10.3843900, -73.1733200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27653, 'La Paz', 'La Paz', '', 6.1784800, -73.5894800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27654, 'Landázuri', 'Landazuri', 'Landazuri,Landázuri', 6.2182600, -73.8112100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27655, 'La Montañita', 'La Montanita', 'La Montanita,La Montañita,Montanita,Montañita', 1.4766000, -75.4398000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27656, 'La Mesa', 'La Mesa', '', 5.2666700, -73.9166700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27657, 'La Merced', 'La Merced', '', 5.4019400, -75.8847200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27658, 'La Llanada', 'La Llanada', 'La Llanada,Llanada', 1.4899700, -77.5834700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27659, 'La Jagua de Ibirico', 'La Jagua de Ibirico', 'Jagua,La Jagua,La Jagua de Ibirico', 9.5622800, -73.3340500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27660, 'La Gloria', 'La Gloria', '', 8.6186800, -73.8026500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27661, 'La Florida', 'La Florida', 'Florida,La Florida', 1.2985100, -77.4061400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27662, 'La Estrella', 'La Estrella', 'Estrella,La Estrella,La-Ehstrel''ja,Ла-Эстрелья', 6.1576900, -75.6431700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27663, 'La Esperanza', 'La Esperanza', '', 8.2104300, -72.4639900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27664, 'La Dorada', 'La Dorada', 'Dorada,La Dorada,La-Dorada,Ла-Дорада', 5.4478300, -74.6631100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27665, 'La Cruz', 'La Cruz', 'La Cruz', 1.6030100, -76.9690100, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27666, 'La Celia', 'La Celia', 'La Celia', 5.0433300, -76.0166700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27667, 'La Ceja', 'La Ceja', 'La Ceja', 6.0313100, -75.4333300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27668, 'La Capilla', 'La Capilla', '', 5.7049300, -73.4752700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27669, 'La Calera', 'La Calera', 'La Calera', 4.7206900, -73.9692600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27670, 'La Belleza', 'La Belleza', 'La Belleza', 5.8637100, -73.9616700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27671, 'Juradó', 'Jurado', 'JUO,Jurado,Juradó', 7.1042100, -77.7620000, 'CO', '2015-12-04', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27672, 'Junín', 'Junin', 'Chipasaque,Junin,Junín', 4.7902700, -73.6601100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27673, 'Juan de Acosta', 'Juan de Acosta', 'Juan de Acosta', 10.8281300, -75.0334100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27674, 'Jericó', 'Jerico', 'Jerico,Jericó', 5.7921100, -75.7860100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27675, 'Jenesano', 'Jenesano', 'Jenesano,Jenezano,Piranguata', 5.3854100, -73.3636400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27676, 'Jardín', 'Jardin', 'Jardin,Jardín', 5.5990200, -75.8197600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27677, 'Jamundí', 'Jamundi', 'El Rosario,Jamundi,Jamundí,Khamundi,Хамунди', 3.2607400, -76.5349900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27678, 'Jambaló', 'Jambalo', '', 2.7922500, -76.3225900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27679, 'Ituango', 'Ituango', 'Ituango', 7.1711700, -75.7640400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27680, 'Itagüí', 'Itaguei', 'Itagoui,Itagui,Itagüí,atagwy,aytagwyy,yi ta gui,Ιταγουί,Итагуи,اتاگوی,ایتاگویی,伊塔圭', 6.1846100, -75.5991300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27681, 'Istmina', 'Istmina', 'Istmia,Istmina,Istmino,Itsmina', 5.1605400, -76.6839700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27682, 'Iscuandé', 'Iscuande', 'Iscande,Iscandé,Iscuande,Iscuandé,Santa Barbara,Santá Barbara', 2.4500700, -77.9793600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27683, 'Íquira', 'Iquira', 'Iquira,Íquira', 2.6486700, -75.6345700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27684, 'Ipiales', 'Ipiales', 'Gorad Ipijales,IPI,Ip''jales,Ipiales,Ipjalesas,yi pi ya lai si,Горад Іпіялес,Ипьялес,伊皮亞萊斯', 0.8301800, -77.6495900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27685, 'Inzá', 'Inza', 'Inza,Inzá', 2.5545200, -76.0672200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27686, 'Imués', 'Imues', 'Imues,Imués', 1.0529500, -77.5017100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27687, 'Iles', 'Iles', 'Iles', 0.9749100, -77.5274100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28403, 'Vila Nova Sintra', 'Vila Nova Sintra', 'Vila Nova Cinteus,Vila Nova Sintra,Vila de Nova Cintra,Vila de Nova Sintra', 14.8666700, -24.7166700, 'CV', '2013-08-03', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28404, 'Vila do Maio', 'Vila do Maio', 'MMO,Maio,Nossa Senhora da Luz,Port Ingles,Porto Ingles,Porto Inglez,Porto Inglês,Vila do Maio,Vila do Porto Ingles,Vila do Porto Inglês', 15.1382300, -23.2115800, 'CV', '2016-09-24', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28405, 'Vila da Ribeira Brava', 'Vila da Ribeira Brava', 'Ribeira Brava,Vila da Ribeira Brava', 16.6166700, -24.3000000, 'CV', '2012-02-28', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28406, 'Tarrafal de São Nicolau', 'Tarrafal de Sao Nicolau', 'Tarrafal', 16.5666700, -24.3666700, 'CV', '2013-08-03', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28407, 'Tarrafal', 'Tarrafal', 'Tarrafal,Vila do Tarrafal', 15.2788100, -23.7519200, 'CV', '2014-10-06', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28408, 'São Filipe', 'Sao Filipe', 'Luz,SFL,Saint Philip,Sao Filipe,São Filipe,Vila de Sao Filippe,Vila de São Filippe,sheng fei li pu xian,聖菲利普縣', 14.8961000, -24.4955600, 'CV', '2014-12-01', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28409, 'São Domingos', 'Sao Domingos', 'San-Domingos,Сан-Домингос', 15.0243800, -23.5625000, 'CV', '2010-06-08', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28410, 'Santa Maria', 'Santa Maria', 'Santa Maria', 16.5979600, -22.9050900, 'CV', '2017-07-12', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28411, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 15.1333300, -23.5666700, 'CV', '2012-01-18', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28412, 'Vila de Sal Rei', 'Vila de Sal Rei', 'Sal Rei,Sal-Rel,Vila de Sal Rei', 16.1833300, -22.9166700, 'CV', '2014-07-21', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28413, 'Ribeira Grande', 'Ribeira Grande', 'Puvuason,R''bera Grend,Ribeira Grande,R’bera Grénd', 17.1856100, -25.0724300, 'CV', '2013-08-11', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28414, 'Praia', 'Praia', 'Braia,Cidade da Praia,Gorad Praja,Municipio da Praia,Município da Praia,Pragia,Praia,Praja,Praje,Prajo,Prajė,Praya,RAI,braya,pei ya,peulaia,pirxa,pra''i''a,pra''iya,praya,prayya,puraia,Πράγια,Πράια,Горад Прая,Прая,Праја,Պրայա,פראיה,برايا,پرائا,پرائیا,پرايا,پرایا,پڕایا,प्राईया,ਪ੍ਰਾਈਆ,ไปรอา,ཕུ་ར་ཡ།,პრაია,ፕራያ,プライア,培亞,프라이아', 14.9315200, -23.5125400, 'CV', '2012-06-05', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28415, 'Porto Novo', 'Porto Novo', 'Carvoeiros,Vila do Porto Novo,Vila do Pôrto Novo,alto de peixim', 17.0196900, -25.0647100, 'CV', '2012-02-12', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28416, 'Porto dos Mosteiros', 'Porto dos Mosteiros', '', 15.0333300, -24.3333300, 'CV', '2006-01-17', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28417, 'Ponta do Sol', 'Ponta do Sol', 'Sol Point', 17.2017100, -25.0921700, 'CV', '2017-07-12', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28418, 'Pombas', 'Pombas', 'Pombas,Vila das Pombas', 17.1502600, -25.0200700, 'CV', '2012-01-18', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28419, 'Picos', 'Picos', 'Picos,Pikus', 15.0836000, -23.6323600, 'CV', '2013-08-03', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28420, 'Mindelo', 'Mindelo', 'Mihdelo,Mindelas,Mindello,Mindelo,Mindelu,Mintelo,mindellu,mindero,ming de lu,Μιντέλο,Минделу,Мінделу,ミンデロ,明德盧,민델루', 16.8901400, -24.9804200, 'CV', '2013-06-06', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28421, 'Cova Figueira', 'Cova Figueira', 'Cova Figueira,Koba Figera,Kóba Figera', 14.8905400, -24.2934300, 'CV', '2013-08-02', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28422, 'Cidade Velha', 'Cidade Velha', 'Cidade Velha,Sidade Vel''ja,Sidade Velia,Sidade Velja,Sidade-Vel''ja,Sidadi-Vel''ja,Velha,jiu cheng,sidade-velia,sidadeubellya,sydady fylha,Σιδάδε Βέλια,Сидаде Велья,Сидади-Велья,Сідаде-Велья,סידאדה וליה,سيدادي فيلها,სიდადე-ველია,シダーデ・ヴェーリャ,舊城,시다드벨랴', 14.9153100, -23.6052700, 'CV', '2017-07-11', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28423, 'Calheta', 'Calheta', '', 15.1861300, -23.5922800, 'CV', '2013-08-08', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28424, 'Assomada', 'Assomada', 'Assomada,Assumada', 15.1000000, -23.6833300, 'CV', '2012-01-18', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28425, 'João Teves', 'Joao Teves', 'Joao Teves,João Teves', 15.0645700, -23.5896900, 'CV', '2013-06-06', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28426, 'Pedra Badejo', 'Pedra Badejo', 'Pedra Badejo', 15.1349300, -23.5321500, 'CV', '2013-08-03', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28427, 'Espargos', 'Espargos', 'Espargos', 16.7552400, -22.9446000, 'CV', '2013-04-18', 38);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28432, 'Flying Fish Cove', 'Flying Fish Cove', 'Flaing Fish Kouv,Flajing Fish Kouv,Flajing-Fish-Kouv,Flayinq Fis Kouv,Flayinq Fiş Kouv,Flying Fish Cove,Gorad Flain-Fish-Kouv,The Settlement,fala''iga fisa kova,fei yu wan,flay xing fich khof,flayngh fysh kwf,flayyng fsh kww,peullaingpisikobeu,phla''inga phisa kova,pilaiyin pis kov,plaing-pishi,Горад Флаін-Фіш-Коўв,Флаинг Фиш Коув,Флайинг-Фиш-Коув,Флајинг Фиш Коув,فلائینگ فش کوو,فلاينغ فيش كوف,फ्लाइंग फिश कोव,ਫ਼ਲਾਇੰਗ ਫ਼ਿਸ਼ ਕੋਵ,பிளையிங் பிஷ் கோவ்,ฟลายอิงฟิชโคฟ,ფლაინგ-ფიში,フライング・フィッシュ・コーブ,飞鱼湾,플라잉피시코브', -10.4217200, 105.6791200, 'CX', '2015-10-18', 47);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27688, 'Icononzo', 'Icononzo', 'Icononzo', 4.1769800, -74.5325400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27689, 'Ibagué', 'Ibague', 'Gorad Ibageh,IBE,Ibage,Ibague,Ibagué,Ibagė,abajy,ibage,yi wa ge,Ібаге,Горад Ібагэ,Ибаге,أباجي,اباگوۓ,იბაგე,イバゲ,伊瓦格,이바게', 4.4388900, -75.2322200, 'CO', '2017-02-13', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27690, 'Honda', 'Honda', 'Honda', 5.2085600, -74.7358400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27691, 'Hobo', 'Hobo', 'El Hobo,Hobo', 2.5833300, -75.4500000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27692, 'Hispania', 'Hispania', 'Hispania', 5.7992500, -75.9071800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27693, 'Herveo', 'Herveo', 'Herbeo,Herveo', 5.0833300, -75.1666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27694, 'Herrán', 'Herran', 'Herran,Herrán', 7.5061100, -72.4833200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27695, 'Heliconia', 'Heliconia', 'Heliconia', 6.2083100, -75.7356500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27696, 'Municipio Hato Corozal', 'Municipio Hato Corozal', 'Corozal,HTZ,Hato de Corozal,Hato del Corozal,Municipio Hato Corozal', 6.1567600, -71.7637200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27697, 'Hatillo de Loba', 'Hatillo de Loba', 'Corregimiento Hatillo de Loba,El Hatillo de Loba,Hatillo,Hatillo de Loba', 8.9563500, -74.0781900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27698, 'Hacarí', 'Hacari', 'Hacari,Hacarí,La Palma', 8.3233300, -73.1488900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27699, 'Güicán', 'Gueican', 'Guican,Güicán', 6.4655400, -72.4153900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27700, 'Güepsa', 'Gueepsa', 'Guepsa,Güepsa', 6.0250500, -73.5731300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27701, 'Guayatá', 'Guayata', 'Guayata,Guayatá', 4.9641700, -73.4875000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27702, 'Guayabetal', 'Guayabetal', 'Guayabetal', 4.2147200, -73.8171900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27703, 'Guayabal de Síquima', 'Guayabal de Siquima', 'Guayabal,Guayabal Siquima,Guayabal de Siquima,Guayabal de Síquima,Siquima,Síquima', 4.8773900, -74.4674400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27704, 'Guática', 'Guatica', 'Guatica,Guática', 5.3156900, -75.7982600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27705, 'Guateque', 'Guateque', 'Guateque', 5.0061900, -73.4727400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27706, 'Guatavita', 'Guatavita', 'Guatavita', 4.9365800, -73.8331400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27707, 'Guataquí', 'Guataqui', 'Guataqui,Guataquí', 4.5157300, -74.7893500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27708, 'Guatapé', 'Guatape', 'Guatape,Guatapé', 6.2342900, -75.1633500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27709, 'Guasca', 'Guasca', 'Guasca', 4.8660100, -73.8774800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27710, 'Guarne', 'Guarne', 'Guarne', 6.2804600, -75.4435400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27711, 'Guapi', 'Guapi', 'GPI,Guapi', 2.5708200, -77.8854200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27712, 'Guamo', 'Guamo', 'Guamo', 4.0307800, -74.9701000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27713, 'Guamal', 'Guamal', 'GAA,Guamal', 9.1433400, -74.2238400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27714, 'Guamal', 'Guamal', 'Guamal', 3.8804300, -73.7656600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27715, 'Gualmatán', 'Gualmatan', 'Gualmatan,Gualmatán', 0.9188800, -77.5665100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27716, 'Guaitarilla', 'Guaitarilla', 'Guaitarilla,Guaitarrilla', 1.1310300, -77.5481500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27717, 'Guaduas', 'Guaduas', 'Guaduas', 5.0669200, -74.5949900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27718, 'Guadalupe', 'Guadalupe', 'Guadalupe,Planta', 6.8144900, -75.2406300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27719, 'Guadalupe', 'Guadalupe', 'Guadalupe', 6.2464000, -73.4183300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27720, 'Guadalupe', 'Guadalupe', 'Guadalupe', 2.0248000, -75.7558900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27721, 'Guachucal', 'Guachucal', 'Guachegal,Guachucal', 0.9609300, -77.7316100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27722, 'Guachetá', 'Guacheta', 'Guacheta,Guachetá', 5.3842500, -73.6861700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27723, 'Guacarí', 'Guacari', 'Concordia,Guacari,Guacarí', 3.7638300, -76.3329200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27724, 'Guaca', 'Guaca', 'Guaca', 6.8762100, -72.8559400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27725, 'Granada', 'Granada', 'Granada,Grenada,Гренада', 6.1435300, -75.1853200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27726, 'Granada', 'Granada', '', 5.0666700, -74.5666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27727, 'Granada', 'Granada', 'Boca de Monte,Granada,Grenada,Гренада', 3.5462500, -73.7068700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27728, 'Gramalote', 'Gramalote', 'Gramalote,ge la ma luo te,გრამალოტე,格拉馬洛特', 7.8875200, -72.7974900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27729, 'González', 'Gonzalez', 'Gonzales,Gonzalez,Gonzáles,González', 8.3894400, -73.3798900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27730, 'Gómez Plata', 'Gomez Plata', 'Gomez Plata,Gómez Plata', 6.6817800, -75.2190700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27731, 'Girón', 'Giron', 'Giron,Girón,Khiron,Хирон', 7.0682000, -73.1698100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27732, 'Girardot City', 'Girardot City', 'GIR,Girardot,Zhirardo,Жирардо', 4.3007900, -74.8075400, 'CO', '2014-09-29', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27733, 'Giraldo', 'Giraldo', 'Giraldo', 6.6830600, -75.9891700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27734, 'Ginebra', 'Ginebra', 'Ginebra', 3.7246100, -76.2667500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27735, 'Gigante', 'Gigante', 'Gigante', 2.3867800, -75.5473600, 'CO', '2015-02-13', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27736, 'Génova', 'Genova', '', 4.3166700, -75.7666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27737, 'Génova', 'Genova', 'Capital Genova,Capital Génova,Colon,Colón,Genova,Génova', 1.6432200, -77.0243300, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27738, 'Garzón', 'Garzon', 'GLJ,Garzon,Garzón', 2.1959300, -75.6277700, 'CO', '2017-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27739, 'Garagoa', 'Garagoa', 'Garagoa,garagoa,jia la ge a,გარაგოა,加拉戈阿', 5.0823600, -73.3633400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27740, 'Gámeza', 'Gameza', 'Gameza,Gámeza', 5.8026300, -72.8058600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27741, 'Gamarra', 'Gamarra', '', 8.3227900, -73.7426800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27742, 'Galeras', 'Galeras', 'Corregimiento Nueva Granada,Galeras,Nueva Granada', 9.1609500, -75.0481100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27743, 'Galapa', 'Galapa', 'Galapa', 10.8968600, -74.8860000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27744, 'Galán', 'Galan', 'Galan,Galán', 6.6378100, -73.2887800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27745, 'Gachancipá', 'Gachancipa', 'Gachacipa,Gachancipa,Gachancipá', 4.9911100, -73.8715400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27746, 'Gachalá', 'Gachala', 'Gachala,Gachalá', 4.6924400, -73.5204200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27747, 'Fusagasuga', 'Fusagasuga', 'Fusagasuga', 4.3364600, -74.3637800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27748, 'Funza', 'Funza', 'Funza', 4.7163800, -74.2119500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27749, 'Funes', 'Funes', 'Funes', 1.0026600, -77.4506700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27750, 'Fundación', 'Fundacion', 'Fundacion,Fundación', 10.5206600, -74.1850400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27751, 'Fuente de Oro', 'Fuente de Oro', 'Fuente de Oro,Municipio Fuente de Oro,San Antonio,San Antonio Ariari', 3.4626300, -73.6216200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27752, 'Frontino', 'Frontino', 'Frontino', 6.7713300, -76.1332400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27753, 'Fresno', 'Fresno', 'Fresno', 5.1526400, -75.0362400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27754, 'Fosca', 'Fosca', 'Fosca', 4.3391600, -73.9385200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27755, 'Fortoul', 'Fortoul', 'Fortoul,Municipio de Fortul', 6.7926100, -71.7759600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27756, 'Fonseca', 'Fonseca', '', 10.8860600, -72.8487000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27757, 'Fómeque', 'Fomeque', 'Fomeque,Fómeque', 4.4879700, -73.8974900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27758, 'Floridablanca', 'Floridablanca', 'Florida,Floridablanca', 7.0622200, -73.0864400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27759, 'Florida', 'Florida', 'Florida,La Florida,Perodias,Perodías,Флорида', 3.3223000, -76.2348000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27760, 'Florián', 'Florian', 'Florian,Florián', 5.8048700, -73.9702900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27761, 'Floresta', 'Floresta', '', 5.8590300, -72.9188200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27762, 'Florencia', 'Florencia', 'Florencia,Florencio', 1.6831800, -77.0733100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27763, 'Florencia', 'Florencia', 'FLA,Florencia', 1.6143800, -75.6062300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27764, 'Flandes', 'Flandes', 'Flandes', 4.2900500, -74.8161200, 'CO', '2014-09-29', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27765, 'Firavitoba', 'Firavitoba', 'Firavitoba,Firavitova', 5.6688500, -72.9928900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27766, 'Filandia', 'Filandia', 'Filandia,Finlandia', 4.6747200, -75.6583300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27767, 'Filadelfia', 'Filadelfia', 'Filadelfia', 5.2960600, -75.5612000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27768, 'Falan', 'Falan', 'Falan,Santa Ana,Santana,Santana de Lajas', 5.1156400, -74.9489400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27769, 'Facatativá', 'Facatativa', 'Facatativa,Facatativá,Fakatativa,fa ka ta di wa,fakatatywa,Φακατατιβά,Факататива,فاکاتاتیوا,فیکاٹیٹوا,ფაკატატივა,法卡塔蒂瓦', 4.8136700, -74.3545300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27770, 'Espinal', 'Espinal', 'Ehspinal'',El Espinal,Espinal,Эспиналь', 4.1492400, -74.8842900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27771, 'Envigado', 'Envigado', 'Ehnvigado,Envigadas,Envigado,anwygadw,aymbygadw,en wei jia duo,Ενβιγάδο,Енвигадо,Энвигадо,انویگادو,ایمبیگادو,恩維加多', 6.1759100, -75.5917400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27772, 'Entrerríos', 'Entrerrios', 'Entrerrios,Entrerríos', 6.5654000, -75.5169000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27773, 'El Zulia', 'El Zulia', 'El Zulia,Villa Zulia,Zulia', 7.9324800, -72.6012500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27774, 'El Tambo', 'El Tambo', 'El Tambo,Tambo', 2.4519900, -76.8102900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27775, 'El Tambo', 'El Tambo', 'El Tambo,Tambo', 1.4181400, -77.3967800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27776, 'El Tablón', 'El Tablon', 'El Tablon,El Tablón,Tablon', 1.4318800, -77.0966400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27777, 'El Rosario', 'El Rosario', 'El Rosario,Rosario', 1.7417300, -77.3352000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27778, 'El Rosal', 'El Rosal', 'El Rosal', 4.8531400, -74.2599600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27779, 'El Roble', 'El Roble', 'El Roble', 9.1019300, -75.1950800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27780, 'El Retén', 'El Reten', 'Corregimiento El Reten,El Reten,El Retén,Reten', 10.6113500, -74.2682400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27781, 'El Piñón', 'El Pinon', 'El Pinon,El Piñón,Pinon,Pinón', 10.4028300, -74.8241500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27782, 'El Peñón', 'El Penon', 'El Penon,El Peñón', 8.9891600, -73.9485700, 'CO', '2012-05-06', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27783, 'El Peñol', 'El Penol', 'El Penol,El Peñol,Penol,Peñol', 1.4598700, -77.4454400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27784, 'El Paujil', 'El Paujil', 'El Paujil,Pajuil', 1.5700600, -75.3286300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27785, 'El Paso', 'El Paso', 'Corregimiento El Paso,El Paso', 9.6572400, -73.7468500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27786, 'El Molino', 'El Molino', 'El Molino,Molino', 10.6522500, -72.9240500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27787, 'Elías', 'Elias', 'Elias,Elías', 2.0117000, -75.9396800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27788, 'El Guamo', 'El Guamo', 'El Guamo,Guamo', 10.0315500, -74.9761200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27789, 'El Espino', 'El Espino', 'El Espino,Espino', 6.4827700, -72.4971800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27790, 'El Dovio', 'El Dovio', 'El Dovio', 4.5079000, -76.2361900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27791, 'El Doncello', 'El Doncello', 'El Doncello', 1.6781700, -75.2846600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27792, 'El Copey', 'El Copey', 'Copei,Corregimiento El Copey,El Copey', 10.1503100, -73.9614000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27793, 'El Cocuy', 'El Cocuy', 'Cocuy,El Cocuy', 6.4115100, -72.4487600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27794, 'El Charco', 'El Charco', 'Charco,El Charco', 2.4769100, -78.1104900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27795, 'El Cerrito', 'El Cerrito', 'Cerrito,El Cerrito', 3.6854900, -76.3137200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27796, 'El Castillo', 'El Castillo', 'El Castillo', 3.5636300, -73.7948800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27797, 'El Carmen de Bolívar', 'El Carmen de Bolivar', 'Carmen,El Carmen,El Carmen de Bolivar,El Carmen de Bolívar,Karmen-de-Bolivar,Кармен-де-Боливар', 9.7174000, -75.1202300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27798, 'El Carmen', 'El Carmen', 'Carmen,El Carmen', 8.5106400, -73.4477600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27799, 'El Carmen', 'El Carmen', 'Carmen,El Carmen', 6.6973600, -73.5111700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27800, 'El Carmen', 'El Carmen', 'Carmen,El Carmen', 5.8877800, -75.1641700, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27801, 'El Cairo', 'El Cairo', 'El Cairo', 4.7627900, -76.2210000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27802, 'El Bordo', 'El Bordo', 'El Bordo,Patia,Patía', 2.1169600, -76.9821400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27803, 'El Banco', 'El Banco', 'Banco,ELB,Ehl''-Banka,El Banco,Эль-Банка', 9.0011400, -73.9758100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27804, 'El Bagre', 'El Bagre', 'EBG,Ehl''-Bagre,El Bagre,ai er ba ge lai,al bagrh,el-bagre,Эль-Багре,ال باگره,ელ-ბაგრე,埃爾巴格萊', 7.6034700, -74.8095100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27805, 'El Águila', 'El Aguila', '', 4.9134500, -76.0400400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27806, 'Ebéjico', 'Ebejico', 'Ebejico,Ebéjico', 6.3259800, -75.7683500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27807, 'Durania', 'Durania', 'Durania', 7.7130700, -72.6575900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27808, 'Duitama', 'Duitama', 'Douitama,Duitama,du yi ta ma,Δουιτάμα,Дуитама,杜伊塔馬', 5.8245000, -73.0340800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27809, 'Dos Quebradas', 'Dos Quebradas', 'Dos Quebradas', 4.8391600, -75.6672700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27810, 'Don Matías', 'Don Matias', 'Don Matias,Don Matías', 6.4856900, -75.3949600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27811, 'Distracción', 'Distraccion', 'Distraccion,Distracción', 10.8969300, -72.8861000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27812, 'Dibulla', 'Dibulla', 'Corregimiento Dibulla,Dibulla', 11.2725100, -73.3091100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27813, 'Dagua', 'Dagua', 'Dagua,Papagalleros', 3.6568500, -76.6885900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27814, 'Dabeiba', 'Dabeiba', 'Dabeiba,Dabelba', 7.0001700, -76.2691500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27815, 'Curumaní', 'Curumani', 'Corregimiento Curumani,Corregimiento Curumaní,Curumani,Curumaní,Kurumani,Курумани', 9.1999200, -73.5427400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27816, 'Curití', 'Curiti', 'Curiti,Curití,Curuti', 6.6051900, -73.0680900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27817, 'Cunday', 'Cunday', 'Cunday,Parroquia Vieja', 4.0600400, -74.6921200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27818, 'Cumbitara', 'Cumbitara', 'Cumbitara,San Pedro', 1.6517400, -77.5822500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27819, 'Cumbal', 'Cumbal', '', 0.9087500, -77.7914500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27820, 'Cumaral', 'Cumaral', 'Cumaral', 4.2708000, -73.4866900, 'CO', '2016-03-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27821, 'Cucutilla', 'Cucutilla', 'Cucutilla', 7.5394100, -72.7723800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27822, 'Cúcuta', 'Cucuta', 'CUC,Cucuta,Cúcuta,Gorad Kukuta,Kukuta,San Jose de Cucuta,San Jose de Guacimal,San José de Cùcuta,San José de Cúcuta,San José de Guacimal,ku ku ta,kukuta,kwkwta,swswta,Горад Кукута,Кукута,سوسوتا,کوکوتا,กูกูตา,კუკუტა,ククタ,库库塔,쿠쿠타', 7.8939100, -72.5078200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27823, 'Cucunubá', 'Cucunuba', 'Cucunuba,Cucunubá', 5.2495800, -73.7661000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27824, 'Cucaita', 'Cucaita', 'Cucaita', 5.5437300, -73.4543300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27825, 'Cubará', 'Cubara', 'Cubara,Cubará', 7.0057800, -72.1056800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27826, 'Cruces de Anorí', 'Cruces de Anori', 'Anori,Cruces de Anori,Cruces de Anorí', 7.1833300, -75.0666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27827, 'Cravo Norte', 'Cravo Norte', 'Corregimiento Cravo Norte,Cravo,Cravo Norte,Gravo,RAV', 6.3017300, -70.2041500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27828, 'Coyaima', 'Coyaima', '', 3.7993600, -75.1946700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27829, 'Cotorra', 'Cotorra', 'Corregimiento Cotorra,Cotorra', 9.0388600, -75.7896900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27830, 'Cota', 'Cota', 'Cota', 4.8093800, -74.0980000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27831, 'Corrales', 'Corrales', 'Corrales', 5.8296800, -72.8433200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27832, 'Corozal', 'Corozal', 'CZU,Corozal', 9.3150500, -75.2928300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27833, 'Coromoro', 'Coromoro', 'Coromoro', 6.2946100, -73.0402200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27834, 'Corinto', 'Corinto', 'Corinto', 3.1730100, -76.2627500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27835, 'Córdoba', 'Cordoba', 'Cordoba,Cordova,Córdoba,Teton,Tetón', 9.5861200, -74.8270500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27836, 'Córdoba', 'Cordoba', 'Cordoba,Cordova,Córdoba,Córdova', 4.3931800, -75.6893500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27837, 'Córdoba', 'Cordoba', 'Cordoba,Córdoba,Males', 0.8590500, -77.5195000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27838, 'Municipio de Copacabana', 'Municipio de Copacabana', 'Copacabana,Kopakabana,Municipio de Copacabana,Копакабана', 6.3463300, -75.5088800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27839, 'Contratación', 'Contratacion', 'Contratacion,Contratación', 6.2900500, -73.4735400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27840, 'Contadero', 'Contadero', 'Contadero', 0.9070000, -77.5472900, 'CO', '2016-03-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27841, 'Consacá', 'Consaca', 'Consaca,Consacá', 1.2080500, -77.4654800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27842, 'Condoto', 'Condoto', 'COG,Condoto', 5.0935100, -76.6497300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27843, 'Concordia', 'Concordia', 'Concordia,Hacienda Concordia', 9.8354500, -74.4554800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27844, 'Concordia', 'Concordia', 'Concordia,Konkordija,kong ke er di ya,kwnkwrdya,Конкордия,کونکوردیا,კონკორდია,孔科爾迪亞', 6.0463900, -75.9070500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27845, 'Concepción', 'Concepcion', 'Concepcion,Concepción', 6.7661900, -72.6940000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27846, 'Concepción', 'Concepcion', 'Concepcion,Concepción', 6.3940800, -75.2583000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27847, 'Combita', 'Combita', '', 5.6333300, -73.3166700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27848, 'Colosó', 'Coloso', 'Coloso,Colosó,Ricaurte', 9.4915000, -75.3614500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27849, 'Colón', 'Colon', 'Colon,Colón', 1.1903400, -76.9736900, 'CO', '2015-06-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27850, 'Colombia', 'Colombia', 'Colombia', 3.3760600, -74.8015000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27851, 'Cogua', 'Cogua', 'Cogua', 5.0605100, -73.9792500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27852, 'Cocorná', 'Cocorna', 'Cocorna,Cocorná', 6.0573000, -75.1852400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27853, 'Clemencia', 'Clemencia', 'Clemencia', 10.5664500, -75.3249900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27854, 'Cisneros', 'Cisneros', '', 6.5383300, -75.0886100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27855, 'Circasia', 'Circasia', 'Circacia,Circasia', 4.6188900, -75.6358300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27856, 'Cimitarra', 'Cimitarra', 'CIM,Cimitarra', 6.3141900, -73.9496800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27857, 'Ciénega', 'Cienega', 'Cienaga,Cienega,Ciénaga,Ciénega,sienega,xie na jia,სიენეგა,謝納加', 5.4086700, -73.2957200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27858, 'Ciénaga de Oro', 'Cienaga de Oro', 'Cienaga de Oro,Ciénaga de Oro', 8.8744300, -75.6202800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27859, 'Ciénaga', 'Cienaga', 'Cienaga,Ciénaga,San Juan de Cienaga,San Juan de Ciénaga,Sienaga,Сиенага', 11.0070300, -74.2476500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27860, 'Cicuco', 'Cicuco', 'Caserio Sicuco,Caserío Sicuco,Cicuco', 9.2630600, -74.6569400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27861, 'Chocontá', 'Choconta', 'Choconta,Chocontá', 5.1446800, -73.6857800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27862, 'Choachí', 'Choachi', 'Choachi,Choachí', 4.5289700, -73.9227300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27863, 'Chivolo', 'Chivolo', 'Chibolo,Chivolo,Chivoto,Corregimiento Chivolo,IVO', 10.0250200, -74.6227900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27864, 'Chitagá', 'Chitaga', 'Chitaga,Chitagá', 7.1378100, -72.6645600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27865, 'Chita', 'Chita', 'Chita', 6.1905300, -72.4758800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27866, 'Chiscas', 'Chiscas', 'Chiscas', 6.5564200, -72.5037800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27867, 'Chiriguaná', 'Chiriguana', 'Chiriguana,Chiriguaná', 9.3623800, -73.6031300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27868, 'Chiquinquirá', 'Chiquinquira', 'Chiquinquira,Chiquinquirá', 5.6163700, -73.8174800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27869, 'Chipaque', 'Chipaque', 'Chipaque', 4.4425000, -74.0441700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27870, 'Chinú', 'Chinu', 'Chinu,Chinú', 9.1056900, -75.3981200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27871, 'Chinchiná', 'Chinchina', 'Chinchina,Chinchiny,Chinchiná,Чинчины', 4.9825000, -75.6036100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27872, 'Chinavita', 'Chinavita', 'Chinavita', 5.1672300, -73.3682300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27873, 'Chinácota', 'Chinacota', 'Chinacota,Chinácota', 7.6073100, -72.6010800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27874, 'Chimichagua', 'Chimichagua', 'Chimichagua,Chimicragua', 9.2577800, -73.8122800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27875, 'Chimá', 'Chima', 'Chima,Chimá', 9.1489300, -75.6284100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27876, 'Chigorodó', 'Chigorodo', 'Chigorodo,Chigorodó', 7.6663800, -76.6810600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27877, 'Chía', 'Chia', 'Chia,Chía', 4.8587600, -74.0586600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27878, 'Chaparral', 'Chaparral', 'CPL,Chaparral', 3.7231500, -75.4831600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27879, 'Chalán', 'Chalan', 'Chaflan,Chalan,Chalán', 9.5476500, -75.3112800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27880, 'Chaguaní', 'Chaguani', 'Chaguani,Chaguaní', 4.9482900, -74.5939200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27881, 'Chachagüí', 'Chachaguei', '', 1.3594300, -77.2836700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27882, 'Cértegui', 'Certegui', 'Certegui,Certigui,Cértegui', 5.3707300, -76.6044000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27883, 'Cerro de San Antonio', 'Cerro de San Antonio', 'Cerro San Antonio,Cerro de San Antonio,El Cerro', 10.3258500, -74.8693300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27884, 'Cerrito', 'Cerrito', 'Cerrito,Villa del Rosario', 6.8431500, -72.6940400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27885, 'Cerinza', 'Cerinza', '', 5.9556800, -72.9478300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27886, 'Cereté', 'Cerete', 'Cerete,Cereté', 8.8847900, -75.7905200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27887, 'Caucasia', 'Caucasia', 'CAQ,Canafistola,Caucasia,Cañafístola,Kaukasija,Kavkaz,kao ka xi ya,kawkasya,Кавказ,Каукасия,کاوکاسیا,კაუკასია,考卡西亞', 7.9865400, -75.1934900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27888, 'Castilla La Nueva', 'Castilla La Nueva', 'Castilla,Castilla La Nueva,Shell', 3.8272200, -73.6883100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27889, 'Casabianca', 'Casabianca', 'Casabianca,Casablanca', 5.0795900, -75.1205900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27890, 'Cartago', 'Cartago', 'CRC,Cartago', 4.7463900, -75.9116700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27891, 'Cartago', 'Cartago', 'Cartago,Kartago,San Pedro de Cartago,Картаго', 1.5630500, -77.1176000, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27892, 'Cartagena', 'Cartagena', 'CTG,Caratagena de Indias,Cartagena,Cartagena das Indias,Cartagena das Índias,Cartagena de Indias,Cartaxena de Indias,Carthagene,Carthagene des Indes,Carthagène,Carthagène des Indes,Kartachena,Kartageno,Kartakhena,Kartakhena de Indijas,ka ta he na,kaleutahena,kartagyna,kartajyna,karutahena,qrtajnt  kwlwmbya,qrthnh,Картахена,Картахена де Индијас,קרטחנה,قرطاجنة، كولومبيا,کارتاجینا,کارتاگینا,კარტახენა,カルタヘナ,卡塔赫纳,카르타헤나', 10.3997200, -75.5144400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27893, 'Carolina', 'Carolina', 'Carolina', 6.7243900, -75.2816800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27894, 'Carmen de Viboral', 'Carmen de Viboral', 'Carmen Viboral,Carmen de Viboral,Ehl''-Karmen-de-Viboral'',El Carmen de Viboral,al karmn dh wywwral,ka men de bi bo la er,Эль-Кармен-де-Вибораль,ال کارمن ده ویوورال,კარმენ-დე-ვიბორალი,卡門德比博拉爾', 6.0823600, -75.3350900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27895, 'Carmen de Carupa', 'Carmen de Carupa', 'Carmen de Carupa,Carupa', 5.3486200, -73.9016800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27896, 'Carmen de Apicalá', 'Carmen de Apicala', 'Apicala,Carmen,Carmen Apicala,Carmen Apicalá,Carmen de Apicala,Carmen de Apicalá', 4.1472500, -74.7201400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27897, 'Carlosama', 'Carlosama', 'Carlosama,Cuaspud', 0.8629200, -77.7273400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27898, 'Caramanta', 'Caramanta', 'Caramanta', 5.5478200, -75.6436800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27899, 'Caracolí', 'Caracoli', '', 6.4119400, -74.7605600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27900, 'Cáqueza', 'Caqueza', 'Caqueza,Cáqueza', 4.4056900, -73.9468300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27901, 'Capitanejo', 'Capitanejo', 'Capitanejo', 6.5288100, -72.6959500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27902, 'Caparrapí', 'Caparrapi', 'Caparappi,Caparappí,Caparrapi,Caparrapí', 5.3464400, -74.4914700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27903, 'Cantagallo', 'Cantagallo', 'Cantagallo,Caserio Cantagallo,Caserío Cantagallo', 7.3759900, -73.9196300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27904, 'Candelaria', 'Candelaria', 'Candelaria', 10.4591200, -74.8797000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27905, 'Candelaria', 'Candelaria', 'Candelaria', 3.4067100, -76.3481900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27906, 'Cañasgordas', 'Canasgordas', 'Canasgordas,Cañasgordas', 6.7498900, -76.0253900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27907, 'Campo de la Cruz', 'Campo de la Cruz', 'Campo de la Cruz,Kampo-de-la-Krus,Puerto Real de la Cruz,Кампо-де-ла-Крус', 10.3780800, -74.8835600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27908, 'Campoalegre', 'Campoalegre', 'Campoalegre,Kampoalegre,Sevilla,Кампоалегре', 2.6848900, -75.3231100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27909, 'Campamento', 'Campamento', 'Campamento', 6.9792000, -75.2972400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27910, 'Caloto', 'Caloto', 'Caloto', 3.0358600, -76.4078800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27911, 'Calimita', 'Calimita', '', 3.9166700, -76.5000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27912, 'Cali', 'Cali', 'CLO,Cali,Calium,Cáli,Kali,Kalis,Santiago de Cali,ka li,kali,kalli,kaly,santiago・de・kari,Кали,Калі,סנטיאגו דה קאלי,كالي,کالی,กาลี,サンティアゴ・デ・カリ,卡利,칼리', 3.4372200, -76.5225000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27913, 'Caldono', 'Caldono', 'Caldono', 2.7973900, -76.4831600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27914, 'Caldas', 'Caldas', 'Caldas,Kal''das,Kaldas,ka er da si,kaldas,Κάλδας,Кальдас,کالداس,კალდასი,卡爾達斯', 6.0910600, -75.6356900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27915, 'Calarcá', 'Calarca', 'Calarca,Calarcá', 4.5294900, -75.6409100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27916, 'Calamar', 'Calamar', '', 10.2511000, -74.9146200, 'CO', '2006-01-17', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27917, 'Calamar', 'Calamar', '', 1.9596000, -72.6531500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27918, 'Cajicá', 'Cajica', 'Cajica,Cajicá', 4.9185700, -74.0279900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27919, 'Cajibío', 'Cajibio', 'Cajibio,Cajibío', 2.6227100, -76.5703900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27920, 'Cajamarca', 'Cajamarca', 'Cajamarca,San Miguel,San Miguel de Perdomo', 4.4423400, -75.4287400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27921, 'Caimito', 'Caimito', '', 8.8122900, -75.4106600, 'CO', '2011-10-11', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27922, 'Caicedonia', 'Caicedonia', 'Caicedonia', 4.3324000, -75.8266500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27923, 'Caicedo', 'Caicedo', 'Caicedo', 6.4051100, -75.9825500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27924, 'Cácota', 'Cacota', 'Cacota,Cácota', 7.2678700, -72.6419700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27925, 'Cáchira', 'Cachira', '', 7.7410400, -73.0483000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27926, 'Cachipay', 'Cachipay', '', 5.2666700, -74.5666700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27927, 'Cáceres', 'Caceres', 'Caceres,Cáceres', 7.5807800, -75.3484200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27928, 'Cabuyaro', 'Cabuyaro', 'Cabuyaro,Pueblo Cabuyaro', 4.2817000, -72.7939900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27929, 'Cabrera', 'Cabrera', 'Cabrera', 3.9859800, -74.4828300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27930, 'Bugalagrande', 'Bugalagrande', 'Bugalagrande', 4.2120700, -76.1556400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27931, 'Buga', 'Buga', 'Buga,Guadalajara de Buga,bu jia,buga,bwga,Буга,بوگا,ბუგა,布加', 3.9008900, -76.2978300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27932, 'Buesaco', 'Buesaco', 'Buesaco,Bueysaco', 1.3901700, -77.1598100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27933, 'Buenos Aires', 'Buenos Aires', '', 3.0139700, -76.6461200, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27934, 'Buenavista', 'Buenavista', 'Buenavista,Corregimiento Buenavista,San Zenon,San Zenón', 9.2143300, -74.3136300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27935, 'Buenavista', 'Buenavista', '', 9.0496300, -76.0028000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27936, 'Buenavista', 'Buenavista', 'Buenavista,El Tolra,El Tolrá', 4.3539000, -75.7178200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27937, 'Buenaventura', 'Buenaventura', 'BUN,Buehnaventura,Buenaventura,bu ai na wen tu la,bwynawntwra,Буенавентура,Буэнавентура,بوئناونتورا,بوئناونتورا، ویے دیل کاؤکا,ბუენავენტურა,布埃納文圖拉', 3.8801000, -77.0311600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27938, 'Buenaventura', 'Buenaventura', '', 3.5833300, -77.0000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27939, 'Bucaramanga', 'Bucaramanga', 'BGA,Bucaramanga,Bukaramanga,Gorad Bukaramanga,bu ka la man jia,bukalamang-ga,bukaramanga,bwkaramanga,Букараманга,Букараманґа,Горад Букараманга,بوکارامانگا,ბუკარამანგა,ブカラマンガ,布卡拉曼加,부카라망가', 7.1253900, -73.1198000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27940, 'Briceño', 'Briceno', 'Briceno,Briceño', 7.1109600, -75.5515200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27941, 'Bolívar', 'Bolivar', 'Bolivar,Bolívar', 5.9894300, -73.7702100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27942, 'Bolívar', 'Bolivar', 'Bolivar,Bolívar', 4.3387000, -76.1834200, 'CO', '2016-03-10', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27943, 'Bojacá', 'Bojaca', 'Bojaca,Bojacá', 4.7317600, -74.3412900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27944, 'Bogotá', 'Bogota', 'BOG,Bogot,Bogota,Bogoto,Bogotà,Bogotá,Boqota,Buoguota,Bógóta,Gorad Bagata,Mponkota,Santa-Fe-de-Bogota,Santafe de Bogota,Santafe de Bogotá,Santafé de Bogotá,Wukuta,beageatta,bo ge da,bogota,bokota,bwghwta,bwgwta,bwgwth,bwjwta,pokotta,Μπογκοτά,Богота,Боґота,Горад Багата,Санта-Фе-де-Богота,Բոգոտա,באגאטא,בוגוטה,بوجوتا,بوغوتا,بوگوتا,بگوٹا,بۆگۆتا,बोगोटा,बोगोता,বোগোতা,ਬੋਗੋਤਾ,ବୋଗୋଟା,பொகோட்டா,ಬೊಗೋಟ,ബൊഗോട്ട,โบโกตา,པོ་གོ་ཏ,ဘိုဂိုတာမြို့,ბოგოტა,ቦጎታ,ទីក្រុងបូកូតា,ボゴタ,波哥大,보고타', 4.6097100, -74.0817500, 'CO', '2016-12-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27945, 'Bochalema', 'Bochalema', 'Bochaleina,Bochalema', 7.6109500, -72.6477300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27946, 'Boavita', 'Boavita', 'Boavita', 6.3303100, -72.5850500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27947, 'Betulia', 'Betulia', 'Betulia', 6.9006900, -73.2834700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27948, 'Betulia', 'Betulia', 'Betulia', 6.1128400, -75.9837800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27949, 'Betania', 'Betania', '', 5.7460100, -75.9776500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27950, 'Arboleda', 'Arboleda', 'Arboleda,Berruacos,Berruecos', 1.4976600, -77.1358700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27951, 'Belmira', 'Belmira', 'Belmira', 6.6050800, -75.6661900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27952, 'Bello', 'Bello', 'Begio,Bejo,Bel''o,Beljas,Bella,Bello,bei yue,belio,byyw,byyw  antywkya,Μπέγιο,Бейо,Белла,Бельо,بییو,بییو، انتیوکیا,ბელიო,貝約', 6.3373200, -75.5579500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27953, 'Belén de Umbría', 'Belen de Umbria', 'Belen,Belen de Umbria,Belén,Belén de Umbría,Mocatan,Mocatán', 5.2008700, -75.8686500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27954, 'Belén de los Andaquíes', 'Belen de los Andaquies', 'Belen,Belen de los Andaquies,Belen del Andaqui,Belén,Belén de los Andaquíes,Belén del Andaqui', 1.4182800, -75.8775300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27955, 'Belén', 'Belen', 'Belen,Belen de Cerinza,Belén,Belén de Cerinza', 5.9889200, -72.9125400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27956, 'Belén', 'Belen', 'Belen,Belén', 1.5947700, -77.0540800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27957, 'Belalcázar', 'Belalcazar', 'Belalcazar,Belalcázar', 4.9952800, -75.8127800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27958, 'Becerril', 'Becerril', 'Becerril', 9.7041300, -73.2793000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27959, 'Barranquilla', 'Barranquilla', 'BAQ,Barankila,Barankilija,Barankilja,Barran''kigia,Barrancas de San Nicolas,Barrancas de San Nicolás,Barrankil''ja,Barrankilya,Barranquilha,Barranquilla,Gorad Barankil''ja,ba lan ji ya,ba leng ji ye,balangkiya,bar rang ki ya,baranakiya,barankija,barankwla,barankwyla,brnqyyh,byarenkvila,Μπαρρανκίγια,Баранкиля,Баранкиља,Барранкилья,Барранкілья,Горад Баранкілья,ברנקייה,بارانكويلا,بارانکولا,ब्यारेन्क्विला,ਬਾਰਾਙਕੀਯਾ,บาร์รังกียา,ბარანკილია,バランキージャ,巴兰基亚,巴冷基也,바랑키야', 10.9685400, -74.7813200, 'CO', '2016-03-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27960, 'Barranco de Loba', 'Barranco de Loba', 'Barranco,Barranco de Loba', 8.9459700, -74.1064700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27961, 'Barrancas', 'Barrancas', '', 10.9575600, -72.7876900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27962, 'Barranca de Upía', 'Barranca de Upia', 'Barranca,Barranca de Upia,Barranca de Upta,Barranca de Upía,Cumaral', 4.5696300, -72.9667600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27963, 'Barrancabermeja', 'Barrancabermeja', 'Barankabermecha,Barracana Bermeja,Barrancabermeja,Barrankabermekha,EJA,ba lan ka wei mei ha,barankaberumeha,Барранкабермеха,ბარანკაბერმეხა,バランカベルメハ,巴蘭卡韋梅哈', 7.0652800, -73.8547200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27964, 'Barichara', 'Barichara', 'Barichara', 6.6357200, -73.2228200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27965, 'Barbosa', 'Barbosa', 'Barbosa,Barboza,ba er bo sa,babwsa,barbosa,Барбоза,Барбоса,بابوسا,ბარბოსა,巴爾博薩', 6.4380900, -75.3313600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27966, 'Barbosa', 'Barbosa', 'Barbosa,Barboza,Барбоза', 5.9316800, -73.6150700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27967, 'Barbacoas', 'Barbacoas', 'Barbacoas', 1.6715400, -78.1397800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27968, 'Baraya', 'Baraya', 'Baraya,Santa Maria de Nunchia,Santa María de Nunchía', 3.1533300, -75.0530600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27969, 'Baranoa', 'Baranoa', 'Baranoa', 10.7940800, -74.9164000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27970, 'Balboa', 'Balboa', '', 4.9516700, -75.9572200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27971, 'Balboa', 'Balboa', 'Balboa', 2.0395600, -77.2168400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27972, 'Bahía Solano', 'Bahia Solano', 'BSC,Bahia Solano,Bahía Solano,Ciudad Mutis,Ciudad de Mutis,Mutis,Puerto Mutis', 6.2262200, -77.4043900, 'CO', '2016-12-17', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27973, 'Bagadó', 'Bagado', 'Bagado,Bagadó', 5.4116400, -76.4152000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27974, 'Ayapel', 'Ayapel', 'AYA,Ayapel', 8.3137200, -75.1398200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27975, 'Ataco', 'Ataco', 'Ataco', 3.5914700, -75.3817800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27976, 'Astrea', 'Astrea', 'Astrea,Corregimiento Astrea', 9.4982800, -73.9759100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27977, 'Arroyohondo', 'Arroyohondo', 'Arroyo Hondo,Arroyohondo,Corregimiento Arroyo Hondo', 10.2522000, -75.0198000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27978, 'Guayabal', 'Guayabal', 'Armero,Guayabal', 5.0310300, -74.8868300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27979, 'Armenia', 'Armenia', 'Armenia,Armenia Mantequilla,Armenija,Армения', 6.1563900, -75.7872200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27980, 'Armenia', 'Armenia', 'AXM,Armenia', 4.5338900, -75.6811100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27981, 'Arjona', 'Arjona', '', 10.2544400, -75.3438900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27982, 'Ariguaní', 'Ariguani', '', 10.2500000, -74.0000000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27983, 'Argelia', 'Argelia', 'Argelia', 5.7312700, -75.1425700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27984, 'Argelia', 'Argelia', '', 4.7234200, -76.1190900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27985, 'Argelia', 'Argelia', 'Argelia', 2.2556300, -77.2487600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27986, 'Arenal', 'Arenal', 'Arenal,Corregimiento Arenal', 8.4592800, -73.9433100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27987, 'Arcabuco', 'Arcabuco', 'Arcabuco', 5.7546300, -73.4366900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27988, 'Arboletes', 'Arboletes', 'Arboletas,Arboletes', 8.8505100, -76.4269400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27989, 'Arboledas', 'Arboledas', '', 7.6423300, -72.7994400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27990, 'Arbeláez', 'Arbelaez', 'Arbelaez,Arbeláez', 4.2725400, -74.4151300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27991, 'Arauquita', 'Arauquita', 'ARQ', 7.0291700, -71.4280600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27992, 'Arauca', 'Arauca', 'AUC,Arauca,Arauka,Arauko,Araŭko,a lao ka,alauka,arawka,arawka  arawka,araywka,Араука,آراؤکا,آرائوکا,آراوکا، آراوکا,არაუკა,阿劳卡,아라우카', 7.0847100, -70.7590800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27993, 'Aratoca', 'Aratoca', 'Aratoca', 6.6935300, -73.0208300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27994, 'Aranzazu', 'Aranzazu', '', 5.2712300, -75.4904400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27995, 'Aracataca', 'Aracataca', 'Aracataca,Arakataka,a la ka ta ka,arakataka,yarkataka,Аракатака,آراکاتاکا,أراكاتاكا,ئارکاتاکا,არაკატაკა,阿拉卡塔卡', 10.5918100, -74.1898300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27996, 'Aquitania', 'Aquitania', 'Aquitania,Guaquira,Guáquira,Puebloviejo', 5.5197200, -72.8875000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27997, 'Apía', 'Apia', 'Apia,Apía', 5.1064500, -75.9431800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27998, 'Apartadó', 'Apartado', 'APO', 7.8829900, -76.6258700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(27999, 'Anzoátegui', 'Anzoategui', 'Anzoategui,Anzoátegui,Briceno,Briceño', 4.6299600, -75.0953900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28000, 'Antioquia', 'Antioquia', 'Antioquia,Santa Fe de Antioquia', 6.5568700, -75.8280600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28001, 'Ansermanuevo', 'Ansermanuevo', 'Ansermanueva,Ansermanuevo,Santa Ana de los Caballeros', 4.7972200, -75.9950000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28002, 'Anserma', 'Anserma', 'Anserma', 5.3327800, -75.7911100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28003, 'Anolaima', 'Anolaima', 'a nuo lai ma,anolaima,ანოლაიმა,阿諾萊馬', 4.8336200, -74.4995000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28004, 'Angostura', 'Angostura', 'Angostura,Angosturas', 6.8850800, -75.3346700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28005, 'Angelópolis', 'Angelopolis', 'Angelopolis,Angelópolis', 6.1107200, -75.7092300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28006, 'Andes', 'Andes', 'ADN,Andes,Los Andes', 5.6561000, -75.8787700, 'CO', '2016-01-30', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28007, 'Andalucía', 'Andalucia', 'Andalucia,Andalucía', 4.1706100, -76.1664100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28008, 'Ancuya', 'Ancuya', 'Ancuya', 1.2633000, -77.5137600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28009, 'Anapoima', 'Anapoima', 'Anapoima', 4.5202800, -74.5394400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28010, 'Ambalema', 'Ambalema', 'Ambalema,Амбалема', 4.7840500, -74.7626800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28011, 'Amalfi', 'Amalfi', 'AFI,Amalfi', 6.9101600, -75.0776400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28012, 'Amagá', 'Amaga', 'Amaga,Amagá', 6.0400100, -75.7031500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28013, 'Alvarado', 'Alvarado', 'Alvarado', 4.5661200, -74.9622900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28014, 'Altamira', 'Altamira', 'Altamira,Boqueron,Boquerón', 2.0627800, -75.7872200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28015, 'Almaguer', 'Almaguer', 'Almaguer', 1.9170000, -76.8523300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28016, 'Algeciras', 'Algeciras', 'Algeciras,San Juanito', 2.5238500, -75.3173300, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28017, 'Algarrobo', 'Algarrobo', 'Algarrobo,Hacienda Algarrobo', 10.1869400, -74.5752800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28018, 'Aldana', 'Aldana', 'Aldana,Dana', 0.8828300, -77.7010300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28019, 'Alcalá', 'Alcala', 'Acala,Acalá,Alcala,Alcalá,La Balsa,San Sebastian de la Balsa', 4.6747200, -75.7825000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28020, 'Albania', 'Albania', 'Albania,Albanio', 11.1609900, -72.5923800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28021, 'Albania', 'Albania', '', 1.3286600, -75.8782400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28022, 'Albán', 'Alban', '', 4.8766100, -74.4376800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28023, 'Aipe', 'Aipe', 'Aipe', 3.2222200, -75.2366700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28024, 'Aguazul', 'Aguazul', 'Agua Azul,Aguazul,a gua su er,aguasuli,agwazwl,اگوازول,აგუასული,阿瓜蘇爾', 5.1728200, -72.5470600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28025, 'Agua de Dios', 'Agua de Dios', 'Agua de Dios,Aqua de Dios,a gua de di ao si,agua-de-diosi,agwa d dayws,agwa dw daywz,اگوا د دایوس,اگوا دو دایوز,აგუა-დე-დიოსი,阿瓜德迪奧斯', 4.3764800, -74.6699500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28026, 'Aguadas', 'Aguadas', 'Aguadas', 5.6116100, -75.4562400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28027, 'Aguachica', 'Aguachica', 'Aguachica,Aguachika,Aquachia,Aquachía,Агуачика', 8.3084400, -73.6166000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28028, 'Agrado', 'Agrado', 'Agrado,Belen Pitalito,Belén Pitalito', 2.2572500, -75.7714200, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28029, 'Achí', 'Achi', 'Achi,Achí', 8.5681800, -74.5540500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28030, 'Acevedo', 'Acevedo', 'Acevedo,Concepcion,Concepción', 1.8360500, -75.8549800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28031, 'Acandí', 'Acandi', 'ACD,Acandi,Acandí,Acanti', 8.5115800, -77.2771900, 'CO', '2017-02-07', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28032, 'Acacías', 'Acacias', 'Acacias,Acacías', 3.9869500, -73.7579700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28033, 'Abriaquí', 'Abriaqui', 'Abriaqui,Abriaquí', 6.6314800, -76.0644400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28034, 'Ábrego', 'Abrego', 'Abrego,La Cruz,Ábrego', 8.0806500, -73.2205400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28035, 'Abejorral', 'Abejorral', 'Abejorral', 5.7892800, -75.4272500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28036, 'Los Santos', 'Los Santos', '', 7.1700000, -73.0930600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28037, 'Lejanías', 'Lejanias', 'Lejanias,Lejanías', 3.5276200, -74.0233500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28038, 'El Dorado', 'El Dorado', '', 2.7741100, -72.8683400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28039, 'Curillo', 'Curillo', 'Curillo,El Curillo', 1.0332700, -75.9190700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28040, 'Santacruz', 'Santacruz', 'Santacruz,Sontarruz', 1.5209000, -77.2620600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28041, 'El Tarra', 'El Tarra', '', 8.5756200, -73.0948900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28042, 'Mesetas', 'Mesetas', 'Mesetas', 3.3846300, -74.0442400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28043, 'Bellavista', 'Bellavista', 'Bellavista,Bojaya,Bojayá,La Loma', 6.5213000, -76.9723400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28044, 'Chivor', 'Chivor', 'Chivor', 4.8855600, -73.3688900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28045, 'Monterrey', 'Monterrey', '', 4.8720600, -72.8987900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28046, 'Paratebueno', 'Paratebueno', 'EUO,Paratebueno', 4.3757500, -73.2154700, 'CO', '2016-11-01', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28047, 'Puerto Gaitán', 'Puerto Gaitan', 'Puerto Gaitan,Puerto Gaitán', 4.3132800, -72.0815700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28048, 'Sabanalarga', 'Sabanalarga', 'Sabanalarga', 4.8543000, -73.0400300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28049, 'San Luis', 'San Luis', '', 6.0416700, -74.9927800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28050, 'Morales', 'Morales', 'Morales', 2.7570100, -76.6172300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28051, 'Villa Rica', 'Villa Rica', 'Villa Rica', 2.5142000, -76.8493900, 'CO', '2015-06-17', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28052, 'Quípama', 'Quipama', 'Quipama,Quípama', 5.5194000, -74.1776500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28053, 'La Cumbre', 'La Cumbre', 'La Cumbre', 3.7225000, -76.0208300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28054, 'Canalete', 'Canalete', '', 8.6761100, -76.2041700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28055, 'Fredonia', 'Fredonia', '', 5.9258300, -75.6705600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28056, 'Gachetá', 'Gacheta', 'Gacheta,Gachetá', 4.8185400, -73.6365900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28057, 'San Carlos', 'San Carlos', '', 8.7437200, -75.7133100, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28058, 'San Andrés', 'San Andres', 'San Andres,San Andrés', 6.9033300, -75.6825000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28059, 'Buriticá', 'Buritica', '', 6.7187300, -75.9073400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28060, 'Carepa', 'Carepa', 'Carepa', 7.7584900, -76.6525500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28061, 'Ciudad Bolívar', 'Ciudad Bolivar', 'Ciudad Bolivar,Ciudad Bolívar', 5.8538900, -76.0252800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28062, 'Vegachí', 'Vegachi', 'Vegachi,Vegachí', 6.7614100, -74.7947300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28063, 'Altos del Rosario', 'Altos del Rosario', 'Altos del Rosario', 8.7944400, -74.1658300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28064, 'Santa Rosa del Sur', 'Santa Rosa del Sur', 'Santa Rosa del Sur', 7.9644400, -74.0544400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28065, 'Tiquisio', 'Tiquisio', 'Tiquisio', 8.5597200, -74.2669400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28066, 'Cartagena del Chairá', 'Cartagena del Chaira', 'Cartagena del Chaira,Cartagena del Chairá', 1.3348800, -74.8428900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28067, 'Agustín Codazzi', 'Agustin Codazzi', 'Agustin Codazzi,Agustin-Kodassi,Agustín Codazzi,Codazzi,agstn kwdazy,agwstyn kwdazy,ke da qi,Агустин-Кодасси,آگستن کودازی,اگوستین کودازی,კოდასი,科達齊', 10.0367200, -73.2355800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28068, 'Manaure Balcón del Cesar', 'Manaure Balcon del Cesar', 'Manaure Balcon del Cesar,Manaure Balcón del Cesar', 10.3927800, -73.0325000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28069, 'San Martín', 'San Martin', 'San Martin,San Martín', 8.0015100, -73.5112600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28070, 'El Cantón de San Pablo', 'El Canton de San Pablo', 'El Canton de San Pablo,El Cantón de San Pablo', 5.3388900, -76.7313900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28071, 'El Retorno', 'El Retorno', 'El Retorno', 2.3302200, -72.6276500, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28072, 'Isnos', 'Isnos', 'Isnos', 1.9355600, -76.2405600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28073, 'Plato', 'Plato', 'PLT,Plato', 9.7902900, -74.7824400, 'CO', '2017-01-14', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28074, 'Mapiripán', 'Mapiripan', 'Mapiripan,Mapiripán', 2.8911500, -72.1332800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28075, 'Puerto Concordia', 'Puerto Concordia', 'Concordia,La Concordia,Puerto Concordia,Puerto La Concordia', 2.6220600, -72.7572400, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28076, 'La Tola', 'La Tola', 'La Tola', 2.4108300, -78.2427800, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28077, 'Puerto Guzmán', 'Puerto Guzman', 'Puerto Guzman,Puerto Guzmán', 0.9702800, -76.5858300, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28078, 'El Playón', 'El Playon', 'El Playon,El Playón', 7.4713100, -73.2031000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28079, 'San Antonio del Tequendama', 'San Antonio del Tequendama', 'San Antonio del Tequendama', 4.6188900, -74.3538900, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28080, 'Tibacuy', 'Tibacuy', 'Tibacuy', 4.3511100, -72.4563900, 'CO', '2012-01-19', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28081, 'Santa Genoveva de Docorodó', 'Santa Genoveva de Docorodo', 'Litoral del San Juan,Santa Genoveva de Docorodo,Santa Genoveva de Docorodó', 4.2587500, -77.3651600, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28082, 'La Argentina', 'La Argentina', 'La Argentina', 2.1961100, -75.9800000, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28083, 'La Macarena', 'La Macarena', 'LMC,La Macarena', 2.1826600, -73.7871000, 'CO', '2017-04-23', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28084, 'Valle del Guamuez', 'Valle del Guamuez', 'La Hormiga,Valle del Guamuez', 0.4525000, -76.9191700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28085, 'San José del Guaviare', 'San Jose del Guaviare', 'SJE,San Jose del Guaviare,San José del Guaviare', 2.5728600, -72.6459100, 'CO', '2016-11-27', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28086, 'Orito', 'Orito', 'Orito', 0.6674900, -76.8729700, 'CO', '2015-06-21', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28087, 'Cubará', 'Cubara', '', 6.9988900, -72.1091700, 'CO', '2016-01-28', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28088, 'Barrio San Luis', 'Barrio San Luis', 'Capilla,Moraci,Morací,San Luis via La Calera,San Luis vía La Calera,Surena,Sureña', 4.6677900, -74.0215000, 'CO', '2016-12-18', 49);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28089, 'Zarcero', 'Zarcero', 'Zarcero', 10.1856100, -84.3907600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28090, 'Zapotal', 'Zapotal', 'San Antonio,Zapotal', 10.0000000, -85.3000000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28091, 'Upala', 'Upala', 'UPL,Upala', 10.8979200, -85.0145400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28092, 'Turrialba', 'Turrialba', 'Turialba,Turrial''ba,Turrialba,Турриальба', 9.9046700, -83.6835200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28093, 'Tucurrique', 'Tucurrique', '', 9.8533600, -83.7227300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28094, 'Tres Ríos', 'Tres Rios', 'La Union,La Unión,Tres Rios,Tres Ríos', 9.9064400, -83.9876000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28095, 'Tobosi', 'Tobosi', 'Tobosi,Tobosí', 9.8383700, -83.9839100, 'CR', '2016-10-29', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28096, 'Tilarán', 'Tilaran', 'Tilaran', 10.4670100, -84.9677500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28097, 'Tejar', 'Tejar', '', 9.7462200, -84.2336800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28098, 'Sixaola', 'Sixaola', 'Sixaola,Sixola', 9.5276600, -82.6218500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28099, 'Siquirres', 'Siquirres', 'Siquirres', 10.0974800, -83.5065900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28100, 'Sardinal', 'Sardinal', '', 10.5167400, -85.6474800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28101, 'Sarchí', 'Sarchi', 'Sarchi,Sarchi Norte,Sarchí,Sarchí Norte', 10.0897000, -84.3475200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28102, 'San Vito', 'San Vito', 'Ciudad San Vito,San Vito,San Vito de Java,TOO', 8.8207900, -82.9709200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28103, 'San Vicente', 'San Vicente', '', 9.9601600, -84.0476200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28104, 'Santo Domingo', 'Santo Domingo', '', 10.0638900, -84.1549900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28105, 'Santiago', 'Santiago', '', 10.0227500, -84.4442000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28106, 'Santiago', 'Santiago', 'Puriscal,Santiago,Santiago de Puriscal', 9.8463600, -84.3142800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28107, 'Santa Cruz', 'Santa Cruz', 'SZC,Santa Cruz', 10.2605300, -85.5851000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28108, 'Santa Ana', 'Santa Ana', 'Santa Ana', 9.9326000, -84.1825500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28109, 'San Ramón', 'San Ramon', 'San Ramon,San Ramón', 10.0880200, -84.4702200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28110, 'San Rafael Arriba', 'San Rafael Arriba', 'San Rafael,San Rafael Arriba', 9.8755600, -84.0766100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28111, 'San Rafael Abajo', 'San Rafael Abajo', '', 9.8310000, -84.2900800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28112, 'San Rafael', 'San Rafael', '', 10.0640300, -84.4728100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28113, 'San Rafael', 'San Rafael', '', 10.0132000, -84.1001600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28114, 'San Rafael', 'San Rafael', '', 10.0638300, -84.4676500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28115, 'San Rafael', 'San Rafael', '', 9.9278700, -84.1372200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28116, 'San Pedro', 'San Pedro', 'Pedro,San Pedro,San Pedro de Montes de Oca', 9.9282900, -84.0507400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28117, 'San Pablo', 'San Pablo', 'San Pablo', 9.9955900, -84.0965600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28118, 'San Pablo', 'San Pablo', '', 9.6832300, -84.0405000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28119, 'San Miguel', 'San Miguel', '', 9.8712100, -84.0608400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28120, 'San Marcos', 'San Marcos', 'Marcos,San Marcos,San Marcos de Dota,San Marcos de Tarrazu,San Marcos de Tarrazú', 9.6601000, -84.0202600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28121, 'San Juan de Dios', 'San Juan de Dios', 'Juan de Dios,San Juan de Dios', 9.8773000, -84.0847000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28122, 'San Juan', 'San Juan', '', 10.1024800, -84.3169400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28123, 'San Juan', 'San Juan', '', 9.9597400, -84.0816500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28124, 'San Josecito', 'San Josecito', '', 10.0166700, -84.1000000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28125, 'San José', 'San Jose', '', 10.9517300, -85.1361000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28126, 'San José', 'San Jose', 'Gorad San-Khaseh,SJO,San Chose,San Chosė,San Hose,San Jose,San Jose de Costa Rica,San Jose i Costa Rica,San José,San José de Costa Rica,San José i Costa Rica,San Joze,San Jozé,San Jusiy,San Khose,San Khoze,San Xose,San Xosé,San-Joseo,San-Khose,San-Xose,Sanhose,Sanhosē,Urbs Sancti Iosephi in Costarica,can hoce,san jwz,san khwsyh,san khwzh,san khwzے  kwsٹaryka,san-khose,sana hoje,sana hose,sana hoze,sanhose,sheng he xi,sn hwsh,syana hose,Σαν Χοσέ,Горад Сан-Хасэ,Сан Хозе,Сан Хосе,Сан-Хосе,Սան Խոսե,סאן חוסה,סן חוסה,سان جوز,سان خوزه,سان خوزے، کوسٹاریکا,سان خوسيه,سان خوسې,सान होज़े,सान होजे,স্যান হোসে,ਸਾਨ ਹੋਸੇ,சான் ஹொசே,ซันโฮเซ,སན་ཇོ་སེ།,სან-ხოსე,ሳን ሆዜ,サンホセ,聖荷西,산호세', 9.9333300, -84.0833300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28127, 'San Isidro', 'San Isidro', 'Barrio Urena,Barrio Ureña,San Isidro,San Isidro Urena,San Isidro de El General,San Isidro del General,Urena,Ureña', 9.3721000, -83.7039900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28128, 'San Ignacio', 'San Ignacio', 'San Ignacia de Acosta,San Ignacio,San Ignacio de Acosta', 9.7985300, -84.1617300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28129, 'San Francisco', 'San Francisco', '', 9.9929900, -84.1293400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28130, 'San Felipe', 'San Felipe', '', 9.9048800, -84.1055100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28131, 'San Diego', 'San Diego', '', 9.8989800, -84.0028700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28132, 'San Antonio', 'San Antonio', 'San Antonio,San Antonio de Belen', 9.9833300, -84.1833300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28133, 'Sámara', 'Samara', 'PLD,Samara,Sámara', 9.8814700, -85.5280900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28134, 'Salitrillos', 'Salitrillos', '', 9.8525900, -84.0906200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28135, 'Salitral', 'Salitral', 'El Salitral,Salitral', 9.9116300, -84.1783500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28136, 'Sabanilla', 'Sabanilla', 'Sabanilla,Sabanilla de Pampas', 10.0740400, -84.2155100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28137, 'Sabanilla', 'Sabanilla', '', 9.9452200, -84.0392700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28138, 'Sabalito', 'Sabalito', 'Sabalito', 8.8181400, -82.9091100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28139, 'Roxana', 'Roxana', 'Roxana,Roxano', 10.2671200, -83.7511000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28140, 'Río Segundo', 'Rio Segundo', '', 10.2413800, -84.2793300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28141, 'Quesada', 'Quesada', 'Ciudad Quesada,Kesada,Quesada,Sioudad Kesada,Villa Quesada,ke sa da,Σιουδάδ Κεσάδα,Кесада,Կեսադա,克薩達', 10.3238100, -84.4271400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28142, 'Quepos', 'Quepos', 'Puerto Quepos,Quepos,XQP', 9.4306300, -84.1623100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28143, 'Purral', 'Purral', '', 9.9580800, -84.0305000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28144, 'Puntarenas', 'Puntarenas', 'JAP,Pountarenas,Puntarenas,Puntarenasas,peng ta lei na si,puntalenaseu,puntarenasu,pwntarynas,pwntrns,Πουνταρένας,Пунтаренас,Պունտարենաս,פונטרנס,پونتاریناس,プンタレナス,蓬塔雷納斯,푼타레나스', 9.9762500, -84.8383600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28145, 'Quepos', 'Quepos', '', 9.4166700, -84.1666700, 'CR', '2016-09-06', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28146, 'Limón', 'Limon', 'Ciudad de Limon,Ciudad de Limón,LIO,Limon,Limonas,Limón,Pouerto Limon,Provincia de Limon,Provinsi Limon,Provinsi Limón,Província de Limón,Puehrto-Limon,Puerto Limon,Puerto Limón,li meng,limon,lymwn,rimon,Πουέρτο Λιμόν,Лимон,Пуэрто-Лимон,Լիմոն,לימון,لیمون,リモン,利蒙,리몬', 9.9907400, -83.0359600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28147, 'Pocosol', 'Pocosol', '', 10.3666700, -84.6166700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28148, 'Pocora', 'Pocora', 'Pacora Oeste,Pocora,Pocora Oeste,Pocora West', 10.1718500, -83.6043900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28149, 'Pital', 'Pital', '', 10.4505600, -84.2740600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28150, 'Pejibaye', 'Pejibaye', 'Pejibaye,Pejivalle', 9.8113500, -83.7033600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28151, 'Patarrá', 'Patarra', '', 9.8807100, -84.0350100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28152, 'Parrita', 'Parrita', '', 9.5201200, -84.3224900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28153, 'Paraíso', 'Paraiso', 'Paraiso,Paraíso', 9.8383200, -83.8655700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28154, 'Paquera', 'Paquera', '', 9.8200500, -84.9351300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28155, 'Palmichal', 'Palmichal', '', 9.8377800, -84.2047800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28156, 'Pacuarito', 'Pacuarito', '', 10.1018800, -83.4698700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28157, 'Pacayas', 'Pacayas', '', 9.8070900, -84.0476400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28158, 'Orotina', 'Orotina', 'Orotina', 9.9119700, -84.5233700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28159, 'Orosí', 'Orosi', 'Orosi,Orosí', 9.7961700, -83.8538300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28160, 'Nicoya', 'Nicoya', 'NCT,Nicoya,Nikogia,Nikoja,Nikoya,ni ke ya,nykwja,Νικόγια,Նիկոյա,نيكوجا,尼科亞', 10.1503800, -85.4509300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28161, 'Naranjo', 'Naranjo', 'Naranjo', 10.0986600, -84.3782400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28162, 'Nandayure', 'Nandayure', 'Mandayure,Nandayure', 10.0333300, -85.2000000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28163, 'Monterrey', 'Monterrey', '', 9.7573000, -84.1095600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28164, 'Miramar', 'Miramar', '', 10.0925000, -84.7297800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28165, 'Mercedes', 'Mercedes', 'Mercedes,Mercedes Norte', 10.0069500, -84.1339600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28166, 'Mercedes', 'Mercedes', '', 9.2627000, -83.5820200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28167, 'Matina', 'Matina', 'Matina,Matino', 10.0836300, -83.2843100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28168, 'Los Chiles', 'Los Chiles', 'LSL,Los Chiles', 11.0333300, -84.7166700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28169, 'Llorente', 'Llorente', '', 9.9984400, -84.1544800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28170, 'Liberia', 'Liberia', 'LIR,Liberia,Liberii,Liberija,Limperia,li wei li ya,libelia,lybryh,riberia,Λιμπέρια,Либерия,Լիբերիա,ליבריה,لیبیریا، کوسٹاریکا,リベリア,利韋里亞,리베리아', 10.6350400, -85.4377200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28171, 'La Virgen', 'La Virgen', '', 10.4017400, -84.1334800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28172, 'La Suiza', 'La Suiza', 'La Suiza,Suiza', 9.8506500, -83.6169000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28173, 'La Cruz', 'La Cruz', '', 11.0737700, -85.6327200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28174, 'La Asunción', 'La Asuncion', 'Asuncion,La Asuncion,La Asunción', 9.9796100, -84.1728100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28175, 'Juntas', 'Juntas', 'Juntas,Las Juntas', 10.2808900, -84.9595100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28176, 'Jacó', 'Jaco', 'Jaco,Jacó', 9.6149700, -84.6297500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28177, 'Ipís', 'Ipis', '', 9.9674500, -84.0132600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28178, 'Hojancha', 'Hojancha', 'Hoja Ancha,Hojancha', 10.0579000, -85.4180300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28179, 'Heredia', 'Heredia', 'Ciudad de Heredia,Ehredia,Ehredija,Eredia,Eredija,Heredia,Heredija,Heridia,San Francisco de Heredia,ai lei di ya,eledia,Ερέδια,Ередия,Эредиа,Эредия,Էրեդիա,ארדיה,ایریدیا، کوسٹاریکا,埃雷迪亞,에레디아', 10.0023600, -84.1165100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28180, 'Guápiles', 'Guapiles', 'GPL', 10.2168200, -83.7848300, 'CR', '2017-02-19', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28181, 'Guadalupe', 'Guadalupe', 'Goicoechea', 9.9480500, -84.0566500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28182, 'Guácimo', 'Guacimo', 'Guacimo,Guácimo', 10.2129000, -83.6879300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28183, 'Granadilla', 'Granadilla', '', 9.9349100, -84.0168800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28184, 'Golfito', 'Golfito', 'GLF,Golfita,Golfito,Puerto Golfito', 8.6032700, -83.1134200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28185, 'Fortuna', 'Fortuna', '', 10.6738400, -85.1998400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28186, 'La Fortuna', 'La Fortuna', 'El Burio,El Burío,FON,Fortuna,La Fortuna', 10.4708900, -84.6453500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28187, 'Esquipulas', 'Esquipulas', '', 10.0567600, -84.4233700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28188, 'Esparza', 'Esparza', 'Esparta,Esparza', 9.9944700, -84.6646600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28189, 'Escazú', 'Escazu', 'Escasu,Escazu,Escazú', 9.9188700, -84.1398900, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28190, 'Desamparados', 'Desamparados', '', 9.9472700, -84.5062600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28191, 'Daniel Flores', 'Daniel Flores', '', 9.3355400, -83.6694000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28192, 'Curridabat', 'Curridabat', 'Curridabat', 9.9117900, -84.0340700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28193, 'Cot', 'Cot', '', 9.8944900, -83.8730200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28194, 'Corredor', 'Corredor', '', 8.6400200, -82.9460000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28195, 'Concepción', 'Concepcion', '', 9.9333300, -84.0000000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28196, 'Colón', 'Colon', 'Centro Colon,Centro Colón,Villa Colon,Villa Colón', 9.9149100, -84.2417000, 'CR', '2016-10-29', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28197, 'Colima', 'Colima', 'Colima,La Estacion,La Estación', 9.9509100, -84.0850300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28198, 'Ciudad Cortés', 'Ciudad Cortes', 'Ciudad Cortes,Ciudad Cortés,El Pozo,Pozo,Puerto Cortes,Puerto Cortés', 8.9598800, -83.5238100, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28199, 'Chacarita', 'Chacarita', 'Chacarita,JAP', 9.9842400, -84.7789200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28200, 'Cartago', 'Cartago', 'Cartago,Kartagas,Kartago,ka ta ge,kaleutago,kartagw  kastaryka,qrtgw,Καρτάγο,Картаго,Կարտագո,קרטגו,کارتاگو، کاستاریکا,کارتاگو، کوسٹاریکا,卡塔戈,카르타고', 9.8644400, -83.9194400, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28201, 'Carrillos', 'Carrillos', '', 10.0291800, -84.2740300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28202, 'Canoas', 'Canoas', '', 8.5330500, -82.8384400, 'CR', '2011-04-19', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28203, 'Cañas', 'Canas', 'CSC,Canas,Ciudad Canas,Ciudad Cañas,Kanash,Las Canas,Las Cañas,Канаш', 10.4310500, -85.0982500, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28204, 'Calle Blancos', 'Calle Blancos', 'Blancos,Calle Blancos', 9.9500000, -84.0666700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28205, 'Buenos Aires', 'Buenos Aires', 'BAI,Buenos Aires', 9.1718900, -83.3341700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28206, 'Bijagua', 'Bijagua', '', 10.7327900, -85.0567600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28207, 'Belén', 'Belen', '', 10.4078900, -85.5883600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28208, 'Bejuco', 'Bejuco', '', 9.8501400, -85.3292300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28209, 'Batán', 'Batan', 'Bataan,Batan,Bataán,Batán', 10.0835400, -83.3341300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28210, 'Barrio Jesús', 'Barrio Jesus', '', 9.9743900, -84.4216600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28211, 'Bagaces', 'Bagaces', 'Bagaces', 10.5254100, -85.2553700, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28212, 'Atenas', 'Atenas', 'Atenas', 9.9748900, -84.3788600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28213, 'Aserrí', 'Aserri', 'Aseri,Aserri,Aserrí', 9.8587600, -84.0923000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28214, 'Ángeles', 'Angeles', '', 9.9959100, -84.0512600, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28215, 'Alajuelita', 'Alajuelita', 'Alajuelita', 9.9016300, -84.1004200, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28216, 'Alajuela', 'Alajuela', 'Alachouela,Alachuela,Alajuela,Alakhuehla,Alaxuela,a la hu ai la,alakhwyla,allahuella,Αλαχουέλα,Алахуэла,Ալախուելա,אלחואלה,آلاخوئلا,ألاخويلا,الاخویلا,阿拉胡埃拉,알라후엘라', 10.0162500, -84.2116300, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28217, 'San Vicente de Moravia', 'San Vicente de Moravia', '', 9.9616400, -84.0488000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28218, 'Cariari', 'Cariari', '', 10.3571900, -83.7362000, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28219, 'Dulce Nombre de Jesus', 'Dulce Nombre de Jesus', '', 10.1514400, -83.9774800, 'CR', '2016-09-07', 54);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28220, 'Zaza del Medio', 'Zaza del Medio', 'Zaza,Zaza del Medio', 21.9971200, -79.3667800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28221, 'Yara', 'Yara', 'Poblado Yara,Yara', 20.2746500, -76.9513200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28222, 'Yaguajay', 'Yaguajay', 'Yaguajay', 22.3269100, -79.2356700, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28223, 'Viñales', 'Vinales', 'VNL,Vin''jales,Vinales,Viñales,Виньялес', 22.6189200, -83.7069400, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28224, 'Vertientes', 'Vertientes', 'Vertientes', 21.2581700, -78.1497900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28225, 'Venezuela', 'Venezuela', 'Stewart,Venezuela', 21.7374800, -78.7933600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28226, 'Varadero', 'Varadero', 'La Varadero,VRA,Varaderas,Varadero,Veradero,ba la de luo,baladelo,varadero,waradrw,Варадеро,وارادرو,وراڈیرو,ვარადერო,巴拉德罗,바라데로', 23.1567800, -81.2444100, 'CU', '2014-07-15', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28227, 'San Germán', 'San German', 'San German,San Germán,Urbano Noris', 20.6000900, -76.1336400, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28228, 'Unión de Reyes', 'Union de Reyes', 'Union Reyes,Union de Reyes,Unión de Reyes', 22.7950500, -81.5361700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28229, 'Trinidad', 'Trinidad', 'Gorad Trynidad,TND,Trinidad,Trinidadas,te li ni da,teulinidadeu,torinida,trinidada,trynydad  kwba,trynydd,Горад Трынідад,Тринидад,Тринідад,טרינידד,ترینیداد، کوبا,ٹرینیڈاڈ، کیوبا,त्रिनिदाद,ტრინიდადი,トリニダ,特立尼达,트리니다드', 21.8022400, -79.9846700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28230, 'Topes de Collantes', 'Topes de Collantes', 'Topes de Collantes,Topes de Kol''jantes,Топес де Кольянтес', 21.9152400, -80.0192900, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28231, 'Taguasco', 'Taguasco', 'Taguasco', 22.0019800, -79.2638700, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28232, 'Soroa', 'Soroa', 'Soroa,Сороа', 22.8000000, -83.0166700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28233, 'Sibanicú', 'Sibanicu', 'Poblado Sibanicu,Sibanicu,Sibanicú', 21.2363100, -77.5256100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28234, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 22.5867700, -80.2426100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28235, 'Santiago de las Vegas', 'Santiago de las Vegas', 'Sant''jago-de-las-Vegas,Santiago de las Vegas,Сантьяго-де-лас-Вегас', 22.9700000, -82.3869400, 'CU', '2016-11-23', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28236, 'Santiago de Cuba', 'Santiago de Cuba', 'Gorad Santjaga-deh-Kuba,Kubos Santjagas,SCU,Sant''jago-de-Kuba,Sant''jago-de-Kubae,Santiago,Santiago de Cuba,Santiago de Cúba,Santiago de Kubo,Santiago di Cuba,Santiago nte Kouva,Santijago de Kuba,Santjago de Kuba,santiagodekuba,santyaghw dy kwba,santyagw d kwba,sheng de ya ge-de gu ba,Σαντιάγο ντε Κούβα,Горад Сантяга-дэ-Куба,Сантијаго де Куба,Сантьяго-де-Кубæ,Сантьяго-де-Куба,Сантяго де Куба,סנטיאגו דה קובה,سانتياغو دي كوبا,سانتیاگو د کوبا,სანტიაგო-დე-კუბა,サンティアーゴ・デ・クーバ,圣地亚哥-德古巴,산티아고데쿠바', 20.0208300, -75.8266700, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28237, 'Santa Cruz del Sur', 'Santa Cruz del Sur', 'Santa Cruz del Sur', 20.7163300, -77.9981600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28238, 'Santa Cruz del Norte', 'Santa Cruz del Norte', 'Santa Cruz del Norte', 23.1542400, -81.9255600, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28239, 'Santa Clara', 'Santa Clara', 'SNU,Santa Clara,Santa Klara,Santa-Klara,santa klara,santa klara  kywba,santakeullala,sheng ke la la,snth qlrh,Σάντα Κλάρα,Санта Клара,Санта-Клара,סנטה קלרה,سانتا كلارا,سانتا کلارا,سانتا کلارا، کیوبا,სანტა-კლარა,サンタ・クララ,圣克拉拉,산타클라라', 22.4069400, -79.9647200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28240, 'San Nicolás de Bari', 'San Nicolas de Bari', 'QSN,San Nicolas,San Nicolas de Bari,San Nicolás,San Nicolás de Bari', 22.7844400, -81.9133300, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28241, 'San Miguel del Padrón', 'San Miguel del Padron', 'San Miguel del Padron,San Miguel del Padrón', 23.0663900, -82.2947200, 'CU', '2012-06-26', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28242, 'San Luis', 'San Luis', 'San Luis', 22.2789800, -83.7595600, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28243, 'San Luis', 'San Luis', 'San Luis', 20.1880900, -75.8503100, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28244, 'San Juan y Martínez', 'San Juan y Martinez', 'San Juan y Martinez,San Juan y Martínez', 22.2796700, -83.8401000, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28245, 'San José de las Lajas', 'San Jose de las Lajas', '', 22.9613900, -82.1511100, 'CU', '2011-02-18', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28246, 'San Diego de Los Baños', 'San Diego de Los Banos', 'Banos San Diego,Baños San Diego,San Diego de Los Banos,San Diego de Los Baños', 22.6466700, -83.3697200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28247, 'Sancti Spíritus', 'Sancti Spiritus', 'Sancti Spiritus,Sancti Spíritus,Sankti-Spiritus,USS,Санкти-Спиритус', 21.9297200, -79.4425000, 'CU', '2017-05-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28248, 'San Cristobal', 'San Cristobal', 'San Cristobal,San Cristóbal', 22.7165800, -83.0564700, 'CU', '2014-07-18', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28249, 'San Antonio del Sur', 'San Antonio del Sur', 'San Antonio,San Antonio del Sur', 20.0575600, -74.8105400, 'CU', '2016-03-10', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28250, 'San Antonio de los Baños', 'San Antonio de los Banos', 'San Antonio de los Banos,San Antonio de los Baños', 22.8901800, -82.5009900, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28251, 'Sagua la Grande', 'Sagua la Grande', 'Sagua,Sagua la Grande', 22.8066700, -80.0755600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28252, 'Sagua de Tánamo', 'Sagua de Tanamo', 'Sagua de Tanamo,Sagua de Temamo,Sagua de Tánamo', 20.5826900, -75.2411600, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28253, 'Rodas', 'Rodas', 'Robas,Rodas,Родас', 22.3418400, -80.5559600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28254, 'Río Guayabal de Yateras', 'Rio Guayabal de Yateras', '', 20.3666700, -75.0166700, 'CU', '2006-01-17', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28255, 'Río Cauto', 'Rio Cauto', 'Rio Cauto,Río Cauto', 20.5597100, -76.9167300, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28256, 'Remedios', 'Remedios', 'Remedios,San Juan de los Remedios,Ремедиос', 22.4950200, -79.5454800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28257, 'Regla', 'Regla', 'Regea,Regla', 23.1250000, -82.3319400, 'CU', '2012-06-26', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28258, 'Ranchuelo', 'Ranchuelo', 'Ranchuelo', 22.3726600, -80.1504600, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28259, 'Rancho Veloz', 'Rancho Veloz', 'Rancho Veloz', 22.8804200, -80.3909800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28260, 'Santa Lucía', 'Santa Lucia', 'Rafael Freyre,Santa Lucia,Santa Lucía', 21.0294200, -75.9944100, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28261, 'Quivicán', 'Quivican', 'Kivikan,Quivican,Quivicán,Кивикан', 22.8231300, -82.3555800, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28262, 'Quemado de Güines', 'Quemado de Guines', 'Quemado de Guines,Quemado de Güines', 22.7881600, -80.2522600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28263, 'Puerto Padre', 'Puerto Padre', 'Puehrto-Padre,Puerto Padre,Пуэрто-Падре', 21.1951700, -76.6035800, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28264, 'Primero de Enero', 'Primero de Enero', 'Primero de Enero,Violeta', 21.9450100, -78.4313000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28265, 'Placetas', 'Placetas', 'Placetas', 22.3118400, -79.6544000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28266, 'Pinar del Río', 'Pinar del Rio', 'LCL,Pinar del Rio,Pinar del Rioko probintzia,Pinar del Río,Pinar-del''-Rio,Пинар дел Рио,Пинар-дель-Рио', 22.4166700, -83.6966700, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28267, 'Pilón', 'Pilon', 'Pilon,Pilón,Pion', 19.9055300, -77.3215200, 'CU', '2014-08-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28268, 'Perico', 'Perico', 'Perico', 22.7698700, -81.0183000, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28269, 'Pedro Betancourt', 'Pedro Betancourt', 'Corral Falso,Pedro Betancourt', 22.7270900, -81.2896300, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28270, 'Palmira', 'Palmira', 'Palmira', 22.2412600, -80.3911000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28271, 'Palma Soriano', 'Palma Soriano', 'Palma Soriano', 20.2113000, -75.9936200, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28272, 'Palenque', 'Palenque', 'Molina Palenque,Palenque', 20.3637300, -74.9704000, 'CU', '2016-03-10', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28273, 'Nuevitas', 'Nuevitas', 'Nuevitas', 21.5458500, -77.2650400, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28274, 'Nueva Paz', 'Nueva Paz', 'Nueva Paz', 22.7626600, -81.7561700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28275, 'Nueva Gerona', 'Nueva Gerona', 'GER,Nuehva-Kherona,Nueva Cherona,Nueva Gerona,Nueva Kherona,Nueva-Kherona,nuebahelona,nueva-kherona,nwywa gyrwna,xin he luo na,Нуева Херона,Нуева-Херона,Нуэва-Херона,نویوا گیرونا,ნუევა-ხერონა,ヌエバ・ヘローナ,新赫羅納,누에바헤로나', 21.8866700, -82.8055600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28276, 'Niquero', 'Niquero', 'Niguero,Niquero', 20.0469800, -77.5808900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28277, 'Najasa', 'Najasa', 'Najasa', 21.0730800, -77.7451600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28278, 'Morón', 'Moron', 'Moron,Morón,mo long,moroni,Морон,მორონი,莫隆', 22.1077400, -78.6266700, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28279, 'Moa', 'Moa', 'MOA,Minas de Hierro Moa,Moa,Puerto Cayo Moa,Моа', 20.6577600, -74.9507500, 'CU', '2014-08-14', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28280, 'Minas de Matahambre', 'Minas de Matahambre', 'Matahambre,Minas de Matahambre', 22.5869100, -83.9455100, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28281, 'Minas', 'Minas', 'Minas,Poblado Minas,Минас', 21.4880200, -77.6103300, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28282, 'Melena del Sur', 'Melena del Sur', '', 22.7881300, -82.1513800, 'CU', '2010-07-17', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28283, 'Media Luna', 'Media Luna', 'Media Luna', 20.1429800, -77.4353200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28284, 'Mayarí', 'Mayari', 'Mayari,Mayari Abajo,Mayarí', 20.6541700, -75.6794500, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28285, 'Matanzas', 'Matanzas', 'Gorad Matansas,Matansas,Matansasas,Matanzas,QMA,VRO,ma tan sa si,matansasu,Горад Матансас,Матанзас,Матансас,მატანსასი,マタンサス,馬坦薩斯', 23.0411100, -81.5775000, 'CU', '2014-01-19', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28286, 'Martí', 'Marti', 'Hato Nuevo,Marti,Martí', 22.9471400, -80.9190200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28287, 'Mariel', 'Mariel', 'Mariel', 22.9893100, -82.7537600, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28288, 'Manzanillo', 'Manzanillo', 'MZO,Mansanil''o,Mansaniljas,Manzanillo,Manzanilo,man sa ni yue,mansanilio,mansaniyo,mnsnyw,mnzanylw  kywba,Манзаниљо,Мансанильо,מנסניו,منزانیلو، کیوبا,მანსანილიო,曼薩尼約,만사니요', 20.3417300, -77.1212600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28289, 'Mantua', 'Mantua', 'Mantua', 22.2905800, -84.2859900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28290, 'Manicaragua', 'Manicaragua', 'Manicaragua,Poblado Manicaragua', 22.1502100, -79.9786700, 'CU', '2014-08-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28291, 'Manguito', 'Manguito', 'Manguito', 22.5873300, -80.9145100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28292, 'Manatí', 'Manati', 'Manati,Manatí', 21.3107000, -76.9340300, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28293, 'Majagua', 'Majagua', 'Majagua', 21.9171700, -79.0032900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28294, 'Maisí', 'Maisi', 'Maisi,Maisí,Maysi,Punta De Maisi,UMA', 20.2467300, -74.1518100, 'CU', '2013-09-22', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28295, 'Madruga', 'Madruga', 'Madruga', 22.9100000, -81.8563900, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28296, 'Los Palacios', 'Los Palacios', 'Los Palacios', 22.5888200, -83.2467100, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28297, 'Los Arabos', 'Los Arabos', 'Los Arabos', 22.7296900, -80.7208100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28298, 'Limonar', 'Limonar', 'Guamacaro,Limonar', 22.9503500, -81.4105900, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28299, 'Las Tunas', 'Las Tunas', 'Las Tunas,Las Tunasas,Las-Tunas,Tunas,VTU,Victoria,Victoria de Las Tunas,Victoria de las Tunas,Viktoria de las Tunas,Viktorija de Las Tunas,las twnas,laseutunaseu,wei duo li ya-de la si tu na si,Викторија де Лас Тунас,Лас-Тунас,Тунас,Վիկտորիա դե լաս Տունաս,ויקטוריה דה לאס טונאס,لاس توناس,ლას-ტუნასი,维多利亚-德拉斯图纳斯,라스투나스', 20.9616700, -76.9511100, 'CU', '2013-11-02', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28300, 'La Sierpe', 'La Sierpe', 'La Sierpe', 21.7724100, -79.2683200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28301, 'La Salud', 'La Salud', 'La Saljud,La Salud,Salud,Ла Салюд', 22.8719900, -82.4232800, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28302, 'La Palma', 'La Palma', 'Consolacion del Norte,Consolación del Norte,La Palma,La Palma Consolacion del Norte', 22.7499500, -83.5541500, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28303, 'Lajas', 'Lajas', 'Lajas,Santa Isabel de las Lajas', 22.4147900, -80.2931000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28304, 'Havana', 'Havana', 'A Habana,Abana,Gavana,Gavanae,Gavane,Gorad Gavana,HAV,Habana,Hafana,Hahvaxnaz,Havan,Havana,Havanna,Havano,Hawana,Khavana,L''Avana,LAvan-a,LAvana,LAvann-a,LHabana,LHavana,La Ahuana,La Avan,La Avàn,La Habana,La Havana,La Havane,abana,avana,ha wa na,habana,habhana,hafana,havana,hawana,xia wan na,Ħavana,ŁAvana,Αβάνα,Гaванa,Гаванæ,Гавана,Гаване,Горад Гавана,Хавана,Ҳавана,Հավանա,האוואנע,הוואנה,هافانا,هاوانا,ہوانا,हवाना,হাভানা,ਹਵਾਨਾ,ହାଭାନା,அவானா,ഹവാന,ฮาวานา,ཧ་ཝན,ဟာဗားနားမြို့,ჰავანა,ሀቫና,ሀኖይ,ハバナ,哈瓦那,夏灣拿,아바나', 23.1330200, -82.3830400, 'CU', '2014-04-04', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28305, 'Puerto Esperanza', 'Puerto Esperanza', 'La Esperanza,La Esperenza,Puehrto Ehsperansa,Puerto Esperanza,Puerto La Esperanza,Puerto de Esperanza,Пуэрто Эсперанса', 22.7704100, -83.7313800, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28306, 'Jovellanos', 'Jovellanos', 'Bemba,Jovallanos,Jovellanos', 22.8037500, -81.1912700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28307, 'Jobabo', 'Jobabo', 'Jaboba,Jobabo', 20.9691700, -76.2994400, 'CU', '2012-01-18', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28308, 'Jobabo', 'Jobabo', 'Jababo,Jobabo', 20.9074800, -77.2819400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28309, 'Jiguaní', 'Jiguani', 'Jiguani,Jiguaní', 20.3678500, -76.4274100, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28310, 'Jesús Menéndez', 'Jesus Menendez', 'Chaparra,Jesus Menendez,Jesús Menéndez', 21.1613900, -76.4791900, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28311, 'Jatibonico', 'Jatibonico', 'Jatibonico', 21.9433300, -79.1690600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28312, 'Jaruco', 'Jaruco', 'Jaruco', 23.0441900, -82.0091900, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28313, 'Jamaica', 'Jamaica', 'Jamaica', 22.9755900, -82.1685200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28314, 'Jagüey Grande', 'Jaguey Grande', 'Jaguey Grande,Jagüey Grande', 22.5269400, -81.1286100, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28315, 'Imías', 'Imias', 'Imias,Imías', 20.0693600, -74.6314000, 'CU', '2016-03-10', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28316, 'Holguín', 'Holguin', 'Gorad Ol''gin,HOG,Holginas,Holguin,Holguín,Holquin,Ol''gin,Olgin,ao er jin,olgini,orugin,ʼwlgyn,Горад Ольгін,Олгин,Ольгин,אולגין,ოლგინი,オルギン,奧爾金', 20.8872200, -76.2630600, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28317, 'Guisa', 'Guisa', 'Guisa,Poblado Guisa', 20.2549400, -76.5393000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28318, 'Güira de Melena', 'Guira de Melena', 'Gueira de Melena,Guira de Melena,Güira de Melena', 22.7961300, -82.5066700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28319, 'Güines', 'Gueines', 'Guines,Güines,Гуинес', 22.8372700, -82.0264100, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28320, 'Guayos', 'Guayos', 'Guayos', 22.0495600, -79.4610600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28321, 'Guara', 'Guara', '', 22.8100000, -82.2030600, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28322, 'Guantánamo', 'Guantanamo', 'GAO,Guantanama,Guantanamo,Guantánamo,Guatanamo,guantanamo,Гуантанама,Гуантанамо,גואנטנמו,グアンタナモ', 20.1444400, -75.2091700, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28323, 'Guane', 'Guane', 'Guane', 22.2017900, -84.0848400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28324, 'Guanajay', 'Guanajay', 'Guanajay', 22.9263900, -82.6875000, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28325, 'Guanabacoa', 'Guanabacoa', 'Guanabacoa', 23.1236000, -82.3008200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28326, 'Guáimaro', 'Guaimaro', 'Guaimaro,Guasimaro,Guaymaro,Guáimaro', 21.0522200, -77.3499000, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28327, 'Mañalich', 'Manalich', '', 22.8111200, -82.1474800, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28328, 'Gibara', 'Gibara', 'Gibara', 21.1098800, -76.1314500, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28329, 'Gaspar', 'Gaspar', 'Gaspar', 21.7387200, -78.5443400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28330, 'Fomento', 'Fomento', 'Fomento', 22.1047500, -79.7214100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28331, 'Florida', 'Florida', 'Florida,La Florida,Флорида', 21.5253600, -78.2257900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28332, 'Florencia', 'Florencia', 'Florencia', 22.1461000, -78.9732800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28333, 'Esperanza', 'Esperanza', 'Esperanza,La Esperanza', 22.4468000, -80.0971100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28334, 'Esmeralda', 'Esmeralda', 'Ehsmeral''da,Esmeralda,La Esmeralda,ai si mei la da,esmeralda,Эсмеральда,ესმერალდა,埃斯梅拉達', 21.8513900, -78.1172500, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28335, 'Encrucijada', 'Encrucijada', 'Encrucijada', 22.6180200, -79.8660300, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28336, 'El Cobre', 'El Cobre', 'Cobre,El Cobre,Santiago del Prado', 20.0485000, -75.9457900, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28337, 'El Caney', 'El Caney', '', 21.3000000, -78.4833300, 'CU', '2006-01-17', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28338, 'Cumanayagua', 'Cumanayagua', 'Cumanayagua', 22.1524700, -80.2035400, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28339, 'Cueto', 'Cueto', 'Cueto', 20.6485500, -75.9296700, 'CU', '2015-11-02', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28340, 'Cruces', 'Cruces', 'Cruces,Crues,Kruses,Las Cruces,Крусес', 22.3420300, -80.2702100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28341, 'Corralillo', 'Corralillo', 'Coralillo,Corralillo', 22.9821200, -80.5855600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28342, 'Contramaestre', 'Contramaestre', 'Contramaestre', 20.2987900, -76.2451100, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28343, 'Consolación del Sur', 'Consolacion del Sur', 'Consolacion,Consolacion del Sur,Consolación,Consolación del Sur', 22.5041900, -83.5144200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28344, 'Condado', 'Condado', 'Condado,General Machado,Kondado,Кондадо', 21.8767000, -79.8401400, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28345, 'Colón', 'Colon', 'Colon,Colón,Kolon,Kolonas,QCO,ke long,kwlwn  kywba,Колон,کولون، کیوبا,კოლონი,科隆', 22.7206400, -80.9049200, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28346, 'Colombia', 'Colombia', 'Colombia', 20.9881200, -77.4259800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28347, 'Ciro Redondo', 'Ciro Redondo', 'Ciro Redondo,Pina', 22.0192100, -78.7036500, 'CU', '2014-08-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28348, 'Cifuentes', 'Cifuentes', 'Cifuentes', 22.6493000, -80.0493500, 'CU', '2014-07-18', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28349, 'Cienfuegos', 'Cienfuegos', 'CFG,Cienfuegos,Gorad S''enfuehgas,S''enfuegos,S''enfuehgos,Sjenfuegos,Sjenfuegosas,seiyn fwy kos,shienfuegosu,sienpuegosi,synfwyghws,xi en fu ge si,Горад Сьенфуэгас,Сьенфуэгос,Сьєнфуегос,Сјенфуегос,סיינפואגוס,سينفويغوس,เซียนฟวยโกส,სიენფუეგოსი,シエンフエーゴス,西恩富戈斯', 22.1495700, -80.4466200, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28350, 'Ciego de Ávila', 'Ciego de Avila', 'AVI,Ciego de Avila,Ciego de Ávila', 21.8400000, -78.7619400, 'CU', '2012-01-14', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28351, 'Chambas', 'Chambas', 'Chambas', 22.1953400, -78.9123000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28352, 'Cerro', 'Cerro', 'Cerro', 23.1086100, -82.3777800, 'CU', '2012-06-20', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28353, 'Cayo Mambí', 'Cayo Mambi', 'Cayo Mambi,Cayo Mambí,Cayo Manbi,Frank Pais,Frank País', 20.6638100, -75.2688200, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28354, 'Cauto Cristo', 'Cauto Cristo', 'Cauto Cristo,Cauto del Cristo,Cauto el Cristo', 20.5570900, -76.4727000, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28355, 'Carlos Manuel de Céspedes', 'Carlos Manuel de Cespedes', 'Carlos Manuel de Cespedes,Carlos Manuel de Céspedes,Cespedes,Céspedes', 21.5757200, -78.2825100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28356, 'Cárdenas', 'Cardenas', 'Cardenas,Cárdenas,Gorad Kardehnas,Kardenas,Kardenasas,ka er de na si,Горад Кардэнас,Карденас,کارڈیناس، کیوبا,კარდენასი,卡爾德納斯', 23.0366100, -81.2059600, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28357, 'Candelaria', 'Candelaria', 'Candelaria', 22.7405700, -82.9591200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28358, 'Campechuela', 'Campechuela', 'Campechuela', 20.2332900, -77.2799000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28359, 'Camajuaní', 'Camajuani', '', 22.4833300, -79.7500000, 'CU', '2006-01-17', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28360, 'Camajuaní', 'Camajuani', 'Camajuani,Camajuaní', 22.4647600, -79.7232400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28361, 'Camagüey', 'Camaguey', 'CMW,Camagueey,Camaguey,Camagüey,Kamaguehj,Kamaguej,Puerto Principe,kamaguei,Камагуей,Камагуэй,קמאגואיי,カマグエイ', 21.3808300, -77.9169400, 'CU', '2014-01-18', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28362, 'Calixto', 'Calixto', 'Calixto', 20.9203600, -76.8714400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28363, 'Calimete', 'Calimete', 'Calimete,Poblado Calimete', 22.5342000, -80.9110500, 'CU', '2014-08-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28364, 'Calabazar de Sagua', 'Calabazar de Sagua', 'Calabazar,Calabazar de Sagua', 22.6451500, -79.8951000, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28365, 'Caimito', 'Caimito', 'Caimito,Caimito Guayabal,Caimito de Guayaba,Caimito del Guavabal,Caimito del Guayabal', 22.9505200, -82.5943500, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28366, 'Caibarién', 'Caibarien', 'Caibairien,Caibarien,Caibarién,Kaibarjenas,kai wa lian,kybryyn,کیبریئن,კაიბარიენი,凱瓦連', 22.5199600, -79.4659900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28367, 'Cacocum', 'Cacocum', 'Cacocum,San Pedro de Cacocum', 20.7377500, -76.3257400, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28368, 'Cabañas', 'Cabanas', 'Cabanas,Cabañas', 22.9794400, -82.9221400, 'CU', '2014-04-17', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28369, 'Cabaiguán', 'Cabaiguan', 'Cabaiguan,Cabaiguán,Poblado Cabaiguan', 22.0787400, -79.4972600, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28370, 'Buey Arriba', 'Buey Arriba', 'Buey Arriba,Minas de Buey Arriba', 20.1718200, -76.7565900, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28371, 'Bolondrón', 'Bolondron', 'Bolondron,Bolondrón', 22.7630700, -81.4478000, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28372, 'Bolivia', 'Bolivia', 'Bolivia,Cunagua', 22.0839700, -78.3388400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28373, 'Bejucal', 'Bejucal', 'Bejucal,Bejucall,Bekhukal'',bei hu ka er,Бехукаль,ბეხუკალი,貝胡卡爾', 22.9286100, -82.3886100, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28374, 'Bayamo', 'Bayamo', 'BYM,Bajamo,Bayamo,Баямо', 20.3741700, -76.6436100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28375, 'Bauta', 'Bauta', 'Bauta,Hoyo Colorado', 22.9822600, -82.5471900, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28376, 'Batabanó', 'Batabano', 'Batabano,Batabanó', 22.7179400, -82.2896500, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28377, 'Bartolomé Masó', 'Bartolome Maso', 'Bartolome Maso,Bartolomé Masó', 20.1663500, -76.9429100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28378, 'Baraguá', 'Baragua', 'Baragua,Baraguá', 21.6821600, -78.6256700, 'CU', '2014-08-12', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28379, 'Baracoa', 'Baracoa', 'BCA,Baracoa,Barakoa,Баракоа', 20.3471100, -74.4962400, 'CU', '2016-03-10', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28380, 'Banes', 'Banes', 'Banes', 20.9611600, -75.7220000, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28381, 'Bahía Honda', 'Bahia Honda', 'Bahia Honda,Bahía Honda', 22.9033200, -83.1599400, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28382, 'Báguanos', 'Baguanos', 'Baguano,Baguanos,Báguano,Báguanos,Lopez Pena,López Peña', 20.7510300, -76.0257100, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28383, 'Artemisa', 'Artemisa', 'Artemisa,Артемиса', 22.8166700, -82.7594400, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28384, 'Arroyo Naranjo', 'Arroyo Naranjo', 'Arroyo Naranjo,Ponce', 23.0367700, -82.3693700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28385, 'Antilla', 'Antilla', 'Antilla', 20.8310400, -75.7356600, 'CU', '2016-02-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28386, 'Amancio', 'Amancio', 'Amancio,Amancio Rodriguez,Amancio Rodríguez,Francisco', 20.8191400, -77.5795800, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28387, 'Alquízar', 'Alquizar', 'Alquizar,Alquízar', 22.8051700, -82.5839200, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28388, 'Alamar', 'Alamar', 'Alamar,Nueva Villa Real,Аламар', 23.1579400, -82.2783700, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28389, 'Alacranes', 'Alacranes', 'Alacranes,Alcranes,Alfonso XII', 22.7671900, -81.5680300, 'CU', '2015-12-06', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28390, 'Aguada de Pasajeros', 'Aguada de Pasajeros', 'Aguada,Aguada de Pasajeros', 22.3852000, -80.8479200, 'CU', '2016-11-21', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28391, 'Abreus', 'Abreus', 'Abreu,Abreus', 22.2779700, -80.5693100, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28392, 'Habana del Este', 'Habana del Este', 'Habana del Este,La Habana del Este', 23.1591700, -82.3305600, 'CU', '2012-06-26', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28393, 'Centro Habana', 'Centro Habana', 'Centro Habana', 23.1383300, -82.3641700, 'CU', '2012-05-31', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28394, 'La Habana Vieja', 'La Habana Vieja', 'La Habana Vieja', 23.1302800, -82.3530600, 'CU', '2012-06-27', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28395, 'Báguanos', 'Baguanos', 'Baguanos,Báguanos', 20.7516700, -76.0269400, 'CU', '2013-04-04', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28396, 'Jimaguayú', 'Jimaguayu', 'Jimaguayu,Jimaguayú', 21.2422400, -77.8262500, 'CU', '2016-01-07', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28397, 'Arroyo Naranjo', 'Arroyo Naranjo', '', 23.0144000, -82.3031000, 'CU', '2012-09-11', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28398, 'Boyeros', 'Boyeros', 'Bojeros,Boyeros,Бойерос', 23.0072000, -82.4017000, 'CU', '2016-09-27', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28399, 'Diez de Octubre', 'Diez de Octubre', '', 23.0881000, -82.3597000, 'CU', '2012-06-26', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28400, 'Segundo Frente', 'Segundo Frente', '', 20.4138400, -75.4963500, 'CU', '2014-08-14', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28401, 'Cubitas', 'Cubitas', 'Cubitas', 21.7121200, -77.7613000, 'CU', '2016-01-09', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28402, 'La Máquina', 'La Maquina', 'La Maquina,La Máquina', 20.1919800, -74.2271900, 'CU', '2016-03-12', 57);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28428, 'Willemstad', 'Willemstad', 'Gorad Vilemstad,Vilemstad,Vilemstadas,Vilemstade,Vilemstado,Villemstad,Villemstant,Villemştad,Willemstad,Willemsted,Willemstêd,billemseutateu,u~iremusutatto,vilemastada,villemstatu,wei lian si ta de,willems tad,wylmstad,Βίλλεμσταντ,Вилемстад,Виллемстад,Віллемстад,Горад Вілемстад,וילמסטאד,ويلمستاد,ویلمستاد,ویلمسٹیڈ,विलेमश्टाड,வில்லெம்ஸ்டாடு,วิลเลมสตัด,ვილემსტადი,ウィレムスタット,威廉斯塔德,빌렘스타트', 12.1084000, -68.9335400, 'CW', '2010-12-18', 58);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28429, 'Sint Michiel Liber', 'Sint Michiel Liber', '', 12.1500000, -68.9833300, 'CW', '2006-01-17', 58);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28430, 'Dorp Soto', 'Dorp Soto', 'Dorp Soto,Soto', 12.2774900, -69.1125000, 'CW', '2017-02-18', 58);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28431, 'Barber', 'Barber', 'Barber', 12.2901400, -69.0738900, 'CW', '2017-02-17', 58);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28433, 'Protaras', 'Protaras', 'Protaras,Протарас', 35.0125000, 34.0583300, 'CY', '2014-07-16', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28434, 'Ýpsonas', 'Ypsonas', 'Ipsona,Ipsonas,Ypsonas,Ýpsonas,İpsona,Ύψωνας', 34.6879700, 32.9619100, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28435, 'Géri', 'Geri', 'Geri,Géri,Yeri,Γέρι,Гери', 35.1056000, 33.4197700, 'CY', '2015-04-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28436, 'Xylotymbou', 'Xylotymbou', 'Ksilodimbo,Ksilodimbu,Ksilotimbu,Xylotymbo,Xylotymbou,Xylotymvou,Ξυλοτύμβου', 35.0172000, 33.7424500, 'CY', '2013-03-07', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28437, 'Tséri', 'Tseri', 'Bilen,Seri,Tseri,Tséri,Xeri,Τσέρι', 35.0730700, 33.3234400, 'CY', '2015-04-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28438, 'Voróklini', 'Voroklini', 'Oroklini,Vorglini,Voroglini,Voroklini,Voróklini,Βορόκληνη', 34.9860000, 33.6538700, 'CY', '2017-05-09', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28439, 'Troúlloi', 'Troulloi', 'Troulli,Troulloi,Troúlloi,Trulli,Τρούλλοι', 35.0320300, 33.6150100, 'CY', '2015-03-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28440, 'Tríkomo', 'Trikomo', 'Iskele,Trikomo,Tríkomo,İskele,Τρίκωμο', 35.2862800, 33.8916700, 'CY', '2015-01-07', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28441, 'Tersefánou', 'Tersefanou', 'Tersefan,Tersefanou,Tersefánou,Tersephanou,Tersofanu,Τερσεφάνου', 34.8541100, 33.5474600, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28442, 'Tála', 'Tala', 'Dala,Dalâ,Tala,Tála,Τάλα', 34.8374500, 32.4327200, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28443, 'Sotíra', 'Sotira', 'Sotira,Sotíra,Σωτήρα', 34.7118900, 32.8634000, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28444, 'Rizokárpaso', 'Rizokarpaso', 'Dipkarpas,Dipkarpaz,Dipkurpaz,Rizokarpaso,Rizokarpason,Rizokarpasso,Rizokárpaso,Ριζοκάρπασο', 35.5971900, 34.3791600, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28445, 'Pyrgos', 'Pyrgos', 'Pyrga,Pyrgos', 34.7416700, 33.1833300, 'CY', '2013-08-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28446, 'Pýla', 'Pyla', 'Pila,Pile,Pyla,Pýla,Πύλα', 35.0123700, 33.6918800, 'CY', '2015-03-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28447, 'Psimolofou', 'Psimolofou', 'Psimolofou,Psomolafa,Psomolof,Psomolopho,Psomolophou,Somolof,Ψιμολόφου', 35.0625000, 33.2625000, 'CY', '2012-05-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28448, 'Psevdás', 'Psevdas', 'Pseftas,Psevda,Psevdas,Psevdhas,Psevdás,Ψευδάς', 34.9465300, 33.4627700, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28449, 'Pólis', 'Polis', 'Poli,Polis,Polis Chrysochous,Pólis,Πόλις', 35.0353400, 32.4257500, 'CY', '2014-05-28', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28450, 'Pissoúri', 'Pissouri', 'Pissouri,Pissoúri,Pissuri,Πισσούρι', 34.6694200, 32.7013200, 'CY', '2014-09-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28451, 'Frénaros', 'Frenaros', 'Frenaro,Frenaros,Frennaros,Frénaros,Phrenaros,Φρέναρος', 35.0412100, 33.9224200, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28452, 'Pégeia', 'Pegeia', 'Pegeia,Peya,Peyia,Pégeia,Πέγεια', 34.8834100, 32.3816600, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28453, 'Perivólia', 'Perivolia', 'Bahcalar,Bahceler,Bahçalar,Bahçeler,Bervolya,Perivolia,Perivolya,Perivólia,Περιβόλια', 34.8335500, 33.5819600, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28454, 'Peristeróna', 'Peristerona', 'Peristerona,Peristeróna,Perısterona,Περιστερώνα', 35.1292800, 33.0785800, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28455, 'Pérgamos', 'Pergamos', 'Beyarmudu,Pergama,Pergamos,Pérgamos,Πέργαμος,Пергамос', 35.0416700, 33.7083300, 'CY', '2015-03-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28456, 'Péra', 'Pera', 'Pera,Péra,Πέρα', 35.0335000, 33.2541300, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28457, 'Peléndri', 'Pelendri', 'Belendri,Pelendri,Pelendria,Peléndri,Πελένδρι', 34.8959700, 32.9681700, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28458, 'Parekklisha', 'Parekklisha', 'Parekklisha,Parekklisia,Pareklisa,Pareklisha,Pareklişa', 34.7458300, 33.1583300, 'CY', '2013-08-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28459, 'Paralímni', 'Paralimni', 'Paralim,Paralimni,Paralímni,Paralımnı,Παραλίμνι', 35.0394500, 33.9818100, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28460, 'Paphos', 'Paphos', 'Baf,Gazibaf,Nea Pafos,Nea Paphos,Néa Páfos,PFO,Pafo,Pafos,Paphos,Páfos,Πάφος,Παφος,Пафос', 34.7767900, 32.4245100, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28461, 'Páno Polemídia', 'Pano Polemidia', 'Pano Polemidhia,Pano Polemidia,Pano Polemidya,Polemidia,Páno Polemídia,Yukari Binatli,Yukari Polemitya,Yukarı Binatlı,Yukarı Polemitya,Πάνω Πολεμίδια', 34.7055900, 32.9926900, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28462, 'Páno Defterá', 'Pano Deftera', 'Deftera Pano,Defterá Pano,Pano Deftera,Pano Dheftera,Páno Defterá,Yukari Deftera,Yukarı Deftera,Πάνω Δευτερά', 35.0777800, 33.2658400, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28463, 'Páchna', 'Pachna', 'Pachna,Pahna,Pakhna,Páchna,Πάχνα', 34.7787400, 32.7935500, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28464, 'Nicosia', 'Nicosia', 'An Leafcois,An Leafcóis,Gorad Nikasija,Lefkosa,Lefkosha,Lefkosia,Lefkosian,Lefkosía,Lefkoşa,Leucosia,NIC,Nekoseje,Nicosea,Nicosia,Nicosia (Lefkosia),Nicosia - Leukosia,Nicosia - Λευκωσία,Nicosie,Nicoséa,Nicosìa,Nicusia,Nicusìa,Nicòsia,Nicósia,Nikosi,Nikosia,Nikosie,Nikosii,Nikosij,Nikosija,Nikosija osh,Nikosiya,Nikozi,Nikozia,Nikozija,Nikozio,Nikozja,Nikósie,Nikósía,Nikózia,Niqusya,Nėkosėjė,ni ke xi ya,ni kho seiy,nikkeasya,nikkociya,nikojya,nikoshia,nikosi''a,nikosia,nikosiya,nikozia,nykwsya,nykwzya,nyqwsya,nyqwsyh,Λευκωσία,Λευκωσίαν,Горад Нікасія,Лефкоша,Никозия,Никозија,Никоси,Никосий,Никосия,Никосия ош,Нікосія,Նիկոսիա,ניקאסיע,ניקוסיה,نىكوسىيە,نيقوسيا,نيكوسيا,نیکوزیا,نیکوسیا,نیکۆسیا,निकोज्या,निकोसिया,নিকোসিয়া,ਨਿਕੋਸੀਆ,ନିକୋସିଆ,நிக்கோசியா,ನಿಕೋಸಿಯ,നിക്കോഷ്യ,นิโคเซีย,ནེ་ཁོ་ཤི་ཡ།,ნიქოზია,ሌፍኮዚያ,ニコシア,尼科西亚,尼科西亞,니코시아', 35.1753100, 33.3642000, 'CY', '2015-04-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28465, 'Mouttagiáka', 'Mouttagiaka', 'Moutayaka,Moutayiaka,Mouttagiaka,Mouttagiáka,Mutayaka,Muthiyaka,Mutlayaka,Mutluyaka,Muttayaka,Μουτταγιάκα', 34.7202200, 33.1006600, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28466, 'Mosfilotí', 'Mosfiloti', 'Mosfiloti,Mosfilotí,Mosphiloti,Μοσφιλωτή', 34.9525600, 33.4251100, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28467, 'Mórfou', 'Morfou', 'Guzelkoy,Guzelyurt,Güzelköy,Güzelyurt,Morfou,Morphou,Mórfou,Omorfo,Μόρφου', 35.1986900, 32.9933800, 'CY', '2014-01-09', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28468, 'Mesógi', 'Mesogi', 'Mesogi,Mesoyi,Mesógi,Μεσόγη', 34.8157700, 32.4554200, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28469, 'Meneou', 'Meneou', 'Meneou,Meneu,Menevi', 34.8611400, 33.5951600, 'CY', '2012-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28470, 'Mámmari', 'Mammari', 'Mammari,Mámmari,Μάμμαρη,Μάμμαρι', 35.1760400, 33.2043500, 'CY', '2015-02-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28471, 'Lythrodóntas', 'Lythrodontas', 'Litrodonda,Litrodontas,Litronda,Lythrodhonda,Lythrodhondas,Lythrodonda,Lythrodontas,Lythrodóntas,Λυθροδόντας', 34.9510500, 33.2977700, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28472, 'Lýmpia', 'Lympia', 'Limbia,Limbya,Limya,Lymbia,Lympia,Lýmpia,Olympia,Λύμπια', 34.9988900, 33.4617500, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28473, 'Livádia', 'Livadia', 'Leivadia,Livadhia,Livadia,Livadya,Livatia,Livatya,Livádia,Sazlikoy,Sazlıköy,Λιβάδια', 34.9511800, 33.6265800, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28474, 'Liopétri', 'Liopetri', 'Leopetra,Liopetri,Liopétri,Liyopetri,Lıopetrı,Λιοπέτρι', 35.0088500, 33.8925600, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28475, 'Limassol', 'Limassol', 'Gorad Limasol,Lemesos,Lemessus,Lemesós,Leymosun,Limasol,Limasol shaary,Limasolis,Limasolo,Limassol,Limisso,QLI,li ma suo er,li ma sxl,limasol,limasoli,lymaswl,lymswl,rimasoru,Λεμεσός,Горад Лімасол,Лимасол,Лимасол шаары,Лімасол,Լիմասոլ,לימסול,ليماسول,لیماسول,ലിമസ്സോൾ,ลีมาซอล,ლიმასოლი,リマソール,利马索尔,리마솔', 34.6840600, 33.0379400, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28476, 'Leonárisso', 'Leonarisso', 'Leonariso,Leonarisso,Leonárisso,Ziamet,Ziyamet,Λεονάρισσο', 35.4689200, 34.1388600, 'CY', '2014-05-28', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28477, 'Lefkónoiko', 'Lefkonoiko', 'Aksaray,GEC,Gecitkale,Geçitkale,Lefkoniko,Lefkonikon,Lefkonoiko,Lefkonuk,Lefkónoiko,Λευκόνοικο', 35.2598000, 33.7318900, 'CY', '2017-01-09', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28478, 'Léfka', 'Lefka', 'Lefka,Lefke,Lefke-Karadag,Lefke-Karadağ,Léfka,Λεύκα', 35.1119900, 32.8499700, 'CY', '2015-04-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28479, 'Larnaca', 'Larnaca', 'Chittim,Citium,Kition,Kitium,Kittim,Kozan,LCA,Lapithou,Larnaca,Larnaka,Làrnaca,Lárnaca,Lárnaka,Salina,Salines,la na ka,laleunaka,lar na ka,larnaka,larnka,lrnaka,lrnqh,rarunaka,Λάρνακα,Ларнака,Լառնակա,לרנקה,لارناکا,لارنكا,لرناکا,ลาร์นากา,ལར་ན་ཀ།,ლარნაკა,ラルナカ,拉纳卡,라르나카', 34.9229100, 33.6233000, 'CY', '2017-07-03', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28480, 'Lápithos', 'Lapithos', 'Gilderen,Gildirin,Lapithos,Lapitos,Lapta,Lápithos,Lâpta,Λάπηθος', 35.3382300, 33.1736800, 'CY', '2014-11-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28481, 'Kyrenia', 'Kyrenia', 'Cirenia,Cirénia,Girne,Kerineja,Kerinia,Keryneia,Kerynia,Kerínia,Kerýneia,Kirenia,Kirenija,Kirinija,Kyrenia,Kyrinia pa Kypros,Kyrínia på Kypros,Kérynia,ghrnt,kai li ni ya,kayrnya,kilenia,kirenia,kyrynya,qyrnyh,Κερύνεια,Керинеја,Кирения,Кириния,Кіренія,Կիրենիա,קירניה,غرنة,کایرنیا,کیرینیا,کیرینیہ,კირენია,キレニア,凯里尼亚,키레니아', 35.3363400, 33.3172900, 'CY', '2014-09-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28482, 'Kyperoúnta', 'Kyperounta', 'Ciperunda,Kiperunda,Kyperounda,Kyperounta,Kyperoúnta,Κυπερούντα', 34.9381500, 32.9755100, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28483, 'Kórnos', 'Kornos', 'Khorno,Korno,Kornos,Kórnos,Kόρνος,Κόρνος', 34.9239600, 33.3976400, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28484, 'Kofínou', 'Kofinou', 'Bakracli,Bakraçli,Gecitkale,Geçitkale,Kato Kophinou,Kofinou,Kofinu,Kofunye,Kofínou,Kophino,Kophinou,Köfünye,Pano Kophina,Pano Kophinou,Páno Kophína,Κοφίνου', 34.8244900, 33.3913000, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28485, 'Kolossi', 'Kolossi', 'Burciu,Burclu,Burçiu,Burçlu,Kolos,Kolossi,Yunus', 34.6686500, 32.9337500, 'CY', '2012-03-28', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28486, 'Kokkinotrimithiá', 'Kokkinotrimithia', 'Koccinno-Trimitya,Koccinotrimitya,Kocinodrimitya,Kokino Trimithia,Kokkini Trimithia,Kokkinotrimithia,Kokkinotrimithiá,Kokkinotrimitya,Kokıno Trımıthıa,Koçinodrimitya,Koççinno-Trimitya,Koççinotrimitya,Κοκκινοτριμιθιά', 35.1530300, 33.1996600, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28487, 'Klírou', 'Klirou', 'Klirou,Kliru,Klírou,Klırou,Κλήρου', 35.0200400, 33.1780600, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28488, 'Kíti', 'Kiti', 'Cite,Kiti,Kition,Kíti,Çite,Κίτι', 34.8469600, 33.5734400, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28489, 'Kissónerga', 'Kissonerga', 'Cisonerga,Kisonerga,Kissonerga,Kissoneros,Kissónerga,Κισσόνεργα', 34.8221700, 32.4019100, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28490, 'Chlórakas', 'Chlorakas', 'Chloraka,Chlorakas,Chlórakas,Hiloraka,Hloraka,Khlorakas,Klorakas,Χλώρακας', 34.7976800, 32.4120700, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28491, 'Káto Pýrgos', 'Kato Pyrgos', 'Asagi Pirgo,Aşağı Pirgo,Kato Pirgo,Kato Pyrgos,Káto Pýrgos,Κάτω Πύργος', 35.1789700, 32.6860000, 'CY', '2015-02-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28492, 'Káto Defterá', 'Kato Deftera', 'Asagi Deftera,Aşağı Deftera,Deftera,Dheftera,Kato Deftera,Kato Dheftera,Káto Defterá,Κάτω Δευτερά', 35.0848900, 33.2755800, 'CY', '2015-04-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28493, 'Kakopetriá', 'Kakopetria', 'Kakopetria,Kakopetriya,Kakopetriá,Κακοπετριά', 34.9876800, 32.9046800, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28494, 'Famagusta', 'Famagusta', 'Ammochostos,Ammochostus,Ammokhostos,Ammóchostos,Ammókhostos,Amokhostos,Fama Augusta,Famagosta,Famagouste,Famagusta,Gazi Magosa,Gazimagusa,Gazimağusa,Magosa,Magusa,Mağusa,fa ma gu si ta,famaghwsta,famagusuta,famagwsta,pamaguseuta,pmgwsth,Αμμόχωστος,Амохостос,Фамагуста,Ֆամագուստա,פמגוסטה,فاماغوستا,فاماگوستا,ფამაგუსტა,ファマグスタ,法马古斯塔,파마구스타', 35.1205400, 33.9389400, 'CY', '2014-09-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28495, 'Erími', 'Erimi', 'Erimi,Erími,Ερήμη', 34.6776600, 32.9181500, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28496, 'Émpa', 'Empa', 'Emba,Empa,Émpa,Έμπα', 34.8076500, 32.4240200, 'CY', '2014-06-04', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28497, 'Dhromolaxia', 'Dhromolaxia', 'Dromolaksia,Dromolaxia,Mor Menekshe,Mormenekse,Mormenekşe', 34.8755100, 33.5868400, 'CY', '2008-11-10', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28498, 'Derýneia', 'Deryneia', 'Derinia,Derinkoy,Derinköy,Derinya,Deryneia,Derynia,Derýneia,Dherinia,Yukari Derinya,Yukarı Derinya,Δερύνεια', 35.0648400, 33.9608300, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28499, 'Dáli', 'Dali', 'Dali,Dalı,Dhali,Dáli,Idalion,Δάλι', 35.0229400, 33.4219500, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28500, 'Ágios Týchon', 'Agios Tychon', 'Agios Tychon,Ayandihona,Ayios Tihonos,Ayios Tykhonas,Ayithona,Ágios Týchon,Άγιος Τύχων', 34.7260600, 33.1387200, 'CY', '2014-03-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28501, 'Ayia Napa', 'Ayia Napa', 'Agia Napa,Agija Napa,Agía Nápa,Aja-Napa,Ajia Napa,Ajja-Napa,Aya Napa,Ayia Napa,Aynapa,Aĝia Napa,QNP,a yi na pa,aya napa,ayya napa,Αγία Νάπα,Агия Напа,Айя-Напа,Ая-Напа,Այիա Նապա,איה נאפה,آئیا ناپا,ایا ناپا,აია-ნაპა,阿依納帕', 34.9821300, 34.0018300, 'CY', '2014-07-15', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28502, 'Avgórou', 'Avgorou', 'Avghorou,Avgora,Avgoro,Avgorou,Avgoru,Avgórou,Αυγόρου', 35.0361500, 33.8391800, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28503, 'Áchna', 'Achna', 'Achna,Ahna,Akhna,Athna,Duzce,Düzce,Áchna,Άχνα', 35.0551500, 33.7838800, 'CY', '2014-09-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28504, 'Athíenou', 'Athienou', 'Athiaenou,Athienou,Athiænou,Athíenou,Atienu,Atiyenu,Kiracikoy,Kiracıköy,Αθίενου', 35.0618000, 33.5415600, 'CY', '2015-03-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28505, 'Astromerítis', 'Astromeritis', 'Astromerit,Astromeriti,Astromeritia,Astromeritis,Astromerítis,Αστρομερίτης', 35.1409600, 33.0379300, 'CY', '2015-02-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28506, 'Ergátes', 'Ergates', 'Argadez,Argataes,Argates,Argatoes,Argatœs,Argátaes,Ergates,Ergátes,Εργάτες', 35.0536500, 33.2429200, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28507, 'Aradíppou', 'Aradippou', 'Aradhippou,Aradip,Aradippou,Aradippu,Aradíppou,Αραδίππου', 34.9515100, 33.5919900, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28508, 'Aredioú', 'Arediou', 'Aradhiou,Aradiou,Aradyu,Aratyu,Aredhiou,Arediou,Aredioú,Arediu,Aredyu,Αρεδιού', 35.0484400, 33.1961000, 'CY', '2015-02-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28509, 'Alámpra', 'Alampra', 'Alambra,Alampra,Alámpra,Αλάμπρα', 34.9889800, 33.3988700, 'CY', '2014-07-08', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28510, 'Acherítou', 'Acheritou', 'Acheritou,Acherítou,Agratur,Aharida,Aharitu,Ahiritu,Akhyritou,Aseritu,Ağratur,Aşeritu,Guvercinlik,Güvercinlik,Kouverjinlik,Αχερίτου', 35.1002200, 33.8615500, 'CY', '2014-09-30', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28511, 'Akáki', 'Akaki', 'Akaca,Akacha,Akaki,Akácha,Akáki,Ακάκι', 35.1334100, 33.1287300, 'CY', '2015-02-05', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28512, 'Méniko', 'Meniko', 'Meniko,Menikon,Menıko,Méniko,Μένικο', 35.1094500, 33.1447400, 'CY', '2015-09-06', 59);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28513, 'Dvůr Králové nad Labem', 'Dvur Kralove nad Labem', 'Dvur Kralove,Dvur Kralove na Labi,Dvur Kralove prie Labes,Dvur-Kralove,Dvur-Kralove-nad-Labem,Dvūr Kralovė prie Labės,Dvŭr Králové,Gorad Dvur-Kralaveh-nad-Labehm,Koniginhof an der Elbe,Königinhof an der Elbe,la bei he pan huang gong zhen,Горад Двур-Кралавэ-над-Лабэм,Двур Кралове на Лаби,Двур-Кралове,Двур-Кралове-над-Лабем,拉貝河畔皇宮鎮', 50.4317200, 15.8140200, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28514, 'Zvole', 'Zvole', 'Swoll', 49.9346600, 14.4176900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28515, 'Žulová', 'Zulova', 'Friedeberg,Frydberk,Frydeberk,Frýdberk,Frýdeberk,Zaludova,Zhulova,Zulova,ru luo wa,Žaludová,Žulova,Жулова,茹洛瓦', 50.3093300, 17.0987100, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28516, 'Zubří', 'Zubri', '', 49.4660300, 18.0924900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28517, 'Zruč nad Sázavou', 'Zruc nad Sazavou', 'Zruc,Zruč', 49.7401000, 15.1060600, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28518, 'Znojmo', 'Znojmo', 'Gorad Znojma,Znaim,Znain,Znaym,Znoimas,Znojmo,Znoyma,jeunoimo,zi nuo yi mo,znwymw,znymw,zunoimo,Горад Знойма,Зноймо,Знојмо,زنويمو,زنیمو,ズノイモ,茲諾伊莫,즈노이모', 48.8555000, 16.0488000, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28519, 'Žlutice', 'Zlutice', 'Luditz,Zhlutice,ri lu ji cai,Жлутице,日盧季采', 50.0919200, 13.1629700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28520, 'Žlutava', 'Zlutava', '', 49.1997600, 17.4903700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28521, 'Zlonice', 'Zlonice', 'Zlonitz', 50.2875000, 14.0921400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28522, 'Zliv', 'Zliv', 'Zliv,Zliw,zi li fu,Злив,茲利夫', 49.0660800, 14.3661300, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28523, 'Zlín', 'Zlin', 'Gottvoldov,Gottwald,Gottwaldov,Sillein,Z''lin,Zlin,Zlín,Ζλιν,Злин,Зьлін', 49.2264500, 17.6706500, 'CZ', '2014-07-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28524, 'Zlechov', 'Zlechov', '', 49.0739600, 17.3793800, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28525, 'Žleby', 'Zleby', 'Zleb,Žleb', 49.8895800, 15.4885300, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28526, 'Zlaté Hory', 'Zlate Hory', 'Cukmantl,Zlate Horai,Zlate Hori,Zlate Khori,Zlate-Gori,Zuckmantel,Злате Хори,Злате-Гори', 50.2638000, 17.3960200, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28527, 'Žiželice', 'Zizelice', 'Zizelic,Žiželic', 50.1319200, 15.3932000, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28528, 'Žitenice', 'Zitenice', 'Schudenitz,Schüdenitz', 50.5552800, 14.1566500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28529, 'Žirovnice', 'Zirovnice', 'Serowitz', 49.2531800, 15.1882400, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28530, 'Žihle', 'Zihle', 'Scheles', 50.0449100, 13.3750200, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28531, 'Židlochovice', 'Zidlochovice', 'Gross Seelowitz,Groß Seelowitz,Zhidlokhovice,Zidlohovice,Ziolochovice,ri de luo huo wei cai,Židlohovice,Жидлоховице,日德洛霍維采', 49.0395200, 16.6188100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28532, 'Žeravice', 'Zeravice', 'Zerawitz', 49.0228800, 17.2372600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28533, 'Želiv', 'Zeliv', 'Seelau', 49.5298400, 15.2218100, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28534, 'Železný Brod', 'Zelezny Brod', 'Eisenbrod', 50.6427400, 15.2540800, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28535, 'Železnice', 'Zeleznice', 'Eisenstadtl', 50.4727400, 15.3845900, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28536, 'Železná Ruda', 'Zelezna Ruda', 'Eisenstein,Eisenstein Markt,Markt Eisenstein,Mestys Zelezna Ruda,Městys Železná Ruda,Zhelezna Ruda,Zhelezna-Ruda,Zolezna Ruda,tie kuang zhen,Žolezná Ruda,Железна Руда,Железна-Руда,鐵礦鎮', 49.1374300, 13.2352000, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28537, 'Želetava', 'Zeletava', 'Scheletau', 49.1418700, 15.6730000, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28538, 'Želešice', 'Zelesice', 'Schollschitz,Schöllschitz', 49.1168900, 16.5813700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28539, 'Zeleneč', 'Zelenec', '', 50.1336200, 14.6607000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28540, 'Žebrák', 'Zebrak', '', 49.8757400, 13.8973500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28541, 'Zdounky', 'Zdounky', 'Zdounek', 49.2277100, 17.3189900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28542, 'Zdíkov', 'Zdikov', 'Gross Zdikau,Gross Ždikau', 49.0845600, 13.6973800, 'CZ', '2012-11-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28543, 'Zdice', 'Zdice', 'Zdice,Zditz,zi di cai,Здице,茲迪采', 49.9120700, 13.9774700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28544, 'Zdiby', 'Zdiby', '', 50.1679900, 14.4511800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28545, 'Žďár nad Sázavou Druhy', 'Zd''ar nad Sazavou Druhy', 'Saar Schloss,Zd''ar nad Sazavou Druhy,Žďár nad Sázavou Druhy', 49.5872600, 15.9321500, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28546, 'Žďár nad Sázavou', 'Zd''ar nad Sazavou', 'Mesto Zd''ar,Mesto Zd''ar a Zamek Zd''ar,Město Žďar,Město Žďár,Město Žďár a Zámek Žďár,Saar,Sar,Zd''ar,Zdar,Zdiaras prie Sazavos,Zdjara pie Sazavas,Zdziar nad Sazawa,Zdziar nad Sazawą,Zhdjar na Sazavi,Zhdjar-nad-Sazavoju,Zhdjar-nad-Sazavou,jdyar nad sazafw,sa zha wa he pan ri gu er,zhdar nad sazaww,Ždiaras prie Sazavos,Ždjāra pie Sāzavas,Žďár,Ждяр-над-Сазавоу,Ждяр-над-Сазавою,Ждјар на Сазави,جديار ناد سازافو,ژدار ناد سازاوو,薩扎瓦河畔日賈爾', 49.5626300, 15.9392400, 'CZ', '2015-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28547, 'Žďár', 'Zd''ar', '', 50.5436600, 15.0803400, 'CZ', '2012-09-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28548, 'Ždánice', 'Zdanice', 'Steinitz,Zdanice,Zhdanice,ri da ni cai,Ždānice,Жданице,Ждањице,日達尼采', 49.0672900, 17.0275100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28549, 'Zbýšov', 'Zbysov', 'Zbeschau,Zbishov,Zbisova,Zbysov u Brna,Zbýšov u Brna,Zbīšova,zi bi shao fu,Збишов,茲比紹夫', 49.1552400, 16.3495100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28550, 'Zbůch', 'Zbuch', 'Zwug', 49.6784000, 13.2256400, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28551, 'Zbraslavice', 'Zbraslavice', 'Zbraslawitz', 49.8117900, 15.1831900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28552, 'Zbraslav', 'Zbraslav', 'Zbraslau,Zbraslav u Brna', 49.2215500, 16.2941500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28553, 'Zborovice', 'Zborovice', 'Zborowitz', 49.2488900, 17.2846400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28554, 'Zbiroh', 'Zbiroh', 'Zbirog,Zbirokh,Zbirow,zi bi luo he,Збирог,Збирох,茲比羅赫', 49.8602400, 13.7726200, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28555, 'Zátor', 'Zator', 'Seifersdorf', 50.0341300, 17.5929600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28556, 'Žatec', 'Zatec', 'Saaz,Zatec,Zhatec,jatetsu,zha tai ci,Žatec,Жатец,ジャテツ,扎泰茨', 50.3271700, 13.5457700, 'CZ', '2017-04-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28557, 'Zastávka', 'Zastavka', 'Bozi Pozehnani,Boži Požehnání,Segen Gottes,Zastavka u Brna,Zastávka u Brna', 49.1880000, 16.3631000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28558, 'Zašová', 'Zasova', 'Zaschau', 49.4741000, 18.0443600, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28559, 'Zásmuky', 'Zasmuky', 'Zasmuk,Zásmuk', 49.9547000, 15.0305800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28560, 'Žandov', 'Zandov', 'Sandau', 50.7139400, 14.3962300, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28561, 'Žamberk', 'Zamberk', 'Senftenberg,Zamberka,Zhamberk,jambeleukeu,ran bei er ke,Žamberka,Жамберк,然貝爾克,잠베르크', 50.0860100, 16.4673800, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28562, 'Zákupy', 'Zakupy', 'Reichstadt,Zakupy,Zákupy', 50.6847500, 14.6452200, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28563, 'Zaječov', 'Zajecov', 'Zajecow,Zaječow,Zajicov,Zajícov', 49.7743500, 13.8407200, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28564, 'Zaječí', 'Zajeci', 'Saitz,Zajece,Zajechi,Zaječē,Зајечи', 48.8729500, 16.7664600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28565, 'Záhorovice', 'Zahorovice', 'Zahorowitz', 49.0226600, 17.7792200, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28566, 'Zadní Mostek', 'Zadni Mostek', '', 50.4967000, 15.6980400, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28567, 'Žacléř', 'Zacler', 'Schatzlar,Scheczler,Zhaclerzh,zha ci lai ri,Жацлерж,扎茨萊日', 50.6632900, 15.9106300, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28568, 'Zabrušany', 'Zabrusany', 'Sobrusan', 50.6049500, 13.7874800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28569, 'Zábřeh', 'Zabreh', 'Azbreh,Hohenstadt,Zabrekh,Zabrzeha,Zabrzheg,Zabrzhekh,Zebreh,Zābržeha,zha bu re he,Забрех,Забржег,Забржех,扎布熱赫', 49.8826000, 16.8722300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28570, 'Žabčice', 'Zabcice', 'Zabcic,Žabčic', 49.0116000, 16.6025700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28571, 'Vyšší Brod', 'Vyssi Brod', 'Altum Vodum,Hohenfurth,Vishi Brod,Vishshi-Brod,shang bu luo de,Виши Брод,Вишши-Брод,上布罗德', 48.6159800, 14.3118300, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28572, 'Vysoké nad Jizerou', 'Vysoke nad Jizerou', 'Hochstadt', 50.6855900, 15.4015200, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28573, 'Vysoké Mýto', 'Vysoke Myto', 'Hohenmauth,Visoke Mito,Visoke Mīto,Visoke-Mito,Visoko Mito,Vyskoe Myto,shang mi tuo,Високе Мито,Високе-Мито,Високо Мито,ვისოკე-მიტო,上米托', 49.9532000, 16.1616900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28574, 'Vysočany', 'Vysocany', 'Vysocan,Vysocany,Vysočan,Vysočany,Wysocan,Wysočan', 50.1093800, 14.5166700, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28575, 'Vyškov', 'Vyskov', 'Vyshkov,Vyskov,Vyškov,Wischau,Вышков', 49.2774700, 16.9989700, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28576, 'Vsetín', 'Vsetin', 'Vsetin,Vsetina,Vsetynas,Vsetīna,Wsetin,Wszetyn,fsytyn,fu sai ting,wstyn,Всетин,Всетін,فسيتين,وستین,弗塞廷', 49.3387100, 17.9961900, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28577, 'Všetaty', 'Vsetaty', 'Wschetat', 50.2818700, 14.5929700, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28578, 'Všestary', 'Vsestary', '', 50.2566000, 15.7598300, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28579, 'Všeruby', 'Vseruby', 'Wscherau', 49.8416700, 13.2294300, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28580, 'Všenory', 'Vsenory', '', 49.9288300, 14.3039200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28581, 'Všemina', 'Vsemina', 'Wschemin,Wschemina', 49.2810000, 17.8768200, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28582, 'Vroutek', 'Vroutek', 'Rudig,Rüdig', 50.1799900, 13.3798600, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28583, 'Vřesina', 'Vresina', '', 49.9458100, 18.1900500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28584, 'Vřesina', 'Vresina', 'Wrzessin', 49.8241800, 18.1256900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28585, 'Vrdy', 'Vrdy', 'Wrdy', 49.9215300, 15.4724300, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28586, 'Vrchlabí', 'Vrchlabi', 'Hohenelbe,Vrchlabis,Vrkhlabi,fu er he la bi,Врхлаби,弗爾赫拉比', 50.6269700, 15.6093700, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28587, 'Vrbovec', 'Vrbovec', 'Urbau', 48.7997800, 16.1006100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28588, 'Vrbno pod Pradědem', 'Vrbno pod Pradedem', 'Vrbno,Vrbno pie Pradeda,Vrbno pie Pradēda,Vrbno pod Pradjedom,Vrbno-pod-Pradedem,Wurbenthal,Würbenthal,Врбно под Прадједом,Врбно-под-Прадедем', 50.1209500, 17.3831600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28589, 'Vrbice', 'Vrbice', '', 48.9150800, 16.8977900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28590, 'Vrbátky', 'Vrbatky', '', 49.5080500, 17.1999400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28591, 'Vratimov', 'Vratimov', 'Rattimau', 49.7699500, 18.3101500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28592, 'Vranovice', 'Vranovice', '', 48.9660000, 16.6066000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28593, 'Vrané nad Vltavou', 'Vrane nad Vltavou', 'Vrane,Vrané,Wran', 49.9358500, 14.3770600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28594, 'Vracov', 'Vracov', '', 48.9752300, 17.2110000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28595, 'Votice', 'Votice', 'Wotitz', 49.6401300, 14.6380900, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28596, 'Volyně', 'Volyne', 'Voline,Wolin,wo li nei,Волиње,沃利內', 49.1657800, 13.8862400, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28597, 'Volary', 'Volary', 'Volari,Volary,Wallern,wo la li,Волари,Волары,沃拉里', 48.9088100, 13.8865700, 'CZ', '2015-10-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28598, 'Vojkovice', 'Vojkovice', '', 49.0513800, 16.6082000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28599, 'Vodňany', 'Vodnany', 'Vodnani,Wodnan,Wodňan,wo de ni ya ni,Водњани,沃德尼亞尼', 49.1478900, 14.1751300, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28600, 'Vnorovy', 'Vnorovy', '', 48.9309600, 17.3505000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28601, 'Vlkoš', 'Vlkos', '', 48.9896000, 17.1635600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28602, 'Vlčnov', 'Vlcnov', 'Wolfsdorf', 49.5786600, 17.9545800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28603, 'Vlčnov', 'Vlcnov', 'Wltschnau', 49.0099000, 17.5818300, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28604, 'Vlašim', 'Vlasim', 'Vlashim,Wlaschim,fu la xi mu,Влашим,弗拉希姆', 49.7063200, 14.8988100, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28605, 'Vladislav', 'Vladislav', 'Wladislau', 49.2101700, 15.9883000, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28606, 'Vlachovo Březí', 'Vlachovo Brezi', 'Vlakhovo Brezi,Wallischbirken,Wällischbirken,Влахово Брези', 49.0813500, 13.9584200, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28607, 'Vlachovice', 'Vlachovice', 'Vlahovice,Wlachowitz', 49.1237700, 17.9400100, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28608, 'Vizovice', 'Vizovice', 'Vizovice,Wisowitz,wei zuo wei cai,Визовице,維佐維采', 49.2228700, 17.8545500, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28609, 'Vítkov', 'Vitkov', 'Wigstadtl', 49.7744500, 17.7494100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28610, 'Višňové', 'Visnove', 'Visnova,Višňová', 48.9824100, 16.1502500, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28611, 'Višňova', 'Visnova', 'Weigsdorf', 50.9666300, 15.0249500, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28612, 'Vintířov', 'Vintirov', 'Wintersgrun,Wintersgrün', 50.2338200, 12.7174800, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28613, 'Viničné Šumice', 'Vinicne Sumice', '', 49.2135800, 16.8254100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28614, 'Vinařice', 'Vinarice', 'Winaritz,Wínařitz', 50.1758500, 14.0910600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28615, 'Vimperk', 'Vimperk', 'Vimperk,Winterberg,wen pei er ke,Вимперк,溫佩爾克', 49.0585700, 13.7828600, 'CZ', '2007-09-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28616, 'Vilémov', 'Vilemov', 'Woelmsdorf,Wolmsdorf,Wölmsdorf', 50.9905400, 14.3353100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28617, 'Vilémov', 'Vilemov', 'Wilimow', 49.8156600, 15.5358400, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28618, 'Vilémov', 'Vilemov', '', 49.5357800, 15.3834700, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28619, 'Vikýřovice', 'Vikyrovice', 'Weikersdorf', 49.9779200, 17.0123400, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28620, 'Vidnava', 'Vidnava', 'Vidnava,Weidenau,wei de na wa,Виднава,維德納瓦', 50.3723400, 17.1862600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28621, 'Vidče', 'Vidce', 'Witsche', 49.4415100, 18.0947300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28622, 'Veverská Bítýška', 'Veverska Bityska', 'Bittischka,Veverska Bitishka,Веверска Битишка', 49.2759100, 16.4368600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28623, 'Větřní', 'Vetrni', 'Wettern', 48.7742500, 14.2861600, 'CZ', '2016-01-05', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28624, 'Vestec', 'Vestec', 'Westetz', 49.9805000, 14.5048700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28625, 'Veselí nad Moravou', 'Veseli nad Moravou', 'Veseli na Moravi,Veseli pie Moravas,Veseli pie Morāvas,Veseli-nad-Moravoju,besellinateumolabou,mo la wa he pan wei sai li,Весели на Морави,Веселі-над-Моравою,摩拉瓦河畔韋塞利,베셀리나트모라보우', 48.9536300, 17.3764800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28626, 'Veselí nad Lužnicí', 'Veseli nad Luznici', 'Mezimosti,Mezimosti nad Nezarkou,Mezimostí,Mezimostí nad Nežárkou,Veseli na Luzhnici,Weseli,lu ri ni cai he pan wei sai li,Весели на Лужњици,盧日尼采河畔韋塞利', 49.1843000, 14.6973400, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28627, 'Veřovice', 'Verovice', 'Wernsdorf', 49.5391600, 18.1142500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28628, 'Věrovany', 'Verovany', 'Wierowan', 49.4610900, 17.2879500, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28629, 'Verneřice', 'Vernerice', 'Vernerzhice,Wernstadt,wrnryk,Вернержице,ورنریک', 50.6611400, 14.3011400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28630, 'Vendryně', 'Vendryne', 'Wedrynie,Wędrynie', 49.6666200, 18.7130700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28631, 'Velvary', 'Velvary', 'Welwarn', 50.2815200, 14.2361600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28632, 'Veltrusy', 'Veltrusy', 'Weltrus', 50.2704600, 14.3285700, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28633, 'Veltruby', 'Veltruby', 'Weltrub', 50.0705900, 15.1845400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28634, 'Velký Újezd', 'Velky Ujezd', 'Gross Aujezd,Velki Ujezd,wlky ywjzd,Велки Ујезд,ولکی یوجزد', 49.5785800, 17.4834700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28635, 'Velký Týnec', 'Velky Tynec', 'Gross Teinitz', 49.5499400, 17.3335900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28636, 'Velký Šenov', 'Velky Senov', 'Gross Schonau in Bohmen,Gross Schönau in Böhmen,Gross-Schonau,Gross-Schönau,Senov,Šenov', 50.9907800, 14.3742800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28637, 'Velký Osek', 'Velky Osek', 'Gross Wosek', 50.0986700, 15.1862900, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28638, 'Velký Beranov', 'Velky Beranov', 'Beranov,Gross Beranau', 49.4050400, 15.6670000, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28639, 'Velké Svatoňovice', 'Velke Svatonovice', 'Gross Schwadowitz', 50.5316400, 16.0285300, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28640, 'Velké Přílepy', 'Velke Prilepy', 'Vel''ke-Prshilepi,Velke Prilepi,wlk prylpy,Велке Прилепи,Вельке-Пршилепи,ولک پریلپی', 50.1605000, 14.3144700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28641, 'Velké Poříčí', 'Velke Porici', 'Gross Poric,Gross Pořič', 50.4617700, 16.1893100, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28642, 'Velké Popovice', 'Velke Popovice', 'Grosspopowitz,Velke Popovice,Велке Поповице', 49.9225200, 14.6393400, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28643, 'Velké Pavlovice', 'Velke Pavlovice', 'Velke Pavlovice,Velke Pavluovece,Velkė Pavluovėcē,da pa fu luo wei cai,Велке Павловице,大帕夫洛維采', 48.9046900, 16.8160500, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28644, 'Velké Opatovice', 'Velke Opatovice', 'Gross Opatowitz,Velke Opatovice,da ao pa tuo wei cai,wlkh awpatwwytsh,Велке Опатовице,ولکه اوپاتوویتسه,大奧帕托維采', 49.6123700, 16.6794700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28645, 'Velké Němčice', 'Velke Nemcice', 'Nemcice,Němčice', 48.9916800, 16.6720800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28646, 'Velké Meziříčí', 'Velke Mezirici', 'Gross-Meseritsch,Grossmeseritsch,Großmeseritsch,Vel''ke-Mezirzhichi,Veliki Mezirichi,Velke Mezerici,Velke Mezirzici,Velke Meziržīči,Velké Mezeříčí,da mei ji ri qi,Велики Мезиричи,Вельке-Мезиржичи,大梅濟日奇', 49.3552200, 16.0122400, 'CZ', '2011-04-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28647, 'Velké Losiny', 'Velke Losiny', 'Gross-Ullersdorf,Grossullersdorf,Velke Losini,wlk lsyny,Велке Лосини,ولک لسینی', 50.0319700, 17.0405800, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28648, 'Velké Karlovice', 'Velke Karlovice', 'Gross Karlowitz', 49.3606400, 18.2835500, 'CZ', '2012-11-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28649, 'Velké Hoštice', 'Velke Hostice', 'Gross Hoschutz,Gross Hoschütz', 49.9360900, 17.9738000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28650, 'Velké Heraltice', 'Velke Heraltice', 'Gross Herrlitz', 49.9749300, 17.7287900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28651, 'Velké Hamry', 'Velke Hamry', 'Ober Hammer,Unter Hammer', 50.7137300, 15.3153900, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28652, 'Velké Březno', 'Velke Brezno', 'Gross Priesen', 50.6627000, 14.1417400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28653, 'Velké Bílovice', 'Velke Bilovice', '', 48.8492900, 16.8922700, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28654, 'Velká Polom', 'Velka Polom', 'Gross Pohlom', 49.8635900, 18.0933100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28655, 'Velká nad Veličkou', 'Velka nad Velickou', 'Velka,Velká', 48.8825700, 17.5206000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28656, 'Velká Hleďsebe', 'Velka Hled''sebe', 'Gross-Sichdichfur,Gross-Sichdichfür,Siehdichfur,Siehdichfür', 49.9615100, 12.6676300, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28657, 'Velká Dobrá', 'Velka Dobra', '', 50.1096400, 14.0698000, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28658, 'Velká Bystřice', 'Velka Bystrice', 'Gross Wisternitz,Velka Bistrica,Velka Bistrsice,Velka Bistršice,da bi si te ri cai,wlka bystryk,Велка Бистрица,ولکا بیستریک,大比斯特日采', 49.5948000, 17.3654400, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28659, 'Velká Bíteš', 'Velka Bites', 'Gross Bittesch,Velka Bitesa,Velka Bitesh,Velka Bīteša,da bi tai shen,Велка Битеш,大比泰什', 49.2883800, 16.2274200, 'CZ', '2011-04-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28660, 'Velim', 'Velim', 'Velim u Kolina,Welim', 50.0596500, 15.1071100, 'CZ', '2017-05-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28661, 'Velešín', 'Velesin', 'Veleshin,wei lai xin,Велешин,韋萊欣', 48.8294900, 14.4625200, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28662, 'Velemín', 'Velemin', 'Wellemin', 50.5389800, 13.9767500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28663, 'Velehrad', 'Velehrad', 'Welehrad', 49.1054300, 17.3942600, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28664, 'Vejprty', 'Vejprty', 'Vejprti,Weipert,wei yi pu er di,Вейпрти,Вејпрти,韋伊普爾蒂', 50.4923200, 13.0321200, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28665, 'Vejprnice', 'Vejprnice', 'Weipernitz', 49.7298800, 13.2762800, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28666, 'Včelná', 'Vcelna', '', 48.9237300, 14.4538300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28667, 'Varnsdorf', 'Varnsdorf', 'Varnsdorf,Warnocicy,Warnoćicy,Warnsdorf,wa en si duo fu,Варнсдорф,瓦恩斯多夫', 50.9115400, 14.6182400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28668, 'Vápenná', 'Vapenna', 'Setzdorf,Zighartice', 50.2833800, 17.0976200, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28669, 'Vamberk', 'Vamberk', 'Wamberg', 50.1175600, 16.2906700, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28670, 'Valtice', 'Valtice', 'Feldsberg,Gorad Val''cicy,Val''tice,Valtece,Valtice,Valticė,Valtėcē,baltiche,valtice,vu~aruchitsu~e,wa er ji cai,Валтице,Вальтице,Горад Вальціцы,ヴァルチツェ,瓦爾季采,발티체', 48.7406900, 16.7549900, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28671, 'Valdice', 'Valdice', '', 50.5835000, 15.4124800, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28672, 'Valdice', 'Valdice', 'Karthaus-Walditz,Kartouzy-Valdice,Valdice-Kartouzy', 50.4550100, 15.3848800, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28673, 'Valašské Meziříčí', 'Valasske Mezirici', 'Mezirzhichi,Valashke Mezirzhichi,Valashki Mezirichi,Valashske-Mezirzhichi,Valasske Mezirzici,Valasske Mezirzyciai,Valašske Meziržyčiai,Valašske Meziržīči,Walachison Mesiritsch,Wallachisch Meseritsch,falashsky myzyrytshy,wa la shen si kai mei ji ri qi,walashskh mzyrzhychy,Валашке Мезиржичи,Валашки Мезиричи,Валашске-Мезиржичи,Мезиржичи,فالاشسكي ميزيريتشي,والاشسکه مزیرژیچی,瓦拉什斯凱梅濟日奇', 49.4718100, 17.9711300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28674, 'Valašské Klobouky', 'Valasske Klobouky', 'Klobouk,Valashke Klobouki,Valashske-Klobouki,Valasske Klobouki,Valašske Klobouki,wa la shen si kai ke luo bo wu ji,Валашке Клобоуки,Валашске-Клобоуки,瓦拉什斯凱克洛博烏基', 49.1406400, 18.0076000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28675, 'Valašská Polanka', 'Valasska Polanka', 'Polanka,Valashka Polanka,Валашка Поланка', 49.2621500, 17.9966700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28676, 'Valašská Bystřice', 'Valasska Bystrice', 'Gross Bistrzitz', 49.4150700, 18.1097700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28677, 'Vacov', 'Vacov', '', 49.1368600, 13.7291100, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28678, 'Václavovice', 'Vaclavovice', '', 49.7553100, 18.3722000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28679, 'Vacenovice', 'Vacenovice', '', 48.9451000, 17.1740400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28680, 'Úvaly', 'Uvaly', 'Auwal', 50.0739400, 14.7308000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28681, 'Ústí nad Orlicí', 'Usti nad Orlici', 'Uscie nad Orlica,Usti na Orlici,Usti pie Orlices,Usti-nad-Orlici,Ustin Orl,Uście nad Orlicą,Wildenschwert,ao er li cai he pan wu si ji,awsty nad awrlytsy,Ústin Orl,Ūsti pie Orlices,Усти на Орлици,Усти-над-Орлици,أوستي ناد أورليتسي,უსტი-ნად-ორლიცი,奧爾利采河畔烏斯季', 49.9738700, 16.3936100, 'CZ', '2007-10-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28682, 'Ústí nad Labem', 'Usti nad Labem', 'Aussig,Aussig an der Elbe,Auszig,Usti,Usti nad Labem,Usti-nad-Labem,Ustina Labe,usti nad labom,Ústina Labe,Ústí,Ústí nad Labem,Усти над Лабом,Усти-над-Лабем', 50.6607000, 14.0322700, 'CZ', '2014-03-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28683, 'Úštěk', 'Ustek', 'Auscha,Ushtek,Ushtjek,wu shen jie ke,Уштек,Уштјек,烏什捷克', 50.5847400, 14.3433200, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28684, 'Úsov', 'Usov', 'Mahrisch Aussee,Mährisch Aussee,Usov,Usova,wu suo fu,Ūsova,Усов,烏索夫', 49.7983100, 17.0105500, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28685, 'Určice', 'Urcice', 'Urcitz,Určitz', 49.4304500, 17.0729100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28686, 'Úpice', 'Upice', 'Eipel,Upice,wu pi cai,Упице,烏皮采', 50.5123700, 16.0160700, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28687, 'Uničov', 'Unicov', 'Mahrisch Neustadt,Mährisch Neustadt,Unichov,Unicova,Uničova,wu ni qiao fu,Уничов,Уњичов,烏尼喬夫', 49.7709200, 17.1214400, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28688, 'Unhošť', 'Unhost''', 'Unhoscht,Unkhosht,weng huo shen ji,Унхошт,翁霍什季', 50.0853500, 14.1300700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28689, 'Únanov', 'Unanov', '', 48.9008200, 16.0635100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28690, 'Újezd', 'Ujezd', 'Augezd', 49.7639700, 17.1804000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28691, 'Újezd', 'Ujezd', 'Aujezd', 49.1680900, 17.9061000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28692, 'Uhlířské Janovice', 'Uhlirske Janovice', 'Kohljanowitz', 49.8801900, 15.0648100, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28693, 'Uherský Ostroh', 'Uhersky Ostroh', 'Magyarsarvar,Magyarsárvár,Ugerski-Ostrog,Uherski Ostroha,Ukherski Ostrokh,Угерски-Острог,Ухерски Острох', 48.9855600, 17.3898400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28694, 'Uherský Brod', 'Uhersky Brod', 'Magyarbrod,Magyarbród,Ugers''kij Brod,Ugerski-Brod,Uherski Broda,Uhersky Brodas,Ukherski Brod,Ungarisch Brod,Vehersky Brod,wu he er bu luo de,Угерски-Брод,Угерський Брод,Ухерски Брод,烏赫爾布羅德', 49.0251300, 17.6471500, 'CZ', '2015-11-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28695, 'Uherské Hradiště', 'Uherske Hradiste', 'Magyarhradis,UHE,Ugerske-Gradishte,Uherske Hradiste,Uherské Hradiště,Ungarisch Hradisch,Ungarisch-Hradisch,Угерске-Градиште,ウヘルスケー・フラジシチェ', 49.0697500, 17.4596900, 'CZ', '2017-07-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28696, 'Údlice', 'Udlice', 'Eidlitz', 50.4406000, 13.4573800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28697, 'Týn nad Vltavou', 'Tyn nad Vltavou', 'Moldauthein,Tin na Vltavi,Tyn na Vltava,Týn na Vltava,fu er ta wa he pan di en,Тин на Влтави,伏爾塔瓦河畔蒂恩', 49.2234000, 14.4205700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28698, 'Týniště nad Orlicí', 'Tyniste nad Orlici', 'Tinischt,Tyniste,Tyniště', 50.1513600, 16.0777000, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28699, 'Týnec nad Sázavou', 'Tynec nad Sazavou', 'Tejnitz', 49.8334800, 14.5898300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28700, 'Týnec nad Labem', 'Tynec nad Labem', 'Elbeteinitz,Tynec,Týnec', 50.0420200, 15.3583600, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28701, 'Týnec', 'Tynec', '', 48.7794300, 17.0132200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28702, 'Tvrdonice', 'Tvrdonice', '', 48.7604800, 16.9944600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28703, 'Tvarožná', 'Tvarozna', 'Bosenitz,Tvarozhna,Tvarozna,Tvarožná,Тварожна', 49.1917700, 16.7714600, 'CZ', '2016-07-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28704, 'Turnov', 'Turnov', 'Turnau,Turnov,Turnovas,tu er nuo fu,tuleunopeu,Турнов,图尔诺夫,투르노프', 50.5835600, 15.1518600, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28705, 'Tupesy', 'Tupesy', 'Tupes', 49.0842700, 17.3698300, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28706, 'Tuchoměřice', 'Tuchomerice', '', 50.1354300, 14.2821800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28707, 'Tuchlovice', 'Tuchlovice', 'Tuchlowitz', 50.1380300, 13.9911500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28708, 'Trutnov', 'Trutnov', 'Gorad Trutnau,Trautenau,Trutnov,Trutnovas,te lu te nuo fu,trtnwf,trwtnw,Горад Трутнаў,Трутнов,ترتنوف,تروتنو,特魯特諾夫', 50.5610100, 15.9127000, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28709, 'Tršice', 'Trsice', 'Trschitz,Trshice,Trsnice,Tršnice,trshysh,Тршице,ترشیسه', 49.5423700, 17.4248300, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28710, 'Troubsko', 'Troubsko', 'Strutz', 49.1695100, 16.5107800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28711, 'Troubky', 'Troubky', 'Troubek,Troubkach,Troubky nad Becvou,Troubky nad Bečvou', 49.4321500, 17.3491400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28712, 'Troubelice', 'Troubelice', 'Treublitz,Troubelice,Троубелице', 49.8173100, 17.0810000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28713, 'Trojanovice', 'Trojanovice', 'Trojanowitz', 49.5203900, 18.2380000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28714, 'Trnava', 'Trnava', 'Tranawa', 49.2960300, 17.8419100, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28715, 'Trmice', 'Trmice', 'Turmitz,Türmitz', 50.6428600, 13.9944900, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28716, 'Třinec', 'Trinec', 'Trinec,Trshinec,Trsineca,Trsinecas,Trzyniec,Tršineca,Tršinecas,te ri nei ci,trzhynts,Тринец,Тршинец,Тршінец,ترژینتس,特日內茨', 49.6776300, 18.6707800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28717, 'Trhový Štěpánov', 'Trhovy Stepanov', 'Trhowy Stepanow,Trhowy Stěpanow', 49.7114700, 15.0135600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28718, 'Trhové Sviny', 'Trhove Sviny', 'Trgove-Svini,Trkhove Svini,te er huo wei si wei ni,Тргове-Свини,Трхове Свини,特爾霍韋斯維尼', 48.8423100, 14.6392400, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28719, 'Třešť', 'Trest''', 'Triesch', 49.2909200, 15.4821100, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28720, 'Třemošnice', 'Tremosnice', '', 49.8691200, 15.5800200, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28721, 'Třemošná', 'Tremosna', 'Tremoschna,Třemoschna', 49.8158400, 13.3949900, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28722, 'Třebotov', 'Trebotov', '', 49.9724400, 14.2912700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28723, 'Třeboň', 'Trebon', 'Trebon,Trshebon'',Trzebon,Trzeboń,Trzhebon'',Wittingau,te re bang,Требоњ,Тржебонь,Тршебонь,特熱邦', 49.0036400, 14.7706500, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28724, 'Třebíč', 'Trebic', 'Trebic,Trebitsch-Stadt,Trshebich,Třebíč,toshebichi,Тршебич,トシェビーチ', 49.2149200, 15.8816600, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28725, 'Třebenice', 'Trebenice', 'Trebenice,Trebnitz,Trshebenice,te re bei ni cai,Требењице,Тршебенице,特熱貝尼采', 50.4763200, 13.9900500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28726, 'Třebechovice pod Orebem', 'Trebechovice pod Orebem', 'Hohenbruck,Trebechovice,Třebechovice', 50.2009700, 15.9922300, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28727, 'Traplice', 'Traplice', 'Traplitz', 49.1308800, 17.4362200, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28728, 'Tovačov', 'Tovacov', 'Tobitschau,Tovachov,Tovacova,Tovačova,tuo wa qiao fu,Товачов,托瓦喬夫', 49.4308300, 17.2879500, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28729, 'Toužim', 'Touzim', 'Theusing,Touzhim,tuo wu ri mu,Тоужим,托烏日姆', 50.0604900, 12.9850600, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28730, 'Topolná', 'Topolna', '', 49.1218700, 17.5443400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28731, 'Tlumačov', 'Tlumacov', 'Tlumatschau', 49.2535100, 17.4955900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28732, 'Tlučná', 'Tlucna', '', 49.7242500, 13.2353400, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28733, 'Tišnov', 'Tisnov', 'Tischnowitz,Tishnov,Tisnova,Tišnova,ji shen nuo fu,Тишнов,季什諾夫', 49.3487200, 16.4243800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28734, 'Tišice', 'Tisice', '', 50.2698000, 14.5541100, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28735, 'Tichá', 'Ticha', 'Tichau', 49.5699900, 18.2214800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28736, 'Těšetice', 'Tesetice', '', 49.5931700, 17.1260700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28737, 'Těšany', 'Tesany', 'Tieschan', 49.0395600, 16.7700300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28738, 'Terezín', 'Terezin', 'Terezin,Terezín,Theresienstadt,tai lei jin,telechin,terejin,Терезин,Терезін,テレジーン,泰雷津,테레친', 50.5110000, 14.1505500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28739, 'Teplice nad Metují', 'Teplice nad Metuji', 'Teplice Na Metuje,Wekelsdorf', 50.5933200, 16.1702600, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28740, 'Teplice', 'Teplice', 'Cieplice,Teplice,Teplice-Sanov,Teplice-Šanov,Teplicė,Teplitse,Teplitz,Teplitz-Schoenau,Teplitz-Schönau,tblytsh,te pu li cai,tepeulliche,tepuritsu~e,tplytsh,tplyzh,Теплитсе,Теплице,Тепліце,טפליצה,تبليتسه,تپلیتسه,ტეპლიცე,テプリツェ,特普利采,테플리체', 50.6404000, 13.8245100, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28741, 'Telnice', 'Telnice', 'Telnice,Telnitz,Телнице', 49.1018700, 16.7177400, 'CZ', '2016-07-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28742, 'Telč', 'Telc', 'Gorad Tehl''ch,Tel''ch,Telca,Telcas,Telch,Telcz,Teltsch,Telča,Telčas,tai er qi,telchi,teruchi,tlz,Горад Тэльч,Телч,Тельч,טלץ,ტელჩი,テルチ,泰尔奇,텔치', 49.1841800, 15.4527500, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28743, 'Tečovice', 'Tecovice', '', 49.2210700, 17.5873300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28744, 'Tasovice', 'Tasovice', 'Tasswitz', 48.8361000, 16.1555800, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28745, 'Tanvald', 'Tanvald', 'Tannwald,Tanvald,tan wa er de,Танвалд,坦瓦爾德', 50.7373500, 15.3058500, 'CZ', '2017-02-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28746, 'Tachov', 'Tachov', 'Gorad Takhau,Reichental,Tachau,Tachof,Tachov,Tachovas,Tachovia,Tahova,Takhov,ta huo fu,takhwf,Τάχοφ,Горад Тахаў,Тахов,تاخوف,塔霍夫', 49.7952800, 12.6336500, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28747, 'Tábor', 'Tabor', 'Gorad Tabar,Tabor,Taboras,Tábor,ta bo er,taboleu,tabor,taboru,tabwr,Горад Табар,Табор,Տաբոր,تابور,ターボル,塔博尔,타보르', 49.4144100, 14.6578000, 'CZ', '2007-11-05', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28748, 'Svratka', 'Svratka', 'Svratka,Swratka,si fu la te ka,Свратка,斯夫拉特卡', 49.7106600, 16.0321400, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28749, 'Svoboda nad Úpou', 'Svoboda nad Upou', 'Freiheit,Svoboda', 50.6259600, 15.8164800, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28750, 'Svitavy', 'Svitavy', 'Svitave,Svitavi,Svitavy,Zwittau,si wei ta wei,Свитави,斯維塔維', 49.7559400, 16.4682900, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28751, 'Svitávka', 'Svitavka', 'Swittawka', 49.5017800, 16.5979300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28752, 'Švihov', 'Svihov', 'Schwihau,Shvigov,Shvikhov,Svihov u Klatov,shen wei huo fu,Švihov u Klatov,Швигов,Швихов,什維霍夫', 49.4813600, 13.2841700, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28753, 'Sviadnov', 'Sviadnov', '', 49.6892600, 18.3276200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28754, 'Světlá nad Sázavou', 'Svetla nad Sazavou', 'Svetla pie Sazavas,Svetla pie Sāzavas,Svetla-nad-Sazavou,Svjetla na Sazavi,Swetla,Swětlá,sa zha wa he pan si wei te la,Светла-над-Сазавоу,Свјетла на Сазави,薩扎瓦河畔斯韋特拉', 49.6680100, 15.4039300, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28755, 'Svatava', 'Svatava', 'Zwodau', 50.1922300, 12.6252400, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28756, 'Sušice', 'Susice', 'Schuttenhofen,Schüttenhofen,Sushice,su xi cai,susiche,Сушице,蘇希采,수시체', 49.2310600, 13.5201800, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28757, 'Šumperk', 'Sumperk', 'Maehrisch-Schoenberg,Mährisch-Schönberg,Shumperk,Sumperka,Sumperkas,shumuperuku,shun pei er ke,shwmbyrk,shwmprk,syumpeleukeu,Šumperka,Šumperkas,Шумперк,شومبيرك,شومپرک,シュムペルク,順佩爾克,슘페르크', 49.9652800, 16.9706100, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28758, 'Šumice', 'Sumice', 'Schumitz', 49.0285800, 17.7220500, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28759, 'Sudoměřice', 'Sudomerice', '', 48.8672300, 17.2567600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28760, 'Sudkov', 'Sudkov', 'Zautke', 49.9190300, 16.9451600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28761, 'Suchohrdly', 'Suchohrdly', 'Zuckerhandl', 48.8682200, 16.0947100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28762, 'Suchdol nad Lužnicí', 'Suchdol nad Luznici', 'Suchenthal an der Lainsitz', 48.8900000, 14.8772000, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28763, 'Suchdol', 'Suchdol', '', 49.9524700, 15.1665100, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28764, 'Suchá Loz', 'Sucha Loz', '', 48.9700100, 17.7137900, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28765, 'Studénka', 'Studenka', 'Stauding', 49.7234200, 18.0785300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28766, 'Studenec', 'Studenec', '', 50.5534400, 15.5493600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28767, 'Studená', 'Studena', 'Studein', 49.1851600, 15.2868800, 'CZ', '2012-11-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28768, 'Strunkovice nad Blanicí', 'Strunkovice nad Blanici', 'Strunkovice,Strunkowitz', 49.0840200, 14.0552200, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28769, 'Strmilov', 'Strmilov', 'Strmelov,Tremles', 49.1584600, 15.1993400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28770, 'Střížkov', 'Strizkov', '', 50.1267400, 14.4936300, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28771, 'Stříbro', 'Stribro', 'Mies,Shtribro,Stribro,Strshibro,si te ri bu luo,Стрибро,Стршибро,Штрібро,斯特日布羅', 49.7556500, 12.9970000, 'CZ', '2013-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28772, 'Střelice', 'Strelice', 'Strelice u Brna,Strelitz,Střelice u Brna,Střelitz', 49.1522100, 16.5039900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28773, 'Stráž pod Ralskem', 'Straz pod Ralskem', 'Strazh pod Ralskom,Strazh-pod-Ral''skem,Wartenberg,Страж под Ралском,Страж-под-Ральскем', 50.7028000, 14.8010200, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28774, 'Strážov', 'Strazov', 'Drosau', 49.3032600, 13.2462300, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28775, 'Strážnice', 'Straznice', 'Strazhnice,Straznice,Strāžnice,seuteulajuniche,si te la ri ni cai,Стражнице,Стражњице,斯特拉日尼采,스트라주니체', 48.9010200, 17.3168000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28776, 'Stráž nad Nisou', 'Straz nad Nisou', 'Alt-Habendorf,Stary Habendorf,Starý Habendorf', 50.7909900, 15.0268300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28777, 'Strážná', 'Strazna', 'Moravsky Sumvald,Moravský Šumvald,Schonwald,Schönwald,Sumvald,Sumwald,Šumvald,Šumwald', 49.8310400, 17.1327500, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28778, 'Stráž', 'Straz', 'Neustadtl', 49.6687800, 12.7754600, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28779, 'Strašice', 'Strasice', 'Straschitz', 49.7355200, 13.7575500, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28780, 'Strání', 'Strani', '', 48.9021600, 17.7067100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28781, 'Strančice', 'Strancice', 'Stranschitz', 49.9481100, 14.6774500, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28782, 'Štramberk', 'Stramberk', 'Stramberg', 49.5918100, 18.1174100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28783, 'Strakonice', 'Strakonice', 'Strakonice,Strakonitse,Strakonitz,si te la ke ni cai,straknytsh,Страконитсе,Страконице,Стракоњице,ستراکنیتسه,斯特拉科尼采', 49.2614100, 13.9023700, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28784, 'Stonava', 'Stonava', 'Stonawa', 49.8169100, 18.5251800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28785, 'Štoky', 'Stoky', 'Shtoki,Stecken,Штоки', 49.5024900, 15.5886300, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28786, 'Stod', 'Stod', 'Staab,Stod,si tuo de,Стод,斯托德', 49.6390900, 13.1647400, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28787, 'Stochov', 'Stochov', '', 50.1463100, 13.9634500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28788, 'Štíty', 'Stity', 'Schildberg,Shtiti,Silperk,Stiti,shen di di,Šilperk,Štīti,Штити,什蒂蒂', 49.9612200, 16.7657600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28789, 'Štítná nad Vláří', 'Stitna nad Vlari', '', 49.0688100, 17.9827400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28790, 'Štítina', 'Stitina', '', 49.9148700, 18.0124500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28791, 'Stěžery', 'Stezery', 'Stezer', 50.2157200, 15.7483100, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28792, 'Štětí', 'Steti', 'Wegstadtl,Wegstädtl', 50.4529800, 14.3742100, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28793, 'Šternberk', 'Sternberk', 'Shternberk,Sternberg,Sternberk,Sternberka,shi teng bei ke,Šternberk,Šternberka,Штернберк,施滕貝克', 49.7304400, 17.2988900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28794, 'Štěpánov', 'Stepanov', 'Stepanov,Stiepanau,Štěpánov', 50.1623800, 16.9170200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28795, 'Štěpánov', 'Stepanov', 'Stefanau', 49.6840400, 17.2204100, 'CZ', '2014-12-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28796, 'Štěpánkovice', 'Stepankovice', 'Schepankowitz', 49.9573800, 18.0374100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28797, 'Štěnovice', 'Stenovice', 'Stenowitz,Stěnowitz', 49.6705100, 13.3996300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28798, 'Štěchovice', 'Stechovice', 'Shtekhovice,Shtjekhovice,Stechovice u Prahy,Stechowitz,Štěchovice u Prahy,Штеховице,Штјеховице', 49.8510900, 14.4054300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28799, 'Stěbořice', 'Steborice', '', 49.9370800, 17.8054700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28800, 'Starý Plzenec', 'Stary Plzenec', 'Alt Pilsenetz,Stari Plzenec,Stari-Pl''zenec,Stary Plzenec,Starý Plzeňec,jiu pu er ze nei ci,Стари Плзенец,Стари-Пльзенец,舊普爾澤內茨', 49.6976800, 13.4735000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28801, 'Starý Kolín', 'Stary Kolin', 'Alt Kolin', 50.0097700, 15.2938800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28802, 'Starý Jičín', 'Stary Jicin', 'Alttitschein', 49.5768600, 17.9616900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28803, 'Starý Bohumín', 'Stary Bohumin', 'Bogumin,Bohumin,Bohumín,Oderberg,Stary Bohumin,Starý Bohumín', 49.9169000, 18.3361900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28804, 'Staříč', 'Staric', 'Stara Staric,Staritsch,Stará Staříč', 49.6859400, 18.2728100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28805, 'Staré Nechanice', 'Stare Nechanice', '', 50.2429800, 15.6178700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28806, 'Staré Město', 'Stare Mesto', 'Cidade Velha,Citta Vecchia,Città Vecchia,Ciudad vieja,Malnova Urbo,Old Town,Oude Stad,Ovaros,Pragako Hiri Zaharra,Prager Altstadt,Praski stari grad,Praški stari grad,Stara-Mesta,Stare Miasto,Stare Miesto,Stare Misto,Stare-Mesto,Vieille Ville,bu la ge lao cheng,seutalemeseuto,Óváros,Στάρε Μιέστο,Стара-Места,Старе Місто,Старе-Место,布拉格老城,스타레메스토', 50.0870000, 14.4202400, 'CZ', '2014-09-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28807, 'Staré Město', 'Stare Mesto', 'Altstadt,Mahrisch-Altstadt,Mährisch-Altstadt,Stare Mesto,Stare Mesto pod Sneznikem,Stare Mjesto,Staré Město pod Sněžníkem,si ta lei mei si tuo,Старе Мјесто,斯塔雷梅斯托', 50.1617400, 16.9473400, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28808, 'Staré Město', 'Stare Mesto', 'Stare Miasto', 49.6699200, 18.3634900, 'CZ', '2014-11-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28809, 'Staré Město', 'Stare Mesto', 'Altstadt,Stare Mesto,Stare Mesto u Uherskeho Hradiste,Stare Mjesto,Stare-Mesto,Staré Město u Uherského Hradiště,si ta lei mei si tuo,Старе Мјесто,Старе-Место,斯塔雷梅斯托', 49.0751500, 17.4333800, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28810, 'Staré Křečany', 'Stare Krecany', 'Alt-Ehrenberg,Stary Ehrenberk,Starý Ehrenberk', 50.9504400, 14.4961700, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28811, 'Staré Hradiště', 'Stare Hradiste', '', 50.0654000, 15.7788500, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28812, 'Stařeč', 'Starec', 'Startsch', 49.1978300, 15.8279100, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28813, 'Stará Ves nad Ondřejnicí', 'Stara Ves nad Ondrejnici', 'Altendorf,Stara Ves,Stará Ves', 49.7277500, 18.1885000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28814, 'Stará Paka', 'Stara Paka', 'Alt Paka,Stara Paka,Стара Пака', 50.5103200, 15.4944400, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28815, 'Stará Huť', 'Stara Hut''', 'Althutten,Althütten', 49.7822500, 14.1973500, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28816, 'Staňkov', 'Stankov', 'Mestys Stankov,Městys Staňkov,Stan''kov,Stankau,Stankov,Ves Stankov,Ves Staňkov,si ta ni ke fu,Станьков,Стањков,斯塔尼科夫', 49.5534800, 13.0697600, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28817, 'Šťáhlavy', 'St''ahlavy', 'Shtjakhlavi,Stahlau,Штјахлави', 49.6755500, 13.5039400, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28818, 'Stachy', 'Stachy', 'Stachau', 49.1017900, 13.6665900, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28819, 'Srubec', 'Srubec', '', 48.9480600, 14.5413100, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28820, 'Spytihněv', 'Spytihnev', 'Spitinau,Spytinov', 49.1411500, 17.4980800, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28821, 'Špindlerův Mlýn', 'Spindleruv Mlyn', 'Shpindleruv Mlin,Shpindleruv-Mlin,Spindelmuhle,Spindelmühle,Spindlermuehle,Spindlermühle,Spindleruv Mlyn,Spindleruv Mlynas,Szpindlerowy Mlyn,Szpindlerowy Młyn,shen ping de lai lu fu mu lin,spyndlrwb mlyn,syupindeullelupeumeullin,Špindlerūv Mlynas,Špindlerův Mlýn,Шпиндлерув Млин,Шпиндлерув-Млин,Шпіндлерув Млин,שפינדלרוב מלין,什平德萊魯夫姆林,슈핀들레루프믈린', 50.7261500, 15.6094400, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28822, 'Spálené Poříčí', 'Spalene Porici', 'Brennporitschen', 49.6137100, 13.6055600, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28823, 'Solnice', 'Solnice', 'Sollnitz', 50.2036600, 16.2376200, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28824, 'Sokolov', 'Sokolov', 'Faiknov,Falkenau,Falkenau an der Eger,Falknov,Falknov nad Ohri,Falknov nad Ohří,Gorad Sokalau,Sokolov,Sokolov nad Ohri,Sokolov nad Ohří,Sokolovas,sklw,sokollopeu,suo ke luo fu,swkwlwf,Горад Сокалаў,Соколов,سوكولوف,سکلو,索科洛夫,소콜로프', 50.1813000, 12.6401000, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28825, 'Sokolnice', 'Sokolnice', 'Sokolnitz', 49.1139200, 16.7215600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28826, 'Sobotka', 'Sobotka', '', 50.4674100, 15.1761900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28827, 'Sobotín', 'Sobotin', 'Sobotin,Zoptau,Zöptau,Соботин', 50.0103900, 17.0912900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28828, 'Soběslav', 'Sobeslav', 'Sobeslau,Sobeslav,Sobjeslav,Soběslau,suo bie si la fu,Собеслав,Собјеслав,索別斯拉夫', 49.2599300, 14.7186100, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28829, 'Smržovka', 'Smrzovka', 'Morchenstern', 50.7382000, 15.2463900, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28830, 'Smržice', 'Smrzice', 'Smrzitz', 49.5056900, 17.1069800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28831, 'Smiřice', 'Smirice', 'Smiritz,Smirzhice,Smiřitz,si mi ri cai,Смиржице,斯米日采', 50.2997800, 15.8650800, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28832, 'Smidary', 'Smidary', 'Smidar', 50.2914600, 15.4772500, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28833, 'Smečno', 'Smecno', '', 50.1884400, 14.0403700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28834, 'Slušovice', 'Slusovice', 'Sluschowitz,Slushovice,si lu shao wei cai,Слушовице,斯盧紹維采', 49.2478200, 17.8015000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28835, 'Šluknov', 'Sluknov', 'Schluckenau,Shluknov,shen lu ke nuo fu,Шлукнов,什盧克諾夫', 51.0036900, 14.4525800, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28836, 'Slavonice', 'Slavonice', 'Slavonice,Slavonices,Slavonicės,Zlabings,si la wo ni cai,Славоњице,斯拉沃尼采', 48.9975300, 15.3515400, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28837, 'Slavkov u Brna', 'Slavkov u Brna', 'Austerlitz,Slaukovia,Slavkov kraj Burno,Slavkov u Brna,Slavkov-u-Brna,Slavkova pie Brno,Slavkovas prie Brno,Slawkow,Sławków,bu er nuo fu jin si la fu ke fu,seullabeukopeuubeuleuna,slʼwqwb,Славков край Бърно,Славков у Брна,Славков-у-Брна,סלאוקוב,スラフコフ・ウ・ブルナ,布尔诺附近斯拉夫科夫,슬라브코프우브르나', 49.1532500, 16.8764900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28838, 'Slavkov', 'Slavkov', 'Schlakau', 49.9218000, 17.8364100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28839, 'Slavičín', 'Slavicin', 'Mladotitz,Slavichin,Slavicin-Mladotice,Slavicina,Slavičín-Mladotice,Slavičīna,Slawitschin,si la wei qin,Славичин,斯拉維欽', 49.0879900, 17.8734900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28840, 'Slatinice', 'Slatinice', '', 49.5615500, 17.0999200, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28841, 'Slatiňany', 'Slatinany', 'Slatinan', 49.9211000, 15.8137700, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28842, 'Šlapanice', 'Slapanice', 'Lapanz,Schlapanitz,Schlappanitz,Shlapanice,Slapanice,shen la pa ni cai,Šlapanice,Шлапанице,Шлапањице,什拉帕尼采', 49.1686300, 16.7273100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28843, 'Slaný', 'Slany', 'Schlan,Slani,Слани', 50.2304600, 14.0869300, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28844, 'Skuteč', 'Skutec', 'Skuteca,Skutech,Skuteča,Skutsch,si ku tai qi,Скутеч,斯庫泰奇', 49.8434700, 15.9965500, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28845, 'Skuhrov nad Bělou', 'Skuhrov nad Belou', '', 50.2294600, 16.2923000, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28846, 'Skrbeň', 'Skrben', 'Kirwein', 49.6411500, 17.1765000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28847, 'Skalná', 'Skalna', 'Vildstejn,Vildštejn,Wildstein', 50.1703000, 12.3614400, 'CZ', '2011-01-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28848, 'Šitbořice', 'Sitborice', 'Schuttborzitz,Schüttborzitz', 49.0143300, 16.7797500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28849, 'Šilheřovice', 'Silherovice', 'Schillersdorf', 49.9260200, 18.2701700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28850, 'Sezimovo Ústí', 'Sezimovo Usti', 'Alt Tabor', 49.3851900, 14.6848000, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28851, 'Sezemice', 'Sezemice', 'Sezemitz', 50.0665100, 15.8527000, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28852, 'Ševětín', 'Sevetin', 'Schewetin', 49.1000500, 14.5722000, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28853, 'Šestajovice', 'Sestajovice', '', 50.1084500, 14.6801300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28854, 'Sepekov', 'Sepekov', 'Sepekau', 49.4286500, 14.4181500, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28855, 'Šenov', 'Senov', '', 49.7931500, 18.3760700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28856, 'Senice na Hané', 'Senice na Hane', 'Gross Senitz,Senice', 49.6240100, 17.0857800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28857, 'Semily', 'Semily', 'Semil', 50.6019100, 15.3355200, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28858, 'Sedlnice', 'Sedlnice', 'Sedlnitz', 49.6577000, 18.0869000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28859, 'Sedliště', 'Sedliste', 'Siedliszcze', 49.7183600, 18.3686900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28860, 'Sedlice', 'Sedlice', 'Sedlitz', 49.3771500, 13.9389500, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28861, 'Sedlice', 'Sedlice', '', 48.7740100, 14.3911500, 'CZ', '2014-05-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28862, 'Sedlec', 'Sedlec', 'Sedlec,Sedletz,Sedlice,Седлец,Седліце', 49.9639100, 15.2884600, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28863, 'Sedlčany', 'Sedlcany', 'Sedl''chani,Sedlchani,Selcan,Selčan,sai de er qia ni,Седлчани,Седльчани,塞德爾恰尼', 49.6605700, 14.4266400, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28864, 'Seč', 'Sec', '', 49.8469400, 15.6564300, 'CZ', '2012-11-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28865, 'Sázava', 'Sazava', 'Sazau', 49.8716400, 14.8967400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28866, 'Šatov', 'Satov', 'Schattau', 48.7931700, 16.0099200, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28867, 'Satalice', 'Satalice', 'Satalic,Satalitz', 50.1248400, 14.5719100, 'CZ', '2014-04-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28868, 'Šardice', 'Sardice', '', 48.9640300, 17.0281200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28869, 'Šanov', 'Sanov', 'Schonau,Schönau', 48.8008900, 16.3785800, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28870, 'Samotíšky', 'Samotisky', '', 49.6304200, 17.3280700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28871, 'Šakvice', 'Sakvice', '', 48.8974600, 16.7142400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28872, 'Sadská', 'Sadska', 'Sadska,sa de si ka,Садска,薩德斯卡', 50.1359600, 14.9863300, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28873, 'Sadov', 'Sadov', 'Sodau', 50.2671100, 12.8970800, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28874, 'Rýmařov', 'Rymarov', 'Rimarzhov,Rimarzova,Romerstadt,Römerstadt,Rīmaržova,li ma ruo fu,Римаржов,里馬若夫', 49.9318300, 17.2717700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28875, 'Rychvald', 'Rychvald', 'Rychwald', 49.8662500, 18.3762600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28876, 'Rychnov nad Kněžnou', 'Rychnov nad Kneznou', 'Reichenau,Richnovas prie Kneznos,Richnovas prie Knežnos,Rikhnov na Knezhnoj,Rikhnov-nad-Knezhnou,rykhnwf nad knyjnw,Рихнов на Књежној,Рихнов-над-Кнежноу,ريخنوف ناد كنيجنو', 50.1628400, 16.2748800, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28877, 'Rybitví', 'Rybitvi', 'Rybitew', 50.0601500, 15.7047200, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28878, 'Rybí', 'Rybi', 'Reimlich,Reimrich', 49.6007300, 18.0759200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28879, 'Rumburk', 'Rumburk', 'Rumburg,Rumburk,lun bu er ke,Румбурк,倫布爾克', 50.9515100, 14.5569900, 'CZ', '2013-01-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28880, 'Rudolfov', 'Rudolfov', 'Rudolfov,Rudolfstadt,lu duo er fu fu,Рудолфов,魯多爾福夫', 48.9933900, 14.5417900, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28881, 'Rudník', 'Rudnik', 'Hermannseifen,Hermanovy Sejfy,Heřmanovy Sejfy,Rudnik,Rudnik v Krkonosich,Rudník v Krkonoších,Scify,Рудњик', 50.5951700, 15.7336200, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28882, 'Rudná', 'Rudna', '', 50.0350200, 14.2343500, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28883, 'Ruda nad Moravou', 'Ruda nad Moravou', 'Eisenberg an der March,Eisenberg an der Morava,Ober Eisenberg,Ruda na Morave,Ruda na Moravě', 49.9810000, 16.8778200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28884, 'Rtyně v Podkrkonoší', 'Rtyne v Podkrkonosi', 'Hertin', 50.5052300, 16.0718700, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28885, 'Roztoky', 'Roztoky', 'Rostok,Rostoki,Roztoki,Roztoky u Prahy,luo zi tuo ji,Розтоки,Ростоки,羅茲托基', 50.1584100, 14.3976000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28886, 'Roztoky', 'Roztoky', 'Rostok', 50.0267100, 13.8678700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28887, 'Rožnov pod Radhoštěm', 'Roznov pod Radhostem', 'Rozhnov pod Radkhoshtjem,Rozhnov-pod-Radgoshtem,Roznau,Roznov,Roznov pod Radhostem,Roznova pie Radhostja,Rožnov,Rožnov pod Radhoštěm,Rožnova pie Radhoštja,Рожнов под Радхоштјем,Рожнов-под-Радгоштем', 49.4585300, 18.1430200, 'CZ', '2017-05-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28888, 'Rožmitál pod Třemšínem', 'Rozmital pod Tremsinem', 'Rozmital,Rožmitál', 49.6019600, 13.8643000, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28889, 'Rožďalovice', 'Rozd''alovice', 'Rozdalowitz,Rozdd''alovice,Roždálowitz,Roždďalovice', 50.3047600, 15.1696200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28890, 'Rovensko pod Troskami', 'Rovensko pod Troskami', 'Rovensko,Rowensko', 50.5353200, 15.2594100, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28891, 'Rousínov', 'Rousinov', 'Rousinov,Rousinova,Rousīnova,luo wu xi nuo fu,Роусинов,羅烏西諾夫', 49.2012800, 16.8821500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28892, 'Roudnice nad Labem', 'Roudnice nad Labem', 'Raudnitz a.d. Elbe,Roudnice na Labi,Roudnice-nad-Labem,la bei he pan luo wu de ni cai,Роуднице-над-Лабем,Роудњице на Лаби,拉貝河畔羅烏德尼采', 50.4252800, 14.2617500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28893, 'Rouchovany', 'Rouchovany', 'Rouchowan', 49.0703600, 16.1076000, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28894, 'Rotava', 'Rotava', 'Rothau', 50.2962700, 12.5734100, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28895, 'Rosice', 'Rosice', 'Rositz', 49.9222600, 15.9512700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28896, 'Rosice', 'Rosice', 'Rosice,Rosice u Brna,Rossitz,luo xi cai,Росице,Росіце,羅西采', 49.1823200, 16.3878700, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28897, 'Ropice', 'Ropice', '', 49.7053600, 18.6134500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28898, 'Ronov nad Doubravou', 'Ronov nad Doubravou', 'Ronow an der Doubrava', 49.8882500, 15.5314400, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28899, 'Rokytnice v Orlických Horách', 'Rokytnice v Orlickych Horach', 'Rokitnitz,Rokitnitz im Adlergebirge', 50.1647300, 16.4656700, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28900, 'Rokytnice nad Jizerou', 'Rokytnice nad Jizerou', 'Rochlitz an der Iser,Rokytnice', 50.7256100, 15.4335700, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28901, 'Rokytnice', 'Rokytnice', 'Roketnitz', 49.4659200, 17.3912000, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28902, 'Rokycany', 'Rokycany', 'Rokicanai,Rokicani,Rokitzan,Rokycan,luo ji cha ni,rwkytsany,Рокицани,روكيتساني,羅基察尼', 49.7427000, 13.5945900, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28903, 'Rohatec', 'Rohatec', '', 48.8804000, 17.1833000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28904, 'Říčany', 'Ricany', 'Rican,Richani,Ričan,Rzhichani,ri qia ni,Ржичани,Ричани,日恰尼', 49.9916800, 14.6542700, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28905, 'Říčany', 'Ricany', 'Rican,Ricany u Brna,Ričan,Říčany u Brna', 49.2149700, 16.3936200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28906, 'Řež', 'Rez', '', 50.1773400, 14.3573300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28907, 'Řevničov', 'Revnicov', 'Rentsch', 50.1848900, 13.8082300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28908, 'Řevnice', 'Revnice', 'Rewnitz', 49.9139500, 14.2358900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28909, 'Řepiště', 'Repiste', '', 49.7333800, 18.3170700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28910, 'Řehlovice', 'Rehlovice', 'Gross Tschochau', 50.6071200, 13.9541200, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28911, 'Řečany nad Labem', 'Recany nad Labem', 'Recan,Rečan', 50.0358900, 15.4773500, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28912, 'Ratíškovice', 'Ratiskovice', '', 48.9200200, 17.1656100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28913, 'Ratiboř', 'Ratibor', '', 49.3676900, 17.9149900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28914, 'Rataje', 'Rataje', '', 49.2713000, 17.3355500, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28915, 'Raspenava', 'Raspenava', 'Raspenau,Raspenava,la si pei na wa,Распенава,拉斯佩納瓦', 50.9041500, 15.1146500, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28916, 'Raškovice', 'Raskovice', 'Raszkowice', 49.6197500, 18.4728600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28917, 'Rapotín', 'Rapotin', 'Ciudad de Rapotin,Ciudad de Rapotín,Rapotin,Reitendorf,Рапотин', 50.0109400, 17.0312100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28918, 'Rakvice', 'Rakvice', '', 48.8581100, 16.8133000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28919, 'Rakovník', 'Rakovnik', 'Rakonitz', 50.1037000, 13.7334000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28920, 'Rajhradice', 'Rajhradice', '', 49.0920300, 16.6293300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28921, 'Rajhrad', 'Rajhrad', 'Rajhrada,Rajkhrad,lai he la de,Рајхрад,賴赫拉德', 49.0902100, 16.6038800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28922, 'Ráječko', 'Rajecko', '', 49.3939300, 16.6449700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28923, 'Rájec-Jestřebí', 'Rajec-Jestrebi', 'Rajec-Jestrebi,Rajeca-Jestrsebi,Rājeca-Jestršebi,la ye ci-ye si te re bi,Рајец-Јестреби,拉耶茨-耶斯特熱比', 49.4109400, 16.6390200, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28924, 'Radvanice', 'Radvanice', 'Radowenz', 50.5674500, 16.0617200, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28925, 'Radslavice', 'Radslavice', '', 49.4781700, 17.5165600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28926, 'Radonice', 'Radonice', 'Radonitz', 50.2980300, 13.2846400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28927, 'Radomyšl', 'Radomysl', 'Radomischl,Radomishl,Радомишл', 49.3163400, 13.9302400, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28928, 'Radnice', 'Radnice', 'Radnice,Radnitz,la de ni cai,Раднице,Радњице,拉德尼采', 49.8567700, 13.6057000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28929, 'Radiměř', 'Radimer', 'Bohmisch Rothmuhl,Böhmisch Rothmühl,Ceska Radimer,Mahrisch Rothmuhl,Moravska Radimer,Moravská Radiměř,Mährisch Rothmühl,Rothmuhl,Rothmühl,Česká Radiměř', 49.6985000, 16.4407000, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28930, 'Pyšely', 'Pysely', 'Pischely', 49.8767800, 14.6771300, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28931, 'Pustiměř', 'Pustimer', 'Nemecke Prusy,Německé Prusy,Pustomer,Pustoměř', 49.3225100, 17.0279200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28932, 'Pustá Polom', 'Pusta Polom', 'Wuest Pohlom,Wüst Pohlom', 49.8491700, 17.9979000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28933, 'Ptení', 'Pteni', 'Ptin', 49.5116300, 16.9611000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28934, 'Psáry', 'Psary', 'Psar', 49.9362200, 14.5127600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28935, 'Prusinovice', 'Prusinovice', 'Prusinowitz', 49.3789800, 17.5871000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28936, 'Prušánky', 'Prusanky', '', 48.8284000, 16.9806800, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28937, 'Průhonice', 'Pruhonice', '', 49.9996200, 14.5501700, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28938, 'Protivín', 'Protivin', 'Protivin,Protiwin,Protiwín,pu luo di wen,Противин,普羅蒂溫', 49.1994900, 14.2171700, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28939, 'Protivanov', 'Protivanov', 'Protiwanow', 49.4835100, 16.8359400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28940, 'Prostřední Bečva', 'Prostredni Becva', 'Mittel Becwa,Mittel Beczwa,Mittel Bečwa', 49.4360900, 18.2520000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28941, 'Prostějov', 'Prostejov', 'Prosciejow,Prosnitz,Prossnitz,Prostejov,Prostejova,Prostejovas,Prostjejov,Prostějov,Prosznitz,Prościejów,brwstywf,peuloseuteyopeu,prwstyw,prwstywb,prxs teiy yxf,pu luo si jie yue fu,purosucheyofu,Простейов,Простеёв,Простјејов,פראסטיץ,פרוסטיוב,بروستيوف,پرستیه‌یو,پروستیو,ปรอสเตียยอฟ,プロスチェヨフ,普羅斯捷約夫,프로스테요프', 49.4718800, 17.1118400, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28942, 'Prosek', 'Prosek', 'Prosek', 50.1152500, 14.5068500, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28943, 'Proseč', 'Prosec', '', 49.8059000, 16.1162100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28944, 'Proboštov', 'Probostov', 'Probstau', 50.6677300, 13.8360100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28945, 'Příšovice', 'Prisovice', '', 50.5781300, 15.0839000, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28946, 'Přimda', 'Primda', 'Pfraumberg,Primda,Prshimda,pu ri mu da,Примда,Пршимда,普日姆達', 49.6748800, 12.6736600, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28947, 'Příkazy', 'Prikazy', 'Przikaz', 49.6436000, 17.1433700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28948, 'Přibyslav', 'Pribyslav', 'Pribislau,Pribislav,Prshibislav,Prsibislava,Pršibislava,Přibislau,pu ri bi si la fu,Прибислав,Пршибислав,普日比斯拉夫', 49.5768400, 15.7385500, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28949, 'Příbram', 'Pribram', 'Pribram,Prshibram,Prsybramas,Przybram,Pršybramas,Příbram,bshybram,peuleujibeulam,przhybram,pu ri bu la mu,Прибрам,Пршибрам,بشيبرام,پرژیبرام,普日布拉姆,프르지브람', 49.6898800, 14.0104300, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28950, 'Příbor', 'Pribor', 'Freiberg,Gorad Prshybar,Pribor,Primpor,Prshibor,Prsibora,Pršībora,pu ri bo er,Πρίμπορ,Горад Пршыбар,Прибор,Пршибор,普日博尔', 49.6409400, 18.1449900, 'CZ', '2013-12-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28951, 'Přeštice', 'Prestice', 'Preshtice,Prestitz,Prsheshtice,Přestitz,pu re shen ji cai,Прештице,Пршештице,普熱什季采', 49.5729800, 13.3335000, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28952, 'Přerov nad Labem', 'Prerov nad Labem', 'Alt-Prerow,Alt-Přerow,Neu-Prerow,Neu-Přerow,Prerov na Labi,Prsherov nad Labem,Prsherov-nad-Labem,Преров на Лаби,Пршеров над Лабем,Пршеров-над-Лабем', 50.1602700, 14.8250200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28953, 'Přerov', 'Prerov', 'PRV,Prerau,Prerov,Prserova,Prserovas,Prsherov,Przerow,Przerów,Pršerova,Pršerovas,Přerov,brshyrwf,peuleujelopeu,przhrw,pu re luo fu,purujerofu,pzhyrw,Преров,Пршеров,برشيروف,پرژرو,پژیرو,პრშეროვი,プルジェロフ,普熱羅夫,프르제로프', 49.4551100, 17.4509000, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28954, 'Přemyslovice', 'Premyslovice', 'Przemislowitz', 49.5563700, 16.9558100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28955, 'Přelouč', 'Prelouc', 'Prelauc,Přelauč', 50.0398500, 15.5603100, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28956, 'Předměřice nad Labem', 'Predmerice nad Labem', 'Predmeritz,Předmeřitz', 50.2563300, 15.8155600, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28957, 'Předklášteří', 'Predklasteri', 'Vorkloster', 49.3525300, 16.4024100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28958, 'Pražmo', 'Prazmo', '', 49.6087600, 18.4861700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28959, 'Přáslavice', 'Praslavice', 'Przaslawitz', 49.5856800, 17.3820900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28960, 'Prague', 'Prague', 'PRG,Praag,Prag,Praga,Pragae,Prago,Prague,Praha,Pràg,Prág,Prága,Prâg,Prāga,bragh,bu la ge,peulaha,prag,praga,prak,prg,puraha,Πράγα,Праг,Прагæ,Прага,פראג,براغ,پراگ,پراگا,ܦܪܓ,ปราก,པུ་ལ་ཁེ,პრაღა,ፕራግ,プラハ,布拉格,프라하', 50.0880400, 14.4207600, 'CZ', '2013-11-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28961, 'Prachovice', 'Prachovice', '', 49.8937900, 15.6287200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28962, 'Prachatice', 'Prachatice', 'Gorad Prakhacicy,Prachatitz,Prakhatice,brakhatytsh,pu la ha ji cai,Горад Прахаціцы,Прахатице,براخاتيتسه,普拉哈季采', 49.0129200, 13.9975200, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28963, 'Pozořice', 'Pozorice', 'Posoritz,Posořitz,Pozorzhice,Позоржице', 49.2097600, 16.7907400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28964, 'Pozlovice', 'Pozlovice', 'Poslowitz,Pozlovice,Позловице', 49.1292100, 17.7692500, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28965, 'Povrly', 'Povrly', 'Poemmerle,Pomerle,Pömerle,Pömmerle', 50.6727600, 14.1603300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28966, 'Potštát', 'Potstat', 'Bodenstadt,Potshtat,Potstata,Potštāta,bo te shi ta te,Потштат,波特施塔特', 49.6369300, 17.6517400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28967, 'Postupice', 'Postupice', 'Postupitz', 49.7279800, 14.7772200, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28968, 'Postřelmov', 'Postrelmov', 'Gross Heilendorf', 49.9075600, 16.9122600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28969, 'Postřekov', 'Postrekov', 'Postrekov,Постреков', 49.4582700, 12.8067800, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28970, 'Postoloprty', 'Postoloprty', 'Postelberg,Postoloprti,bo si tuo luo pu di,Постолопрти,波斯托洛普蒂', 50.3597900, 13.7029100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28971, 'Poříčí nad Sázavou', 'Porici nad Sazavou', 'Poric,Pořič', 49.8389500, 14.6744600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28972, 'Poříčany', 'Poricany', 'Porican,Pořican', 50.1080600, 14.9181800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28973, 'Popovice', 'Popovice', 'Popowitz', 49.0525500, 17.5271200, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28974, 'Poniklá', 'Ponikla', 'Pinklau', 50.6615200, 15.4632900, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28975, 'Pomezí', 'Pomezi', 'Laubendorf,Limberk', 49.7102600, 16.3172900, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28976, 'Polná', 'Polna', 'Pol''na,Polna,bo er na,Полна,Польна,波爾納', 49.4870000, 15.7188100, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28977, 'Polička', 'Policka', 'Polichka,bo li qi ka,Поличка,波利奇卡', 49.7146500, 16.2654300, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28978, 'Police nad Metují', 'Police nad Metuji', 'Police na Metuji,Police-nad-Metui,Politz,mei tu ye he pan bo li cai,Полице на Метуји,Поліце-над-Метуї,梅圖耶河畔波利采', 50.5368700, 16.2335000, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28979, 'Polešovice', 'Polesovice', 'Poleschowitz', 49.0339000, 17.3406400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28980, 'Polepy', 'Polepy', '', 50.5056300, 14.2644700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28981, 'Pohořelice', 'Pohorelice', 'Pogorzhelice,Pohorzelice,Pohorželice,Pohrlitz,Pokhorzhelice,bo huo re li cai,Погоржелице,Похоржелице,波霍熱利采', 48.9811900, 16.5244500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28982, 'Podolí', 'Podoli', 'Kricen,Kritschen,Kříčeň,Podoli,Podolí,Подоли', 49.1904200, 16.7208400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28983, 'Podivín', 'Podivin', '', 48.8255400, 16.8482200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28984, 'Poděbrady', 'Podebrady', 'Podebrad,Podebradai,Podebradi,Podebrady,Podiebrady,Podjebradi,bo jie bu la di,Подебради,Подебрады,Подєбради,Подјебради,Պոդեբրադի,波傑布拉迪', 50.1424200, 15.1188100, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28985, 'Podbořany', 'Podborany', 'Podborzhani,Podersam,bo de bo zha ni,Подборжани,波德博扎尼', 50.2293700, 13.4119200, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28986, 'Počátky', 'Pocatky', 'Pocatek,Pocatki,Pochatki,Počátek,Počātki,bo qia te ji,Початки,波恰特基', 49.2602000, 15.2402200, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28987, 'Poběžovice', 'Pobezovice', 'Pobezhovice,Pobjezhovice,Ronsperg,Ronsperk,Ronšperk,bo bie ruo wei cai,Побежовице,Побјежовице,波別若維采', 49.5102900, 12.8026100, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28988, 'Pilsen', 'Pilsen', 'P''lzen,Pilsen,Pilsna,Pilzen,Pilzenas,Pilzeń,Pilzno,Pl''zen'',Plzen,Plzena,Plzeņa,Plzeň,bi er sen,blzn,peil sen,pelaja''ina,peuljen,plzn,puruzeni,pylzn,Πίλζεν,Πίλσεν,Пилзен,Плзен,Плзењ,Пльзень,П’лзењ,פילזן,פילזען,بلزن,پلزن,पेलजाईन,เปิลเซน,პლზენი,プルゼニ,比尔森,플젠', 49.7474700, 13.3775900, 'CZ', '2014-05-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28989, 'Plumlov', 'Plumlov', 'Plumenau', 49.4661400, 17.0150200, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28990, 'Plesná', 'Plesna', 'Fleissen', 50.2207000, 12.3466900, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28991, 'Plavy', 'Plavy', '', 50.7032400, 15.3173600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28992, 'Plasy', 'Plasy', 'Plasi,Plass,pu la xi,Пласи,普拉西', 49.9344900, 13.3903500, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28993, 'Plánice', 'Planice', 'Planice,Planitz,pu la ni cai,Планице,Плањице,普拉尼采', 49.3899300, 13.4710600, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28994, 'Plaňany', 'Planany', 'Planan,Plaňan', 50.0501000, 15.0294400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28995, 'Planá nad Lužnicí', 'Plana nad Luznici', 'Plana an der Lusnitz,Planá an der Lusnitz', 49.3544400, 14.7014700, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28996, 'Planá', 'Plana', 'Plan,Plana,Plana u Marianskych Lazni,Planá u Mariánských Lázní,pu la na,Плана,普拉納', 49.8681600, 12.7437800, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28997, 'Píšť', 'Pist''', 'Sandau', 49.9785700, 18.1934900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28998, 'Písek', 'Pisek', 'Piasek,Piosek,Pisek,Писек', 49.5592400, 18.8023100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(28999, 'Písek', 'Pisek', 'Pisek,Pysekas,Písek,bysk,pi sai ke,pisekeu,piseku,pysk,Писек,Пісек,بيسك,پیسک,ピーセク,皮塞克,피세크', 49.3088000, 14.1475000, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29000, 'Písečná', 'Pisecna', 'Sandhubel,Sandhybl,Sandhübel,Sandhýbl', 50.2730300, 17.2537300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29001, 'Pilníkov', 'Pilnikov', 'Pilsdorf', 50.5324700, 15.8202000, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29002, 'Petřvald', 'Petrvald', '', 49.8310000, 18.3894000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29003, 'Petřvald', 'Petrvald', 'Gross Peterswald', 49.7087200, 18.1571900, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29004, 'Petrovice u Karviné', 'Petrovice u Karvine', 'Petrovice u Karvine,Petrovice u Karviné,Piotrowice kolo Karwiny,Piotrowice koło Karwiny', 49.8958700, 18.5477900, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29005, 'Petrovice', 'Petrovice', 'Petrowitz', 49.5542600, 14.3373700, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29006, 'Petrov', 'Petrov', '', 48.8819600, 17.2781000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29007, 'Peruc', 'Peruc', 'Perutz', 50.3425000, 13.9598600, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29008, 'Perštejn', 'Perstejn', 'Purstein,Pürstein', 50.3816600, 13.1102000, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29009, 'Pěnčín', 'Pencin', '', 50.6876900, 15.2359300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29010, 'Pelhřimov', 'Pelhrimov', 'Pilgram', 49.4313400, 15.2233600, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29011, 'Pečky', 'Pecky', 'Petschek', 50.0904300, 15.0301700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29012, 'Pecka', 'Pecka', '', 50.4803400, 15.6082200, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29013, 'Pchery', 'Pchery', 'Pcher', 50.1937800, 14.1178200, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29014, 'Pavlíkov', 'Pavlikov', 'Pavlikov,Pawlikow,Павликов', 50.0559900, 13.7363600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29015, 'Paskov', 'Paskov', 'Paskau', 49.7317900, 18.2903700, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29016, 'Paseka', 'Paseka', 'Paseha,Passek', 49.7964400, 17.2227600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29017, 'Pardubice', 'Pardubice', 'PED,Pardubice,Pardubices,Pardubicy,Pardubicės,Pardubitse,Pardubitz,Parntoumpitse,bardwbytsh,pa er du bi cai,paleudubiche,par du bit se,pardwbytsh,parudo~ubitsu~e,prdwbyzh,Παρντούμπιτσε,Пардубитсе,Пардубице,פרדוביצה,باردوبيتسه,پاردوبیتسه,پاردوبیتسے,ปาร์ดูบีตเซ,პარდუბიცე,パルドゥビツェ,帕尔杜比采,파르두비체', 50.0407500, 15.7765900, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29018, 'Palkovice', 'Palkovice', 'Palkowitz', 49.6346700, 18.3150800, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29019, 'Pacov', 'Pacov', 'Pacov,Pacova,Patzau,pa zuo fu,Пацов,帕佐夫', 49.4707600, 15.0016800, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29020, 'Otrokovice', 'Otrokovice', 'Bahnak,Bahňák,Otrokovice,Otrokovice-Kvitkovice,Otrokovice-Kvítkovice', 49.2166700, 17.5166700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29021, 'Otrokovice', 'Otrokovice', 'Kvitkovice,Kvítkovice,Otrokovice,ao te luo ke wei cai,oteulokobiche,Отроковице,奧特羅科維采,오트로코비체', 49.2093400, 17.5394400, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29022, 'Otnice', 'Otnice', 'Ottnitz', 49.0864200, 16.8144300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29023, 'Otice', 'Otice', 'Ottendorf', 49.9168400, 17.8698200, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29024, 'Otaslavice', 'Otaslavice', 'Dolni Otaslavice,Dolní Otaslavice,Unter Ottaslawitz', 49.3883300, 17.0710800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29025, 'Ostrožská Nová Ves', 'Ostrozska Nova Ves', 'Hradisch,Neudorf', 49.0043400, 17.4363200, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29026, 'Ostrožská Lhota', 'Ostrozska Lhota', '', 48.9755900, 17.4675100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29027, 'Ostrov u Macochy', 'Ostrov u Macochy', 'Ostrow', 49.3823600, 16.7626800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29028, 'Ostrov', 'Ostrov', 'Ostrov,Ostrov nad Ohri,Ostrov nad Ohří,Ostrovas,Schlackenwerth,ao si te luo fu,Остров,奧斯特羅夫', 50.3059200, 12.9390700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29029, 'Ostroměř', 'Ostromer', 'Wostromer,Wostroměr', 50.3724600, 15.5494900, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29030, 'Ostravice', 'Ostravice', 'Ostrawica,Ostrawitz,Ostrawitza', 49.5351000, 18.3916400, 'CZ', '2014-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29031, 'Ostrava', 'Ostrava', 'OSR,Ostraba,Ostrava,Ostrawa,ao si te la wa,awstrafa,e si te la fa,oseuteulaba,osutoravu~a,Οστράβα,Острава,אוסטרבה,أوسترافا,オストラヴァ,俄斯特拉發,奥斯特拉瓦,오스트라바', 49.8346500, 18.2820400, 'CZ', '2015-10-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29032, 'Ostopovice', 'Ostopovice', '', 49.1610000, 16.5454800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29033, 'Osoblaha', 'Osoblaha', 'Hotzenplotz,Osoblaga,Osoblakha,Osobloga,Osobłaga,Osobłoga,Особлага,Особлаха', 50.2751700, 17.7152300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29034, 'Oslavany', 'Oslavany', 'Oslavani,Oslawan,ao si la wa ni,Ославани,奧斯拉瓦尼', 49.1233500, 16.3365300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29035, 'Oskava', 'Oskava', 'Oskau', 49.8952300, 17.1321400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29036, 'Osík', 'Osik', '', 49.8435500, 16.2846700, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29037, 'Osek nad Bečvou', 'Osek nad Becvou', 'Osek', 49.5112100, 17.5282900, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29038, 'Osek', 'Osek', 'Osek,Ossegg,ao sai ke,Осек,奧塞克', 50.6211500, 13.6927400, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29039, 'Osek', 'Osek', 'Wosek', 49.7759400, 13.5906000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29040, 'Osečná', 'Osecna', 'Oschitz,Osechna,ao sai qi na,Осечна,奧塞奇納', 50.6948900, 14.9213800, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29041, 'Orlová', 'Orlova', 'Orlau,Orlova,Orlowa,Orłowa,ao er luo wa,arlwa,Орлова,ارلوا,奧爾洛瓦', 49.8452700, 18.4301100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29042, 'Ořechov', 'Orechov', 'Gross Urhau', 49.1111800, 16.5232900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29043, 'Opočno', 'Opocno', 'Opochno,ao bo qi nuo,Опочно,奧波奇諾', 50.2674200, 16.1148000, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29044, 'Opava', 'Opava', 'Gorad Opava,Opava,Opawa,Oppavia,Troppau,Uopawa,ao pa wa,awbafa,awpawa,opaba,opavu~a,Горад Опава,Опава,أوبافا,اوپاوا,ოპავა,オパヴァ,奥帕瓦,오파바', 49.9386600, 17.9025700, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29045, 'Opatovice nad Labem', 'Opatovice nad Labem', 'Opatovic,Opatovice', 50.1454100, 15.7904500, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29046, 'Opatov', 'Opatov', 'Abtsdorf', 49.8250000, 16.5045800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29047, 'Opařany', 'Oparany', 'Oporany,Opořany,Woporan,Wopořan', 49.3967800, 14.4813700, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29048, 'Ondřejov', 'Ondrejov', 'Ondrejow,Ondřejow', 49.9046100, 14.7842000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29049, 'Olšany', 'Olsany', '', 49.9650900, 16.8589400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29050, 'Oloví', 'Olovi', 'Bleistadt', 50.2511300, 12.5587700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29051, 'Olomouc', 'Olomouc', 'Aebura,Eburum,Gorad Olamauc,OLO,Olmic,Olmuetz,Olmütz,Olomouc,Olomouca,Olomoucas,Olomouch,Olomouts,Olomucium,Olomuniec,Ołomuniec,Wolomuc,Wołomuc,ao luo mu ke,awlwmwk,awlwmwts,ollomoucheu,olomauka,olomoutsi,oromoutsu,xxlx mots,ʼwlwmwʼwz,Όλομουτς,Горад Оламаўц,Оломоутс,Оломоуц,אולומואוץ,أولوموتس,اولوموتس,اولوموڅ,اولوموک,ओलोमौक,ออลอโมตซ์,ოლომოუცი,オロモウツ,奧洛穆克,올로모우츠', 49.5955200, 17.2517500, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29052, 'Olešnice', 'Olesnice', 'Oels,Oleshnice,Olesnice na Morave,Olešnice na Moravě,ao lai shen ni cai,Олешнице,Олешњице,奧萊什尼采', 49.5575500, 16.4216900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29053, 'Oldřišov', 'Oldrisov', 'Odersch,Oldrisov,Oldrzyszow,Oldrzyszów,Oldřišov', 49.9913000, 17.9607400, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29054, 'Olbramovice', 'Olbramovice', 'Wolframitz', 48.9848000, 16.4023900, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29055, 'Okrouhlice', 'Okrouhlice', 'Okroulitz', 49.6299100, 15.4908300, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29056, 'Okříšky', 'Okrisky', 'Okrischka,Okrischko', 49.2453900, 15.7695900, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29057, 'Ohrazenice', 'Ohrazenice', 'Wohrazenitz', 50.5976500, 15.1259600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29058, 'Odry', 'Odry', 'Odrau', 49.6625500, 17.8308400, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29059, 'Odolena Voda', 'Odolena Voda', 'Wodolka', 50.2334100, 14.4107800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29060, 'Obrnice', 'Obrnice', 'Obernitz', 50.5049800, 13.6954000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29061, 'Obecnice', 'Obecnice', 'Obecnitz', 49.7161500, 13.9473100, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29062, 'Nýrsko', 'Nyrsko', 'Neuern,Nirsko,ni er si ke,Нирско,尼爾斯科', 49.2938700, 13.1435300, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29063, 'Nýřany', 'Nyrany', 'Nurschan,Nürschan', 49.7114500, 13.2118500, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29064, 'Nymburk', 'Nymburk', 'Neuenberg,Nimburg,Nimburk,ning bu er ke,nymbwrk,Нимбурк,Նիմբուրկ,نيمبورك,寧布爾克', 50.1860500, 15.0416700, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29065, 'Nýdek', 'Nydek', '', 49.6560900, 18.7568700, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29066, 'Nový Malín', 'Novy Malin', 'Frankstadt,Frankstat,Frankštát', 49.9426200, 17.0319100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29067, 'Nový Knín', 'Novy Knin', 'Neu Knin,Novi Knin,xin ke ning,Нови Књин,新克寧', 49.7880000, 14.2935500, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29068, 'Nový Jičín', 'Novy Jicin', 'Neutitschein', 49.5943800, 18.0102800, 'CZ', '2013-12-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29069, 'Nový Hrozenkov', 'Novy Hrozenkov', 'Neu-Hrosenkau', 49.3369700, 18.1979300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29070, 'Nový Bydžov', 'Novy Bydzov', 'Neubidschow,Novi Bidzov,Novy Budzov,Novy Budžov,xin bi jiao fu,Нови Биџов,新比焦夫', 50.2415000, 15.4908200, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29071, 'Nový Bor', 'Novy Bor', 'Haida,Novi Bor,Novi-Bor,Novy Boras,xin bo er,Нови Бор,Нови-Бор,新博爾', 50.7576100, 14.5555500, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29072, 'Novosedly', 'Novosedly', 'Neusiedl', 48.8370400, 16.4927300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29073, 'Novosedlice', 'Novosedlice', 'Weisskirchlitz,Weißkirchlitz', 50.6563300, 13.8230400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29074, 'Nové Veselí', 'Nove Veseli', 'Neuwessely,xin wei sai li,新韋塞利', 49.5197600, 15.9085300, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29075, 'Nové Syrovice', 'Nove Syrovice', 'Neu Serowitz', 49.0176300, 15.7734500, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29076, 'Nové Strašecí', 'Nove Straseci', 'Neustraschitz,Nove Strasheci,Nove-Strasheci,xin si te la xie qi,Нове Страшеци,Нове-Страшеци,新斯特拉謝齊', 50.1527200, 13.9004300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29077, 'Nové Sedlo', 'Nove Sedlo', 'Neu Sattl,Neusattle', 50.2064700, 12.7380000, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29078, 'Nové Město pod Smrkem', 'Nove Mesto pod Smrkem', 'Neustadt an der Tafelfichte,Nove Mesto,Nove Mjesto pod Smrkom,Nove-Mesto-pod-Smrkem,Nové Město,si mu er ke shan lu xin cheng,Нове Мјесто под Смрком,Нове-Место-под-Смркем,斯姆爾克山麓新城', 50.9249100, 15.2294300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29079, 'Nové Město na Moravě', 'Nove Mesto na Morave', 'Neustadtl', 49.5614400, 16.0741800, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29080, 'Nové Město nad Metují', 'Nove Mesto nad Metuji', 'Neustadt an der Mettau,Nove Mestas prie Metujes,Nove Mestas prie Metujės,Nove Mjesto na Metuji,Nowe Miasto nad Metuja,Nowe Miasto nad Metują,mei tu ye he pan xin cheng,Нове Мјесто на Метуји,梅圖耶河畔新城', 50.3445600, 16.1514700, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29081, 'Nové Hrady', 'Nove Hrady', 'Gratzen,Nove Khradi,Nove-Gradi,xin he la di,Нове Хради,Нове-Гради,新赫拉迪', 48.7896300, 14.7783900, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29082, 'Nová Včelnice', 'Nova Vcelnice', 'Vcelnice,Včelnice', 49.2393500, 15.0726000, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29083, 'Nová Role', 'Nova Role', 'Neu-Rohlau', 50.2709200, 12.7842200, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29084, 'Nová Paka', 'Nova Paka', 'Neu Paka,Nova Paka,Nova-Paka,xin pa ka,Нова Пака,Нова-Пака,新帕卡', 50.4944900, 15.5150300, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29085, 'Nová Cerekev', 'Nova Cerekev', 'Neucerekwe', 49.4172300, 15.1167500, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29086, 'Nová Bystřice', 'Nova Bystrice', 'Neu-Bistritz,Nova Bistrica,Novy Bystrice,Nový Bystřice,xin bi si te ri cai,Нова Бистрица,新比斯特日采', 49.0192600, 15.1031600, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29087, 'Nosislav', 'Nosislav', 'Noslau', 49.0138000, 16.6543100, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29088, 'Nižbor', 'Nizbor', '', 49.9999500, 14.0023700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29089, 'Nivnice', 'Nivnice', '', 48.9746500, 17.6475700, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29090, 'Nezvěstice', 'Nezvestice', 'Nezbawietitz', 49.6404300, 13.5196200, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29091, 'Nezamyslice', 'Nezamyslice', 'Nezamislitz', 49.3254300, 17.1732600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29092, 'Neveklov', 'Neveklov', 'Neweklau', 49.7537300, 14.5329100, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29093, 'Netvořice', 'Netvorice', 'Networitz', 49.8156900, 14.5182700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29094, 'Netolice', 'Netolice', 'Netolice,Netolitz,Nettolitz,nei tuo li cai,Нетолице,內托利采', 49.0493000, 14.1970000, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29095, 'Nesovice', 'Nesovice', 'Nesovice,Nessowitz,Несовице', 49.1511100, 17.0809500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29096, 'Neratovice', 'Neratovice', 'Nerarovice,Neratovice,Neratowitz,nei la tuo wei cai,Нератовице,內拉托維采', 50.2592600, 14.5175900, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29097, 'Nepomuk', 'Nepomuk', 'Gorad Nepamuk,Nepomuk,Nepomukas,nei bo mu ke,nepomukeu,Горад Непамук,Непомук,内波穆克,네포무크', 49.4861600, 13.5822500, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29098, 'Němčice nad Hanou', 'Nemcice nad Hanou', 'Nemcice na Hane,Němčice na Hané', 49.3418100, 17.2059600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29099, 'Nelahozeves', 'Nelahozeves', 'Muhlhausen,Mühlhausen,Nelachozeves,Nelagozeves,Nelakhozeves,Νελαχόζεβες,Нелагозевес,Нелахозевес', 50.2614800, 14.2988100, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29100, 'Nejdek', 'Nejdek', 'Nejdek,Neudek in Boehmen,Neudek in Böhmen,nei dai ke,Нейдек,Нејдек,內代克', 50.3224200, 12.7293600, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29101, 'Nehvizdy', 'Nehvizdy', 'Gross Nehwist,Gross-Nehwizd', 50.1305600, 14.7299300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29102, 'Nedvědice', 'Nedvedice', 'Nedweditz,Nedwěditz', 49.4570200, 16.3340600, 'CZ', '2014-05-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29103, 'Nedašov', 'Nedasov', '', 49.1077800, 18.0703600, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29104, 'Nedakonice', 'Nedakonice', 'Nedakonitz', 49.0315900, 17.3814100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29105, 'Nechanice', 'Nechanice', 'Nechanices,Nechanicės,Nechanitz,Nekhanice,nei ha ni cai,Нехањице,內哈尼采', 50.2373700, 15.6327600, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29106, 'Návsí u Jablunkova', 'Navsi u Jablunkova', 'Navsi,Nawsie,Nawsy,Návsí', 49.5872000, 18.7590700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29107, 'Nasavrky', 'Nasavrky', 'Nassaberg', 49.8445000, 15.8046100, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29108, 'Napajedla', 'Napajedla', 'Napajedl,Napajedla,na pa ye de la,Напаједла,納帕耶德拉', 49.1715600, 17.5119400, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29109, 'Náměšť na Hané', 'Namest'' na Hane', 'Namiescht', 49.6021300, 17.0653900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29110, 'Náměšť nad Oslavou', 'Namest'' nad Oslavou', 'Namiest', 49.2072600, 16.1584900, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29111, 'Náklo', 'Naklo', '', 49.6546200, 17.1296900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29112, 'Náchod', 'Nachod', '', 50.4167000, 16.1628900, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29113, 'Načeradec', 'Naceradec', 'Naceradetz,Načeradetz', 49.6101800, 14.9063300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29114, 'Mýto', 'Myto', 'Mauth', 49.7890400, 13.7346100, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29115, 'Mutěnice', 'Mutenice', 'Mutienitz', 48.9041300, 17.0291700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29116, 'Mukařov', 'Mukarov', 'Mukarschow', 49.9911500, 14.7415500, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29117, 'Mšeno', 'Mseno', 'Mscheno', 50.4380900, 14.6325000, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29118, 'Mrákov', 'Mrakov', '', 49.4031400, 12.9512000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29119, 'Moutnice', 'Moutnice', '', 49.0492400, 16.7374100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29120, 'Mosty u Jablunkova', 'Mosty u Jablunkova', 'Mosty', 49.5273700, 18.7541700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29121, 'Mostkovice', 'Mostkovice', '', 49.4721500, 17.0521200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29122, 'Mostek', 'Mostek', 'Mastig', 50.4862300, 15.6962200, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29123, 'Most', 'Most', 'Bruex,Brüx,Most,Мост', 50.5030100, 13.6361700, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29124, 'Mořkov', 'Morkov', 'Murk', 49.5368400, 18.0596800, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29125, 'Moravský Žižkov', 'Moravsky Zizkov', '', 48.8328500, 16.9314000, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29126, 'Moravský Písek', 'Moravsky Pisek', '', 48.9901600, 17.3326900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29127, 'Moravský Krumlov', 'Moravsky Krumlov', 'Mahrisch Kromau,Moravski Krumlov,Moravski Krumlova,Moravski-Krumlov,Mährisch Kromau,Моравски Крумлов,Моравски-Крумлов', 49.0489300, 16.3116900, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29128, 'Moravský Beroun', 'Moravsky Beroun', 'Barn,Beroun,Bärn,Moravski Beroun,Moravski Berouna,mo la wa bei long,Моравски Бероун,摩拉瓦貝龍', 49.7937400, 17.4421200, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29129, 'Moravské Budějovice', 'Moravske Budejovice', 'Mahrisch-Budwitz,Moravske Budejovice,Moravske Budjejovice,Moravske-Budejovice,Morawskie Budziejowice,Mährisch-Budwitz,mo la wa bu jie yue wei cai,molapeuseukebudeyobiche,Моравске Будјејовице,Моравске-Будеёвице,摩拉瓦布傑約維采,모라프스케부데요비체', 49.0520900, 15.8086400, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29130, 'Moravská Třebová', 'Moravska Trebova', 'Gorad Morauska-Trshehbava,Mahrisch Trubau,Moravska Trebova,Moravska Trsebova,Moravska Tršebova,Moravska-Trshebova,Mährisch Trübau,mo la wa te re bo wa,Горад Мораўска-Тршэбава,Моравска Требова,Моравска-Тршебова,摩拉瓦特熱博瓦', 49.7579300, 16.6642600, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29131, 'Moravská Nová Ves', 'Moravska Nova Ves', '', 48.8030400, 17.0137100, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29132, 'Morávka', 'Moravka', 'Morawka', 49.5960700, 18.5247100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29133, 'Moravičany', 'Moravicany', 'Morawiczan', 49.7569400, 16.9604200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29134, 'Moravany', 'Moravany', 'Morawan', 50.0009500, 15.9407100, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29135, 'Moravany', 'Moravany', 'Morbes', 49.1478000, 16.5802600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29136, 'Mokré Lazce', 'Mokre Lazce', '', 49.9046200, 18.0295400, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29137, 'Mokrá Hora', 'Mokra Hora', '', 49.2617600, 16.5910700, 'CZ', '2014-05-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29138, 'Mohelno', 'Mohelno', '', 49.1141200, 16.1902200, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29139, 'Mohelnice', 'Mohelnice', 'Mokhelnice,Muglitz,Müglitz,mo hai er ni cai,Мохелњице,莫海爾尼采', 49.7769800, 16.9194600, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29140, 'Modřice', 'Modrice', 'Modrice,Modritz,Modrzice,Modržice,Mödritz,mo de ri cai,Модрице,莫德日采', 49.1192800, 16.6044600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29141, 'Modřany', 'Modrany', 'Modran,Modrzhany,Modřan,Модржаны', 50.0111600, 14.4096000, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29142, 'Mníšek pod Brdy', 'Mnisek pod Brdy', 'Mnischek,Mnisek,Mnishek pod Brdom,Mnishek-pod-Brdi,Мнишек-под-Брди,Мњишек под Брдом', 49.8665000, 14.2617600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29143, 'Mníšek', 'Mnisek', 'Einsiedel,Mnisk', 50.8316300, 15.0563000, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29144, 'Mnichovo Hradiště', 'Mnichovo Hradiste', 'Mnichovo Hradiste,Mnichovo Hradištė,Mnichovo Hradiště,Mnikhovo Gradishte,Mnikhovo Khradishte,Mnikhovo-Gradishte,Muenchengraetz,Münchengrätz,mu ni hei cheng bao,Мнихово Градиште,Мнихово-Градиште,Мњихово Храдиште,ムニホヴォ・フラジシチェ,慕尼黑城堡', 50.5272000, 14.9713400, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29145, 'Mnichovice', 'Mnichovice', 'Mnichowitz', 49.9360100, 14.7090700, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29146, 'Mladé Buky', 'Mlade Buky', 'Jungbuch', 50.6064300, 15.8334800, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29147, 'Mladá Vožice', 'Mlada Vozice', 'Jungwoschitz,Male Vozice,Malé Vožice', 49.5331300, 14.8085700, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29148, 'Mladá Boleslav', 'Mlada Boleslav', 'Jungbunzlau,Mlada Boleslav,Mlada Boleslaz,Mlada-Boleslav,Mladá Boleslav,Млада-Болеслав', 50.4113500, 14.9031800, 'CZ', '2016-09-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29149, 'Mistřice', 'Mistrice', 'Mistritz', 49.0866800, 17.5359700, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29150, 'Mirovice', 'Mirovice', 'Mirovice,Mirowitz,mi luo wei cai,Мировице,米羅維采', 49.5155500, 14.0358200, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29151, 'Mirotice', 'Mirotice', 'Mirotice,Mirotitz,mi luo ji cai,Миротице,米羅季采', 49.4290800, 14.0369700, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29152, 'Mirošov', 'Mirosov', 'Miroschau,Miröschau', 49.6878200, 13.6580700, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29153, 'Miroslav', 'Miroslav', 'Misslitz', 48.9476700, 16.3125200, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29154, 'Miřetice', 'Miretice', '', 49.8412600, 15.8847200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29155, 'Mimoň', 'Mimon', 'Mimon,Mimon'',Mimonjecy,Niemes,mi meng,Мимонь,Мимоњ,Мімонь,米蒙', 50.6586900, 14.7247400, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29156, 'Milovice', 'Milovice', 'Milowitz', 50.2259600, 14.8886300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29157, 'Milotice', 'Milotice', '', 48.9552800, 17.1424100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29158, 'Milín', 'Milin', '', 49.6319200, 14.0460000, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29159, 'Milíkov', 'Milikov', '', 49.5856500, 18.7194300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29160, 'Milevsko', 'Milevsko', 'Milevsko,Muhlhausen,Mühlhausen,mi lai fu si ke,Милевско,米萊夫斯科', 49.4508900, 14.3600000, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29161, 'Mikulovice', 'Mikulovice', 'Niklasdorf', 50.2985400, 17.3215500, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29162, 'Mikulov', 'Mikulov', 'Mekoluovs,Mikulov,Mikulova,Míkulov,Mėkoluovs,Nickolsburg,Nikolov,Nikolsburg,mi ku luo fu,mikurofu,myqwlwb,Микулов,Мікулов,מיקולוב,ניקאלשבורג,ミクロフ,米庫洛夫', 48.8055600, 16.6378000, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29163, 'Mikulčice', 'Mikulcice', '', 48.8164300, 17.0510700, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29164, 'Mikulášovice', 'Mikulasovice', 'Nixdorf', 50.9650700, 14.3636800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29165, 'Meziměstí', 'Mezimesti', 'Halbstadt,Mesimesti,Mesiměstí,Mezimjesti,mei ji mei si ji,Мезимјести,梅濟梅斯季', 50.6246100, 16.2420700, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29166, 'Meziboři', 'Mezibori', 'Schonbach,Schönbach', 50.6211500, 13.5987000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29167, 'Metylovice', 'Metylovice', '', 49.6066600, 18.3391100, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29168, 'Město Touškov', 'Mesto Touskov', 'Mesto-Toushkov,Mjesto Toushkov,Touskov,Touškov,Tuschkau Stadt,tuo wu shen ke fu cheng,Место-Тоушков,Мјесто Тоушков,托烏什科夫城', 49.7758700, 13.2510800, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29169, 'Město Libavá', 'Mesto Libava', 'Libava,Libavá,Stadt Liebau', 49.7216200, 17.5201300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29170, 'Město Albrechtice', 'Mesto Albrechtice', 'Albrechtice,Olbersdorf,Olbersdorf Stadt,Olbrachcice', 50.1629400, 17.5748100, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29171, 'Město', 'Mesto', 'Meste Tepla,Mesto,Měste Teplá,Město,Tepl,Tepl Stadt,Tepla,Teplá', 49.9799700, 12.8643200, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29172, 'Městec Králové', 'Mestec Kralove', 'Konigstadtl,Königstadtl,Mjestec Kralove,Мјестец Кралове', 50.2071800, 15.2975800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29173, 'Městečko Trnávka', 'Mestecko Trnavka', 'Markt Turnau,Markt Türnau,Trnavka,Trnávka,Turnau,Türnau', 49.7092600, 16.7274400, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29174, 'Měšice', 'Mesice', '', 50.1979900, 14.5199200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29175, 'Merklín', 'Merklin', 'Merkelsgrun,Merkelsgrün,Merklin u Karlovych Var,Merklín u Karlových Var', 50.3280800, 12.8635000, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29176, 'Merklín', 'Merklin', '', 49.5604300, 13.1979000, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29177, 'Měřín', 'Merin', 'Wollein', 49.3932100, 15.8838100, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29178, 'Měnín', 'Menin', 'Monitz,Mönitz', 49.0824000, 16.6942400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29179, 'Mělník', 'Melnik', 'Mel''nik,Melnik,Mělník,mlnyk,Мельник,ملنیک', 50.3505000, 14.4741100, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29180, 'Medlov', 'Medlov', 'Meedl', 49.7875400, 17.0626100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29181, 'Meclov', 'Meclov', 'Metzling', 49.5055600, 12.8808200, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29182, 'Měčín', 'Mecin', '', 49.4800900, 13.4028900, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29183, 'Měcholupy', 'Mecholupy', 'Michelob', 50.2666600, 13.5373700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29184, 'Markvartovice', 'Markvartovice', 'Markersdorf', 49.9059500, 18.2360200, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29185, 'Mariánské Lázně', 'Marianske Lazne', 'MKA,Marians''ki Lazni,Marianske Lazne,Marianske Laznes,Marianske Laznės,Marianske-Lazne,Marianskie Laznie,Mariańskie Łaźnie,Marienbad,Marijanske Lazne,Mariánské Lázně,Mariënbad,ma li ya wen quan shi,malianseukelajeune,mryʼnsqh lʼznyyh,Марианске-Лазне,Маријанске Лазње,Маріанські Лазні,Մարիանսկե Լազնե,מריאנסקה לאזנייה,マリアーンスケー・ラーズニェ,玛丽亚温泉市,마리안스케라즈네', 49.9645900, 12.7011800, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29186, 'Manětín', 'Manetin', 'Manetin,ma nie ting,Манетин,Мањетин,馬涅廷', 49.9917700, 13.2331900, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29187, 'Malšice', 'Malsice', 'Malschitz', 49.3639100, 14.5786800, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29188, 'Malonty', 'Malonty', 'Meinetschlag', 48.6861100, 14.5767800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29189, 'Malé Svatoňovice', 'Male Svatonovice', 'Klein Schwadowitz', 50.5339500, 16.0497800, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29190, 'Malá Strana', 'Mala Strana', 'Kisoldal,Mala Strana,Mala-Strana,Malgranda Kvartalo,Malá Strana,Prager Kleinseite,bu la ge xiao cheng,Μάλα Στράνα,Мала Страна,Мала-Страна,マラー・ストラナ,布拉格小城', 50.0877400, 14.4044900, 'CZ', '2014-09-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29191, 'Malá Skála', 'Mala Skala', '', 50.6463100, 15.1954300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29192, 'Majetín', 'Majetin', '', 49.4980800, 17.3331400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29193, 'Machov', 'Machov', 'Machau', 50.4992700, 16.2769000, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29194, 'Lysice', 'Lysice', 'Lisice,Lissitz,Лисице', 49.4516000, 16.5371600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29195, 'Lysá nad Labem', 'Lysa nad Labem', 'Lisa na Labi,Lisa-nad-Labem,Lissa an der Elbe,la bei he pan li sa,Лиса на Лаби,Лиса-над-Лабем,拉貝河畔利薩', 50.2014300, 14.8328100, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29196, 'Lužná', 'Luzna', '', 50.1237700, 13.7700400, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29197, 'Lužice', 'Luzice', '', 48.8409800, 17.0710400, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29198, 'Lužec nad Vltavou', 'Luzec nad Vltavou', 'Luzec', 50.3213800, 14.4002200, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29199, 'Luže', 'Luze', '', 49.8934100, 16.0285000, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29200, 'Lutín', 'Lutin', 'Luttein', 49.5584500, 17.1357200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29201, 'Luštěnice', 'Lustenice', 'Luschtenitz,Luschtěnitz', 50.3229600, 14.9366700, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29202, 'Lukov', 'Lukov', '', 49.2902700, 17.7295900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29203, 'Lukavice', 'Lukavice', '', 50.0602900, 16.4820700, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29204, 'Lukavec', 'Lukavec', 'Lukawetz', 49.5654100, 14.9904100, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29205, 'Luka nad Jihlavou', 'Luka nad Jihlavou', 'Wiese', 49.3740300, 15.7019400, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29206, 'Luhačovice', 'Luhacovice', 'Lugachovice,Luhatschowitz,Lukhachovice,lu ha qiao wei cai,Лугачовице,Лухачовице,盧哈喬維采', 49.0998200, 17.7574700, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29207, 'Ludgeřovice', 'Ludgerovice', 'Ludgerstal', 49.8904200, 18.2400800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29208, 'Lučany nad Nisou', 'Lucany nad Nisou', 'Lucany,Lučany,Wiesenthal,Wiesenthal an der Neisse', 50.7413600, 15.2204600, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29209, 'Luby', 'Luby', 'Lubi,Schoenbach,Schonbach,Schönbach,lu bi,Луби,盧比', 50.2524800, 12.4059500, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29210, 'Lubenec', 'Lubenec', 'Lubenz', 50.1320700, 13.3131900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29211, 'Lovosice', 'Lovosice', 'Lavosice,Lobositz,Lovosice,luo wo xi cai,rovu~oshitsu~e,Ловосице,ロヴォシツェ,洛沃西采', 50.5150400, 14.0510300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29212, 'Louny', 'Louny', 'Laun,Louni,Louny,luo wu ni,lwny,Лоуни,لوني,洛烏尼', 50.3569900, 13.7966700, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29213, 'Louka', 'Louka', '', 48.9151700, 17.4892700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29214, 'Loučovice', 'Loucovice', 'Bolechy,Wullachen', 48.6201900, 14.2574700, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29215, 'Loučovice', 'Loucovice', 'Kienberg,Loucovice,Loučovice', 48.6209000, 14.2497600, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29216, 'Loučná nad Desnou', 'Loucna nad Desnou', 'Vizmberk,Vízmberk,Wiesenberg', 50.0743300, 17.0905200, 'CZ', '2012-12-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29217, 'Loučeň', 'Loucen', 'Lautschin', 50.2853700, 15.0204900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29218, 'Loštice', 'Lostice', 'Loschitz', 49.7447000, 16.9289200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29219, 'Lom u Mostu', 'Lom u Mostu', 'Bruch,Lom', 50.5932800, 13.6572900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29220, 'Lomnice nad Popelkou', 'Lomnice nad Popelkou', 'Lomnice,Lomnitz an der Popelka', 50.5306200, 15.3734100, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29221, 'Lomnice nad Lužnicí', 'Lomnice nad Luznici', 'Lomnice na Luznici,Lomnice na Lužnicí,Lomnitz', 49.0846800, 14.7172700, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29222, 'Lomnice', 'Lomnice', 'Lanz', 50.2117400, 12.6326700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29223, 'Lomnice', 'Lomnice', 'Lomnice,Lomnice u Tisnova,Lomnice u Tišnova,Lomnitz,Ломњице', 49.4046200, 16.4135900, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29224, 'Loket', 'Loket', 'Elbogen,Loket,luo ke te,Локет,洛克特', 50.1860000, 12.7540500, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29225, 'Loděnice', 'Lodenice', 'Lodenitz', 49.9948600, 14.1578500, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29226, 'Lochovice', 'Lochovice', 'Lochowitz', 49.8531800, 13.9812600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29227, 'Litvínovice', 'Litvinovice', 'Leitowitz', 48.9620700, 14.4514600, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29228, 'Litvínov', 'Litvinov', 'Litvinov,Litvynovas,Litvínov,Oberleutensdorf,li te wei nuo fu,lytwynw,Литвинов,لیتوینو,利特威諾夫', 50.6042000, 13.6181200, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29229, 'Litovel', 'Litovel', 'Litovel,Litovela,Littau,li tuo wei er,Литовел,利托韋爾', 49.7012100, 17.0761500, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29230, 'Litomyšl', 'Litomysl', 'Leitomischl,Litomishl'',Litomisl,Litomisla,Litomislas,Litomišl,Litomišla,Litomišlas,Litomyshl'',Litomysl,Litomyšl,li tuo mi shen er,litomisyul,lytwmyshl,ritomishuru,Литомишль,Литомышль,لیتومیشل,ლიტომიშლი,リトミシュル,利托米什爾,리토미슐', 49.8680900, 16.3129800, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29231, 'Litoměřice', 'Litomerice', 'Gorad Litamerzhycy,Leitmeritz,Litomerice,Litomericium,Litomerzhice,Litomerzices,Litomeržicės,Litomierzyce,Litomjerzhice,Litoměřice,li tuo mei ri cai,litomeleujiche,lytwmyrytsh,ritomunyejitsu~e,Горад Літамержыцы,Литомержице,Литомјержице,Літомержіце,ليتوميريتسه,لیتمیه‌رژیتسه,リトムニェジツェ,利托梅日采,리토메르지체', 50.5334800, 14.1318000, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29232, 'Lišov', 'Lisov', 'Lischau,Lishov,li shao fu,Лишов,利紹夫', 49.0159700, 14.6083800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29233, 'Lipůvka', 'Lipuvka', 'Lipuwka', 49.3393300, 16.5531300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29234, 'Liptál', 'Liptal', 'Lipove,Lipové,Lipthal', 49.2905100, 17.9217700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29235, 'Lipovec', 'Lipovec', 'Lipowetz', 49.3839400, 16.8058300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29236, 'Lipov', 'Lipov', '', 48.9049500, 17.4617100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29237, 'Lipník nad Bečvou', 'Lipnik nad Becvou', 'Lipnik,Lipnik na Bechvi,Lipnik-nad-Bechvou,Lipnika pie Becvas,Lipník,Lipnīka pie Bečvas,bei qi wa he pan li pu ni ke,Липник-над-Бечвоу,Липњик на Бечви,ליפניק על הבצווה,貝奇瓦河畔利普尼克', 49.5272100, 17.5859400, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29238, 'Lípa', 'Lipa', '', 49.5541800, 15.5446500, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29239, 'Líně', 'Line', 'Lihn', 49.6947200, 13.2569300, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29240, 'Lidečko', 'Lidecko', 'Lidetschko', 49.2030300, 18.0513000, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29241, 'Lichnov', 'Lichnov', 'Lichnow,Lichnów,Lichten', 50.0078600, 17.6264000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29242, 'Lichnov (o. Nový Jičín)', 'Lichnov (o. Novy Jicin)', 'Lichnau', 49.5642300, 18.1689800, 'CZ', '2016-09-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29243, 'Libušín', 'Libusin', 'Libuschin', 50.1681900, 14.0545800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29244, 'Libouchec', 'Libouchec', 'Konigswald,Königswald', 50.7585400, 14.0407100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29245, 'Libochovice', 'Libochovice', 'Libochowitz,Libokhovice,li bo huo wei cai,Либоховице,利博霍維采', 50.4062600, 14.0443900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29246, 'Libiš', 'Libis', 'Libisch', 50.2741700, 14.5024000, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29247, 'Libice nad Cidlinou', 'Libice nad Cidlinou', 'Libice,Libice Cidlinou,Libice na Cidlini,Libice prie Cidlinos,Libice-nad-Cidlinou,Libicė prie Cidlinos,Libitz,qi de li na he pan li bi cai,Либице на Цидлини,Либице-над-Цидлиноу,齊德利納河畔利比采', 50.1267700, 15.1782000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29248, 'Líbeznice', 'Libeznice', 'Libeznitz', 50.1919800, 14.4935700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29249, 'Liběšice', 'Libesice', 'Libeschitz', 50.5688600, 14.2890600, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29250, 'Liberec', 'Liberec', 'Gorad Liberac,Liberec,Liberec'',Libereca,Liberecas,Liberets,Limperets,Reichenberg,Reichenberga,li bei lei ci,libelecheu,liberetsi,lybrts,lybrz,lybyryts,riberetsu,Λίμπερετς,Горад Ліберац,Либеретс,Либерец,Ліберець,Լիբերեց,ליברץ,ليبيريتس,لیبرتس,ლიბერეცი,リベレツ,利贝雷茨,리베레츠', 50.7671100, 15.0561900, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29251, 'Libeň', 'Liben', '', 50.1081900, 14.4745700, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29252, 'Libčice nad Vltavou', 'Libcice nad Vltavou', 'Libschitz,Libsice,Libšice', 50.1977800, 14.3638500, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29253, 'Libáň', 'Liban', '', 50.3754200, 15.2168400, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29254, 'Lhenice', 'Lhenice', 'Elhenitz', 48.9947900, 14.1498000, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29255, 'Letovice', 'Letovice', 'Letovice,Lettowitz,lai tuo wei cai,Летовице,萊托維采', 49.5470900, 16.5735700, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29256, 'Letonice', 'Letonice', 'Letonitz', 49.1772600, 16.9591300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29257, 'Letohrad', 'Letohrad', 'Geiersberg,Kysperk,Kyšperk,Supi Hora,Supí Hora', 50.0358000, 16.4987900, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29258, 'Letňany', 'Letnany', 'Letnan,Letňan', 50.1333300, 14.5166700, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29259, 'Leština', 'Lestina', 'Lesche', 49.8687900, 16.9274800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29260, 'Lešná', 'Lesna', 'Leshna,Lesne,Lešne,Loschna,Löschna,Лешна', 49.5205500, 17.9300400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29261, 'Lenešice', 'Lenesice', 'Leneschitz', 50.3751600, 13.7659000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29262, 'Lelekovice', 'Lelekovice', 'Lelekowitz', 49.2914400, 16.5787400, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29263, 'Lednice', 'Lednice', 'Eisgrub,Lednece,Lednice,Lednicy,Lednicė,Lednėcē,lai de ni cai,ledeuniche,Леднице,Ледніцы,Ледњице,萊德尼采,레드니체', 48.7999200, 16.8033900, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29264, 'Ledenice', 'Ledenice', '', 48.9332900, 14.6188600, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29265, 'Ledeč nad Sázavou', 'Ledec nad Sazavou', 'Ledec,Ledec na Sazave,Ledeca pie Sazavas,Ledech na Sazavi,Ledeč,Ledeč na Sazavé,Ledeča pie Sāzavas,sa zha wa he pan lai dai qi,Ледеч на Сазави,薩扎瓦河畔萊代奇', 49.6951700, 15.2777200, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29266, 'Lázně Kynžvart', 'Lazne Kynzvart', 'Bad Konigswart,Bad Königswart,Lazne Kinzhvart,Lazne-Kinzhvart,jin ri wa te kuang quan zhen,Лазне-Кинжварт,Лазне-Кінжварт,Лазње Кинжварт,金日瓦特礦泉鎮', 50.0105800, 12.6247400, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29267, 'Lázně Bělohrad', 'Lazne Belohrad', 'Bad Belohrad', 50.4287400, 15.5826900, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29268, 'Lanžhot', 'Lanzhot', 'Landshut', 48.7244300, 16.9669500, 'CZ', '2013-01-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29269, 'Lány', 'Lany', 'Lana', 50.1247100, 13.9504100, 'CZ', '2017-02-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29270, 'Lanškroun', 'Lanskroun', 'Landskron,Lanshkroun,Lanskrouna,Lanškrouna,lan shen ke long,Ланшкроун,蘭什克龍', 49.9121700, 16.6119000, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29271, 'Kynšperk nad Ohří', 'Kynsperk nad Ohri', 'Kinshperk na Okhri,Kinshperk-nad-Ogrzhi,Konigsberg,Konigsberg an der Eger,Kynsperk,Königsberg,Königsberg an der Eger,ao he re he pan jin shen pei er ke,Киншперк на Охри,Киншперк-над-Огржи,奧赫熱河畔金什佩爾克', 50.1189300, 12.5302700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29272, 'Kyjov', 'Kyjov', 'Gaya,Kijov,Kijova,ji yue fu,Кийов,Кијов,基約夫', 49.0101800, 17.1225300, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29273, 'Kvasiny', 'Kvasiny', 'Kwasnei', 50.2125000, 16.2632300, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29274, 'Kvasice', 'Kvasice', 'Kwassitz', 49.2422300, 17.4697400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29275, 'Kutná Hora', 'Kutna Hora', 'Gorad Kutna-Gora,Kutna Gora,Kutna Hora,Kutna Khora,Kutna-Gora,Kutná Hora,Kuttenberg,ku te na huo la,kuteunahola,kwtna hra,kwtna hwra,qwtnh hwrh,Горад Кутна-Гора,Кутна Гора,Кутна Хора,Кутна-Гора,Куттенберг,קוטנה הורה,كوتنا هورا,کوتنا هرا,კუტნა-ჰორა,クトナー・ホラ,库特纳霍拉,쿠트나호라', 49.9483900, 15.2681600, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29276, 'Kuřim', 'Kurim', 'Gurein,Kurzhim,Kurzima,Kuržima,ku ri mu,Куржим,庫日姆', 49.2985200, 16.5314400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29277, 'Kunžak', 'Kunzak', 'Konigseck,Königseck', 49.1211900, 15.1902800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29278, 'Kunvald', 'Kunvald', 'Kunwald', 50.1292700, 16.4999600, 'CZ', '2012-11-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29279, 'Kunštát', 'Kunstat', 'Kunshhat,Kunshtat,Kunstadt,Kunstata,Kunštāta,kun shen ta te,Кунштат,Кунщат,昆什塔特', 49.5064500, 16.5172200, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29280, 'Kunovice', 'Kunovice', 'Kunovice,Kunowitz,ku nuo wei cai,Куновице,庫諾維采', 49.0449900, 17.4701100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29281, 'Kunín', 'Kunin', 'Kunewald,Kunvald', 49.6337700, 17.9896500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29282, 'Kunčina', 'Kuncina', 'Kunzendorf', 49.7945500, 16.6276300, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29283, 'Kunčice pod Ondřejníkem', 'Kuncice pod Ondrejnikem', 'Kuntschitz', 49.5507000, 18.2611300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29284, 'Kryry', 'Kryry', 'Kriegern', 50.1743700, 13.4266000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29285, 'Krupka', 'Krupka', 'Gorad Krupka,Graupen,Krupka,ke lu pu ka,Горад Крупка,Крупка,克魯普卡', 50.6844900, 13.8581500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29286, 'Krumvíř', 'Krumvir', '', 48.9890100, 16.9102700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29287, 'Krouna', 'Krouna', 'Krauna', 49.7724000, 16.0267400, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29288, 'Kroměříž', 'Kromeriz', 'Kremsier,Kromeriz,Kromerzhizh,Kromerziza,Kromerzyzas,Kromeržyžas,Kromeržīža,Kromieryz,Kromieryż,Kromjerzhizh,Kromnerzhizh,Kroměříž,ke luo mei ri shen,keulomeleujisi,krwmyshrysh,Кромержиж,Кромнержиж,Кромјержиж,كروميشريش,کرمیه‌رژیژ,克罗梅日什,크로메르지시', 49.2978500, 17.3931200, 'CZ', '2015-11-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29289, 'Krnov', 'Krnov', 'Jaegerndorf,Jägerndorf,Karniow,Karniów,Karnuw,Karníow,Karńůw,Krnov,Krnova,Krnovas,Kurnov,ke er nuo fu,keuleunopeu,krnw,Крнов,Кърнов,کرنو,克爾諾夫,크르노프', 50.0896700, 17.7038500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29290, 'Krmelín', 'Krmelin', '', 49.7291400, 18.2354100, 'CZ', '2014-06-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29291, 'Křížová', 'Krizova', 'Kreuzberg,Krucemburk', 49.6884100, 15.8520700, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29292, 'Křižanov', 'Krizanov', 'Krizanau,Křižanau', 49.3885800, 16.1096000, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29293, 'Křinec', 'Krinec', 'Krinec,Krinetz,Křinetz,Кринец', 50.2644900, 15.1378200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29294, 'Křešice', 'Kresice', 'Krzeschitz', 50.5225900, 14.2145000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29295, 'Křepice', 'Krepice', '', 48.9998600, 16.7198900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29296, 'Křenovice', 'Krenovice', 'Krenowitz', 49.1421600, 16.8293200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29297, 'Křemže', 'Kremze', 'Krems', 48.9049700, 14.3056800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29298, 'Kravaře', 'Kravare', 'Deutsch,Krawarn', 49.9320300, 18.0047200, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29299, 'Krásná Lípa', 'Krasna Lipa', 'Krasna Lipa,Krasna-Lipa,Schonlind,Schonlinde,Schönlind,Schönlinde,Красна Липа,Красна-Липа', 50.9130300, 14.5099900, 'CZ', '2012-11-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29300, 'Krásná Lípa', 'Krasna Lipa', 'Krasna Lipa,Krásná Lípa,Schonlind,Schönlind', 50.4837800, 13.3575000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29301, 'Krásná Hora nad Vltavou', 'Krasna Hora nad Vltavou', 'Krasna Hora,Krásná Hora,Schonberg,Schönberg', 49.6046100, 14.2774200, 'CZ', '2017-02-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29302, 'Kraslice', 'Kraslice', 'Graslitz,Kraslice,ke la si li cai,Краслице,克拉斯利采', 50.3237200, 12.5174700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29303, 'Králův Dvůr', 'Kraluv Dvur', 'Konigshof,Kraluv Dvur,Kraluv-Dvur,Králův Dvůr,Königshof,wang gong cun,Кралув Двур,Кралув-Двур,王宮村', 49.9498100, 14.0344500, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29304, 'Kralupy nad Vltavou', 'Kralupy nad Vltavou', 'Kralup,Kralupi,Kralupi na Vltavi,Kralupi-na-Vltavi,Kralupi-nad-Vltavou,Kralupy,Kralupy nad Weltawa,Kralupy nad Wełtawą,keulallupinateubeultabou,Кралупи,Кралупи на Влтави,Кралупи-на-Влтаві,Кралупи-над-Влтавоу,크랄루피나트블타보우', 50.2410700, 14.3114900, 'CZ', '2015-03-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29305, 'Kralovice', 'Kralovice', 'Kralovice,Kralowitz,Královice,ke la luo wei cai,Краловице,克拉洛維采', 49.9819200, 13.4874700, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29306, 'Králíky', 'Kraliky', 'Grulich,Kraliki,Krālīki,ke la li ji,Кралики,克拉利基', 50.0838400, 16.7605400, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29307, 'Kralice na Hané', 'Kralice na Hane', 'Kralice,Kralitz', 49.4629600, 17.1804800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29308, 'Kozmice', 'Kozmice', 'Kosmutz,Kosmütz', 49.9128000, 18.1558400, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29309, 'Kozlovice', 'Kozlovice', 'Koslowitz', 49.5904000, 18.2565600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29310, 'Kožlany', 'Kozlany', 'Kozhlani,Kozlan,ke ri la ni,Кожлани,科日拉尼', 49.9938900, 13.5410700, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29311, 'Kovářská', 'Kovarska', 'Schmiedeberg,Smideberk,Šmídeberk', 50.4382100, 13.0538800, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29312, 'Kovářov', 'Kovarov', 'Kowarow,Kowářow', 49.5176000, 14.2780900, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29313, 'Kout na Šumavě', 'Kout na Sumave', 'Kauth', 49.4025500, 13.0020800, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29314, 'Kouřim', 'Kourim', 'Kaurim,Kauřim', 50.0030600, 14.9770300, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29315, 'Kostice', 'Kostice', '', 48.7468500, 16.9786900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29316, 'Kostelec na Hané', 'Kostelec na Hane', 'Kostelec,Kosteletz', 49.5139800, 17.0582400, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29317, 'Kostelec nad Orlicí', 'Kostelec nad Orlici', 'Adler-Kosteletz,Kostelec na Orlici,Kostelec-nad-Orlici,Podnebi Kostelec nad Orlici,Podnebí Kostelec nad Orlicí,ao er li cai he pan ke si tai lai ci,Костелец на Орлици,Костелец-над-Орлици,奧爾利采河畔科斯泰萊茨', 50.1226700, 16.2131900, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29318, 'Kostelec nad Labem', 'Kostelec nad Labem', 'Elbe Kosteletz', 50.2265300, 14.5855200, 'CZ', '2017-02-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29319, 'Kostelec nad Černými Lesy', 'Kostelec nad Cernymi Lesy', 'Schwarzkosteletz', 49.9940300, 14.8592200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29320, 'Košťany', 'Kost''any', 'Kosten', 50.6550700, 13.7555400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29321, 'Košťálov', 'Kost''alov', '', 50.5716500, 15.4040300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29322, 'Kosova Hora', 'Kosova Hora', 'Amschelberg', 49.6541400, 14.4717300, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29323, 'Kosmonosy', 'Kosmonosy', 'Kosmanos,Kosmonosi,ke si mo nuo xi,Космоноси,科斯莫諾西', 50.4385000, 14.9300000, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29324, 'Koryčany', 'Korycany', 'Koricani,Korichani,Koritschan,Koričani,ke ri qia ni,Коричани,科日恰尼', 49.1063900, 17.1643300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29325, 'Kořenov', 'Korenov', 'Wurzelsdorf', 50.7592600, 15.3653200, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29326, 'Kopřivnice', 'Koprivnice', 'Koprivnice,Koprshivnicakh,Koprshivnice,Koprsivnice,Koprsivnices,Koprzhivnice,Kopršivnice,Kopršivnicės,Nesselsdorf,ke pu ri fu ni cai,kopeuleujibeuniche,kprzhywnytsh,Копрживніце,Копривњице,Копршивницах,Копршивнице,کپرژیونیتسه,科普日夫尼采,코프르지브니체', 49.5994700, 18.1448000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29327, 'Kopidlno', 'Kopidlno', 'Kopidlno,ke pi de er nuo,Копидлно,科皮德爾諾', 50.3308500, 15.2702900, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29328, 'Konice', 'Konice', 'Konitz', 49.5903000, 16.8891100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29329, 'Komorní Lhotka', 'Komorni Lhotka', 'Kameralna Ligotka', 49.6581100, 18.5277700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29330, 'Komárov', 'Komarov', '', 49.8065000, 13.8563600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29331, 'Kolinec', 'Kolinec', 'Kolinec,Kolinetz,Колинец', 49.2989500, 13.4390000, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29332, 'Kolín', 'Kolin', 'Koeln an der Elbe,Kolin,Kolynas,Kolín,Köln an der Elbe,ke lin,klyn,kollin,korin,kwlyn,Колин,كولين,کلین,コリーン,科林,콜린', 50.0280600, 15.1998000, 'CZ', '2016-11-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29333, 'Kokory', 'Kokory', 'Kokor', 49.4948200, 17.3754400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29334, 'Kojetín', 'Kojetin', 'Koetin,Kojetein,Kojetin,Kojetina,Kojetīna,ke ye ting,Коетин,Којетин,科耶廷', 49.3517900, 17.3020700, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29335, 'Kobylí', 'Kobyli', 'Kobili,Kuobile,Kuobīlē,Кобили', 48.9328600, 16.8915900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29336, 'Kobeřice', 'Koberice', 'Koberwitz,Köberwitz', 49.9854800, 18.0521200, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29337, 'Kněžpole', 'Knezpole', '', 49.0985500, 17.5167100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29338, 'Kněžmost', 'Knezmost', 'Furstenbruck,Fürstenbruck', 50.4891700, 15.0382900, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29339, 'Kněžice', 'Knezice', 'Knezitz,Knězitz', 49.2707800, 15.6721600, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29340, 'Kněždub', 'Knezdub', '', 48.8866600, 17.3954600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29341, 'Klobuky', 'Klobuky', '', 50.2940100, 13.9874800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29342, 'Klobouky', 'Klobouky', 'Klobouk,Klobouky', 48.9960900, 16.8629800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29343, 'Klimkovice', 'Klimkovice', 'Konigsberg,Königsberg', 49.7880900, 18.1258500, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29344, 'Klenčí pod Čerchovem', 'Klenci pod Cerchovem', 'Klenec pod Cerchovem,Kleneč pod Čerchovem,Klentsch', 49.4348400, 12.8147300, 'CZ', '2009-07-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29345, 'Klecany', 'Klecany', 'Gross-Klecan', 50.1759900, 14.4114800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29346, 'Klatovy', 'Klatovy', 'Klatovai,Klatovi,Klatovy,Klattau,ke la tuo wei,klatwfy,klatwy,Клатови,Клатовы,كلاتوفي,کلاتوی,克拉托維', 49.3955200, 13.2950500, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29347, 'Klášterec nad Ohří', 'Klasterec nad Ohri', 'Klashterec na Okhri,Klashterec-nad-Ogrzhi,Klosterle an der Eger,Klösterle an der Eger,Клаштерец на Охри,Клаштерец-над-Огржи', 50.3886000, 13.1834200, 'CZ', '2014-11-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29348, 'Klášter', 'Klaster', 'Klaster Tepla,Kloster Tepla,Klášter Teplá,Stift Tepl,Tepl Stift', 49.9676200, 12.8762300, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29349, 'Kladruby', 'Kladruby', 'Kladrau', 49.7149800, 12.9823200, 'CZ', '2013-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29350, 'Kladno', 'Kladno', 'Cladna,Gorad Kladna,Kladnas,Kladno,Klantno,ke la de nuo,keulladeuno,klad no,kladnw,klandw,kuradono,Κλάντνο,Горад Кладна,Кладно,كلادنو,کلادنو,کلاندو,กลาดโน,კლადნო,クラドノ,克拉德诺,클라드노', 50.1473400, 14.1028500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29351, 'Kelč', 'Kelc', 'Kel''ch,Kelca,Kelch,Keltsch,Kelča,Kielce,kai er qi,Келч,Кельч,凱爾奇', 49.4784400, 17.8153300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29352, 'Kdyně', 'Kdyne', 'Kdine,Kdyne Nova,Kdyně Nová,Neugedein,ke di nie,Кдине,Кдиње,克迪涅', 49.3907700, 13.0396800, 'CZ', '2013-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29353, 'Kbely', 'Kbely', '', 50.1333300, 14.5500000, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29354, 'Kaznějov', 'Kaznejov', 'Kaznau', 49.8931300, 13.3829500, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29355, 'Katovice', 'Katovice', 'Katovice,Katowitz,Катовице', 49.2734800, 13.8303500, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29356, 'Kašperské Hory', 'Kasperske Hory', 'Bergreichenstein,Kashpers''ke Gori,Kashperske Khori,Kashperske-Gori,ka shen pei er si kai huo li,Кашперске Хори,Кашперске-Гори,Кашперське Гори,კაშპერსკე-ჰორი,卡什佩尔斯凯霍里', 49.1428900, 13.5561600, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29357, 'Kasejovice', 'Kasejovice', 'Kasejowitz', 49.4627000, 13.7406000, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29358, 'Karviná', 'Karvina', 'Freistadt,Frystat,Frysztat,Fryštát,Karvina,Karvina 1,Karviná 1,Карвина', 49.8540000, 18.5416900, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29359, 'Karolinka', 'Karolinka', 'Karolinina Hut'',Karolinina Huť', 49.3512800, 18.2400600, 'CZ', '2012-12-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29360, 'Karlovy Vary', 'Karlovy Vary', 'Carlsbad,Gorad Karlavy Vary,KLV,Karl Vary,Karlove Vari,Karlove Vary,Karlovi Varai,Karlovi Vari,Karlovi-Vari,Karlovy Vary,Karlovı Varı,Karlowe Ware,Karlowe Wary,Karlowé Warë,Karlsbad,Thermae Carolinae,ka luo wei fa li,kaleullobibali,karlwfy fary,karlwwy wary,karlwy wary,Κάρλοβι Βάρι,Горад Карлавы Вары,Карлове Вари,Карлови Вари,Карлови-Вари,Карловы Вары,Карлові Вари,Կառլովի Վարի,קרלובי וארי,كارلوفي فاري,کارلووی واری,کارلوی واری,კარლოვი-ვარი,カルロヴィ・ヴァリ,卡罗维发利,카를로비바리', 50.2327100, 12.8711700, 'CZ', '2012-11-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29361, 'Karlovice', 'Karlovice', 'Karlsthal', 50.1056400, 17.4456300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29362, 'Karlín', 'Karlin', 'Karolinenthal', 50.0927200, 14.4471100, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29363, 'Kardašova Řečice', 'Kardasova Recice', 'Kardasch Recice,Kardasch Řečice,Kardashova Rechica,Kardashova-Rzhechice,ka er da shao wa re qi cai,Кардашова Речица,Кардашова-Ржечице,卡爾達紹瓦熱奇采', 49.1847800, 14.8531500, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29364, 'Kaplice', 'Kaplice', 'Kaplice,Kaplitz,ka pu li cai,Каплице,卡普利采', 48.7388100, 14.4944900, 'CZ', '2016-07-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29365, 'Kamenný Újezd', 'Kamenny Ujezd', '', 48.8975300, 14.4463800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29366, 'Kamenný Přívoz', 'Kamenny Privoz', 'Stein Uberfuhr,Stein Überfuhr', 49.8629900, 14.5033900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29367, 'Kamenné Žehrovice', 'Kamenne Zehrovice', 'Zehrovice,Žehrovice', 50.1269700, 14.0180900, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29368, 'Kamenický Šenov', 'Kamenicky Senov', 'Stein Schonau,Stein Schönau', 50.7735900, 14.4728700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29369, 'Kamenice nad Lipou', 'Kamenice nad Lipou', 'Kamenice,Kamenice Nadlipova,Kamenice na Lipi,Kamenitz an der Linde,li pa he pan ka mei ni cai,Камењице на Липи,利帕河畔卡梅尼采', 49.3030300, 15.0751900, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29370, 'Kamenice', 'Kamenice', 'Kamenitz', 49.9015100, 14.5824200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29371, 'Kamenice', 'Kamenice', 'Kamenitz', 49.3665900, 15.7802300, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29372, 'Kájov', 'Kajov', 'Gojau', 48.8108200, 14.2585900, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29373, 'Kadaň', 'Kadan', 'Kaaden,Kadan,Kadan'',Kadaň,Кадань,Кадањ', 50.3833300, 13.2666700, 'CZ', '2016-03-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29374, 'Kačice', 'Kacice', '', 50.1626100, 13.9881500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29375, 'Josefův Důl', 'Josefuv Dul', 'Josefodol,Josefsthal', 50.7819100, 15.2314600, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29376, 'Jistebník', 'Jistebnik', 'Stiebnig', 49.7540000, 18.1306300, 'CZ', '2013-09-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29377, 'Jistebnice', 'Jistebnice', 'Jistebnitz', 49.4855300, 14.5276000, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29378, 'Jirny', 'Jirny', 'Gross Jirna', 50.1157800, 14.6992300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29379, 'Jirkov', 'Jirkov', 'Gorkau,Görkau,Jirkov,Jirkovas,yi er ke fu,yyrkw,Јирков,Йирков,ییرکو,伊尔科夫', 50.4997900, 13.4476900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29380, 'Jiříkov', 'Jirikov', 'Georgswalde,Jirzhikov,yi ri ke fu,Јиржиков,Йиржиков,伊日科夫', 50.9951400, 14.5691000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29381, 'Jindřichův Hradec', 'Jindrichuv Hradec', 'Gorad Jindrzhykhuu-Gradzec,Indrzhikhuv Khradec,Indrzhikhuv-Gradec,Jindrikhuv Khradec,Jindrzhikhuv Gradec,Jindrzhikhuv-Gradec,Jindrzichuv Hradecas,Jindržichūv Hradecas,Neuhaus,yin de ri he cheng bao,yndrykhwf hradts,yyndrzhykhww hradts,Їндржихув-Градец,Јиндрихув Храдец,Горад Йіндржыхуў-Градзец,Индржихув Храдец,Йиндржихув Градец,Йиндржихув-Градец,يندريخوف هرادتس,ییندرژیخوو هرادتس,因德日赫城堡', 49.1440400, 15.0030100, 'CZ', '2012-12-05', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29382, 'Jindřichov', 'Jindrichov', 'Hennersdorf', 50.2518400, 17.5190300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29383, 'Jince', 'Jince', 'Jinetz', 49.7862400, 13.9786700, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29384, 'Jimramov', 'Jimramov', 'Ingrowitz,yi mu la mo fu,伊姆拉莫夫', 49.6371900, 16.2263200, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29385, 'Jílové u Prahy', 'Jilove u Prahy', 'Eule,Jilove,Jílové', 49.8954500, 14.4933300, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29386, 'Jílové', 'Jilove', 'Eulau', 50.7608200, 14.1038300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29387, 'Jilemnice', 'Jilemnice', 'Jilemnice,yi lai mu ni cai,Јилемњице,Йилемнице,伊萊姆尼采', 50.6089000, 15.5065300, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29388, 'Jihlava', 'Jihlava', 'Iglau,Iglawa,Igława,Jiglava,Jihlava,Jikhlava,Јихлава,Йиглава', 49.3961000, 15.5912400, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29389, 'Jičín', 'Jicin', 'Gitschin,Gitzinum,Jichin,Jicin,Jiczyn,Jitschin,Jičín,Titschein,ichin,yi qin,Јичин,Йичин,イチーン,伊钦,이친', 50.4372300, 15.3516200, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29390, 'Jevišovice', 'Jevisovice', 'Jevishovice,ye wei shao wei cai,Јевишовице,耶維紹維采', 48.9873600, 15.9899200, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29391, 'Jevíčko', 'Jevicko', 'Gewitsch,Jevichko,Jevicko,Jevīčko,ye wei qi ke,Јевичко,耶維奇科', 49.6322000, 16.7112500, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29392, 'Jeseník nad Odrou', 'Jesenik nad Odrou', 'Deutsch Jassnik,Nemecky Jesenik,Německý Jeseník', 49.6119400, 17.9052600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29393, 'Jeseník', 'Jesenik', 'Freiwaldau,Fryvaldov,Frývaldov', 50.2293700, 17.2046400, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29394, 'Jesenice', 'Jesenice', 'Jechnitz', 50.0970300, 13.4694800, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29395, 'Jesenice', 'Jesenice', 'Jessenitz', 49.9681400, 14.5135000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29396, 'Jeneč', 'Jenec', 'Gross Jentsch', 50.0873000, 14.2148200, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29397, 'Jemnice', 'Jemnice', 'Emnice,Jamnitz,Jemnice,ye mu ni cai,Јемњице,Емнице,耶姆尼采', 49.0189800, 15.5699400, 'CZ', '2015-12-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29398, 'Jedovnice', 'Jedovnice', 'Jedovnice,Jedownitz,Једовњице', 49.3445300, 16.7559500, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29399, 'Jedlová', 'Jedlova', 'Schonbrunn,Schönbrunn', 49.6610000, 16.3060800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29400, 'Javorník', 'Javornik', 'Jauernig,Javornik,Javornika,Javornīka,ya wo er ni ke,Јаворњик,亞沃爾尼克', 50.3907700, 17.0027200, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29401, 'Jarošov nad Nežárkou', 'Jarosov nad Nezarkou', 'Jareschau', 49.1898900, 15.0673400, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29402, 'Jaroslavice', 'Jaroslavice', 'Joslowitz', 48.7565700, 16.2335100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29403, 'Jaroměřice nad Rokytnou', 'Jaromerice nad Rokytnou', 'Jarmeritz,Jaromerice na Rokytne,Jaromerzice pie Rokitnas,Jaromeržice pie Rokitnas,Jaromjerzhice na Rokitni,Jaroměřice na Rokytné,luo ji te na he pan ya luo mei ri cai,Јаромјержице на Рокитни,羅基特納河畔亞羅梅日采', 49.0940800, 15.8933100, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29404, 'Jaroměřice', 'Jaromerice', 'Jarmeritz,Jaromeritz,Jaroměřitz', 49.6255600, 16.7518500, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29405, 'Jaroměř', 'Jaromer', 'Jaromerzas,Jaromerzh,Jaromeržas,Jaromjerzh,ya luo mei ri,Јаромјерж,Яромерж,亞羅梅日', 50.3562000, 15.9213600, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29406, 'Janov nad Nisou', 'Janov nad Nisou', 'Honsberg,Honsberk,Johannesberg', 50.7720400, 15.1691300, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29407, 'Janovice nad Úhlavou', 'Janovice nad Uhlavou', 'Janovice na Ukhlavi,Janowitz,wu he la wa he pan ya nuo wei cai,Јановице на Ухлави,烏赫拉瓦河畔亞諾維采', 49.3451500, 13.2181300, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29408, 'Janovice', 'Janovice', '', 49.6214100, 18.4060200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29409, 'Jalubí', 'Jalubi', 'Jalub', 49.1162600, 17.4278800, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29410, 'Jakartovice', 'Jakartovice', 'Eckersdorf', 49.9151000, 17.6840000, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29411, 'Jáchymov', 'Jachymov', 'Jachymow,Jachymów,Jakhimiv,Jakhimov,Joachimsthal,Sankt-Joachimsthal,ya xi mo fu,yahimofu,Јахимов,Яхимов,Яхимів,ヤーヒモフ,亞希莫夫', 50.3584600, 12.9346500, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29412, 'Jablunkov', 'Jablunkov', 'Jablonkow,Jablunkau,Jablunkov,Jablunkova,Jabłonków,jblnkww,ya bu lun ke fu,Јаблунков,Яблунков,جبلنکوو,亞布倫科夫', 49.5767200, 18.7645800, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29413, 'Jablůnka', 'Jablunka', '', 49.3835500, 17.9502100, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29414, 'Jablonné v Podještědí', 'Jablonne v Podjestedi', 'Deutsch Gabel,Jablone v Podjeshtjedi,Jablonne-v-Pod''eshtedi,Jablonne-v-Podeshtedi,Nemecke Jablonne,Německé Jablonné,ye shen jie de shan lu ya bu long nei,Јаблоне в Подјештједи,Яблонне-в-Подьештеди,Яблонне-в-Подєштеді,耶什捷德山麓亞布隆內', 50.7652800, 14.7605200, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29415, 'Jablonné nad Orlicí', 'Jablonne nad Orlici', 'Gabl', 50.0296400, 16.6005900, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29416, 'Jablonec nad Nisou', 'Jablonec nad Nisou', 'Gablonz,Gablonz an der Neisse,Jablonec,Jablonec nad Nisou,Jablonec nad Nysa,Jablonec nad Nysą,Jablonecas prie Nisos,yabeullonecheunateunisou,Яблонец,야블로네츠나트니소우', 50.7243100, 15.1710800, 'CZ', '2014-10-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29417, 'Jablonec nad Jizerou', 'Jablonec nad Jizerou', 'Jablonec,Jablonec an der Iser,Jablonetz', 50.7034700, 15.4295900, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29418, 'Ivanovice na Hané', 'Ivanovice na Hane', 'Eiwanowitz,Ivanovice na Khana,Ivanovice na Khani,Ivanovice pie Hanas,Ивановице на Хана,Ивановице на Хани', 49.3054200, 17.0934300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29419, 'Ivančice', 'Ivancice', 'Eibenschitz,Ivanchice,yi wan qi cai,Иванчице,伊萬契采', 49.1014400, 16.3775200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29420, 'Hýskov', 'Hyskov', 'Hyskow', 49.9907200, 14.0505500, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29421, 'Hvozdná', 'Hvozdna', '', 49.2484800, 17.7516300, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29422, 'Hustopeče Nad Bečvou', 'Hustopece Nad Becvou', 'Hustopetsch', 49.5305300, 17.8699400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29423, 'Hustopeče', 'Hustopece', 'Auspitz,Hostuopece,Hostuopečē,Khustopeche,hu si tuo pei qie,Хустопече,胡斯托佩切', 48.9408500, 16.7376200, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29424, 'Husinec', 'Husinec', 'Husinetz', 49.0549600, 13.9869700, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29425, 'Humpolec', 'Humpolec', 'Gumpolec,Humpoleca,Humpoletz,Khumpolec,hong bo lai ci,Гумполец,Хумполец,洪波萊茨', 49.5415200, 15.3593200, 'CZ', '2012-11-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29426, 'Hulín', 'Hulin', 'Gulin,Hulina,Hullein,Hulīna,Khulin,hu lin,Гулин,Хулин,胡林', 49.3168900, 17.4637400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29427, 'Hukvaldy', 'Hukvaldy', 'Hochwald', 49.6238100, 18.2218900, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29428, 'Hudlice', 'Hudlice', 'Hudlitz', 49.9609600, 13.9706300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29429, 'Hrušovany u Brna', 'Hrusovany u Brna', 'Rohrbach', 49.0386300, 16.5942900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29430, 'Hrušovany nad Jevišovkou', 'Hrusovany nad Jevisovkou', 'Grusbach,Hrusovani pie Jevisovkas,Hrušovani pie Jevišovkas,Khrushovani na Jevishovki,ye wei shao fu ka he pan he lu shao wa ni,Хрушовани на Јевишовки,耶維紹夫卡河畔赫魯紹瓦尼', 48.8299100, 16.4027100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29431, 'Hrušky', 'Hrusky', '', 48.7927200, 16.9740400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29432, 'Hroznová Lhota', 'Hroznova Lhota', '', 48.9078400, 17.4169700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29433, 'Hroznětín', 'Hroznetin', 'Lichtenstadt', 50.3094000, 12.8718000, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29434, 'Hrotovice', 'Hrotovice', 'Hrottowitz', 49.1077000, 16.0606700, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29435, 'Hronov', 'Hronov', 'Hronow', 50.4796800, 16.1823000, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29436, 'Hromnice', 'Hromnice', '', 49.8490700, 13.4414600, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29437, 'Hrochův Týnec', 'Hrochuv Tynec', 'Hrochow-Teinitz,Hrochowteinitz', 49.9594600, 15.9105400, 'CZ', '2015-12-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29438, 'Hrob', 'Hrob', 'Klostergrab', 50.6591900, 13.7267600, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29439, 'Hřebeč', 'Hrebec', '', 50.1359500, 14.1644600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29440, 'Hrdějovice', 'Hrdejovice', 'Hartowitz', 49.0189300, 14.4785700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29441, 'Hranice', 'Hranice', 'Rossbach', 50.3045900, 12.1757700, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29442, 'Hranice', 'Hranice', 'Granice,Hranice na Morave,Hranice na Moravě,Hranices,Hranicės,Khranice,Mahrisch Weisskirchen,Mährisch Weisskirchen,he la ni cai,heulaniche,Границе,Храњице,フラニツェ・ナ・モラヴィェ,赫拉尼采,흐라니체', 49.5479600, 17.7346900, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29443, 'Hradištko', 'Hradistko', 'Hradischko', 49.8682800, 14.4093500, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29444, 'Hrádek nad Nisou', 'Hradek nad Nisou', 'Grodek nad Nysa,Grottau,Gródek nad Nysą,Khradek na Nisi,ni si he pan he la de ke,Храдек на Ниси,尼斯河畔赫拉德克', 50.8527900, 14.8445500, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29445, 'Hrádek', 'Hradek', '', 49.7131600, 13.6529600, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29446, 'Hrádek', 'Hradek', '', 49.6166100, 18.7372000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29447, 'Hrádek', 'Hradek', '', 49.2612700, 13.4985000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29448, 'Hradec nad Svitavou', 'Hradec nad Svitavou', 'Graendorf,Grandorf,Greifendorf,Grándorf', 49.7114300, 16.4805800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29449, 'Hradec Králové', 'Hradec Kralove', 'Chrantets Kralove,Gorad Gradzec-Kralave,Gradec Kralove,Gradec''-Kralove,Gradec-Kralove,Gradets Kralove,Gradets-Kralove,Hradec Kralove,Hradec Kralovė,Hradec Králové,Khradec Kralove,Koeniggraetz,Kraljicin Gradac,Kraljičin Gradac,Königgrätz,Reginogradecium,h ra dets kral xwe,he la de ci-ke la luo wei,heuladecheukeulallobe,hradts kralwfh,hradts kralwwh,Χράντετς Κράλοβε,Горад Градзец-Кралаве,Градетс-Кралове,Градец Кралове,Градец-Кралове,Градець-Кралове,Храдец Кралове,Һрадец-Кралове,הראדץ קראלובה,هرادتس كرالوفه,هرادتس کرالووه,ہاردک کارلوف,ฮราเดตส์กราลอเว,ჰრადეც-კრალოვე,フラデツ・クラーロヴェー,赫拉德茨-克拉洛韦,흐라데츠크랄로베', 50.2092300, 15.8327700, 'CZ', '2014-10-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29450, 'Hradec nad Moravici', 'Hradec nad Moravici', 'Gratz,Grätz,Hradec,Hradec nad Moravici', 49.8704200, 17.8784300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29451, 'Hrabyně', 'Hrabyne', 'Hrabin', 49.8824900, 18.0548300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29452, 'Hovorčovice', 'Hovorcovice', '', 50.1786600, 14.5178900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29453, 'Hovorany', 'Hovorany', '', 48.9549300, 16.9934600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29454, 'Hovězí', 'Hovezi', 'Howiezy', 49.3036500, 18.0606200, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29455, 'Hostouň', 'Hostoun', 'Hostau', 49.5597100, 12.7714700, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29456, 'Hostomice', 'Hostomice', 'Hostomitz', 50.5877000, 13.8080300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29457, 'Hostomice', 'Hostomice', 'Hostomitz', 49.8252600, 14.0456000, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29458, 'Hošťka', 'Host''ka', 'Gastorf', 50.4885900, 14.3350000, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29459, 'Hostivice', 'Hostivice', 'Hostiwitz', 50.0815800, 14.2585600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29460, 'Hostinné', 'Hostinne', 'Arnau,Gostinne,Khostine,huo si ting nei,Гостинне,Хостине,霍斯廷內', 50.5406600, 15.7233400, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29461, 'Hostěradice', 'Hosteradice', 'Hosterlitz', 48.9500600, 16.2593100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29462, 'Hostavice', 'Hostavice', '', 50.0928300, 14.5582200, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29463, 'Hošťálková', 'Host''alkova', 'Hostialkow', 49.3546700, 17.8694400, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29464, 'Horšovský Týn', 'Horsovsky Tyn', 'Bischofteinitz,Gorshovski-Tin,Khorshovski Tin,Горшовски-Тин,Хоршовски Тин', 49.5296500, 12.9440500, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29465, 'Hořovice', 'Horovice', 'Gorzhovice,Horowitz,Horschowitz,Khorzhovice,huo ruo wei cai,hwrwbyz,hwrwytz,Горжовице,Хоржовице,הורוביץ,هورویتز,霍若維采', 49.8359700, 13.9026800, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29466, 'Horoměřice', 'Horomerice', 'Horomeritz,Horoměřitz', 50.1317300, 14.3387900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29467, 'Horní Těrlicko', 'Horni Terlicko', 'Gorne Cierlicko,Górne Cierlicko,Horni Terlicko,Horní Těrlicko,Tierlitzko', 49.7517700, 18.4829000, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29468, 'Horní Suchá', 'Horni Sucha', 'Gorna Sucha,Khorni Sukha,Sucha Gorna,Sucha Górna,Хорњи Суха', 49.7978000, 18.4818900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29469, 'Horní Stropnice', 'Horni Stropnice', 'Stropnice', 48.7612400, 14.7350200, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29470, 'Horní Štěpánov', 'Horni Stepanov', 'Horni Stefanau,Horní Stefanau,Stefanau', 49.5490100, 16.7907800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29471, 'Horní Sloupnice', 'Horni Sloupnice', 'Sloupnice,Sloupnitz', 49.9213800, 16.3394800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29472, 'Horní Slavkov', 'Horni Slavkov', 'Gorni-Slavkov,Khorni Slavkov,Schlaggenwald,shang si la fu ke fu,Горни-Славков,Хорњи Славков,上斯拉夫科夫', 50.1386300, 12.8075800, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29473, 'Horní Počernice', 'Horni Pocernice', 'Ober Pocernitz,Ober Počernitz', 50.1121000, 14.6103600, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29474, 'Horní Počaply', 'Horni Pocaply', 'Ober Podcap,Ober Podčáp', 50.4244000, 14.3899300, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29475, 'Horní Planá', 'Horni Plana', 'Khorni Plana,Oberplan,shang pu la na,Хорњи Плана,上普拉納', 48.7673600, 14.0325700, 'CZ', '2016-01-05', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29476, 'Horní Moštěnice', 'Horni Mostenice', 'Ober Moschtienitz', 49.4121300, 17.4587900, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29477, 'Horní Město', 'Horni Mesto', 'Bergstadt', 49.9084500, 17.2111200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29478, 'Horní Lideč', 'Horni Lidec', 'Khorni Lidech,Ober Litsch,Хорњи Лидеч', 49.1812100, 18.0609900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29479, 'Horní Libina', 'Horni Libina', 'Deutsch Liebau,Horni Libina,Horní Libina,Labau,Libina,Nemecka Libina,Německá Libina', 49.8898700, 17.0726200, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29480, 'Horní Jiřetín', 'Horni Jiretin', 'Gorni-Jirzhetin,Khorni Jirzhetin,Ober-Georgenthal,shang yi re ting,Горни-Йиржетин,Хорњи Јиржетин,上伊熱廷', 50.5730900, 13.5471700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29481, 'Horní Jelení', 'Horni Jeleni', 'Ober Jeleni,Ober Jelení', 50.0490100, 16.0839600, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29482, 'Horní Čermná', 'Horni Cermna', '', 49.9705300, 16.6077200, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29483, 'Horní Cerekev', 'Horni Cerekev', 'Horni Cerekeva,Khorni Cerekev,Ober Cerekve,shang cai lei kai fu,Хорњи Церекев,上采雷凱夫', 49.3202600, 15.3276900, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29484, 'Horní Bříza', 'Horni Briza', 'Ober Bris,Ober Břis', 49.8401200, 13.3555800, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29485, 'Horní Branná', 'Horni Branna', 'Branna', 50.6082600, 15.5714600, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29486, 'Horní Bludovice', 'Horni Bludovice', '', 49.7496500, 18.4367700, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29487, 'Horní Benešov', 'Horni Benesov', 'Benisch,Bennisch,Horni Bennisch,Horní Bennisch', 49.9668200, 17.6026200, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29488, 'Horní Bečva', 'Horni Becva', '', 49.4321600, 18.2885900, 'CZ', '2012-12-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29489, 'Horka nad Moravou', 'Horka nad Moravou', 'Horka', 49.6400900, 17.2107000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29490, 'Hořice', 'Horice', 'Horice v Podkrkonosi,Horitz,Horzices,Horžicės,Hořice v Podkrkonoší,Hořitz,Khorzhice,huo ri cai,Хоржице,霍日采', 50.3660900, 15.6318300, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29491, 'Horažďovice', 'Horazd''ovice', 'Gorazhdjovice,Horazdowitz,Horaždowitz,Khorazhdjovice,huo la ri jiao wei cai,Гораждёвице,Хораждјовице,霍拉日焦維采', 49.3206900, 13.7010000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29492, 'Holýšov', 'Holysov', 'Golishov,Holeischen,Kholishov,huo li shao fu,Голишов,Холишов,霍利紹夫', 49.5936100, 13.1012900, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29493, 'Holoubkov', 'Holoubkov', 'Holoubkau', 49.7759800, 13.6924600, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29494, 'Holice', 'Holice', 'Holitz', 50.0660100, 15.9859000, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29495, 'Holešov', 'Holesov', 'Goleshov,Holesova,Holešova,Holleschau,Kholeshov,huo lai shao fu,Голешов,Холешов,霍萊紹夫', 49.3333100, 17.5783200, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29496, 'Holasovice', 'Holasovice', 'Kreuzendorf', 49.9984300, 17.8084700, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29497, 'Hodslavice', 'Hodslavice', 'Hotzendorf', 49.5385600, 18.0236700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29498, 'Hodonín', 'Hodonin', 'Goding,Godonin,Göding,Hodonin,Hodonín,Годонин', 48.8489300, 17.1324400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29499, 'Hodonice', 'Hodonice', 'Hodnitz,Hödnitz', 48.8368000, 16.1633700, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29500, 'Hodkovičky', 'Hodkovicky', '', 50.0234600, 14.4141500, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29501, 'Hodkovice nad Mohelkou', 'Hodkovice nad Mohelkou', 'Hodkovice,Liebenau,Liebenau in Bohmen,Liebenau in Böhmen', 50.6658600, 15.0898500, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29502, 'Hnojník', 'Hnojnik', '', 49.6825000, 18.5414300, 'CZ', '2017-03-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29503, 'Hněvotín', 'Hnevotin', 'Nebotein', 49.5720500, 17.1795400, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29504, 'Hněvošice', 'Hnevosice', 'Schreibersdorf', 50.0029900, 18.0082900, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29505, 'Hluk', 'Hluk', 'Gluk,Hluck,Hluka,Khluk,he lu ke,Глук,Хлук,赫盧克', 48.9880500, 17.5274400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29506, 'Hlučín', 'Hlucin', 'Gluchin,Hlucina,Hlučīna,Hulczyn,Hultschin,Khluchin,he lu qin,Глучин,Хлучин,赫盧欽', 49.8979500, 18.1919600, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29507, 'Hluboká nad Vltavou', 'Hluboka nad Vltavou', 'Frauenberg,Gluboka-nad-Vltavoj,Gluboka-nad-Vltavou,Gorad Gluboka-nad-Vltavaj,Hluboka nad Vltavou,Khluboka na Vltavi,fu er ta wa he pan he lu bo ka,Глубока-над-Влтавой,Глубока-над-Влтавоу,Горад Глубока-над-Влтавай,Фрауенберг,Хлубока на Влтави,伏爾塔瓦河畔赫盧博卡', 49.0522500, 14.4342700, 'CZ', '2016-05-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29508, 'Hlubočky', 'Hlubocky', 'Hombock,Khlubochki,Хлубочки', 49.6178300, 17.3943600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29509, 'Hlohovec', 'Hlohovec', '', 48.7739900, 16.7623000, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29510, 'Hlinsko', 'Hlinsko', 'Glinsko,Hlinsko v Cechach,Hlinsko v Čechách,Khlinsko,he lin si ke,Глинско,Хлинско,赫林斯科', 49.7621300, 15.9075600, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29511, 'Hevlín', 'Hevlin', 'Hoflein,Höflein', 48.7520900, 16.3813100, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29512, 'Heřmanův Městec', 'Hermanuv Mestec', 'Hermanmestetz,Heřmanměstetz', 49.9470700, 15.6649200, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29513, 'Heřmanova Huť', 'Hermanova Hut''', 'Hermannshutte,Hermannshütte', 49.7067900, 13.1006900, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29514, 'Herálec', 'Heralec', 'Heraletz', 49.6889100, 15.9943100, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29515, 'Herálec', 'Heralec', 'Heraletz', 49.5308300, 15.4570800, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29516, 'Hejnice', 'Hejnice', 'Haindorf', 50.8772000, 15.1816800, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29517, 'Hazlov', 'Hazlov', 'Haslau,Khazlov,Хазлов', 50.1563400, 12.2723800, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29518, 'Havlíčkův Brod', 'Havlickuv Brod', 'Deutsch Brod,Gavlichkuv-Brod,Havlickuv Brod,Havlíčkův Brod,Nemecky Brod,Německý Brod,Гавличкув-Брод', 49.6078500, 15.5806900, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29519, 'Havířov', 'Havirov', 'Chavirov,Gavirsov,Gavirzhov,Gorad Gavirzhau,Havirov,Havirzova,Havirzovas,Haviržovas,Havířov,Havīržova,Hawierzow,Hawierzów,Khavirzhov,ha wei ruo fu,ha weiychxf,habileujopeu,hafrwf,havirzhovi,havu~ijofu,hawyrzhw,Χάβιροβ,Гавиржов,Гавіржов,Гавіршов,Горад Гавіржаў,Хавиржов,هافروف,هاویرژو,ہاوہروف,ฮาเวียชอฟ,ჰავირჟოვი,ハヴィジョフ,哈维若夫,하비르조프', 49.7798400, 18.4368800, 'CZ', '2013-08-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29520, 'Hať', 'Hat''', 'Haatsch', 49.9464400, 18.2393100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29521, 'Hartmanice', 'Hartmanice', 'Hartmanitz', 49.1694800, 13.4545500, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29522, 'Harrachov', 'Harrachov', 'Garrakhov,Harachovas,Kharakhov,ha la huo fu,halahopeu,Гаррахов,Харахов,哈拉霍夫,하라호프', 50.7720900, 15.4314100, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29523, 'Hanušovice', 'Hanusovice', 'Hannsdorf,Hansovice,Khanushovice,ha nu shao wei cai,Ханушовице,哈努紹維采', 50.0804900, 16.9364100, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29524, 'Halenkovice', 'Halenkovice', 'Allenkowitz,Halenovice', 49.1710200, 17.4715600, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29525, 'Halenkov', 'Halenkov', 'Hallenkau', 49.3174000, 18.1474900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29526, 'Háj ve Slezsku', 'Haj ve Slezsku', 'Haj,Háj', 49.8985600, 18.0954000, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29527, 'Habry', 'Habry', 'Habern', 49.7560300, 15.4848600, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29528, 'Habartov', 'Habartov', 'Habersbirk', 50.1829700, 12.5505400, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29529, 'Grygov', 'Grygov', 'Gru"gau,Gru”gau', 49.5384100, 17.3088700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29530, 'Golčův Jeníkov', 'Golcuv Jenikov', 'Goleav Jenikov,Goltsch Jenikau', 49.8162600, 15.4768600, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29531, 'Fulnek', 'Fulnek', 'Ful''nek,Fulnek,Fulneka,fu er nei ke,Фулнек,Фульнек,富爾內克', 49.7123800, 17.9031900, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29532, 'Fryšták', 'Frystak', 'Freistadtl,Frishtak,Fristaka,Frištāka,fu li shen ta ke,Фриштак,弗里什塔克', 49.2852000, 17.6834600, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29533, 'Frymburk', 'Frymburk', 'Friedberg in Boehmen,Friedberg in Böhmen,Frimburk,Frymburk nad Vltavou,Фримбурк', 48.6609400, 14.1656400, 'CZ', '2016-01-05', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29534, 'Frýdlant nad Ostravicí', 'Frydlant nad Ostravici', 'Fridlant na Ostravici,Fridlant-nad-Ostravici,Fridlanta pie Ostravices,Friedland an der Ostrawitza,Frydland,Frydlant,Frydlant n Ostroh,Frydlant nad Ostrawica,Frydlant nad Ostrawicą,Frýdlant n Ostroh,Frīdlanta pie Ostravices,Gorad Frydlant-na-Ostravicy,ao si te la wei cai he pan fu li de lan te,Горад Фрыдлант-на-Остравіцы,Фридлант на Остравици,Фридлант-над-Остравици,奧斯特拉維采河畔弗里德蘭特', 49.5928000, 18.3596700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29535, 'Frýdlant', 'Frydlant', 'Fridlant,Friedland,Friedland in Bohmen,Friedland in Böhmen,Frydlant v Cechach,Frýdlant v Čechách,fu li de lan te,Фридлант,ფრიდლანტი,弗里德蘭特', 50.9213900, 15.0797400, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29536, 'Frýdek-Místek', 'Frydek-Mistek', 'Fridek-Mistek,Fridekmisteka,Friedeck,Friedek,Frydek,Frydek Mystekas,Frydek-Mistek,Frýdek,Frýdek-Místek,Frīdekmīsteka,Gorad Frydak-Mistak,Mistek,fri dek-mi s tek,frydk-mystk,fu li dai ke-mi si tai ke,furideku=misuteku,peulidekeumiseutekeu,Горад Фрыдак-Містак,Мистек,Фридек-Мистек,Фрідек-Містек,فريدك-ميستك,فریدک-میستک,ฟรีเดก-มีสเตก,ფრიდეკ-მისტეკი,フリーデク＝ミーステク,弗里代克-米斯泰克,프리데크미스테크', 49.6833300, 18.3500000, 'CZ', '2012-12-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29537, 'Fryčovice', 'Frycovice', 'Fritschowitz,Fritzendorf', 49.6667700, 18.2232100, 'CZ', '2016-01-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29538, 'Frenštát pod Radhoštěm', 'Frenstat pod Radhostem', 'Frankstadt,Frankstadt am Radhost,Frankstadt am Radhošt,Frenstat,Frenštát', 49.5483500, 18.2107800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29539, 'Františkovy Lázně', 'Frantiskovy Lazne', 'Franzensbad', 50.1203300, 12.3517400, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29540, 'Francova Lhota', 'Francova Lhota', 'Lhota Franzowa', 49.2017400, 18.1117500, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29541, 'Dýšina', 'Dysina', '', 49.7773500, 13.4915000, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29542, 'Dvorce', 'Dvorce', 'Hof', 49.8333200, 17.5476200, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29543, 'Duchcov', 'Duchcov', 'Duchcov,Dukhcov,Dux,do~ufutsu~ofu,dshkwf,du he zuo fu,duhochopeu,Духцов,دشكوف,ドゥフツォフ,杜赫佐夫,두호초프', 50.6037600, 13.7462100, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29544, 'Dubné', 'Dubne', '', 48.9761900, 14.3603800, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29545, 'Dubňany', 'Dubnany', 'Dubnain', 48.9169400, 17.0900400, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29546, 'Dub nad Moravou', 'Dub nad Moravou', 'Dub', 49.4824900, 17.2772300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29547, 'Dubicko', 'Dubicko', 'Dubitzke', 49.8280600, 16.9626600, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29548, 'Dubí', 'Dubi', 'Dubi,Eichwald,do~ubi,du bi,dubi,Дуби,ドゥビー,杜比,두비', 50.6855800, 13.7856100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29549, 'Dubá', 'Duba', 'Dauba', 50.5403400, 14.5402300, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29550, 'Drnovice', 'Drnovice', 'Drnowitz', 49.4693100, 16.5422300, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29551, 'Drnovice', 'Drnovice', 'Drnowitz', 49.2763000, 16.9514600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29552, 'Drnholec', 'Drnholec', 'Drnhuolecos,Drnkholec,Drnoholec,Durnholz,Dürnholz,Дрнхолец', 48.8574600, 16.4858600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29553, 'Dřiteň', 'Driten', 'Zirnau', 49.1428000, 14.3459600, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29554, 'Dřevohostice', 'Drevohostice', 'Drevokhostice,Drewohostitz,Dřewohostitz,Древохостице', 49.4259400, 17.5920400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29555, 'Drásov', 'Drasov', 'Drasow', 49.3318300, 16.4779800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29556, 'Drahanovice', 'Drahanovice', 'Drahanowitz', 49.5785600, 17.0770100, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29557, 'Doudleby nad Orlicí', 'Doudleby nad Orlici', 'Daudleb', 50.1074200, 16.2613100, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29558, 'Doubravice nad Svitavou', 'Doubravice nad Svitavou', 'Doubravice na Svitavi,Doubrawitz,Доубравице на Свитави', 49.4366400, 16.6293700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29559, 'Doubrava', 'Doubrava', 'Daabrowa,Daąbrowa,Dombrau', 49.8587300, 18.4801800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29560, 'Domažlice', 'Domazlice', 'Taus,Tausz', 49.4404900, 12.9297600, 'CZ', '2012-11-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29561, 'Domanín', 'Domanin', '', 49.0016700, 17.2847600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29562, 'Doloplazy', 'Doloplazy', 'Doloplas', 49.5687600, 17.4139300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29563, 'Dolní Životice', 'Dolni Zivotice', 'Schonstein,Schönstein', 49.8973200, 17.7796900, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29564, 'Dolní Žandov', 'Dolni Zandov', 'Unter-Sandau', 50.0179400, 12.5510100, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29565, 'Dolní Újezd', 'Dolni Ujezd', 'Unter Aujezd', 49.8256200, 16.2546100, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29566, 'Dolní Újezd', 'Dolni Ujezd', '', 49.5459700, 17.5354700, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29567, 'Dolní Studénky', 'Dolni Studenky', 'Schonbrunn,Schönbrunn,Studenky,Studénky', 49.9350600, 16.9710700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29568, 'Dolní Sloupnice', 'Dolni Sloupnice', '', 49.9272100, 16.2940100, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29569, 'Dolní Rychnov', 'Dolni Rychnov', 'Unter-Reichenau', 50.1646200, 12.6450700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29570, 'Dolní Roveň', 'Dolni Roven', 'Roven,Roveň,Rowen,Roweň', 50.0292700, 15.9677400, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29571, 'Dolní Poustevna', 'Dolni Poustevna', 'Nieder-Einsiedel,Poustevna', 50.9825100, 14.2868400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29572, 'Dolní Podluží', 'Dolni Podluzi', 'Dolni Grunt,Dolní Grunt,Nieder-Grund', 50.8798800, 14.5950300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29573, 'Dolní Počernice', 'Dolni Pocernice', 'Unter Pocernitz,Unter Počernitz', 50.0876000, 14.5719900, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29574, 'Dolní Němčí', 'Dolni Nemci', '', 48.9683700, 17.5858500, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29575, 'Dolní Lutyně', 'Dolni Lutyne', 'Nemecka Lutyne,Německá Lutyně', 49.8987600, 18.4281500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29576, 'Dolní Loućky', 'Dolni Loucky', 'Unter-Loucka', 49.3609900, 16.3587100, 'CZ', '2013-09-29', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29577, 'Dolní Libina', 'Dolni Libina', 'Bohmisch Liebau,Böhmisch Liebau,Libina,Moravska Libina,Moravská Libina', 49.8582100, 17.1072900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29578, 'Dolní Lhota', 'Dolni Lhota', '', 49.8423600, 18.0924100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29579, 'Dolní Kounice', 'Dolni Kounice', 'Dolni Kounice,Kanitz,xia ke wu ni cai,Долњи Коуњице,下科烏尼采', 49.0701100, 16.4649200, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29580, 'Dolní Dvořiště', 'Dolni Dvoriste', 'Unter-Haid', 48.6564200, 14.4522100, 'CZ', '2012-11-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29581, 'Dolní Dunajovice', 'Dolni Dunajovice', 'Unter-Tannowitz', 48.8544700, 16.5928300, 'CZ', '2012-11-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29582, 'Dolní Dobrouč', 'Dolni Dobrouc', 'Liebenthal', 49.9927300, 16.4976600, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29583, 'Dolní Černilov', 'Dolni Cernilov', '', 50.2611000, 15.9610700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29584, 'Dolní Čermná', 'Dolni Cermna', '', 49.9795400, 16.5647500, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29585, 'Dolní Cerekev', 'Dolni Cerekev', 'Unter Cerekwe', 49.3444900, 15.4565500, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29586, 'Dolní Bukovsko', 'Dolni Bukovsko', 'Bukowsko,Dolni Bukovsko,Долњи Буковско', 49.1708600, 14.5812700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29587, 'Dolní Břežany', 'Dolni Brezany', 'Unterbrezan,Unterbřežan', 49.9632100, 14.4585000, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29588, 'Dolní Bousov', 'Dolni Bousov', 'Unter Bautzen', 50.4382500, 15.1281200, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29589, 'Dolní Bojanovice', 'Dolni Bojanovice', '', 48.8586100, 17.0285900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29590, 'Dolní Bohdíkov', 'Dolni Bohdikov', 'Cesky Bohdikov,Český Bohdíkov', 50.0099600, 16.9043300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29591, 'Dolní Beřkovice', 'Dolni Berkovice', 'Unter Berkowitz,Unter Beřkowitz', 50.3931300, 14.4502400, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29592, 'Dolní Benešov', 'Dolni Benesov', 'Beneschau', 49.9210100, 18.1083500, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29593, 'Dolní Bečva', 'Dolni Becva', '', 49.4549800, 18.1941900, 'CZ', '2012-11-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29594, 'Dolany', 'Dolany', 'Dollein', 49.6498700, 17.3224000, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29595, 'Doksy', 'Doksy', 'Doksi,Doksy,Hirschberg,Hirschberg in Bohmen,Hirschberg in Böhmen,duo ke xi,Докси,Доксы,多克西', 50.5647100, 14.6555300, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29596, 'Doksy', 'Doksy', '', 50.1190000, 14.0478200, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29597, 'Dobšice', 'Dobsice', 'Klein Tesswitz', 48.8483400, 16.0821800, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29598, 'Dobruška', 'Dobruska', 'Dobruschka', 50.2920100, 16.1600100, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29599, 'Dobrovice', 'Dobrovice', 'Dobrowitz', 50.3693300, 14.9623300, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29600, 'Dobronín', 'Dobronin', 'Dobrenz', 49.4783300, 15.6499200, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29601, 'Dobroměřice', 'Dobromerice', '', 50.3700900, 13.7947300, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29602, 'Dobřív', 'Dobriv', 'Dobriw,Dobříw', 49.7156600, 13.6868100, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29603, 'Dobříš', 'Dobris', 'Dobrish,Dobrzhish,duo bu ri shen,Добржиш,Добриш,多布日什', 49.7811300, 14.1671700, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29604, 'Dobřichovice', 'Dobrichovice', 'Dobrichowitz,Dobrikhovice,Dobrzhikhovice,duo bu ri huo wei cai,Добржиховице,Добриховице,多布日霍維采', 49.9274900, 14.2746900, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29605, 'Dobratice', 'Dobratice', '', 49.6603900, 18.4922600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29606, 'Dobřany', 'Dobrany', 'Dobrani,Dobrzan,Dobrzhani,duo bu zha ni,Добрани,Добржани,多布扎尼', 49.6548200, 13.2930700, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29607, 'Dobrá', 'Dobra', '', 49.6738300, 18.4139300, 'CZ', '2017-03-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29608, 'Dlouhá Třebová', 'Dlouha Trebova', 'Langentriebe', 49.9404000, 16.4232900, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29609, 'Divišov', 'Divisov', 'Diwischau', 49.7884900, 14.8757900, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29610, 'Dětmarovice', 'Detmarovice', 'Detmarovice,Dittmannsdorf,Dziecmorowice,Dziećmorowice,Dětmarovice', 49.8941200, 18.4607900, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29611, 'Desná', 'Desna', 'Dessendorf', 50.7598700, 15.3028400, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29612, 'Děčín', 'Decin', 'Dechin,Decin,Decina,Decynas,Dečynas,Dečīna,Djechin,Děčín,Gorad Dzechyn,Tetschen,dechin,dechini,dychyn,dytshyn,dyychyn,jechin,jie qin,Горад Дзечын,Дечин,Дјечин,ديتشين,دیچین,دییچین,დეჩინი,ジェチーン,杰钦,데친', 50.7821500, 14.2147800, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29613, 'Davle', 'Davle', 'Dalve,Dawle', 49.8921800, 14.4003700, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29614, 'Dašice', 'Dasice', 'Daschitz', 50.0284400, 15.9124400, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29615, 'Darkovice', 'Darkovice', '', 49.9359200, 18.2221300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29616, 'Dambořice', 'Damborice', 'Damboritz', 49.0382800, 16.9175700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29617, 'Dalovice', 'Dalovice', 'Dallwitz', 50.2477900, 12.8958100, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29618, 'Dačice', 'Dacice', 'Dachice,Datschitz,da qi cai,Дачице,達奇采', 49.0815400, 15.4372700, 'CZ', '2012-11-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29619, 'Cvikov', 'Cvikov', 'Cvikov,Zwickau,ci wei ke fu,Цвиков,茨維科夫', 50.7766800, 14.6329800, 'CZ', '2017-05-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29620, 'Čkyně', 'Ckyne', 'Ckyn,Čkyn', 49.1150300, 13.8290600, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29621, 'Čížkovice', 'Cizkovice', 'Tschischkowitz', 50.4841800, 14.0283900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29622, 'Cítov', 'Citov', '', 50.3722500, 14.3981300, 'CZ', '2013-01-15', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29623, 'Církvice', 'Cirkvice', '', 49.9456000, 15.3350500, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29624, 'Čimelice', 'Cimelice', 'Cimelitz,Čimelitz', 49.4655700, 14.0692200, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29625, 'Chyšky', 'Chysky', 'Klein Chyschka', 49.5234600, 14.4275700, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29626, 'Chýnov', 'Chynov', 'Chejnow,Khinov,xi nuo fu,Хинов,希諾夫', 49.4067700, 14.8112200, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29627, 'Chyňava', 'Chynava', 'Chynawa,Khinava,Хињава', 50.0273600, 14.0739800, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29628, 'Chvalšiny', 'Chvalsiny', 'Kalsching', 48.8540100, 14.2111400, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29629, 'Chvaletice', 'Chvaletice', 'Chavaletice,Chwaletitz', 50.0344300, 15.4184600, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29630, 'Chvalčov', 'Chvalcov', '', 49.3891800, 17.7114900, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29631, 'Chuchelná', 'Chuchelna', 'Kuchelna', 49.9866400, 18.1165600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29632, 'Chrudim', 'Chrudim', 'Chrudimas,Gorad Khrudzim,Hrudima,Khrudim,he lu di mu,khrwdym,Горад Хрудзім,Хрудим,خروديم,خرودیم,赫魯迪姆', 49.9510900, 15.7955800, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29633, 'Chroustovice', 'Chroustovice', 'Chroustowitz', 49.9555300, 15.9914300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29634, 'Chropyně', 'Chropyne', 'Chropin,Hropine,Hropiņe,Khropine,he luo pi nie,Хропине,Хропиње,赫羅皮涅', 49.3564400, 17.3645100, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29635, 'Chřibská', 'Chribska', 'Kreibitz', 50.8607900, 14.4844400, 'CZ', '2012-12-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29636, 'Chrastava', 'Chrastava', 'Khrastava,Kratzau,he la si ta wa,Храстава,赫拉斯塔瓦', 50.8169300, 14.9688400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29637, 'Chrast', 'Chrast', '', 49.9020500, 15.9339600, 'CZ', '2007-10-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29638, 'Chrást', 'Chrast', '', 49.7932000, 13.4935800, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29639, 'Chotoviny', 'Chotoviny', '', 49.4780300, 14.6769500, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29640, 'Chotěšov', 'Chotesov', 'Choteschau,Chotěschau', 49.6540800, 13.2027100, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29641, 'Chotěbuz', 'Chotebuz', 'Chotebuz,Chotěbuz,Kocobedz,Kocobędz,Kotzobenz,Kozobentz', 49.7684900, 18.5691200, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29642, 'Chotěboř', 'Chotebor', 'Hoteborza,Hoteborža,Khotjeborzh,chwtbwr,huo jie bo ri,tshwtbwr,Хотјеборж,تشوتبور,چوتبور,霍捷博日', 49.7207200, 15.6701800, 'CZ', '2017-01-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29643, 'Chomutov', 'Chomutov', 'Chomutov,Chomutovas,Khomutov,Komotau,homutofu,homutopeu,huo mu tuo fu,khmwtw,khwmtw,khwmwtwf,Хомутов,خموتو,خومتو,خوموتوف,ხომუტოვი,ホムトフ,霍穆托夫,호무토프', 50.4604800, 13.4177900, 'CZ', '2013-01-04', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29644, 'Chodová Planá', 'Chodova Plana', 'Kuttenplan', 49.8932100, 12.7301400, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29645, 'Chodov', 'Chodov', 'Chodau,Chodovas,Khodov,hodofu,hodopeu,huo duo fu,Ходов,ホドフ,霍多夫,호도프', 50.2401800, 12.7455100, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29646, 'Choceň', 'Chocen', 'Checen,Checeň,Chotzen,Hocena,Hoceņa,Khocen,Khocen'',huo cai ni,Хоцень,Хоцењ,霍采尼', 50.0016100, 16.2230300, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29647, 'Chlum u Třeboně', 'Chlum u Trebone', 'Chlum,Chlumec,Chlumetz', 48.9623500, 14.9279900, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29648, 'Chlumec nad Cidlinou', 'Chlumec nad Cidlinou', 'Chlumec,Chlumec na Cidline,Chlumec na Cidliňe,Chlumecas prie Cidlinos,Khlumec na Cidlini,Khlumec-nad-Cidlinou,qi de li na he pan he lu mei ci,Хлумец на Цидлини,Хлумец-над-Цидлиноу,齊德利納河畔赫盧梅茨', 50.1544000, 15.4602600, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29649, 'Chlumec', 'Chlumec', 'Kulm', 50.6997200, 13.9396400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29650, 'Chlumčany', 'Chlumcany', '', 49.6325600, 13.3132300, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29651, 'Chlebičov', 'Chlebicov', '', 49.9594200, 17.9674800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29652, 'Cheb', 'Cheb', 'Cheb,Chebas,Eger,Egra,Gorad Kheb,Kheb,hai bu,hepeu,hepu,khb,khp,Горад Хеб,Хеб,خب,خپ,ヘプ,海布,헤프', 50.0796300, 12.3739200, 'CZ', '2012-12-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29653, 'Chabařovice', 'Chabarovice', 'Karbitz', 50.6731800, 13.9418400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29654, 'Český Těšín', 'Cesky Tesin', 'Ceski Tesina,Ceski Tjesin,Cesky Tesin,Cesky Tesynas,Ches''kij Teshin,Cheshki Tjeshin,Cheski-Teshin,Czeski Cieszyn,Gorad Chehski-Ceshyn,Teschen,Tesin,Tschechisch Teschen,cheseukitesin,jie ke jie xin,tshysky tshyn,Česki Tešīna,Česky Tešynas,Český Tešín,Český Těšín,Češki Tješin,Горад Чэскі-Цешын,Чески-Тешин,Чеський Тешин,Чешки Тјешин,تشيسكي تشين,چسکی تیه‌شین,チェスキー・チェシーン,捷克捷欣,체스키테신', 49.7461300, 18.6261300, 'CZ', '2013-08-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29655, 'Český Rudolec', 'Cesky Rudolec', 'Bohmisch Rudoletz,Böhmisch Rudoletz', 49.0683500, 15.3243700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29656, 'Český Krumlov', 'Cesky Krumlov', 'Boehmisch Krumau,Böhmisch Krumau,Ceske Krumlov,Ceski Krumlov,Cesky Krumlov,Cesky Krumlovas,Ches''kij Krumlov,Cheshki Krumlov,Cheski Krumlov,Cheski-Krumlov,Crumlovia,Gorad Chehski-Krumlau,Krumau,Krumlov,Krummau,Tseski Kroumlov,che ski kru mlxf,cheseukikeulumlopeu,jie ke ke lu mu luo fu,tshysky krwmlwf,zsqy qrwmlwb,Çeski Krumlov,Česky Krumlovas,Český Krumlov,Τσέσκι Κρούμλοβ,Горад Чэскі-Крумлаў,Чески Крумлов,Чески-Крумлов,Чеський Крумлов,Чешки Крумлов,צסקי קרומלוב,تشيسكي كروملوف,เชสกีกรุมลอฟ,ჩესკი-კრუმლოვი,チェスキー・クルムロフ,捷克克鲁姆洛夫,체스키크룸로프', 48.8109100, 14.3152100, 'CZ', '2014-09-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29657, 'Český Dub', 'Cesky Dub', 'Bohmisch Aicha,Böhmisch Aicha,Cheshki Dub,Cheski-Dub,jie ke du bu,Чески-Дуб,Чешки Дуб,捷克杜布', 50.6605400, 14.9961700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29658, 'Český Brod', 'Cesky Brod', 'Bohmisch Brod,Böhmisch Brod,Cheshki Brod,jie ke bu luo de,Чешки Брод,捷克布羅德', 50.0742000, 14.8608100, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29659, 'České Velenice', 'Ceske Velenice', 'Cheshke Velenice,Cheske-Velenice,jie ke wei lai ni cai,Ческе-Веленице,Чешке Велењице,捷克韋萊尼采', 48.7685100, 14.9636800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29660, 'České Meziříčí', 'Ceske Mezirici', 'Mezirici,Meziříčí,Mezritz,Mezřitz', 50.2868000, 16.0442800, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29661, 'České Budějovice', 'Ceske Budejovice', 'Boehmisch Budweis,Budejovice,Budweis,Böhmisch Budweis,Ceske Budejovicai,Ceske Budejovice,Ceské Budejovice,Cheshke Budjejovice,Cheske Budejovice,Cheske-Budejovice,Czeskie Budziejowice,Tseske Mpountegiobitse,Česke Budejovicai,České Budějovice,Τσέσκε Μπουντεγιόβιτσε,Ческе Будейовице,Ческе-Будеёвице,Чешке Будјејовице,Чешке Буђејовице', 48.9744700, 14.4743400, 'CZ', '2014-08-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29662, 'Česká Ves', 'Ceska Ves', 'Bohmischdorf,Böhmischdorf', 50.2573600, 17.2280500, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29663, 'Česká Třebová', 'Ceska Trebova', 'Bohmisch-Trubau,Böhmisch-Trübau,Ceska Trsebova,Cheshka Trebova,Cheska-Trshebova,jie ke te re bo wa,Česka Tršebova,Ческа-Тршебова,Чешка Требова,ჩესკა-ტრშებოვა,捷克特熱博瓦', 49.9043600, 16.4441300, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29664, 'Česká Skalice', 'Ceska Skalice', 'Bohmisch,Böhmisch,Cheshka Skalica,Scalis,jie ke si ka li cai,Чешка Скалица,捷克斯卡利采', 50.3946700, 16.0427600, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29665, 'Česká Lípa', 'Ceska Lipa', 'Boehmisch-Leipa,Böhmisch-Leipa,Ceska Lipa,Cheshka Lipa,Cheska Lipa,Cheska-Lipa,Czeska Lipa,Lipa,chska lypa,jie ke li pa,Česká Lípa,Ческа Липа,Ческа-Липа,Чешка Липа,چسکا لیپا,捷克利帕', 50.6855100, 14.5376400, 'CZ', '2016-07-21', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29666, 'Česká Kamenice', 'Ceska Kamenice', 'Bohmisch Kamnitz,Böhmisch Kamnitz,Cheshka Kamenica,Cheska-Kamenice,jie ke ka mei ni cai,Ческа-Каменице,Чешка Камењица,捷克卡梅尼采', 50.7978000, 14.4176700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29667, 'Červený Kostelec', 'Cerveny Kostelec', 'Cherveni Kostelec,Roth-Kosteletz,qie er wei ni ke si tai lai ci,Червени Костелец,切爾韋尼科斯泰萊茨', 50.4762600, 16.0928900, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29668, 'Červenka', 'Cervenka', 'Chervenka,Червенка', 49.7206800, 17.0777300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29669, 'Červené Pečky', 'Cervene Pecky', 'Cerveny Pecky,Petschkau', 49.9782200, 15.2085600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29670, 'Červená Voda', 'Cervena Voda', 'Chervena Voda,Chervena-Voda,Mahrisch Rothwasser,Mährisch Rothwasser,Rothwasser,Червена Вода,Червена-Вода', 50.0402900, 16.7426800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29671, 'Černožice', 'Cernozice', '', 50.3186300, 15.8740300, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29672, 'Černovice', 'Cernovice', 'Cernovice u Tabora,Cernowitz,Chernovice,qie er nuo wei cai,Černovice u Tábora,Černowitz,Черновице,切爾諾維采', 49.3726500, 14.9608900, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29673, 'Černošín', 'Cernosin', 'Tschernoschin', 49.8161300, 12.8838100, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29674, 'Černošice', 'Cernosice', '', 49.9600800, 14.3197900, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29675, 'Černilov', 'Cernilov', 'Cernilow,Černílow', 50.2626500, 15.9225400, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29676, 'Černčice', 'Cerncice', '', 50.3613800, 13.8452100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29677, 'Černá Hora', 'Cerna Hora', 'Cherna Gora,Cherna Khora,Черна Гора,Черна Хора', 49.4136100, 16.5814000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29678, 'Cerhenice', 'Cerhenice', 'Cerhenitz', 50.0712700, 15.0720300, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29679, 'Čerčany', 'Cercany', 'Cercan,Čerčan', 49.8529300, 14.7029900, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29680, 'Čelechovice na Hané', 'Celechovice na Hane', '', 49.5162600, 17.0937900, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29681, 'Čelákovice', 'Celakovice', 'Celakowitz,Celakoyice,Cellakovice,Čelakowitz', 50.1603800, 14.7500500, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29682, 'Čeladná', 'Celadna', '', 49.5487300, 18.3375900, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29683, 'Čejkovice', 'Cejkovice', '', 48.9059200, 16.9423000, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29684, 'Čejč', 'Cejc', '', 48.9465300, 16.9651100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29685, 'Čechtice', 'Cechtice', 'Cechtitz', 49.6240300, 15.0482400, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29686, 'Čebín', 'Cebin', '', 49.3132400, 16.4779100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29687, 'Častolovice', 'Castolovice', 'Castolowitz,Častolowitz', 50.1291000, 16.1812800, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29688, 'Čáslav', 'Caslav', 'Caslau,Chaslav,Gorad Chaslau,Tschaslau,qia si la fu,Časlau,Горад Часлаў,Часлав,恰斯拉夫', 49.9109900, 15.3897200, 'CZ', '2007-10-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29689, 'Bzenec', 'Bzenec', 'Bisenz,Bzenec,Bzeneca,bu ze nie ci,Бзенец,布澤涅茨', 48.9733600, 17.2668500, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29690, 'Bystřice pod Hostýnem', 'Bystrice pod Hostynem', 'Bistrice pod Khostinom,Bistrsice pie Hostina,Bistršice pie Hostīna,Bystritz-am-Hostein,Бистрице под Хостином', 49.3992400, 17.6740100, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29691, 'Bystřice nad Pernštejnem', 'Bystrice nad Pernstejnem', 'Bistrice na Pernshtejnu,Bistrsice pie Pernstejnas,Bistršice pie Pernštejnas,Bystrice pod Pernstynem,Bystritz am Pernstein,Bystritz-ober-Pernstein,Bystřice pod Pernštýnem,Бистрице на Пернштејну', 49.5229500, 16.2614700, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29692, 'Bystřice', 'Bystrice', 'Bistritz', 49.7321300, 14.6674000, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29693, 'Bystřice', 'Bystrice', 'Bystrzyca', 49.6365700, 18.7203800, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29694, 'Bystřec', 'Bystrec', 'Waltersdorf', 50.0116800, 16.6190000, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29695, 'Bystré', 'Bystre', 'Bistrau,Bistre,Bystre u Policky,Bystré u Poličky,bi si te lei,Бистре,比斯特雷', 49.6284600, 16.3467900, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29696, 'Bystřany', 'Bystrany', 'Wisterschan', 50.6286700, 13.8641900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29697, 'Býšť', 'Byst''', 'Bejscht', 50.1324300, 15.9111600, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29698, 'Byšice', 'Bysice', 'Bischitz', 50.3104400, 14.6113600, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29699, 'Buštěhrad', 'Bustehrad', 'Bushtegrad,Bushtjekhrad,bu shen jie he la de,Буштєград,Буштјехрад,布什捷赫拉德', 50.1559400, 14.1889700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29700, 'Bukovec', 'Bukovec', '', 49.5511400, 18.8268300, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29701, 'Bukovany', 'Bukovany', 'Bukwa', 50.1663200, 12.5726500, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29702, 'Budyně nad Ohří', 'Budyne nad Ohri', 'Budin,Budine na Okhri,Будиње на Охри', 50.4042700, 14.1259100, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29703, 'Budišov nad Budišovkou', 'Budisov nad Budisovkou', 'Bautsch,Budisop n Bud,Budišop n Bud', 49.7951100, 17.6296900, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29704, 'Budišov', 'Budisov', 'Budischau', 49.2713800, 16.0038300, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29705, 'Bučovice', 'Bucovice', 'Buchovice,Butschowitz,bu qiao wei cai,Бучовице,布喬維采', 49.1489600, 17.0019100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29706, 'Buchlovice', 'Buchlovice', 'Buchlovice,Buchlowitz,Bukhlovice,Buxlovitse,Buxlovîtse,Бухловице', 49.0862700, 17.3385200, 'CZ', '2015-07-14', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29707, 'Brušperk', 'Brusperk', 'Braunsberg', 49.7001000, 18.2221000, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29708, 'Bruntál', 'Bruntal', 'Freudenthal', 49.9884400, 17.4647000, 'CZ', '2012-12-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29709, 'Brumovice', 'Brumovice', 'Braunsdorf', 50.0153000, 17.7495800, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29710, 'Brtnice', 'Brtnice', 'Brtnice,Brutnice,Pirnitz,bu er te ni cai,Бртнице,Бртњице,Брътнице,布爾特尼采', 49.3069500, 15.6764200, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29711, 'Broumov', 'Broumov', 'Braunau,Broumov,Brunoviensis civitas,bu lao mo fu,Броумов,布劳莫夫', 50.5856600, 16.3318100, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29712, 'Brodek u Přerova', 'Brodek u Prerova', 'Brodek', 49.4841900, 17.3382500, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29713, 'Brno', 'Brno', 'BRQ,Berno,Brno,Brno osh,Bruenn,Bruna,Brunn,Brünn,Burno,Gorad Brno,Mprno,beuleuno,bexr no,brano,brno,brnw,bryn,bu er nuo,buruno,Μπρνο,Брно,Брно ош,Бърно,Горад Брно,Բռնո,ברין,ברנו,برنو,ब्रनो,เบอร์โน,ბრნო,ブルノ,布爾諾,브르노', 49.1952200, 16.6079600, 'CZ', '2012-11-22', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29714, 'Brniště', 'Brniste', 'Brims,Brins', 50.7291900, 14.7033800, 'CZ', '2017-01-27', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29715, 'Brněnec', 'Brnenec', 'Brunnlitz,Brünnlitz', 49.6273500, 16.5220200, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29716, 'Brloh', 'Brloh', 'Berlau,Brlohy', 48.9298700, 14.2185700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29717, 'Břidličná', 'Bridlicna', 'Friedland,Friedland an der Mohra,Frydland na Morave,Frydlant nad Moravici,Frýdland na Moravě,Frýdlant nad Moravicí', 49.9116700, 17.3710700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29718, 'Březová nad Svitavou', 'Brezova nad Svitavou', 'Brezova,Brusau,Brüsau,Březová', 49.6441800, 16.5179900, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29719, 'Březová', 'Brezova', 'Prosau,Prösau', 50.1455700, 12.6499600, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29720, 'Březová', 'Brezova', 'Briesau', 49.7915800, 17.8655600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29721, 'Březová', 'Brezova', '', 48.9254300, 17.7398600, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29722, 'Březolupy', 'Brezolupy', 'Brzezoluse', 49.1213800, 17.5803400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29723, 'Březno', 'Brezno', 'Priesen', 50.4018500, 13.4211800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29724, 'Březnice', 'Breznice', 'Breznice,Breznitz,Brzheznice,Březnitz,bu re zi ni cai,Брезњице,Бржезнице,布熱茲尼采', 49.5576300, 13.9506300, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29725, 'Březnice', 'Breznice', 'Brzeznitz,Břzeznitz', 49.1864300, 17.6627700, 'CZ', '2017-02-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29726, 'Březí', 'Brezi', 'Bratelsbrunn,Pratelsbrunn,Pratlsbrun,Prátelsbrunn,Prátlsbrun', 48.8192800, 16.5674800, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29727, 'Břeclav', 'Breclav', 'Brecizlavia,Breclav,Brzeclava,Brzeclavas,Brzeclavs,Brzeclaw,Brzecław,Brzheclav,Bržeclava,Bržeclavas,Bržeclavs,Břeclav,Lundenburg,beuleujecheullapeu,brytslaf,brzhtslaw,bu re ci la fu,bujetsurafu,Брецлав,Бржецлав,بريتسلاف,برژتسلاو,ブジェツラフ,布熱茨拉夫,브르제츨라프', 48.7589700, 16.8820300, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29728, 'Břasy', 'Brasy', '', 49.8370000, 13.5783300, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29729, 'Brantice', 'Brantice', 'Bransdorf', 50.0635100, 17.6291100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29730, 'Braník', 'Branik', '', 50.0349800, 14.4151800, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29731, 'Brandýs nad Orlicí', 'Brandys nad Orlici', 'Brandeis', 50.0019400, 16.2852800, 'CZ', '2017-02-02', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29732, 'Brandýs nad Labem-Stará Boleslav', 'Brandys nad Labem-Stara Boleslav', 'Brandis na Labi-Stara Boleslav,Brandis-nad-Labem-Stara-Boleslav,Брандис на Лаби-Стара Болеслав,Брандис-над-Лабем-Стара-Болеслав,Брандіс-над-Лабем-Стара-Болеслав', 50.1870900, 14.6632600, 'CZ', '2017-02-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29733, 'Brandýsek', 'Brandysek', 'Brandeis', 50.1892300, 14.1619900, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29734, 'Braňany', 'Branany', 'Prohn', 50.5429500, 13.7001700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29735, 'Božice', 'Bozice', 'Possitz', 48.8368700, 16.2887500, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29736, 'Bouzov', 'Bouzov', 'Busau', 49.7042600, 16.8928800, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29737, 'Bošovice', 'Bosovice', 'Boschowitz', 49.0535100, 16.8367600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29738, 'Boskovice', 'Boskovice', 'Boskovice,Boskowitz,bo si ke wei cai,Босковице,博斯科維采', 49.4875100, 16.6599700, 'CZ', '2012-12-13', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29739, 'Boršice', 'Borsice', 'Borschitz', 49.0625400, 17.3508400, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29740, 'Borovany', 'Borovany', 'Borovani,bo luo wa ni,Боровани,博羅瓦尼', 48.8986000, 14.6422700, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29741, 'Borová Lada', 'Borova Lada', 'Ferchenhaid,Ferchenheid', 48.9898300, 13.6598600, 'CZ', '2012-11-28', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29742, 'Borohrádek', 'Borohradek', '', 50.0977700, 16.0932600, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29743, 'Bořitov', 'Boritov', 'Borstendorf', 49.4250400, 16.5911900, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29744, 'Bořetice', 'Boretice', '', 48.9130200, 16.8530600, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29745, 'Borek', 'Borek', '', 49.0233900, 14.5008800, 'CZ', '2017-01-19', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29746, 'Bor', 'Bor', 'Bor,Bor u Tachova,Haid,bo er,Бор,博爾', 49.7115900, 12.7751600, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29747, 'Bolatice', 'Bolatice', 'Bolatitz', 49.9517200, 18.0835800, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29748, 'Bojkovice', 'Bojkovice', 'Bojkovice,Bojkowitz,bo yi ke wei cai,Бойковице,Бојковице,博伊科維采', 49.0386400, 17.8148700, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29749, 'Bohutín', 'Bohutin', '', 49.6555100, 13.9438900, 'CZ', '2017-02-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29750, 'Bohušovice nad Ohří', 'Bohusovice nad Ohri', 'Bauschowitz', 50.4931600, 14.1504800, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29751, 'Bohuslavice', 'Bohuslavice', 'Buslawitz', 49.9423200, 18.1286600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29752, 'Bohuňovice', 'Bohunovice', '', 49.6630100, 17.2869300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29753, 'Bohumín', 'Bohumin', 'Bogumin,Bohumina,Bohumynas,Bohumīna,Bokhumin,bhwmyn,Богумин,Бохумин,بهومین', 49.9041100, 18.3575500, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29754, 'Bohdalov', 'Bohdalov', 'Bohdalau', 49.4792100, 15.8758200, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29755, 'Bochov', 'Bochov', 'Buchau', 50.1487200, 13.0522700, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29756, 'Bludov', 'Bludov', 'Blauda,Bludov,Блудов', 49.9408000, 16.9284900, 'CZ', '2013-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29757, 'Blučina', 'Blucina', '', 49.0549700, 16.6445000, 'CZ', '2013-10-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29758, 'Blovice', 'Blovice', 'Blovice,Blowitz,bu luo wei cai,Бловице,布洛維采', 49.5822000, 13.5400900, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29759, 'Blížkovice', 'Blizkovice', '', 48.9997600, 15.8348200, 'CZ', '2017-01-17', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29760, 'Blížejov', 'Blizejov', 'Blisowa', 49.5000000, 12.9892600, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29761, 'Blažovice', 'Blazovice', '', 49.1656900, 16.7861100, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29762, 'Blatná', 'Blatna', 'Blatna,bu la te na,Блатна,布拉特納', 49.4248900, 13.8817600, 'CZ', '2013-01-11', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29763, 'Blansko', 'Blansko', 'Blansko,Бланско', 49.3630400, 16.6444600, 'CZ', '2012-11-16', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29764, 'Bílovice nad Svitavou', 'Bilovice nad Svitavou', 'Bilowitz', 49.2470800, 16.6724700, 'CZ', '2017-01-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29765, 'Bílovice', 'Bilovice', 'Bilovice u Uherskeho Hradiste,Bilowitz,Bílovice u Uherského Hradiště', 49.0996500, 17.5496100, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29766, 'Bílovec', 'Bilovec', 'Bielowiec,Bilovec,Biloveca,Bīloveca,Wagstadt,bi luo wei ci,Биловец,比洛韋茨', 49.7563900, 18.0158100, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29767, 'Bílina Kyselka', 'Bilina Kyselka', 'Bilina Kyselka,Bílina Kyselka,Sauerbrunn', 50.5500000, 13.7666700, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29768, 'Bílina', 'Bilina', 'Bilin,Bilina,bi li na,Билина,比利纳', 50.5485400, 13.7753500, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29769, 'Bílá Třemešná', 'Bila Tremesna', 'Weiss Tremeschna', 50.4446500, 15.7410100, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29770, 'Bílá Lhota', 'Bila Lhota', 'Lhota', 49.7095300, 16.9750700, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29771, 'Bezdružice', 'Bezdruzice', 'Weseritz', 49.9072400, 12.9711000, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29772, 'Beroun', 'Beroun', 'Beraun,Beroun,Verona,bei long,byrwn,Бероун,بيرون,貝龍', 49.9638200, 14.0720000, 'CZ', '2012-11-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29773, 'Bernartice', 'Bernartice', 'Bernaditz', 49.3688900, 14.3810100, 'CZ', '2017-01-20', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29774, 'Benešov nad Ploučnicí', 'Benesov nad Ploucnici', 'Beneshov na Plouchnici,Bensen,bnswb ʻl hplwʼwznyzh,pu luo wu qi ni cai he pan bei nei shao fu,Бенешов на Плоучњици,בנשוב על הפלואוצניצה,普洛烏奇尼采河畔貝內紹夫', 50.7415900, 14.3123900, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29775, 'Benešov nad Černou', 'Benesov nad Cernou', 'Deutsch Beneschau,Nemecky Benesov,Německý Benešov', 48.7294000, 14.6273700, 'CZ', '2017-02-09', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29776, 'Benešov', 'Benesov', 'Beneschau,Beneshov,Benesov,Benesovas,Benešov,Benešovas,bei nei shao fu,beneshofu,benesyopeu,bnshwf,bynyshwf,Бенешов,بنشوف,بينيشوف,ベネショフ,貝內紹夫,베네쇼프', 49.7816200, 14.6869700, 'CZ', '2012-12-18', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29777, 'Benecko', 'Benecko', '', 50.6663300, 15.5481600, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29778, 'Benátky nad Jizerou', 'Benatky nad Jizerou', 'Benatki na Jizeri,Benatki-nad-Jizerou,Benatky,Benátky,Neu Benatek,Nove Benatky,Nové Benátky,benateukinateu-ijelou,yi ze la he pan bei na te ji,Бенатки на Јизери,Бенатки-над-Йизероу,伊澤拉河畔貝納特基,베나트키나트이제로우', 50.2908500, 14.8234300, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29779, 'Bělotín', 'Belotin', 'Bjelotin,Bolten,Bölten,Бјелотин', 49.5912000, 17.8065400, 'CZ', '2017-01-30', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29780, 'Bělá pod Bezdězem', 'Bela pod Bezdezem', 'Bela pri Bedez,Bela-pod-Bezdezem,Weisswasser in Bohmen,Weisswasser in Böhmen,Бела-под-Бездезем', 50.5012100, 14.8041800, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29781, 'Bělá nad Radbuzou', 'Bela nad Radbuzou', 'Bjela na Radbuzi,Weissensulz,la de bu zha he pan bie la,Бјела на Радбузи,拉德布扎河畔別拉', 49.5911500, 12.7176100, 'CZ', '2017-02-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29782, 'Bedihošť', 'Bedihost''', 'Bedihoscht', 49.4482600, 17.1664300, 'CZ', '2017-01-31', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29783, 'Bečov', 'Becov', 'Hochpetsch', 50.4497200, 13.7178400, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29784, 'Bechyně', 'Bechyne', 'Bechyn,Bekhine,bei xi nie,Бехине,Бехиње,貝希涅', 49.2952300, 14.4681000, 'CZ', '2013-01-03', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29785, 'Bechlín', 'Bechlin', '', 50.4161500, 14.3409200, 'CZ', '2017-02-06', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29786, 'Bavorov', 'Bavorov', 'Barau,Bavorov,ba wo luo fu,Баворов,巴沃羅夫', 49.1218400, 14.0789300, 'CZ', '2012-12-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29787, 'Batelov', 'Batelov', 'Batelau,Battelau', 49.3142500, 15.3946500, 'CZ', '2017-01-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29788, 'Baška', 'Baska', '', 49.6458400, 18.3723300, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29789, 'Bartošovice', 'Bartosovice', 'Partschendorf', 49.6688400, 18.0546100, 'CZ', '2013-09-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29790, 'Bánov', 'Banov', '', 48.9880100, 17.7175200, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29791, 'Bakov nad Jizerou', 'Bakov nad Jizerou', 'Bakow', 50.4823000, 14.9414900, 'CZ', '2017-02-10', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29792, 'Babice', 'Babice', '', 49.1216700, 17.4807500, 'CZ', '2015-04-23', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29793, 'Aš', 'As', 'Asch,Ash,a shen,ashu,asi,Аш,アシュ,阿什,아시', 50.2238700, 12.1949900, 'CZ', '2017-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29794, 'Albrechtice nad Orlicí', 'Albrechtice nad Orlici', '', 50.1397900, 16.0643700, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29795, 'Albrechtice', 'Albrechtice', '', 49.7864500, 18.5244400, 'CZ', '2016-09-07', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29796, 'Adamov', 'Adamov', 'Adamov,Adamov u Brna,Adamova,Adamsthal,a da mo fu,adamovi,Адамов,ადამოვი,阿達莫夫', 49.3016200, 16.6525300, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29797, 'Abertamy', 'Abertamy', 'Abertham', 50.3687400, 12.8182600, 'CZ', '2017-01-26', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29798, 'Lázně Bohdaneč', 'Lazne Bohdanec', '', 50.0756000, 15.6797800, 'CZ', '2013-01-25', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29799, 'Černý Most', 'Cerny Most', '', 50.1047500, 14.5797400, 'CZ', '2007-04-24', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29800, 'Lučina', 'Lucina', '', 49.7208200, 18.4477600, 'CZ', '2017-02-01', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29801, 'Vysehrad', 'Vysehrad', 'Vysehrad,Vyshegrad,Vyšehrad,Вышеград', 50.0650900, 14.4171100, 'CZ', '2017-01-12', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29802, 'Provodov-Šonov', 'Provodov-Sonov', '', 50.3871100, 16.1079700, 'CZ', '2017-02-08', 60);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29803, 'Zwota', 'Zwota', 'Zwota', 50.3510300, 12.4224100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29804, 'Zwönitz', 'Zwoenitz', 'Cvenic,Cvenica,Cvjonic,Cvēnica,Zwoenitz,Zwonitz,Zwönitz,ci wei ni ci,tsfwnyts,tswnytz,Цвениц,Цвёниц,تسفونيتس,تسونیتز,茨韦尼茨', 50.6302700, 12.8099900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29805, 'Zwochau', 'Zwochau', 'Cvokhau,Grebehna,Zwochau,Zwochau vald,ci wo hao,Цвохау,茨沃豪', 51.4646700, 12.2684400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29806, 'Zwingenberg', 'Zwingenberg', 'Cvingenberg,Zwingenberg,ci wen gen bei er ge,tsuvu~ingenberuku,tswyngnbrg,Цвингенберг,تسوینگنبرگ,ツヴィンゲンベルク,茨温根贝尔格', 49.7238900, 8.6108400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29807, 'Zwingenberg', 'Zwingenberg', 'Cvingenberg,tsuvu~ingenberuku,Цвингенберг,Цвінгенберг,ツヴィンゲンベルク', 49.4191700, 9.0405600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29808, 'Zwiesel', 'Zwiesel', 'Cvizel,Cvizel'',Zwiesel,Zwiesl,Zwisel,ci wei sai er,tswyzl,Цвизел,Цвизель,Цвізель,Ցվիզել,تسویزل,茨维塞尔', 49.0169300, 13.2376500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29809, 'Zwiefalten', 'Zwiefalten', 'Cvifal''ten,Cvifalten,ci wei fa er teng,Цвифалтен,Цвифальтен,Цвіфальтен,茨维法尔滕', 48.2339600, 9.4623200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29810, 'Zwickau', 'Zwickau', 'Cvikau,Cvikava,Cvikkau,Cygnea,Gorad Cvikau,Stadt Zwickau,Swikawa,Zwickau,cheubikau,ci wei kao,tsfykaw,tsuvu~ikkau,tswykaw,Šwikawa,Горад Цвікау,Цвикау,Цвиккау,Цвікау,צוויקאו,تسفيكاو,تسویکاو,ツヴィッカウ,茨维考,츠비카우', 50.7272400, 12.4883900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29811, 'Zwenkau', 'Zwenkau', 'Cvenkau,Cvenkava,Zwenkau,ci wen kao,tsfynkaw,tswyka,Цвенкау,تسفينكاو,تسویکا,茨文考', 51.2187200, 12.3300800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29812, 'Zweiflingen', 'Zweiflingen', 'Cvajflingen,ci wei fu lin gen,tsuvu~aifuringen,Цвайфлинген,Цвайфлінген,Цвајфлинген,ツヴァイフリンゲン,茨魏夫林根', 49.2563900, 9.5180600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29813, 'Zweifelscheid', 'Zweifelscheid', '', 50.0333300, 6.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29814, 'Zweibrücken', 'Zweibruecken', 'Cvajbriken,Cvajbrjukken,Deux Ponts,Deux-Ponts,Dos Puentes,Zweebrigge,Zweibrucken,Zweibruecken,Zweibrücken,ci wei bu lu ken,tsuvu~aiburyukken,tswaybrwkn,Цвайбрюккен,Цвајбрикен,تسوایبروکن,ツヴァイブリュッケン,茨魏布吕肯', 49.2468600, 7.3697700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29815, 'Zuzenhausen', 'Zuzenhausen', 'Cucengauzen,Cucenkhauzen,chu cen hao sen,tsutsu~enhauzen,Цуценгаузен,Цуценхаузен,ツーツェンハウゼン,楚岑豪森', 49.2963600, 8.8225400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29816, 'Züssow', 'Zuessow', 'Cisov,Cjussov,Цисов,Цюссов', 53.9770900, 13.5485500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29817, 'Zusmarshausen', 'Zusmarshausen', 'Cusmarsgauzen,Cusmarskhauzen,Zusmarshausen,chu si ma er si hao sen,Цусмарсгаузен,Цусмарсхаузен,Ցուսմարսհաուզեն,楚斯马尔斯豪森', 48.4001400, 10.5991700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29818, 'Züsch', 'Zusch', '', 49.6500000, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29819, 'Zusamaltheim', 'Zusamaltheim', 'Cuzamal''tajm,Cuzamal''tgajm,Cuzamal''tkhajm,Cuzamaltkhajm,chu sa ma er tai mu,tswzamalthaym,Цузамалтхајм,Цузамальтайм,Цузамальтгайм,Цузамальтхайм,Ցուզամալտհայմ,تسوزامالتهایم,楚萨马尔泰姆', 48.5310400, 10.6356200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29820, 'Zurow', 'Zurow', 'Curov,Zurow,chu luo,Цуров,楚罗', 53.8642900, 11.6143400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29821, 'Zulpich', 'Zulpich', 'Cjul''pikh,Slaget vid Tulpiacum,Tolbiac,Zuelpich,Zulpich,Zülpich,Цюльпих', 50.6944700, 6.6541400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29822, 'Zschortau', 'Zschortau', '', 51.4793000, 12.3589300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29823, 'Zschornewitz', 'Zschornewitz', 'Zschornewitz', 51.7158500, 12.3999800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29824, 'Zschorlau', 'Zschorlau', 'Chorlau,Cshorlau,ci xiao er lao,Цшорлау,Чорлау,茨肖尔劳', 50.5666700, 12.6500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29825, 'Zschopau', 'Zschopau', 'Chopau,Cshopau,Csopava,Cšopava,Zschopau,chwpa,ci xiao bao,tshwbaw,Цшопау,Чопау,تشوباو,چوپا,茨肖保', 50.7481800, 13.0769100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29826, 'Zscherndorf', 'Zscherndorf', '', 51.6108700, 12.2675500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29827, 'Zscherben', 'Zscherben', '', 51.4670900, 11.8705800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29828, 'Zscherben', 'Zscherben', '', 51.3357600, 11.9696900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29829, 'Zschepplin', 'Zschepplin', 'Cheplin,Csheplin,Zschepplini vald,ci xie pu lin,Цшеплин,Чеплин,茨歇普林', 51.5000000, 12.6000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29830, 'Zschadrass', 'Zschadrass', 'Zschadrass,Zschadraß', 51.1382800, 12.8184800, 'DE', '2017-07-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29831, 'Zotzenheim', 'Zotzenheim', '', 49.8666700, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29832, 'Zossen', 'Zossen', 'Cosen,Cossen,Sosny,Zossen,cuo sen,swzh,Цосен,Цоссен,Ցոսեն,سوزه,措森', 52.2160000, 13.4490900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29833, 'Zöschingen', 'Zoeschingen', '', 48.6736500, 10.3252200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29834, 'Zöschen', 'Zoeschen', 'Zoschen,Zöschen', 51.3580200, 12.1165200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29835, 'Zornheim', 'Zornheim', 'Cornkhajm,cuo er en hai mu,Цорнхайм,Цорнхајм,措尔恩海姆', 49.8900000, 8.2247200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29836, 'Zorneding', 'Zorneding', 'Corneding,cuo er ne ding,zwrndyng,Цорнединг,Цорнедінг,زورندینگ,措尔讷丁', 48.0843300, 11.8244600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29837, 'Zorge', 'Zorge', '', 51.6333300, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29838, 'Zörbig', 'Zoerbig', 'Cerbig,Cjorbig,Zoerbig,Zorbig,Zörbig,ce er bi xi,tswrbygh,tswrbyrg,Цербиг,Цёрбиг,تسوربيغ,تسوربیرگ,策尔比希', 51.6289400, 12.1174000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29839, 'Zöllnitz', 'Zoellnitz', 'Zoellnitz,Zöllnitz', 50.8733400, 11.6413700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29840, 'Zolling', 'Zolling', 'Coling,Colling,cuo ling,tswlyng,Цолинг,Цоллинг,Цоллінг,Ցոլինգ,تسولینگ,措灵', 48.4500000, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29841, 'Zöblitz', 'Zoeblitz', 'Ceblic,Cjoblic,Zoblitz,Zöblitz,ce bu li ci,tswblytz,Цеблиц,Цёблиц,تسوبليتز,تسوبلیتز,策布利茨', 50.6591200, 13.2298100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29842, 'Zittau', 'Zittau', 'Citau,Citava,Cittau,Sitavia,Tsitaou,ZIT,Zitava,Zitawa,Zittau,Zytawa,qi tao,tsu~ittau,tsu~ittauno,tsyta,tsytaw,Żytawa,Žitava,Žitawa,Žytawa,Τσιτάου,Цитау,Циттау,Ціттаў,تسيتاو,تسیتا,ツィッタウ,ツィッタウの,齐陶', 50.8977200, 14.8076400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29843, 'Zirndorf', 'Zirndorf', 'Cirndorf,Zimdorf,qi er en duo fu,tsyndwrf,tsyrndwrf,Цирндорф,Ցիրնդորֆ,تسيرندورف,تسیندورف,齐尔恩多夫', 49.4424000, 10.9541400, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29844, 'Ostseebad Zinnowitz', 'Ostseebad Zinnowitz', 'Ostseebad Zinnowitz,Zinnowitz', 54.0766800, 13.9112700, 'DE', '2016-12-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29845, 'Zinna', 'Zinna', '', 51.5679000, 12.9535400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29846, 'Zingst', 'Zingst', 'Cingst,Zingst,qin ge si te,Цингст,Цинґст,钦格斯特', 54.4357200, 12.6888000, 'DE', '2014-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29847, 'Zimmerschied', 'Zimmerschied', 'Zimmerscheid,Zimmerschied', 50.3500000, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29848, 'Zimmern unter der Burg', 'Zimmern unter der Burg', '', 48.2205300, 8.7192800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29849, 'Zimmernsupra', 'Zimmernsupra', 'Cimernzupra,Cimmernzupra,Zimmernsupra,qi mei er en su pu la,Цимернзупра,Циммернзупра,齐梅尔恩苏普拉', 50.9833300, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29850, 'Zimmern ob Rottweil', 'Zimmern ob Rottweil', 'Cimern ob Rotvajl,Cimmern-ob-Rotvajl'',Zimmern ce Rottweil,Zimmern ĉe Rottweil,qi mei er en ao bu luo te wei er,Цимерн об Ротвајл,Циммерн-об-Ротвайль,齐梅尔恩奥布罗特魏尔', 48.1666000, 8.5943600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29851, 'Zimmern', 'Zimmern', '', 51.0000000, 11.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29852, 'Ziltendorf', 'Ziltendorf', 'Cil''tendorf,Ciltendorf,qi er teng duo fu,Цилтендорф,Цильтендорф,Ցիլտենդորֆ,齐尔滕多夫', 52.2060800, 14.6241100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29853, 'Zilshausen', 'Zilshausen', '', 50.1166700, 7.3833300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29854, 'Ziethen', 'Ziethen', '', 53.6944100, 10.8094500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29855, 'Ziesendorf', 'Ziesendorf', '', 53.9943300, 12.0393300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29856, 'Ziesar', 'Ziesar', 'Ciezar,Cizar,Ziesar,qi sa er,tsyzar,Циезар,Цизар,Ցիեզար,تسيزار,تسیزار,齐萨尔', 52.2661600, 12.2899700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29857, 'Ziertheim', 'Ziertheim', 'Cirtajm,Cirtgajm,Cirtkhajm,qi er tai mu,tsyrthaym,Циртайм,Циртгайм,Циртхайм,Циртхајм,Ցիրտհայմ,تسیرتهایم,齐尔泰姆', 48.6524400, 10.3988200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29858, 'Zierenberg', 'Zierenberg', 'Cirenberg,qi lun bei ge,tsu~irenberuku,tsyrnbrg,Циренберг,Ціренберг,تسیرنبرگ,ツィーレンベルク,齐伦贝格', 51.3694800, 9.3016400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29859, 'Ziemetshausen', 'Ziemetshausen', 'Cimetsgauzen,Cimetskhauzen,qi mei ci hao sen,Циметсгаузен,Циметсхаузен,Ցիմետսհաուզեն,齐梅茨豪森', 48.2924400, 10.5350300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29860, 'Zielitz', 'Zielitz', 'Cilic,qi li ci,Цилиц,齐利茨', 52.2895800, 11.6757200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29861, 'Ziegenhain', 'Ziegenhain', '', 50.6833300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29862, 'Ziegelheim', 'Ziegelheim', 'Cigel''khajm,Cigelkhajm,Ziegelheim,qi ge er hai mu,Цигелхајм,Цигельхайм,齐格尔海姆', 50.9333300, 12.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29863, 'Zichow', 'Zichow', 'Cikhov,qi xiao,Цихов,Ցիխով,齐肖', 53.1892700, 14.0384700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29864, 'Zeven', 'Zeven', 'Cefen,Ceven,Zeven,ce fen,tsu~efen,tswn,tsyfn,Цевен,Цефен,تسون,تسيفن,ツェーフェン,策芬', 53.2965700, 9.2768500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29865, 'Zeuthen', 'Zeuthen', 'Cojten,Zeuthen,cuo yi teng,Цойтен,Цојтен,Ցոյտեն,措伊滕', 52.3480300, 13.6217400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29866, 'Zeulenroda', 'Zeulenroda', '', 50.6527800, 11.9837700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29867, 'Zettlitz', 'Zettlitz', 'Cetlic,Zettlitzi vald,ce te li ci,Цетлиц,策特利茨', 51.0666700, 12.8333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29868, 'Zettingen', 'Zettingen', '', 50.2333300, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29869, 'Zetel', 'Zetel', 'Cetel,Cetel'',Zetel,ce te er,Цетел,Цетель,策特尔', 53.4166700, 7.9833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29870, 'Zernien', 'Zernien', 'Cernin,cai er ning,zrnyn,Цернин,زرنین,采尔宁', 53.0684500, 10.8832500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29871, 'Zerf', 'Zerf', '', 49.6000000, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29872, 'Zerbst', 'Zerbst', 'Cerbst,Serbisco,Serbišćo,Servesta,Zerbst,Zerbst/Anhalt,ce er bu si te,tsbrst,Цербст,تسبرست,策尔布斯特', 51.9662000, 12.0851700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29873, 'Zenting', 'Zenting', 'Centing,cen ting,zntyng,Центинг,Центінг,Ցենթինգ,زنتینگ,岑廷', 48.7912800, 13.2596800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29874, 'Zendscheid', 'Zendscheid', '', 50.1000000, 6.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29875, 'Zemmer', 'Zemmer', '', 49.9000000, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29876, 'Zell unter Aichelberg', 'Zell unter Aichelberg', 'Cel pod Ajkhelbergom,Cell''-unter-Ajkhel''berg,ai xie er shan xia cai er,Цел под Ајхелбергом,Целль-унтер-Айхельберг,艾谢尔山下采尔', 48.6488200, 9.5713700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29877, 'Zellingen', 'Zellingen', 'Celingen,Cellingen,Zellingen,ce lin gen,Целинген,Целлинген,Целлінген,Ցելինգեն,策林根', 49.8973700, 9.8174600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29878, 'Zell im Wiesental', 'Zell im Wiesental', 'Cel im Vizental,Cell'',Cell''-im-Vizental'',Zell en el Valle del Wiese,tsl dr wyzntal,tsl-am-fyzntal,wei se he gu ce er,Цел им Визентал,Целль,Целль-им-Визенталь,Целль-ім-Візенталь,تسل در ویزنتال,تسل-إم-فيزنتال,维瑟河谷策尔', 47.7055500, 7.8524800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29879, 'Zell am Main', 'Zell am Main', 'Cel na Majni,Cel''-am-Majn,Cell''-na-Majne,Zell,Zell am Main,mei yin he pan ce er,Цел на Мајни,Целль-на-Майне,Цель-ам-Майн,Մայնի Ցել,ツェル・アム・マイン,美因河畔策尔', 49.8121400, 9.8696200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29880, 'Zella-Mehlis', 'Zella-Mehlis', 'Cela-Melis,Cella-Melis,Zella-Mehlis,ce la-mei li si,tsl,tsyla-mylys,Цела-Мелис,Целла-Мелис,Целла-Меліс,تسل,تسيلا-ميليس,策拉-梅利斯', 50.6564200, 10.6604600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29881, 'Zell im Fichtelgebirge', 'Zell im Fichtelgebirge', 'Cel im Fikhtelgebirge,Cel''-im-Fikhtel''gebirge,Cell'',Zell,fei xi te er ge bi er ge shan lu ce er,zl aym fyshtl gbyrgh,Цел им Фихтелгебирге,Целль,Цель-ім-Фіхтельгебірге,زل ایم فیشتل گبیرگه,ツェル・イム・フィヒテルゲビルゲ,菲希特尔格比尔格山麓策尔', 50.1353200, 11.8226600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29882, 'Zell', 'Zell', 'Zell', 50.0291800, 7.1823200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29883, 'Zell', 'Zell', '', 48.6923500, 8.0630100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29884, 'Zeitz', 'Zeitz', 'Cajc,Ceicas,Cice [a. 1140],Zeitz,Zitc,cai ci,tsayts,tsaytz,zyyz,Žitč,Цайц,Цајц,צייץ,تسایتز,تسایتس,蔡茨', 51.0496200, 12.1369000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29885, 'Zeitlofs', 'Zeitlofs', 'Cajtlofs,Zeitlofs,cai te luo fu si,Цайтлофс,Цајтлофс,Ցայտլոֆս,蔡特洛夫斯', 50.2618900, 9.6724300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29886, 'Zeitlarn', 'Zeitlarn', '', 49.0784800, 12.1117400, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29887, 'Zeithain', 'Zeithain', 'Cajtgajn,Cajtkhajn,Cytan,Cytań,Zeithaini vald,cai tai yin,jaitin,Цайтгайн,Цайтхайн,Цајтхајн,蔡泰因,자이틴', 51.3335600, 13.3380900, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29888, 'Zeiskam', 'Zeiskam', 'Cajskam,cai si ka mu,Цайскам,Цајскам,蔡斯卡姆', 49.2327800, 8.2472200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29889, 'Zeilarn', 'Zeilarn', '', 48.3000300, 12.8426000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29890, 'Zeil', 'Zeil', 'Zeil,Zeil am Main', 50.0098600, 10.5947000, 'DE', '2017-06-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29891, 'Zehnhausen bei Wallmerod', 'Zehnhausen bei Wallmerod', '', 50.4761100, 7.9236100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29892, 'Zehnhausen bei Rennerod', 'Zehnhausen bei Rennerod', '', 50.6472200, 8.0597200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29893, 'Zehlendorf', 'Zehlendorf Bezirk', 'Berlin-Zehlendorf,Celendorf,Zehlendorf  Berlin,zlndwrp,Целендорф,צלנדורף', 52.4333300, 13.2500000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29894, 'Zehdenick', 'Zehdenick', 'Cedenik,Zehdenik,ce de ni ke,tshdnyk,tsyhdynk,Цеденик,Զեհդենիկ,تسهدنیک,تسيهدينك,策德尼克', 52.9785200, 13.3316500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29895, 'Zedlitz', 'Zedlitz', 'Cedlic,Zedlitz,ce de li ci,Цедлиц,策德利茨', 50.8166700, 12.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29896, 'Zechin', 'Zechin', '', 52.6084200, 14.4525100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29897, 'Zarrentin', 'Zarrentin', 'Zarrentin', 53.5507500, 10.9155000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29898, 'Zarrendorf', 'Zarrendorf', '', 54.2368900, 13.1009400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29899, 'Zarpen', 'Zarpen', 'Zarpen', 53.8666700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29900, 'Zappendorf', 'Zappendorf', 'Zappendorf', 51.5102400, 11.7951400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29901, 'Zapfendorf', 'Zapfendorf', 'Capfendorf,cha pu fen duo fu,tsu~apufendorufu,Цапфендорф,Ցապֆենդորֆ,ツァプフェンドルフ,察普芬多夫', 50.0178300, 10.9324300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29902, 'Zangberg', 'Zangberg', 'Cangberg,cang bei ge,zangbrg,Цангберг,Ցանգբերգ,زانگبرگ,仓贝格', 48.2748000, 12.4231100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29903, 'Zandt', 'Zandt', 'Candt,Cant,can te,Цандт,Цант,Ցանթ,灿特', 49.1500000, 12.7333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29904, 'Zaisenhausen', 'Zaisenhausen', 'Cajsenkhauzen,Cajzengauzen,Cajzenkhauzen,cai sen hao sen,Цайзенгаузен,Цайзенхаузен,Цајсенхаузен,蔡森豪森', 49.1066700, 8.8127800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29905, 'Zahna', 'Zahna', 'Cana,Zahna,Цана,ذہنا', 51.9141000, 12.7856100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29906, 'Zachenberg', 'Zachenberg', 'Cakhenberg,cha heng bei ge,zakhnbrg,zchnbrg,Цахенберг,Ցախենբերգ,زاخنبرگ,زچنبرگ,察亨贝格', 48.9666700, 13.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29907, 'Zaberfeld', 'Zaberfeld', 'Caberfel''d,Caberfeld,cha bei er fei er de,tsu~abaferuto,zabr fyld,Цаберфелд,Цаберфельд,زابر فیلد,ツァーバーフェルト,察贝尔费尔德', 49.0561100, 8.9269400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29908, 'Zabeltitz', 'Zabeltitz', 'Cabel''tic,Cabeltic,Zabeltitz,Zabeltitzi vald,zabl tts,Цабелтиц,Цабельтиц,زابل تتس', 51.3514700, 13.5046200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29909, 'Xanten', 'Xanten', 'Gorad Ksantehn,Ksanten,Sante,Santen,Xanten,Xantum,ke sang teng,kusanten,Горад Ксантэн,Ксантен,クサンテン,克桑滕', 51.6587700, 6.4529700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29910, 'Wyk auf Föhr', 'Wyk auf Foehr', 'A Wik,De Wyk,OHR,Vik auf Fer,Vik na Fer,Vik-auf-Fjor,Vyk,Wik,Wyck,Wyk,Wyk auf Foehr,Wyk auf Föhr,Wyk op Feer,fyk awf fwr,wei ke ao fu fu he er,wyk an dr fwr,Вик ауф Фер,Вик на Фер,Вик-ауф-Фёр,فيك آوف فور,ویک آن در فور,维克奥夫弗赫尔', 54.6914000, 8.5670200, 'DE', '2017-01-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29911, 'Wyhl', 'Wyhl', 'Wyhl', 48.1661700, 7.6491700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29912, 'Wutöschingen', 'Wutoeschingen', 'Vuteshingen,Vutjoshingen,Wutoeschingen,Wutoschingen,Wutöschingen,wu te xin gen,Вутешинген,Вутёшинген,武特欣根', 47.6601900, 8.3675500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29913, 'Wustrow', 'Wustrow', '', 53.4776500, 13.1556900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29914, 'Wustrow', 'Wustrow', 'Vustrov,fwstrw,wu si te luo fu,wwstrw,Вустров,فوسترو,ووسترو,武斯特罗夫', 52.9237000, 11.1284600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29915, 'Wüstheuterode', 'Wuestheuterode', 'Wuestheuterode,Wüstheuterode', 51.3233200, 10.0590200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29916, 'Wusterwitz', 'Wusterwitz', 'Grosswusterwitz,Großwusterwitz,Vustervic,Wusterwitz,wu si te er wei ci,Вустервиц,Վուստերվից,武斯特尔维茨', 52.3666600, 12.3848800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29917, 'Wustermark', 'Wustermark', 'Vustermark,Wustermark,wu si te ma ke,Вустермарк,Վուստերմարկ,武斯特马克', 52.5500000, 12.9500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29918, 'Wusterhusen', 'Wusterhusen', 'Vusterkhusen,Vusterkhuzen,Wusterhusen,wu si te lu sen,Вустерхузен,Вустерхусен,武斯特鲁森', 54.1131200, 13.6160800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29919, 'Wusterhausen', 'Wusterhausen', 'Wusterhausen/Dosse', 52.8912000, 12.4602100, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29920, 'Wüstenrot', 'Wustenrot', 'Vistenrot,Vjustenrot,Wuestenrot,Wüstenrot,vu~yusutenroto,wei si teng luo te,Вистенрот,Вюстенрот,ヴュステンロート,维斯滕罗特', 49.0808300, 9.4605600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29921, 'Wüschheim', 'Wuschheim', '', 50.0166700, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29922, 'Würzweiler', 'Wurzweiler', '', 49.6500000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29923, 'Wurzen', 'Wurzen', 'Gorad Vurcehn,Vurcen,Vurcene,Worcyn,Wurzen,fwrtsn,wu er cen,wwrtsn,Вурцен,Горад Вурцэн,فورتسن,وورتسن,武尔岑', 51.3707000, 12.7393900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29924, 'Würzburg', 'Wuerzburg', 'Birtsmpournk,Gorad Vjurcburg,Herbipolis,Herbopolis,Vircburg,Vircburga,Virteburh [a. 704],Virtibriga,Viurcburgas,Vjurcburg,Vuirziburga [a. 779],Vyurcʻburg,Wiazburg,Wirciburc,Wirzaburg [a. 742],Wirziburg [a. 779],Wuerzboerj,Wuerzburg,Wurtzbourg,Wurtzburgo,Wurzburg,Wurzburgo,Wûrzburg,Würzburg,Würzbörj,bwileucheubuleukeu,fwrtsbwrgh,viurtsburgi,vu~yurutsuburuku,wei er ci bao,weu xr sburk,wrzbrg,wwrtsbwrg,wyrzbwrg,Βίρτσμπουργκ,Вирцбург,Вюрцбург,Горад Вюрцбург,Վյուրցբուրգ,וירצבורג,فورتسبورغ,ورزبرگ,وورتسبورگ,เวือร์ซบูร์ก,ვიურცბურგი,ヴュルツブルク,维尔茨堡,뷔르츠부르크', 49.7939100, 9.9512100, 'DE', '2014-12-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29925, 'Wurzbach', 'Wurzbach', 'Vurcbakh,Wurzbach,fwrtsbakh,wu er ci ba he,wwrtsbakh,Вурцбах,فورتسباخ,وورتسباخ,武尔茨巴赫', 50.4635700, 11.5377900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29926, 'Würselen', 'Wuerselen', 'Virselen,Vjurzelen,Woeschele,Woesjele,Wuerselen,Wurselen,Wöschele,Wösjele,Würselen,fwrsln,wei er sai lun,wwrsln,Вирселен,Вюрзелен,فورسلن,وورسلن,维尔塞伦', 50.8180900, 6.1347000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29927, 'Würrich', 'Wurrich', '', 49.9833300, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29928, 'Wurmsham', 'Wurmsham', 'Vurmsgam,Vurmsham,Vurmskham,wu er mu si ha mu,wwrmsham,Вурмсгам,Вурмсхам,Վուրմսհամ,وورمسهام,武尔姆斯哈姆', 48.3500000, 12.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29929, 'Wurmlingen', 'Wurmlingen', '', 48.0000000, 8.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29930, 'Wurmberg', 'Wurmberg', 'Vurmberg,wu er mu bei ge,Вурмберг,Վուրմբերգ,武尔姆贝格', 48.8666700, 8.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29931, 'Wurmannsquick', 'Wurmannsquick', 'Vurmannskvik,Vurmanskvik,Wurmannsquick,wu er man si ku yi ke,wwrmanskwyk,Вурманнсквік,Вурмансквик,Վուրմանսքվիք,وورمانسکویک,武尔曼斯库伊克', 48.3533400, 12.7860300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29932, 'Wuppertal', 'Wuppertal', 'Boupertal,Gorad Vupertal'',UWP,Vupertal,Vupertale,Vupertalis,Vupertāle,Vuppertal,Vuppertal'',Wupperdaal,Wuppertal,bupeotal,fwbrtal,vupartala,vuppataru,wu po ta er,wuph phe xrthal,wwprtal,wwprtl,Βούπερταλ,Вупертал,Вупперталь,Горад Вуперталь,Վուպերտալ,וופרטל,فوبرتال,ووپاٹال,ووپرتال,وپرٹال,वुपर्टाल,วุพเพอร์ทัล,ვუპერტალი,ヴッパータール,伍珀塔尔,부퍼탈', 51.2702700, 7.1675500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29933, 'Wunstorf', 'Wunstorf', 'Vunstorf,Wunstorf,fwnstwrf,wen si tuo fu,wwnstwrf,Вунсторф,فونستورف,وونستورف,文斯托夫', 52.4237700, 9.4358500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29934, 'Wunsiedel', 'Wunsiedel', 'Vunsidel,Vunzidel,Vunzidel'',Wunsiedel,Wunsiedel im Fichtelgebirge,fwnzydl,vunjideru,wen xi de er,wwnzydl,Вунзидель,Вунзідель,Вунсидел,Վունզիդել,فونزيدل,وونزیدل,ヴンジーデル,文西德尔', 50.0392300, 12.0034200, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29935, 'Wünschendorf', 'Wuenschendorf', 'Wuenschendorf/Elster,Wünschendorf/Elster', 50.7966200, 12.0982400, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29936, 'Wünnenberg', 'Wuennenberg', 'Bad Wuennenberg,Bad Wünnenberg', 51.5200200, 8.6993400, 'DE', '2017-07-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29937, 'Wundersleben', 'Wundersleben', '', 51.1544500, 11.0388500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29938, 'Wulsbüttel', 'Wulsbuettel', 'Gemeen Wolsbuddel,Vul''sbjuttel'',Vulsbitel,Wulsbuettel,Wulsbüttel,wu er si bi te er,Вулсбител,Вульсбюттель,武尔斯比特尔', 53.3166700, 8.6666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29939, 'Wülknitz', 'Wulknitz', 'Vilknic,Vjul''knic,Wuelknitzi vald,Wülknitzi vald,wei er ke ni ci,Вилкниц,Вюлькниц,Вюлькніц,维尔克尼茨', 51.3666700, 13.4000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29940, 'Wulkenzin', 'Wulkenzin', '', 53.5444500, 13.1692100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29941, 'Wulften', 'Wulften', '', 51.6599900, 10.1743700, 'DE', '2011-03-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29942, 'Wulfsmoor', 'Wulfsmoor', 'Wulfsmoor', 53.9123300, 9.7240200, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29943, 'Wulfsen', 'Wulfsen', 'Vul''fzen,Vulfsen,Wulfsen,wu er fu sen,Вулфсен,Вульфзен,武尔夫森', 53.3000000, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29944, 'Wülfrath', 'Wuelfrath', 'Vilfrat,Viulfratas,Vjul''frat,Wuelfrath,Wülfrath,fwlfrat,wei er fu la te,wwlfrat,Вилфрат,Вюльфрат,فولفرات,وولفرات,维尔夫拉特', 51.2819500, 7.0382100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29945, 'Wülfershausen', 'Wuelfershausen', 'Wulfershausen,Wülfershausen', 50.3320100, 10.3408400, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29946, 'Wulfen', 'Wulfen', 'Wulfen', 51.8193800, 11.9306300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29947, 'Wrohm', 'Wrohm', 'Wrohm', 54.2130500, 9.3821200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29948, 'Wrixum', 'Wrixum', '', 54.6999300, 8.5485600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29949, 'Wrist', 'Wrist', 'Wrist', 53.9333300, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29950, 'Wriezen', 'Wriezen', 'Vricen,Vuritza,frytsn,fu li cen,wrytsn,Врицен,Վրիցեն,فريتسن,وریتسن,弗里岑', 52.7209100, 14.1342500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29951, 'Wriedel', 'Wriedel', 'Vridel,Vridel'',fu li de er,Вридел,Вридель,弗里德尔', 53.0313000, 10.2984800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29952, 'Wrestedt', 'Wrestedt', 'Vreshtedt,Vreshtet,Врештедт,Врештет', 52.9043500, 10.5749400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29953, 'Wremen', 'Wremen', 'Vremen,fu lei men,Времен,弗雷门', 53.6500000, 8.5166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29954, 'Wössingen', 'Woessingen', '', 49.0120500, 8.6075400, 'DE', '2013-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29955, 'Wörthsee', 'Woerthsee', 'Woerthsee,Wörthsee', 48.0725000, 11.2017500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29956, 'Wörth an der Isar', 'Worth an der Isar', 'Vert an der Izar,Vert-an-der-Izar,Vjort-na-Izare,Woerth,Wort,Worth an der Isar,Wörth,Wörth an der Isar,wrt an dr ayzar,Верт ан дер Изар,Верт-ан-дер-Ізар,Вёрт-на-Изаре,Իզարի Վյորթ,ورت آن در ایزار', 48.6230000, 12.3394400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29957, 'Wörth an der Donau', 'Worth an der Donau', 'Vert na Dunavu,Vert-an-der-Donau,Vjort-an-der-Donau,Vjort-na-Dunae,Werth,Wiard,Woerth an der Donau,Worth,Worth an der Donau,Wörth,Wörth an der Donau,duo nao he pan wei er te,fwrt an dr dwnaw,wrt an dr dnaw,Верт на Дунаву,Верт-ан-дер-Донау,Вёрт-ан-дер-Донау,Вёрт-на-Дунае,Դանուբի Վյորթ,فورت أن در دوناو,ورت آن در دناو,多瑙河畔韦尔特', 49.0009300, 12.4053900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29958, 'Wörth am Rhein', 'Woerth am Rhein', 'Vert na Rajni,Vjort-am-Rajn,Vjort-na-Rejne,Woerth am Rhein,Worth,Worth am Rhein,Wörth,Wörth am Rhein,fwrth am rayn,lai yin he pan wei er te,wwrth an dr rayn,Верт на Рајни,Вёрт-ам-Райн,Вёрт-на-Рейне,فورث آم راين,وورث آن در راین,莱茵河畔韦尔特', 49.0488800, 8.2595900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29959, 'Wörth am Main', 'Worth am Main', 'Majndagy Vjort,Vert na Majni,Vert-am-Majn,Vjort-na-Majne,Worth,Worth am Main,Wörth,Wörth am Main,fwrt am mayn,mei yin he pan wei er te,wwrth am mayn,Верт на Мајни,Верт-ам-Майн,Вёрт-на-Майне,Майндагы Вёрт,Մայնի Վյորթ,فورت آم ماين,وورث آم ماین,ヴェルト・アム・マイン,美因河畔韦尔特', 49.7972000, 9.1538900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29960, 'Worth', 'Worth', '', 53.4666700, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29961, 'Wört', 'Wort', 'Vert,Vjort,Верт,Вёрт,ვერტი', 49.0304700, 10.2723900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29962, 'Wörrstadt', 'Worrstadt', 'Vershtat,Vjorshtadt,Woerrstadt,Wörrstadt,wwrashtat,Верштат,Вёрштадт,ووراشتات', 49.8486100, 8.1241700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29963, 'Worpswede', 'Worpswede', '', 53.2166700, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29964, 'Wörnersberg', 'Wornersberg', '', 48.5666700, 8.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29965, 'Worms', 'Worms', 'Borbetomagus,Gorad Vorms,Vormatia,Vorms,Vormsa,Vormsas,Woms,Wormacja,Wormatia,Worms,ZQV,boleumseu,fwrms,vu~orumusu,wo er mu si,wrmz  alman,wwrms,Βορμς,Вормс,Горад Вормс,ווארמז,וורמס,فورمس,ورمز، آلمان,ቩርምዝ,ヴォルムス,沃尔姆斯,보름스', 49.6327800, 8.3591600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29966, 'Wörlitz', 'Woerlitz', 'Verlic,Vjorlic,Worlitz,Wörlitz,Верлиц,Вёрлиц,Вөрлиц', 51.8417200, 12.4211600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29967, 'Woringen', 'Woringen', 'Voringen,wo lin gen,Воринген,Ворінген,Վորինգեն,沃林根', 47.9166700, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29968, 'Worbis', 'Worbis', '', 51.4199700, 10.3633000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29969, 'Woppenroth', 'Woppenroth', '', 49.8666700, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29970, 'Wonsheim', 'Wonsheim', '', 49.7833300, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29971, 'Wonsees', 'Wonsees', 'Vonzes,Wonsees,vu~onzesu,weng sai si,Вонзес,Վոնզես,ヴォンゼース,翁塞斯', 49.9761400, 11.3004700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29972, 'Wonfurt', 'Wonfurt', 'Vonfurt,weng fu er te,Вонфурт,Վոնֆուրթ,翁富尔特', 50.0166700, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29973, 'Womrath', 'Womrath', '', 49.9166700, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29974, 'Woltershausen', 'Woltershausen', '', 51.9833300, 9.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29975, 'Woltersdorf', 'Woltersdorf', '', 53.5726700, 10.6432000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29976, 'Woltersdorf', 'Woltersdorf', 'Vol''tersdorf,Voltersdorf,wltrsdwrf,Волтерсдорф,Вольтерсдорф,ولترسدورف', 52.9500000, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29977, 'Woltersdorf', 'Woltersdorf', 'Woltersdorf', 52.4500000, 13.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29978, 'Wolsfeld', 'Wolsfeld', '', 49.9070200, 6.4659700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29979, 'Wolsdorf', 'Wolsdorf', '', 52.1909800, 10.9387800, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29980, 'Wölpinghausen', 'Wolpinghausen', 'Velpingkhauzen,Vjol''pingkhauzen,vu~erupinguhauzen,wei er ping hao sen,Велпингхаузен,Вёльпингхаузен,ヴェルピングハウゼン,韦尔平豪森', 52.4166700, 9.2333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29981, 'Wolpertswende', 'Wolpertswende', 'Vol''pertsvende,Volpertsvende,Wolpertswende,wo er pei er ci wen de,Волпертсвенде,Вольпертсвенде,沃尔佩尔茨文德', 47.8947100, 9.6120200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29982, 'Wolpertshausen', 'Wolpertshausen', 'Vol''pertsgauzen,Vol''pertskhauzen,Volpertskhauzen,Wolpertshausen,vu~orupatsuhauzen,wo er pei er ci hao sen,Волпертсхаузен,Вольпертсгаузен,Вольпертсхаузен,ヴォルパーツハウゼン,沃尔佩尔茨豪森', 49.1675000, 9.8447200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29983, 'Wolnzach', 'Wolnzach', 'Vol''ncakh,Volncakh,wlntsakh,wo er en cha,Волнцах,Вольнцах,Վոլնցախ,ولنتساخ,沃尔恩察', 48.6038000, 11.6256800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29984, 'Wolmirstedt', 'Wolmirstedt', 'Walmirstidi,Wolmirstedt', 52.2485600, 11.6294500, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29985, 'Wolmirsleben', 'Wolmirsleben', 'Wilmersleve,Wolmirsleben', 51.9500000, 11.4833300, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29986, 'Wölmersen', 'Wolmersen', '', 50.7166700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29987, 'Wolmersdorf', 'Wolmersdorf', 'Wolmersdorf', 54.0765200, 9.1024800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29988, 'Wöllstein', 'Wollstein', 'Velshtajn,Vjoll''shtajn,Woellstein,Wöllstein,wei er si tai yin,Велштајн,Вёлльштайн,韦尔斯泰因', 49.8166700, 7.9666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29989, 'Wollmerath', 'Wollmerath', '', 50.1500000, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29990, 'Wollin', 'Wollin', '', 52.2833300, 12.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29991, 'Wollershausen', 'Wollershausen', '', 51.6000000, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29992, 'Wollbrandshausen', 'Wollbrandshausen', 'Vol''brandskhauzen,Volbrandskhauzen,vu~oruburantsuhauzen,wo er bu lan ci hao sen,Волбрандсхаузен,Вольбрандсхаузен,ヴォルブランツハウゼン,沃尔布兰茨豪森', 51.5833300, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29993, 'Wollbach', 'Wollbach', '', 50.3666700, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29994, 'Wolkramshausen', 'Wolkramshausen', 'Vol''kramskhauzen,Volkramskhauzen,wo er ke la mu si hao sen,Волкрамсхаузен,Волькрамсхаузен,沃尔克拉姆斯豪森', 51.4218500, 10.7381500, 'DE', '2012-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29995, 'Wolkenstein', 'Wolkenstein', 'Wolkenstein', 50.6555200, 13.0713200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29996, 'Wolken', 'Wolken', '', 50.3333300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29997, 'Wolgast', 'Wolgast', 'Vol''gast,Volgast,Volgaste,Wolegoszcza,Wolgast,Wologoszcz,Wołogoszcz,Wòlëgòszcza,fwlghast,vu~orugasuto,wlgast,wo er jia si te,Волгаст,Вольгаст,فولغاست,ولگاست,ヴォルガスト,沃尔加斯特', 54.0527500, 13.7720100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29998, 'Wolfstein', 'Wolfstein', 'Vol''fshtajn,Volfshtajn,Wolfstein,fwlfshtayn,vu~orufushutain,wo er fu si tai yin,Волфштајн,Вольфштайн,فولفشتاين,ولف‌اشتاین,ヴォルフシュタイン,沃尔夫斯泰因', 49.5841100, 7.6049600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(29999, 'Wolfsheim', 'Wolfsheim', '', 49.8722200, 8.0394400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30000, 'Wolfsegg', 'Wolfsegg', '', 49.1073100, 11.9781000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30001, 'Wolfschlugen', 'Wolfschlugen', 'Vol''fshlugen,Volfshlugen,Volfslugen,Wolfschlugen,wo er fu shi lu gen,Волфшлуген,Вольфшлуген,Վոլֆշլուգեն,沃尔夫施卢根', 48.6500000, 9.2833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30002, 'Wolfsburg-Unkeroda', 'Wolfsburg-Unkeroda', 'Vol''fsburg-Unkeroda,Volfsburg-Unkeroda,Wolfsburg-Unkeroda,wo er fu si bu er ge-weng ke luo da,Волфсбург-Ункерода,Вольфсбург-Ункерода,沃尔夫斯布尔格-翁克罗达', 50.9333300, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30003, 'Wolfsburg', 'Wolfsburg', 'BWE,Gorad Vol''fsburg,Vol''fsburg,Volfsburg,Volfsburgas,Volfsmpournk,Wolfsboerj,Wolfsbourg,Wolfsburg,Wolfsburgo,Wolfsbuurich,Wolfsbörj,Wulfsborg,bolpeuseubuleukeu,fwlfsbwrgh,volpsburgi,vu~orufusuburuku,wlfzbrg,wo er fu si bao,wwlfsbwrg,wwlfzbwrg,wwlpsbwrg,Βόλφσμπουργκ,Волфсбург,Вольфсбург,Горад Вольфсбург,Վոլֆսբուրգ,וולפסבורג,فولفسبورغ,ولفزبرگ,وولفزبورگ,وولفسبورگ,ვოლფსბურგი,ヴォルフスブルク,沃尔夫斯堡,볼프스부르크', 52.4245200, 10.7815000, 'DE', '2016-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30004, 'Wolfratshausen', 'Wolfratshausen', 'Vol''fratsgauzen,Vol''fratskhauzen,Volfratshauzen,Volfratskhauzen,fwlfratshawzn,wlfratzhawzn,wo er fu la ci hao sen,Волфратсхаузен,Вольфратсгаузен,Вольфратсхаузен,Վոլֆրատսհաուզեն,فولفراتسهاوزن,ولفراتزهاوزن,沃尔夫拉茨豪森', 47.9128900, 11.4216600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30005, 'Wolframs-Eschenbach', 'Wolframs-Eschenbach', 'Velframs Esenbax,Vol''frams-Ehshenbakh,Vol''frams-Eshenbakh,Volframs-Eshenbakh,Wolframs-Eschenbach,fwlframz-ashnbakh,vu~orufuramusu=esshenbahha,wlframz-ashnbakh,wo er fu la mu si-ai shen ba,Волфрамс-Ешенбах,Вольфрамс-Ешенбах,Вольфрамс-Эшенбах,Վելֆրամս Էշենբախ,فولفرامز-إشنباخ,ولفرامز-اشنباخ,ヴォルフラムス＝エッシェンバッハ,沃尔夫拉姆斯-埃申巴', 49.2267500, 10.7276900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30006, 'Wölfis', 'Woelfis', 'Wolfis,Wölfis', 50.8082500, 10.7790500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30007, 'Wolfhagen', 'Wolfhagen', 'Vol''fgagen,Vol''fkhagen,Volfkhagen,Wolfhagen,fwlfhaghn,vu~orufuhagen,wlfhagn,wo er fu ha gen,Волфхаген,Вольфгаген,Вольфхаген,فولفهاغن,ولفهاگن,ヴォルフハーゲン,沃尔夫哈根', 51.3261100, 9.1701500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30008, 'Wolfertschwenden', 'Wolfertschwenden', 'Vol''ferchvenden,Vol''fertshvenden,Volferchvenden,wo er fei er ci xi wen deng,Волферчвенден,Вольфертшвенден,Вольферчвенден,Վոլֆերթշվենդեն,沃尔费尔茨希文登', 47.8935000, 10.2671500, 'DE', '2012-10-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30009, 'Wolferstadt', 'Wolferstadt', 'Vol''fershtadt,Volfershtat,vu~orufashutatto,wo er fei er si ta te,Волферштат,Вольферштадт,Վոլֆերշթաթ,ヴォルファーシュタット,沃尔费尔斯塔特', 48.9035200, 10.7812900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30010, 'Wölfersheim', 'Wolfersheim', 'Vel''fersgajm,Velferskhajm,Vjol''ferskhajm,Woelfersheim,Wölfersheim,vu~erufasuhaimu,wei er fei er si hai mu,Велферсхајм,Вельферсгайм,Вёльферсхайм,ヴェルファースハイム,韦尔费尔斯海姆', 50.4000000, 8.8166700, 'DE', '2015-01-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30011, 'Wölfershausen', 'Wolfershausen', '', 50.4833300, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30012, 'Wolfersdorf', 'Wolfersdorf', '', 48.5500000, 11.7666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30013, 'Wolfersdorf', 'Wolfersdorf', 'Vol''fersdorf,Volfersdorf,Wolfersdorf,Wolferstorf,wlfrsdwrf,wo er fu si duo fu,Волферсдорф,Вольферсдорф,Վոլֆերսդորֆ,ولفرسدورف,沃尔弗斯多夫', 48.4793700, 11.7094900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30014, 'Wolferschwenda', 'Wolferschwenda', 'Wolferschwenda', 51.2333300, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30015, 'Wolferode', 'Wolferode', '', 51.5065000, 11.5129900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30016, 'Wölferlingen', 'Wolferlingen', 'Woelferlingen,Wölferlingen', 50.5644400, 7.8511100, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30017, 'Wölferbütt', 'Woelferbuett', '', 50.7666700, 10.0500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30018, 'Wolfenbüttel', 'Wolfenbuettel', 'Guelpherbytum,Vol''fenbjuttel'',Volfembutel,Volfenbitel,Volfenbjutel,Wolfenbuettel,Wolfenbuttel,Wolfenbüttel,Wulfenbuettel,Wulfenbüttel,fwlfnbwtl,wlfnbwtl,wo er fen bi te er,Волфенбител,Волфенбютел,Вольфенбюттель,فولفنبوتل,ولفنبوتل,沃爾芬比特爾', 52.1644200, 10.5409500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30019, 'Wolfen', 'Wolfen', 'Gorad Vol''fen,Vol''fen,Volfen,Wolfen,Волфен,Вольфен,Горад Вольфен', 51.6612200, 12.2687300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30020, 'Wolfegg', 'Wolfegg', 'Vol''fegg,Volfeg,wo er fei ge,Волфег,Вольфегг,沃尔费格', 47.8203000, 9.7949100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30021, 'Wolfach', 'Wolfach', 'Vol''fakh,Volfakh,Wolfach,fwlfakh,wlfakh,wo er fa,Волфах,Вольфах,فولفاخ,ولفاخ,沃尔法', 48.2931900, 8.2158000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30022, 'Woldert', 'Woldert', '', 50.6000000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30023, 'Woldegk', 'Woldegk', 'Vol''degk,Voldeg,Voldegka,Voldek,Woldegk,fwldk,wldgk,wo er de ge ke,Волдег,Волдек,Вольдегк,فولدك,ولدگک,沃尔德格克', 53.4605800, 13.5835600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30024, 'Wöhrden', 'Wohrden', 'Verden,Vjorden,Woehrden,Wöhrden,wei he er deng,Верден,Вёрден,韦赫尔登', 54.1666700, 9.0000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30025, 'Wohnste', 'Wohnste', '', 53.3500000, 9.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30026, 'Wohnbach', 'Wohnbach', '', 50.4286400, 8.8292300, 'DE', '2017-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30027, 'Wohltorf', 'Wohltorf', 'Vol''torf,Voltorf,Wohltorf,wo er tuo er fu,Волторф,Вольторф,沃尔托尔夫', 53.5166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30028, 'Wohlsborn', 'Wohlsborn', '', 51.0333300, 11.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30029, 'Wohldorf-Ohlstedt', 'Wohldorf-Ohlstedt', 'Hamburg-Ohlstedt,Hamburg-Wohldorf,Wohldorf-Ohlstedt', 53.6928200, 10.1311700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30030, 'Wohlde', 'Wohlde', '', 54.4061400, 9.2989000, 'DE', '2012-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30031, 'Wobbenbüll', 'Wobbenbull', 'Wobbenbull,Wobbenbüll', 54.5333300, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30032, 'Witzwort', 'Witzwort', 'Vicvort,Vitsvort,Witswort,Witzwort,wei ci wo er te,Вицворт,维茨沃尔特', 54.4000000, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30033, 'Witzmannsberg', 'Witzmannsberg', '', 48.7166700, 13.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30034, 'Witzmannsberg', 'Witzmannsberg', '', 48.6222400, 13.4944400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30035, 'Witzleben', 'Witzleben', '', 50.8166700, 11.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30036, 'Witzhave', 'Witzhave', 'Witzhave', 53.5666700, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30037, 'Witzenhausen', 'Witzenhausen', 'Vicenkhauzen,Vitcengauzen,Vitcenkhauzen,Vitsenhauzen,Witzenhausen,Witzenhusa,fytsnhawzn,vu~ittsu~enhauzen,wei cen hao sen,Витценхаузен,Виценхаузен,Вітценгаузен,فيتسنهاوزن,ویتسن‌هاوزن,ヴィッツェンハウゼン,维岑豪森', 51.3410300, 9.8554000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30038, 'Witzeeze', 'Witzeeze', 'Witzeeze', 53.4515300, 10.6079600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30039, 'Wittstock', 'Wittstock', '', 53.1611800, 12.4828700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30040, 'Wittorf', 'Wittorf', 'Vitorf,Vittorf,Wittoerp,Wittörp,wei tuo fu,Виторф,Витторф,维托夫', 53.3333300, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30041, 'Wittorf', 'Wittorf', '', 53.0120700, 9.5167500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30042, 'Wittnau', 'Wittnau', 'Wittnau', 47.9500000, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30043, 'Wittmund', 'Wittmund', 'Vitmund,Witmundi,Wittmund,fytmwnd,wei te meng de,wytmwnd,Витмунд,فيتموند,ویتموند,维特蒙德', 53.5767400, 7.7783900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30044, 'Wittmoldt', 'Wittmoldt', 'Wittmoldt', 54.1666700, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30045, 'Wittmar', 'Wittmar', '', 52.1296900, 10.6400000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30046, 'Wittlingen', 'Wittlingen', 'Vitlingen,Vittlingen,Wittlingen,wei te lin gen,Витлинген,Віттлінген,维特林根', 47.6552700, 7.6511200, 'DE', '2013-04-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30047, 'Wittlich', 'Wittlich', 'Vitlikh,Vittlikh,Wittlech,Wittlich,fytlysh,vu~ittorihi,wei te li xi,wytlysh,Витлих,Виттлих,فيتليش,ویتلیش,ვიტლიხი,ヴィットリヒ,维特利希', 49.9859600, 6.8930800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30048, 'Wittislingen', 'Wittislingen', 'Vitislingen,Vittislingen,Wittislingen,wei di si lin gen,wytyslyngn,Витислинген,Виттислинген,Віттіслінген,Վիտիսլինգեն,ویتیسلینگن,维蒂斯林根', 48.6191700, 10.4172200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30049, 'Wittingen', 'Wittingen', 'Vitingen,Vittingen,fytynghn,wei ting gen,wytyngn,Витинген,Виттинген,فيتينغن,ویتینگن,维廷根', 52.7269400, 10.7361300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30050, 'Wittichenau', 'Wittichenau', 'Kulow,Vitihenava,Vitikhenau,Vittikhenau,Wittichenau,Wittichenau/Kulow,fytyshynaw,wei di xie nao,wytyshnaw,Витихенау,Виттихенау,فيتيشيناو,ویتیشناو,维蒂歇瑙', 51.3849600, 14.2440300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30051, 'Wittibreut', 'Wittibreut', '', 48.3292100, 12.9870400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30052, 'Wittgert', 'Wittgert', '', 50.5000000, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30053, 'Wittgensdorf', 'Wittgensdorf', '', 50.8831600, 12.8703100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30054, 'Wittgendorf', 'Wittgendorf', '', 50.6000000, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30055, 'Witterda', 'Witterda', 'Viterda,Vitterda,wei te er da,Витерда,Виттерда,维特尔达', 51.0361500, 10.8902800, 'DE', '2016-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30056, 'Wittenhagen', 'Wittenhagen', '', 54.1837900, 13.0713300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30057, 'Wittenförden', 'Wittenfoerden', 'Wittenfoerden,Wittenförden', 53.6291700, 11.3298200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30058, 'Wittenburg', 'Wittenburg', 'Vitenburg,Vitenburga,Vittenburg,Wittenburg,fytnbwrgh,wei teng bao,wytnbwrg,Витенбург,Виттенбург,فيتنبورغ,ویتنبورگ,维滕堡', 53.5059900, 11.0804900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30059, 'Wittenborn', 'Wittenborn', '', 53.9220000, 10.2206500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30060, 'Wittenbergen', 'Wittenbergen', '', 53.9334500, 9.6860800, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30061, 'Wittenberge', 'Wittenberge', 'Vitenberge,Vittenberge,Wittenberge,wei teng bei ge,wytnbrg,Витенберге,Виттенберге,ویتنبرگ,维滕贝格', 53.0054300, 11.7503200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30062, 'Wittenau', 'Wittenau', 'Berlin-Wittenau', 52.5931900, 13.3212700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30063, 'Witten', 'Witten', 'Gorad Vitehn,Viten,Vitenas,Vitten,Witten,ZQR,biten,fytn,vu~itten,wei teng,wytn,Витен,Виттен,Віттен,Горад Вітэн,فيتن,ویتن,ویٹن,ヴィッテン,维滕,비텐', 51.4436200, 7.3525800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30064, 'Wittelshofen', 'Wittelshofen', 'Vitelshofen,Vitelskhofen,Vittel''sgofen,Vittel''skhofen,Wittelshofen,vu~itterusuhofen,wei te er si huo fen,Вителсхофен,Виттельсхофен,Віттельсгофен,Վիտելսհոֆեն,ヴィッテルスホーフェン,维特尔斯霍芬', 49.0612100, 10.4812100, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30065, 'Wittdün', 'Wittdun', 'Wittduen,Wittdün', 54.6269500, 8.3893500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30066, 'Wittbek', 'Wittbek', 'Wittbek', 54.4666700, 9.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30067, 'Witsum', 'Witsum', 'Witsum auf Foehr,Witsum auf Föhr', 54.6994700, 8.4405700, 'DE', '2013-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30068, 'Wistedt', 'Wistedt', '', 53.2666700, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30069, 'Wißmannsdorf', 'Wissmannsdorf', '', 49.9833300, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30070, 'Wissen', 'Wissen', 'Wissen', 50.7791500, 7.7346600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30071, 'Wismar', 'Wismar', 'Gorad Vismar,Vismar,Vismara,Vismaras,Vismāra,Vizmar,Wismar,Wismer,Wysmar,Wyszomierz,vismari,vu~isumaru,wei si ma,wysmar,wysmr,Визмар,Висмар,Вісмар,Горад Вісмар,Վիսմար,ויסמר,ويسمار,ویسمار,ვისმარი,ヴィスマール,维斯马', 53.8931400, 11.4528600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30072, 'Wischhafen', 'Wischhafen', 'Vishkhafen,Wischhoben,vu~ishuhafen,wei sha fen,Вишхафен,ヴィシュハーフェン,维沙芬', 53.7833300, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30073, 'Wisch', 'Wisch', '', 54.4108000, 10.3427900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30074, 'Wisch', 'Wisch', '', 54.4166700, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30075, 'Wirschweiler', 'Wirschweiler', '', 49.7666700, 7.1666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30076, 'Wirscheid', 'Wirscheid', '', 50.4666700, 7.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30077, 'Wirsberg', 'Wirsberg', 'Virsberg,Wirsberg,vu~irusuberuku,wei er si bei ge,Вирсберг,Вірсберг,Վիրսբերգ,ヴィルスベルク,维尔斯贝格', 50.1057200, 11.6051500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30078, 'Wirges', 'Wirges', 'Virges,Wirges,fyrghs,vu~irugesu,wei er ge si,wyrgs,Виргес,فيرغس,ویرگس,ヴィルゲス,维尔格斯', 50.4719500, 7.7984400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30079, 'Wirfus', 'Wirfus', '', 50.2000000, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30080, 'Wirft', 'Wirft', '', 50.3666700, 6.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30081, 'Wirdum', 'Wirdum', '', 53.4766700, 7.2059400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30082, 'Wippra', 'Wippra', 'Kurort Wippra,Vipra,Wippra,Випра', 51.5730000, 11.2749800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30083, 'Wippingen', 'Wippingen', '', 52.9233900, 7.4072300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30084, 'Wipperfürth', 'Wipperfuerth', 'Viperfirt,Viperfiurtas,Vipperfjurt,Wipperfuerth,Wipperfurta,Wipperfurth,Wipperfürth,fybrfwrt,wei pei er fei er te,wyprfwrth,Виперфирт,Випперфюрт,Віпперфюрт,فيبرفورت,ویپرفورث,维佩尔菲尔特', 51.1161000, 7.3986500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30085, 'Wipperdorf', 'Wipperdorf', '', 51.4556000, 10.6438800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30086, 'Wipfeld', 'Wipfeld', 'Vipfel''d,Vipfeld,wei pu fei er de,wypfld,Випфелд,Випфельд,Віпфельд,ویپفلد,维普费尔德', 49.9166700, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30087, 'Winzer', 'Winzer', 'Vincer,Winzer,wen ce er,wyntsr,Винцер,Вінцер,Վինցեր,وینتسر,温策尔', 48.7228500, 13.0775100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30088, 'Winzenburg', 'Winzenburg', 'Vincenburg,wen cen bao,Винценбург,Вінценбург,温岑堡', 51.9333300, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30089, 'Wintrich', 'Wintrich', '', 49.8833300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30090, 'Winterwerb', 'Winterwerb', '', 50.2363900, 7.7390100, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30091, 'Winterspelt', 'Winterspelt', 'Vinterspel''t,Vinterspelt,wen te er si pei er te,Винтерспелт,Винтерспельт,温特尔斯佩尔特', 50.2166700, 6.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30092, 'Wintersheim', 'Wintersheim', '', 49.7786100, 8.2802800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30093, 'Wintersdorf', 'Wintersdorf', 'Wintersdorf', 51.0532000, 12.3544500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30094, 'Winterscheid', 'Winterscheid', '', 50.2333300, 6.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30095, 'Winterrieden', 'Winterrieden', '', 48.1212200, 10.2258100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30096, 'Winterlingen', 'Winterlingen', 'Vinterlingen,wen te er lin gen,Винтерлинген,Вінтерлінген,温特尔林根', 48.1833300, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30097, 'Winterhude', 'Winterhude', 'Hamborg-Winterhuud,Hamburg-Winterhude,Vinterkhude,Винтерхуде', 53.6000000, 10.0000000, 'DE', '2017-06-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30098, 'Winterhausen', 'Winterhausen', '', 49.7068300, 10.0166100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30099, 'Winterburg', 'Winterburg', 'Vinterburg,wen te er bao,Винтербург,温特尔堡', 49.8666700, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30100, 'Winterborn', 'Winterborn', '', 49.7500000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30101, 'Winterberg', 'Winterberg', 'Vinterberg,Winnenmerg,Winterberg,fyntrbrgh,wen te er bei ge,wyntrbrg,Винтерберг,Вінтерберг,فينتربرغ,وینتربرگ,温特尔贝格', 51.1924800, 8.5346800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30102, 'Winterbach', 'Winterbach', '', 49.8666700, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30103, 'Winterbach', 'Winterbach', '', 48.7991800, 9.4791400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30104, 'Winterbach', 'Winterbach', '', 48.4666700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30105, 'Winsen', 'Winsen', '', 53.8333300, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30106, 'Winsen', 'Winsen', 'Winsen', 53.3575300, 10.2128200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30107, 'Winsen', 'Winsen', 'Winsen (Aller),Winsen an der Aller', 52.6830100, 9.9136200, 'DE', '2016-06-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30108, 'Winseldorf', 'Winseldorf', 'Winseldorf', 53.9443100, 9.6063200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30109, 'Winringen', 'Winringen', '', 50.1500000, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30110, 'Winnweiler', 'Winnweiler', 'Vinvajler,Winnwiller,vu~in''vu~aira,wen wei lei,Винвайлер,Винвајлер,ヴィンヴァイラー,温韦勒', 49.5666700, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30111, 'Winningen', 'Winningen', 'Viningen,wei ning gen,Вининген,维宁根', 50.3166700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30112, 'Winnigstedt', 'Winnigstedt', '', 52.0662900, 10.7687900, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30113, 'Winnert', 'Winnert', 'Winnert', 54.4333300, 9.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30114, 'Winnerath', 'Winnerath', '', 50.4288600, 6.8765800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30115, 'Winnenden', 'Winnenden', 'Vinenden,Vinnenden,Winnenden,wen nen deng,wynndn,Виненден,Винненден,Вінненден,وينندن,وینندن,温嫩登', 48.8756300, 9.3981900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30116, 'Winnen', 'Winnen', '', 50.5733300, 8.0116700, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30117, 'Winnemark', 'Winnemark', 'Winnemark', 54.6166700, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30118, 'Winklarn', 'Winklarn', 'Vinklarn,Winklarn,wen ke la er en,wynklarn,Винкларн,Вінкларн,وینکلارن,温克拉尔恩', 49.4268800, 12.4798600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30119, 'Winkelsett', 'Winkelsett', '', 52.8666700, 8.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30120, 'Winkelhaid', 'Winkelhaid', 'Vinkel''gajd,Vinkel''khajd,Vinkelhayd,Vinkelkhajd,wen ke er hai de,Винкелхајд,Винкельхайд,Вінкельгайд,Վինկելհայդ,温克尔海德', 49.3896300, 11.2988800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30121, 'Winkelbach', 'Winkelbach', '', 50.6497200, 7.7330600, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30122, 'Winhöring', 'Winhoring', 'Vingering,Vinhyoring,Vinkhering,Vinkhjoring,Winaring,Winhoering,Winhöring,wen he ling,wynhwryng,Винхеринг,Винхёринг,Вінгерінг,Վինհյորինգ,وینهورینگ,温赫灵', 48.2666700, 12.6500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30123, 'Wingst', 'Wingst', 'Gemeen Wingst,Vingst,wen ge si te,Вингст,温格斯特', 53.7357200, 9.0805400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30124, 'Wingerode', 'Wingerode', 'Wingerode', 51.3903200, 10.2395400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30125, 'Windsbach', 'Windsbach', 'Vindsbakh,Vindsbax,Windsbach,fyndzbakh,vu~intsubahha,wen ci ba he,wyndzbakh,Виндсбах,Віндсбах,Վինդսբախ,فيندزباخ,ویندزباخ,ヴィンツバッハ,温茨巴赫', 49.2478600, 10.8265100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30126, 'Windischleuba', 'Windischleuba', 'Vindishlojba,Windischleuba,wen di shi luo yi ba,Виндишлойба,Виндишлојба,温迪施洛伊巴', 51.0155600, 12.4691400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30127, 'Windischeschenbach', 'Windischeschenbach', 'Vindisesenbax,Vindisheshenbakh,Windischeschenbach,fyndyshyshnbakh,wen di she shen ba he,Виндишешенбах,Віндішешенбах,Վինդիշեշենբախ,فينديشيشنباخ,ویندیش‌اشنباخ,温迪舍申巴赫', 49.8010800, 12.1571000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30128, 'Windhausen', 'Windhausen', '', 51.7854400, 10.2121800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30129, 'Windhagen', 'Windhagen', 'Vindkhagen,wen de ha gen,Виндхаген,温德哈根', 50.6412100, 7.3535200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30130, 'Windesheim', 'Windesheim', '', 49.9000000, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30131, 'Winden', 'Winden', '', 50.3333300, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30132, 'Winden', 'Winden', '', 49.0977800, 8.1169400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30133, 'Windelsbach', 'Windelsbach', 'Vindel''sbakh,Vindelsbakh,Vindelsbax,vu~inderusubahha,wen de er si ba he,Винделсбах,Виндельсбах,Віндельсбах,Վինդելսբախ,ヴィンデルスバッハ,温德尔斯巴赫', 49.4000000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30134, 'Windeby', 'Windeby', 'Windeby', 54.4666700, 9.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30135, 'Windbergen', 'Windbergen', 'Windbergen', 54.0500000, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30136, 'Windberg', 'Windberg', '', 48.9428500, 12.7462000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30137, 'Windach', 'Windach', 'Vindakh,Vindax,vu~indahha,wen da,wyndakh,Виндах,Віндах,Վինդախ,وینداخ,ヴィンダッハ,温达', 48.0666700, 11.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30138, 'Wincheringen', 'Wincheringen', 'Vinkheringen,Wencher,Wëncher,wen xie lin gen,Винхеринген,温歇林根', 49.6090400, 6.4259700, 'DE', '2017-06-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30139, 'Wimsheim', 'Wimsheim', 'Vimsgajm,Vimshaym,Vimskhajm,wei mu si hai mu,Вимсхайм,Вимсхајм,Вімсгайм,Վիմսհայմ,维姆斯海姆', 48.8500000, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30140, 'Wimmelburg', 'Wimmelburg', 'Wimmelburg', 51.5206900, 11.5069600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30141, 'Wimbach', 'Wimbach', '', 50.3666700, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30142, 'Wiltingen', 'Wiltingen', '', 49.6591900, 6.5925500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30143, 'Wilthen', 'Wilthen', 'Vil''ten,Vilten,Viltene,Wilthen,Wjelecin,Wjelećin,fyltn,wei er teng,wyltn,Вилтен,Вильтен,Вільтен,فيلتن,ویلتن,维尔滕', 51.0974500, 14.3929000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30144, 'Wilsum', 'Wilsum', '', 52.5333300, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30145, 'Wilster', 'Wilster', 'Vil''ster,Vilster,fylstr,wei er si te er,wylshtr,Вилстер,Вильстер,فيلستر,ویلشتر,维尔斯特尔', 53.9225300, 9.3746500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30146, 'Wilstedt', 'Wilstedt', '', 53.1949300, 9.0959500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30147, 'Wilsecker', 'Wilsecker', '', 50.0166700, 6.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30148, 'Wilsdruff', 'Wilsdruff', 'Vil''sdruf,Vilsdruf,Vilsdrufa,Wilsdruff,fylzdrwf,wei er si de lu fu,wylzdrwf,Вилсдруф,Вильсдруф,فيلزدروف,ویلزدروف,维尔斯德鲁夫', 51.0519900, 13.5365700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30149, 'Wilnsdorf', 'Wilnsdorf', 'Vil''nsdorf,Vilnsdorf,Wilnsdorf,wei er en si duo fu,Вилнсдорф,Вильнсдорф,Вільнсдорф,维尔恩斯多夫', 50.8166700, 8.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30150, 'Wilmersdorf', 'Wilmersdorf Bezirk', 'Berlin-Wilmersdorf,Vil''mersdorf,wylmrsdrf,wylmrsdwrp,Вильмерсдорф,וילמרסדורף,ویلمرسدرف', 52.4833300, 13.3166700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30151, 'Willwerscheid', 'Willwerscheid', '', 50.0333300, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30152, 'Willstätt', 'Willstaett', 'Vil''shtet,Vill''shtett,Vilshhet,Vilshtet,Willstaett,Willstatt,Willstätt,Вилштет,Вилщет,Вильштет,Вілльштетт', 48.5407100, 7.8931400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30153, 'Willroth', 'Willroth', '', 50.5691200, 7.5275200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30154, 'Willmering', 'Willmering', '', 49.2500000, 12.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30155, 'Willmenrod', 'Willmenrod', '', 50.5413900, 7.9813900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30156, 'Willmars', 'Willmars', 'Vil''mars,Vill''mars,Vilmars,wei er ma er si,Вилльмарс,Вилмарс,Вільмарс,Վիլմարս,维尔马尔斯', 50.5000000, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30157, 'Willingshausen', 'Willingshausen', 'Vilingskhauzen,Villingsgauzen,Villingskhauzen,Willingshausen,vu~iringusuhauzen,wei ling si hao sen,Вилингсхаузен,Виллингсхаузен,Віллінгсгаузен,ヴィリングスハウゼン,维灵斯豪森', 50.8500000, 9.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30158, 'Willingen', 'Willingen', 'Vilingen,Villingen,Willingen,Willingen (Upland),Willingeni vald,vu~iringen,wei lin gen,Вилинген,Виллинген,Віллінген,ヴィリンゲン,维林根', 51.2941800, 8.6091000, 'DE', '2016-12-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30159, 'Willingen', 'Willingen', '', 50.6675800, 8.0877400, 'DE', '2011-08-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30160, 'Willich', 'Willich', 'Vilikh,Villikh,Villix,Willich,fylysh,wei li xi,wylysh,Вилих,Виллих,Вілліх,فيليش,ویلیش,維利希', 51.2637100, 6.5473400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30161, 'Willerstedt', 'Willerstedt', '', 51.0899400, 11.4528600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30162, 'Willenscharen', 'Willenscharen', 'Willenscharen', 54.0166700, 9.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30163, 'Willebadessen', 'Willebadessen', 'Vilebadesen,Villebadessen,fylybadysn,vu~irebatoessen,wei lai ba de sen,wyllbadasn,Вилебадесен,Виллебадессен,Віллебадессен,فيليباديسن,ویللباداسن,ヴィレバートエッセン,维莱巴德森', 51.6256400, 9.0369400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30164, 'Willanzheim', 'Willanzheim', 'Vilanckhajm,Villancgajm,Villanckhajm,Willanzheim,wei lan ci hai mu,Виланцхајм,Вилланцхайм,Вілланцгайм,Վիլանցհայմ,维兰茨海姆', 49.6801100, 10.2324800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30165, 'Wilkau-Haßlau', 'Wilkau-Hasslau', 'Vil''kau-Khaslau,Vilkau-Khaslau,Vilkava-Haslava,Wilkau-Hasslau,Wilkau-Haßlau,fylkaw-haslaw,wei er kao-ha si lao,wylkwa-haslwa,Вилкау-Хаслау,Вилькау-Хаслау,فيلكاو-هاسلاو,ویلکوا-هاسلوا,维尔考-哈斯劳', 50.6750400, 12.5148200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30166, 'Wilhermsdorf', 'Wilhermsdorf', 'Vil''germsdorf,Vil''khermsdorf,Vilhermsdorf,Vilkhermsdorf,Wilhermsdorf,Вилхермсдорф,Вильхермсдорф,Вільгермсдорф,Վիլհերմսդորֆ', 49.4830800, 10.7155500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30167, 'Wilhelmsthal', 'Wilhelmsthal', 'Vil''gel''mstal'',Vilkhelmstal,vu~iruherumusutaru,wei lian si ta er,Вилхелмстал,Вильгельмсталь,Вільгельмсталь,Վիլհելմսթալ,ヴィルヘルムスタール,威廉斯塔尔', 50.3111300, 11.3727800, 'DE', '2012-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30168, 'Wilhelmstadt', 'Wilhelmstadt', 'Berlin-Wilhelmstadt,Wilhelmstadt', 52.5246200, 13.1770700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30169, 'Wilhelmsruh', 'Wilhelmsruh', 'Berlin-Wilhelmsruh,Vil''gel''msru,Wilhelmsruh,Вильгельмсру', 52.5871000, 13.3685500, 'DE', '2012-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30170, 'Wilhelmshaven', 'Wilhelmshaven', 'Gorad Vil''gel''mskhafen,Vil''gel''msgafen,Vil''gel''mskhafen,Vilchelmschafen,Vilhelmshafenas,Vilkhelmskhafen,WVN,Wilhelmshaven,Willelmeshaefen,Willelmeshæfen,Willemshaven,Wuelmshoawen,Wülmshoawen,bilhelleumseuhapen,fylhlmshafn,vu~iruherumusuhafen,wei lian gang,wylhmshafn,Βιλχελμσχάφεν,Вилхелмсхафен,Вильгельмсхафен,Вільгельмсгафен,Горад Вільгельмсхафен,וילהלמסהאפן,فيلهلمسهافن,ویلهمسهافن,ヴィルヘルムスハーフェン,威廉港,빌헬름스하펜', 53.5299800, 8.1125300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30171, 'Wilhelmsfeld', 'Wilhelmsfeld', 'Vil''gel''msfel''d,Vilkhelmsfeld,vu~iruherumusuferuto,wei lian si fei er de,Вилхелмсфелд,Вильгельмсфельд,Вільгельмсфельд,ヴィルヘルムスフェルト,威廉斯费尔德', 49.4705600, 8.7536100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30172, 'Wilhelmsdorf', 'Wilhelmsdorf', '', 50.6296500, 11.5498100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30173, 'Wilhelmsdorf', 'Wilhelmsdorf', '', 49.5641900, 10.7371600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30174, 'Wilhelmsdorf', 'Wilhelmsdorf', 'Wilhelmsdorf', 47.8661200, 9.4262100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30175, 'Wilgartswiesen', 'Wilgartswiesen', 'Vil''gartsvizen,Vilgartsvisen,Wilgartswiesen,wei er jia er ci wei sen,Вилгартсвисен,Вильгартсвизен,维尔加尔茨维森', 49.2089100, 7.8734600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30176, 'Wildsteig', 'Wildsteig', '', 47.7014500, 10.9375300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30177, 'Wildpoldsried', 'Wildpoldsried', 'Vil''dpol''dsrid,Vildpoldsrid,wei er de bo er ci li de,Вилдполдсрид,Вильдпольдсрид,Вільдпольдсрід,Վիլդպոլդսրիդ,维尔德波尔茨里德', 47.7666700, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30178, 'Wildflecken', 'Wildflecken', 'Vil''dflekken,Vildfleken,Wildflecken,wei er de fu lai ken,Вилдфлекен,Вильдфлеккен,Вільдфлеккен,Վիլդֆլեքեն,维尔德夫莱肯', 50.3776400, 9.9109200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30179, 'Wildetaube', 'Wildetaube', 'Wildetaube', 50.7166700, 12.1166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30180, 'Wildeshausen', 'Wildeshausen', 'Vil''deskhauzen,Vildeskhauzen,Wildeshausen,Wilshusen,fyldshawzn,wei er de si hao sen,Вилдесхаузен,Вильдесхаузен,فيلدسهاوزن,ویلدس‌هاوزن,维尔德斯豪森', 52.8944600, 8.4337500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30181, 'Wildenspring', 'Wildenspring', 'Wildenspring', 50.6000000, 11.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30182, 'Wildenhain', 'Wildenhain', 'Wildenhain', 51.3076000, 13.4767800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30183, 'Wildenfels', 'Wildenfels', 'Vil''denfel''s,Vildenfels,Vildenfelsa,Vilntenfels,Wildenfels,fyldnflz,u~irudenferusu,wei er deng fei er si,wyldnfldz,Βίλντενφελς,Вилденфелс,Вильденфельс,فيلدنفلز,ویلدنفلدز,ウィルデンフェルス,维尔登费尔斯', 50.6678400, 12.6088600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30184, 'Wildenbörten', 'Wildenborten', '', 50.9166700, 12.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30185, 'Wildenberg', 'Wildenberg', '', 48.7298100, 11.8984500, 'DE', '2013-02-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30186, 'Wildemann', 'Wildemann', 'Vil''deman,Vildeman,Wildemann,fyldyman,wei er de man,wyldmn,Вилдеман,Вильдеман,فيلديمان,ویلدمن,维尔德曼', 51.8281000, 10.2815200, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30187, 'Wildberg', 'Wildberg', '', 48.6233600, 8.7451800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30188, 'Bad Wildbad', 'Bad Wildbad', 'Bad Vildbad,Bad Wildbad,Bad Wildbad im Schwarzwald,Bad-Vil''dbad,Stadt Bad Wildbad im Schwarzwald,Wildbad,Wildbad im Schwarzwald,ba te wei er de ba te,bad fyldbad,bad wyldbad,Бад Вилдбад,Бад-Вильдбад,Бад-Вільдбад,Բադ Վիլդբադ,باد فيلدباد,باد ویلدباد,バート・ヴィルトバート,巴特维尔德巴特', 48.7507100, 8.5504000, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30189, 'Wildau', 'Wildau', 'Vil''dau,Vildau,Wildau,wei er dao,Вилдау,Вильдау,Վիլդաու,维尔道', 52.3166700, 13.6333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30190, 'Wilburgstetten', 'Wilburgstetten', 'Vil''burgshtetten,Vilburgshteten,Vilburgsteten,Wilburgstetten,vu~iruburukushutetten,wei er bu er ge si te teng,Вилбургштетен,Вильбургштеттен,Вільбургштеттен,Վիլբուրգշտետեն,ヴィルブルクシュテッテン,维尔布尔格斯特滕', 49.0242700, 10.3950500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30191, 'Wiggensbach', 'Wiggensbach', 'Vigensbakh,Vigensbax,Viggensbakh,Wiggensbach,wei gen si ba he,Виггенсбах,Вигенсбах,Віггенсбах,Վիգենսբախ,维根斯巴赫', 47.7478100, 10.2298700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30192, 'Wietzendorf', 'Wietzendorf', 'Gemeen Witzendoerp,Gemeen Witzendörp,Vicendorf,Vitcendorf,wei cen duo fu,Витцендорф,Вицендорф,Вітцендорф,维岑多夫', 52.9166700, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30193, 'Wietzen', 'Wietzen', 'Vicen,Vitcen,vu~itsu~en,wei cen,Витцен,Вицен,ヴィーツェン,维岑', 52.7166700, 9.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30194, 'Wietze', 'Wietze', 'Vice,Vitce,Wietze,wei ce,Витце,Вице,维策', 52.6500000, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30195, 'Wietmarschen', 'Wietmarschen', 'Vitmarshen,wei te ma er shen,Витмаршен,维特马尔申', 52.5180600, 7.1340800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30196, 'Wiesweiler', 'Wiesweiler', 'Visvajler,wei si wei lei,Висвайлер,Висвајлер,维斯韦勒', 49.6333300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30197, 'Wiesthal', 'Wiesthal', 'Vistal,Vistal'',wei si ta er,Вистал,Висталь,Вісталь,Վիսթալ,维斯塔尔', 50.0333300, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30198, 'Wiesmoor', 'Wiesmoor', 'Vismor,fyzmwr,wei si mo er,wyzmwr,Висмор,فيزمور,ویزمور,维斯莫尔', 53.4166700, 7.7333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30199, 'Wiesloch', 'Wiesloch', 'Vislokh,Wiesloch,Wissloch,fyzlwkh,vu~isurohho,wei si luo he,wyzlkh,Вислох,Віслох,فيزلوخ,ویزلخ,ヴィースロッホ,維斯洛赫', 49.2950400, 8.6984600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30200, 'Wieseth', 'Wieseth', 'Vizet,vu~izeto,wei sai te,Визет,Візет,Վիզետ,ヴィーゼト,维塞特', 49.1666700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30201, 'Wiesentheid', 'Wiesentheid', 'Vizentajd,Vizentayd,Vizentkhajd,Wiesentheid,wei sen tai de,Визентайд,Визентајд,Визентхайд,Візентайд,Վիզենտայդ,维森泰德', 49.7945100, 10.3450900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30202, 'Wiesenthau', 'Wiesenthau', 'Vizentau,vu~izentau,wei sen tao,Визентау,Візентау,Վիզենթաու,ヴィーゼンタウ,维森陶', 49.7132600, 11.1356400, 'DE', '2017-06-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30203, 'Wiesenthal', 'Wiesenthal', 'Vizental,Vizental'',Визентал,Визенталь,Վիզենտալ', 50.7000000, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30204, 'Wiesent', 'Wiesent', '', 49.0166700, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30205, 'Wiesensteig', 'Wiesensteig', 'Vizenshtajg,fyznshtaygh,wei sen si tai xi,Визенштайг,Визенштајг,Візенштайг,فيزنشتايغ,ویزن‌اشتایگ,维森斯泰希', 48.5612700, 9.6254000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30206, 'Wiesenfelden', 'Wiesenfelden', 'Vizenfel''den,Vizenfelden,wei sen fei er deng,wyznfldn,Визенфелден,Визенфельден,Візенфельден,ویزنفلدن,维森费尔登', 49.0406600, 12.5400800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30207, 'Wiesenburg', 'Wiesenburg', 'Wiesenburg,Wiesenburg/Mark', 52.1145600, 12.4553400, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30208, 'Wiesenbronn', 'Wiesenbronn', 'Vizenbron,Vizenbronn,wei sen bu long,Визенброн,Визенбронн,Візенбронн,Վիզենբրոն,维森布龙', 49.7500000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30209, 'Wiesenbach', 'Wiesenbach', '', 49.3613900, 8.8036100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30210, 'Wiesenau', 'Wiesenau', 'Vizenau,wei sai nao,Визенау,Վիզենաու,维塞瑙', 52.2307100, 14.5910700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30211, 'Wiesen', 'Wiesen', '', 50.1166700, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30212, 'Wiesemscheid', 'Wiesemscheid', '', 50.3333300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30213, 'Wiesbaum', 'Wiesbaum', '', 50.3406500, 6.6733200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30214, 'Wiesbaden', 'Wiesbaden', 'Aquae Mattiacae,Gorad Visbadehn,Uisibada,Visbaden,Visbadene,Vizmpanten,Vysbadenas,Vīsbādene,WIE,Wiasban,Wiasbån,Wiesbaden,Wissbade,biseubaden,fysbadn,visabadena,visbadeni,vu~isubaden,wayzbadn,wei si ba deng,wi sba dein,wysbadn,Βιζμπάντεν,Висбаден,Вісбаден,Горад Вісбадэн,Վիսբադեն,וויסבאדן,ויסבאדן,فيسبادن,وائزبادن,ویسبادن,वीसबाडेन,วีสบาเดิน,ვისბადენი,ヴィースバーデン,威斯巴登,비스바덴', 50.0825800, 8.2493200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30215, 'Wiesbach', 'Wiesbach', '', 49.3333300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30216, 'Wiesau', 'Wiesau', 'Vizau,Wiesau,wei shao,Визау,Візау,Վիզաու,维绍', 49.9081700, 12.1888900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30217, 'Wiesa', 'Wiesa', '', 50.6111400, 13.0137700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30218, 'Wiershop', 'Wiershop', 'Wiershop', 53.4333300, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30219, 'Wiersdorf', 'Wiersdorf', '', 50.0000000, 6.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30220, 'Wierschem', 'Wierschem', '', 50.2255700, 7.3515700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30221, 'Wiernsheim', 'Wiernsheim', '', 48.8833300, 8.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30222, 'Wieren', 'Wieren', 'Viren,Вирен', 52.8852900, 10.6587100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30223, 'Wienhausen', 'Wienhausen', 'Vinkhauzen,Wienhusen,wen hao sen,Винхаузен,温豪森', 52.5802100, 10.1886200, 'DE', '2014-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30224, 'Wiemerstedt', 'Wiemerstedt', 'Wiemerstedt', 54.2666700, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30225, 'Wiemersdorf', 'Wiemersdorf', 'Wiemersdorf', 53.9581500, 9.9029700, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30226, 'Wielenbach', 'Wielenbach', 'Vilenbakh,Vilenbax,vu~irenbahha,wei lun ba he,wylnbakh,Виленбах,Віленбах,Վիլենբախ,ویلنباخ,ヴィーレンバッハ,维伦巴赫', 47.8740500, 11.1591800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30227, 'Wielen', 'Wielen', '', 52.5500000, 6.7166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30228, 'Wiek', 'Wiek', '', 54.6200000, 13.2891400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30229, 'Wiehl', 'Wiehl', 'Vil,Vil'',Wiehl,fyhl,wei he er,wyl,Вил,Виль,Віль,فيهل,ویل,维赫尔', 50.9495000, 7.5506200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30230, 'Wiehe', 'Wiehe', 'Wiehe', 51.2658600, 11.4128200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30231, 'Wiegendorf', 'Wiegendorf', '', 50.9833300, 11.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30232, 'Wiefelstede', 'Wiefelstede', 'Vifel''shtede,Vifel''stede,Vifelstede,Wiefelstaee,Wiefelstäe,wei fei er si te de,Вифелстеде,Вифельстеде,Вифельштеде,维费尔斯特德', 53.2500000, 8.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30233, 'Wiednitz', 'Wiednitz', 'Wetnica,Wiednitz,Wětnica', 51.3860800, 14.0268300, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30234, 'Wiederstedt', 'Wiederstedt', 'Wiederstedt', 51.6652600, 11.5272300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30235, 'Wiedergeltingen', 'Wiedergeltingen', 'Vidergel''tingen,Vidergeltingen,wei de er ge er ting gen,Видергелтинген,Видергельтинген,Відергельтінген,Վիդերգելտինգեն,维德尔格尔廷根', 48.0394600, 10.6740600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30236, 'Wiedensahl', 'Wiedensahl', 'Vidensal,Videnzal'',Wiedensahl,vu~idenzaru,wei deng sa er,Видензаль,Виденсал,ヴィーデンザール,维登萨尔', 52.3838500, 9.1201900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30237, 'Wieden', 'Wieden', '', 47.8414500, 7.8820000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30238, 'Wiedemar', 'Wiedemar', 'Videmar,Wiedemari vald,wei de ma er,Видемар,维德马尔', 51.4666700, 12.2000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30239, 'Wieda', 'Wieda', 'Vida,wei da,Вида,维达', 51.6340000, 10.5870400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30240, 'Wiebelsheim', 'Wiebelsheim', '', 50.0833300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30241, 'Widdern', 'Widdern', 'Viddern,Vidern,Widdern,fydrn,vu~idderun,wei de er en,wydrn,Виддерн,Видерн,Віддерн,فيدرن,ویدرن,ヴィッデルン,维德尔恩', 49.3182500, 9.4220900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30242, 'Wickenrodt', 'Wickenrodt', '', 49.8166700, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30243, 'Wickede', 'Wickede', 'Vikede,Vikkede,Wickede,wei ke de,Викеде,Виккеде,Віккеде,维克德', 51.4964000, 7.8658700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30244, 'Wichmar', 'Wichmar', 'Wichmar', 51.0333300, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30245, 'Weyhausen', 'Weyhausen', 'Vajkhauzen,Vejkhauzen,wei hao sen,Вайхаузен,Вејхаузен,魏豪森', 52.4620800, 10.7169900, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30246, 'Weyerbusch', 'Weyerbusch', 'Vajerbush,Vejerbush,Weyerbusch,wei ai er bu shi,wyrbwsh,Вайербуш,Вејербуш,ویربوش,魏埃尔布施', 50.7166700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30247, 'Weyer', 'Weyer', '', 50.1833300, 7.7166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30248, 'Weyarn', 'Weyarn', 'Vajarn,Vejarn,Veyarn,wayarn,wei a er en,Вайарн,Вейарн,Вејарн,Վեյարն,وایارن,魏阿尔恩', 47.8583800, 11.7992300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30249, 'Wewelsfleth', 'Wewelsfleth', 'Wewelsfleth', 53.8500000, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30250, 'Wetzlar', 'Wetzlar', 'Betslar,Gorad Veclar,Veclar,Veclara,Veclaras,Veclaro,Veclāra,Vetclar,Vetzlar,Weslar,Weslår,Wetzlar,Wetzlaria,ZQQ,becheulla-eo,ftslar,vetslari,vu~ettsura,wei ci la er,weth s lar,wtslar,wzlr,Βέτσλαρ,Ветцлар,Вецлар,Горад Вецлар,וצלר,فتسلار,وتسلار,เวทซลาร์,ვეცლარი,ヴェッツラー,韦茨拉尔,베츨라어', 50.5610900, 8.5049500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30251, 'Wetzendorf', 'Wetzendorf', '', 49.4705600, 11.0414800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30252, 'Wettstetten', 'Wettstetten', 'Vetshteten,Vetshtetten,Vetsteten,Vettshtetten,wei ci te teng,wtshttn,Веттштеттен,Ветштетен,Ветштеттен,Վետշտետեն,وتشتتن,韦茨特滕', 48.8225200, 11.4142800, 'DE', '2012-11-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30253, 'Wettrup', 'Wettrup', '', 52.5888700, 7.5991100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30254, 'Wettringen', 'Wettringen', 'Vetringen,Vettringen,wei te lin gen,Ветринген,Веттринген,Веттрінген,韦特林根', 52.2093900, 7.3189500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30255, 'Wettringen', 'Wettringen', '', 49.2578800, 10.1569400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30256, 'Wettlingen', 'Wettlingen', '', 49.9333300, 6.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30257, 'Wettin', 'Wettin', 'Vetin,Vettin,Wettin,Ветин,Веттин', 51.5860400, 11.8063000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30258, 'Wetterzeube', 'Wetterzeube', 'Vetercojbe,Vettercojbe,Wetterzeube,wei te er cuo yi bei,Ветерцојбе,Веттерцойбе,韦特尔措伊贝', 51.0000000, 12.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30259, 'Wetter (Ruhr)', 'Wetter (Ruhr)', 'Stadt Wetter (Ruhr),Wetter,Wetter (Ruhr)', 51.3874700, 7.3927700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30260, 'Wetter', 'Wetter', 'Veter,Vetter,Wetter,fytr,vu~etta,wtr,Ветер,Веттер,فيتر,وتر,ヴェッター', 50.9025400, 8.7236600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30261, 'Wetschen', 'Wetschen', '', 52.6129500, 8.4488300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30262, 'Wethau', 'Wethau', 'Wethau', 51.1371700, 11.8568000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30263, 'Westre', 'Westre', 'Vestre,Weestre,Westre,wei si te lei,Βέστρε,Вестре,韦斯特雷', 54.8500000, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30264, 'Westhofen', 'Westhofen', '', 49.7044400, 8.2480600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30265, 'Westheim', 'Westheim', 'Westheim', 49.2464000, 8.3235700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30266, 'Westheim', 'Westheim', '', 49.0000000, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30267, 'Westhausen', 'Westhausen', '', 51.0166700, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30268, 'Westhausen', 'Westhausen', '', 50.3156800, 10.6623600, 'DE', '2016-08-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30269, 'Westhausen', 'Westhausen', 'Westhausen', 48.8833300, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30270, 'Westgreußen', 'Westgreussen', 'Westgreussen,Westgreußen', 51.2387100, 10.9192100, 'DE', '2015-06-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30271, 'Westfeld', 'Westfeld', '', 52.0500000, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30272, 'Westerwalsede', 'Westerwalsede', '', 53.0333300, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30273, 'Westertimke', 'Westertimke', '', 53.2369700, 9.1308400, 'DE', '2011-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30274, 'Westerstetten', 'Westerstetten', 'Vestershteten,Vestershtetten,wei si te er si te teng,Вестерштетен,Вестерштеттен,Վեսթերշտեթեն,ვესტერშტეტენი,韦斯特尔斯特滕', 48.5191600, 9.9549400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30275, 'Westerstede', 'Westerstede', 'Vestershtede,Vesterstede,Westerstaee,Westerstede,Westerstäe,fstrshtydh,wei si te er si te de,wstrashtdh,Вестерстеде,Вестерштеде,فسترشتيده,وستراشتده,韦斯特尔斯特德', 53.2568200, 7.9273700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30276, 'Westerrönfeld', 'Westerronfeld', 'Westerroenfeld,Westerronfeld,Westerrönfeld', 54.2833300, 9.6500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30277, 'Westerrade', 'Westerrade', 'Westerrade', 53.9333300, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30278, 'Wester-Ohrstedt', 'Wester-Ohrstedt', 'Wester-Ohrstedt', 54.5079600, 9.1857400, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30279, 'Westernohe', 'Westernohe', '', 50.5891700, 8.1002800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30280, 'Westermoor', 'Westermoor', 'Westermoor', 53.9135100, 9.6239400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30281, 'Westerland', 'Westerland', 'GWT,Vesterland,Waeaesterloen'',Weesterloen,Weesterlön,Westerland,Wäästerlön'',Вестерланд', 54.9079000, 8.3032600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30282, 'Westerkappeln', 'Westerkappeln', 'Vesterkapeln,Vesterkappel''n,Westerkappeln,wei si te er ka pei er en,Вестеркапелн,Вестеркаппельн,韦斯特尔卡佩尔恩', 52.3166700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30283, 'Westerhorn', 'Westerhorn', '', 53.8571100, 9.6795900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30284, 'Westerholz', 'Westerholz', '', 54.8166700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30285, 'Westerholt', 'Westerholt', '', 53.6000000, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30286, 'Westerhever', 'Westerhever', 'Vestergefer,Vesterhever,Vesterkhefer,Vesterkhever,Waasterheewer,wei si te lei fei er,Вестергефер,Вестерхевер,Вестерхефер,Վեսթերհևեր,韦斯特雷费尔', 54.3823600, 8.6774000, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30287, 'Westerheim', 'Westerheim', '', 48.5151100, 9.6242400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30288, 'Westerheim', 'Westerheim', '', 48.0166700, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30289, 'Westerhausen', 'Westerhausen', 'Vesterkhauzen,Westerhausen,Вестерхаузен', 51.8056600, 11.0563100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30290, 'Westergellersen', 'Westergellersen', '', 53.2333300, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30291, 'Westeregeln', 'Westeregeln', 'Westeregeln,Westeregulun', 51.9632800, 11.3926500, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30292, 'Westerdeichstrich', 'Westerdeichstrich', '', 54.1614800, 8.8644100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30293, 'Westerburg', 'Westerburg', 'Vesterburg,Westerburg,fstrbwrgh,vu~esutaburuku,wei si te er bao,wstrbwrg,Вестербург,فستربورغ,وستربورگ,ヴェスターブルク,韦斯特尔堡', 50.5593800, 7.9748200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30294, 'Westerborstel', 'Westerborstel', 'Westerborstel', 54.2333300, 9.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30295, 'Westerau', 'Westerau', 'Westerau', 53.7774500, 10.4882400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30296, 'Westensee', 'Westensee', 'Westensee', 54.2745200, 9.8958400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30297, 'Westendorf', 'Westendorf', '', 48.5720900, 10.8404900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30298, 'Westendorf', 'Westendorf', '', 47.9333300, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30299, 'Westend', 'Westend', 'Berlin-Westend', 52.5170800, 13.2763600, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30300, 'Weste', 'Weste', '', 53.0594300, 10.7028300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30301, 'Wessobrunn', 'Wessobrunn', 'Vessobrunn,Wessobrunn,Wessobrunn Abbey,wei suo bu lun,Вессобрунн,韦索布伦', 47.8740700, 11.0246100, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30302, 'Weßling', 'Wessling', 'Vesling,wei si ling,wslyng,Веслинг,Веслінг,وسلینگ,韦斯灵', 48.0745200, 11.2482000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30303, 'Wesseln', 'Wesseln', '', 54.2098500, 9.0764400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30304, 'Wesseling', 'Wesseling', 'Veseling,Vesseling,Wesseling,fyzylyngh,wei se ling,wzlyngn,Веселинг,Весселинг,Весселінг,فيزيلينغ,وزلینگن,韦瑟灵', 50.8270900, 6.9747000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30305, 'Wesselburenerkoog', 'Wesselburenerkoog', 'Wesselburenerkoog', 54.2500000, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30306, 'Wesselburener Deichhausen', 'Wesselburener Deichhausen', 'Wesselburener Deichhausen', 54.1666700, 8.9333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30307, 'Wesselburen', 'Wesselburen', 'Veselburen,Veslingburen,Vessel''buren,Wesselburen,fyslbwryn,wei sai er bu lun,wslbwrn,Веселбурен,Вессельбурен,فيسلبورين,وسلبورن,韦塞尔布伦', 54.2121700, 8.9241900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30308, 'Wesendorf', 'Wesendorf', 'Vezendorf,wei sen duo fu,Везендорф,韦森多夫', 52.6000000, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30309, 'Wesenberg', 'Wesenberg', 'Vezenberg,Vezenberga,Vēzenberga,wznbrg  mklnbwrg,Везенберг,وزنبرگ، مکلنبورگ', 53.2803000, 12.9693600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30310, 'Weselberg', 'Weselberg', 'Vezel''berg,Vezelberg,wei se er bei ge,Везелберг,Везельберг,韦瑟尔贝格', 49.3366200, 7.6078000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30311, 'Wesel', 'Wesel', 'Vezel,Vezel'',Wesel,wei sai er,wzl,Везел,Везель,وزل,韋塞爾', 51.6669000, 6.6203700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30312, 'Wertingen', 'Wertingen', 'Vertingen,Wertingen,Wertingeni vald,fyrtynghn,wei er ting gen,wrtyngn,Вертинген,Вертінген,Վերտինգեն,فيرتينغن,ورتینگن,韦尔廷根', 48.5631400, 10.6814900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30313, 'Werther', 'Werther', 'Verter,fyrtr,wei er te er,wrta,Вертер,فيرتر,ورتا,韦尔特尔', 52.0777100, 8.4179300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30314, 'Wertheim', 'Wertheim', 'Vertgajm-am-Majn,Vertkhajm,Wertheim,Wertheim am Main,frthaym am mayn,vu~erutohaimu,wei er tai mu,wrthaym am mayn,Вертгайм-ам-Майн,Вертхайм,Вертхајм,فرتهايم آم ماين,ورتهایم آم ماین,ヴェルトハイム,韦尔泰姆', 49.7590000, 9.5085200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30315, 'Wertach', 'Wertach', 'Vertakh,Wertach,Вертах,Վերթախ', 47.6030100, 10.4096600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30316, 'Wershofen', 'Wershofen', '', 50.4448200, 6.8133300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30317, 'Werpeloh', 'Werpeloh', 'Verpelo,Verpelokh,Weerpel,wei er pei luo,Верпело,Верпелох,韦尔佩洛', 52.8720700, 7.5083100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30318, 'Weroth', 'Weroth', '', 50.4604300, 7.9484400, 'DE', '2017-05-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30319, 'Wernshausen', 'Wernshausen', 'Wernshausen', 50.7240400, 10.3508600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30320, 'Werningshausen', 'Werningshausen', 'Verningskhauzen,wei er ning ge si hao sen,Вернингсхаузен,韦尔宁格斯豪森', 51.1395100, 11.0013500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30321, 'Wernigerode', 'Wernigerode', 'Gorad Vernigerodeh,Vernigerode,Vernigerodė,Wernigerode,fyrnyghyrwdh,vu~erunigerode,wei er ni ge luo de,wrnygrwdh,Вернигероде,Верніґероде,Горад Вернігеродэ,ורניגרודה,فيرنيغيروده,ورنیگه‌روده,ヴェルニゲローデ,韦尔尼格罗德', 51.8365200, 10.7821600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30322, 'Werneuchen', 'Werneuchen', 'Verneihene,Vernojkhen,Vernoyxen,frnwyshn,wei er nuo yi heng,wrnwyshn,Вернойхен,Вернојхен,Վերնոյխեն,فرنويشن,ورنویشن,韦尔诺伊亨', 52.6327500, 13.7343700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30323, 'Wernersberg', 'Wernersberg', '', 49.1906200, 7.9275600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30324, 'Werneck', 'Werneck', 'Vernek,Werneck,wei er nei ke,Вернек,韦尔内克', 49.9820100, 10.0988400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30325, 'Werne', 'Werne', 'Verne,Waeen,Werina,Werne an der Lippe,Wäen,wei er nei,wrnh,Верне,ورنه,韦尔内', 51.6644600, 7.6342100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30326, 'Wernburg', 'Wernburg', 'Vernburg,wei er en bao,Вернбург,韦尔恩堡', 50.6777500, 11.6019900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30327, 'Wernberg-Köblitz', 'Wernberg-Koblitz', 'Vernberg-Keblic,Vernberg-Kjoblic,Wernberg,Wernberg-Koblitz,Wernberg-Köblitz,wei en bei ge-ke bu li ci,wrnbrg-kwblyts,Вернберг-Кеблиц,Вернберг-Кебліц,Вернберг-Кёблиц,ورنبرگ-کوبلیتس,韦恩贝格-克布利茨', 49.5393100, 12.1613000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30328, 'Wernau', 'Wernau', 'Vernau,frnaw,wei er nao,wrnaw,Вернау,Վերնաու,فرناو,ورناو,韦尔瑙', 48.6930600, 9.4153300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30329, 'Wermsdorf', 'Wermsdorf', 'Vermsdorf,Wermsdorf,wei er mu si duo fu,Вермсдорф,韦尔姆斯多夫', 51.2833300, 12.9500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30330, 'Wermelskirchen', 'Wermelskirchen', 'Vermel''skirkhen,Vermelskirkhen,Wermelskirchen,frmlzkyrshn,wei mo er si ji xing,wrmlzkyrshn,Вермелскирхен,Вермельскирхен,Вермельскірхен,فرملزكيرشن,ورملزکیرشن,韦默尔斯基兴', 51.1397000, 7.2158300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30331, 'Werlte', 'Werlte', 'Verl''te,Verlte,Верлте,Верльте', 52.8500000, 7.6833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30332, 'Werl', 'Werl', 'Gorad Verl'',Verl,Verl'',Werl,Werle,Wiaerl,Wiärl,wei er,wrl,Верл,Верль,Горад Верль,ورل,韦尔', 51.5549300, 7.9140300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30333, 'Werkhausen', 'Werkhausen', '', 50.7333300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30334, 'Werftpfuhl', 'Werftpfuhl', 'Verftpful'',Верфтпфуль', 52.6601400, 13.7935100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30335, 'Werdum', 'Werdum', 'Verdum,Weerm,wei er du mu,Вердум,韦尔杜姆', 53.6575100, 7.7190100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30336, 'Werdohl', 'Werdohl', 'Verdol,Verdol'',Werdohl,frdwl,wei er duo er,wrdl,Вердол,Вердоль,فردول,وردل,韦尔多尔', 51.2601100, 7.7660800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30337, 'Werder', 'Werder', 'Verder,Verderis,fyrdr,wrda,Вердер,Վերդեր,فيردر,وردا', 52.3787400, 12.9340000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30338, 'Werdau', 'Werdau', 'Verdau,Verdava,Werdau,frdaw,wei er dao,wrdwa,Вердау,فرداو,وردوا,韦尔道', 50.7360400, 12.3753400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30339, 'Werda', 'Werda', '', 50.4381100, 12.3047300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30340, 'Werben', 'Werben', 'Verben,Werben/Wjerbno,Wjerbno,wei er ben,Вербен,Վերբեն,韦尔本', 51.8166700, 14.1833300, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30341, 'Werbach', 'Werbach', 'Verbakh,vu~erubahha,wei er ba he,Вербах,ヴェルバッハ,韦尔巴赫', 49.6708300, 9.6394400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30342, 'Wenzlow', 'Wenzlow', '', 52.3000000, 12.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30343, 'Wenzendorf', 'Wenzendorf', '', 53.3494800, 9.7723400, 'DE', '2017-07-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30344, 'Wenzenbach', 'Wenzenbach', 'Vencenbakh,wen cen ba he,wntsnbakh,Венценбах,Վենցենբախ,ونتسنباخ,文岑巴赫', 49.0756100, 12.1995400, 'DE', '2012-08-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30345, 'Wentorf bei Hamburg', 'Wentorf bei Hamburg', 'Ventorf baj Khamburg,Ventorf kaj Khamburg,Ventorf-Khamburg,Wentorf apud Hamburgo,Wentorf bei Hamburg,Wentorf pres de Hambourg,Wentorf près de Hambourg,wen tuo er fu bai han bao,Венторф бај Хамбург,Венторф кај Хамбург,Венторф-Хамбург,文托尔夫拜汉堡', 53.5000000, 10.2500000, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30346, 'Wensin', 'Wensin', 'Wensin', 53.9833300, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30347, 'Wennigsen', 'Wennigsen', 'Venigsen,Vennigzen,Wennigsen am Deister,wei ni ge sen,Венигсен,Веннигзен,韦尼格森', 52.2740400, 9.5728700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30348, 'Wennbüttel', 'Wennbuttel', 'Wennbuttel,Wennbüttel', 54.1333300, 9.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30349, 'Weng', 'Weng', 'Veng,wng,Венг,Վենգ,ونگ', 48.6586600, 12.3692700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30350, 'Wendtorf', 'Wendtorf', 'Wendtorf', 54.4121200, 10.2895200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30351, 'Wendorf', 'Wendorf', '', 54.2554000, 13.0768200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30352, 'Wendlingen am Neckar', 'Wendlingen am Neckar', 'Vendlingen,Vendlingen am Nekar,Vendlingen-am-Nekkar,Wendlingen,fndlynghn,nei ka he pan wen de lin gen,wndlyngn an dr nka,Вендлинген ам Некар,Вендлинген-ам-Неккар,Вендлінген,Նեքարի Վենդլինգեն,فندلينغن,وندلینگن آن در نکا,内卡河畔文德林根', 48.6712400, 9.3763200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30353, 'Wendisch Rietz', 'Wendisch Rietz', 'Markisch Rietz,Märkisch Rietz,Vendish Ric,Vendish-Ric,Wendisch Rietz,wen di shi li ci,Вендиш Риц,Вендиш-Риц,Վենդիշ Ռից,文迪施里茨', 52.2161300, 14.0084500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30354, 'Wendisch Evern', 'Wendisch Evern', 'Vendish Evern,Vendish-Ehfern,wen di shi ai fei er en,Вендиш Еверн,Вендиш-Эферн,文迪施埃费尔恩', 53.2166700, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30355, 'Wenden', 'Wenden', 'Venden,Wenden,Венден', 50.9666700, 7.8666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30356, 'Wendelstein', 'Wendelstein', 'Vendel''shtajn,Vendelshtajn,Wendelstein,vu~enderushutain,wen de er si tai yin,Венделштајн,Вендельштайн,Վենդելշթայն,ヴェンデルシュタイン,文德尔斯泰因', 49.3523000, 11.1506900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30357, 'Wendelsheim', 'Wendelsheim', 'Vendel''skhajm,Vendelskhajm,wen de er si hai mu,Венделсхајм,Вендельсхайм,文德尔斯海姆', 49.7666700, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30358, 'Wendeburg', 'Wendeburg', 'Vendeburg,Wenneborg,wen de bao,Вендебург,文德堡', 52.3295700, 10.3925500, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30359, 'Wemding', 'Wemding', 'Vemding,Wemding,Wemdingen,fmdyngh,vu~emudingu,wei mu ding,wmdyng,Вемдинг,Вемдінг,Վեմդինգ,فمدينغ,ومدینگ,ヴェムディング,韦姆丁', 48.8746100, 10.7245200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30360, 'Wembach', 'Wembach', '', 47.7725000, 7.8869000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30361, 'Welzow', 'Welzow', 'Vel''cov,Velco,Velcov,Welzow,Welzow/Wjelcej,Wjelcej,fltsw,wei er cuo,wltsw,Велцо,Велцов,Вельцов,Վելցով,فلتسو,ولتسو,韦尔措', 51.5838100, 14.1708200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30362, 'Welzheim', 'Welzheim', 'Vel''cgajm,Vel''ckhajm,Velckhajm,Velshaym,fltshaym,wei er ci hai mu,wltshaym,Велцхајм,Вельцгайм,Вельцхайм,فلتسهايم,ولتسهایم,韦尔茨海姆', 48.8767500, 9.6343400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30363, 'Welver', 'Welver', 'Kirchwelver,Vel''fer,Velver,Welver,Welveri vald,wei er fei er,Велвер,Вельфер,韦尔费尔', 51.6166700, 7.9666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30364, 'Weltersburg', 'Weltersburg', '', 50.5323300, 7.9605600, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30365, 'Welterod', 'Welterod', '', 50.1333300, 7.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30366, 'Welt', 'Welt', '', 54.3024800, 8.7945800, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30367, 'Welsleben', 'Welsleben', 'Welsleben', 52.0030400, 11.6385100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30368, 'Welschneudorf', 'Welschneudorf', '', 50.3733300, 7.7980600, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30369, 'Welschenbach', 'Welschenbach', '', 50.3666700, 7.0666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30370, 'Welschbillig', 'Welschbillig', 'Vel''shbillig,Velshbilig,wei er shi bi li xi,Велшбилиг,Вельшбиллиг,韦尔施比利希', 49.8500000, 6.5666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30371, 'Welmbüttel', 'Welmbuttel', 'Vel''mbjuttel'',Velmbitel,Welmbuttel,Welmbüttel,wei er mu bi te er,Велмбител,Вельмбюттель,韦尔姆比特尔', 54.2000000, 9.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30372, 'Wellingsbüttel', 'Wellingsbuettel', '', 53.6410400, 10.0798000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30373, 'Welling', 'Welling', '', 50.3333300, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30374, 'Wellendingen', 'Wellendingen', 'Velendingen,Vellendingen,wei lun ding gen,Велендинген,Веллендинген,Веллендінген,韦伦丁根', 48.1474500, 8.7037500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30375, 'Wellen', 'Wellen', '', 52.1451800, 11.4410600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30376, 'Wellen', 'Wellen', '', 49.6666700, 6.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30377, 'Welle', 'Welle', '', 53.2398500, 9.8017800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30378, 'Welkenbach', 'Welkenbach', '', 50.6333300, 7.7263900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30379, 'Welgesheim', 'Welgesheim', '', 49.8833300, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30380, 'Welden', 'Welden', 'Vel''den,Velden,wei er deng,Велден,Вельден,Վելդեն,韦尔登', 48.4550500, 10.6608600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30381, 'Welchweiler', 'Welchweiler', 'Vel''khvajler,Velkhvajler,wei er xi wei lei,Велхвајлер,Вельхвайлер,韦尔希韦勒', 49.5833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30382, 'Welcherath', 'Welcherath', '', 50.3166700, 6.9666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30383, 'Weitramsdorf', 'Weitramsdorf', '', 50.2560000, 10.8798900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30384, 'Weitnau', 'Weitnau', 'Vajtnau,Vaytnau,Weitnau,wei te nao,Вайтнау,Вајтнау,Վայտնաու,魏特瑙', 47.6417100, 10.1273200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30385, 'Weitersweiler', 'Weitersweiler', '', 49.6166700, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30386, 'Weiterstadt', 'Weiterstadt', 'Gorad Vajtehrshtat,Vajtershtadt,Vajtershtat,Weiterstadt,faytrshtat,vu~aitashutatto,waytrashtat,wei te er si ta te,Вайтерштадт,Вајтерштат,Горад Вайтэрштат,فايترشتات,وایتراشتات,ヴァイターシュタット,魏特尔斯塔特', 49.9039000, 8.5887400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30387, 'Weitersburg', 'Weitersburg', '', 50.4166700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30388, 'Weitersborn', 'Weitersborn', 'Vajtersborn,wei te er si bo er en,Вайтерсборн,Вајтерсборн,魏特尔斯博尔恩', 49.8500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30389, 'Weitersbach', 'Weitersbach', '', 49.8666700, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30390, 'Weitenhagen', 'Weitenhagen', 'Weitenhagen', 54.0537200, 13.4099800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30391, 'Weiten', 'Weiten', '', 49.5301100, 6.5406400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30392, 'Weitefeld', 'Weitefeld', '', 50.7254100, 7.9280500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30393, 'Weisweil', 'Weisweil', 'Owayzvayl,Vajsvajl,Vajsvajl'',wei si wei er,Вайсвайль,Вајсвајл,Ուայզվայլ,魏斯魏尔', 48.1993900, 7.6771300, 'DE', '2011-09-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30394, 'Weißwasser', 'Weisswasser', 'Bela Woda,Betla Woda,Biala Woda,Bialawoda,Biała Woda,Białawoda,Bětła Woda,Běła Woda,Vajsvaser,Vajsvasser,Veisvasere,Weisswasser,Weisswasser/Bela Woda,Weisswasser/O.L.,Weisswasser/Oberlausitz,Weißwasser,Weißwasser/Běła Woda,Weißwasser/O.L.,Weißwasser/Oberlausitz,faysfasr,wayswasr,wei si wa sai er,Вайсвасер,Вайсвассер,Вајсвасер,فايسفاسر,وایسواسر,魏斯瓦塞尔', 51.5040300, 14.6401700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30395, 'Weißkeißel', 'Weisskeissel', 'Vajskajsel,Vajskajsel'',Weiskeissel,Weisskeissel,Weisskeissel/Wuskidz,Weisskeisseli vald,Weißkeißel,Weißkeißel/Wuskidź,Weißkeißeli vald,Wuskidz,Wuskidź,wei si kai sai er,Вайскайсель,Вајскајсел,魏斯凯塞尔', 51.4940500, 14.7151500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30396, 'Weißig', 'Weissig', 'Weissig,Weissig Ort,Weißig,Weißig Ort', 51.2919200, 13.4411700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30397, 'Weißenthurm', 'Weissenthurm', 'Vajsenturm,Weissenthurm,Weißenthurm,faysntwrm,vu~aisentsurumu,waysntwrm,wei sen tu er mu,Вайсентурм,Вајсентурм,فايسنتورم,وایسنتورم,ヴァイセンツルム,魏森图尔姆', 50.4171900, 7.4507200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30398, 'Weißenstadt', 'Weissenstadt', 'Vajsenshtadt,Vajsenshtat,Vaysenstad,Weissenstadt,Weißenstadt,faysnshtat,vu~aisenshutatto,wei sen si ta te,Вайсенштадт,Вајсенштат,Վայսենշտադ,فايسنشتات,وایسن‌اشتات,ヴァイセンシュタット,魏森斯塔特', 50.1021700, 11.8884900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30399, 'Weißensee', 'Weissensee', 'Weissensee,Weißensee', 51.1998900, 11.0691400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30400, 'Weißensberg', 'Weissensberg', 'Vajsensberg,Vaysensberg,wei sen si bei ge,Вайсенсберг,Вајсенсберг,Վայսենսբերգ,魏森斯贝格', 47.5813000, 9.7258600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30401, 'Weißenohe', 'Weissenohe', 'Owayzenoe,Vajsenoe,Vajsenoeh,Vajsenokhe,vu~aisenoe,wei sai nuo hei,Вайсеное,Вайсеноэ,Вајсенохе,Ուայզենոե,ヴァイセノーエ,魏塞诺黑', 49.6308900, 11.2536900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30402, 'Weißenhorn', 'Weissenhorn', 'Vajsengorn,Vajsenkhorn,Vaysenhorn,Weissenhorn,Weißenhorn,faysnhwrn,waynhwrn,wei sen huo er en,Вайсенгорн,Вайсенхорн,Вајсенхорн,Վայսենհորն,فايسنهورن,واینهورن,魏森霍尔恩', 48.3050100, 10.1604700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30403, 'Weißenfels', 'Weissenfels', 'Gorad Vajsehnfel''s,Leucopetra,Vaisenfelsas,Vajsenfel''s,Vajsenfels,Weissenfels,Weißenfels,faysnfls,waysnfls,wei sen fei er si,wyysnpls,Вайсенфелс,Вайсенфельс,Вајсенфелс,Горад Вайсэнфельс,וייסנפלס,فايسنفلس,وایسنفلس,魏森费尔斯', 51.2014800, 11.9684300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30404, 'Weißendorf', 'Weissendorf', '', 50.6833300, 12.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30405, 'Weißenburg in Bayern', 'Weissenburg in Bayern', 'Vaisenmpournk in Bagiern,Vajsenburg in Bajern,Vajsenburg-in-Baern,Vajsenburg-in-Bajern,Vaysenburg,Veisenburgas Bavarijoje,Weissenburg,Weissenburg in Bayern,Weissenburgum Noricorum,Weißenburg,bai en zhou wei sen bao,faysnbwrgh an bayrn,waysnbwrg dr bayrn,Βάισενμπουργκ ιν Μπάγιερν,Вайсенбург-ин-Байерн,Вайсенбург-ін-Баєрн,Вајсенбург ин Бајерн,Վայսենբուրգ,فايسنبورغ إن بايرن,وایسنبورگ در بایرن,拜恩州魏森堡', 49.0309500, 10.9722100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30406, 'Weißenbrunn', 'Weissenbrunn', 'Owayzenbrun,Vajsenbrun,Vajsenbrunn,vu~aisenburun,wei sen bu lun,Вайсенбрунн,Вајсенбрун,Ուայզենբրուն,ヴァイセンブルン,魏森布伦', 50.2000000, 11.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30407, 'Weißenborn-Lüderode', 'Weissenborn-Luederode', 'Vajsenborn-Liderode,Vajsenborn-Ljuderode,Weissenborn-Luderode,Weißenborn-Lüderode,Вайсенборн-Людероде,Вајсенборн-Лидероде', 51.5319000, 10.4188900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30408, 'Weißenborn', 'Weissenborn', 'Vajsenborn,vu~aisenborun,Вайсенборн,Вајсенборн,ヴァイセンボルン', 51.1251300, 10.1160100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30409, 'Weißenborn', 'Weissenborn', '', 50.9239300, 11.8794700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30410, 'Weißenborn', 'Weissenborn', '', 50.7395200, 12.4705100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30411, 'Weißenberg', 'Weissenberg', 'Vajsenberg,Veisenberga,Weissenberg,Weissenberg/Wospork,Weißenberg,Weißenberg/Wóspork,Wospork,Wóspork,faysnbrgh,waysnbrg,wei sen bei ge,Вайсенберг,Вајсенберг,فايسنبرغ,وایسنبرگ,魏森贝格', 51.1964400, 14.6587400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30412, 'Weißdorf', 'Weissdorf', 'Vajsdorf,Weissdorf,Weißdorf,vu~aisudorufu,waysdwrf,wei si duo fu,Вайсдорф,Вајсдорф,وایسدورف,ヴァイスドルフ,魏斯多夫', 50.1833300, 11.8500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30413, 'Weißbach', 'Weissbach', '', 50.8166700, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30414, 'Weißbach', 'Weissbach', '', 49.2971700, 9.5953100, 'DE', '2017-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30415, 'Weißandt-Gölzau', 'Weissandt-Goelzau', 'Golzau-Weissandt,Gölzau-Weißandt,Vajsandt-Gjol''cau,Vajsant-Gelcau,Weissandt-Goelzau,Weissandt-Golzau,Weißandt-Gölzau,Вайсандт-Гёльцау,Вайсандт-Гөльцау,Вајсант-Гелцау', 51.6707000, 12.0733800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30416, 'Weissach', 'Weissach', 'Owayzax,Vajsakh,Vajssakh,vaisakhi,wei sa,Вайсах,Вайссах,Вајсах,Ուայզախ,ვაისახი,魏萨', 48.8468700, 8.9282800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30417, 'Weismain', 'Weismain', 'Vajsmajn,Vayzmayn,fayzmayn,vu~aisumain,wayzmayn,wei si mai yin,Вайсмайн,Вајсмајн,Վայզմայն,فايزماين,وایزماین,ヴァイスマイン,魏斯迈因', 50.0851200, 11.2402400, 'DE', '2017-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30418, 'Weiskirchen', 'Weiskirchen', 'Vajskirkhen,ways kyrshn,wei si ji xing,Вайскирхен,Вайскірхен,Вајскирхен,وایس کیرشن,魏斯基兴', 49.5500000, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30419, 'Weisenheim am Sand', 'Weisenheim am Sand', 'Vajzenkhajm am Zand,Vajzenkhajm-am-Zand,Waisrem,wei sen hai mu a mu sang de,Вайзенхайм-ам-Занд,Вајзенхајм ам Занд,魏森海姆阿姆桑德', 49.5180600, 8.2477800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30420, 'Weisenheim am Berg', 'Weisenheim am Berg', 'Vajzenkhajm am Berg,Vajzenkhajm-am-Berg,shan lu wei sen hai mu,Вайзенхайм-ам-Берг,Вајзенхајм ам Берг,山麓魏森海姆', 49.5130600, 8.1538900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30421, 'Weisendorf', 'Weisendorf', 'Vajzendorf,vu~aizendorufu,wei sen duo fu,Вайзендорф,Вајзендорф,ヴァイゼンドルフ,魏森多夫', 49.6228300, 10.8253100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30422, 'Weisenbach', 'Weisenbach', '', 48.7275700, 8.3537800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30423, 'Weisen', 'Weisen', '', 53.0251800, 11.7871000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30424, 'Weisel', 'Weisel', '', 50.1166700, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30425, 'Weischlitz', 'Weischlitz', 'Vajshlic,wei shi li ci,Вайшлиц,Вајшлиц,魏施利茨', 50.4500000, 12.0666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30426, 'Weira', 'Weira', 'Weira', 50.7000000, 11.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30427, 'Weinstadt-Endersbach', 'Weinstadt-Endersbach', 'Endersbach', 48.8131100, 9.3638700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30428, 'Weinsheim', 'Weinsheim', '', 50.2333300, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30429, 'Weinsheim', 'Weinsheim', '', 49.8333300, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30430, 'Weinsberg', 'Weinsberg', 'Vajnsberg,Vaynsberq,Weinsberg,faynzbrgh,vu~ainsuberuku,waynzbrg,wei yin si bei ge,Вайнсберг,Вајнсберг,فاينزبرغ,واینزبرگ,ヴァインスベルク,韦因斯贝格', 49.1512700, 9.2876200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30431, 'Weinolsheim', 'Weinolsheim', '', 49.8158300, 8.2727800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30432, 'Weinheim', 'Weinheim', 'Vajngajm,Vajnkhajm,Weinheim,Woinem,faynhaym,vu~ainhaimu,waynhaym,wei yin hai mu,wyynhyym,Вайнгайм,Вайнхайм,Вајнхајм,ויינהיים,فاينهايم,واینهایم,ヴァインハイム,韦因海姆', 49.5488700, 8.6669700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30433, 'Weingarten', 'Weingarten', '', 49.2594600, 8.2862000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30434, 'Weingarten', 'Weingarten', 'Vajngarten,Weingarten,Вайнгартен,Вајнгартен', 49.0545700, 8.5267800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30435, 'Weingarten', 'Weingarten', 'Vajngarten,Weingarten,faynghartn,wayngartn,wei yin jia er teng,Вайнгартен,Вајнгартен,فاينغارتن,واینگارتن,韦因加尔滕', 47.8100900, 9.6386300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30436, 'Weinböhla', 'Weinbohla', 'Vajnbela,Vajnbjola,Weinboehla,Weinboehla vald,Weinbohla,Weinböhla,Weinböhla vald,wei yin bo he la,Вайнбела,Вайнбёла,Вајнбела,韦因伯赫拉', 51.1666700, 13.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30437, 'Weinbach', 'Weinbach', 'Vajnbakh,Weinbach,wei yin ba he,Вайнбах,Вајнбах,韦因巴赫', 50.4384300, 8.2913300, 'DE', '2012-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30438, 'Weinähr', 'Weinaehr', '', 50.3227800, 7.8469000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30439, 'Weimar', 'Weimar', 'Gorad Vejmar,Vaimari,Vajmar,Vajmaro,Veimar,Veimara,Veimaras,Veimāra,Vejmar,Veymar,Vimaria,Vymar,Výmar,Wehimala,Weimar,baimaleu,faymr,va''imara,vaimari,vu~aimaru,waymar,waymr,wei ma,wi mar,Βαϊμάρη,Ваймар,Вајмар,Веймар,Горад Веймар,ויימאר,فايمر,وائمر,وایمار,वाईमार,ไวมาร์,ვაიმარი,ヴァイマル,魏玛,바이마르', 50.9803000, 11.3290300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30440, 'Weiltingen', 'Weiltingen', 'Vajl''tingen,Vajltingen,Vayltingen,Weiltingen,vu~airutingen,wei er ting gen,Вайлтинген,Вайльтинген,Вайльтінген,Вајлтинген,Վայլտինգեն,ヴァイルティンゲン,魏尔廷根', 49.0387800, 10.4505200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30441, 'Weilmünster', 'Weilmuenster', 'Vajl''mjunster,Vajlminster,Weilmuenster,Weilmünster,wei er ming si te er,Вайльмюнстер,Вајлминстер,魏尔明斯特尔', 50.4314300, 8.3767300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30442, 'Weil im Schönbuch', 'Weil im Schonbuch', 'Vajl im Sh''onbukh,Vajl im Shenbukh,Vajl''-im-Shenbukh,Vajl''-im-Shjonbukh,Vayl im Syonbux,Weil,Weil im Schoenbuch,Weil im Schönbuch,vail-im-shenbukhi,wei er yi mu shen bu,Вайл им Шьонбух,Вайль-им-Шёнбух,Вайль-ім-Шенбух,Вајл им Шенбух,Վայլ իմ Շյոնբուխ,ვაილ-იმ-შენბუხი,魏尔伊姆申布', 48.6227000, 9.0635500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30443, 'Weilheim an der Teck', 'Weilheim an der Teck', 'Vajl''gajm-an-der-Tek,Vajl''khajm-an-der-Tek,Vajl''khajm-an-der-Tekk,Vajlkhajm an der Tek,Vaylhaym an der Tek,Weilheim,faylhaym an dr tk,tai ke shan lu wei er hai mu,waylhaym an dr tk,Вайльгайм-ан-дер-Тек,Вайльхайм-ан-дер-Тек,Вайльхайм-ан-дер-Текк,Вајлхајм ан дер Тек,Վայլհայմ ան դեր Տեկ,فايلهايم آن در تك,وایلهایم آن در تک,泰克山麓魏尔海姆', 48.6157200, 9.5375100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30444, 'Weilheim', 'Weilheim', 'Vajl''khajm-in-Oberbajern,Vajlkhajm u Gornoj Bavarskoj,Weilheim,Weilheim in Alta Baviera,Weilheim in Oberbayern,Wilheim,waylhaym dr awbrbayrn,Вайльхайм-ин-Обербайерн,Вајлхајм у Горњој Баварској,وایلهایم در اوبربایرن,ヴァイルハイム・イン・オーバーバイエルン', 47.8414700, 11.1548400, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30445, 'Weilheim', 'Weilheim', 'Weilheim', 47.6666700, 8.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30446, 'Weilerswist', 'Weilerswist', 'Vajlersvist,Weilerswist,wei lei si wei si te,Вайлерсвист,Вайлерсвіст,Вајлерсвист,魏勒斯维斯特', 50.7529200, 6.8458500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30447, 'Weilerbach', 'Weilerbach', '', 49.4833300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30448, 'Weiler', 'Weiler', '', 50.3166700, 7.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30449, 'Weiler', 'Weiler', '', 50.1500000, 7.0833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30450, 'Weiler', 'Weiler', '', 49.9569600, 7.8648400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30451, 'Weilen unter den Rinnen', 'Weilen unter den Rinnen', 'Vajlen unter den Rinen,Vajlen-unter-den-Rinnen,wei lun weng te er deng li nen,Вайлен-унтер-ден-Риннен,Вайлен-унтер-ден-Ріннен,Вајлен унтер ден Ринен,魏伦翁特尔登里嫩', 48.1898400, 8.7648600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30452, 'Weil der Stadt', 'Weil der Stadt', 'Vajl der Shtat,Vajl''-der-Shtadt,Vayl der Stadt,Weil der Stadt,baildeeosyutateu,fayl dr shtat,wayl shhr,wei er de er si ta te,Вайль-дер-Штадт,Вајл дер Штат,Վայլ դեր Շտադտ,فايل در شتات,وایل شهر,ვაილ-დერ-შტადტი,魏尔德尔斯塔特,바일데어슈타트', 48.7495300, 8.8717600, 'DE', '2012-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30453, 'Weilburg', 'Weilburg', 'Vajl''burg,Vajlburg,Weilborg,Weilbourg,Weilburg,faylbwrgh,waylbwrg,wei er bao,Вайлбург,Вайльбург,Вајлбург,فايلبورغ,وایلبورگ,魏爾堡', 50.4843800, 8.2624900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30454, 'Weilbach', 'Weilbach', 'Vajl''bakh,Vajlbakh,Vaylbax,Weilbach,vu~airubahha,wei er ba he,Вайльбах,Вајлбах,Վայլբախ,ヴァイルバッハ,魏尔巴赫', 49.6681200, 9.2163900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30455, 'Weilar', 'Weilar', 'Vajlar,wei la er,Вайлар,Вајлар,魏拉尔', 50.7666700, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30456, 'Weil am Rhein', 'Weil am Rhein', 'Rejn Vajl'',Stadt Weil am Rhein,Vajl am Rejn,Vajl na Rajni,Vajl''-am-Rajn,Vajl''-na-Rejne,Vajl''-na-Rejni,Weil am Rhein,Weil-am-Rhein,fayl am rayn,lai yin he pan wei er,wayl an dr rayn,Вайл ам Рейн,Вайль-ам-Райн,Вайль-на-Рейне,Вайль-на-Рейні,Вајл на Рајни,Рейн Вайль,וייל אם ריין,فايل آم راين,وایل آن در راین,ヴァイル・アム・ライン,莱茵河畔魏尔', 47.5933100, 7.6208200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30457, 'Weil', 'Weil', '', 48.1171700, 10.9216100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30458, 'Weikersheim', 'Weikersheim', 'Vajkersgajm,Vajkerskhajm,Weikersheim,faykrzhaym,vu~aikasuhaimu,waykrzhaym,wei ke er si hai mu,Вайкерсгайм,Вайкерсхайм,Вајкерсхајм,فايكرزهايم,وایکرزهایم,ヴァイカースハイム,魏克尔斯海姆', 49.4786600, 9.8997700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30459, 'Weihmichl', 'Weihmichl', '', 48.6000000, 12.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30460, 'Weiherhammer', 'Weiherhammer', 'Vaergammer,Vajerkhammer,Vajkherkhamer,Vayerhamer,wei hei la mei er,Вайерхаммер,Ваєргаммер,Вајхерхамер,Վայերհամեր,魏黑拉梅尔', 49.6333300, 12.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30461, 'Weihenzell', 'Weihenzell', 'Vajencell'',Vajgencel'',Vajkhencel,vu~aientsu~eru,wei heng ce er,Вайгенцель,Вайенцелль,Вајхенцел,Վայենցել,ヴァイエンツェル,魏亨策尔', 49.3500000, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30462, 'Weigenheim', 'Weigenheim', '', 49.5757800, 10.2644000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30463, 'Weigendorf', 'Weigendorf', 'Vajgendorf,Vaygendorf,wei gen duo fu,Вайгендорф,Вајгендорф,Վայգենդորֆ,魏根多夫', 49.4977300, 11.5686900, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30464, 'Weidingen', 'Weidingen', '', 50.0166700, 6.3833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30465, 'Weiding', 'Weiding', '', 49.4833300, 12.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30466, 'Weiding', 'Weiding', '', 49.2628200, 12.7631100, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30467, 'Weidhausen bei Coburg', 'Weidhausen bei Coburg', 'Vajdgauzen,Vajdkhauzen baj Koburg,Vajdkhauzen-Koburg,Vaydhauzen Koburg,Weidhausen,Weidhausen bei Coburg,wei de hao sen bai ke bao,Вайдгаузен,Вайдхаузен-Кобург,Вајдхаузен бај Кобург,Վայդհաուզեն Կոբուրգ,ヴァイトハウゼン・バイ・コーブルク,魏德豪森拜科堡', 50.2035400, 11.1400600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30468, 'Weidenthal', 'Weidenthal', 'Vajdental,Vajdental'',wei deng ta er,Вайденталь,Вајдентал,魏登塔尔', 49.4166700, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30469, 'Weidenstetten', 'Weidenstetten', 'Vajdenshteten,Vajdenshtetten,wei deng si te teng,Вайденштеттен,Вајденштетен,Վայդենշտեթեն,ვაიდენშტეტენი,魏登斯特滕', 48.5525000, 9.9961000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30470, 'Weidenhahn', 'Weidenhahn', '', 50.5472200, 7.8338600, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30471, 'Weidenbach', 'Weidenbach', '', 50.1500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30472, 'Weidenbach', 'Weidenbach', '', 50.1333300, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30473, 'Weidenbach', 'Weidenbach', 'Vajdenbakh,Vaydenbax,Weidenbach,vu~aidenbahha,Вайденбах,Вајденбах,Վայդենբախ,ヴァイデンバッハ', 49.1981700, 10.6448900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30474, 'Weiden', 'Weiden', '', 49.8166700, 7.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30475, 'Weiden', 'Weiden', 'Vajden,Weiden,Weyden,Вайден', 49.6768200, 12.1561300, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30476, 'Weida', 'Weida', 'Weida', 50.7744900, 12.0602800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30477, 'Weichs', 'Weichs', 'Vajkhs,Vajks,wayks,wei xi si,Вайкс,Вајхс,Վայքս,وایکس,魏希斯', 48.3833300, 11.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30478, 'Weichering', 'Weichering', 'Vajkhering,Vayxering,wayshryng,wei xie ling,Вайхеринг,Вайхерінг,Вајхеринг,Վայխերինգ,وایشرینگ,魏歇灵', 48.7171300, 11.3214100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30479, 'Weibersbrunn', 'Weibersbrunn', 'Vajbersbrun,Vajbersbrunn,Vaybersbrun,vu~aibasuburun,wei bei er si bu lun,Вайберсбрунн,Вајберсбрун,Վայբերսբրուն,ヴァイバースブルン,魏贝尔斯布伦', 49.9308300, 9.3661100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30480, 'Weibern', 'Weibern', '', 50.4080800, 7.1466900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30481, 'Weißensee', 'Weissensee', 'Berlin-Weissensee,Berlin-Weißensee,Vajsenze,Weissensee,wyysnzh,Вайсензе,וייסנזה', 52.5563200, 13.4664900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30482, 'Wehringen', 'Wehringen', 'Veringen,wei lin gen,Веринген,Верінген,Վերինգեն,韦林根', 48.2500000, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30483, 'Wehrheim', 'Wehrheim', 'Vergajm,Verkhajm,Wehrheim,wei lai mu,Вергайм,Верхайм,Верхајм,韦赖姆', 50.3000000, 8.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30484, 'Wehrbleck', 'Wehrbleck', '', 52.6289000, 8.6901900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30485, 'Wehr', 'Wehr', '', 50.4166700, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30486, 'Wehr', 'Wehr', '', 47.6298300, 7.9042300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30487, 'Wehnde', 'Wehnde', 'Wehnde', 51.4833300, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30488, 'Wehingen', 'Wehingen', 'Vekhingen,wei xin gen,Вехинген,韦欣根', 48.1453300, 8.7915100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30489, 'Wegscheid', 'Wegscheid', 'Vegsayd,Vegshajd,wei ge sha yi de,wgshayd,Вегшайд,Вегшајд,Վեգշայդ,وگشاید,韦格沙伊德', 48.6013600, 13.7873300, 'DE', '2011-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30490, 'Wegeleben', 'Wegeleben', 'Vegeleben,Wegeleben,fyghylybn,wei ge lai ben,wglbn,Вегелебен,فيغيليبن,وگلبن,韦格莱本', 51.8837600, 11.1734700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30491, 'Wegberg', 'Wegberg', 'Berk,Vegberg,Wegberg,fghbrgh,wei ge bei ge,wgbrg,Вегберг,فغبرغ,وگبرگ,韦格贝格', 51.1422100, 6.2843600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30492, 'Weferlingen', 'Weferlingen', 'Veferlingen,Weferlingen,Веферлинген', 52.3120500, 11.0579100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30493, 'Wefensleben', 'Wefensleben', 'Wefensleben', 52.1831900, 11.1607400, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30494, 'Weeze', 'Weeze', 'Vece,Weeze,Weeze vald,fyzh,wei ce,Веце,فيزه,韦策', 51.6267800, 6.1979200, 'DE', '2016-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30495, 'Weesby', 'Weesby', 'Weesby', 54.8333300, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30496, 'Wees', 'Wees', 'Ves,Wees,wei si,Вес,韦斯', 54.8062100, 9.5169500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30497, 'Weenzen', 'Weenzen', 'Vencen,wen cen,Венцен,文岑', 52.0333300, 9.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30498, 'Weener', 'Weener', 'Vener,Weener,fynr,wei nei er,wynr,Венер,فينر,وینر,韦内尔', 53.1633200, 7.3505200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30499, 'Weede', 'Weede', 'Weede', 53.9228200, 10.3708200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30500, 'Wedel', 'Wedel', 'Vedel,Vedel'',Vedelis,Vėdelis,Wedel,fydl,wdl,wei de er,Ведел,Ведель,فيدل,ودل,韦德尔', 53.5837400, 9.6983500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30501, 'Weddingstedt', 'Weddingstedt', 'Veddingshtedt,Vedingshtet,wei ding shi tai te,Веддингштедт,Ведингштет,韦丁施泰特', 54.2342800, 9.0910300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30502, 'Wedding', 'Wedding Bezirk', 'Berlin-Wedding,Vedding,Veding,wdyng,wei ding,Веддинг,Вединг,ודינג,威丁', 52.5473400, 13.3559400, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30503, 'Weddersleben', 'Weddersleben', 'Weddersleben', 51.7653300, 11.0853100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30504, 'Weddelbrook', 'Weddelbrook', 'Weddelbrook', 53.9000000, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30505, 'Wechselburg', 'Wechselburg', 'Vekhselburg,Veksel''burg,Vekselburg,Wechselburgi vald,wei xi sai er bao,Векселбург,Вексельбург,Вехселбург,韦希塞尔堡', 51.0021400, 12.7766100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30506, 'Wechingen', 'Wechingen', 'Vekhingen,Vexingen,vu~ehingen,Вехинген,Вехінген,Վեխինգեն,ヴェヒンゲン', 48.8922900, 10.6133100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30507, 'Weberstedt', 'Weberstedt', 'Vebershtedt,Vebershtet,wei bei er si te,Веберштедт,Веберштет,韦贝尔斯特', 51.1083900, 10.5106000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30508, 'Waxweiler', 'Waxweiler', 'Vaksvajler,Waxweiler,wa ke si wei lei,Ваксвайлер,Ваксвајлер,瓦克斯韦勒', 50.0925700, 6.3629900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30509, 'Wawern', 'Wawern', '', 50.1166700, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30510, 'Wawern', 'Wawern', '', 49.6500000, 6.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30511, 'Watzerath', 'Watzerath', '', 50.1833300, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30512, 'Wattmannshagen', 'Wattmannshagen', '', 53.7759000, 12.4070100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30513, 'Wattenheim', 'Wattenheim', 'Vatenkhajm,Vattenkhajm,wa teng hai mu,Ватенхајм,Ваттенхайм,瓦滕海姆', 49.5216700, 8.0616700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30514, 'Wattendorf', 'Wattendorf', 'Vatendorf,Vattendorf,vu~attendorufu,wa teng duo fu,Ватендорф,Ваттендорф,Վաթենդորֆ,ヴァッテンドルフ,瓦滕多夫', 50.0326100, 11.1262300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30515, 'Wattenbek', 'Wattenbek', 'Wattenbek', 54.1666700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30516, 'Wathlingen', 'Wathlingen', 'Vatlingen,Waditlagun [a. 1022],Wateln,Wathlingen,Wodeln,wa te lin gen,Ватлинген,瓦特林根', 52.5369000, 10.1506900, 'DE', '2014-08-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30517, 'Wasungen', 'Wasungen', 'Vazungen,Wasungen,fazwnghn,wa sun gen,wazwngn,Вазунген,فازونغن,وازونگن,瓦孙根', 50.6619000, 10.3694700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30518, 'Wassertrüdingen', 'Wassertrudingen', 'Vasertridingen,Vasertrjudingen,Vasertryudingen,Vassertrjudingen,Wassertrudingen,Wassertruedingen,Wassertrüdingen,fasrtrwdynghn,vu~assatoryudingen,wa sai er te lu ding gen,wayrtrwdyngn,Васертридинген,Васертрюдинген,Вассертрюдинген,Вассертрюдінген,Վասերտրյուդինգեն,فاسرترودينغن,وایرترودینگن,ヴァッサートリューディンゲン,瓦塞尔特吕丁根', 49.0432800, 10.5990600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30519, 'Wasserthaleben', 'Wasserthaleben', 'Wasserthaleben', 51.2500000, 10.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30520, 'Wasserlosen', 'Wasserlosen', 'Vaserlozen,Vasserlozen,wa sai er luo sen,wasrlwzn,Васерлозен,Вассерлозен,واسرلوزن,瓦塞尔洛森', 50.0947600, 10.0301700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30521, 'Wasserliesch', 'Wasserliesch', 'Vaserlish,Vasserlish,Wasserliesch,wa sai er li shi,Васерлиш,Вассерлиш,瓦塞尔利施', 49.7073900, 6.5394400, 'DE', '2015-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30522, 'Wasserleben', 'Wasserleben', 'Vaserleben,Vasserleben,Wasserleben,Васерлебен,Вассерлебен', 51.9208900, 10.7567000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30523, 'Wasserburg am Inn', 'Wasserburg am Inn', 'Inni Vaserburg,Vaserburg na In,Vaserburg na Inu,Vasserburg-am-Inn,Wassabuag am Inn,Wasserburg,fasrbwrgh am an,wayrbwrg an dr ayn,yin he pan wa se bao,Васербург на Ин,Васербург на Ину,Вассербург-ам-Інн,Вассербург-ам-Инн,Իննի Վասերբուրգ,فاسربورغ آم إن,وایربورگ آن در این,因河畔瓦瑟堡', 48.0525000, 12.2234100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30524, 'Wasserburg', 'Wasserburg', '', 48.4410500, 10.2693000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30525, 'Wassenberg', 'Wassenberg', 'Vasenberg,Vassenberg,Wasseberg,Wassenberg,fasnbrgh,wa sen bei ge,waznbrg,Васенберг,Вассенберг,فاسنبرغ,وازنبرگ,瓦森贝格', 51.1000900, 6.1548400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30526, 'Wassenach', 'Wassenach', '', 50.4333300, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30527, 'Wasenbach', 'Wasenbach', 'Vazenbakh,wa sen ba,Вазенбах,瓦森巴', 50.3166700, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30528, 'Wäschenbeuren', 'Waschenbeuren', 'Veshenbojren,Waeschenbeuren,Wäschenbeuren,wei shen bo yi lun,Вешенбойрен,Вешенбојрен,韦申博伊伦', 48.7599100, 9.6873500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30529, 'Wasbüttel', 'Wasbuttel', 'Vasbitel,Vasbjuttel'',wa si bi te er,Васбител,Васбюттель,瓦斯比特尔', 52.4133100, 10.5935700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30530, 'Wasbek', 'Wasbek', 'Wasbek', 54.0742700, 9.8973800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30531, 'Warza', 'Warza', 'Warza', 51.0000000, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30532, 'Wartmannsroth', 'Wartmannsroth', 'Vartmannsrot,Vartmansrot,wa er te man si luo te,Вартманнсрот,Вартмансрот,Վարտմանսրոտ,瓦尔特曼斯罗特', 50.1666700, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30533, 'Warthausen', 'Warthausen', 'Vartauzen,Vartgauzen,Varthauzen,Vartkhauzen,wa er tao sen,Вартаузен,Вартгаузен,Вартхаузен,Վարտհաուզեն,ვარტჰაუზენი,瓦尔陶森', 48.1286300, 9.7974900, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30534, 'Wartenberg-Rohrbach', 'Wartenberg-Rohrbach', '', 49.5276000, 7.8525800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30535, 'Wartenberg', 'Wartenberg', 'Berlin-Wartenberg', 52.5752000, 13.5155900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30536, 'Wartenberg', 'Wartenberg', 'Vartenberg,Wartenberg,Wartenburg,wartnbrg,Вартенберг,وارتنبرگ', 48.4059700, 11.9886500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30537, 'Warstein', 'Warstein', 'Stadt Warstein,Varshtajn,Warstein,farshtayn,wa er si tai yin,warashtayn,Варштайн,Варштајн,فارشتاين,واراشتاین,瓦尔斯泰因', 51.4448800, 8.3485100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30538, 'Warringholz', 'Warringholz', 'Warringholz', 54.0833300, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30539, 'Warpe', 'Warpe', 'Varpe,vu~arupe,wa er pei,Варпе,ヴァルペ,瓦尔佩', 52.7333300, 9.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30540, 'Warnow', 'Warnow', '', 53.7858000, 11.8810600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30541, 'Warngau', 'Warngau', '', 47.8321700, 11.7217300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30542, 'Warnemünde', 'Warnemuende', 'Seebad Warnemuende,Seebad Warnemünde,Varneminde,Varnemjunde,Warnemuenn,Warnemünn,Wmd,vu~anemyunde,wa er nei ming de,Варнеминде,Варнемюнде,ヴァーネミュンデ,瓦尔内明德', 54.1767000, 12.0840200, 'DE', '2014-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30543, 'Warnau', 'Warnau', '', 54.1833300, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30544, 'Warmsroth', 'Warmsroth', '', 49.9500000, 7.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30545, 'Warmsen', 'Warmsen', 'Varmzen,vu~arumuzen,wa er mu sen,Вармзен,ヴァルムゼン,瓦尔姆森', 52.4569500, 8.8494900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30546, 'Warmensteinach', 'Warmensteinach', 'Varmenshtajnakh,Varmenstaynax,Warmensteinach,vu~arumenshutainaha,wa er men si tai na,Варменштайнах,Варменштајнах,Վարմենշտայնախ,ヴァルメンシュタイナハ,瓦尔门斯泰纳', 49.9934800, 11.7786600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30547, 'Warin', 'Warin', 'Varin,Varine,Vārīne,Warin,faryn,wa lin,waryn,Варин,فارين,وارین,瓦林', 53.8002600, 11.7050400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30548, 'Warendorf', 'Warendorf', 'Gorad Varehndorf,Varendorf,Warendorf,Warendorp,Warnduorp,wa lun duo er fu,warndwrf,Варендорф,Горад Варэндорф,وارندورف,瓦伦多尔夫', 51.9510900, 7.9875600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30549, 'Waren', 'Waren', 'Varen,Varene pie Mirica,Vārene pie Mīrica,Waren,farn,warn,Варен,וארן,فارن,وارن', 53.5204000, 12.6798500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30550, 'Wardow', 'Wardow', 'Wardow', 53.9305400, 12.4081800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30551, 'Warder', 'Warder', '', 54.2166700, 9.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30552, 'Wardenburg', 'Wardenburg', 'Vardenburg,Варденбург', 53.0666700, 8.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30553, 'Warburg', 'Warburg', 'Varburg,Varburgum Vestphalorum,Waberich,Warburg,Warburgu,farbwrgh,vu~aruburuku,wa er bao,warbwrg,Варбург,فاربورغ,واربورگ,ヴァールブルク,瓦尔堡', 51.4901100, 9.1464100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30554, 'Warberg', 'Warberg', 'Varberg,wa er bei ge,Варберг,瓦尔贝格', 52.1812000, 10.9197200, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30555, 'Wapelfeld', 'Wapelfeld', 'Wapelfeld', 54.0833300, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30556, 'Wanzleben', 'Wanzleben', 'Uuanzleua [a. 875],Vancleben,Wanzleben,Wanzlee,Wanzleva,Wonclava,Ŭŭanzleŭa [a. 875],Ванцлебен', 52.0608700, 11.4408000, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30557, 'Wansleben', 'Wansleben', '', 51.4603400, 11.7513500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30558, 'Wannweil', 'Wannweil', 'Vannvajl'',Vanvajl,Vanvajl'',wan wei er,Ванвайль,Ванвајл,Ваннвайль,万魏尔', 48.5166700, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30559, 'Wannsee', 'Wannsee', 'Berlin-Wannsee,Colonie Alsen,Stolpe (Dorf),Stolpeken,Vanze,Vanzee,Wannsee,Wendisch-Stolpe,wan hu,wanzh,Ванзе́,Ванзе́е,ואנזה,وانزه,万湖', 52.4191500, 13.1553100, 'DE', '2015-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30560, 'Wanna', 'Wanna', '', 53.7500000, 8.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30561, 'Wankendorf', 'Wankendorf', 'Vankendorf,wan ken duo fu,Ванкендорф,万肯多夫', 54.1122400, 10.2054600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30562, 'Wangerooge', 'Wangerooge', 'AGE,Vangeroge,Wangereach,Wangeroog,Wangerooge,fanjr awkhh,wan ge luo ge,Вангероге,فانجر أوخه,万格罗格', 53.7900200, 7.8993800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30563, 'Wangen im Allgäu', 'Wangen im Allgau', 'Vangen im Algoj,Vangen-im-All''goj,Wangen,Wangen im Allgaeu,Wangen im Allgau,Wangen im Allgäu,a er gao de qu wang gen,fanghn am alghwy,wangn dr algwy,Ванген им Алгој,Ванген-им-Алльгой,Ванген-ім-Алльгой,فانغن إم آلغوي,وانگن در آلگوی,阿尔高地区旺根', 47.6895000, 9.8324700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30564, 'Wangenheim', 'Wangenheim', 'Vangenkhajm,Wangenheim,wan gen hai mu,Вангенхайм,Вангенхајм,万根海姆', 51.0198200, 10.6242100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30565, 'Wangen', 'Wangen', 'Vangen,Wangen bei Goeppingen,Wangen bei Göppingen,Ванген', 48.7293300, 9.6117500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30566, 'Wangels', 'Wangels', 'Vangel''s,Vangels,Wangels,wan ge er si,Вангелс,Вангельс,万格尔斯', 54.2666700, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30567, 'Wangelnstedt', 'Wangelnstedt', 'Vangel''nshtedt,Vangelnshtet,vu~angerunshutetto,wan ge er en shi tai te,Вангелнштет,Вангельнштедт,ヴァンゲルンシュテット,万格尔恩施泰特', 51.8666700, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30568, 'Wangelau', 'Wangelau', 'Wangelau', 53.4500000, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30569, 'Wang', 'Wang', '', 48.4954900, 11.9364100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30570, 'Wanfried', 'Wanfried', 'Vanfrid,Wanfried,fanfryd,vu~anfurito,wan fu li de,wanfryd,Ванфрид,Ванфрід,فانفريد,وانفرید,ヴァンフリート,万夫里德', 51.1820700, 10.1728300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30571, 'Wandlitz', 'Wandlitz', 'Vandlic,wan de li ci,Вандлиц,Вандліц,Վանդլից,万德利茨', 52.7419600, 13.4579900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30572, 'Wanderup', 'Wanderup', 'Wanderup', 54.6833300, 9.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30573, 'Wandersleben', 'Wandersleben', 'Vandersleben,Wandersleben,Вандерслебен', 50.8994600, 10.8495900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30574, 'Waltrop', 'Waltrop', 'Val''trop,Valtrop,Waltrop,faltrwb,wa er te luo pu,waltrwp,Валтроп,Вальтроп,فالتروب,والتروپ,瓦尔特罗普', 51.6212500, 7.4023800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30575, 'Walting', 'Walting', 'Val''ting,Valting,Walting,wa er ting ge,waltyng,Валтинг,Вальтинг,Вальтінг,Վալտինգ,والتینگ,瓦尔廷格', 48.9166700, 11.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30576, 'Waltershausen', 'Waltershausen', 'Val''terskhauzen,Valterskhauzen,Waltershausen,faltrzhawzn,wa er te er si hao sen,Валтерсхаузен,Вальтерсхаузен,فالترزهاوزن,والترس‌هاوزن,瓦尔特尔斯豪森', 50.8982700, 10.5579100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30577, 'Waltersdorf', 'Waltersdorf', '', 50.8333300, 11.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30578, 'Walterschen', 'Walterschen', '', 50.6833300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30579, 'Waltenhofen', 'Waltenhofen', 'Val''tengofen,Val''tenkhofen,Valtenhofen,Valtenkhofen,wa er teng huo fen,Валтенхофен,Вальтенгофен,Вальтенхофен,Վալտենհոֆեն,瓦尔滕霍芬', 47.6731900, 10.3070300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30580, 'Waltenhausen', 'Waltenhausen', 'Val''tengauzen,Val''tenkhauzen,Valtenhauzen,Valtenkhauzen,wa er teng hao sen,Валтенхаузен,Вальтенгаузен,Вальтенхаузен,Վալտենհաուզեն,瓦尔滕豪森', 48.1904700, 10.3645700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30581, 'Walsrode', 'Walsrode', 'Gemeen Wasra,Val''srode,Valsrode,Walsrode,falzrwdh,wa er si luo de,walzrwdh,Валсроде,Вальсроде,فالزروده,والزروده,瓦尔斯罗德', 52.8614700, 9.5926000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30582, 'Walsleben', 'Walsleben', '', 52.9382900, 12.6644900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30583, 'Walsheim', 'Walsheim', '', 49.2372200, 8.1269400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30584, 'Walshausen', 'Walshausen', '', 49.2166700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30585, 'Walsdorf', 'Walsdorf', '', 50.2833300, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30586, 'Walsdorf', 'Walsdorf', '', 49.8666700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30587, 'Walschleben', 'Walschleben', '', 51.0666700, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30588, 'Walpertskirchen', 'Walpertskirchen', 'Val''pertskirkhen,Valpertskirkhen,wa er pei er ci ji er xing,walprts kyrshn,Валпертскирхен,Вальпертскирхен,Вальпертскірхен,والپرتس کیرشن,瓦尔佩尔茨基尔兴', 48.2584000, 11.9752700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30589, 'Walpernhain', 'Walpernhain', 'Walpernhain', 51.0166700, 11.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30590, 'Wallwitz', 'Wallwitz', '', 51.5802900, 11.9288800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30591, 'Wallstawe', 'Wallstawe', '', 52.8000000, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30592, 'Wallscheid', 'Wallscheid', '', 50.1000000, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30593, 'Wallsbüll', 'Wallsbuell', '', 54.7764100, 9.2368000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30594, 'Wallmerod', 'Wallmerod', 'Val''merod,Valmerod,vu~arumaroto,wa er mei luo de,Валмерод,Вальмерод,ヴァルマロート,瓦尔梅罗德', 50.4833300, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30595, 'Wallmenroth', 'Wallmenroth', '', 50.8000000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30596, 'Wallhausen', 'Wallhausen', 'Valeshusun [a. 1013],Valkhauzen (Khelme),Vall''khauzen (Khel''me),Walahusun [a. 908],Wallhausen (Helme),Валльхаузен (Хельме),Валхаузен (Хелме)', 51.4611700, 11.2076000, 'DE', '2014-12-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30597, 'Wallhausen', 'Wallhausen', '', 49.8833300, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30598, 'Wallhausen', 'Wallhausen', '', 49.2104200, 10.0621900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30599, 'Wallhalben', 'Wallhalben', '', 49.3170700, 7.5214900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30600, 'Wallgau', 'Wallgau', 'Val''gau,Valgau,Valgava,Wallgau,Wollga,wa er gao,walgaw,Валгау,Вальгау,Վալգաու,والگاو,瓦尔高', 47.5166700, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30601, 'Wallertheim', 'Wallertheim', '', 49.8355600, 8.0513900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30602, 'Wallerstein', 'Wallerstein', 'Valershtajn,Vallershtajn,Wallerstein,vu~arashutain,wa lei shi tai yin,Валерштајн,Валлерштайн,Վալերշթայն,ヴァラーシュタイン,瓦勒施泰因', 48.8874100, 10.4759100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30603, 'Wallersheim', 'Wallersheim', '', 50.2031500, 6.5278100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30604, 'Wallersdorf', 'Wallersdorf', 'Valersdorf,Vallersdorf,Wallersdorf,wa lei si duo fu,walrsdwrf,Валерсдорф,Валлерсдорф,Վալերսդորֆ,والرسدورف,瓦勒斯多夫', 48.7376700, 12.7474400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30605, 'Wallerfing', 'Wallerfing', '', 48.6841600, 12.8803500, 'DE', '2012-11-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30606, 'Wallerfangen', 'Wallerfangen', 'Valerfangen,Vallerfangen,Vaudrevange,Wallerfangen,wa lai er fan gen,walrfangn,Валерфанген,Валлерфанген,والرفانگن,瓦莱尔凡根', 49.3274900, 6.7110200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30607, 'Wallenhorst', 'Wallenhorst', 'Valenkhorst,Vallenkhorst,Wallenhorst,wa lun huo er si te,Валенхорст,Валленхорст,瓦伦霍尔斯特', 52.3500000, 8.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30608, 'Wallenfels', 'Wallenfels', 'Valenfels,Vallenfel''s,Wallenfels,falnfylz,vu~arenferusu,wa lun fei er si,walnfldz,Валенфелс,Валленфельс,Վալենֆելս,فالنفيلز,والنفلدز,ヴァレンフェルス,瓦伦费尔斯', 50.2685000, 11.4705800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30609, 'Wallendorf', 'Wallendorf', 'Wallendorf', 51.3598300, 12.0753700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30610, 'Wallendorf', 'Wallendorf', 'Valendorf,Vallendorf,Wallenduerf,wa lun duo fu,Валендорф,Валлендорф,瓦倫多夫', 49.8761200, 6.2891300, 'DE', '2013-11-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30611, 'Wallenborn', 'Wallenborn', 'Valenborn,Vallenborn,wa lun bo er en,Валенборн,Валленборн,瓦伦博尔恩', 50.1500000, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30612, 'Wallen', 'Wallen', '', 54.2833300, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30613, 'Walldürn', 'Walldurn', 'Val''djurn,Valdirn,Vall''djurn,Wallduern,Walldurn,Walldürn,faldwrn,vu~arude~yurun,wa er di er en,waldwrn,Валдирн,Валльдюрн,Вальдюрн,فالدورن,والدورن,ヴァルデュルン,瓦尔迪尔恩', 49.5835800, 9.3664200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30614, 'Walldorf', 'Walldorf', '', 50.6166700, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30615, 'Walldorf', 'Walldorf', 'Val''dorf,Valdorf,Walldoaf,Walldorf,vu~arudorufu,waldwrf,wo er duo fu,Валдорф,Вальдорф,والدورف,ヴァルドルフ,沃尔多夫', 49.3063700, 8.6423600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30616, 'Wallbach', 'Wallbach', '', 50.6333300, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30617, 'Walksfelde', 'Walksfelde', 'Walksfelde', 53.6333300, 10.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30618, 'Walkertshofen', 'Walkertshofen', 'Val''kertsgofen,Val''kertskhofen,Valkertshofen,Valkertskhofen,wa er ke er ci huo fen,Валкертсхофен,Валькертсгофен,Валькертсхофен,Վալկերտսհոֆեն,瓦尔克尔茨霍芬', 48.2261300, 10.5883600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30619, 'Walkenried', 'Walkenried', 'Val''kenrid,Valkenrid,Walkenried,wa er ken li de,Валкенрид,Валькенрид,瓦尔肯里德', 51.5833300, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30620, 'Walheim', 'Walheim', 'Val''gajm,Val''khajm,Valkhajm,Walheim,walhaym,Валхајм,Вальгайм,Вальхайм,والهایم', 49.0141700, 9.1511100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30621, 'Walhausen', 'Walhausen', '', 50.0333300, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30622, 'Waldweiler', 'Waldweiler', 'Waldweiler', 49.6166700, 6.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30623, 'Waldthurn', 'Waldthurn', 'Val''dturn,Valdturn,wa er tu er en,Валдтурн,Вальдтурн,Վալդթուրն,瓦尔图尔恩', 49.6722100, 12.3291900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30624, 'Waldstetten', 'Waldstetten', '', 48.7661500, 9.8213500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30625, 'Waldstetten', 'Waldstetten', '', 48.3481500, 10.2938500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30626, 'Waldsieversdorf', 'Waldsieversdorf', 'Val''dziversdorf,Valdzifersdorf,Valdziversdorf,Valjiversdorf,wa er qi fei er si duo fu,Валдзиверсдорф,Валдзиферсдорф,Вальдзиверсдорф,Վալջիվերսդորֆ,瓦尔齐费尔斯多夫', 52.5422100, 14.0702200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30627, 'Waldshut-Tiengen', 'Waldshut-Tiengen', 'Val''dsgut-Tingen,Val''dskhut-Tingen,Valdskhut-Tingen,Waldshut,faldzhwt-tynghn,wa er ci hu te tian gen,waldzhwt-tyngn,Валдсхут-Тинген,Вальдсгут-Тінген,Вальдсхут-Тинген,فالدزهوت-تينغن,والدزهوت-تینگن,瓦尔茨胡特田根', 47.6232300, 8.2171700, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30628, 'Waldsee', 'Waldsee', '', 49.3952800, 8.4402800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30629, 'Waldsassen', 'Waldsassen', 'Val''dzassen,Valdzasen,Waldsassen,Woidsassen,faldzasn,wa er cha sen,waldzasn,Валдзасен,Вальдзассен,Վալդզասեն,فالدزاسن,والدزاسن,瓦尔察森', 50.0016700, 12.3043400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30630, 'Waldrohrbach', 'Waldrohrbach', '', 49.1666700, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30631, 'Waldrach', 'Waldrach', 'Val''drakh,Valdrakh,valdrakhi,vu~arutorahha,wa er de la,Валдрах,Вальдрах,ვალდრახი,ヴァルトラッハ,瓦尔德拉', 49.7462300, 6.7454300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30632, 'Waldorf', 'Waldorf', '', 50.4833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30633, 'Waldmünchen', 'Waldmunchen', 'Val''dmjunkhen,Valdminkhen,Valdmyunxen,Waldmunchen,Waldmünchen,faldmwnshn,wa er de ming xing,waldmwnshn,Валдминхен,Вальдмюнхен,Վալդմյունխեն,فالدمونشن,والدمونشن,瓦尔德明兴', 49.3780400, 12.7090500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30634, 'Waldmühlen', 'Waldmuhlen', 'Waldmuehlen,Waldmühlen', 50.5833300, 8.0666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30635, 'Waldmohr', 'Waldmohr', 'Val''dmor,Valdmor,vu~arutomoa,wa er de mo er,Валдмор,Вальдмор,ヴァルトモア,瓦尔德莫尔', 49.3833300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30636, 'Wald-Michelbach', 'Wald-Michelbach', 'Val''d-Mikhel''bakh,Vald-Mikhelbakh,Wald-Mischlbach,vu~aruto=mihyerubahha,wa er de-mi xie er ba he,Валд-Михелбах,Вальд-Михельбах,Вальд-Міхельбах,ヴァルト＝ミヒェルバッハ,瓦尔德-米谢尔巴赫', 49.5700000, 8.8316700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30637, 'Waldleiningen', 'Waldleiningen', '', 49.4000000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30638, 'Waldlaubersheim', 'Waldlaubersheim', '', 49.9333300, 7.8333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30639, 'Waldkraiburg', 'Waldkraiburg', 'Val''dkrajburg,Valdkrajburg,Valdkrayburg,Woidkroaburg,faldkraybwrgh,wa er de ke lai bao,waldkraybwrg,Валдкрајбург,Вальдкрайбург,Վալդկրայբուրգ,فالدكرايبورغ,والدکرایبورگ,瓦尔德克赖堡', 48.2085400, 12.3989300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30640, 'Waldkirchen', 'Waldkirchen', '', 50.5966700, 12.3799400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30641, 'Waldkirchen', 'Waldkirchen', 'Val''dkirkhen,Valdkirkhen,Valdkirxen,Waldkirchen,faldkyrshn,wa er de ji er xing,waldkyrshn,Валдкирхен,Вальдкирхен,Вальдкірхен,Վալդկիրխեն,فالدكيرشن,والدکیرشن,瓦尔德基尔兴', 48.7327000, 13.6008200, 'DE', '2011-07-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30642, 'Waldkirch', 'Waldkirch', 'Val''dkirkh,Valdkirkh,Valdkirx,wa er de ji er xi,waldkyrsh,Валдкирх,Вальдкирх,Вальдкірх,Վալդկիրխ,والدکیرش,瓦尔德基尔希', 48.0958500, 7.9637100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30643, 'Waldkappel', 'Waldkappel', 'Val''dkappel'',Valdkapel,Waldkappel,faldkabl,vu~arutokaperu,wa er de ka pei er,waldkpl,Валдкапел,Вальдкаппель,فالدكابل,والدکپل,ヴァルトカペル,瓦尔德卡佩尔', 51.1446200, 9.8769500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30644, 'Waldhof-Falkenstein', 'Waldhof-Falkenstein', '', 49.9666700, 6.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30645, 'Waldheim', 'Waldheim', 'Waldheim', 51.0728200, 13.0200400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30646, 'Waldhambach', 'Waldhambach', '', 49.1666700, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30647, 'Waldgrehweiler', 'Waldgrehweiler', '', 49.6666700, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30648, 'Waldfischbach-Burgalben', 'Waldfischbach-Burgalben', 'Val''dfishbakh-Burgal''ben,Valdfishbakh-Burgalben,Waldfischbach-Bojalwe,Waldfischbach-Burgalben,vu~arutofisshubahha=burugaruben,wa er de fei xi ba he-bu jia er ben,Валдфишбах-Бургалбен,Вальдфишбах-Бургальбен,ヴァルトフィッシュバッハ＝ブルガルベン,瓦尔德费希巴赫-布加尔本', 49.2833300, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30649, 'Waldfeucht', 'Waldfeucht', 'Val''dfojkht,Valdfojkht,Vuch,faldfwkht,wa er de fu yi he te,Валдфојхт,Вальдфойхт,فالدفوخت,瓦尔德福伊赫特', 51.0661000, 5.9881500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30650, 'Waldesch', 'Waldesch', '', 50.2833300, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30651, 'Waldershof', 'Waldershof', 'Val''dersgof,Val''derskhof,Valdershof,Valderskhof,Waldershof,faldrzhwf,wa er de er si huo fu,waldrzhwf,Валдерсхоф,Вальдерсгоф,Вальдерсхоф,Վալդերսհոֆ,فالدرزهوف,والدرزهوف,瓦尔德尔斯霍夫', 49.9814400, 12.0629100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30652, 'Walderbach', 'Walderbach', 'Val''derbakh,Valderbakh,Valderbax,wa er de er ba he,Валдербах,Вальдербах,Վալդերբախ,瓦尔德尔巴赫', 49.1833300, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30653, 'Waldenburg', 'Waldenburg', 'Waldenburg', 50.8765300, 12.5991900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30654, 'Waldenburg', 'Waldenburg', 'Waldenburg', 49.1846800, 9.6399400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30655, 'Waldenbuch', 'Waldenbuch', 'Val''denbukh,Valdenbukh,Valdenbux,faldnbwkh,valdenbukhi,wa er deng bu,waldnbwkh,Валденбух,Вальденбух,Վալդենբուխ,فالدنبوخ,والدنبوخ,ვალდენბუხი,瓦尔登布', 48.6383000, 9.1325600, 'DE', '2012-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30656, 'Waldeck', 'Waldeck', 'Val''dek,Valdek,vu~arudekku,waldk  hsn,Валдек,Вальдек,والدک، هسن,ヴァルデック', 51.2061800, 9.0628600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30657, 'Waldeck', 'Waldeck', '', 50.9166700, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30658, 'Waldbüttelbrunn', 'Waldbuttelbrunn', 'Val''dbjuttel''brunn,Valdbitelbrun,Waldbuettelbrunn,Waldbüttelbrunn,vu~arutobyutteruburun,wa er de bi te er bu lun,Валдбителбрун,Вальдбюттельбрунн,Վալդբյութելբրուն,ヴァルトビュッテルブルン,瓦尔德比特尔布伦', 49.7883300, 9.8466700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30659, 'Waldburg', 'Waldburg', '', 47.7571000, 9.7134200, 'DE', '2013-11-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30660, 'Waldbrunn', 'Waldbrunn', '', 49.7586100, 9.8036100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30661, 'Waldbröl', 'Waldbroel', 'Val''dbrel'',Val''dbrjol'',Valdbrel,Waldbroel,Waldbrol,Waldbröl,faldbrwl,wa er de bu lei er,waldbrwl,Валдбрел,Вальдбрель,Вальдбрёль,فالدبرول,والدبرول,瓦尔德布勒尔', 50.8757600, 7.6168800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30662, 'Waldbreitbach', 'Waldbreitbach', 'Val''dbrajtbakh,Valdbrajtbakh,vu~arutoburaitobahha,wa er de bu lai te ba he,Валдбрајтбах,Вальдбрайтбах,ヴァルトブライトバッハ,瓦尔德布赖特巴赫', 50.5500000, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30663, 'Waldböckelheim', 'Waldbockelheim', 'Val''dbjokkel''khajm,Valdbekelkhajm,Waldboeckelheim,Waldböckelheim,wa er de bo ke er hai mu,Валдбекелхајм,Вальдбёккельхайм,瓦尔德伯克尔海姆', 49.8166700, 7.7166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30664, 'Waldaschaff', 'Waldaschaff', 'Val''dashaff,Valdasaf,Valdashaf,vu~arutoashaffu,wa er da sha fu,Валдашаф,Вальдашафф,Վալդաշաֆ,ヴァルトアシャッフ,瓦尔达沙夫', 49.9752800, 9.3019400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30665, 'Waldalgesheim', 'Waldalgesheim', 'Val''dal''geskhajm,Valdalgeskhajm,wa er da er ge si hai mu,Валдалгесхајм,Вальдальгесхайм,瓦尔达尔格斯海姆', 49.9500000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30666, 'Wald', 'Wald', 'Val''d,Vald,Валд,Вальд,Վալդ', 49.1500000, 12.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30667, 'Wald', 'Wald', 'Kloster Wald,Wald', 47.9722300, 10.3005400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30668, 'Wald', 'Wald', 'Wald', 47.9333300, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30669, 'Wald', 'Wald', '', 47.7227700, 10.5582100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30670, 'Walchum', 'Walchum', '', 52.9271700, 7.2832500, 'DE', '2011-09-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30671, 'Waischenfeld', 'Waischenfeld', 'Vajshenfel''d,Vajshenfeld,Vaysenfeld,fayshnfld,vu~aishenferuto,wayshnfld,wei shen fei er de,Вайшенфельд,Вајшенфелд,Վայշենֆելդ,فايشنفلد,وایشنفلد,ヴァイシェンフェルト,魏申费尔德', 49.8464500, 11.3481000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30672, 'Wain', 'Wain', '', 48.1890400, 10.0209000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30673, 'Waigolshausen', 'Waigolshausen', 'Vajgol''sgauzen,Vajgol''skhauzen,Vajgolskhauzen,waygwlhawzn,wei ge er si hao sen,Вайгольсгаузен,Вайгольсхаузен,Вајголсхаузен,وایگولهاوزن,魏戈尔斯豪森', 49.9643000, 10.1200100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30674, 'Waigandshain', 'Waigandshain', '', 50.6447200, 8.0852800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30675, 'Waidhofen', 'Waidhofen', '', 48.5768100, 11.3353700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30676, 'Waidhaus', 'Waidhaus', 'Vajdgaus,Vajdkhaus,Vaydxaus,wei de hao si,Вайдгаус,Вайдхаус,Вајдхаус,Վայդխաուս,魏德豪斯', 49.6421800, 12.4952300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30677, 'Waibstadt', 'Waibstadt', 'Vajbshtadt,Vajbshtat,Waibscht,Waibstadt,faybshtat,vu~aipushutatto,wei bu si ta te,Вайбштадт,Вајбштат,فايبشتات,وایب‌اشتات,ヴァイプシュタット,魏布斯塔特', 49.2950500, 8.9177100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30678, 'Waiblingen', 'Waiblingen', 'Vajblingen,Vayblingen,Waiblinga,fayblynghn,wayblyngn,wei bu lin gen,Вайблинген,Вайблінген,Вајблинген,فايبلينغن,وایبلینگن,魏布林根', 48.8324100, 9.3164100, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30679, 'Wahrenholz', 'Wahrenholz', 'Varenkhol''c,Varenkholc,Wahrenholc,Wahrenholz,Wahrenholç,wa lun huo er ci,Варенхолц,Варенхольц,瓦伦霍尔茨', 52.6166700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30680, 'Wahnwegen', 'Wahnwegen', 'Vanvegen,wa en wei gen,Ванвеген,瓦恩韦根', 49.4846700, 7.3763700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30681, 'Wahns', 'Wahns', 'Wahns', 50.6333300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30682, 'Wahn-Heide', 'Wahn-Heide', '', 50.8589100, 7.1066200, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30683, 'Wahlstorf (Dorf)', 'Wahlstorf (Dorf)', '', 54.1783600, 10.2946200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30684, 'Wahlstedt', 'Wahlstedt', 'Val''shtedt,Valshtet,Wahlstedt,falshtyt,wa er si te,Валштет,Вальштедт,فالشتيت,وال‌اشتت,瓦尔斯特', 53.9516100, 10.2062600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30685, 'Wahlrod', 'Wahlrod', '', 50.6500000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30686, 'Wahlitz', 'Wahlitz', '', 52.1037600, 11.7794700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30687, 'Wahlheim', 'Wahlheim', '', 49.7177800, 8.1061100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30688, 'Wahlhausen', 'Wahlhausen', 'Wahlhausen', 51.3000000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30689, 'Wahlenau', 'Wahlenau', '', 49.9000000, 7.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30690, 'Wahlbach', 'Wahlbach', '', 50.0000000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30691, 'Waging am See', 'Waging am See', 'Vaging na Jezeru,Vaging-am-Ze,Waging,Waging am See,Zeei Vaging,bin hu wa jing,wagyng am zy,Вагинг на Језеру,Вагинг-ам-Зе,Вагінг-ам-Зе,Զեեի Վագինգ,واگینگ ام زی,滨湖瓦京', 47.9341400, 12.7339200, 'DE', '2013-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30692, 'Waghäusel', 'Waghausel', 'Vagkhojzel,Vagkhojzel'',Vagojzel'',Waghaeusel,Waghausel,Waghäusel,faghhwyzl,wa ge huo yi sai er,waghwyzl,Вагойзель,Вагхойзель,Вагхојзел,فاغهويزل,واگهویزل,瓦格霍伊塞尔', 49.2499100, 8.5125700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30693, 'Wagersrott', 'Wagersrott', 'Wagersrott', 54.6666700, 9.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30694, 'Wagenhoff', 'Wagenhoff', '', 52.5523300, 10.5233700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30695, 'Wagenhausen', 'Wagenhausen', '', 50.1500000, 6.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30696, 'Wagenfeld', 'Wagenfeld', 'Vagenfel''d,Vagenfeld,Wagenfeld,wa gen fei er de,Вагенфелд,Вагенфельд,瓦根费尔德', 52.5500000, 8.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30697, 'Waffenbrunn', 'Waffenbrunn', 'Vafenbrun,Vaffenbrunn,wa fen bu lun,Вафенбрун,Ваффенбрунн,Վաֆենբրուն,瓦芬布伦', 49.2666700, 12.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30698, 'Wadgassen', 'Wadgassen', 'Vadgasen,Vadgassen,wa de jia sen,wadgasn,Вадгасен,Вадгассен,وادگاسن,瓦德加森', 49.2666700, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30699, 'Wadersloh', 'Wadersloh', 'Vaderslo,Vaderslokh,Wadersloh,wa de er si luo,Вадерсло,Вадерслох,瓦德尔斯洛', 51.7333300, 8.2500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30700, 'Wadern', 'Wadern', 'Vadern,Wadern,fadrn,vu~adan,wa deng,wadrn,Вадерн,فادرن,وادرن,ヴァーダーン,瓦登', 49.5412200, 6.8877400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30701, 'Waddeweitz', 'Waddeweitz', 'Vaddevajc,Vadevajc,wa de wei ci,wadh wyts,Ваддевайц,Вадевајц,واده ویتس,瓦德魏茨', 53.0000000, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30702, 'Wackersdorf', 'Wackersdorf', 'Vakersdorf,Vakkersdorf,wa ke si duo fu,wakrsdwrf,Вакерсдорф,Ваккерсдорф,واکرسدورف,瓦克斯多夫', 49.3166700, 12.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30703, 'Wackersberg', 'Wackersberg', 'Vakersberg,Vakkersberg,wa ke si bei ge,wakrsbrg,Вакерсберг,Ваккерсберг,Վաքերսբերգ,واکرسبرگ,瓦克斯贝格', 47.7333300, 11.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30704, 'Wackerow', 'Wackerow', '', 53.6768300, 12.9816400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30705, 'Wackernheim', 'Wackernheim', 'Vakernkhajm,Vakkernkhajm,wa ke er en hai mu,Вакернхајм,Ваккернхайм,瓦克尔恩海姆', 49.9744400, 8.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30706, 'Wacken', 'Wacken', '', 54.0207800, 9.3759700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30707, 'Wächtersbach', 'Waechtersbach', 'Vekhtersbakh,Waechtersbach,Wächtersbach,fyshtrzbakh,vu~ehitasubahha,wei xi te er si ba he,wstrzbakh,Вехтерсбах,فيشترزباخ,وسترزباخ,ヴェヒタースバッハ,韦希特尔斯巴赫', 50.2551100, 9.2956400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30708, 'Wachtendonk', 'Wachtendonk', 'Vakhtendonk,Wachtedonk,Wachtedónk,Wachtendonk,wa teng dong ke,Вахтендонк,瓦滕东克', 51.4091600, 6.3389400, 'DE', '2011-11-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30709, 'Wachtberg', 'Wachtberg', 'Arzdorf,Vakhtberg,wa te bei ge,Вахтберг,瓦特贝格', 50.6333300, 7.1000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30710, 'Wachstedt', 'Wachstedt', 'Vakhshtedt,Vakhshtet,Wachstedt,wa si te,Вахштедт,Вахштет,瓦斯特', 51.3000000, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30711, 'Wachenroth', 'Wachenroth', 'Vakhenrot,Wachenroth,vu~ahhyenroto,wa heng luo te,Вахенрот,ヴァッヒェンロート,瓦亨罗特', 49.7518500, 10.7133500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30712, 'Wachenheim', 'Wachenheim', 'Vakhenkhajm,Vakhenkhajm an der Vinshtrase,Wachenheim,Wachenheim an der Weinstrasse,Wachenheim an der Weinstraße,wei yin si te la sai de qu wa heng hai mu,Вахенхайм,Вахенхајм ан дер Винштрасе,واخنهایم آن در واین‌اشتارسه,韦因斯特拉塞地区瓦亨海姆', 49.4404500, 8.1804100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30713, 'Wachau', 'Wachau', 'Wachau', 51.1617200, 13.9065100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30714, 'Wabern', 'Wabern', 'Wabern', 51.1000000, 9.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30715, 'Waal', 'Waal', 'Vaal'',Val,Val'',Waal,vu~aru,Вааль,Вал,Валь,Վալ,ヴァール', 47.9967900, 10.7778600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30716, 'Waakirchen', 'Waakirchen', 'Vaakirkhen,Vakirkhen,Vakirxen,wa ji xing,wakyrshn,Ваакірхен,Вакирхен,Վակիրխեն,واکیرشن,瓦基兴', 47.7725000, 11.6731500, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30717, 'Waake', 'Waake', 'Vake,vu~ake,wa ke,Ваке,ヴァーケ,瓦克', 51.5563700, 10.0571300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30718, 'Waabs', 'Waabs', 'Vabs,Waabs,wa bu si,Вабс,瓦布斯', 54.5333300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30719, 'Vrees', 'Vrees', 'Fres,fu lei si,Фрес,弗雷斯', 52.8833300, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30720, 'Vreden', 'Vreden', 'Freden,Frethenna,Vreden,Vrene,frydn,Фреден,فريدن', 52.0379200, 6.8280000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30721, 'Vorwerk', 'Vorwerk', '', 53.1833300, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30722, 'Vörstetten', 'Vorstetten', 'Fershteten,Fershtetten,Fjorshtetten,Voerstetten,Vörstetten,fu er si te teng,Ферштетен,Ферштеттен,Фёрштеттен,Ֆյորշտեթեն,弗尔斯特滕', 48.0666700, 7.8500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30723, 'Vorra', 'Vorra', 'Fora,Forra,Фора,Форра,Ֆորրա', 49.5571800, 11.4941900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30724, 'Vordorf', 'Vordorf', 'Wurthorp', 52.3652200, 10.5203500, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30725, 'Vorderweidenthal', 'Vorderweidenthal', 'Fordervajdental,Fordervajdental'',fu er de er wei deng ta er,Фордервайденталь,Фордервајдентал,福尔德尔魏登塔尔', 49.1333300, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30726, 'Vorbach', 'Vorbach', '', 49.8213600, 11.7362500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30727, 'Volxheim', 'Volxheim', 'Fol''kskhajm,Folkskhajm,fu er ke si hai mu,Фолксхајм,Фольксхайм,福尔克斯海姆', 49.8166700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30728, 'Voltlage', 'Voltlage', 'Fol''tlage,Foltlage,fu er te la ge,Фолтлаге,Фольтлаге,福尔特拉格', 52.4333300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30729, 'Völpke', 'Volpke', 'Voelpke,Volpke,Völpke', 52.1386500, 11.0987700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30730, 'Vollstedt', 'Vollstedt', 'Vollstedt', 54.6166700, 9.0333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30731, 'Vollmersweiler', 'Vollmersweiler', '', 49.0650000, 8.0772200, 'DE', '2014-09-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30732, 'Vollmershain', 'Vollmershain', '', 50.8500000, 12.3000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30733, 'Vollmersbach', 'Vollmersbach', '', 49.7333300, 7.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30734, 'Vollerwiek', 'Vollerwiek', 'Vollerwiek', 54.2912800, 8.7983300, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30735, 'Vollersroda', 'Vollersroda', '', 50.9360400, 11.3309400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30736, 'Vollersode', 'Vollersode', '', 53.3333300, 8.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30737, 'Vollenborn', 'Vollenborn', 'Vollenborn', 51.3500000, 10.5000000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30738, 'Volkstedt', 'Volkstedt', 'Volkstedt,Vulchistedin', 51.5626700, 11.5565800, 'DE', '2015-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30739, 'Volkmarsen', 'Volkmarsen', 'Fol''kmarzen,Folkmarzen,forukumaruzen,fu er ke ma er sen,fwlkmarsn,Фолкмарзен,Фолькмарзен,فولكمارسن,فولکمارسن,フォルクマールゼン,福尔克马尔森', 51.4089500, 9.1181400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30740, 'Volkmannsdorf', 'Volkmannsdorf', '', 50.6110200, 11.7316800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30741, 'Völklingen', 'Voelklingen', 'Fel''klingen,Felklingen,Fjol''klingen,Voelklingen,Volklingen,Völklingen,ferukuringen,fu er ke lin gen,fwlklynghn,fwlklyngn,plqlyngn,Фелклинген,Фельклінген,Фёльклинген,Фөльклинген,פלקלינגן,فولكلينغن,فولکلینگن,フェルクリンゲン,弗尔克林根', 49.2516200, 6.8587300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30742, 'Volkesfeld', 'Volkesfeld', '', 50.4000000, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30743, 'Volkerzen', 'Volkerzen', '', 50.7166700, 7.6833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30744, 'Volkertshausen', 'Volkertshausen', 'Fol''kertsgauzen,Fol''kertskhauzen,Folkertskhauzen,fu er ke er ci hao sen,Фолкертсхаузен,Фолькертсгаузен,Фолькертсхаузен,福尔克尔茨豪森', 47.8166700, 8.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30745, 'Völkersweiler', 'Volkersweiler', '', 49.1666700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30746, 'Völkershausen', 'Voelkershausen', '', 50.8000000, 10.0500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30747, 'Volkerode', 'Volkerode', 'Fol''kerode,Folkerode,Volkerode,fu er ke luo de,Фолкероде,Фолькероде,福尔克罗德', 51.2666700, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30748, 'Volkenschwand', 'Volkenschwand', '', 48.6000000, 11.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30749, 'Volkach', 'Volkach', 'Fol''kakh,Folkakh,Folkax,Volkach,fu er ka,fwlkakh,Фолках,Фольках,Ֆոլկախ,فولكاخ,فولکاخ,福尔卡', 49.8635200, 10.2281300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30750, 'Voigtstedt', 'Voigtstedt', 'Voigtstedt', 51.3916900, 11.3088800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30751, 'Vöhringen', 'Vohringen', 'Voehringen,Vöhringen', 48.3344600, 8.6639200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30752, 'Vöhringen', 'Vohringen', 'Voehringen,Vöhringen', 48.2783900, 10.0823600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30753, 'Vöhrenbach', 'Vohrenbach', 'Ferenbakh,Fjorenbakh,Voehrenbach,Vohrenbach,Vöhrenbach,fu he lun ba he,fwrnbakh,Ференбах,Фёренбах,فورنباخ,弗赫伦巴赫', 48.0500000, 8.3000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30754, 'Vöhl', 'Vohl', 'Fel,Fel'',Fjol'',Voehl,Vöhl,feru,fu he er,Фел,Фель,Фёль,フェール,弗赫尔', 51.2056500, 8.9451000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30755, 'Vohenstrauß', 'Vohenstrauss', 'Foehnshtraus,Foenshtraus,Fokhenshtraus,Vohenstrauss,Vohenstrausz,Vohenstrauß,fu heng si te lao si,fwhnshtraws,Фоенштраус,Фохенштраус,Фоэнштраус,Ֆոենշթրաուս,فوهنشتراوس,فوهن‌اشتراوس,福亨斯特劳斯', 49.6238300, 12.3380800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30756, 'Vohburg an der Donau', 'Vohburg an der Donau', 'Danubi Foburg,Foburg,Foburg-an-der-Donau,Fokhburg na Dunavu,Vohbuag an da Doana,Vohburg,Vohburg an der Donau,duo nao he pan fu bao,fbwrg an dr danwb,fwbwrgh,Фобург,Фобург-ан-дер-Донау,Фохбург на Дунаву,Դանուբի Ֆոբուրգ,فبورگ آن در دانوب,فوبورغ,多瑙河畔福堡', 48.7697700, 11.6184500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30757, 'Vogtareuth', 'Vogtareuth', 'Voctareit', 47.9469400, 12.1812600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30758, 'Vogt', 'Vogt', 'Vogt', 47.7666700, 9.7666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30759, 'Vögelsen', 'Voegelsen', 'Fegelzen,Fjogel''zen,Voegelsen,Vögelsen,fu ge er sen,Фегелзен,Фёгельзен,弗格尔森', 53.2744700, 10.3537200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30760, 'Vogelsberg', 'Vogelsberg', '', 51.1333300, 11.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30761, 'Vogelsang', 'Vogelsang', '', 52.1823500, 14.6636600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30762, 'Voerde', 'Voerde', 'Ferde,Fjorde,Forde,Voerde,fu ai er de,fwrdh,fwrdt,Ферде,Форде,Фёрде,فوردة,فورده,福埃尔德', 51.5970300, 6.6863000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30763, 'Vockerode', 'Vockerode', 'Fokerode,Fokkerode,Vockerode,Фокероде,Фоккероде', 51.8469800, 12.3520800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30764, 'Vlotho', 'Vlotho', 'Floto,Flotowe,Flôtôwe,flwtw,furoto,Флото,فلوتو,フロートー', 52.1653000, 8.8599600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30765, 'Visselhövede', 'Visselhoevede', 'Fiselkhevede,Fissel''khjofede,Vissel''khjovede,Visselhoeoevd,Visselhoevede,Visselhovede,Visselhövede,Visselhöövd,fei sai er he fei de,fisseruhevu~ede,fyslhwfydh,fyzlhwfdh,Виссельхёведе,Фиселхеведе,Фиссельхёфеде,فيسلهوفيده,فیزلهوفده,フィッセルヘーヴェデ,菲塞尔赫费德', 52.9854600, 9.5826500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30766, 'Visbek', 'Visbek', 'Fisbek,fei si bei ke,Фисбек,菲斯贝克', 52.8333300, 8.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30767, 'Virneburg', 'Virneburg', 'Firneburg,fei er nei bao,Фирнебург,菲尔内堡', 50.3500000, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30768, 'Vippachedelhausen', 'Vippachedelhausen', '', 51.0813600, 11.2093500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30769, 'Viöl', 'Viol', 'Fiel,Fijel,Fijol'',Fjaal,Fjolde,Fjåål,Viol,Viöl,fei e er,Фиел,Фиёль,Фијел,菲厄尔', 54.5666700, 9.1833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30770, 'Vinningen', 'Vinningen', '', 49.1563500, 7.5519100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30771, 'Vilshofen', 'Vilshofen', 'Vilshofen,Vilshofen an der Donau', 48.6269500, 13.1922200, 'DE', '2015-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30772, 'Vilsheim', 'Vilsheim', 'Fil''sgajm,Fil''skhajm,Filshaym,Filskhajm,fei er si hai mu,fylshaym,Филсхајм,Фильсхайм,Фільсгайм,Ֆիլսհայմ,فیلسهایم,菲尔斯海姆', 48.4488200, 12.1068600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30773, 'Vilseck', 'Vilseck', 'Fil''zek,Filzek,Vilseck,fei er sai ke,fylsk,Филзек,Фильзек,Фільзек,Ֆիլզեկ,فیلسک,菲尔塞克', 49.6148000, 11.8026100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30774, 'Vilsbiburg', 'Vilsbiburg', 'Fil''sbiburg,Filsbiburg,Vilsbiburg,fei er si bi bao,fylsbybwrg,fylsbybwrgh,Филсбибург,Фильсбибург,Фільсбібург,Ֆիլսբիբուրգ,فيلسبيبورغ,فیلسبیبورگ,菲尔斯比堡', 48.4529600, 12.3560400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30775, 'Villmar', 'Villmar', 'Fil''mar,Fill''mar,Filmar,Villmar,fei er ma er,Филмар,Фильмар,Філльмар,菲尔马尔', 50.3928700, 8.1931000, 'DE', '2013-09-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30776, 'Villingen-Schwenningen', 'Villingen-Schwenningen', 'Filingen-Shveningen,Filingenas-Sveningenas,Filingenas-Šveningenas,Fillingen-Shvenningen,Villingen Schwenningen,Villingen-Schwenningen,Villingen-Shvenningen,ZQL,fei lin gen-shi wen ning gen,fylynghn-shfnynghn,fylyngn-ashwnyngn,Виллинген-Швеннинген,Филинген-Швенинген,Филлинген-Швеннинген,Філлінген-Швеннінген,فيلينغن-شفنينغن,فیلینگن-اشونینگن,菲林根-施文宁根', 48.0622600, 8.4935800, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30777, 'Villingendorf', 'Villingendorf', 'Filingendorf,Fillingendorf,Villingendorf,fei lin gen duo fu,Филингендорф,Филлингендорф,Філлінгендорф,菲林根多夫', 48.2000000, 8.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30778, 'Villenbach', 'Villenbach', '', 48.5088700, 10.6146800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30779, 'Vilgertshofen', 'Vilgertshofen', 'Fil''gertsgofen,Fil''gertskhofen,Filgertskhofen,fei er ge er ci huo fen,firugerutsuhofen,fylgrtshwfn,Филгертсхофен,Фильгертсхофен,Фільгертсгофен,Ֆիլգերթսհոֆեն,فیلگرتسهوفن,フィルゲルツホーフェン,菲尔格尔茨霍芬', 47.9500000, 10.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30780, 'Veitsrodt', 'Veitsrodt', 'Veitsrodt,Vietsrodt', 49.7557600, 7.3013100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30781, 'Viersen', 'Viersen', 'Firzen,Veeese,Veeëse,Viersen,ZQK,fei er sen,fyrzn,Фирзен,Фірзен,فيرزن,فیرزن,菲爾森', 51.2543500, 6.3944100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30782, 'Viernheim', 'Viernheim', 'Firngajm,Firnkhajm,Gorad Firnkhajm,Vernem,Viernheim,fei er en hai mu,firunhaimu,fyrnhaym,Горад Фірнхайм,Фирнхайм,Фирнхајм,Фірнгайм,فيرنهايم,فیرنهایم,フィールンハイム,菲尔恩海姆', 49.5403300, 8.5782000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30783, 'Viernau', 'Viernau', 'Firnau,Viernau,fei er nao,Фирнау,菲尔瑙', 50.6622500, 10.5577800, 'DE', '2012-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30784, 'Vierkirchen', 'Vierkirchen', '', 48.3666700, 11.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30785, 'Vierhöfen', 'Vierhofen', 'Vierhoefen,Vierhöfen', 53.2666700, 10.2166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30786, 'Viereck', 'Viereck', '', 53.5489800, 14.0400100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30787, 'Vierden', 'Vierden', '', 53.3333300, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30788, 'Vienenburg', 'Vienenburg', 'Finenburg,Vienenburg,fei nen bao,fynnbwrg,fynnbwrgh,Финенбург,فيننبورغ,فیننبورگ,菲嫩堡', 51.9524200, 10.5637400, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30789, 'Vielbach', 'Vielbach', '', 50.5105600, 7.7719400, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30790, 'Viechtach', 'Viechtach', 'Fikhtakh,Veita,Viechtach,fei xi ta,fyshtakh,Фихтах,Фіхтах,Ֆիխթախ,فيشتاخ,فیشتاخ,菲希塔', 49.0800100, 12.8856600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30791, 'Vettweiß', 'Vettweiss', 'Fettvajs,Fettweiss,Fettweĳß,Fetvajs,Vettweiss,Vettweiß,fei te wei si,Фетвайс,Фетвајс,Феттвайс,费特魏斯', 50.7333300, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30792, 'Vettelschoß', 'Vettelschoss', 'Fetelshos,Fettel''shos,Vettelschoss,Vettelschoß,fei te er shao si,Фетелшос,Феттельшос,费特尔绍斯', 50.6166700, 7.3500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30793, 'Vetschau', 'Vetschau', 'Vetschau,Wetosow,Wětošow', 51.7863800, 14.0794100, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30794, 'Vestenbergsgreuth', 'Vestenbergsgreuth', 'Vestenbergsgreuth', 49.6876400, 10.6515700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30795, 'Versmold', 'Versmold', 'Fersmele,Fersmol''d,Fersmold,Versmold,fei er si mo er de,frsmwld,Ферсмолд,Ферсмольд,فرسمولد,费尔斯莫尔德', 52.0400900, 8.1527200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30796, 'Verl', 'Verl', 'Ferl,Ferl'',Verl,fei er,frl,Ферл,Ферль,فرل,费尔', 51.8833300, 8.5166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30797, 'Veringenstadt', 'Veringenstadt', 'Feringenshtadt,Feringenshtat,fei lin gen si ta te,Ферингенштадт,Ферингенштат,فرینگن‌اشتات,费林根斯塔特', 48.1851500, 9.2107900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30798, 'Verden', 'Verden', 'Ferden,QVQ,Veern,Verden,Verden an der Aller,fei er deng,feruden,frdn nydrzaksn,frdn  nydrzaksn,Ферден,فردن نيدرزاكسن,فردن، نیدرزاکسن,フェルデン,费尔登', 52.9234300, 9.2349100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30799, 'Venusberg', 'Venusberg', 'Venusberg', 50.6991800, 13.0185400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30800, 'Venningen', 'Venningen', '', 49.2816700, 8.1736100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30801, 'Vendersheim', 'Vendersheim', 'Fenderskhajm,fen de er si hai mu,wndrshym,Фендерсхайм,Фендерсхајм,وندرشیم,芬德尔斯海姆', 49.8663900, 8.0686100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30802, 'Veltheim', 'Veltheim', 'Fel''tkhajm,Feltkhajm,Veltheim,fei er tai mu,wlthym,Фелтхајм,Фельтхайм,ولتهیم,费尔泰姆', 52.2187400, 10.6832700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30803, 'Velten', 'Velten', 'Fel''ten,Felten,Velten,fei er teng,fltn,Фелтен,Фельтен,Ֆելտեն,فلتن,费尔滕', 52.6914900, 13.1753300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30804, 'Velpke', 'Velpke', 'Fel''pke,Felpke,fei er pu ke,wlpk,Фелпке,Фельпке,ولپک,费尔普克', 52.4079700, 10.9363700, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30805, 'Vellberg', 'Vellberg', 'Fel''berg,Felberg,Fell''berg,Vellberg,fei er bei ge,feruberuku,flbrg,flbrgh,Фелберг,Фелльберг,Фельберг,فلبرغ,فلبرگ,フェルベルク,费尔贝格', 49.0843000, 9.8791400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30806, 'Velgast', 'Velgast', 'Fel''gast,Felgast,fei er jia si te,wlgst,Фелгаст,Фельгаст,ولگست,费尔加斯特', 54.2720400, 12.8107500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30807, 'Velen', 'Velen', 'Felen,Felie,Felin,Velen,fei lun,Фелен,费伦', 51.8944700, 6.9880700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30808, 'Veldenz', 'Veldenz', 'Fel''denc,Feldenc,fei er deng ci,wldnz,Фелденц,Фельденц,ولدنز,费尔登茨', 49.8886700, 7.0220600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30809, 'Velden', 'Velden', 'Fel''den,Felden,Velden,fldn,fldn an dr pgnyts,Фелден,Фельден,Ֆելդեն,فلدن,فلدن آن در پگنیتس', 49.6138800, 11.5100800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30810, 'Velden', 'Velden', 'Fel''den,Felden,Velden,wldn,Фелден,Фельден,Ֆելդեն,ولدن', 48.3663200, 12.2559600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30811, 'Velburg', 'Velburg', 'Fel''burg,Felburg,fei er bao,flbwrg,flbwrgh,Фелбург,Фельбург,Ֆելբուրգ,فلبورغ,فلبورگ,费尔堡', 49.2321200, 11.6716000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30812, 'Velbert', 'Velbert', 'Fel''bert,Felbert,Velbed,Velbert,Vèlbed,ZQJ,fei er bei te,flbrt,Фелберт,Фельберт,فلبرت,費爾貝特', 51.3353700, 7.0434800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30813, 'Veitshöchheim', 'Veitshochheim', 'Fajtsgekhgajm,Fajtskhekhkhajm,Fajtskhjokhkhajm,Faytshyoxhaym,Veitshoechheim,Veitshöchheim,fa yi ci he xia yi mu,faitsuhehihaimu,wytshwchym,Файтсгехгайм,Файтсхёххайм,Фајтсхеххајм,Ֆայտսհյոխհայմ,قلع ویٹسوکیم,ویتشوچیم,ファイツヘーヒハイム,法伊茨赫夏伊姆', 49.8327800, 9.8816700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30814, 'Veitsbronn', 'Veitsbronn', 'Fajtsbron,Fajtsbronn,fa yi ci bu long,wytsbrn,Файтсбронн,Фајтсброн,Ֆայթսբրոն,ویتسبرن,法伊茨布龙', 49.5123900, 10.8879700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30815, 'Veilsdorf', 'Veilsdorf', 'Fajl''sdorf,Fajlsdorf,Veilsdorf,fa yi er si duo fu,wylsdrf,Файльсдорф,Фајлсдорф,ویلسدرف,法伊尔斯多夫', 50.4087600, 10.8094700, 'DE', '2016-08-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30816, 'Veckenstedt', 'Veckenstedt', 'Veckenstedt', 51.9011300, 10.7320300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30817, 'Vechta', 'Vechta', 'Fekhta,Vechta,Vechte,fei xi ta,fshta,Фехта,فشتا,费希塔', 52.7263200, 8.2859800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30818, 'Vechelde', 'Vechelde', 'Fehtlon [a. 973],Fekhel''de,Fekhelde,Vechel,Vechtla [a. 1145],fei xie er de,wchld,Фехелде,Фехельде,وچلد,费歇尔德', 52.2603800, 10.3649100, 'DE', '2014-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30819, 'Vaterstetten', 'Vaterstetten', 'Fatershteten,Fatershtetten,fa te er si te teng,wtrsttn,Фатерштетен,Фатерштеттен,وترستتن,法特尔斯特滕', 48.1053700, 11.7682500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30820, 'Vastorf', 'Vastorf', 'Fastorf,fa si tuo fu,wstrf,Фасторф,وسترف,法斯托夫', 53.1980100, 10.5456300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30821, 'Varrel', 'Varrel', 'Farel,Farrel'',fa lei er,Фарел,Фаррель,法雷尔', 52.6215000, 8.7331000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30822, 'Varel', 'Varel', 'Farel,Farel'',Foarel,farl,Фарел,Фарель,فارل', 53.3969300, 8.1362100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30823, 'Valwig', 'Valwig', 'Valwig bei Cochem', 50.1500000, 7.2166700, 'DE', '2016-02-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30824, 'Valley', 'Valley', '', 47.8931000, 11.7791500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30825, 'Vallendar', 'Vallendar', 'Falendar,Fallendar,Vallendar,fa lun da er,falndar,farenda,Фалендар,Фаллендар,فالندار,ファレンダー,法伦达尔', 50.3958600, 7.6242700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30826, 'Vaihingen an der Enz', 'Vaihingen an der Enz', 'Fajgingen-an-der-Enc,Fajingen-an-der-Ehnc,Fajkhingen an der Enc,Fajkhingen na Enc,Fajkhingen-na-Ehnce,Vaihingen,Vaihingen an der Enz,Vaihingen-sur-lEnz,en ci he pan fa yi xin gen,fayhynghn,fayhyngn an dr ants,Файгінген-ан-дер-Енц,Файинген-ан-дер-Энц,Файхинген на Енц,Файхинген-на-Энце,Фајхинген ан дер Енц,فايهينغن,فایهینگن آن در انتس,恩茨河畔法伊欣根', 48.9356300, 8.9604500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30827, 'Vahlde', 'Vahlde', '', 53.1851000, 9.6320900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30828, 'Vahlbruch', 'Vahlbruch', 'Fal''brukh,Falbrukh,fa er bu lu,faruburufu,Фалбрух,Фальбрух,ファールブルーフ,法尔布鲁', 51.9207700, 9.3406100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30829, 'Vagen', 'Vagen', '', 47.8741000, 11.8844600, 'DE', '2013-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30830, 'Vachendorf', 'Vachendorf', '', 47.8425600, 12.6060600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30831, 'Vachdorf', 'Vachdorf', 'Vachdorf', 50.5263200, 10.5373300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30832, 'Vacha', 'Vacha', 'Fakha,fa ha,fasha  alman,Фаха,فاشا، آلمان,法哈', 50.8279000, 10.0218500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30833, 'Vaalermoor', 'Vaalermoor', 'Vaalermoor', 53.9850600, 9.3391300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30834, 'Vaale', 'Vaale', 'Vaale', 54.0000000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30835, 'Üxheim', 'Uxheim', 'Ikskhajm,Uxheim,Uxheim-Ahutte,yu ke si hai mu,Üxheim,Üxheim-Ahütte,Иксхайм,Иксхајм,于克斯海姆', 50.3500000, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30836, 'Utzerath', 'Utzerath', '', 50.2166700, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30837, 'Utzenhain', 'Utzenhain', '', 50.1333300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30838, 'Utzenfeld', 'Utzenfeld', 'Ucenfeld,Utcenfel''d,wu cen fei er de,Утценфельд,Уценфелд,乌岑费尔德', 47.8000000, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30839, 'Utting am Ammersee', 'Utting am Ammersee', '', 48.0260800, 11.0861200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30840, 'Uttenweiler', 'Uttenweiler', 'Utenvajler,Uttenvajler,Uttenweiler,wu teng wei lei,Утенвајлер,Уттенвайлер,Ութենվայլեր,უტენვაილერი,乌滕韦勒', 48.1500000, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30841, 'Uttenreuth', 'Uttenreuth', 'Utenrojt,Uttenrojt,uttenroito,wu teng luo yi te,Утенројт,Уттенройт,ウッテンロイト,乌滕罗伊特', 49.5967500, 11.0721600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30842, 'Uthlede', 'Uthlede', '', 53.3111900, 8.5786100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30843, 'Uthleben', 'Uthleben', 'Uthleben', 51.4491200, 10.8380000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30844, 'Utersum', 'Utersum', 'OEdersem,Uterzum,Yttersum,wu te er su mu,Ödersem,Утерзум,乌特尔苏姆', 54.7143100, 8.4060900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30845, 'Uetersen', 'Uetersen', 'Gorad Jutehrzen,I-Uetersen,Itersen,Iterzen,Iterzene,Iterzens,Juterzen,Owetersen,QSM,U''tersen,UEterzen,Uetersen,Utarsan,Utersen,Yterzen,Yterzenas,u''etersen,uetersen,utarsena,uterasena,witeojen,wu te sen,yu te sen,yutarjhana,yutersen,yuteruzen,yuttarcen,ywtrsn,Ütersen,Üterzen,Īterzens,ʼytrzn,Ύτερζεν,Горад Ютэрзен,Итерзен,Уетерсен,Утăрсан,Уьтерсен,Ютерзен,Ѷтєрꙁєнъ,Ուետերսեն,איטערזען,איטרזן,ئوته‌رزهن,يوترسن,یوترسن,یوٹرسن,ܐܝܛܙܢ,ऊएतेर्सेन्,यूटर्झन,উটার্সেন,উটেরসেন,ઊએતેર્સેન્,ଊଏତେର୍ସେନ୍,யூட்டர்சென்,ఊఎతెర్సెన్,ಯುಟೆರ್ಸೆನ್,ඌඑටෙර්සෙන්,อือแทร์เซิน,ཨུ་ཏེར་སེན,უეტერზენი,ኢውተዘን,ᐃᐊᐃᑖᓯᓐ/iaitaatsin,ᔨᑌᕐᓭᓐ,ユーテルゼン,于特森,於特森,위터젠,', 53.6876900, 9.6639400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30846, 'Utendorf', 'Utendorf', 'Utendorf', 50.6166700, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30847, 'Utarp', 'Utarp', 'Utarp,wu ta er pu,Утарп,乌塔尔普', 53.6166700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30848, 'Ustersbach', 'Ustersbach', 'Owstersbax,Ustasboch,Ustersbach,Ustersbakh,awshtrsbakh,wu si te er si ba he,Устерсбах,Ուստերսբախ,اوشترسباخ,乌斯特尔斯巴赫', 48.3166700, 10.6500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30849, 'Uslar', 'Uslar', 'UEsseler,Uslar,awzlar,usura,wu si la er,Üsseler,Услар,اوزلار,ウスラー,乌斯拉尔', 51.6569000, 9.6350100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30850, 'Usingen', 'Usingen', 'Usingen,Uzingen,awzynghn,awzyngn,wu xin gen,Узинген,Узінген,أوزينغن,اوزینگن,乌辛根', 50.3355400, 8.5368800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30851, 'Usedom', 'Usedom', 'Usedom', 53.8753700, 13.9239400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30852, 'Usch', 'Usch', '', 50.1000000, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30853, 'Ürzig', 'Urzig', 'Ircig,Ircikh,UErzig,yu er qi xi,Ürzig,Ирциг,Ирцих,于尔齐希', 49.9794300, 7.0061000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30854, 'Urspringen', 'Urspringen', 'Urshpringen,wu er si pu lin gen,Уршпринген,Уршпрінген,Ուրշփրինգեն,乌尔斯普林根', 49.9016600, 9.6712300, 'DE', '2013-02-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30855, 'Uersfeld', 'Uersfeld', 'Uersfeld,Ursfeld,Ürsfeld', 50.2500000, 7.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30856, 'Ursensollen', 'Ursensollen', 'Owrzenzolen,Urzenzolen,Urzenzollen,wu er sen suo lun,Урзензолен,Урзензоллен,Ուրզենզոլեն,乌尔森索伦', 49.4020400, 11.7550300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30857, 'Urschmitt', 'Urschmitt', '', 50.1166700, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30858, 'Ursberg', 'Ursberg', 'Owrsberg,Ursberg,wu er si bei ge,Урсберг,Ուրսբերգ,乌尔斯贝格', 48.2642800, 10.4459400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30859, 'Urnshausen', 'Urnshausen', 'Urnskhauzen,wu er en si hao sen,Урнсхаузен,乌尔恩斯豪森', 50.7349400, 10.1738100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30860, 'Urmitz', 'Urmitz', 'Urmic,Urmitz,wu er mi ci,Урмиц,乌尔米茨', 50.4166700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30861, 'Urmersbach', 'Urmersbach', '', 50.2500000, 7.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30862, 'Urbar', 'Urbar', '', 50.3833300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30863, 'Urbar', 'Urbar', '', 50.1333300, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30864, 'Urbach-Überdorf', 'Urbach-UEberdorf', 'Uberdorf,Urbach-Uberdorf,Urbach-Überdorf,Überdorf', 50.5569000, 7.5869500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30865, 'Urbach', 'Urbach', 'Urbeke [a. 1206]', 51.4801000, 10.9011800, 'DE', '2014-12-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30866, 'Urbach', 'Urbach', '', 51.2946800, 10.6054000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30867, 'Bad Urach', 'Bad Urach', 'Bad Urakh,Bad-Urakh,Urach,ba te wu la he,bad awrakh,Бад Урах,Бад-Урах,باد أوراخ,باد اوراخ,巴特乌拉赫', 48.4910700, 9.4000900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30868, 'Uppershausen', 'Uppershausen', '', 50.0333300, 6.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30869, 'Uphusum', 'Uphusum', '', 54.8500000, 8.8500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30870, 'Upgant-Schott', 'Upgant-Schott', 'Upgant-Shot,wu pu gan te-shao te,Упгант-Шот,乌普甘特-绍特', 53.5166700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30871, 'Unzenberg', 'Unzenberg', '', 49.9697000, 7.4394500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30872, 'Untrasried', 'Untrasried', '', 47.8333300, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30873, 'Unterwössen', 'Unterwossen', 'Untawoessn,Untawössn,Untervesen,Untervessen,Untervjossen,Unterwoessen,Unterwössen,awntrwsn,weng te er wei sen,Унтервесен,Унтервессен,Унтервёссен,Ունթերվյոսեն,اونتروسن,翁特尔韦森', 47.7333300, 12.4666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30874, 'Unterwellenborn', 'Unterwellenborn', 'Untervelenborn,Untervellenborn,Unterwellenborn,weng te er wei lun bo er en,Унтервеленборн,Унтервелленборн,翁特尔韦伦博尔恩', 50.6500000, 11.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30875, 'Unterweißbach', 'Unterweissbach', 'Untervajsbakh,Unterweissbach,Unterweißbach,weng te er wei si ba he,Унтервайсбах,Унтервајсбах,翁特尔魏斯巴赫', 50.6139600, 11.1674300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30876, 'Unterweid', 'Unterweid', 'Unterweid', 50.6098600, 10.0607400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30877, 'Unterwaldhausen', 'Unterwaldhausen', 'Unterval''dgauzen,Unterval''dkhauzen,Untervaldkhauzen,weng te er wa er de hao sen,Унтервалдхаузен,Унтервальдгаузен,Унтервальдхаузен,翁特尔瓦尔德豪森', 47.9000000, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30878, 'Unterwachingen', 'Unterwachingen', '', 48.2028800, 9.6435500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30879, 'Unterthingau', 'Unterthingau', 'Owntertingau,Unterthingau,Untertingau,untatingau,weng te er ting gao,Унтертингау,Унтертінгау,Ունտերտինգաու,ウンターティンガウ,翁特尔廷高', 47.7715500, 10.5044600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30880, 'Untersteinach', 'Untersteinach', 'Untershtajnakh,untashutainaha,weng te er si tai na,Унтерштайнах,Унтерштајнах,Ունթերշթայնախ,ウンターシュタイナハ,翁特尔斯泰纳', 50.1333300, 11.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30881, 'Unterstadion', 'Unterstadion', '', 48.2030500, 9.6884000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30882, 'Untersiemau', 'Untersiemau', 'Untersimau,Unterzimau,untajimau,weng te er xi mao,Унтерзимау,Унтерзімау,Унтерсимау,Ունթերզիմաու,ウンタージーマウ,翁特尔西毛', 50.1941500, 10.9744800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30883, 'Untershausen', 'Untershausen', '', 50.4000000, 7.8500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30884, 'Unterschwaningen', 'Unterschwaningen', 'Owntersvaningen,Untershvaningen,untashuvu~aningen,weng te er shi wa ning gen,Унтершванинген,Унтершванінген,Ունտերշվանինգեն,ウンターシュヴァーニンゲン,翁特尔施瓦宁根', 49.0797700, 10.6217900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30885, 'Unterschönau', 'Unterschonau', 'Unterschoenau,Unterschönau', 50.7166700, 10.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30886, 'Unterschneidheim', 'Unterschneidheim', 'Unterschneidheim,Untershnajdgajm,Untershnajdkhajm,xia shi nai de hai mu,Унтершнайдгайм,Унтершнайдхайм,Унтершнајдхајм,უნტერშნაიდჰაიმი,下施奈德海姆', 48.9333300, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30887, 'Unterschleißheim', 'Unterschleissheim', 'Schleisheim,Unterschleissheim,Unterschleißheim,Untershlajskhajm,Untershljajsgajm,awntrashlayshaym,awntrshlayshaym,xia shi lai si hai mu,Унтершлайсхайм,Унтершлајсхајм,Унтершляйсгайм,Ունթերշլայսհայմ,أونترشلايسهايم,اونتراشلایسهایم,下施莱斯海姆', 48.2803800, 11.5768400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30888, 'Unterroth', 'Unterroth', '', 48.1956200, 10.1711100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30889, 'Unterreit', 'Unterreit', 'Kirchreit,Unterajt,Unterrajt,Unterreit,awntrayt,weng te lai te,Унтерајт,Унтеррайт,Ունթեռայթ,اونترایت,翁特赖特', 48.1166700, 12.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30890, 'Unterreichenbach', 'Unterreichenbach', 'Ownterayxenbax,Unterajkhenbakh,Unterrajkhenbakh,weng te lai xing ba he,Унтерајхенбах,Унтеррайхенбах,Ունտերայխենբախ,翁特赖兴巴赫', 48.8249600, 8.7088500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30891, 'Unterpleichfeld', 'Unterpleichfeld', '', 49.8688600, 10.0439900, 'DE', '2012-10-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30892, 'Unterneukirchen', 'Unterneukirchen', 'Ownternoykirxen,Untanaikira,Unternojkirkhen,awntrnwy kyrshn,weng te er nuo yi ji er xing,Унтернойкирхен,Унтернойкірхен,Унтернојкирхен,Ունտերնոյկիրխեն,اونترنوی کیرشن,翁特尔诺伊基尔兴', 48.1666700, 12.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30893, 'Untermünkheim', 'Untermunkheim', 'Unterminkkhajm,Untermjunkgajm,Untermjunkkhajm,Untermuenkheim,Untermünkheim,untamyunkuhaimu,weng te er ming ke hai mu,Унтерминкхајм,Унтермюнкгайм,Унтермюнкхайм,ウンターミュンクハイム,翁特尔明克海姆', 49.1525500, 9.7338400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30894, 'Untermerzbach', 'Untermerzbach', 'Untermercbakh,weng te er mei er ci ba he,Унтермерцбах,Ունթերմերցբախ,翁特尔梅尔茨巴赫', 50.1275400, 10.8563400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30895, 'Untermeitingen', 'Untermeitingen', '', 48.1608200, 10.8069400, 'DE', '2012-12-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30896, 'Untermaßfeld', 'Untermassfeld', 'Untermasfel''d,Untermasfeld,Untermassfeld,Untermaßfeld,weng te er ma si fei er de,Унтермасфелд,Унтермасфельд,翁特尔马斯费尔德', 50.5333300, 10.4166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30897, 'Untermarchtal', 'Untermarchtal', 'Owntermarxtal,Untermarkhtal,Untermarkhtal'',weng te er ma er xi ta er,Унтермархтал,Унтермархталь,Ունտերմարխտալ,უნტერმარხტალი,翁特尔马尔希塔尔', 48.2391900, 9.6097800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30898, 'Unterlüß', 'Unterluess', 'Unterlis,Unterljus,weng te er lu si,Унтерлис,Унтерлюс,翁特尔吕斯', 52.8347100, 10.2968500, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30899, 'Unterleinleiter', 'Unterleinleiter', 'Unterlajnlajter,Unterljajnljajter,untarainraita,weng te er lai yin lai te er,Унтерлайнлайтер,Унтерлајнлајтер,Унтерляйнляйтер,Ունթերլայնլայթեր,ウンターラインライター,翁特尔莱因莱特尔', 49.8230300, 11.1890600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30900, 'Unterkirnach', 'Unterkirnach', 'Unterkirnakh,weng te er ji er na,Унтеркирнах,Унтеркірнах,翁特尔基尔纳', 48.0794600, 8.3657500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30901, 'Unterkatz', 'Unterkatz', 'Unterkatz', 50.6194500, 10.2569200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30902, 'Unterjettingen', 'Unterjettingen', '', 48.5623000, 8.7844500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30903, 'Unterjeckenbach', 'Unterjeckenbach', 'Unterjekenbakh,Unterjekkenbakh,weng te er ye ken ba he,Унтерйеккенбах,Унтерјекенбах,翁特尔耶肯巴赫', 49.6666700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30904, 'Unterhausen', 'Unterhausen', 'Likhtenshtajn-Unterkhauzen,Unterkhauzen,Лихтенштайн-Унтерхаузен,Унтерхаузен', 48.4298000, 9.2550400, 'DE', '2015-05-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30905, 'Unterhaching', 'Unterhaching', 'Haching,Untergakhing,Unterhachingas,Unterkhakhing,an da he zhi,awntrhakhyng,Унтергахінг,Унтерхахинг,Ունթերհախինգ,اونترهاخینگ,安達赫治', 48.0659800, 11.6156400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30906, 'Untergruppenbach', 'Untergruppenbach', 'Untergrupenbakh,Untergruppenbakh,untaguruppenbahha,weng te er ge lu peng ba he,Унтергрупенбах,Унтергруппенбах,ウンターグルッペンバッハ,翁特尔格鲁彭巴赫', 49.0894000, 9.2751600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30907, 'Untergriesbach', 'Untergriesbach', 'Owntergrisbax,Untagriasbo,Untergrisbakh,awntrgrysbakh,weng te er ge li si ba he,Унтергрисбах,Унтергрісбах,Ունտերգրիսբախ,اونترگریسباخ,翁特尔格里斯巴赫', 48.5743400, 13.6672500, 'DE', '2011-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30908, 'Unterföhring', 'Unterfoehring', 'Untafering,Unterfering,Unterfjoring,Unterfoehring,Unterfohring,Unterföhring,awntrfwryng,wen te fu ling,Унтерферинг,Унтерферінг,Унтерфёринг,Ունթերֆյորինգ,اونترفورینگ,温特弗灵', 48.1925300, 11.6429300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30909, 'Unterensingen', 'Unterensingen', 'Ensingen,Ownterenzingen,Unterenzingen,weng te lun xin gen,Унтерензинген,Унтерензінген,Ունտերենզինգեն,翁特伦辛根', 48.6545200, 9.3579900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30910, 'Untereisesheim', 'Untereisesheim', 'Unterajzesgajm,Unterajzeskhajm,Untereisesheim,untaaizesuhaimu,weng te lai sai si hai mu,Унтерайзесгайм,Унтерайзесхайм,Унтерајзесхајм,ウンターアイゼスハイム,翁特赖塞斯海姆', 49.2111100, 9.2019400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30911, 'Unteregg', 'Unteregg', 'Untereg,Unteregg,weng te lei ge,Унтерег,Унтерегг,Ունթերեգ,翁特雷格', 47.9666700, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30912, 'Unterdietfurt', 'Unterdietfurt', 'Unterditfurt,awntrdytfwrt,weng te er di te fu er te,Унтердитфурт,Унтердітфурт,Ունթերդիթֆուրտ,اونتردیتفورت,翁特尔迪特富尔特', 48.3833300, 12.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30913, 'Unterdießen', 'Unterdiessen', 'Unterdiessen,Unterdießen', 47.9833300, 10.8333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30914, 'Unterbreizbach', 'Unterbreizbach', 'Unterbrajcbakh,weng te er bu lai ci ba he,Унтербрайцбах,Унтербрајцбах,翁特尔布赖茨巴赫', 50.8166700, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30915, 'Unterbodnitz', 'Unterbodnitz', 'Unterbodnitz', 50.8166700, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30916, 'Unterkrozingen', 'Unterkrozingen', 'Bad Krozingen,Unter-Bad Krozingen,Unterkrozingen', 47.9193300, 7.6904500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30917, 'Unterammergau', 'Unterammergau', 'Ownteramergau,Unteramergau,Unterammergau,awntr amrgaw,weng te la mei er gao,Унтерамергау,Унтераммергау,Ունտերամերգաու,اونتر آمرگاو,翁特拉梅尔高', 47.6165800, 11.0271800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30918, 'Unter-Abtsteinach', 'Unter-Abtsteinach', '', 49.5271100, 8.7867900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30919, 'Unsleben', 'Unsleben', '', 50.3793700, 10.2530600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30920, 'Unseburg', 'Unseburg', 'Unnesburg,Unseburg', 51.9328400, 11.5128100, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30921, 'Unnau', 'Unnau', '', 50.6488100, 7.9082700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30922, 'Unna', 'Unna', 'Una,Unna,ZQI,awna,weng na,Уна,Унна,اونا,翁納', 51.5379500, 7.6896900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30923, 'Unlingen', 'Unlingen', 'Ownlingen,Unlingen,unlingeni,weng lin gen,Унлинген,Унлінген,Ունլինգեն,უნლინგენი,翁林根', 48.1673400, 9.5221900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30924, 'Unkenbach', 'Unkenbach', '', 49.7166700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30925, 'Unkel', 'Unkel', 'Unkel,Unkel'',awnkl,unkeru,weng ke er,Ункел,Ункель,أونكل,اونکل,ウンケル,翁克尔', 50.5965300, 7.2188800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30926, 'Ungerhausen', 'Ungerhausen', 'Owngerhauzen,Ungergauzen,Ungerkhauzen,weng ge lao sen,Унгергаузен,Унгерхаузен,Ունգերհաուզեն,翁格劳森', 48.0056600, 10.2667200, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30927, 'Undenheim', 'Undenheim', 'Undenkhajm,weng deng hai mu,Унденхайм,Унденхајм,翁登海姆', 49.8380600, 8.2188900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30928, 'Undeloh', 'Undeloh', 'Undelo,Undelokh,weng de luo,Ундело,Унделох,翁德洛', 53.1971100, 9.9757500, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30929, 'Umpferstedt', 'Umpferstedt', '', 50.9833300, 11.4166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30930, 'Ummern', 'Ummern', 'Umern,Ummern,wu mei er en,Умерн,Уммерн,乌梅尔恩', 52.5911100, 10.4319500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30931, 'Ummendorf', 'Ummendorf', '', 52.1564500, 11.1815100, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30932, 'Ummendorf', 'Ummendorf', 'Ummendorf', 48.0666700, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30933, 'Umkirch', 'Umkirch', 'Owmkirx,Umkirkh,wu mu ji xi,Умкирх,Умкірх,Ումկիրխ,乌姆基希', 48.0333300, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30934, 'Uelvesbüll', 'Uelvesbull', 'Il''fesbjull'',Ilfesbil,Ilvesbil,Uelvesbull,Uelvesbüll,Ulvesbull,Ylvesbol,Ylvesbøl,wu ai er fei si bi er,Ülvesbüll,Илвесбил,Илфесбил,Ильфесбюлль,乌埃尔费斯比尔', 54.4153000, 8.9239200, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30935, 'Ulsnis', 'Ulsnis', 'Ul''snis,Ulsnaes,Ulsnis,Ulsnæs,wu er si ni si,Улснис,Ульснис,乌尔斯尼斯', 54.5666700, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30936, 'Ülsby', 'Ulsby', '', 54.6333300, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30937, 'Ulrichstein', 'Ulrichstein', 'Ulrichstein', 50.5755000, 9.1927200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30938, 'Ulmet', 'Ulmet', 'Ul''met,Ulmet,wu er mei te,Улмет,Ульмет,乌尔梅特', 49.5833300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30939, 'Ulmen', 'Ulmen', 'Ul''men,Ulmen,awlmn,urumen,wu er men,Улмен,Ульмен,أولمن,اولمن,ウルメン,乌尔门', 50.2094300, 6.9794100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30940, 'Ulm', 'Ulm', 'Gorad Ul''m,Oulm,Owlm,QUL,Ul''m,Ulm,Ulma,Ulmas,alm,awlm,ulleum,ulma,ulmi,urumu,wu er mu,xulm,Ουλμ,Горад Ульм,Улм,Ульм,Ուլմ,אולם,أولم,الم,اولم,उल्म,উল্‌ম,อุล์ม,ულმი,ウルム,乌尔姆,울름', 48.3984100, 9.9915500, 'DE', '2015-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30941, 'Uichteritz', 'Uichteritz', 'Uichteritz', 51.2065200, 11.9221500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30942, 'Uhyst', 'Uhyst', 'Delni Wujezd,Delni Wujězd,Uhyst,Uist,Уист', 51.3646900, 14.5060000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30943, 'Uehrde', 'Uehrde', 'Uehrde,Uhrde,Ührde', 52.0990200, 10.7652300, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30944, 'Uehlfeld', 'Uehlfeld', 'Il''fel''d,Ilfeld,Jul''fel''d,Uhlfeld,yu er fei er de,Ühlfeld,Илфелд,Ильфельд,Юльфельд,Իլֆելդ,于尔费尔德', 49.6708500, 10.7201700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30945, 'Uhler', 'Uhler', '', 50.0833300, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30946, 'Uhingen', 'Uhingen', 'Ugingen,Uingen,Ukhingen,awyynghn,awyyngn,wu xin gen,Угінген,Уинген,Ухинген,أويينغن,اویینگن,乌欣根', 48.7047500, 9.5857000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30947, 'Uftrungen', 'Uftrungen', 'Uftrungen,Уфтрунген', 51.4985900, 10.9806600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30948, 'Uffing', 'Uffing', 'Uffing', 47.7137800, 11.1503400, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30949, 'Uffenheim', 'Uffenheim', 'Owfenhaym,Ufenkhajm,Uffengajm,Uffenheim,Uffenkhajm,awfnhaym,wu fen hai mu,Уфенхајм,Уффенгайм,Уффенхайм,Ուֆենհայմ,أوفنهايم,اوفنهایم,乌芬海姆', 49.5441500, 10.2328600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30950, 'Uetze', 'Uetze', 'Juce,UEtze,Utisson [a. 1022],wu ai ce,Ütze,Юце,乌埃策', 52.4651100, 10.2046700, 'DE', '2014-05-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30951, 'Uettingen', 'Uettingen', '', 49.7947200, 9.7305600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30952, 'Ueß', 'Uess', '', 50.2500000, 6.9333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30953, 'Uenglingen', 'Uenglingen', 'Uenglingen', 52.6179700, 11.8089300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30954, 'Uelzen', 'Uelzen', 'Il''cen,Ilcen,Uelzen,Ulyssea,awyltsn,yu er cen,Илцен,Ильцен,أويلتسن,اویلتسن,于尔岑', 52.9657200, 10.5611100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30955, 'Uelversheim', 'Uelversheim', '', 49.8100000, 8.2886100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30956, 'Uelsen', 'Uelsen', 'Il''zen,Ilzen,wu ai er sen,Илзен,Ильзен,乌埃尔森', 52.5000000, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30957, 'Uedem', 'Uedem', 'Judem,Udem,Uedem,wu ai de mu,Удем,Уедем,Юдем,乌埃德姆', 51.6652000, 6.2737100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30958, 'Ueckermünde', 'Ueckermuende', 'Ikerminde,Ikkermjunde,Ueckermuende,Ueckermünde,Ukkermunde,Wkra,awakrmwndh,awkrmwndh,wu ai ke er ming de,Икерминде,Иккермюнде,Уккермунде,أوكرمونده,اواکرمونده,乌埃克尔明德', 53.7379500, 14.0447300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30959, 'Uebigau', 'Uebigau', 'Ibigau,UEbigau,Uebigau,Übigau,Ибигау', 51.5941500, 13.2998300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30960, 'Udler', 'Udler', '', 50.1333300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30961, 'Udestedt', 'Udestedt', 'Udeshtedt,Udeshtet,wu de si te,Удештедт,Удештет,ادے سٹدت,乌德斯特', 51.0500000, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30962, 'Üdersdorf', 'Udersdorf', 'UEdersdorf,Üdersdorf', 50.1500000, 6.8000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30963, 'Uder', 'Uder', 'Uder,adr,wu de er,ywdr,Удер,ادر,یودر,乌德尔', 51.3624300, 10.0721000, 'DE', '2016-02-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30964, 'Udenheim', 'Udenheim', '', 49.8647200, 8.1716700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30965, 'Udenhausen', 'Udenhausen', 'Udenhausen (Grebenstein),Udenhusen', 51.4638500, 9.4633500, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30966, 'Uchtspringe', 'Uchtspringe', 'Uchtspringe', 52.5401100, 11.5995900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30967, 'Üchtelhausen', 'Uchtelhausen', 'Ikhtel''khauzen,Ikhtelkhauzen,Jukhtel''gauzen,UEchtelhausen,yu xi te er hao sen,Üchtelhausen,Ихтелхаузен,Ихтельхаузен,Юхтельгаузен,اچٹیلہاؤسین,于希特尔豪森', 50.0918400, 10.2686100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30968, 'Uchte', 'Uchte', 'Uchte,Ukhte,ufute,wu te,ywcht,Ухте,اچٹے,یوچت,ウフテ,乌特', 52.4997500, 8.9092800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30969, 'Übersee', 'Ubersee', 'UEbersee,Übersee', 47.8166700, 12.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30970, 'Überlingen', 'Uberlingen', 'Iberlingen,Juberlingen,UEberlingen,Uberlingen,abyrlngyn,awbrlyngn,iuberlingeni,yu bei er lin gen,Überlingen,Иберлинген,Юберлинген,Юберлінген,Իբերլինգեն,ابیرلنگین,اوبرلینگن,იუბერლინგენი,于贝尔林根', 47.7697700, 9.1713600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30971, 'Überherrn', 'Uberherrn', 'Iberkhern,Jubergern,UEberherrn,awbrhrn,yu bo hei en,Überherrn,Иберхерн,Юбергерн,ابیرھیرن,اوبرهرن,于伯黑恩', 49.2418700, 6.6984000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30972, 'Übereisenbach', 'Ubereisenbach', '', 50.0000000, 6.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30973, 'Übach-Palenberg', 'UEbach-Palenberg', 'Ibakh-Palenberg,Jubakh-Palenberg,UEbach-Palenberg,Ubach-Palenberg,abach-palynbrg,awbakh-balnbrgh,awbakh-palnbrg,yu ba he-pa lun bei ge,Übach-Palenberg,Ибах-Паленберг,Юбах-Паленберг,أوباخ-بالنبرغ,اباچ-پالینبرگ,اوباخ-پالنبرگ,于巴赫-帕伦贝格', 50.9177500, 6.1233600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30974, 'Tschernitz', 'Tschernitz', 'Tschernitz,Tzschernitz', 51.5833300, 14.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30975, 'Tyrlaching', 'Tyrlaching', 'Tirlakhing,Tirlaxing,di er la xing,tyrlchyng,Тирлахинг,Тирлахінг,Տիրլախինգ,تیرلچینگ,蒂尔拉兴', 48.0666700, 12.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30976, 'Twistringen', 'Twistringen', 'Tvistringen,Twistringen,Twustern,te wei si te lin gen,tfystrynghn,twystryngn,Твистринген,تفيسترينغن,تویسترینگن,特维斯特林根', 52.7992600, 8.6416300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30977, 'Twist', 'Twist', '', 52.6379300, 7.0662200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30978, 'Twieflingen', 'Twieflingen', 'Twiflinge', 52.1248500, 10.9168100, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30979, 'Twedt', 'Twedt', '', 54.6000000, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30980, 'Tutzing', 'Tutzing', 'Tucing,Tutcing,tu qing,twtzng,twtzyng,Тутцинг,Туцинг,توتزنگ,توتزینگ,图青', 47.9093800, 11.2803000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30981, 'Tuttlingen', 'Tuttlingen', 'Gorad Tutlingen,Tutlingen,Tuttlingen,tu te lin gen,twtlynghn,twtlyngn,Горад Тутлінген,Тутлинген,Тутлінген,توتلينغن,توتلینگن,图特林根', 47.9846400, 8.8177000, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30982, 'Tüttleben', 'Tuettleben', 'Titleben,Tjutleben,Tuettleben,Tuttleben,Tyutleben,Tüttleben,di te lai ben,twtlbn,Титлебен,Тютлебен,Տյուտլեբեն,توتلبن,蒂特莱本', 50.9458300, 10.7878600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30983, 'Tüttendorf', 'Tuttendorf', 'Tuettendorf,Tuttendorf,Tüttendorf', 54.4000000, 10.0000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30984, 'Tutow', 'Tutow', 'Tutov,Tutow,tu tuo,twtw,Тутов,توتو,图托', 53.9156600, 13.2481400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30985, 'Tüßling', 'Tuessling', 'Tisling,Tjusling,Tussling,Tuszshing,Tyusling,Tüßling,di si ling,twblyng,Тислинг,Тюслинг,Тюслінг,Տյուսլինգ,توبلینگ,蒂斯灵', 48.2121800, 12.5995400, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30986, 'Tussenhausen', 'Tussenhausen', 'Tusenkhauzen,Tussengauzen,Tussenhausen,Tussenkhauzen,tu sen hao sen,twsnhawzn,Тусенхаузен,Туссенгаузен,Туссенхаузен,Թուսենհաուզեն,تسن ہاسن,توسنهاوزن,图森豪森', 48.1021800, 10.5606900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30987, 'Türnich', 'Tuernich', '', 50.8589200, 6.7553500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30988, 'Türkheim', 'Turkheim', 'Tirkkhajm,Tjurkgajm,Tjurkkhajm,Tuerkheim,Turkheim,Türkheim,di er ke hai mu,twrkhaym,Тиркхајм,Тюркгайм,Тюркхайм,Թյուրքհայմ,تورکهایم,蒂尔克海姆', 48.0640100, 10.6415600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30989, 'Türkenfeld', 'Tuerkenfeld', 'Tirkenfeld,Tirknfoeld,Tirknföld,Tjurkenfel''d,Tuerkenfeld,Türkenfeld,di er ken fei er de,twrknfld,Тиркенфелд,Тюркенфельд,Թյուրքենֆելդ,تورکنفلد,蒂尔肯费尔德', 48.1053100, 11.0830300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30990, 'Tuntenhausen', 'Tuntenhausen', 'Tuntengauzen,Tuntenkhauzen,tong teng hao sen,twntn hawzn,Тунтенгаузен,Тунтенхаузен,Թունթենհաուզեն,تونتن هاوزن,通滕豪森', 47.9350900, 12.0151800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30991, 'Tuningen', 'Tuningen', 'Tuningen,tu ning gen,Тунинген,Тунінген,图宁根', 48.0333300, 8.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30992, 'Tunau', 'Tunau', '', 47.7861400, 7.9242800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30993, 'Tümlauer Koog', 'Tumlauer Koog', 'Tumlauer Koog,Tummlauer Koog,Tümlauer Koog,Tümmlauer Koog', 54.3500000, 8.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30994, 'Tülau', 'Tulau', 'Tilau,Tjulau,di lao,twlayw,Тилау,Тюлау,تولائو,蒂劳', 52.5757800, 10.8781800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30995, 'Tuchenbach', 'Tuchenbach', 'Tukhenbakh,tu heng ba he,twkhnbakh,Тухенбах,Թուխենբախ,توخنباخ,图亨巴赫', 49.5279400, 10.8597300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30996, 'Tucheim', 'Tucheim', 'Tucheim', 52.2892300, 12.1842300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30997, 'Tübingen', 'Tuebingen', 'Gorad Cjubingen,ITuebingen,ITübingen,Tibingen,Tibingene,Tiubingenas,Tjubingen,Tubinga,Tuebinga,Tuebingen,Tybinga,Tybingen,Tympinken,Tübinga,Tübingen,Tībingene,di bin gen,te~yubingen,thu xbing ngein,tu bin gen,twbynghn,twbyngn,twibing-gen,tybyngn,tyubin''gana,Τύμπιγκεν,Горад Цюбінген,Тибинген,Тюбинген,Тюбінген,Түбинген,טובינגן,טיבינגן,توبينغن,توبینگن,ٹوبنگن,ट्युबिन्गन,ทือบิงเงิน,テュービンゲン,图宾根,蒂宾根,튀빙겐', 48.5226600, 9.0522200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30998, 'Tschirn', 'Tschirn', 'Chirn,Tschirn,chirun,ci xi er en,Чирн,Չիրն,チルン,茨希尔恩', 50.4000000, 11.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(30999, 'Trusetal', 'Trusetal', 'Auwallenburg,Herges-Auwallenburg,Trusetal,Truzetal,Truzetal'',trwztyl,Трузетал,Трузеталь,تروزتیل', 50.7833300, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31000, 'Trunkelsberg', 'Trunkelsberg', 'Trunkel''sberg,Trunkelsberg,te lun ke er si bei ge,trwnklzbrg,Трункелсберг,Трункельсберг,Տրունկելսբերգ,ترونکلزبرگ,特伦克尔斯贝格', 48.0000000, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31001, 'Trulben', 'Trulben', '', 49.1391600, 7.5437000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31002, 'Trostberg an der Alz', 'Trostberg an der Alz', 'Trosburg,Trostberg,Trostberg an der Alz', 48.0280200, 12.5580400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31003, 'Tröstau', 'Trostau', 'Troestau,Tröstau', 50.0166700, 11.9500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31004, 'Trossingen', 'Trossingen', 'Trosingen,Trossingen,te luo xin gen,trwsynghn,trwsyngn,Тросинген,Троссинген,تروسينغن,تروسینگن,特罗辛根', 48.0766700, 8.6440900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31005, 'Trossin', 'Trossin', 'Trosin,Trossin,te luo xin,Тросин,Троссин,Троссін,特罗辛', 51.6166700, 12.8166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31006, 'Tröndel', 'Trondel', 'Trondel,Tröndel', 54.3333300, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31007, 'Trollenhagen', 'Trollenhagen', 'Trolenkhagen,Trollenhagen,Trollenkhagen,te luo lun ha gen,Троленхаген,Тролленхаген,特罗伦哈根', 53.6070600, 13.2910300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31008, 'Troistedt', 'Troistedt', '', 50.9333300, 11.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31009, 'Troisdorf', 'Troisdorf', 'Troisdorf,Trojsdorf,ZQG,te luo si duo fu,trwysdwrf,trwyzdwrf,Троисдорф,Тройсдорф,ترويسدورف,ترویزدورف,特羅斯多夫', 50.8090100, 7.1496800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31010, 'Trogen', 'Trogen', '', 50.3666700, 11.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31011, 'Trockenborn-Wolfersdorf', 'Trockenborn-Wolfersdorf', 'Trockenborn-Wolfersdorf', 50.7833300, 11.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31012, 'Trochtelfingen', 'Trochtelfingen', 'Trokhtel''fingen,Trokhtelfingen,te luo te er fen gen,trwkhtlfynghn,trwshtlfyngn,Трохтелфинген,Трохтельфинген,Трохтельфінген,تروختلفينغن,تروشتلفینگن,特罗特尔芬根', 48.3084300, 9.2449100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31013, 'Tröchtelborn', 'Trochtelborn', 'Trochtelborn,Tröchtelborn', 51.0000000, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31014, 'Tröbnitz', 'Trobnitz', 'Trobnitz,Tröbnitz', 50.8333300, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31015, 'Tröbitz', 'Trobitz', 'Trebic,Trjebicy,Trjobic,te lei bi ci,trwbytz,Требиц,Трёбиц,Տրյոբից,تروبیتز,特勒比茨', 51.6000000, 13.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31016, 'Trittenheim', 'Trittenheim', 'Tritenkhajm,Trittenheim,Trittenkhajm,te li teng hai mu,Тритенхајм,Триттенхайм,特里滕海姆', 49.8247100, 6.8992900, 'DE', '2016-03-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31017, 'Trittau', 'Trittau', 'Tritau,Trittau,Trittow,te li tao,Тритау,Триттау,特里陶', 53.6166700, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31018, 'Triptis', 'Triptis', 'Triptis,te li pu di si,trybtys,tryptys,Триптис,تريبتيس,تریپتیس,特里普蒂斯', 50.7356700, 11.8701500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31019, 'Trippstadt', 'Trippstadt', 'Tribbschdadt,Tripshtadt,Tripshtat,te li pu si ta te,Трипштадт,Трипштат,特里普斯塔特', 49.3593500, 7.7748000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31020, 'Trinwillershagen', 'Trinwillershagen', '', 54.2504800, 12.6231200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31021, 'Trimport', 'Trimport', '', 49.9166700, 6.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31022, 'Trimbs', 'Trimbs', '', 50.3166700, 7.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31023, 'Triglitz', 'Triglitz', '', 53.2166700, 12.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31024, 'Triftern', 'Triftern', 'Triftern,Truftlern', 48.3946800, 13.0062700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31025, 'Trierweiler', 'Trierweiler', '', 49.7623100, 6.5598700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31026, 'Trierscheid', 'Trierscheid', '', 50.3500000, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31027, 'Trier', 'Trier', 'Augusta Treverorum,Gorad Tryr,Treier,Trevere,Treveri,Treveris,Treves,Trevir,Treviri,Treviro,Trevèri,Trevír,Trewir,Trier,Trir,Trire,Triri,Tryras,Trèveris,Trèves,Tréier,Tréveris,Trīre,ZQF,te li er,teulieo,the riyr,toria,tryr,Τρηρ,Горад Трыр,Трир,Трір,טריר,ترير,تری‌یر,ٹریر,เทรียร์,ტრირი,ትሪር,トリーア,特里尔,트리어', 49.7556500, 6.6393500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31028, 'Triebes', 'Triebes', 'Triebes', 50.6848900, 12.0204200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31029, 'Tribsees', 'Tribsees', 'Tribzes,Tribzese,Tribzēse,Trzebuza,Trzebùza,te li bu sai si,trybzys,trybzyz,Трибзес,تريبزيس,تریبزیز,特里布塞斯', 54.0955600, 12.7568300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31030, 'Triberg im Schwarzwald', 'Triberg im Schwarzwald', 'Gorad Tryberg-im-Shvarcval''d,Triberg,Triberg im Schwarzwald,Triberg im Shvarcvald,Triberg-im-Shvarcval''d,hei lin shan qu te li bei ge,trybrg aym shwarzwald,trybrgh,Горад Трыберг-ім-Шварцвальд,Триберг,Триберг им Шварцвалд,Триберг-им-Шварцвальд,Тріберг-ім-Шварцвальд,تريبرغ,تریبرگ ایم شوارزوالد,黑林山区特里贝格', 48.1317500, 8.2331700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31031, 'Treuenbrietzen', 'Treuenbrietzen', 'Treuenbrietzen,Trojenbricen,te luo yi en bu li cen,trwyn brytzn,trwynbrytzn,Тройенбрицен,Тројенбрицен,Տրոյենբրիցեն,تروينبريتزن,تروین بریتزن,特罗伊恩布里岑', 52.0975400, 12.8725800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31032, 'Treuen', 'Treuen', 'Treiene,Treuen,Trojen,te luo yi en,trwyn,Тройен,Тројен,تروين,تروین,特罗伊恩', 50.5424700, 12.3033900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31033, 'Treuchtlingen', 'Treuchtlingen', 'Treuchtlingen,Trojkhtlingen,Troyxtlingen,te luo yi he te lin gen,trwyktlyngn,trwyshtlynghn,trwyshtlyngn,Тройхтлинген,Тройхтлінген,Тројхтлинген,Տրոյխտլինգեն,טרויכטלינגן,ترويشتلينغن,ترویشتلینگن,特罗伊赫特林根', 48.9547300, 10.9083300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31034, 'Alt-Treptow', 'Treptow Bezirk', 'Berlin-Alt-Treptow,Treptow,Verwaltungsbezirk Treptow,alt-trptw,الت-ترپتو,ٹریپٹو-کوپرنک', 52.4886300, 13.4586000, 'DE', '2013-03-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31035, 'Treplin', 'Treplin', '', 52.4000000, 14.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31036, 'Trennewurth', 'Trennewurth', 'Trennewurth', 54.0000000, 9.0333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31037, 'Trendelburg', 'Trendelburg', 'Dringelborg,Trendel''burg,Trendelburg,te lun de er bao,torenderuburuku,trndlbwrg,trndlbwrgh,Тренделбург,Трендельбург,ترندلبورغ,ترندلبورگ,トレンデルブルク,特伦德尔堡', 51.5740800, 9.4209500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31038, 'Tremsbüttel', 'Tremsbuttel', 'Tremsbitel,Tremsbjuttel'',Tremsbuettel,Tremsbüttel,te lei mu si bi te er,Тремсбител,Тремсбюттель,特雷姆斯比特尔', 53.7438400, 10.3102400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31039, 'Treis-Karden', 'Treis-Karden', 'Trajs-Karden,te lai si-ka er deng,toraisu=kaden,Трайс-Карден,Трајс-Карден,トライス＝カーデン,特赖斯-卡尔登', 50.1717400, 7.3021800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31040, 'Treia', 'Treia', '', 54.5000000, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31041, 'Treffurt', 'Treffurt', 'Treffurt,Trefurt,te lei fu er te,trfwrt,tryfwrt,Трефурт,Треффурт,ترفورت,تريفورت,特雷富尔特', 51.1369100, 10.2336100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31042, 'Treffelstein', 'Treffelstein', 'Trefelshtajn,Treffel''shtajn,te lei fei er si tai yin,Трефелштајн,Треффельштайн,Թրեֆելշթայն,特雷费尔斯泰因', 49.4224600, 12.6157400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31043, 'Trechtingshausen', 'Trechtingshausen', 'Trechtingshausen,Trekhtingskhauzen,te lei xi ting ge si hao sen,Трехтингсхаузен,特雷希廷格斯豪森', 50.0103100, 7.8470900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31044, 'Trebur', 'Trebur', '', 49.9263900, 8.4073200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31045, 'Trebsen', 'Trebsen', 'Trebsen/Mulde', 51.2889800, 12.7549600, 'DE', '2017-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31046, 'Trebra', 'Trebra', '', 51.2833300, 10.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31047, 'Trebitz', 'Trebitz', '', 51.5861500, 11.9196500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31048, 'Trebgast', 'Trebgast', 'Trebgast,te lei bu jia si te,torepugasuto,Требгаст,Թրեբգասթ,トレプガスト,特雷布加斯特', 50.0666700, 11.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31049, 'Trebendorf', 'Trebendorf', 'Trebendorf,Trebendorf/Trjebin,Trebendorfi vald,Trjebin,te lei ben duo fu,Требендорф,特雷本多夫', 51.5333300, 14.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31050, 'Treben', 'Treben', 'Treben,te lei ben,Требен,特雷本', 51.0500000, 12.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31051, 'Trebbin', 'Trebbin', 'Trebbin,Trebin,te lei bin,trbyn,Треббин,Требин,Տրեբին,تربین,特雷宾', 52.2167500, 13.2249600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31052, 'Travenhorst', 'Travenhorst', 'Travenhorst', 54.0166700, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31053, 'Travemünde', 'Travemuende', 'Luebeck-Travemuende,Lübeck-Travemünde,Traveminde,Travemjunde,Travemuende,Travemuenn,Travemunda,Travemunde,Travemünde,Travemünn,te la fu ming de,toravu~emyunde,Травеминде,Травемюнде,ტრავემიუნდე,トラーヴェミュンデ,特拉弗明德', 53.9630400, 10.8709000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31054, 'Trautskirchen', 'Trautskirchen', 'Trautskirkhen,te lao ci ji er xing,Траутскирхен,Траутскірхен,Թրաութսկիրխեն,特劳茨基尔兴', 49.4581000, 10.5936100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31055, 'Trausnitz', 'Trausnitz', '', 49.5211400, 12.2624900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31056, 'Traunstein', 'Traunstein', 'Traunshtajn,Traunstein,Traunstoa,te lao en shi tai yin,teulaunsyutain,trawnshtayn,Траунштайн,Траунштајн,Թրաունշթայն,טראונשטיין,تراونشتاين,تروان‌اشتاین,特勞恩施泰因,트라운슈타인', 47.8682500, 12.6433500, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31057, 'Traunreut', 'Traunreut', 'Traunreit,Traunrojt,te luo yin luo yi te,trawnrwyt,trwanrwyt,Траунройт,Траунројт,Թրաունրոյթ,تراونرويت,تروانرویت,特罗因罗伊特', 47.9626900, 12.5923100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31058, 'Trassem', 'Trassem', '', 49.5784900, 6.5254000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31059, 'Trappstadt', 'Trappstadt', 'Trappshtadt,Trappstadt,Trapshtadt,Trapshtat,te la pu si ta te,Траппштадт,Трапштадт,Трапштат,Տրապշթաթ,特拉普斯塔特', 50.3188000, 10.5699500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31060, 'Trappenkamp', 'Trappenkamp', 'Trappenkamp', 54.0398800, 10.2149600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31061, 'Tramm', 'Tramm', '', 53.5644600, 10.6117200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31062, 'Traitsching', 'Traitsching', 'Trajching,te lai qing,Трайчинг,Трајчинг,Թրայչինգ,特赖青', 49.1500000, 12.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31063, 'Traisen', 'Traisen', '', 49.8166700, 7.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31064, 'Train', 'Train', '', 48.7333300, 11.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31065, 'Trabitz', 'Trabitz', 'Trabic,te la bi ci,Трабиц,Трабіц,Թրաբից,特拉比茨', 49.8000000, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31066, 'Traben-Trarbach', 'Traben-Trarbach', 'Traben-Trarbach,Traben-Trarbakh,te la ben-te la er ba he,toraben=torabahha,trabn-trarabakh,trabn-trarbakh,Трабен-Трарбах,ترابن-تراراباخ,ترابن-ترارباخ,トラーベン＝トラーバッハ,特拉本-特拉尔巴赫', 49.9507600, 7.1156200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31067, 'Tottleben', 'Tottleben', '', 51.1666700, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31068, 'Tosterglope', 'Tosterglope', '', 53.2098400, 10.8193000, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31069, 'Tostedt', 'Tostedt', 'Toest,Toshtedt,Toshtet,Töst,tuo si te,Тоштедт,Тоштет,托斯特', 53.2833300, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31070, 'Tornesch', 'Tornesch', 'Tornesch,Tornesh,trnsh,tuo er nei shi,twrnsh,Торнеш,ترنش,تورنش,托尔内施', 53.7000000, 9.7166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31071, 'Torgelow', 'Torgelow', 'Torgelov,Torgelova,Torgelow,Turzoglowe,Turzogłowë,tuo er ge luo,twrghlw,twrglw,Торгелов,تورغلو,تورگلو,托尔格洛', 53.6341500, 14.0134600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31072, 'Torgau', 'Torgau', 'Gorad Torgau,Torgau,Torgava,Torgawa,Torhow,tuo er gao,twrgaw,twrjaw,Горад Торгау,Торгау,טורגאו,تورجاو,تورگاو,托尔高', 51.5601600, 12.9961700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31073, 'Toppenstedt', 'Toppenstedt', '', 53.2643000, 10.1145100, 'DE', '2011-09-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31074, 'Töpen', 'Toepen', 'Tepen,Tjopen,Toepen,Töpen,te peng,tepen,tpn,Тепен,Тёпен,تپن,テーペン,特彭', 50.3906700, 11.8732900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31075, 'Tönning', 'Toenning', 'Taning,Tening,Tjonning,Toenning,Tonning,Tuenn,Tönning,Tønning,Tünn,teng ning,twnyng,twnyngh,Тенинг,Тённинг,تونينغ,تونینگ,滕宁', 54.3187900, 8.9423400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31076, 'Tonndorf', 'Tonndorf', '', 50.8889800, 11.2037400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31077, 'Tönisvorst', 'Toenisvorst', 'Stadt Tonisvorst,Stadt Tönisvorst,Tenisforst,Tenisvorst,Tjonisforst,Toenisvorst,Tonisvorst,Tönisvorst,te ni si fu er si te,twnysfwrst,twnysfwrth,Тенисворст,Тенісфорст,Тёнисфорст,تونيسفورست,تونیسفورث,特尼斯福尔斯特', 51.3209200, 6.4941200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31078, 'Tömmelsdorf', 'Tommelsdorf', 'Tommelsdorf,Tömmelsdorf', 50.7166700, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31079, 'Tollwitz', 'Tollwitz', 'Tollwitz', 51.2860100, 12.0973300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31080, 'Tolk', 'Tolk', '', 54.5798700, 9.6384400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31081, 'Töging am Inn', 'Toging am Inn', 'Deging am Inn,Inndegi Tjoging,Inni Tyoging,Teging na Inu,Teging-am-Inn,Tjoging-na-Inne,Toeging am Inn,Toging,Toging am Inn,Töging,Töging am Inn,twghyngh,twgyng am ayn,yin he pan te jin ge,Инндеги Тёгинг,Тегинг на Ину,Тегінг-ам-Інн,Тёгинг-на-Инне,Իննի Տյոգինգ,توغينغ,توگینگ آم این,因河畔特金格', 48.2601800, 12.5846000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31082, 'Todtnau', 'Todtnau', 'Todtnau,tuo te nao,twdnaw,twttnaw,Тодтнау,توتتناو,تودناو,托特瑙', 47.8294100, 7.9438000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31083, 'Todtmoos', 'Todtmoos', 'Todtmos,tuo te mo si,Тодтмос,托特莫斯', 47.7401400, 8.0018300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31084, 'Todtenweis', 'Todtenweis', 'Doadaweis,Todnevays,Todtenvajs,totten''vu~aisu,tuo teng wei si,Тодтенвайс,Тодтенвајс,Տոդնեվայս,トッテンヴァイス,托滕魏斯', 48.5171200, 10.9285600, 'DE', '2012-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31085, 'Todesfelde', 'Todesfelde', 'Todesfelde', 53.9000000, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31086, 'Todenroth', 'Todenroth', '', 49.9666700, 7.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31087, 'Todendorf', 'Todendorf', '', 53.6946100, 10.3478100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31088, 'Todenbüttel', 'Todenbuttel', 'Todenbuettel,Todenbuttel,Todenbüttel', 54.1333300, 9.5500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31089, 'Titz', 'Titz', 'Tic,di ci,Тиц,Тіц,蒂茨', 51.0061900, 6.4247700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31090, 'Tittmoning', 'Tittmoning', 'Didtmoning,Titamanninga,Titmoning,Tittmaning,Tittmening,Tittmoning,di te mo ning ge,tytmwnyng,tytmwnyngh,Титмонинг,Тіттмонінг,Թիթմոնինգ,تيتمونينغ,تیتمونینگ,蒂特莫宁格', 48.0616400, 12.7676000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31091, 'Tittling', 'Tittling', 'Titling,Tittling,Tutling,di te ling,tytlyng,Титлинг,Тіттлінг,Թիթլինգ,تیتلینگ,蒂特灵', 48.7261900, 13.3822100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31092, 'Titisee-Neustadt', 'Titisee-Neustadt', 'Titisee-Neustadt,Titize-Nojshtadt,Titize-Nojshtat,Titizee Noystadt,Titizee-Nojshtadt,di di hu-xin cheng,tytyzy-nywashtat,tytyzyh-nwyshtat,Титизе-Нојштат,Титизее-Нойштадт,Тітізе-Нойштадт,Տիտիզեե Նոյշտադտ,تيتيزيه-نويشتات,تیتیزی-نیواشتات,蒂蒂湖-新城', 47.9210400, 8.1906300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31093, 'Tiste', 'Tiste', '', 53.2833300, 9.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31094, 'Tissa', 'Tissa', 'Tissa', 50.8500000, 11.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31095, 'Tirschenreuth', 'Tirschenreuth', 'Tirschenreit,Tirschenreith,Tirschenreuth,Tirshenrojt,di shen luo yi te,tyrshnrwyt,Тиршенройт,Тиршенројт,Тіршенройт,Թիրշենրոյթ,تيرشنرويت,تیرشن‌رویس,蒂申罗伊特', 49.8826300, 12.3311200, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31096, 'Tirpersdorf', 'Tirpersdorf', 'Tirpersdorf,di er pei er si duo fu,Тирперсдорф,蒂尔佩尔斯多夫', 50.4333300, 12.2500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31097, 'Tinnum', 'Tinnum', '', 54.8993200, 8.3347600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31098, 'Tinningstedt', 'Tinningstedt', 'Tinningstedt', 54.8166700, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31099, 'Timmenrode', 'Timmenrode', 'Timmenrode', 51.7711300, 11.0062400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31100, 'Timmendorfer Strand', 'Timmendorfer Strand', 'Timendorfer Shtrand,Timmendorf Beach,Timmendorfer Strand,Timmendorfer-Shtrand,di men duo er fei er si te lan de,Тимендорфер Штранд,Тиммендорфер-Штранд,蒂门多尔费尔斯特兰德', 53.9953000, 10.7767600, 'DE', '2013-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31101, 'Timmaspe', 'Timmaspe', 'Timmaspe', 54.1396700, 9.8943000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31102, 'Tiergarten', 'Tiergarten Bezirk', 'Berlin-Tiergarten,Tirgarten,Tyrgartehn,di er jia teng,Тиргартен,Тыргартэн,טירגארטן,蒂尔加滕', 52.5166700, 13.3666700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31103, 'Tielen', 'Tielen', 'Tielen', 54.2833300, 9.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31104, 'Tiefenthal', 'Tiefenthal', '', 49.7500000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31105, 'Tiefenthal', 'Tiefenthal', '', 49.5386100, 8.1038900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31106, 'Tiefenort', 'Tiefenort', 'Tiefenort,Tifenort,di fei nuo er te,Тифенорт,蒂费诺尔特', 50.8394600, 10.1660400, 'DE', '2013-11-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31107, 'Tiefenbronn', 'Tiefenbronn', 'Tifenbron,Tifenbronn,di fen bu long,Тифенброн,Тіфенбронн,Տիֆենբրոն,蒂芬布龙', 48.8239800, 8.8012900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31108, 'Tiefenbach', 'Tiefenbach', '', 49.9376100, 7.5438900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31109, 'Tiefenbach', 'Tiefenbach', '', 49.4333300, 12.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31110, 'Tiefenbach', 'Tiefenbach', '', 49.1852500, 12.3233700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31111, 'Tiefenbach', 'Tiefenbach', '', 48.6242100, 13.4002500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31112, 'Tiefenbach', 'Tiefenbach', '', 48.5000000, 12.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31113, 'Tiefenbach', 'Tiefenbach', '', 48.0833300, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31114, 'Tiddische', 'Tiddische', 'Tiddishe,Tidishe,di di she,Тиддише,Тидише,蒂迪舍', 52.5166700, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31115, 'Thyrnau', 'Thyrnau', 'Tirnau,di er nao,tyrnaw,Тирнау,Թիրնաու,تیرناو,蒂尔瑙', 48.6166700, 13.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31116, 'Thurnau', 'Thurnau', 'Thurnau', 50.0254200, 11.3934800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31117, 'Thurmansbang', 'Thurmansbang', '', 48.7662700, 13.3155000, 'DE', '2016-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31118, 'Thüringenhausen', 'Thueringenhausen', 'Thuringenhausen,Thüringenhausen', 51.2666700, 10.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31119, 'Thür', 'Thuer', '', 50.3569200, 7.2768900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31120, 'Thüngersheim', 'Thungersheim', 'Thuengersheim,Thüngersheim,Tingerskhajm,Tjungersgajm,Tjungerskhajm,Tyungershaym,te~yungasuhaimu,ting ge er si hai mu,Тингерсхајм,Тюнгерсгайм,Тюнгерсхайм,Տյունգերսհայմ,テュンガースハイム,廷格尔斯海姆', 49.8783300, 9.8491700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31121, 'Thüngen', 'Thungen', 'Thuengen,Thungen,Thüngen,Tingen,Tjungen,ting gen,Тинген,Тюнген,Թյունգեն,廷根', 49.9414000, 9.8586000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31122, 'Thundorf in Unterfranken', 'Thundorf in Unterfranken', 'Thundorf,Thundorf i. Ufr.,Thundorf i. Unterfranken,Thundorf in Unterfranken,Tundorf,Tundorf in Unterfranken,Tundorf-in-Unterfranken,xia fu lan ken tong duo fu,Тундорф,Тундорф ин Унтерфранкен,Тундорф-ін-Унтерфранкен,Տունդորֆ,下弗兰肯通多夫', 50.2009700, 10.3190600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31123, 'Thumby', 'Thumby', 'Tumbi,Tumby,tong bi,Тумби,通比', 54.5833300, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31124, 'Thum', 'Thum', 'Thum,Tum,Tuma,tu mu,twm,Тум,توم,图姆', 50.6708100, 12.9509100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31125, 'Thuine', 'Thuine', 'Tuine,Tujne,tu yi nei,Туине,Туйне,图伊内', 52.5000000, 7.4833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31126, 'Thörnich', 'Thornich', '', 49.8333300, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31127, 'Thörlingen', 'Thorlingen', '', 50.1333300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31128, 'Thonhausen', 'Thonhausen', '', 50.8333300, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31129, 'Thomm', 'Thomm', 'Tom,Tumba,tuo mu,Том,托姆', 49.7414000, 6.8049200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31130, 'Thomasburg', 'Thomasburg', 'Tomasburg,tuo ma si bao,Томасбург,托马斯堡', 53.2333300, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31131, 'Tholey', 'Tholey', 'Theulegium,Tolaj,tuo lai,Толай,Толај,托莱', 49.4837400, 7.0369100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31132, 'Thierstein', 'Thierstein', 'Thierstein,Tirshtajn,Tirstayn,tierushutain,Тирштайн,Тирштајн,Тірштайн,Տիրշտայն,ティーエルシュタイン', 50.1064300, 12.1020300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31133, 'Thiersheim', 'Thiersheim', 'Thiersheim,Tirsgajm,Tirshaym,Tirskhajm,di er si hai mu,tierusuhaimu,Тирсхайм,Тирсхајм,Тірсгайм,Տիրսհայմ,ティーエルスハイム,蒂尔斯海姆', 50.0760900, 12.1265000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31134, 'Thierschneck', 'Thierschneck', 'Thierschneck', 51.0333300, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31135, 'Thierhaupten', 'Thierhaupten', 'Diahappn,Thierhaupten,Tirgaupten,Tirhaupten,Tirkhaupten,di lao pu teng,Тирхауптен,Тіргауптен,Տիրհաուպտեն,蒂劳普滕', 48.5653100, 10.9086200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31136, 'Thiendorf', 'Thiendorf', 'Theindorf,Thiendorfi vald,Tiendorf,Tindorf,ting duo fu,Тиендорф,Тиндорф,Тіендорф,廷多夫', 51.2937500, 13.7412400, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31137, 'Theuma', 'Theuma', '', 50.4700700, 12.2219500, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31138, 'Thermalbad Wiesenbad', 'Thermalbad Wiesenbad', 'Termalbad Visenbad,Termalbad Vizenbad,Thermalbad Wiesenbad,Vizenbad,Wiesenbad,te er ma er ba de wei sen ba de,Визенбад,Термалбад Визенбад,Термалбад Висенбад,特尔马尔巴德维森巴德', 50.6166700, 13.0500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31139, 'Themar', 'Themar', 'Temar,Themar,te ma er,tmar,Темар,تمار,特马尔', 50.5046500, 10.6153600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31140, 'Theißen', 'Theissen', 'Theissen,Theißen', 51.0874800, 12.1065900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31141, 'Theisseil', 'Theisseil', '', 49.6903400, 12.2274400, 'DE', '2017-07-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31142, 'Theilheim', 'Theilheim', '', 49.7540300, 10.0305600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31143, 'Thedinghausen', 'Thedinghausen', 'Tedingkhauzen,Thaenhusen,Thedinghausen,Thänhusen,tai ding hao sen,tedinguhauzen,Тедингхаузен,テディングハウゼン,泰丁豪森', 52.9666700, 9.0166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31144, 'Tharandt', 'Tharandt', 'Tarandt,Tarant,Taranta,Tharandt,Tāranta,Utdrag af ett bref 1835-11-18|Utdrag af ett bref fran en resande Landsman,Utdrag af ett bref 1835-11-18|Utdrag af ett bref från en resande Landsman,tarant,Тарандт,Тарант,تارانت', 50.9852500, 13.5803500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31145, 'Thanstein', 'Thanstein', 'Tanshtajn,tan si tai yin,tanshtayn,Танштайн,Танштајн,تانشتاین,坦斯泰因', 49.3833300, 12.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31146, 'Thannhausen', 'Thannhausen', 'Thannhausen', 48.2833400, 10.4691700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31147, 'Thalwenden', 'Thalwenden', 'Thalwenden', 51.3500000, 10.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31148, 'Thalmässing', 'Thalmassing', 'Tal''messing,Talmesing,Thalmassing,Thalmässing,ta er mei xing,tarumesshingu,Талмесинг,Тальмессинг,Тальмессінг,Թալմեսինգ,タールメッシング,塔尔梅兴', 49.0883400, 11.2215000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31149, 'Thalmassing', 'Thalmassing', 'Tal''massing,Talmasing,Thalmaessing,Thalmässing,ta er ma xing,talmasyng,Талмасинг,Тальмассинг,Тальмассінг,Թալմասինգ,تالماسینگ,塔尔马兴', 48.9116700, 12.1550000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31150, 'Thallwitz', 'Thallwitz', 'Tall''vic,Talvic,Thallwitzi vald,ta er wei ci,Талвиц,Талльвиц,塔尔维茨', 51.4333300, 12.6833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31151, 'Thallichtenberg', 'Thallichtenberg', 'Talikhtenberg,Tallikhtenberg,ta li xi teng bei ge,Талихтенберг,Таллихтенберг,塔利希滕贝格', 49.5582100, 7.3509300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31152, 'Thalheim', 'Thalheim', '', 51.6526800, 12.2275600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31153, 'Thalheim', 'Thalheim', 'Tal''khajm,Talheima/Rudu kalni,Talheima/Rūdu kalni,Talkhajm,Thalheim,talhaym,Талхајм,Тальхайм,تالهايم,تالهایم', 50.7007700, 12.8499600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31154, 'Thalhausen', 'Thalhausen', '', 50.5000000, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31155, 'Thaleischweiler-Fröschen', 'Thaleischweiler-Froschen', 'Talajshvajler-Freshen,Talajshvajler-Frjoshen,Thaleischweiler-Froeschen,Thaleischweiler-Fröschen,ta lai shi wei lei-fu lei shen,taraishuvu~aira=fureshen,Талайшвайлер-Фрёшен,Талајшвајлер-Фрешен,ターライシュヴァイラー＝フレーシェン,塔莱施韦勒-弗勒申', 49.2666700, 7.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31156, 'Thale', 'Thale', 'Tale,Talė,Thale,ta lei,talh,tare,Тале,تاله,ターレ,塔勒', 51.7486100, 11.0410000, 'DE', '2015-06-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31157, 'Thal', 'Thal', '', 50.9168400, 10.3920900, 'DE', '2013-11-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31158, 'Thaining', 'Thaining', '', 47.9730200, 10.9576600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31159, 'Thaden', 'Thaden', 'Thaden', 54.1014500, 9.4251500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31160, 'Teutschenthal', 'Teutschenthal', 'Teutschenthal,Tojchental,Tojchental'',tuo yi ci xing ta er,Тойченталь,Тојчентал,托伊茨兴塔尔', 51.4500000, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31161, 'Teuschnitz', 'Teuschnitz', 'Teuschnitz,Tojshnic,toishunittsu,tuo yi shi ni ci,twyshnytz,Тойшниц,Тойшніц,Тојшниц,Թոյշնից,تويشنيتز,تویشنیتز,トイシュニッツ,托伊施尼茨', 50.3983900, 11.3823500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31162, 'Teupitz', 'Teupitz', 'Teipica,Teupitz,Tojpic,tuo yi pi ci,twybytz,twypytz,Тойпиц,Тојпиц,Տոյպից,تويبيتز,تویپیتز,托伊皮茨', 52.1296700, 13.6196000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31163, 'Teunz', 'Teunz', 'Tojnc,tuo yin ci,twynts,Тойнц,Тојнц,توینتس,托因茨', 49.4833300, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31164, 'Teugn', 'Teugn', '', 48.8929900, 12.0117500, 'DE', '2013-02-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31165, 'Teuchern', 'Teuchern', 'Teuchera,Teuchern,Tojkhern,tuo yi hei er en,twyshrn,Тойхерн,Тојхерн,تويشرن,تویشرن,托伊黑尔恩', 51.1209400, 12.0241000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31166, 'Teublitz', 'Teublitz', 'Teublitz,Tojblic,tuo yi bu li ci,twyblytz,Тойблиц,Тойбліц,Тојблиц,تويبليتز,تویبلیتز,托伊布利茨', 49.2228900, 12.0872700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31167, 'Tettnang', 'Tettnang', 'Tetnang,Tettnang,Tettnang Castle,Тетнанг', 47.6685700, 9.5913200, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31168, 'Tettenweis', 'Tettenweis', 'Tetenvajs,Tettenvajs,te teng wei si,ttnways,Тетенвајс,Теттенвайс,Թեթենվայս,تتنوایس,特滕魏斯', 48.4428100, 13.2695500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31169, 'Tettau', 'Tettau', '', 51.4333300, 13.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31170, 'Tettau', 'Tettau', 'Tetau,Tettau,te tao,tettau,Тетау,Теттау,Տեթաու,テッタウ,特陶', 50.4697900, 11.2588800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31171, 'Teterow', 'Teterow', 'Teterov,Teterova,Teterow,Tēterova,te luo,Тетеров,特罗', 53.7754500, 12.5748700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31172, 'Tetenhusen', 'Tetenhusen', 'Tetenhusen', 54.3500000, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31173, 'Tetenbüll', 'Tetenbull', 'Tetenbull,Tetenbüll', 54.3521400, 8.8279400, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31174, 'Tessin', 'Tessin', '', 54.0276400, 12.4651900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31175, 'Tespe', 'Tespe', 'Gemeen Tesp,Tespe,te si pei,Теспе,特斯佩', 53.3964000, 10.4108400, 'DE', '2011-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31176, 'Teschenmoschel', 'Teschenmoschel', '', 49.6333300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31177, 'Tensfeld', 'Tensfeld', 'Tensfeld', 54.0422900, 10.3185600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31178, 'Tennenbronn', 'Tennenbronn', '', 48.1904100, 8.3517600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31179, 'Teningen', 'Teningen', 'Teningen,te ning gen,Тенинген,Тенінген,Տենինգեն,特宁根', 48.1295200, 7.8120500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31180, 'Tengen', 'Tengen', '', 47.8212800, 8.6611700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31181, 'Templin', 'Templin', 'Templin,teng pu lin,tmblyn,tmplyn,Темплин,Темплін,Տեմպլին,تمبلين,تمپلین,滕普林', 53.1186500, 13.5022000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31182, 'Tempelhof', 'Tempelhof Bezirk', 'Berlin-Tempelhof,Tempel''gof,Tempel''khof,Templinum,tmplhwp,Темпельгоф,Темпельхоф,טמפלהוף,ٹیمپلہوف-شونبرگ', 52.4666700, 13.4000000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31183, 'Temmels', 'Temmels', '', 49.6888700, 6.4654000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31184, 'Teltow', 'Teltow', 'Dolnjow,Tel''tov,Teltov,Teltow,te er tuo,tltw,Телтов,Тельтов,Տելթով,تلتو,特尔托', 52.4031000, 13.2601400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31185, 'Tellingstedt', 'Tellingstedt', 'Telingshtet,Tellingshtedt,tai ling shi tai te,Телингштет,Теллингштедт,泰灵施泰特', 54.2166700, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31186, 'Tellig', 'Tellig', '', 50.0333300, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31187, 'Telgte', 'Telgte', 'Tel''gte,Telgte,Telligte,Telqte,tai er ge te,tlghth,tlgth,Телгте,Тельгте,تلغته,تلگته,泰尔格特', 51.9799500, 7.7829300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31188, 'Teistungen', 'Teistungen', 'Tajstungen,Teistingen,Teistungen,tai si tong gen,Тайстунген,Тајстунген,泰斯通根', 51.4666700, 10.2666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31189, 'Teisnach', 'Teisnach', 'Tajsnakh,Teisnach,tai si na,taysnakh,Тайснах,Тајснах,Թայսնախ,تایسناخ,泰斯纳', 49.0411400, 12.9878400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31190, 'Teising', 'Teising', 'Tajsing,Tajzing,Tayzing,tai xin ge,tayzyng,Тайзинг,Тайзінг,Тајсинг,Տայզինգ,تایزینگ,泰辛格', 48.2272100, 12.6113700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31191, 'Teisendorf', 'Teisendorf', 'Deisndorf,Tajsendorf,Tajzendorf,Tayzendorf,Teisendorf,tai sen duo fu,tayzndwrf,Тайзендорф,Тајсендорф,Տայզենդորֆ,تایزندورف,泰森多夫', 47.8492100, 12.8191900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31192, 'Teichwolframsdorf', 'Teichwolframsdorf', 'Tajkhvol''framsdorf,Tajkhvolframsdorf,Teichwolframsdorf,Тайхвольфрамсдорф,Тајхволфрамсдорф', 50.7209300, 12.2468900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31193, 'Teichwitz', 'Teichwitz', 'Teichwitz', 50.7500000, 12.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31194, 'Teicha', 'Teicha', '', 51.5588700, 11.9548200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31195, 'Tegernsee', 'Tegernsee', 'Tegernze,tai gen sai,tgrnzy,tyghrnzyh,Тегернзе,Տեգերնզե,تيغرنزيه,تگرنزی,泰根塞', 47.7123000, 11.7582000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31196, 'Tegernheim', 'Tegernheim', 'Tegerngajm,Tegernhaym,Tegernkhajm,te ge er en hai mu,tgrnhaym,Тегернгайм,Тегернхайм,Тегернхајм,Տեգերնհայմ,تگرنهایم,特格尔恩海姆', 49.0239400, 12.1730300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31197, 'Tegel', 'Tegel', 'Berlin-Tegel,Tegel'',Тегель', 52.5760100, 13.2938900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31198, 'Tegau', 'Tegau', 'Tegau', 50.6500000, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31199, 'Tecklenburg', 'Tecklenburg', 'Tecklembourg,Tecklenburg,Tecklenbuurich,Tekklenburg,Teklenburg,Teklenburq,te ke lun bao,tklnbwrg,tklnbwrgh,Теккленбург,Текленбург,تكلنبورغ,تکلنبورگ,特克伦堡', 52.2195700, 7.8135700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31200, 'Techelsdorf', 'Techelsdorf', 'Techelsdorf', 54.2166700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31201, 'Tawern', 'Tawern', 'Tavern,ta wei er en,Таверн,塔韦尔恩', 49.6666700, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31202, 'Tautenhain', 'Tautenhain', '', 50.9247000, 11.9194500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31203, 'Tautendorf', 'Tautendorf', '', 50.8166700, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31204, 'Tautenburg', 'Tautenburg', 'Tautenburg,tao teng bao,Таутенбург,陶滕堡', 51.0000000, 11.7166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31205, 'Tauscha', 'Tauscha', 'Tauscha vald,Tausha,tao sha,Тауша,陶沙', 51.2666700, 13.8000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31206, 'Taura', 'Taura', '', 50.9166700, 12.8500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31207, 'Taunusstein', 'Taunusstein', 'Gorad Taunusshtajn,Stadt Taunusstein,Taunusshtajn,Taunusstein,tao nu si tai yin,taunusushutain,tawnwsshtayn,Горад Таўнусштайн,Таунусштайн,Таунусштајн,تاونوسشتاين,تاونوس‌اشتاین,タウヌスシュタイン,陶努斯泰因', 50.1499300, 8.1520600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31208, 'Taufkirchen', 'Taufkirchen', 'Taufkirchen,Taufkirkhen,tawf kyrshn,Тауфкирхен,Тауфкірхен,تاوف کیرشن', 48.3498700, 12.1320200, 'DE', '2013-04-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31209, 'Taufkirchen', 'Taufkirchen', '', 48.1500000, 12.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31210, 'Taufkirchen', 'Taufkirchen', 'Taufkira,Taufkirkhen,tawf kyrshn,Тауфкирхен,Тауфкірхен,تاوف کیرشن', 48.0486000, 11.6170100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31211, 'Tauer', 'Tauer', '', 51.9000000, 14.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31212, 'Tauche', 'Tauche', 'Taukhe,Tauxe,tao hei,Таухе,Տաուխե,陶黑', 52.1500000, 14.1666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31213, 'Taucha', 'Taucha', 'Taucha,Tauha,Taukha,tao ha,tawkha,tawshaw,Тауха,تاوخا,تاوشاو,陶哈', 51.3833300, 12.4833300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31214, 'Tauberrettersheim', 'Tauberrettersheim', 'Taubereterskhajm,Tauberrettersgajm,Tauberretterskhajm,tao bei lei te er si hai mu,taubarettasuhaimu,Тауберетерсхајм,Тауберреттерсгайм,Тауберреттерсхайм,Տաուբերեթերսհայմ,タウバーレッタースハイム,陶贝雷特尔斯海姆', 49.4944400, 9.9366700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31215, 'Tauberbischofsheim', 'Tauberbischofsheim', 'Tauberbischofsheim,Tauberbishofsgajm,Tauberbishofskhajm,tao bei er bi shao fu si hai mu,taubabishofusuhaimu,tawbrbyshwfshaym,tawbrbyshwfzhaym,Таубербишофсхайм,Таубербишофсхајм,Таубербішофсгайм,تاوبربيشوفسهايم,تاوبربیشوفزهایم,タウバービショフスハイム,陶贝尔比绍夫斯海姆', 49.6247200, 9.6627800, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31216, 'Tating', 'Tating', 'Tating', 54.3260700, 8.7080200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31217, 'Tastungen', 'Tastungen', '', 51.4691900, 10.3096400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31218, 'Tastrup', 'Tastrup', 'Tastrup', 54.7666700, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31219, 'Tasdorf', 'Tasdorf', 'Tasdorf', 54.1000000, 10.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31220, 'Markt Taschendorf', 'Markt Taschendorf', 'Markt Taschendorf,Markt Tashendorf,Markt-Tashendorf,Taschendorf,ma ke te ta shen duo fu,Маркт Ташендорф,Маркт-Ташендорф,Մարքթ Թաշենդորֆ,马克特塔申多夫', 49.7011100, 10.5555700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31221, 'Tarp', 'Tarp', 'Tarp', 54.6666700, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31222, 'Tarnow', 'Tarnow', '', 53.7794100, 12.0178500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31223, 'Tarmstedt', 'Tarmstedt', 'Tarms,Tarmshtedt,Tarmshtet,Tarmstedt,ta er mu si te,tarumushutetto,Тармштедт,Тармштет,タルムシュテット,塔尔姆斯特', 53.2250500, 9.0776300, 'DE', '2011-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31224, 'Tarbek', 'Tarbek', 'Tarbek', 54.0500000, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31225, 'Tappendorf', 'Tappendorf', 'Tappendorf', 54.1042200, 9.6937000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31226, 'Tappenbeck', 'Tappenbeck', '', 52.4705500, 10.7406800, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31227, 'Tapfheim', 'Tapfheim', 'Tapfgajm,Tapfkhajm,ta pu fu hai mu,tapufuhaimu,Тапфгайм,Тапфхайм,Тапфхајм,Թափֆհայմ,タプフハイム,塔普夫海姆', 48.6732200, 10.6837700, 'DE', '2012-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31228, 'Tantow', 'Tantow', 'Tantov,tan tuo,Тантов,Տանտով,坦托', 53.2716300, 14.3509800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31229, 'Tannheim', 'Tannheim', '', 48.0000000, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31230, 'Tannhausen', 'Tannhausen', 'Tankhauzen,Tanngauzen,tan hao sen,Таннгаузен,Танхаузен,ტანჰაუზენი,坦豪森', 48.9787000, 10.3612900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31231, 'Tännesberg', 'Tannesberg', 'Taennesberg,Tannesberg,Tenesberg,Tennesberg,Tännesberg,tanasbrg,te nei si bei ge,Тенесберг,Теннесберг,Թեննեսբերգ,تاناسبرگ,特内斯贝格', 49.5318200, 12.3276500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31232, 'Tannenbergsthal', 'Tannenbergsthal', 'Tanenbergstal,Tannenbergstal'',Tannenbergsthal,Таненбергстал,Танненбергсталь', 50.4366500, 12.4575400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31233, 'Tannenberg', 'Tannenberg', '', 50.6073800, 12.9379800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31234, 'Tanna', 'Tanna', 'Tanna', 50.4946000, 11.8572500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31235, 'Tann', 'Tann', 'Tan,Tann,tan,tan zhen,Тан,Танн,تان,坦镇', 50.6428400, 10.0238500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31236, 'Tann', 'Tann', 'Tan,Tann,tan,Тан,Танн,Տանն,تان', 48.3146300, 12.8930100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31237, 'Tangstedt', 'Tangstedt', '', 53.7333300, 10.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31238, 'Tangstedt', 'Tangstedt', '', 53.6771100, 9.8488000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31239, 'Tangermünde', 'Tangermuende', 'Tangerminde,Tangermjunde,Tangermuende,Tangermuenn,Tangermundum,Tangermünde,Tangermünn,Tongeremuthi,tan ge er ming de,tanghrmwndh,tangrmwndh,Тангерминде,Тангермюнде,تانغرمونده,تانگرمونده,坦格尔明德', 52.5446300, 11.9764700, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31240, 'Tangerhütte', 'Tangerhuette', 'Tangerhuette,Tangerhutte,Tangerhütte,Tangerkhite,Tangerkhjutte,tan ge lu te,tanghrhwth,tangrhwth,Тангерхите,Тангерхютте,تانغرهوته,تانگرهوته,坦格吕特', 52.4353000, 11.8072400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31241, 'Tamm', 'Tamm', 'Tam,Tamm,ta mu,tam,Там,Тамм,تام,塔姆', 48.9198800, 9.1155600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31242, 'Tambach-Dietharz', 'Tambach-Dietharz', 'Dietharz,Tambach-Dietharz,Tambach-Dietharz/Thueringer Wald,Tambach-Dietharz/Thüringer Wald,Tambakh-Ditarc,Tambakh-Ditkharc,tambakh-dytharts,tan ba he-di ta er ci,Тамбах-Дитарц,Тамбах-Дитхарц,تامباخ-ديتهارتس,تامباخ-دیت‌هارتس,坦巴赫-迪塔尔茨', 50.7924500, 10.6156800, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31243, 'Talling', 'Talling', '', 49.7666700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31244, 'Talkau', 'Talkau', 'Talkau', 53.5752400, 10.5708000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31245, 'Talheim', 'Talheim', '', 49.0833300, 9.1930600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31246, 'Talheim', 'Talheim', '', 48.0166700, 8.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31247, 'Tagmersheim', 'Tagmersheim', '', 48.8166700, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31248, 'Täferrot', 'Taferrot', 'Taeferrot,Teferot,Teferrot,Täferrot,tafrt,te fei luo te,Теферот,Теферрот,تافرت,ტეფეროტი,特费罗特', 48.8497200, 9.8382400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31249, 'Tackesdorf', 'Tackesdorf', 'Tackesdorf', 54.1833300, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31250, 'Taching am See', 'Taching am See', 'Taching a. See,Taching am See,Takhing am Ze,Takhing-am-Ze,bin hu ta xing,takhyng am zy,Тахинг ам Зе,Тахинг-ам-Зе,Тахінг-ам-Зе,Զեեի Թախինգ,تاخینگ ام زی,滨湖塔兴', 47.9594200, 12.7293300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31251, 'Tacherting', 'Tacherting', 'Takherting,takhrtyng,Тахертинг,Тахертінг,Թախերթինգ,تاخرتینگ', 48.0782500, 12.5700800, 'DE', '2012-09-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31252, 'Taben-Rodt', 'Taben-Rodt', '', 49.5500000, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31253, 'Tabarz', 'Tabarz', 'Tabarz,Tabarz/Thueringer Wald,Tabarz/Thüringer Wald', 50.8752900, 10.5160700, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31254, 'Taarstedt', 'Taarstedt', 'Taarstedt', 54.5666700, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31255, 'Syrau', 'Syrau', 'Syrau', 50.5429700, 12.0793300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31256, 'Syke', 'Syke', 'Syke,Zike,swike,sykh,zwkt,Зике,زوكة,سیکه,쉬케', 52.9134500, 8.8220900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31257, 'Sustrum', 'Sustrum', 'Zustrum,su si te lu mu,Зуструм,苏斯特鲁姆', 52.9166700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31258, 'Süstedt', 'Suestedt', 'Suest,Süst,Zishtet,Zjushtedt,xu si te,Зиштет,Зюштедт,叙斯特', 52.8616500, 8.9221300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31259, 'Süßen', 'Sussen', 'Zisen,Zjusen,Zjussen,xu sen,zwsn,Зисен,Зюсен,Зюссен,زوسن,叙森', 48.6793400, 9.7553400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31260, 'Süsel', 'Suesel', 'Susel,Süsel,Zizel,Zjuzel'',xu sai er,Зизел,Зюзель,叙塞尔', 54.0813500, 10.7017200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31261, 'Surwold', 'Surwold', 'Zurvol''d,Zurvold,su er wo er de,Зурволд,Зурвольд,苏尔沃尔德', 52.9780000, 7.5153400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31262, 'Surberg', 'Surberg', 'Zurberg,su er bei ge,zwrbrg,Зурберг,Զուրբերգ,زوربرگ,苏尔贝格', 47.8666700, 12.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31263, 'Süpplingenburg', 'Supplingenburg', 'Suepplingenburg,Süpplingenburg,Ziplingenburg,Zjuplingenburg,xu pu lin gen bao,Зиплингенбург,Зюплингенбург,叙普林根堡', 52.2507200, 10.9101100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31264, 'Süpplingen', 'Supplingen', 'Suepplingen,Süpplingen', 52.2281100, 10.9039300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31265, 'Süplingen', 'Sueplingen', 'Suplingen,Süplingen', 52.2875900, 11.3245000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31266, 'Sundhausen', 'Sundhausen', '', 51.1666700, 10.7166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31267, 'Sundern', 'Sundern', 'Sonnern,Sundern,Zundern,sun deng,zwndrn,Зундерн,زوندرن,孙登', 51.3281000, 8.0036900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31268, 'Sünching', 'Sunching', 'Zinkhing,Zjunkhing,Zyunxing,xin xing,zwnshyng,Зинхинг,Зюнхинг,Зюнхінг,Զյունխինգ,زونشینگ,辛兴', 48.8785500, 12.3512900, 'DE', '2012-08-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31269, 'Sulzheim', 'Sulzheim', '', 49.9500000, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31270, 'Sulzheim', 'Sulzheim', '', 49.8430600, 8.0916700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31271, 'Sulzfeld am Main', 'Sulzfeld am Main', 'Zul''cfel''d-am-Majn,Zul''cfel''d-na-Majne,Zulcfeld na Majni,mei yin he pan su er ci fei er de,Зулцфелд на Мајни,Зульцфельд-ам-Майн,Зульцфельд-на-Майне,Մայնի Զուլցֆելդ,美因河畔苏尔茨费尔德', 49.7069400, 10.1324800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31272, 'Sülzfeld', 'Suelzfeld', '', 50.5232200, 10.3600500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31273, 'Sulzfeld', 'Sulzfeld', '', 50.2597200, 10.4052500, 'DE', '2012-01-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31274, 'Sulzfeld', 'Sulzfeld', 'Sulzfeld', 49.1047200, 8.8558300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31275, 'Sulzemoos', 'Sulzemoos', 'Sulzermoos,Zul''cemos,Zulcemos,su er ce mo si,zwltsmws,Зулцемос,Зульцемос,Զուլցեմոս,زولتسموس,苏尔策莫斯', 48.2910700, 11.2635600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31276, 'Sulzdorf', 'Sulzdorf', '', 49.6500200, 9.9038900, 'DE', '2012-10-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31277, 'Sulzburg', 'Sulzburg', 'Zul''cburg,Zulcburg,Zulsburq,su er ci bao,zwltsbwrg,zwltsbwrgh,zwlzbwrg,Зулцбург,Зульцбург,Զուլցբուրգ,זולצבורג,زولتسبورغ,زولتسبورگ,苏尔茨堡', 47.8411600, 7.7077700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31278, 'Sulzberg', 'Sulzberg', 'Sulzberg,Zul''cberg,Zulcberg,Зулцберг,Зульцберг,Զուլցբերգ', 47.6603300, 10.3499100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31279, 'Sulzbach-Rosenberg', 'Sulzbach-Rosenberg', 'Suizboch-Rosnberg,Sulzbach,Sulzbach-Rosenberg,Zul''cbakh-Rozenberg,Zulcbakh-Rozenberg,su er ci ba he-luo sen bei ge,zwltsbakh-rwznbrgh,zwltsbakh-rznbrg,Зулцбах-Розенберг,Зульцбах-Розенберг,Զուլցբախ Ռոզենբերգ,زولتسباخ-رزنبرگ,زولتسباخ-روزنبرغ,苏尔茨巴赫-罗森贝格', 49.5012600, 11.7459800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31280, 'Sulzbach an der Murr', 'Sulzbach an der Murr', 'Sulzbach,Zul''cbakh-an-der-Mur,Zul''cbakh-an-der-Murr,Zul''cbakh-na-Mure,Zulcbakh an der Mur,mu er he pan su er ci ba he,Зулцбах ан дер Мур,Зульцбах-ан-дер-Мур,Зульцбах-ан-дер-Мурр,Зульцбах-на-Муре,穆尔河畔苏尔茨巴赫', 49.0030300, 9.5003000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31281, 'Sulzbach am Main', 'Sulzbach am Main', 'Sulzbach,Sulzbach am Main,Zul''cbakh-am-Majn,Zul''cbakh-na-Majne,Zulcbakh na Majni,mei yin he pan su er ci ba he,Зулцбах на Мајни,Зульцбах-ам-Майн,Зульцбах-на-Майне,Մայնի Զուլցբախ,ズルツバッハ・アム・マイン,美茵河畔苏尔茨巴赫', 49.9114900, 9.1531500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31282, 'Sulzbach', 'Sulzbach', '', 50.3025500, 7.7523100, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31283, 'Sulzbach', 'Sulzbach', 'Sulzbach,Zul''cbakh,Zulcbakh,su er ci ba he,zurutsubahha,Зулцбах,Зульцбах,ズルツバッハ,苏尔茨巴赫', 50.1339600, 8.5279700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31284, 'Sulzbach', 'Sulzbach', 'Zul''cbakh,Zulcbakh,Зулцбах,Зульцбах', 49.8333300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31285, 'Sulzbach', 'Sulzbach', 'Sulzbach,Sulzbach/ Saar,Sulzbach/Saar,Zul''cbakh,Zulcbakh,zwltsbakh,Зулцбах,Зульцбах,زولتسباخ', 49.2988200, 7.0569600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31286, 'Sulz am Neckar', 'Sulz am Neckar', 'Sulz,Zul''c-am-Nekkar,Zul''c-na-Nekkare,Zulc am Nekar,nei ka he pan su er ci,zwlts am nka,Зулц ам Некар,Зульц-ам-Неккар,Зульц-на-Неккаре,زولتس آم نكا,زولتس آم نکا,内卡河畔苏尔茨', 48.3624100, 8.6330900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31287, 'Sulza', 'Sulza', 'Sulza', 50.8666700, 11.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31288, 'Sülm', 'Sulm', '', 49.9166700, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31289, 'Sulingen', 'Sulingen', 'Sulingen,Zulingen,su lin gen,zwlyngn,Зулинген,زولینگن,苏林根', 52.6837300, 8.8094900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31290, 'Sülfeld', 'Sulfeld', 'Suelfeld,Sülfeld,Zilfeld,Zjul''fel''d,xu er fei er de,Зилфелд,Зюльфельд,叙尔费尔德', 53.8000000, 10.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31291, 'Sukow', 'Sukow', '', 53.5442800, 11.5619400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31292, 'Sülstorf', 'Suelstorf', 'Suhlstorf,Sulstorf,Sühlstorf,Sülstorf', 53.5093100, 11.3746300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31293, 'Suhlendorf', 'Suhlendorf', '', 52.9333300, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31294, 'Suhl', 'Suhl', 'Suhl,ZSO,Zul,Zul'',jul,su er,sul,zul'',zuru,zwl,Зул,Зуль,زول,ซูล,ズール,苏尔,줄', 50.6091100, 10.6940100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31295, 'Sugenheim', 'Sugenheim', 'Sugenheim,Zugengajm,Zugenhaym,Zugenkhajm,su gen hai mu,Зугенгайм,Зугенхайм,Зугенхајм,Զուգենհայմ,苏根海姆', 49.6027600, 10.4356300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31296, 'Sudwalde', 'Sudwalde', 'Suwohle,Zudval''de,Zudvalde,su de wa er de,Зудвалде,Зудвальде,苏德瓦尔德', 52.7933700, 8.8361100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31297, 'Südlohn', 'Sudlohn', 'Sudlohn,Suedlohn,Südlohn,Zidlon,Zjudlon,swdlwn,xu de luo en,Зидлон,Зюдлон,سودلون,叙德洛恩', 51.9333300, 6.8666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31298, 'Süderstapel', 'Suderstapel', 'Sonder Stabel,Suderstapel,Sønder Stabel,Süderstapel,Zidershtapel,Ziderstapel,Zjudershtapel'',xu de er si ta pei er,Зидерстапел,Зидерштапел,Зюдерштапель,叙德尔斯塔佩尔', 54.3500000, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31299, 'Süderlügum', 'Suederluegum', 'Laeigem,Läigem,Sonder Logum,Sønder Løgum,Ziderligum,Zjuderljugum,xu de er lu gu mu,Зидерлигум,Зюдерлюгум,叙德尔吕古姆', 54.8739100, 8.9111100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31300, 'Süderhöft', 'Suderhoft', '', 54.3833300, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31301, 'Süderheistedt', 'Suederheistedt', 'Suderheistedt,Süderheistedt', 54.2352100, 9.1472100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31302, 'Süderhastedt', 'Suederhastedt', 'Suderhastedt,Süderhastedt', 54.0494000, 9.2076300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31303, 'Süderhackstedt', 'Suderhackstedt', 'Suderhackstedt,Süderhackstedt', 54.6000000, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31304, 'Südergellersen', 'Sudergellersen', '', 53.2166700, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31305, 'Süderfahrenstedt', 'Suderfahrenstedt', 'Suderfahrenstedt,Süderfahrenstedt', 54.5833300, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31306, 'Süderende', 'Suderende', '', 54.7261100, 8.4385300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31307, 'Süderdeich', 'Suderdeich', '', 54.2000000, 8.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31308, 'Suderburg', 'Suderburg', 'Zuderburg,su de er bao,Зудербург,苏德尔堡', 52.8958600, 10.4514100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31309, 'Süderbrarup', 'Suderbrarup', 'Sonder Brarup,Suderbrarup,Suederbrarup,Sønder Brarup,Süderbrarup,Ziderbrarup,Zjuderbrarup,xu de er bu la lu pu,Зидербраруп,Зюдербраруп,叙德尔布拉鲁普', 54.6333300, 9.7833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31310, 'Süderau', 'Suederau', 'Suderau,Süderau', 53.8166700, 9.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31311, 'Suddendorf', 'Suddendorf', '', 52.3009600, 7.2257200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31312, 'Stuvenborn', 'Stuvenborn', 'Stuvenborn', 53.8500000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31313, 'Stützerbach', 'Stutzerbach', 'Shticerbakh,Shtjutcerbakh,Stuetzerbach,Stutzerbach,Stützerbach,shi di ce er ba he,Штицербах,Штютцербах,施蒂策尔巴赫', 50.6333300, 10.8666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31314, 'Stützengrün', 'Stutzengrun', 'Shticengrin,Shtjutcengrjun,Stuetzengruen,Stützengrün,shi di cen lin,Штиценгрин,Штютценгрюн,施蒂岑林', 50.5333300, 12.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31315, 'Stuttgart', 'Stuttgart', 'Estugarda,Gorad Shtutgart,STR,Shhutgart,Shtutgart,Shtutgarti,Shtuttgart,Stocarda,Stoccarda,Stoutnkarde,Stucarda,Stuggart,Stutgardia,Stutgartas,Stutgarte,Stutgarto,Stutqart,Stuttgart,ashtwtgart,ch tuthth kar th,icututkart,shtwtgart,shtwtghart,shuto~uttogaruto,si tu jia te,stutagarta,stwtgrt,syututeugaleuteu,Ştutqart,Štutgartas,Štutgarte,Στουτγκάρδη,Горад Штутгарт,Штутгарт,Штуттгарт,Щутгарт,שטוטגארט,שטוטגרט,اشتوتگارت,سٹٹگارٹ,شتوتغارت,شتوتگارت,شٹوٹگارٹ,श्टुटगार्ट,স্টুটগার্ট,સ્ટુટગાર્ટ,இசுடுட்கார்ட்,സ്റ്റുട്ട്ഗാർട്ട്,ชตุทท์การ์ท,შტუტგარტი,シュトゥットガルト,斯图加特,슈투트가르트', 48.7823200, 9.1770200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31316, 'Stürzelbach', 'Sturzelbach', '', 50.6500000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31317, 'Stulln', 'Stulln', 'Shtul''n,Shtuln,ashtwln,shi tu er en,Штулн,Штульн,اشتولن,施图尔恩', 49.4166700, 12.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31318, 'Stuhr', 'Stuhr', '', 53.0333300, 8.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31319, 'Stühlingen', 'Stuhlingen', 'Shtilingen,Shtjulingen,Stuehlingen,Stuhlingen,Stühlingen,ashtwlyngn,shi di he lin gen,shtwlynghn,Штилинген,Штюлинген,Штюлінген,اشتولینگن,شتولينغن,施蒂赫林根', 47.7458000, 8.4481300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31320, 'Stubenberg', 'Stubenberg', '', 48.3166700, 13.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31321, 'Stubben', 'Stubben', '', 53.7333300, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31322, 'Struxdorf', 'Struxdorf', 'Struxdorf', 54.6310000, 9.6386600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31323, 'Struvenhütten', 'Struvenhutten', 'Struvenhutten,Struvenhütten', 53.8666700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31324, 'Strüth', 'Struth', '', 50.1333300, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31325, 'Struppen', 'Struppen', 'Shtrupen,Shtruppen,shi te lu peng,Штрупен,Штруппен,施特鲁彭', 50.9333300, 14.0166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31326, 'Strullendorf', 'Strullendorf', 'Shtrulendorf,Shtrullendorf,Strulendorf,shi te lu lun duo fu,shutorurendorufu,Штрулендорф,Штруллендорф,Շտրուլենդորֆ,シュトルレンドルフ,施特鲁伦多夫', 49.8442900, 10.9720800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31327, 'Strukdorf', 'Strukdorf', 'Strukdorf', 53.9166700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31328, 'Struckum', 'Struckum', 'Struckum,Struekem,Strükem', 54.5833300, 9.0000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31329, 'Strübbel', 'Struebbel', 'Strubbel,Strübbel', 54.2666700, 8.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31330, 'Strotzbüsch', 'Strotzbuesch', 'Strotzbuesch,Strotzbüsch', 50.1000000, 6.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31331, 'Stromberg', 'Stromberg', '', 50.4577900, 7.6004100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31332, 'Stromberg', 'Stromberg', 'Shtromberg,ashtrmbrg,shi te long bei ge,shtrwmbrgh,Штромберг,اشترمبرگ,شترومبرغ,施特龙贝格', 49.9438900, 7.7728600, 'DE', '2012-04-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31333, 'Strohn', 'Strohn', '', 50.1166700, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31334, 'Ströbeck', 'Stroebeck', 'Strobeck,Stroebeck,Ströbeck', 51.9140600, 10.9444500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31335, 'Strickscheid', 'Strickscheid', '', 50.1333300, 6.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31336, 'Streithausen', 'Streithausen', '', 50.6936100, 7.8152800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31337, 'Strehla', 'Strehla', 'Shtrela,Strehla,Strela,Strjela,ashtrla,shi te lei la,shtryla,Štrēla,Штрела,اشترلا,شتريلا,施特雷拉', 51.3524800, 13.2266000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31338, 'Straußfurt', 'Straussfurt', 'Shtrausfurt,Straussfurt,Straußfurt,shi te lao si fu er te,Штраусфурт,施特劳斯富尔特', 51.1666700, 10.9833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31339, 'Strausberg', 'Strausberg', 'QPK,Shtrausberg,Straousmpernk,Strausberg,Strausbergum,ashtrawsbrg,satarasabaraga,shi te lao si bei ge,shtrawsbrgh,shutorausuberuku,Στράουσμπεργκ,Штраусберг,Շտրաուսբերգ,اشتراوسبرگ,شتراوسبرغ,ਸਟਰਾਸਬਰਗ,シュトラウスベルク,施特劳斯贝格', 52.5785900, 13.8874100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31340, 'Straupitz', 'Straupitz', 'Shtraupic,Straupitz,Straupitz/Tsupc,Straupitz/Tšupc,Tsupc,Tšupc,shi te lao pi ci,Штраупиц,Շտրաուպից,施特劳皮茨', 51.9135700, 14.1227500, 'DE', '2013-05-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31341, 'Straubing', 'Straubing', 'Gorad Shtraubing,RBM,Shtraubing,Straubing,ashtrawbyng,shi te lao bin,Горад Штраўбінг,Страубинг,Штраубинг,اشتراوبینگ,ስትራውቢንግ,施特劳宾', 48.8812600, 12.5738500, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31342, 'Straßkirchen', 'Strasskirchen', '', 48.8307100, 12.7210500, 'DE', '2012-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31343, 'Straßberg', 'Strassberg', 'Strassberg,Straßberg', 48.1780500, 9.0905900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31344, 'Strasburg', 'Strasburg', 'Strasburg', 53.5103000, 13.7451300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31345, 'Strande', 'Strande', 'Shtrande,Strande,shi te lan de,Штранде,施特兰德', 54.4333300, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31346, 'Stralsund', 'Stralsund', 'BBH,Gorad Shtral''zund,Shhralzund,Shtral''zund,Shtralzund,Stralsund,Stralsunda,Stralzunde,Strzalowo,Strzałowò,ashtralzwnd,shi te la er song,shi te la er song de,shutoraruzunto,strlzwnd,syuteulaljunteu,Štrālzunde,Горад Штральзунд,Штралзунд,Штральзунд,Щралзунд,שטרלזונד,اشترالزوند,შტრალზუნდი,シュトラールズント,施特拉尔松,施特拉爾松德,슈트랄준트', 54.3091100, 13.0818000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31347, 'Stralendorf', 'Stralendorf', 'Shtralendorf,shi te la lun duo fu,Штралендорф,施特拉伦多夫', 53.5749800, 11.3035600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31348, 'Strahlungen', 'Strahlungen', '', 50.2833300, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31349, 'Straelen', 'Straelen', 'Shtraelen,Shtralen,Shtrelen,Straele,Straelen,ashtrln,shi te la ai lun,shtryln,Штраелен,Штрален,Штрелен,اشترلن,شتريلن,施特拉埃伦', 51.4419000, 6.2663900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31350, 'Stöttwang', 'Stottwang', 'Shtettvang,Shtetvang,Shtjotvang,Stoettwang,Styotvang,Stöttwang,shi te wang,shutettovu~angu,Штетванг,Штеттванг,Штётванг,Շտյոտվանգ,シュテットヴァング,施特旺', 47.8833300, 10.7166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31351, 'Stötten am Auerberg', 'Stotten am Auerberg', 'Stotten am Auerberg,Stötten am Auerberg', 47.7387100, 10.6888100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31352, 'Stößen', 'Stoessen', 'Shtesen,Shtjosen,Shtjossen,Stossen,Stößen,ashtwsn,shi te sen,shtwsn,Штесен,Штёсен,Штёссен,Штөссен,اشتوسن,شتوسن,施特森', 51.1144000, 11.9240500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31353, 'Stoßdorf', 'Stossdorf', '', 50.7824800, 7.2512600, 'DE', '2011-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31354, 'Störnstein', 'Stoernstein', 'Shternshtajn,Shtjornshtajn,Sternstein,Stornstein,Störnstein,shi te er en shi tai yin,Штернштайн,Штернштајн,Штёрнштайн,Շթյորնշթայն,施特尔恩施泰因', 49.7323200, 12.2054700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31355, 'Storkow', 'Storkow', 'Shtorkov,Storkov,Storkow,ashtrkw,shi tuo er ke,shtwrkw,Шторков,Շտորկով,اشترکو,شتوركو,施托尔科', 52.2566200, 13.9333700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31356, 'Störkathen', 'Storkathen', 'Storkathen,Störkathen', 53.9833300, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31357, 'Stördorf', 'Stordorf', 'Stordorf,Stördorf', 53.9153100, 9.4258800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31358, 'Stolzenau', 'Stolzenau', 'Shtol''cenau,Shtolcenau,Stolzenau,shi tuo er ce nao,shutorutsu~enau,Штолценау,Штольценау,シュトルツェナウ,施托尔策瑙', 52.5166700, 9.0666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31359, 'Stoltenberg', 'Stoltenberg', 'Stoltenberg', 54.3500000, 10.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31360, 'Stoltebüll', 'Stoltebull', 'Stoltebuell,Stoltebull,Stoltebüll', 54.7000000, 9.8833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31361, 'Stolpen', 'Stolpen', 'Shtol''pen,Shtolpen,Stolpen,Stolpene,Stolpin,Stołpin,ashtwlpn,shi tuo er peng,shtwlbn,Štolpene,Штолпен,Штольпен,اشتولپن,شتولبن,施托尔彭', 51.0490100, 14.0794300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31362, 'Stolpe', 'Stolpe', '', 54.1333300, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31363, 'Stollberg', 'Stollberg', 'Shtol''berg,Shtolberg,Stollberg,Stollberg/Erzgeb.,Stollberga/Rudu kalni,atwlbrg,shtwlbrgh,Štollberga/Rūdu kalni,Штолберг,Штольберг,اتولبرگ,شتولبرغ', 50.7099900, 12.7803400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31364, 'Stolk', 'Stolk', 'Stolk', 54.6000000, 9.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31365, 'Stolberg', 'Stolberg', 'Stolberg', 51.5742600, 10.9558200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31366, 'Stolberg', 'Stolberg', 'Shtol''berg,Shtolberg,Sjtolberg,Stolberg,Stolbersch,ashtwlbrg,shi tuo er bei ge,shtwlbrgh,shutoruberuku,Штолберг,Штольберг,اشتولبرگ,شتولبرغ,シュトルベルク,施托尔贝格', 50.7736800, 6.2259500, 'DE', '2016-09-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31367, 'Stoetze', 'Stoetze', '', 53.0666700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31368, 'Stödtlen', 'Stodtlen', 'Shtedtlen,Shtjodtlen,Stodtlen,Stoedtlen,Stödtlen,shi te lun,Штедтлен,Штёдтлен,შტედტლენი,施特伦', 49.0000000, 10.3000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31369, 'Stockstadt am Main', 'Stockstadt am Main', 'Stockstadt,Stockstadt am Main', 49.9700500, 9.0715300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31370, 'Stockstadt am Rhein', 'Stockstadt am Rhein', '', 49.8094400, 8.4727800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31371, 'Stocksee', 'Stocksee', 'Stocksee', 54.0899400, 10.3416900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31372, 'Stöckse', 'Stockse', 'Shtekse,Shtjokse,shi te ke sai,shutekkuze,Штексе,Штёксе,シュテックゼ,施特克塞', 52.6406700, 9.3402700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31373, 'Stockheim', 'Stockheim', '', 50.4595900, 10.2730100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31374, 'Stockheim', 'Stockheim', '', 50.3063900, 11.2817200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31375, 'Stockhausen-Illfurth', 'Stockhausen-Illfurth', 'Stockhausen-Illfurt,Stockhausen-Illfurth', 50.6466700, 7.9875000, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31376, 'Stockem', 'Stockem', '', 49.9333300, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31377, 'Stockelsdorf', 'Stockelsdorf', '', 53.8922000, 10.6471300, 'DE', '2012-03-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31378, 'Stockach', 'Stockach', 'Shtokakh,Shtokkakh,Stockach,shi tuo ka,shtwkakh,Штоках,Штокках,اشتوک‌آخ,شتوكاخ,施托卡', 47.8510500, 9.0091000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31379, 'Stipshausen', 'Stipshausen', 'Shtipskhauzen,shi di pu si hao sen,Штипсхаузен,施蒂普斯豪森', 49.8500000, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31380, 'Stipsdorf', 'Stipsdorf', 'Stipsdorf', 53.9500000, 10.3333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31381, 'Stinstedt', 'Stinstedt', 'Gemeen Stinst,Shtinshtedt,Shtinshtet,shi ting shi te,Штинштедт,Штинштет,施廷施特', 53.6611600, 8.9723200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31382, 'Stimpfach', 'Stimpfach', 'Shtimpfakh,shi ting pu fa,shutimupufahha,Штимпфах,Штімпфах,シュティムプファッハ,施廷普法', 49.0613500, 10.0927400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31383, 'Steyerberg', 'Steyerberg', 'Shtajerberg,Staarbarg,Steyerberg,shi tai ai er bei ge,shutaiaberuku,Штайерберг,Штајерберг,シュタイアーベルク,施泰埃尔贝格', 52.5701700, 9.0242300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31384, 'Stettfeld', 'Stettfeld', '', 49.9718700, 10.7238600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31385, 'Stetten am Kalten Markt', 'Stetten am Kalten Markt', '', 48.1241900, 9.0777500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31386, 'Stetten', 'Stetten', '', 49.6694400, 8.0919400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31387, 'Stetten', 'Stetten', '', 48.0238200, 10.4447400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31388, 'Stetten', 'Stetten', '', 47.6901200, 9.2985500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31389, 'Sterup', 'Sterup', 'Sterup', 54.7265000, 9.7357200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31390, 'Sternenfels', 'Sternenfels', 'Shternenfel''s,Shternenfels,Sternenfels,shi te er nen fei er si,Штерненфелс,Штерненфельс,Շտերնենֆելս,施特尔嫩费尔斯', 49.0513900, 8.8508300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31391, 'Sternberg', 'Sternberg', 'Shternberg,Sternberga,ashtrnbrg,shi te er en bei er ge,Šternberga,Штернберг,اشترنبرگ,施特尔恩贝尔格', 53.7123600, 11.8267800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31392, 'Sterley', 'Sterley', 'Sterley', 53.6166700, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31393, 'Stephansposching', 'Stephansposching', 'Shtefansposhing,Shtepkhansposhing,ashtfanspwshyng,shi te fan si bo xing,Штепханспошинг,Штефанспошинг,Շտեֆանսփոշինգ,اشتفانسپوشینگ,施特凡斯波兴', 48.8166700, 12.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31394, 'Stephanskirchen', 'Stephanskirchen', 'Shtefanskirkhen,Shtepkhanskirkhen,Stefanskirxen,Stephanskircha,ashtfans kyrshn,shi te fan si ji er xing,Штепханскирхен,Штефанскирхен,Штефанскірхен,Շտեֆանսկիրխեն,اشتفانس کیرشن,施特凡斯基尔兴', 47.8538900, 12.1856000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31395, 'Stepfershausen', 'Stepfershausen', 'Shtepferskhauzen,Stepfershausen,shi te pu fei er si hao sen,Штепферсхаузен,施特普费尔斯豪森', 50.6000000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31396, 'Stendal', 'Stendal', 'Hansestadt Stendal,Shtendal,Shtendal'',Stendal,Stendal'',Stendalia,Stendalis,ZSN,ashtndl,shi teng da er,shtndal,syutendal,Štendalis,Стендаль,Штендал,Штендаль,שטנדאל,اشتندل,شتندال,施滕达尔,슈텐달', 52.6069000, 11.8586700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31397, 'Stemshorn', 'Stemshorn', 'Shtemskhorn,shi te mu si huo er en,Штемсхорн,施特姆斯霍尔恩', 52.4500000, 8.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31398, 'Stemmen', 'Stemmen', '', 53.2242300, 9.5531300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31399, 'Stelzenberg', 'Stelzenberg', '', 49.3775600, 7.7381400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31400, 'Stellingen', 'Stellingen', '', 53.5922000, 9.9287000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31401, 'Stelle-Wittenwurth', 'Stelle-Wittenwurth', 'Stelle-Wittenwurth', 54.2666700, 9.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31402, 'Stelle', 'Stelle', '', 53.3841600, 10.1113800, 'DE', '2011-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31403, 'Steißlingen', 'Steisslingen', 'Shtajslingen,shi tai si lin gen,Штайслинген,Штайслінген,Штајслинген,施泰斯林根', 47.8000000, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31404, 'Stein-Wingert', 'Stein-Wingert', '', 50.7225000, 7.7408300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31405, 'Steinwiesen', 'Steinwiesen', 'Shtajnvisen,Shtajnvizen,Steinwiesen,shi tai yin wei sen,shutain''vu~izen,Штайнвизен,Штайнвізен,Штајнвисен,Շթայնվիզեն,シュタインヴィーゼン,施泰因维森', 50.2944400, 11.4629500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31406, 'Steinwenden', 'Steinwenden', '', 49.4570800, 7.5272600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31407, 'Steinweiler', 'Steinweiler', 'Shtajnvajler,shi tai yin wei lei,Штайнвайлер,Штајнвајлер,施泰因韦勒', 49.1211100, 8.1413900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31408, 'Steinsfeld', 'Steinsfeld', 'Shtajnsfel''d,Shtajnsfeld,Staynsfeld,shi tai yin si fei er de,shutainsuferuto,Штайнсфельд,Штајнсфелд,Շտայնսֆելդ,シュタインスフェルト,施泰因斯费尔德', 49.4166700, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31409, 'Steinsdorf', 'Steinsdorf', '', 50.7500000, 12.0500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31410, 'Steinsberg', 'Steinsberg', '', 50.3333300, 7.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31411, 'Stein-Neukirch', 'Stein-Neukirch', 'Neukirch,Stein-Neukirch', 50.6761100, 8.0547200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31412, 'Steinmauern', 'Steinmauern', 'Shtajnmauehrn,Shtajnmauern,shi tai yin mao ai er en,Штайнмауерн,Штайнмауэрн,Штајнмауерн,施泰因毛埃尔恩', 48.9009500, 8.1969200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31413, 'Steinkirchen', 'Steinkirchen', '', 53.5660100, 9.6111100, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31414, 'Steinkirchen', 'Steinkirchen', '', 48.3833300, 12.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31415, 'Steiningen', 'Steiningen', '', 50.1833300, 6.9166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31416, 'Steinigtwolmsdorf', 'Steinigtwolmsdorf', 'Shtajnigtvol''msdorf,Shtajnigtvolmsdorf,Shtajniktvolmsdorf,Steinigtwolmsdorfi vald,Wolbramecy,Wołbramecy,shi tai ni ge te wo er mu si duo fu,Штайнигтвольмсдорф,Штайнігтвольмсдорф,Штајнигтволмсдорф,Штајниктволмсдорф,施泰尼格特沃尔姆斯多夫', 51.0631400, 14.3454000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31417, 'Steinhorst', 'Steinhorst', '', 53.7166700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31418, 'Steinhorst', 'Steinhorst', '', 52.6833300, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31419, 'Steinhöring', 'Steinhoring', 'Shtajngering,Shtajnkhering,Shtajnkhjoring,Stoanaring,ashtayn hwryng,shi tai yin he ling,Штайнгерінг,Штайнхёринг,Штајнхеринг,اشتاین هورینگ,施泰因赫灵', 48.0867900, 12.0314000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31420, 'Steinhöfel', 'Steinhofel', 'Chateau de Steinhoefel,Château de Steinhöfel,Shtajnkhefel,Shtajnkhjofel'',Staynhyofel,Steinhoefel,Steinhöfel,shi tai yin he fei er,Штайнхёфель,Штајнхефел,Շտայնհյոֆել,施泰因赫费尔', 52.4000000, 14.1666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31421, 'Steinheuterode', 'Steinheuterode', '', 51.3833300, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31422, 'Steinheim am der Murr', 'Steinheim am der Murr', 'Steinheim,Steinheim am der Murr,Steinheim an der Murr', 48.9682100, 9.2770800, 'DE', '2017-07-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31423, 'Steinheim am Albuch', 'Steinheim am Albuch', 'Shtajngajm-am-Al''bukh,Shtajnkhajm am Albukh,Shtajnkhajm-am-Al''bukh,a er bu he de qu shi tai yin hai mu,Штайнгайм-ам-Альбух,Штайнхайм-ам-Альбух,Штајнхајм ам Албух,阿尔布赫地区施泰因海姆', 48.6909000, 10.0638200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31424, 'Steinheim', 'Steinheim', 'Shtajnkhajm,Staime,ashtaynhaym  wstfaln,shi tai yin hai mu,Штайнхайм,Штајнхајм,اشتاینهایم، وستفالن,施泰因海姆', 51.8706600, 9.0913600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31425, 'Steinheim', 'Steinheim', '', 48.0147300, 10.1608100, 'DE', '2015-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31426, 'Steinheid', 'Steinheid', 'Steinheid', 50.4653800, 11.0826500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31427, 'Steinhausen an der Rottum', 'Steinhausen an der Rottum', 'Shtajngauzen-an-der-Rottum,Shtajnkhauzen an der Rotum,Shtajnkhauzen-an-der-Rottum,luo tu mu he pan shi tai yin hao sen,Штайнгаузен-ан-дер-Роттум,Штайнхаузен-ан-дер-Роттум,Штајнхаузен ан дер Ротум,Շտայնխաուզեն ան դեր Ռոթում,შტაინჰაუზენ-ან-დერ-როტუმი,罗图姆河畔施泰因豪森', 48.0166700, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31428, 'Steinhagen', 'Steinhagen', '', 54.2261600, 12.9886700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31429, 'Steinhagen', 'Steinhagen', 'Steinhagen', 52.0000000, 8.4000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31430, 'Steingaden', 'Steingaden', 'Shtajngaden,Stayngaden,ashtayngadn,shi tai yin jia deng,shutaingaden,Штайнгаден,Штајнгаден,Շտայնգադեն,اشتاینگادن,シュタインガーデン,施泰因加登', 47.7000000, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31431, 'Steinfurt', 'Steinfurt', 'Gorad Shtajnfurt,Shhajnfurt,Shtajnfurt,Staynfurt,Stemmert,ashtaynfwrt,shi tai yin fu er te,shtaynfwrt,Ştaynfurt,Горад Штайнфурт,Штайнфурт,Штајнфурт,Щайнфурт,اشتاینفورت,شتاينفورت,施泰因富尔特', 52.1504500, 7.3366400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31432, 'Steinfeld', 'Steinfeld', '', 54.6000000, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31433, 'Steinfeld', 'Steinfeld', 'Shtajnfel''d,Shtajnfeld,Steinfeld,Штайнфельд,Штајнфелд', 52.5859600, 8.2141700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31434, 'Steinfeld', 'Steinfeld', 'Shtajnfel''d,Shtajnfeld,Штайнфельд,Штајнфелд,Շթայնֆելդ', 49.9527800, 9.6694400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31435, 'Steinfeld', 'Steinfeld', '', 49.0483300, 8.0369400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31436, 'Steineroth', 'Steineroth', '', 50.7603800, 7.8544300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31437, 'Steinenbronn', 'Steinenbronn', 'Shtajnenbron,Shtajnenbronn,Staynenbron,Steinenbronn,shi tai nen bu long,Штайненброн,Штайненбронн,Штајненброн,Շտայնենբրոն,შტაინენბრონი,施泰嫩布龙', 48.6666700, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31438, 'Steinen', 'Steinen', '', 50.5833300, 7.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31439, 'Steinen', 'Steinen', '', 47.6444600, 7.7391400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31440, 'Steinefrenz', 'Steinefrenz', '', 50.4593300, 7.9330700, 'DE', '2017-05-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31441, 'Steineberg', 'Steineberg', '', 50.1833300, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31442, 'Steindorf', 'Steindorf', '', 48.2166700, 11.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31443, 'Steinborn', 'Steinborn', '', 50.0666700, 6.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31444, 'Stein-Bockenheim', 'Stein-Bockenheim', '', 49.7666700, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31445, 'Steinbergkirche', 'Steinbergkirche', 'Shtajnbergkirkhe,Shtajnberkirkhe,Steinbergkirche,Stenbjergkirke,shi tai yin bei ge ji xie,Штайнбергкирхе,Штајнбергкирхе,Штајнберкирхе,施泰因贝格基谢', 54.7546300, 9.7606900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31446, 'Steinberg', 'Steinberg', '', 54.7666700, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31447, 'Steinberg', 'Steinberg', '', 49.2833300, 12.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31448, 'Stein', 'Stein', 'Stein,Stein bei Nuernberg,Stein bei Nürnberg', 49.4158100, 11.0159900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31449, 'Steinbach-Hallenberg', 'Steinbach-Hallenberg', 'Kurort Steinbach-Hallenberg,Shtajnbakh-Khalenberg,Shtajnbakh-Khallenberg,Steinbach-Hallenberg,ashtaynbakh-halnbrg,shi tai yin ba he-ha lun bei ge,shtaynbakh-halnbrgh,Штайнбах-Халленберг,Штајнбах-Халенберг,اشتاینباخ-هالنبرگ,شتاينباخ-هالنبرغ,施泰因巴赫-哈伦贝格', 50.6962400, 10.5654100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31450, 'Steinbach am Taunus', 'Steinbach am Taunus', 'Steinbach,Steinbach (Taunus),Steinbach am Taunus', 50.1677400, 8.5727800, 'DE', '2017-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31451, 'Steinbach am Donnersberg', 'Steinbach am Donnersberg', '', 49.6000000, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31452, 'Steinbach', 'Steinbach', 'Steinbach (Eichsfeld)', 51.4221200, 10.2186600, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31453, 'Steinbach', 'Steinbach', 'Steinbach', 50.8332100, 10.3639300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31454, 'Steinbach', 'Steinbach', '', 50.1532800, 11.6505500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31455, 'Steinbach', 'Steinbach', '', 50.0333300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31456, 'Steinau', 'Steinau', '', 53.6833300, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31457, 'Steinau an der Straße', 'Steinau an der Strasse', 'Shtajnau an der Shtrase,Shtajnau-an-der-Shtrase,Steinau,Steinau an der Strasse,Steinau an der Straße,ashtaynaw an dr ashtrash,shi tai nao an de er shi te la sai,Штайнау-ан-дер-Штрасе,Штајнау ан дер Штрасе,اشتایناو آن در اشتراسه,シュタイナウ・アン・デア・シュトラーセ,施泰瑙安德尔施特拉塞', 50.3140100, 9.4633500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31458, 'Steinalben', 'Steinalben', '', 49.3166700, 7.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31459, 'Steinach', 'Steinach', 'Steinach', 50.4312900, 11.1590900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31460, 'Steinach', 'Steinach', '', 48.9541700, 12.6070900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31461, 'Steinach', 'Steinach', 'Steinach', 48.3000000, 8.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31462, 'Steina', 'Steina', 'Niedersteina,Steina', 51.2000000, 14.0500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31463, 'Stein', 'Stein', '', 54.4166700, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31464, 'Steimel', 'Steimel', '', 50.6166700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31465, 'Steimbke', 'Steimbke', 'Shtajmbke,shi tai yin bu ke,shutainpuke,Штаймбке,Штајмбке,シュタインプケ,施泰因布克', 52.6548300, 9.3909100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31466, 'Steilshoop', 'Steilshoop', '', 53.6102800, 10.0591700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31467, 'Steigra', 'Steigra', 'Steigra', 51.3000000, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31468, 'Stiefenhofen', 'Stiefenhofen', 'Shtifengofen,Shtifenkhofen,Steifenhofen,Stiefenhofen,shi di fen huo fen,Штифенхофен,Штіфенгофен,Շթիֆենհոֆեն,施蒂芬霍芬', 47.5932000, 10.0036500, 'DE', '2011-07-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31469, 'Steglitz', 'Steglitz Bezirk', 'Berlin-Steglitz,Shteglic,Штеглиц', 52.4560600, 13.3320000, 'DE', '2013-03-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31470, 'Stegen', 'Stegen', 'Shtegen,Steeen,Steeën,shi te gen,Штеген,施特根', 47.9833300, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31471, 'Stegaurach', 'Stegaurach', 'Shtegaurakh,Stegaurax,shi te gao la,shutegauraha,Штегаурах,Շտեգաուրախ,シュテーガウラハ,施特高拉', 49.8654300, 10.8438500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31472, 'Steffeln', 'Steffeln', '', 50.2833300, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31473, 'Steenfeld', 'Steenfeld', 'Steenfeld', 54.1500000, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31474, 'Steeden', 'Steeden', 'Steeden', 50.4153900, 8.1274800, 'DE', '2013-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31475, 'Stedten', 'Stedten', 'Stedten', 51.4430800, 11.6929100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31476, 'Stedesdorf', 'Stedesdorf', 'Shtedesdorf,shi te de si duo fu,Штедесдорф,施特德斯多夫', 53.6333300, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31477, 'Stedesand', 'Stedesand', 'Staeaesoenj,Stedesand,Stääsönj', 54.7386000, 8.9275500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31478, 'Stebach', 'Stebach', '', 50.5166700, 7.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31479, 'Staufenberg', 'Staufenberg', 'Staufenberg', 50.6619700, 8.7315800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31480, 'Staufen', 'Staufen', '', 47.7568600, 8.2107800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31481, 'Staudt', 'Staudt', '', 50.4666700, 7.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31482, 'Staudernheim', 'Staudernheim', 'Shtaudernkhajm,shi tao de er en hai mu,Штаудернхайм,Штаудернхајм,施陶德尔恩海姆', 49.7767500, 7.6889000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31483, 'Staudach-Egerndach', 'Staudach-Egerndach', '', 47.7833300, 12.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31484, 'Stauchitz', 'Stauchitz', 'Shtaukhic,Stauchitzi vald,shi tao xi ci,Штаухиц,Штаухіц,施陶希茨', 51.2435000, 13.2143700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31485, 'Staßfurt', 'Stassfurt', 'Shtasfurt,Stadt Stassfurt,Stadt Staßfurt,Stassfurt,Staßfurt,ashtasfwrt,shi ta si fu er te,shtasfwrt,Штасфурт,اشتاسفورت,شتاسفورت,施塔斯富尔特', 51.8518600, 11.5850800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31486, 'Starnberg', 'Starnberg', 'Gorad Shtarnberg,Shharnberg,Shtarnberg,Starenberg,Starnberg,Starnberga,ashtarnbrg,shi ta en bei ge,shtarnbrgh,syutaleunbeleukeu,Štarnberga,Горад Штарнберг,Штарнберг,Щарнберг,اشتارنبرگ,شتارنبرغ,施塔恩贝格,슈타른베르크', 48.0019300, 11.3441600, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31487, 'Starkenburg', 'Starkenburg', '', 49.9666700, 7.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31488, 'Stapelfeld', 'Stapelfeld', '', 53.6000000, 10.2166700, 'DE', '2011-08-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31489, 'Stapelburg', 'Stapelburg', 'Stapelburg', 51.9007500, 10.6624000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31490, 'Stangheck', 'Stangheck', 'Stangheck', 54.7166700, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31491, 'Standenbühl', 'Standenbuehl', '', 49.6000000, 7.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31492, 'Stanau', 'Stanau', 'Stanau', 50.7833300, 11.7333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31493, 'Stamsried', 'Stamsried', 'Shtamsrid,Stamsried,shi ta mu si li de,Штамсрид,Штамсрід,Շթամսրիդ,施塔姆斯里德', 49.2675500, 12.5305100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31494, 'Stammham', 'Stammham', '', 48.8557700, 11.4553600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31495, 'Stammham', 'Stammham', '', 48.2960400, 11.8696100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31496, 'Stammham', 'Stammham', '', 48.2500000, 12.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31497, 'Stammbach', 'Stammbach', 'Shtambakh,Shtammbakh,Stammbach,shi tan ba he,shutamubahha,Штамбах,Штаммбах,シュタムバッハ,施坦巴赫', 50.1455100, 11.6912900, 'DE', '2013-04-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31498, 'Stallwang', 'Stallwang', 'Shtal''vang,Shtalvang,ashtalwang,shi ta er wang,Шталванг,Штальванг,اشتالوانگ,施塔尔旺', 49.0509700, 12.6550000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31499, 'Stallwang', 'Stallwang', '', 48.5583800, 12.2310800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31500, 'Stakendorf', 'Stakendorf', 'Stakendorf', 54.3887000, 10.4234200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31501, 'Staig', 'Staig', 'Shtajg,Stayg,shi tai xi,Штайг,Штајг,Շտայգ,შტაიგი,施泰希', 48.2999800, 9.9913800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31502, 'Stahnsdorf', 'Stahnsdorf', 'Shtansdorf,Stahnsdorf,Stansdorf,shi ta en si duo fu,Штансдорф,Շտանսդորֆ,施塔恩斯多夫', 52.3833300, 13.2166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31503, 'Stahlhofen', 'Stahlhofen', '', 50.3938900, 7.8594400, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31504, 'Stahlberg', 'Stahlberg', '', 49.6666700, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31505, 'Stafstedt', 'Stafstedt', 'Stafstedt', 54.1666700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31506, 'Staffhorst', 'Staffhorst', '', 52.7166700, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31507, 'Bad Staffelstein', 'Bad Staffelstein', 'Bad Shtafelshtajn,Bad-Shtaffel''shtajn,Staffelstein,ba te shi ta fu er shi tai yin,bad shtaflshtayn,Бад Штафелштајн,Бад-Штаффельштайн,Բադ Շտաֆելշթայն,باد اشتافل‌اشتاین,باد شتافلشتاين,بیڈ سٹیفلسٹین,バート・シュタッフェルシュタイン,巴特施塔弗尔施泰因', 50.1019900, 11.0012800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31508, 'Stadum', 'Stadum', 'Shtadum,Staarem,Stadum,Ståårem,shi ta du mu,Штадум,施塔杜姆', 54.7333300, 9.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31509, 'Stadt Wehlen', 'Stadt Wehlen', 'Shhat Velen,Shtadt-Velen,Shtat Velen,Statvelene,ashtat wlhn,shi ta te wei lun,shtat fyhln,Štatvēlene,Штадт-Велен,Штат Велен,Щат Велен,اشتات ولهن,شتات فيهلن,施塔特韦伦', 50.9582100, 14.0309100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31510, 'Stadtsteinach', 'Stadtsteinach', 'Shtadtshtajnakh,Shtatshtajnakh,Stadtsteinach,shi ta ci tai na,shtatshtaynakh,shutattoshutainaha,Штадтштайнах,Штатштајнах,Շթաթշթայնախ,اشتات‌اشتایناخ,شتاتشتايناخ,シュタットシュタイナハ,施塔茨泰纳', 50.1643300, 11.5034900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31511, 'Stadtroda', 'Stadtroda', 'Shtadtroda,Shtatroda,Stadtroda,shi ta te luo da,shtatrwda,Штадтрода,Штатрода,اشتات‌رودا,شتاترودا,施塔特罗达', 50.8568400, 11.7267700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31512, 'Stadtprozelten', 'Stadtprozelten', 'Shtadtprocel''ten,Shtatprocelten,Stadtprozelten,shi ta te pu luo ce er teng,shtatbrwtsltn,shutattopurotsu~eruten,Штадтпроцельтен,Штатпроцелтен,Շթաթպրոցելտեն,اشتات‌پرتسلتن,شتاتبروتسلتن,シュタットプロツェルテン,施塔特普罗策尔滕', 49.7846600, 9.4118400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31513, 'Stadtoldendorf', 'Stadtoldendorf', 'Shtadtol''dendorf,Shtatoldendorf,Stadtoldendorf,shi ta tuo deng duo fu,shtatwldndwrf,shutattoorudendorufu,Штадтольдендорф,Штатолдендорф,اشتات‌اولدندورف,شتاتولدندورف,シュタットオルデンドルフ,施塔托登多夫', 51.8824200, 9.6265000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31514, 'Stadtlohn', 'Stadtlohn', 'Shtadtlon,Shtatlon,Stadtlohn,shi ta te luo en,shtatlwn,Штадтлон,Штатлон,اشتات‌لون,شتاتلون,施塔特洛恩', 51.9939900, 6.9191800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31515, 'Stadtlengsfeld', 'Stadtlengsfeld', 'Lengsfeld,Shtadtlengsfel''d,Shtatlengsfeld,Stadtlengsfeld,shi ta te lun si fei er de,shtatlnghzfld,sttlngspld,Штадтленгсфельд,Штатленгсфелд,שטטלנגספלד,اشتات‌لنگزفلد,شتاتلنغزفلد,施塔特伦斯费尔德', 50.7832900, 10.1291800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31516, 'Stadtlauringen', 'Stadtlauringen', 'Shtadtlauringen,Shtatlauringen,Stadtlauringen,ashtat lwryngn,shi ta te lao lin gen,Штадтлауринген,Штадтлаурінген,Штатлауринген,اشتات لورینگن,施塔特劳林根', 50.1870800, 10.3616400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31517, 'Stadtkyll', 'Stadtkyll', 'Shtadtkill'',Shtatkil,shi ta te ji er,Штадткилль,Штаткил,施塔特基尔', 50.3500000, 6.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31518, 'Stadtilm', 'Stadtilm', 'Shhadtilm,Shtadtil''m,Shtatilm,Stadtilm,shi ta di er mu,shtatylm,Штадтильм,Штатилм,Щадтилм,اشتات‌ایلم,شتاتيلم,施塔蒂尔姆', 50.7759600, 11.0826200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31519, 'Stadthagen', 'Stadthagen', 'Shhadtkhagen,Shtadtkhagen,Shtatkhagen,shtathaghn,shutattohagen,si ta de ha gen,Штадтхаген,Штатхаген,Щадтхаген,اشتات‌هاگن,شتاتهاغن,シュタットハーゲン,斯塔德哈根', 52.3233300, 9.2031100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31520, 'Stadtbergen', 'Stadtbergen', 'Shtadtbergen,Shtatbergen,Stadbergen,Stadtbergen,Stadtberger,shi ta te bei er gen,shtatbrghn,Штадтберген,Штатберген,Շտադբերգեն,اشتات‌برگن,شتاتبرغن,施塔特贝尔根', 48.3664100, 10.8463600, 'DE', '2015-07-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31521, 'Stadtallendorf', 'Stadtallendorf', 'Shtadtallendorf,Shtatalendorf,Stadtallendorf,shi ta te a lun duo fu,shtatalndwrf,shutattoarendorufu,Штадталлендорф,Штаталендорф,اشتات‌آلندورف,شتاتالندورف,シュタットアレンドルフ,施塔特阿伦多夫', 50.8226100, 9.0129400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31522, 'Stadlern', 'Stadlern', 'Shtadlern,ashtadlrn,shi ta de lai er en,Штадлерн,اشتادلرن,施塔德莱尔恩', 49.5066200, 12.6123900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31523, 'Stadensen', 'Stadensen', '', 52.8757100, 10.5561900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31524, 'Stadelhofen', 'Stadelhofen', 'Shtadel''gofen,Shtadel''khofen,Shtadelkhofen,Stadelhofen,shi ta de er huo fen,shutaderuhofen,Штаделхофен,Штадельгофен,Штадельхофен,Շտադելհոֆեն,シュターデルホーフェン,施塔德尔霍芬', 50.0031700, 11.1975700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31525, 'Stade', 'Stade', 'Gemeen Stood,Shhade,Shtade,Stade,ashtdth,shi ta de,shtadh,shutade,Штаде,Щаде,اشتدته,شتاده,シュターデ,施塔德', 53.5933700, 9.4762900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31526, 'Stäbelow', 'Staebelow', 'Stabelow,Staebelow,Stäbelow', 54.0411900, 12.0233600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31527, 'Staaken', 'Staaken', 'Berlin-Staaken,Staaken', 52.5366100, 13.1505700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31528, 'Sprötau', 'Sproetau', 'Sproetau,Sprötau', 51.1246100, 11.1965200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31529, 'Sprockhövel', 'Sprockhoevel', 'Hasslinghausen,Haßlinghausen,Shprokkhevel,Shprokkhjofel'',Sprockhoevel,Sprockhovel,Sprockhövel,ashprwkhawl,shbrwkhwfl,shi pu luo he fu,Шпрокхевел,Шпрокхёфель,اشپروکهاول,شبروكهوفل,施普洛和弗', 51.3466900, 7.2434300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31530, 'Springstille', 'Springstille', 'Springstille', 50.6871600, 10.5281600, 'DE', '2012-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31531, 'Springe', 'Springe', 'Shpringe,Springe,Stadt Springe,ashpryngh,shbrynghh,shi pu lin ge,Шпринге,Шпрінге,اشپرینگه,شبرينغه,施普林格', 52.2084500, 9.5541600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31532, 'Sprendlingen', 'Sprendlingen', 'Shprendlingen,shi pu lun de lin gen,shupurentoringen,Шпрендлинген,シュプレントリンゲン,施普伦德林根', 49.8666700, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31533, 'Spreenhagen', 'Spreenhagen', 'Shprenkhagen,Sprenhagen,shi pu lun ha gen,Шпренхаген,Շպրենհագեն,施普伦哈根', 52.3432500, 13.8766300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31534, 'Sprakensehl', 'Sprakensehl', 'Shprakensel,Shprakenzel'',shi pu la ken sai er,Шпракензель,Шпракенсел,施普拉肯塞尔', 52.7666800, 10.4917700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31535, 'Sprakebüll', 'Sprakebuell', 'Sprakebull,Sprakebüll', 54.7833300, 9.0833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31536, 'Spraitbach', 'Spraitbach', 'Shprajtbakh,shi pu lai te ba he,Шпрайтбах,Шпрајтбах,შპრაიტბახი,施普赖特巴赫', 48.8806500, 9.7621700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31537, 'Spornitz', 'Spornitz', 'Shpornic,shi bo er ni ci,Шпорниц,施波尔尼茨', 53.4074900, 11.7186400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31538, 'Sponheim', 'Sponheim', '', 49.8449600, 7.7266500, 'DE', '2011-07-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31539, 'Spirkelbach', 'Spirkelbach', '', 49.2000000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31540, 'Spiesheim', 'Spiesheim', '', 49.8102800, 8.1275000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31541, 'Spiesen-Elversberg', 'Spiesen-Elversberg', 'Shpisen-Elversberg,Shpizen-Ehl''versberg,Shpizen-El''fersberg,ashpyzn-alfrsbrg,shi pi sen-ai er fei er si bei er ge,shupizen=eruvu~erusuberuku,Шпизен-Эльверсберг,Шписен-Елверсберг,Шпізен-Ельферсберг,اشپیزن-الفرسبرگ,シュピーゼン＝エルヴェルスベルク,施皮森-埃尔费尔斯贝尔格', 49.3166700, 7.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31542, 'Spiekeroog', 'Spiekeroog', 'Shpikerog,Spiekerooch,Spikereach,sbykyrawkh,shi pi ke luo ge,Шпикерог,سبيكيرأوخ,შპიკეროოგი,施皮克罗格', 53.7701200, 7.6948100, 'DE', '2012-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31543, 'Spiegelberg', 'Spiegelberg', 'Shpigel''berg,Shpigelberg,shi pi ge er bei ge,Шпигелберг,Шпигельберг,Шпігельберг,施皮格尔贝格', 49.0408300, 9.4444400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31544, 'Speyer', 'Speyer', 'Espira,Gorad Shpaer,Schbaya,Shpaer,Shpajer,Shpejer,Spaier,Speyer,Spira,Spire,Spyr,ZQC,ashpyr,ch pi xexr,shi pai er,shupaia,spyyr,syupaieo,Špýr,Σπάιερ,Горад Шпаер,Шпайер,Шпаєр,Шпајер,Шпейер,שפייר,اشپیر,ชไปเออร์,ስፓየር,シュパイアー,施派尔,슈파이어', 49.3208300, 8.4311100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31545, 'Spessart', 'Spessart', '', 50.4397700, 7.1104300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31546, 'Spesenroth', 'Spesenroth', '', 50.0500000, 7.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31547, 'Spergau', 'Spergau', 'Spergau', 51.2934700, 12.0229200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31548, 'Sperenberg', 'Sperenberg', '', 52.1411300, 13.3650000, 'DE', '2012-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31549, 'Spenge', 'Spenge', 'Spenge', 52.1402100, 8.4847500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31550, 'Spelle', 'Spelle', 'Shpele,Shpelle,Spelle,shi pei lai,Шпеле,Шпелле,施佩莱', 52.3666700, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31551, 'Speinshart', 'Speinshart', 'Shpajnsgart,Shpajnskhart,shi pai yin si ha er te,Шпайнсгарт,Шпайнсхарт,Шпајнсхарт,Շպայնսհարթ,施派因斯哈尔特', 49.7900200, 11.8194900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31552, 'Speichersdorf', 'Speichersdorf', 'Shpajkhersdorf,Spayhersdorf,shi pai xie er si duo fu,shupaihyasudorufu,Шпайхерсдорф,Шпајхерсдорф,Շպայհերսդորֆ,シュパイヒャースドルフ,施派歇尔斯多夫', 49.8713300, 11.7812300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31553, 'Speicher', 'Speicher', '', 49.9333300, 6.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31554, 'Spechbach', 'Spechbach', 'Schbeeschbach,Shpekhbakh,shi pei xi ba he,shupehibahha,Шпехбах,シュペヒバッハ,施佩希巴赫', 49.3463900, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31555, 'Spatzenhausen', 'Spatzenhausen', '', 47.7166700, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31556, 'Sparneck', 'Sparneck', 'Shparnek,Sparneck,ashparnk,shi pa er nei ke,shuparunekku,Шпарнек,اشپارنک,シュパルネック,施帕尔内克', 50.1621400, 11.8434900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31557, 'Spardorf', 'Spardorf', 'Shpardorf,shi pa er duo fu,shuparudorufu,Шпардорф,シュパールドルフ,施帕尔多夫', 49.6085400, 11.0558500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31558, 'Spangenberg', 'Spangenberg', 'Shpangenberg,Spangenberg,ashpangnbrg,shbanghnbrgh,shi pan gen bei ge,shupangenberuku,Шпангенберг,اشپانگنبرگ,شبانغنبرغ,シュパンゲンベルク,施潘根贝格', 51.1164400, 9.6627000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31559, 'Spangdahlem', 'Spangdahlem', 'SPM', 49.9833300, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31560, 'Spalt', 'Spalt', 'Shpal''t,Shpalt,ashpalt,shbalt,shi pa er te,shuparuto,Шпалт,Шпальт,Շփալթ,اشپالت,شبالت,シュパルト,施帕尔特', 49.1755300, 10.9245300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31561, 'Spall', 'Spall', '', 49.8833300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31562, 'Spaichingen', 'Spaichingen', 'Shpajkhingen,Spaichingen,ashpayshyngn,shbayshynghn,shi pai xin gen,Шпайхинген,Шпајхинген,اشپایشینگن,شبايشينغن,施派欣根', 48.0747700, 8.7350800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31563, 'Spabrücken', 'Spabrucken', 'Shpabriken,Shpabrjukken,Spabruecken,Spabrücken,shi pa bu lu ken,Шпабрикен,Шпабрюккен,施帕布吕肯', 49.9000000, 7.7166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31564, 'Soyen', 'Soyen', 'Zoen,Zojen,Zoyen,suo yi en,zwyn,Зойен,Зоєн,Зојен,Զոյեն,زوین,索伊恩', 48.1080800, 12.2100600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31565, 'Sottrum', 'Sottrum', 'Soettmer,Sottrum,Söttmer,Zotrum,suo te lu mu,zottorumu,Зотрум,ゾットルム,索特鲁姆', 53.1166700, 9.2333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31566, 'Sosberg', 'Sosberg', '', 50.0833300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31567, 'Sosa', 'Sosa', '', 50.4991700, 12.6512000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31568, 'Sörup', 'Sorup', 'Soerup,Sorup,Sörup,Sørup,Zerup,Zjorup,se lu pu,Зеруп,Зёруп,瑟鲁普', 54.7166700, 9.6666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31569, 'Sörth', 'Sorth', '', 50.7000000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31570, 'Sörgenloch', 'Sorgenloch', '', 49.8830600, 8.2011100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31571, 'Sören', 'Soeren', 'Soren,Sören', 54.2000000, 10.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31572, 'Sophienhamm', 'Sophienhamm', 'Sophienhamm', 54.2833300, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31573, 'Sontra', 'Sontra', 'Sontra,Zontra,song te la,zontora,zwntra,Зонтра,زونترا,ゾントラ,松特拉', 51.0717100, 9.9355800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31574, 'Sonthofen', 'Sonthofen', 'Sonthofen,Zontgofen,Zonthofen,Zontkhofen,song te huo fen,zwnthwfn,Зонтгофен,Зонтхофен,Զոնտհոֆեն,زونتهوفن,松特霍芬', 47.5182100, 10.2826200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31575, 'Sontheim an der Brenz', 'Sontheim an der Brenz', 'Sontheim', 48.5523500, 10.2909700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31576, 'Sontheim', 'Sontheim', '', 48.0070400, 10.3546100, 'DE', '2012-10-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31577, 'Sonsbeck', 'Sonsbeck', 'Sonsbeck,Zonsbek,song si bei ke,Зонсбек,松斯贝克', 51.6074100, 6.3791600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31578, 'Sonnschied', 'Sonnschied', '', 49.8166700, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31579, 'Sonnewalde', 'Sonnewalde', 'Grozisco,Groźišćo,Sonnewalde,Zonevalde,Zonneval''de,suo nei wa er de,znnwald,zwnhfaldt,Зоневалде,Зонневальде,Զոնևալդե,زننوالد,زونهفالدة,索内瓦尔德', 51.6922300, 13.6473000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31580, 'Sonnenberg-Winnenberg', 'Sonnenberg-Winnenberg', '', 49.6666700, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31581, 'Sonnenberg', 'Sonnenberg', '', 53.0191700, 13.0884100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31582, 'Sonnen', 'Sonnen', 'Zonen,Zonnen,suo nen,zwnn,Зонен,Зоннен,Զոնեն,زونن,索嫩', 48.6833300, 13.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31583, 'Sonnefeld', 'Sonnefeld', 'Zonefeld,Zonnefel''d,suo nei fei er de,zon''neferuto,Зонефелд,Зоннефельд,Զոնեֆելդ,ゾンネフェルト,索内费尔德', 50.2166700, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31584, 'Sönnebüll', 'Sonnebull', 'Sonnebull,Sönnebüll', 54.6333300, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31585, 'Sonneborn', 'Sonneborn', '', 50.9927000, 10.5917300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31586, 'Sonneberg', 'Sonneberg', 'Sonneberg,Stadt Sonneberg,Zoneberg,Zonneberg,suo nei bei ge,zon''neberuku,zwnbrg,zwnhbrgh,Зонеберг,Зоннеберг,زونبرگ,زونهبرغ,ゾンネベルク,索内贝格', 50.3592000, 11.1746300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31587, 'Sondheim vor der Rhön', 'Sondheim vor der Rhoen', 'Sondheim', 50.4651000, 10.1567500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31588, 'Sondershausen', 'Sondershausen', 'Sondershausen,Zonderskhauzen,song de er si hao sen,zwndrshawzn,zwndrzhawzn,Зондерсхаузен,זונדרסהאוזן,زوندرزهاوزن,زوندرسهاوزن,松德尔斯豪森', 51.3697300, 10.8701100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31589, 'Sonderhofen', 'Sonderhofen', '', 49.5931300, 10.0024500, 'DE', '2012-10-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31590, 'Sommersdorf', 'Sommersdorf', 'Zomersdorf,Zommersdorf,suo mei er si duo fu,Зомерсдорф,Зоммерсдорф,索梅尔斯多夫', 52.1666700, 11.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31591, 'Sommerloch', 'Sommerloch', '', 49.8772700, 7.7599500, 'DE', '2011-09-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31592, 'Sommerland', 'Sommerland', 'Sommerland', 53.8036000, 9.5374800, 'DE', '2011-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31593, 'Sommerkahl', 'Sommerkahl', 'Zomerkal,Zommerkal'',suo mei er ka er,zonmakaru,Зомеркал,Зоммеркаль,Զոմերկալ,ゾンマーカール,索梅尔卡尔', 50.0696100, 9.2567600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31594, 'Sommerhausen', 'Sommerhausen', 'Zomerhauzen,Zomerkhauzen,Zommergauzen,Zommerkhauzen,suo mei lao sen,zonmahauzen,Зомерхаузен,Зоммергаузен,Зоммерхаузен,Զոմերհաուզեն,ゾンマーハウゼン,索梅劳森', 49.7036100, 10.0260500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31595, 'Sömmerda', 'Soemmerda', 'Soemmerda,Sommerda,Sömmerda,Z''omerda,Zemerda,Zjommerda,se mei er da,swmrdaw,zwmrda,Земерда,Зьомерда,Зёммерда,Зөммерда,زومردا,سومرداو,瑟梅尔达', 51.1591400, 11.1152400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31596, 'Sommerau', 'Sommerau', '', 49.7166700, 6.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31597, 'Sommerach', 'Sommerach', 'Zomerakh,Zomerax,Zommerakh,suo mei la,Зомерах,Зоммерах,Զոմերախ,索梅拉', 49.8292300, 10.2079200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31598, 'Soltendieck', 'Soltendieck', 'Zol''tendik,Zoltendik,suo er teng di ke,Золтендик,Зольтендик,索尔滕迪克', 52.8736900, 10.7616200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31599, 'Soltau', 'Soltau', 'Gemeen Soltau,Soltau,Zol''tau,Zoltau,joltau,suo er tao,zorutau,zwataw,zwltaw,Золтау,Зольтау,زواتاو,زولتاو,ゾルタウ,索尔陶,졸타우', 52.9863800, 9.8433800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31600, 'Solnhofen', 'Solnhofen', 'Solnhofa,Zol''ngofen,Zol''nkhofen,Zolnhofen,Zolnkhofen,suo er en huo fen,Золнхофен,Зольнгофен,Зольнхофен,Զոլնհոֆեն,索尔恩霍芬', 48.8958200, 10.9956000, 'DE', '2012-10-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31601, 'Sollwitt', 'Sollwitt', 'Sollwitt', 54.6000000, 9.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31602, 'Sollstedt', 'Sollstedt', 'Sollstedt,Zol''shtedt,Zolshtet,suo er si te,Золштет,Зольштедт,索尔斯特', 51.4166700, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31603, 'Sollstedt', 'Sollstedt', '', 51.3097600, 10.4881000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31604, 'Söllingen', 'Sollingen', 'Soellingen,Söllingen', 52.0898400, 10.9252200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31605, 'Sollerup', 'Sollerup', 'Sollerup', 54.5833300, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31606, 'Solkwitz', 'Solkwitz', 'Solkwitz', 50.7000000, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31607, 'Solingen', 'Solingen', 'Gorad Zolingen,Solich,Solingen,ZIO,Zolin''nken,Zolingen,Zolingenas,Zolingene,jolling-gen,so ling ngein,suo lin gen,swlngn,zolingeni,zoringen,zwlynghn,zwlyngn,Ζόλινγκεν,Горад Золінген,Золинген,Золінген,זולינגן,زولينغن,زولینگن,سولنگن,โซลิงเงิน,ზოლინგენი,ゾーリンゲン,索林根,졸링겐', 51.1734300, 7.0845000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31608, 'Sölden', 'Solden', '', 47.9333300, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31609, 'Sohrschied', 'Sohrschied', '', 49.9000000, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31610, 'Sohren', 'Sohren', 'Zoren,suo lun,Зорен,索伦', 49.9333300, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31611, 'Söhlde', 'Sohlde', 'Soehlde,Söhlde,Zelde,Zjol''de,se he er de,Зелде,Зёльде,瑟赫尔德', 52.1889800, 10.2323900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31612, 'Sohland am Rotstein', 'Sohland am Rotstein', 'Sohland,Sohland am Rotstein', 51.1164300, 14.7837200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31613, 'Sohland', 'Sohland', '', 51.0408900, 14.4189700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31614, 'Sögel', 'Sogel', 'Soegel,Suugel,Sögel,Zegel,Zjogel'',se ge er,Зегел,Зёгель,瑟格尔', 52.8500000, 7.5166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31615, 'Soest', 'Soest', 'Gorad Zost,Saust,Soest,Zest,Zoest,Zost,suo si te,zosuto,zwyst  alman,Горад Зост,Зест,Зоест,Зост,زوئست، آلمان,ゾースト,索斯特', 51.5755800, 8.1061900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31616, 'Soderstorf', 'Soderstorf', 'Zoderstorf,suo de er si tuo fu,Зодерсторф,索德尔斯托夫', 53.1427500, 10.1480700, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31617, 'Södel', 'Soedel', '', 50.3938200, 8.8047400, 'DE', '2017-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31618, 'Söchtenau', 'Sochtenau', 'Soechtenau,Söchtenau', 47.9311800, 12.2295900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31619, 'Sitzendorf', 'Sitzendorf', 'Sitzendorf', 50.6318200, 11.1721500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31620, 'Sitters', 'Sitters', '', 49.7166700, 7.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31621, 'Sittensen', 'Sittensen', 'Zitensen,Zittens,Zittenzen,jittenzen,xi teng sen,Зитенсен,Зиттензен,ジッテンゼン,西滕森', 53.2761500, 9.5042900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31622, 'Sirksfelde', 'Sirksfelde', 'Sirksfelde', 53.6666700, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31623, 'Sipplingen', 'Sipplingen', 'Sipplingen,Ziplingen,Zipplingen,xi pu lin gen,Зиплинген,Зипплинген,Зіпплінген,Զիփլինգեն,ზიპლინგენი,西普林根', 47.7967800, 9.0973700, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31624, 'Sippersfeld', 'Sippersfeld', '', 49.5500000, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31625, 'Sinzing', 'Sinzing', 'Sinzing,Zincing,syntsyng,xin qin ge,Зинцинг,Зінцинг,Զինցինգ,سینتسینگ,辛钦格', 49.0000000, 12.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31626, 'Sinzig', 'Sinzig', 'Sentiacum,Sinzig,Zincig,Zincigas,jintsu~ihhi,xin qi xi,zyntsyg,zyntsygh,Зинциг,زينتسيغ,زینتسیگ,ジンツィッヒ,辛齐希', 50.5438400, 7.2463900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31627, 'Sinzheim', 'Sinzheim', 'Zincgajm,Zinckhajm,xin ci hai mu,Зинцхайм,Зинцхајм,Зінцгайм,辛茨海姆', 48.7666700, 8.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31628, 'Sinspelt', 'Sinspelt', '', 49.9725900, 6.3181700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31629, 'Sinsheim', 'Sinsheim', 'Sinse,Zinsgajm,Zinsheimas,Zinskhajm,jinseuhaim,jinsuhaimu,synshaym,xin si hai mu,zynshaym,Зинсхайм,Зинсхајм,Зінсгайм,زینسهایم,سينسهايم,ジンスハイム,辛斯海姆,진스하임', 49.2529000, 8.8786700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31630, 'Sinnersdorf', 'Sinnersdorf', '', 51.0244500, 6.8178700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31631, 'Sinn', 'Sinn', 'Sinn,Zin,Zinn,Зин,Зинн', 50.6500000, 8.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31632, 'Singhofen', 'Singhofen', '', 50.2744000, 7.8333300, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31633, 'Singen', 'Singen', 'Zingen,singena,xin gen,zynghn,zyngn,Зинген,Зінген,زينغن,زینگن,सिंगेन,辛根', 47.7593500, 8.8403000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31634, 'Sindelsdorf', 'Sindelsdorf', '', 47.7245800, 11.3329500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31635, 'Sindelfingen', 'Sindelfingen', 'Sindelfingen,ZPZ,Zindel''fingen,Zindelfingen,Zintelfinken,jinderufingen,xin de er fen gen,zindelpingeni,zyndlfynghn,zyndlfyngn,Ζίντελφιγκεν,Зинделфинген,Зиндельфинген,Зіндельфінген,Զինդելֆինգեն,زيندلفينغن,زیندلفینگن,ზინდელფინგენი,ジンデルフィンゲン,辛德尔芬根', 48.7000000, 9.0166700, 'DE', '2012-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31636, 'Simonsberg', 'Simonsberg', '', 54.4335500, 8.9769200, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31637, 'Simmozheim', 'Simmozheim', '', 48.7512700, 8.8114200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31638, 'Simmershofen', 'Simmershofen', 'Zimershofen,Zimerskhofen,Zimmersgofen,Zimmerskhofen,xi mei er si huo fen,Зимерсхофен,Зиммерсхофен,Зіммерсгофен,Զիմերսհոֆեն,西梅尔斯霍芬', 49.5333300, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31639, 'Simmersfeld', 'Simmersfeld', 'Zimersfeld,Zimmersfel''d,xi mei er si fei er de,Зимерсфелд,Зиммерсфельд,Зіммерсфельд,Զիմերսֆելդ,西梅尔斯费尔德', 48.6166700, 8.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31640, 'Simmern', 'Simmern', '', 50.3891400, 7.6739600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31641, 'Simmern', 'Simmern', 'Simmern,Simmern/ Hunsrueck,Simmern/ Hunsrück,Simmern/Hunsrueck,Simmern/Hunsrück,Zimern,Zimmern,xi mei er en,zymrn,Зимерн,Зиммерн,زیمرن,西梅尔恩', 49.9819800, 7.5235100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31642, 'Simmertal', 'Simmertal', 'Simmern,Simmertal,Zimertal,Zimmertal'',xi mei er ta er,Зимертал,Зиммерталь,西梅尔塔尔', 49.8098100, 7.5228200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31643, 'Simmerath', 'Simmerath', 'Simmerath,Soemmert,Sömmert,Zimerat,Zimmerat,Zoemmert,Zömmert,xi mo la te,Зимерат,Зиммерат,Зіммерат,锡默拉特', 50.6000000, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31644, 'Simmelsdorf', 'Simmelsdorf', '', 49.5977500, 11.3390100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31645, 'Simbach am Inn', 'Simbach am Inn', 'Ini Zimbax,Simbach,Simbach am Inn,Simboch am Inn,Zimbakh am In,Zimbakh-am-Inn,Zimbakh-na-Inne,jimbaheuam-in,yin he pan xin ba he,zymbakh am an,zymbakh am ayn,Зимбах ам Ин,Зимбах-ам-Инн,Зимбах-на-Инне,Зімбах-ам-Інн,Ինի Զիմբախ,زيمباخ آم إن,زیمباخ آم این,因河畔辛巴赫,짐바흐암인', 48.2654800, 13.0230900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31646, 'Simbach', 'Simbach', 'Markt Simbach,Simbach,Simpach,Zimbakh,Zimbax,symbakh,Зимбах,Зімбах,Զիմբախ,سیمباخ', 48.5660600, 12.7388800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31647, 'Silzen', 'Silzen', 'Silzen', 54.0333300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31648, 'Silz', 'Silz', '', 49.1500000, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31649, 'Sillenstede', 'Sillenstede', 'Celensteda [a. 1138],Sillenstae,Sillenstä', 53.5743700, 7.9850000, 'DE', '2011-03-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31650, 'Silbitz', 'Silbitz', 'Silbitz,Zil''bic,Zilbic,xi er bi ci,Зилбиц,Зильбиц,西尔比茨', 50.9500000, 12.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31651, 'Silberstedt', 'Silberstedt', 'Silberstedt', 54.5166700, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31652, 'Silberhausen', 'Silberhausen', 'Silberhausen', 51.3108400, 10.3396000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31653, 'Sigmarszell', 'Sigmarszell', 'Zigmarscel,Zigmarscell'',xi ge ma er si ce er,Зигмарсцел,Зигмарсцелль,Зігмарсцелль,Զիգմարսցել,西格马尔斯策尔', 47.5833300, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31654, 'Sigmaringendorf', 'Sigmaringendorf', 'Zigmaringendorf,xi ge ma lin gen duo fu,Зигмарингендорф,Зігмарінгендорф,锡格马林根多夫', 48.0658600, 9.2620800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31655, 'Sigmaringen', 'Sigmaringen', 'Gorad Zigmaryngen,Sigmaringa,Sigmaringen,Zigmaringen,xi ge ma lin gen,zygmaryngn,zygmryngn,Горад Зігмарынген,Зигмаринген,זיגמרינגן,زیگمارینگن,西格马林根', 48.0882900, 9.2303300, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31656, 'Siggelkow', 'Siggelkow', 'Zigelkov,Ziggel''kov,xi ge er ke,Зиггельков,Зигелков,锡格尔科', 53.3874200, 11.9380200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31657, 'Sieverstedt', 'Sieverstedt', 'Sieverstedt', 54.6414500, 9.4694900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31658, 'Sievershütten', 'Sievershuetten', 'Sievershutten,Sievershütten', 53.8423800, 10.1121600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31659, 'Siesbach', 'Siesbach', '', 49.7333300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31660, 'Siersleben', 'Siersleben', 'Siersleben,Zirsleben,Зирслебен', 51.6041100, 11.5433400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31661, 'Siershahn', 'Siershahn', 'Zirskhan,xi er si ha en,Зирсхан,西尔斯哈恩', 50.4863900, 7.7797200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31662, 'Siersdorf', 'Siersdorf', '', 50.8982700, 6.2268400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31663, 'Sierscheid', 'Sierscheid', '', 50.4570700, 6.9174400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31664, 'Sierksrade', 'Sierksrade', 'Sierksrade', 53.7333300, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31665, 'Sierksdorf', 'Sierksdorf', 'Sierksdorf,Zirksdorf,xi er ke si duo fu,Зирксдорф,锡尔克斯多夫', 54.0666700, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31666, 'Sienhachenbach', 'Sienhachenbach', '', 49.7000000, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31667, 'Sien', 'Sien', 'Zin,Зин', 49.6947200, 7.5041600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31668, 'Siemerode', 'Siemerode', 'Selmanroth [a. 1055]', 51.4228100, 10.1206400, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31669, 'Siemensstadt', 'Siemensstadt', 'Berlin-Siemensstadt', 52.5405300, 13.2629400, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31670, 'Sielenbach', 'Sielenbach', 'Sialabo,Zilenbakh,Zilenbax,jirenbahha,xi lun ba,Зиленбах,Зіленбах,Զիլենբախ,ジーレンバッハ,西伦巴', 48.4000000, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31671, 'Siek', 'Siek', '', 53.6333300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31672, 'Siegsdorf', 'Siegsdorf', 'Siagsdorf,Zigsdorf,xi ge si duo fu,zygsdwrf,Зигсдорф,Зігсдорф,Զիգսդորֆ,زیگسدورف,锡格斯多夫', 47.8227800, 12.6427700, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31673, 'Siegenburg', 'Siegenburg', 'Siegenburg,Sigenburg,Zigenburg,xi gen bao,Зигенбург,Зігенбург,Զիգենբուրգ,西根堡', 48.7542100, 11.8483100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31674, 'Siegen', 'Siegen', 'SGE,Siegen,Zigen,jigen,Зиген,ジーゲン', 50.8748100, 8.0243100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31675, 'Siegelsbach', 'Siegelsbach', 'Zigel''sbakh,Zigelsbakh,jigerusubahha,xi ge er si ba he,Зигелсбах,Зигельсбах,Зігельсбах,ジーゲルスバッハ,西格尔斯巴赫', 49.2697200, 9.0897200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31676, 'Siegburg', 'Siegburg', 'Sieburch,Siegburg,Siegburgum,ZPY,Zigburg,Ziqburq,jikuburuku,xi ge bao,zigburg,zygbwrg,zyghbwrgh,Зигбург,Зігбург,זיגבורג,زيغبورغ,زیگبورگ,ジークブルク,锡格堡', 50.8001900, 7.2076900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31677, 'Siefersheim', 'Siefersheim', '', 49.8000000, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31678, 'Siedenburg', 'Siedenburg', 'Sie''enborg,Sie’enborg,Zidenburg,xi deng bao,Зиденбург,西登堡', 52.6929300, 8.9396100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31679, 'Siebeneichen', 'Siebeneichen', '', 53.5109200, 10.6181100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31680, 'Siebenbäumen', 'Siebenbaumen', 'Siebenbaeumen,Siebenbaumen,Siebenbäumen', 53.7500000, 10.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31681, 'Siebenbach', 'Siebenbach', '', 50.3833300, 7.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31682, 'Siebeldingen', 'Siebeldingen', '', 49.2088900, 8.0513900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31683, 'Sickerode', 'Sickerode', 'Sickerode', 51.2500000, 10.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31684, 'Sickenhausen', 'Sickenhausen', '', 48.5325200, 9.1811400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31685, 'Sibbesse', 'Sibbesse', 'Sibbesse,Zibbesse,Zibese,xi bei sai,Зиббессе,Зибесе,西贝塞', 52.0500000, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31686, 'Seyda', 'Seyda', '', 51.8816300, 12.9081200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31687, 'Seybothenreuth', 'Seybothenreuth', 'Zajbotenrojt,Zejbotenrojt,Zeybotenroyt,sai bo teng luo yi te,zaibotenroito,Зайботенройт,Зајботенројт,Зейботенройт,Զեյբոտենրոյտ,ザイボーテンロイト,赛博滕罗伊特', 49.8937200, 11.7053100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31688, 'Sexau', 'Sexau', 'Sexau,Zeksau,sai ke shao,Зексау,Զեքսաու,塞克绍', 48.1020900, 7.9075700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31689, 'Seulingen', 'Seulingen', 'Zojlingen,suo yi lin gen,zoiringen,Зойлинген,Зојлинген,ゾイリンゲン,索伊林根', 51.5412900, 10.1626300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31690, 'Seukendorf', 'Seukendorf', '', 49.4884400, 10.8799900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31691, 'Seubersdorf', 'Seubersdorf', '', 49.1621200, 11.6271400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31692, 'Setzingen', 'Setzingen', '', 48.5381500, 10.1302500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31693, 'Seth', 'Seth', 'Seth', 53.8471800, 10.1742100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31694, 'Seßlach', 'Sesslach', 'Sesslach,Seßlach,Zeslakh,Zeslax,sai si la,zesuraha,zslakh,Зеслах,Զեսլախ,زسلاخ,ゼスラハ,塞斯拉', 50.1896900, 10.8419700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31695, 'Sessenhausen', 'Sessenhausen', '', 50.5272000, 7.7136500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31696, 'Sessenbach', 'Sessenbach', '', 50.4769400, 7.6444400, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31697, 'Sersheim', 'Sersheim', 'Zersgajm,Zerskhajm,sai er si hai mu,srshaym,Зерсгайм,Зерсхайм,Зерсхајм,سرسهایم,塞尔斯海姆', 48.9666700, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31698, 'Serrig', 'Serrig', 'Zerig,Zerrig,sai li xi,Зериг,Зерриг,塞里希', 49.5751900, 6.5745400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31699, 'Serba', 'Serba', 'Serba', 50.9500000, 11.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31700, 'Sensweiler', 'Sensweiler', '', 49.7753900, 7.1969000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31701, 'Senscheid', 'Senscheid', '', 50.3333300, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31702, 'Sennfeld', 'Sennfeld', 'Zenfel''d,Zenfeld,Zennfel''d,sen fei er de,znfld,Зеннфельд,Зенфелд,Зенфельд,زنفلد,森费尔德', 50.0389500, 10.2598600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31703, 'Sennewitz', 'Sennewitz', '', 51.5432600, 11.9521800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31704, 'Senheim', 'Senheim', 'Zenkhajm,sen hai mu,Зенхайм,Зенхајм,森海姆', 50.0833300, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31705, 'Sengerich', 'Sengerich', '', 50.1166700, 6.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31706, 'Sengenthal', 'Sengenthal', 'Zengental,Zengental'',sen gen ta er,Зенгентал,Зенгенталь,Զենգենթալ,森根塔尔', 49.2333300, 11.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31707, 'Senftenberg', 'Senftenberg', 'Senftenberg,Zenftenberg,Zenftenbergas,Zly Komorow,Zły Komorow,jenpeutenbeleukeu,sen fu teng bei ge,znftnbrg,znftnbyrgh,Зенфтенберг,Զենֆտենբերգ,زنفتنبرگ,زنفتنبيرغ,森夫滕贝格,젠프텐베르크', 51.5251700, 14.0016400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31708, 'Sendenhorst', 'Sendenhorst', 'Sendenhorst', 51.8430300, 7.8299600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31709, 'Senden', 'Senden', 'Senden', 51.8564500, 7.4832700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31710, 'Senden', 'Senden', '', 48.3244100, 10.0444200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31711, 'Semmenstedt', 'Semmenstedt', '', 52.0937500, 10.6969100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31712, 'Sembach', 'Sembach', 'Zembakh,Зембах', 49.5117700, 7.8666100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31713, 'Selzen', 'Selzen', '', 49.8605600, 8.2552800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31714, 'Selters', 'Selters', '', 50.5325300, 7.7557700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31715, 'Selters', 'Selters', '', 50.5168100, 8.2895300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31716, 'Selsingen', 'Selsingen', '', 53.3732900, 9.2128900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31717, 'Selmsdorf', 'Selmsdorf', 'Selmsdorf,Zel''msdorf,Zelmsdorf,sai er mu si duo fu,Зелмсдорф,Зельмсдорф,塞尔姆斯多夫', 53.8822400, 10.8599700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31718, 'Selm', 'Selm', 'Selm,Siaelm,Siälm,Stadt Selm,Zel''m,Zelm,sai er mu,zlm,zylm,Зелм,Зельм,زلم,زيلم,塞尔姆', 51.6968900, 7.4680900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31719, 'Sellin', 'Sellin', '', 53.8849500, 11.6079000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31720, 'Sellerich', 'Sellerich', '', 50.2333300, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31721, 'Selk', 'Selk', 'Selk,Zel''k,Zelk,Зелк,Зельк', 54.4666700, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31722, 'Seligenstadt', 'Seligenstadt', 'Gorad Zeligenshtat,Zeligenshhat,Zeligenshtadt,Zeligenshtat,sai li gen si ta te,zerigenshutatto,zylynghnshtat,Горад Зелігенштат,Зелигенштадт,Зелигенштат,Зелигенщат,Зелігенштадт,زلینگن‌اشتات,زيلينغنشتات,ゼーリゲンシュタット,塞利根斯塔特', 50.0432000, 8.9739400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31723, 'Selent', 'Selent', 'Selent', 54.2889300, 10.4270200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31724, 'Selchenbach', 'Selchenbach', 'Zel''khenbakh,Zelkhenbakh,sai er xing ba he,Зелхенбах,Зельхенбах,塞尔兴巴赫', 49.5000000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31725, 'Selbitz', 'Selbitz', 'Selbitz', 50.3170200, 11.7501900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31726, 'Selb', 'Selb', 'Zel''b,Zelb,sai er bu,zerupu,zlb,zylb,Зелб,Зельб,Զելբ,זלב,زلب,زيلب,ゼルプ,塞尔布', 50.1705800, 12.1305400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31727, 'Seiwerath', 'Seiwerath', '', 50.1500000, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31728, 'Seitenroda', 'Seitenroda', 'Seitenroda', 50.8000000, 11.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31729, 'Seisla', 'Seisla', '', 50.6502800, 11.5348300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31730, 'Seinsheim', 'Seinsheim', 'Zajnsgajm,Zajnskhajm,Zaynshaym,sai yin si hai mu,Зайнсгайм,Зайнсхайм,Зајнсхајм,Զայնսհայմ,赛因斯海姆', 49.6407300, 10.2203800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31731, 'Seinsfeld', 'Seinsfeld', '', 50.0500000, 6.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31732, 'Seifhennersdorf', 'Seifhennersdorf', 'Seifhennersdorf,Wodowe Hendrichecy,Zajfkhenersdorf,Zajfkhennersdorf,Zaruz,Zaruž,Zeifhennersdorfa,sai fu hei nei er si duo fu,zayfhnrsdwrf,zayfnrzdwrf,Зайфхенерсдорф,Зайфхеннерсдорф,Зајфхенерсдорф,زايفهنرسدورف,زایفنرزدورف,赛夫黑内尔斯多夫', 50.9349200, 14.6019400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31733, 'Seifen', 'Seifen', '', 50.6833300, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31734, 'Seifen', 'Seifen', '', 50.6333300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31735, 'Seibersbach', 'Seibersbach', '', 49.9666700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31736, 'Sehnde', 'Sehnde', 'Seinje,Senede [a. 1216],Senethe [a. 1147],Zende,sai en de,zndh,zyndt,Зенде,زنده,زيندة,塞恩德', 52.3139400, 9.9682000, 'DE', '2014-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31737, 'Sehlen', 'Sehlen', '', 54.3797100, 13.3890700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31738, 'Sehlem', 'Sehlem', '', 52.0123600, 9.9759300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31739, 'Sehlem', 'Sehlem', '', 49.9000000, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31740, 'Sehlde', 'Sehlde', 'Zelde,sai er de,Зелде,塞尔德', 52.0388700, 10.2656900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31741, 'Sehestedt', 'Sehestedt', 'Zeehshtedt,Zeeshtet,Zeshtet,sai hei si te,Зеештет,Зештет,Зеэштедт,塞黑斯特', 54.3666700, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31742, 'Segnitz', 'Segnitz', 'Zegnic,sai ge ni ci,Зегниц,Зегніц,Զեգնից,塞格尼茨', 49.6724100, 10.1441600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31743, 'Seggebruch', 'Seggebruch', '', 52.3005000, 9.0946200, 'DE', '2011-07-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31744, 'Sefferweich', 'Sefferweich', '', 50.0666700, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31745, 'Seffern', 'Seffern', '', 50.0666700, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31746, 'Seevetal', 'Seevetal', 'Seevedaal,Zefetal,Zevetal'',sai fei ta er,Зеветаль,Зефетал,סיווטאל,塞费塔尔', 53.4000000, 9.9666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31747, 'Seeth-Ekholt', 'Seeth-Ekholt', 'Seeth-Ekholt', 53.7413000, 9.7300200, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31748, 'Seeth', 'Seeth', 'Saed,Seet,Sæd,Zet,Зет', 54.3666700, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31749, 'Seestermühe', 'Seestermuhe', 'Seestermuehe,Seestermuhe,Seestermühe,Zestermie,Zestermikhe,Zestermjueh,sai si te er mi hei,Зестермие,Зестермихе,Зестермюэ,塞斯特尔米黑', 53.7000000, 9.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31750, 'Seester', 'Seester', 'Seester,Zester,sai si te er,Зестер,塞斯特尔', 53.7178300, 9.5979800, 'DE', '2011-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31751, 'Seeshaupt', 'Seeshaupt', 'Zeeskhaupt,Zesgaupt,Zeskhaupt,Zeyeshaupt,sai si hao pu te,zesuhauputo,zyshawpt,Зеесхаупт,Зесгаупт,Зесхаупт,Զեյեսհաուպտ,زیسهاوپت,ゼースハウプト,塞斯豪普特', 47.8246800, 11.3021900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31752, 'Seesen', 'Seesen', 'Seesen,Sesa,Zezen,sai sen,zyzn,Зезен,زيزن,زیزن,塞森', 51.8909500, 10.1784700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31753, 'Seesbach', 'Seesbach', '', 49.8453600, 7.5466500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31754, 'Seelze', 'Seelze', 'Seelze,Zel''ce,Zelce,sai er ce,zyltsh,Зелце,Зельце,زيلتسه,زیلتسه,塞尔策', 52.3963500, 9.5972700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31755, 'Seelow', 'Seelow', 'Zelov,jello,sai luo,zerou gao de,Зелов,زی‌لو,ゼーロウ高地,塞洛,젤로', 52.5339200, 14.3812800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31756, 'Seelitz', 'Seelitz', 'Seelitzi vald,Zelic,sai li ci,Зелиц,塞利茨', 51.0333300, 12.8166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31757, 'Seelingstädt', 'Seelingstaedt', 'Seelingstaedt,Seelingstaedt-Bahnhof,Seelingstädt,Seelingstädt-Bahnhof,Zelingshtedt,Zelingshtet,sai ling shi tai te,Зелингштедт,Зелингштет,塞灵施泰特', 50.7726600, 12.2436100, 'DE', '2017-07-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31758, 'Seelen', 'Seelen', '', 49.6000000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31759, 'Seelbach', 'Seelbach', '', 50.3166700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31760, 'Seelbach', 'Seelbach', 'Seelbach', 48.3105500, 7.9406900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31761, 'Seekirch', 'Seekirch', 'Zeekirkh,Zeekirx,Zekirkh,sai ji er xi,Зеекирх,Зекирх,Зекірх,Զեեկիրխ,ზეეკირხი,塞基尔希', 48.1000000, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31762, 'Seehof', 'Seehof', '', 53.6924900, 11.4325600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31763, 'Seehausen am Staffelsee', 'Seehausen am Staffelsee', 'Seehausen a. Staffelsee,Seehausen am Staffesee,Zeekhauzen-am-Shtaffel''zee,Zegauzen-am-Shtaffel''ze,Zekhauzen am Shtafelze,Zeyhauzen am Stafelzey,shi ta fu er hu pan sai hao sen,zyhawzn,Зегаузен-ам-Штаффельзе,Зеехаузен-ам-Штаффельзее,Зехаузен ам Штафелзе,Զեյհաուզեն ամ Շտաֆելզեյ,زیهاوزن,施塔弗尔湖畔塞豪森', 47.6892800, 11.1849800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31764, 'Seehausen', 'Seehausen', 'Seehausen', 52.8887200, 11.7523600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31765, 'Seehausen', 'Seehausen', 'Seehausen,Seehausen (Boerde),Seehausen (Börde),Seehusen,Sehusen,Zekhauzen,Zekhauzen (Berde),Зехаузен,Зехаузен (Берде)', 52.1028700, 11.2915300, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31766, 'Seeg', 'Seeg', 'Zeg,sai ge,zeku,Зег,Զեգ,ゼーク,塞格', 47.6500000, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31767, 'Seefeld', 'Seefeld', '', 54.0997700, 9.4931000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31768, 'Seefeld', 'Seefeld', '', 48.0350500, 11.2139500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31769, 'Seedorf', 'Seedorf', 'Zedorf,Зедорф', 54.0500000, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31770, 'Seedorf', 'Seedorf', '', 53.6197000, 10.8659900, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31771, 'Seedorf', 'Seedorf', 'Seedoerp,Seedörp,Zedorf,zedorufu,Зедорф,ゼードルフ', 53.3500000, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31772, 'Seedorf', 'Seedorf', '', 48.2490800, 8.4899300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31773, 'Seeburg', 'Seeburg', '', 51.5666700, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31774, 'Seebergen', 'Seebergen', 'Seebergen,Zebergen,Zeebergen,Зеберген,Зееберген', 50.9207700, 10.7992000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31775, 'Seebad Heringsdorf', 'Seebad Heringsdorf', 'Heringsdorf,Seebad Heringsdorf', 53.9537900, 14.1685200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31776, 'Seebad Bansin', 'Seebad Bansin', 'Bansin,Bansin/Insel Usedom,Seebad Bansin', 53.9710200, 14.1414700, 'DE', '2016-01-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31777, 'Seebach', 'Seebach', '', 51.1650600, 10.5142800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31778, 'Seebach', 'Seebach', 'Seebach', 50.9166700, 10.4166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31779, 'Seebach', 'Seebach', '', 48.5762100, 8.1704800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31780, 'Seckach', 'Seckach', 'Seckach,Zekakh,Zekkakh,sai ka,zekkaha,Зеках,Зекках,ゼッカハ,塞卡', 49.4422200, 9.3341700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31781, 'Seck', 'Seck', '', 50.5772200, 8.0497200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31782, 'Sebnitz', 'Sebnitz', 'Zebnic,Zebnica,sai bu ni ci,zbnyts,Зебниц,زبنيتس,زبنیتس,塞布尼茨', 50.9754000, 14.2757900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31783, 'Schwörstadt', 'Schworstadt', 'Schwoerstadt,Schwörstadt,Shvershtadt,Shvershtat,Shvjorshtadt,shi wei er si ta te,Шверштадт,Шверштат,Швёрштадт,施韦尔斯塔特', 47.5931400, 7.8784000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31784, 'Schwollen', 'Schwollen', '', 49.7056900, 7.1746200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31785, 'Schwobfeld', 'Schwobfeld', 'Schwobfeld', 51.2833300, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31786, 'Schwissel', 'Schwissel', 'Schwissel', 53.9000000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31787, 'Schwirzheim', 'Schwirzheim', '', 50.2333300, 6.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31788, 'Schwindegg', 'Schwindegg', 'Shvindeg,Shvindegg,Svindeg,shi wen de ge,shwyndg,Швиндег,Швиндегг,Швіндегг,Շվինդեգ,شویندگ,施温德格', 48.2715500, 12.2597800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31789, 'Schwifting', 'Schwifting', 'Shvifting,shi wei fu ting,shuvu~ifutingu,shwyftyng,Швифтинг,Швіфтінг,Շվիֆթինգ,شویفتینگ,シュヴィフティング,施维夫廷', 48.0455500, 10.9276200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31790, 'Schwieberdingen', 'Schwieberdingen', 'Shviberdingen,shi wei bei er ding gen,shwybrdyngn,swwybrdyngn,Швибердинген,Швібердінген,שוויברדינגן,شویبردینگن,施维贝尔丁根', 48.8764400, 9.0743900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31791, 'Schwetzingen', 'Schwetzingen', 'Schwetzinge,Schwetzingen,Shvecingen,Shvetcingen,shftsynghn,shi wei qing gen,shuvu~etsu~ingen,shwtsyngn,Шветцинген,Швецинген,شفتسينغن,شوتسینگن,シュヴェツィンゲン,施韦青根', 49.3821700, 8.5823000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31792, 'Schwesing', 'Schwesing', 'Schwesing', 54.4948200, 9.1350400, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31793, 'Schwerte', 'Schwerte', 'Schweierte,Schwerte,Shverte,Sverte,ZPX,shfyrth,shi wei te,shwrth,Švertė,Шверте,شفيرته,شورته,施韦特', 51.4438700, 7.5675000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31794, 'Schwerstedt', 'Schwerstedt', '', 51.1557800, 10.9207000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31795, 'Schwerstedt', 'Schwerstedt', '', 51.0666700, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31796, 'Schwerinsdorf', 'Schwerinsdorf', '', 53.3103900, 7.6605000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31797, 'Schweringen', 'Schweringen', 'Shveringen,Swering,shi wei lin gen,shuvu~eringen,Шверинген,シュヴェリンゲン,施韦林根', 52.7500000, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31798, 'Schwerin', 'Schwerin', 'Gorad Shveryn,SZW,Schwerin,Shverin,Shverini,Suerinum,Sverin,Sverinas,Sverine,Swerin,Zwerin,Zwěrin,ch weri n,shen wei lin,shfyryn,shuvu~erin,shwryn,sverina,swwryn,syubelin,Šverinas,Šverīne,Σβερίν,Горад Шверын,Шверин,Шверін,Շվերին,שוורין,شفيرين,شورین,श्वेरिन,ชเวริน,シュヴェリーン,什未林,슈베린', 53.6293700, 11.4131600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31799, 'Schwerin', 'Schwerin', '', 52.1500000, 13.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31800, 'Schwerbach', 'Schwerbach', '', 49.9000000, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31801, 'Schweppenhausen', 'Schweppenhausen', '', 49.9266500, 7.7997100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31802, 'Schwepnitz', 'Schwepnitz', 'Schwepnitzi vald,Sepicy,Shvepnic,shi wei pu ni ci,Швепниц,施韦普尼茨', 51.3280900, 13.9577200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31803, 'Schwenningen', 'Schwenningen', '', 48.6500000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31804, 'Schwenningen', 'Schwenningen', '', 48.1000000, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31805, 'Schwendi', 'Schwendi', '', 48.1742400, 9.9754100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31806, 'Schwelm', 'Schwelm', 'Schwelm,Shvel''m,Shvelm,shfylm,shi wei er mu,shwlm,Швелм,Швельм,شفيلم,شولم,施韦尔姆', 51.2863500, 7.2938800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31807, 'Schweix', 'Schweix', '', 49.1333300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31808, 'Schweitenkirchen', 'Schweitenkirchen', 'Schweinkiacha,Shvajtenkirkhen,shi wei teng ji er xing,shwaytn kyrshn,Швайтенкирхен,Швайтенкірхен,Швајтенкирхен,Շվայթենկիրխեն,شوایتن کیرشن,施魏滕基尔兴', 48.5033300, 11.6045100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31809, 'Schweisweiler', 'Schweisweiler', '', 49.5833300, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31810, 'Schweinschied', 'Schweinschied', '', 49.7000000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31811, 'Schweinfurt', 'Schweinfurt', 'Gorad Shvajnfurt,Schweinfurt,Shvajnfurt,Suevofortum,ZPW,shfaynfwrt,shi wei yin fu te,shwaynfwrt,Горад Швайнфурт,Швайнфурт,Швајнфурт,شفاينفورت,شواینفورت,施韦因富特', 50.0493700, 10.2217500, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31812, 'Schweindorf', 'Schweindorf', '', 53.6000000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31813, 'Schweina', 'Schweina', 'Shvajna,shi wei na,Швайна,Швајна,施魏纳', 50.8250200, 10.3378800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31814, 'Schweighofen', 'Schweighofen', '', 49.0398400, 7.9936700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31815, 'Schweighausen', 'Schweighausen', '', 50.2833300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31816, 'Schweich', 'Schweich', 'Schweich,Shvajkh,shfaysh,shi wei xi,shuvu~aihi,shvaikhi,shwaysh,Швайх,Швајх,شفايش,شوایش,შვაიხი,シュヴァイヒ,施魏希', 49.8221500, 6.7525600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31817, 'Schwegenheim', 'Schwegenheim', '', 49.2700000, 8.3286100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31818, 'Schwedt (Oder)', 'Schwedt (Oder)', 'Schwedt,Schwedt/Oder,Stadt Schwedt/Oder', 53.0596300, 14.2815400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31819, 'Schwedelbach', 'Schwedelbach', '', 49.4955700, 7.5936600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31820, 'Schwebheim', 'Schwebheim', 'Shvebgajm,Shvebkhajm,shi wei bu hai mu,shwbhaym,Швебгайм,Швебхайм,Швебхајм,شوبهایم,施韦布海姆', 49.9903600, 10.2477600, 'DE', '2012-09-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31821, 'Schwarzhofen', 'Schwarzhofen', 'Schwarzhofen,Schwoazhof,Shvarcgofen,Shvarckhofen,shi wa er ci huo fen,shwartshwfn,Шварцгофен,Шварцхофен,شوارتسهوفن,施瓦尔茨霍芬', 49.3774900, 12.3449000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31822, 'Schwarzheide', 'Schwarzheide', 'Carny Gozd,Carny Gózd,Schwarzheide,Shvarckhajde,shfartshaydh,shi wa er ci hai de,shwartshaydh,Шварцхайде,Шварцхајде,Շվարցհայդե,شفارتسهايده,شوارتسهایده,施瓦尔茨海德', 51.4767100, 13.8555900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31823, 'Schwarzerden', 'Schwarzerden', 'Shvarcerden,shi wa er ce er deng,Шварцерден,施瓦尔策尔登', 49.8500000, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31824, 'Schwarzenfeld', 'Schwarzenfeld', 'Schwarzenfeld,Shvarcenfel''d,Shvarcenfeld,shi wa er cen fei er de,shwartsnfld,Шварценфелд,Шварценфельд,شوارتسنفلد,施瓦尔岑费尔德', 49.3877400, 12.1348400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31825, 'Schwarzenbruck', 'Schwarzenbruck', 'Schwarzenbruck,Shvarcenbruk,shi wa er cen bu lu ke,Шварценбрук,Շվարցենբրուք,施瓦尔岑布鲁克', 49.3577800, 11.2433300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31826, 'Schwarzenborn', 'Schwarzenborn', 'Schwarzenborn', 50.9097700, 9.4465800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31827, 'Schwarzenborn', 'Schwarzenborn', '', 50.0333300, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31828, 'Schwarzenberg', 'Schwarzenberg', 'Schwarzenberg,Schwarzenberg/Erzgeb.,Shvarcenberg,Svarcenberga/Rudu kalni,shfartsnbrgh,shi wa cen bei ge,shwartsnbrg  zaksn,Švarcenberga/Rūdu kalni,Шварценберг,شفارتسنبرغ,شوارتسنبرگ، زاکسن,施瓦岑贝格', 50.5379100, 12.7852200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31829, 'Schwarzenbek', 'Schwarzenbek', 'Schwarzenbek,Shvarcenbek,shfartsynbk,shi wa cen bei ke,shwartynbk,Шварценбек,شفارتسينبك,شوارتینبک,施瓦岑贝克', 53.5030300, 10.4805500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31830, 'Schwarzenbach an der Saale', 'Schwarzenbach an der Saale', 'Schwarzenbach,Schwarzenbach an der Saale,Shvarcenbakh an der Zale,Shvarcenbakh-an-der-Zaale,Shvarcenbakh-an-der-Zale,Shvarcenbakh-na-Zaale,shfartsnbakh an dr zalh,shwartsnbakh an dr zalh,Шварценбах ан дер Зале,Шварценбах-ан-дер-Заале,Шварценбах-ан-дер-Зале,Шварценбах-на-Заале,شفارتسنباخ أن در زاله,شوارتسنباخ آن در زاله,シュヴァルツェンバッハ・アン・デア・ザーレ', 50.2227900, 11.9350400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31831, 'Schwarzenbach', 'Schwarzenbach', '', 49.8387600, 12.3800500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31832, 'Schwarzenbach', 'Schwarzenbach', '', 49.7246200, 11.9975800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31833, 'Schwarzen', 'Schwarzen', '', 49.9666700, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31834, 'Schwarzburg', 'Schwarzburg', '', 50.6430400, 11.1918900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31835, 'Schwarzbach', 'Schwarzbach', '', 51.4500000, 13.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31836, 'Schwarzbach', 'Schwarzbach', '', 50.7971500, 11.8749300, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31837, 'Spiegelau', 'Spiegelau', 'Schwarzach,Schwarzach mit Spiegelau,Shpigelau,Spiaglau,Spiegelau,Spiegelau mit Schwarzach,ashpyglaw,shi pi ge lao,Шпигелау,Шпігелау,Շփիգելաու,اشپیگلاو,施皮格劳', 48.9151700, 13.3622900, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31838, 'Schwarzach', 'Schwarzach', 'Schwarzach', 48.9156700, 12.8114300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31839, 'Schwarzach', 'Schwarzach', '', 48.7473800, 8.0373800, 'DE', '2013-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31840, 'Schwarza', 'Schwarza', '', 50.8538600, 11.3243300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31841, 'Schwarza', 'Schwarza', '', 50.6192500, 10.5297100, 'DE', '2012-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31842, 'Schwartbuck', 'Schwartbuck', 'Schwartbuck', 54.3575900, 10.4786600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31843, 'Schwarmstedt', 'Schwarmstedt', 'Shvarmshtedt,Shvarmshtet,shi wa er mu si te,Швармштедт,Швармштет,施瓦尔姆斯特', 52.6779400, 9.6176700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31844, 'Schwarme', 'Schwarme', '', 52.9000000, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31845, 'Schwanheim', 'Schwanheim', '', 49.1666700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31846, 'Schwangau', 'Schwangau', 'Schwangau,Shvangau,Швангау', 47.5772200, 10.7341600, 'DE', '2014-08-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31847, 'Schwanfeld', 'Schwanfeld', 'Shvanfel''d,Shvanfeld,shi wan fei er de,shwanfld,Шванфелд,Шванфельд,شوانفلد,施万费尔德', 49.9216600, 10.1386600, 'DE', '2012-09-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31848, 'Schwanewede', 'Schwanewede', 'Gemeen Swonewebel,Schwanewede,Shvanevede,shi wa nei wei de,Шваневеде,施瓦内韦德', 53.2333300, 8.6000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31849, 'Schwanebeck', 'Schwanebeck', 'Schwanebeck,Shvanebek,shfannbk,shi wa nei bei ke,shwannbk,Шванебек,شفاننبك,شواننبک,施瓦内贝克', 51.9679000, 11.1239300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31850, 'Schwandorf in Bayern', 'Schwandorf in Bayern', 'Schwandorf,Schwandorf in Bayern,Stadt Schwandorf', 49.3253400, 12.1098000, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31851, 'Schwalmtal', 'Schwalmtal', 'Schwalmtal', 51.2166700, 6.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31852, 'Schwalmtal', 'Schwalmtal', '', 50.6833300, 9.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31853, 'Schwalmstadt', 'Schwalmstadt', 'Gorad Shval''mshtat,Schwalmstadt,Shval''mshtadt,Shvalmshtat,shi wa er mu si ta te,shuvu~arumushutatto,Горад Швальмштат,Швалмштат,Швальмштадт,شوالم‌اشتات,シュヴァルムシュタット,施瓦尔姆斯塔特', 50.9333300, 9.2166700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31854, 'Schwallungen', 'Schwallungen', 'Schwallungen,Shvallungen,Shvalungen,shi wa lun gen,Шваллунген,Швалунген,施瓦伦根', 50.6926000, 10.3570600, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31855, 'Schwall', 'Schwall', '', 50.1500000, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31856, 'Schwalbach', 'Schwalbach', '', 50.4967200, 8.4694300, 'DE', '2015-09-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31857, 'Schwalbach am Taunus', 'Schwalbach am Taunus', 'Shval''bakh,Shval''bakh-am-Taunus,Shvalbakh am Taunus,shfalbakh am tawnws,shwalbakh am tanws,tao nu si shan lu shi wa er ba he,Швалбах ам Таунус,Швальбах,Швальбах-ам-Таунус,شفالباخ آم تاونوس,شوالباخ آم تانوس,シュヴァルバッハ・アム・タウヌス,陶努斯山麓施瓦尔巴赫', 50.1500000, 8.5333300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31858, 'Schwalbach', 'Schwalbach', '', 49.3000000, 6.8166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31859, 'Schwaikheim', 'Schwaikheim', 'Shvajkgajm,Shvajkkhajm,shi wei ke hai mu,Швайкгайм,Швайкхайм,Швајкхајм,施魏克海姆', 48.8773300, 9.3495800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31860, 'Schwaigern', 'Schwaigern', 'Schwaigern,Shvajgern,shfayghrn,shi wei ge er en,shuvu~aigerun,shwaygrn,Швайгерн,Швајгерн,شفايغرن,شوایگرن,シュヴァイゲルン,施魏格尔恩', 49.1449400, 9.0552500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31861, 'Schwaigen', 'Schwaigen', '', 47.6166700, 11.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31862, 'Schwaig', 'Schwaig', 'Schwaig,Shvajg,Швайг', 49.4695500, 11.2006400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31863, 'Schwaförden', 'Schwaforden', 'Schwafoerden,Schwaförden,Shvaferden,Shvafjorden,Swabern,shi wa fu er deng,Шваферден,Швафёрден,施瓦弗尔登', 52.7377500, 8.8302600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31864, 'Schwabstedt', 'Schwabstedt', 'Schwabstedt,Shvabshtedt,Shvabshtet,Svavsted,Swabstaeae,Swåbstää,shi wa bu si te,Швабштедт,Швабштет,施瓦布斯特', 54.3970500, 9.1864600, 'DE', '2012-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31865, 'Schwabsoien', 'Schwabsoien', 'Shvabzoen,Shvabzojen,Svabzoyen,shi wa bu suo yi en,shuvu~apuzoien,shwabzwyyn,Швабзойен,Швабзоєн,Швабзојен,Շվաբզոյեն,شوابزوئین,シュヴァープゾイエン,施瓦布索伊恩', 47.8333300, 10.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31866, 'Schwabmünchen', 'Schwabmunchen', 'Schwabmuenchen,Schwabmunchen,Schwabmünchen,Shvabminkhen,Shvabmjunkhen,Svabmyunxen,shfabmwnshn,shi wa bu ming xing,shwabmwnshn,Швабминхен,Швабмюнхен,Շվաբմյունխեն,شفابمونشن,شوابمونشن,施瓦布明兴', 48.1792800, 10.7567500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31867, 'Schwäbisch Hall', 'Schwaebisch Hall', 'Hale Suevice,Hall,Halla Suevica,Schwaebisch Hall,Schwäbisch Hall,シュヴェービッシュ・ハル', 49.1112700, 9.7390800, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31868, 'Schwäbisch Gmünd', 'Schwabisch Gmund', 'Gamundia,Gmund,Gmünd,Schwaebisch Gmuend,Schwäbisch Gmünd,Shvebish Gmind,Shvebish Gmjund,Shvebish-Gmjund,Svabijos Gmiundas,chwe bi chk mun d,shfaybysh ghmwnd,shi wa ben ge ming de,shvebish-gmiundi,shwbysh gmwnd,Švabijos Gmiundas,Швебиш Гминд,Швебиш Гмюнд,Швебиш-Гмюнд,Швебіш-Гмюнд,شفايبيش غموند,شوبیش گموند,ชเวบิชกมึนด์,შვებიშ-გმიუნდი,施瓦本格明德', 48.7994700, 9.7980900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31869, 'Schwabhausen', 'Schwabhausen', '', 48.3031800, 11.3557400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31870, 'Schwabhausen', 'Schwabhausen', '', 50.8885000, 10.7310800, 'DE', '2016-02-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31871, 'Schwabhausen', 'Schwabhausen', 'Kleinschwabhausen', 48.4015700, 11.3572900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31872, 'Schwabenheim', 'Schwabenheim', '', 49.9287900, 8.0952500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31873, 'Schwabbruck', 'Schwabbruck', '', 47.8250300, 10.8361900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31874, 'Schwabach', 'Schwabach', 'Gorad Shvabakh,Schwabach,Shvabakh,shi wa ba he,shwabakh,Горад Швабах,Швабах,شواباخ,施瓦巴赫', 49.3304700, 11.0234600, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31875, 'Schwaara', 'Schwaara', 'Schwaara', 50.9034700, 12.1430700, 'DE', '2015-01-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31876, 'Schwaan', 'Schwaan', 'Gorad Shvan,Schwaan,Shvan,Svana,shfan,shi wan,shwan,Švāna,Горад Шван,Шван,شفآن,شوان,施万', 53.9404700, 12.1071500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31877, 'Schutzbach', 'Schutzbach', '', 50.7500000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31878, 'Schutz', 'Schutz', '', 50.1333300, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31879, 'Schüttorf', 'Schuettorf', 'Schuettorf,Schuettrup,Schuttorf,Schüttorf,Schüttrup,Shitorf,Shjuttorf,shwtrtwf,shwtwrf,xu tuo fu,Шиторф,Шютторф,شوترتوف,شوتورف,许托夫', 52.3228100, 7.2217600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31880, 'Schutterwald', 'Schutterwald', 'Shutervald,Shutterval''d,shu te er wa er de,Шутервалд,Шуттервальд,舒特尔瓦尔德', 48.4500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31881, 'Schuttertal', 'Schuttertal', 'Shutertal,Shuttertal'',shu te er ta er,Шутертал,Шуттерталь,舒特尔塔尔', 48.2666700, 7.9500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31882, 'Bad Schussenried', 'Bad Schussenried', 'Bad Schussenried,Bad Shusenrid,Bad Susenrid,Bad-Shussenrid,Schussenried,ba te shu sen li de,bad shwsnryd,bad-shusenridi,Бад Шусенрид,Бад-Шуссенрид,Бад-Шуссенрід,Բադ Շուսենրիդ,باد شوسنريد,باد شوسنرید,ბად-შუსენრიდი,巴特舒森里德', 48.0046800, 9.6574100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31883, 'Schürensöhlen', 'Schurensohlen', 'Schurensohlen,Schürensöhlen', 53.7666700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31884, 'Schürdt', 'Schurdt', '', 50.6666700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31885, 'Schulzendorf', 'Schulzendorf', 'Shul''cendorf,Shulcendorf,shu er cen duo fu,Шулцендорф,Шульцендорф,Շուլցենդորֆ,舒尔岑多夫', 52.3581800, 13.5984200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31886, 'Schülp', 'Schuelp', '', 54.2589600, 9.6303400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31887, 'Schülp', 'Schuelp', '', 54.2426700, 8.9321800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31888, 'Schüller', 'Schuller', 'Schueller,Schüller', 50.3333300, 6.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31889, 'Schülldorf', 'Schulldorf', 'Schuelldorf,Schulldorf,Schülldorf', 54.3000000, 9.7333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31890, 'Schulendorf', 'Schulendorf', '', 53.4732300, 10.5610400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31891, 'Schuld', 'Schuld', '', 50.4476700, 6.8889400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31892, 'Schuby', 'Schuby', 'Schuby', 54.5166700, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31893, 'Schrum', 'Schrum', 'Schrum,Shrum,shi lu mu,Шрум,施鲁姆', 54.1833300, 9.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31894, 'Schrozberg', 'Schrozberg', 'Schrozberg,Shrocberg,shi luo ci bei ge,shrwtsbrg,shrwtsbrgh,shurotsuberuku,Шроцберг,شروتسبرغ,شروتسبرگ,シュロツベルク,施罗茨贝格', 49.3452800, 9.9794400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31895, 'Schrobenhausen', 'Schrobenhausen', 'Schrobenhausen,Shrobengauzen,Shrobenkhauzen,Srobenhauzen,shi luo ben hao sen,shrwbnhawzn,Шробенгаузен,Шробенхаузен,Շրոբենհաուզեն,شروبنهاوزن,شروبن‌هاوزن,施罗本豪森', 48.5606700, 11.2607100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31896, 'Schriesheim', 'Schriesheim', 'Schriesheim,Shrisgajm,Shriskhajm,shi li si hai mu,shryshaym,shryzhaym,shurisuhaimu,Шрисхайм,Шрисхајм,Шрісгайм,شريسهايم,شریزهایم,シュリースハイム,施里斯海姆', 49.4737200, 8.6636000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31897, 'Schrecksbach', 'Schrecksbach', 'Shreksbakh,shi lei ke si ba he,shurekkusubahha,Шрексбах,シュレックスバッハ,施雷克斯巴赫', 50.8333300, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31898, 'Schraplau', 'Schraplau', 'Schraplau,Shraplau,shi la pu lao,shrablaw,shraplaw,Шраплау,شرابلاو,شراپلاو,施拉普劳', 51.4375000, 11.6682300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31899, 'Schramberg', 'Schramberg', 'Shramberg,shi lan bei ge,shrambrg,shrambrgh,Шрамберг,شرامبرغ,شرامبرگ,施兰贝格', 48.2239900, 8.3858300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31900, 'Schraden', 'Schraden', '', 51.4253400, 13.6949500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31901, 'Schotten', 'Schotten', 'Schotten,Shoten,Shotten,shao teng,shotten,shtn,Шотен,Шоттен,شتن,ショッテン,绍滕', 50.5034600, 9.1251600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31902, 'Schortens', 'Schortens', 'Schortens,Shortens,shao er teng si,shrtnz,shwrtnz,Шортенс,شرتنز,شورتنز,绍尔滕斯', 53.5333300, 7.9500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31903, 'Schornsheim', 'Schornsheim', 'Schornsheim,Shornskhajm,shao er en si hai mu,Шорнсхайм,Шорнсхајм,绍尔恩斯海姆', 49.8458300, 8.1750000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31904, 'Schorndorf', 'Schorndorf', '', 49.1604100, 12.5931600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31905, 'Schorndorf', 'Schorndorf', 'Shorndorf,shao en duo fu,shrndwrf,shwrndwrf,Шорндорф,شرندورف,شورندورف,绍恩多夫', 48.8053700, 9.5272100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31906, 'Schöps', 'Schops', 'Schoeps,Schöps', 50.8333300, 11.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31907, 'Schöppingen', 'Schoppingen', 'Schoeppingen,Schöppingen,Shepingen,Sheppingen,Shjoppingen,she ping gen,Шепинген,Шеппінген,Шёппинген,舍平根', 52.1000000, 7.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31908, 'Schöppenstedt', 'Schoeppenstedt', 'Schoeppenstedt,Schoeppenstidde,Schöppenstedt,Schöppenstidde,Shepenshtet,Sheppenshtedt,Shjoppenshtedt,she peng si te,shwbnshtyt,Шепенштет,Шеппенштедт,Шёппенштедт,شوبنشتيت,شوپن‌اشتت,舍彭斯特', 52.1430800, 10.7745000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31909, 'Schopp', 'Schopp', '', 49.3500000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31910, 'Schopfloch', 'Schopfloch', 'Schopfloch,Shopflokh,Sopflox,shopufurohho,swpplwk,Шопфлох,Շոպֆլոխ,שופפלוך,ショプフロッホ', 49.1191700, 10.3077400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31911, 'Schopfloch', 'Schopfloch', '', 48.4547700, 8.5513100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31912, 'Schopfheim', 'Schopfheim', 'Shopfgajm,Shopfkhajm,shao pu fu hai mu,shpfhaym,shwbfhaym,Шопфгайм,Шопфхайм,Шопфхајм,شوبفهايم,شپفهایم,绍普夫海姆', 47.6510500, 7.8208900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31913, 'Schönwalde am Bungsberg', 'Schonwalde am Bungsberg', 'Schonwalde am Bungsberg,Schönwalde am Bungsberg', 54.1833300, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31914, 'Schönwald', 'Schonwald', 'Schoenwald im Schwarzwald,Schonwald,Schönwald,Schönwald im Schwarzwald', 50.1997000, 12.0850300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31915, 'Schönwald im Schwarzwald', 'Schonwald im Schwarzwald', 'Schoenwald im Schwarzwald,Schonwald,Schonwald im Schwarzwald,Schönwald,Schönwald im Schwarzwald,Shenval''d-im-Shvarcval''d,Shenvald im Shvarcvald,Shjonval''d,hei lin shan qu shen wa er de,Шенвалд им Шварцвалд,Шенвальд-ім-Шварцвальд,Шёнвальд,黑林山区申瓦尔德', 48.1054900, 8.2038700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31916, 'Schonungen', 'Schonungen', 'Shonungen,shao nong gen,shwnwngn,Шонунген,شونونگن,绍农根', 50.0500800, 10.3080900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31917, 'Schönthal', 'Schonthal', 'Schoenthal,Schönthal,Shental,Shental'',Shjontal'',Шентал,Шенталь,Шёнталь,Շյոնթալ', 49.3500000, 12.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31918, 'Schonstett', 'Schonstett', '', 47.9833300, 12.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31919, 'Schönsee', 'Schonsee', 'Schonsee,Schönsee,Shenze,Shjonzee,shen sai,Шензе,Шёнзее,شون‌زی,申塞', 49.5103000, 12.5476300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31920, 'Schönkirchen', 'Schonkirchen', 'Schoenkarken,Schoenkirchen,Schönkarken,Schönkirchen,Shenkirkhen,Shjonkirkhen,shen ji xing,Шенкирхен,Шёнкирхен,申基兴', 54.3333300, 10.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31921, 'Schöningen', 'Schoeningen', 'Scahuningi,Sceninge,Schainich,Schoeningen,Schoningen,Schöningen,Sh''oningen,Sheningen,Shjoningen,she ning gen,shwnynghn,shwnyngn,Шенинген,Шьонинген,Шёнинген,شونينغن,شونینگن,舍宁根', 52.1380200, 10.9674500, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31922, 'Schönheide', 'Schoenheide', 'Schoenheide,Schoenheide vald,Schönheide,Schönheide vald,Shenkhajde,Shjonkhajde,shen hai de,Шенхајде,Шёнхайде,申海德', 50.5045800, 12.5215800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31923, 'Schönhausen', 'Schoenhausen', 'Schonhausen,Schönhausen,Sh''onkhauzen,Shenkhauzen,Shjonkhauzen,Soenhauzen,Şönhauzen,Шенхаузен,Шьонхаузен,Шёнхаузен', 52.5807600, 12.0392300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31924, 'Schönhagen', 'Schonhagen', 'QXH,Schoenhagen,Schönhagen', 51.3389800, 10.0209000, 'DE', '2016-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31925, 'Schöngleina', 'Schongleina', 'Schongleina,Schöngleina', 50.9074700, 11.7237900, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31926, 'Schöngeising', 'Schongeising', 'Schoengeising,Schöngeising', 48.1413500, 11.2039900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31927, 'Schongau', 'Schongau', 'Schongau,Schongium,Shongau,shongau,shwngaw  bayrn,Шонгау,شونگاو، بایرن,ショーンガウ', 47.8124000, 10.8966400, 'DE', '2014-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31928, 'Schönfeld', 'Schonfeld', '', 53.4136200, 13.9856800, 'DE', '2016-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31929, 'Schönfeld', 'Schonfeld', 'Schonefeld,Schonfeld,Schönefeld,Schönfeld', 51.3000000, 13.7000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31930, 'Schönewörde', 'Schoneworde', '', 52.6333300, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31931, 'Schönewalde', 'Schoenewalde', 'Schonewalde,Schönewalde', 51.6790100, 13.6024700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31932, 'Schönermark', 'Schonermark', '', 53.0069900, 13.1201600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31933, 'Schönenberg', 'Schonenberg', '', 47.7937800, 7.8824800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31934, 'Schöneiche', 'Schoeneiche', 'Schoeneiche,Schoneiche,Schöneiche', 52.4728600, 13.6922600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31935, 'Schönefeld', 'Schoenefeld', 'Schonefeld,Schönefeld,Shenefeld,Shjonefel''d,Syonefeld,Шенефелд,Шёнефельд,Շյոնեֆելդ', 52.3889700, 13.5037400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31936, 'Schönecken', 'Schonecken', 'Sheneken,Shjonekken,she nei ken,Шенекен,Шёнеккен,舍内肯', 50.1590900, 6.4682000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31937, 'Schöneck', 'Schoeneck', 'Schoeneck,Schoeneck/Vogtland,Schoneck,Schöneck,Schöneck/Vogtland', 50.3905200, 12.3273100, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31938, 'Schöneberg', 'Schoneberg Bezirk', '', 52.4666700, 13.3500000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31939, 'Schöneberg', 'Schoneberg', 'Sheneberg,Shjoneberg,Syoneberg,Шенеберг,Шёнеберг,Շյոնեբերգ', 53.0085300, 14.1425800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31940, 'Schöneberg', 'Schoneberg', '', 50.6666700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31941, 'Schöneberg', 'Schoneberg', 'Sheneberg,Shjoneberg,Шенеберг,Шёнеберг', 49.9166700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31942, 'Schönebeck', 'Schoenebeck', 'Schoenebeck (Elbe),Schoennebeck,Schonebeck,Schönebeck,Schönebeck (Elbe),Schönnebeck,Sconebeke [a. 1223],Shenebek,Shenebek (Elbe),Shjonebek,Shjonebek (Ehl''ba),she na bei ke,shwnbk,shwnhbk,Шенебек,Шенебек (Елбе),Шёнебек,Шёнебек (Эльба),شونبک,شونهبك,舍纳贝克', 52.0168200, 11.7307000, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31943, 'Schondra', 'Schondra', 'Schondra,Shondra,Sondra,xiong de la,Шондра,Շոնդրա,雄德拉', 50.2681400, 9.8627700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31944, 'Schöndorf', 'Schondorf', '', 50.6174500, 11.6947700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31945, 'Schönburg', 'Schoenburg', 'Schoenburg,Schönburg', 51.1666700, 11.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31946, 'Schönborn', 'Schonborn', 'Schonborn,Schönborn', 51.6001600, 13.4896700, 'DE', '2013-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31947, 'Schönborn', 'Schonborn', '', 50.3025000, 7.9940100, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31948, 'Schönborn', 'Schonborn', '', 49.9500000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31949, 'Schönborn', 'Schonborn', 'Schoenborn,Schönborn', 49.6333300, 7.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31950, 'Schönberg', 'Schonberg', 'Schoenberg,Schönberg', 53.6831900, 10.4267100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31951, 'Schönberg', 'Schoenberg', '', 50.8675200, 12.4912600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31952, 'Schönberg', 'Schoenberg', '', 49.7666700, 6.9166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31953, 'Schönberg', 'Schonberg', 'Shenberg,Shjonberg,Syonberg,shwnbrg,Шенберг,Шёнберг,Շյոնբերգ,شونبرگ', 48.3333300, 12.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31954, 'Schönbek', 'Schonbek', 'Schonbek,Schönbek', 54.1666700, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31955, 'Schönbach', 'Schonbach', '', 51.0666700, 14.5666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31956, 'Schönbach', 'Schonbach', '', 50.2166700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31957, 'Schönau-Berzdorf', 'Schoenau-Berzdorf', 'Berzdorf,Berzdorf auf dem Eigen,Berzdorf uber Gorlitz,Berzdorf über Görlitz,Schoenau-Berzdorf auf dem Eigen,Schoenau-Berzdorfi vald,Schonau-Berzdorf,Schönau-Berzdorf,Schönau-Berzdorf auf dem Eigen,Schönau-Berzdorfi vald,Shenau-Bercdorf,Shenau-Bercdorf auf dem Ajgen,Shjonau-Bercdorf,she nao-bei er ci duo fu,Шенау-Берцдорф,Шенау-Берцдорф ауф дем Ајген,Шёнау-Берцдорф,舍瑙-贝尔茨多夫', 51.0640200, 14.8840200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31958, 'Schönau', 'Schonau', '', 50.0757100, 9.7216900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31959, 'Schönau', 'Schonau', 'Schonau,Schönau,Shenau,Shjonau,shenau,shwnaw,Шенау,Шёнау,شوناو,シェーナウ', 49.4366500, 8.8088000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31960, 'Schönau', 'Schonau', '', 48.4833300, 12.8500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31961, 'Schönau im Schwarzwald', 'Schonau im Schwarzwald', 'Schoenau en la Selva Negra,Schoenau im Schwarzwald,Schonau,Schonau im Schwarzwald,Schönau,Schönau en la Selva Negra,Schönau im Schwarzwald,Shenau im Shvarcvald,Shenau-im-Shvarcval''d,Shjonau,hei lin shan qu she nao,shwna aym shwartzwald,shwnaw am shfartsfald,Шенау им Шварцвалд,Шенау-ім-Шварцвальд,Шёнау,شونا ایم شوارتزوالد,شوناو إم شفارتسفالد,黑林山区舍瑙', 47.7862300, 7.8944500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31962, 'Schönau am Königssee', 'Schoenau am Koenigssee', 'Scheenau am Kenigssaeae,Scheenau am Kenigssää,Schoenau a.Koenigssee,Schoenau am Koenigsee,Schonau,Schönau,Schönau a.Königssee,Schönau am Königsee,Shenau am Kenigsze,Shenau-am-Kenigze,Shjonau-am-Kjonigsze,Syonao am Kyonigsze,she nao a mu ke ni ge sai,shwnaw am kwnygzy,Шенау ам Кенигсзе,Шенау-ам-Кенігзе,Шёнау-ам-Кёнигсзе,Շյոնաո ամ Կյոնիգսզե,شوناو ام کونیگزی,舍瑙阿姆克尼格塞', 47.6005500, 12.9870400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31963, 'Schönaich', 'Schonaich', 'Schoenaich,Schonaich,Schönaich,Shenajkh,Shjonajkh,Syonayx,she nai xi,shenaikhi,Шенайх,Шенајх,Шёнайх,Շյոնայխ,შენაიხი,舍奈希', 48.6587100, 9.0601200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31964, 'Schonach im Schwarzwald', 'Schonach im Schwarzwald', 'Schonach,Schonach im Schwarzwald,Shonakh,Shonakh im Shvarcvald,Shonakh-im-Shvarcval''d,hei lin shan qu shao na he,Шонах,Шонах им Шварцвалд,Шонах-ім-Шварцвальд,黑林山区绍纳赫', 48.1422900, 8.2028900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31965, 'Schömerich', 'Schomerich', '', 49.6333300, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31966, 'Schömberg', 'Schoemberg', '', 50.7596200, 12.0201600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31967, 'Schömberg', 'Schomberg', 'Schoemberg,Schömberg', 48.7871300, 8.6449500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31968, 'Schömberg', 'Schomberg', '', 48.2099700, 8.7594900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31969, 'Schöllnach', 'Schollnach', 'Schoellnach,Schollnach,Schöllnach,Shel''nakh,Shelnakh,Shjol''nakh,Syolnax,she er na,shwlnakh,Шелнах,Шельнах,Шёльнах,Շյոլնախ,شولناخ,舍尔纳', 48.7541200, 13.1778100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31970, 'Schöllkrippen', 'Schollkrippen', 'Schoellkrippen,Schollkrippen,Schöllkrippen,Shel''krippen,Shelkripen,Shjol''krippen,she er ke li peng,sherukurippen,Шелкрипен,Шелькріппен,Шёлькриппен,Շյոլկրիփեն,シェルクリッペン,舍尔克里彭', 50.0854500, 9.2469700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31971, 'Schollene', 'Schollene', '', 52.6769500, 12.2186900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31972, 'Schollbrunn', 'Schollbrunn', 'Shol''brunn,Sholbrun,Sholl''brunn,Solbrun,shao er bu lun,Шолбрун,Шолльбрунн,Шольбрунн,Շոլբրուն,绍尔布伦', 49.8350000, 9.4638900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31973, 'Scholen', 'Scholen', 'Sholen,shao lun,Шолен,绍伦', 52.7333300, 8.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31974, 'Schöfweg', 'Schofweg', 'Shefveg,Shjofveg,Syofveg,she fu wei ge,shwfwg,Шефвег,Шёфвег,Շյոֆվեգ,شوفوگ,舍夫韦格', 48.8388200, 13.2286100, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31975, 'Schoden', 'Schoden', '', 49.6333300, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31976, 'Schochwitz', 'Schochwitz', 'Schochwitz', 51.5317400, 11.7548500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31977, 'Schobüll', 'Schobuell', '', 54.5092000, 9.0062100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31978, 'Schnürpflingen', 'Schnurpflingen', 'Schnuerpflingen,Schnürpflingen,Shnirpflingen,Shnjurpflingen,Snyurpflingen,shi ni er pu fu lin gen,Шнирпфлинген,Шнюрпфлинген,Шнюрпфлінген,Շնյուրպֆլինգեն,შნიურპფლინგენი,施尼尔普夫林根', 48.2728000, 9.9929200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31979, 'Schnorbach', 'Schnorbach', '', 49.9833300, 7.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31980, 'Schneverdingen', 'Schneverdingen', 'Gemeen Snevern,Schneverdingen,Shneferdingen,Shneverdingen,ashnfrdyngn,shi nei fei er ding gen,shnfrdynghn,Шневердинген,Шнефердинген,اشنفردینگن,شنفردينغن,施内费尔丁根', 53.1168500, 9.7952400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31981, 'Schnelldorf', 'Schnelldorf', 'Schnelldorf,Shnel''dorf,Shneldorf,Sneldorf,shi nei er duo fu,shunerudorufu,Шнелдорф,Шнельдорф,Շնելդորֆ,シュネルドルフ,施内尔多夫', 49.2000000, 10.1833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31982, 'Schneizlreuth', 'Schneizlreuth', 'Schneizlreith,Schneizlreuth,Shnajcl''rojt,Shnajclrojt,ashnaytslrwyt,shi nai ci er luo yi te,Шнайцльройт,Шнајцлројт,Շնայցլրոյտ,اشنایتسلرویت,施奈茨尔罗伊特', 47.6833300, 12.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31983, 'Schneidlingen', 'Schneidlingen', '', 51.8945400, 11.4448700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31984, 'Schnega', 'Schnega', 'Shnega,ashnga,shi nei jia,Шнега,اشنگا,施内加', 52.8913000, 10.8922600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31985, 'Schneeberg', 'Schneeberg', 'Schneeberg,Shneberg,ashnybrg,Шнеберг,اشنیبرگ', 50.5946500, 12.6413900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31986, 'Schneckenlohe', 'Schneckenlohe', 'Shnekenloe,Shnekkenloe,Shnekkenloeh,shi nei ken luo hei,shunekkenroe,Шнекенлое,Шнеккенлое,Шнеккенлоэ,Շնեքենլոե,シュネッケンローエ,施内肯洛黑', 50.2118400, 11.1939500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31987, 'Schneckenhausen', 'Schneckenhausen', '', 49.5381400, 7.7450600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31988, 'Schnakenbek', 'Schnakenbek', 'Schnakenbek', 53.3833300, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31989, 'Schnaittenbach', 'Schnaittenbach', 'Schnaittenbach,Shnajtenbakh,Shnajttenbakh,Snaytenbax,ashnaytnbakh,shi nai teng ba he,shnaytnbakh,Шнайттенбах,Шнајтенбах,Շնայտենբախ,اشنایتنباخ,شنايتنباخ,施奈滕巴赫', 49.5469200, 12.0018400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31990, 'Schnaittach', 'Schnaittach', 'Schnaittach,Shnajtakh,Shnajttakh,shi nai ta he,Шнайттах,Шнајтах,Շնայթախ,施奈塔赫', 49.5595800, 11.3432800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31991, 'Schnaitsee', 'Schnaitsee', 'Schnoatsee,Shnajtze,ashnaytzy,shi nai ce,Шнайтзе,Шнајтзе,Շնայթզեե,اشنایتزی,施奈策', 48.0666700, 12.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31992, 'Schmorda', 'Schmorda', '', 50.6447800, 11.5864600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31993, 'Schmölln', 'Schmoelln', 'Schmoelln,Schmolln,Schmölln,Shmeln,Shmjol''n,ashmwln,shi mo er en,shmwln,Шмелн,Шмёльн,اشمولن,شمولن,施默尔恩', 50.8967800, 12.3533900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31994, 'Schmöckwitz', 'Schmockwitz', 'Berlin-Schmochwitz,Berlin-Schmoeckwitz,Berlin-Schmöchwitz,Berlin-Schmöckwitz', 52.3751300, 13.6494800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31995, 'Schmitten', 'Schmitten', 'Schmitten im Taunus,Shmiten,Shmitten,shi mi teng,Шмитен,Шмиттен,Шміттен,施米滕', 50.2666700, 8.4500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31996, 'Schmitt', 'Schmitt', '', 50.1666700, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31997, 'Schmitshausen', 'Schmitshausen', '', 49.3000000, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31998, 'Schmißberg', 'Schmissberg', '', 49.6666700, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(31999, 'Schmilau', 'Schmilau', 'Schmilau', 53.6624900, 10.7568400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32000, 'Schmieritz', 'Schmieritz', 'Schmieritz', 50.7166700, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32001, 'Schmiedehausen', 'Schmiedehausen', '', 51.0666700, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32002, 'Schmiedefeld am Rennsteig', 'Schmiedefeld am Rennsteig', 'Schmiedefeld am Rennsteig,Shmidefel''d-am-Renshtajg,Shmidefeld am Renshtajg,Shmidefeld na Renshtajg,lun si tai xi de qu shi mi de fei er de,Шмидефелд ам Ренштајг,Шмидефелд на Ренштајг,Шмидефельд-ам-Ренштайг,伦斯泰希地区施米德费尔德', 50.6086300, 10.8128400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32003, 'Schmiedefeld', 'Schmiedefeld', '', 50.5333300, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32004, 'Schmiedeberg', 'Schmiedeberg', 'Shmideberg,shi mi de bei ge,Шмидеберг,施米德贝格', 50.8364400, 13.6762200, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32005, 'Schmiechen', 'Schmiechen', 'Shmikhen,Smixen,shi mi xing,shumihyen,Шмихен,Шміхен,Շմիխեն,シュミーヒェン,施米兴', 48.2166700, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32006, 'Schmidthachenbach', 'Schmidthachenbach', 'Shmidtakhenbakh,shi mi ta heng ba he,Шмидтахенбах,施米塔亨巴赫', 49.7333300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32007, 'Schmidmühlen', 'Schmidmuhlen', 'Shmidmilen,Shmidmjulen,Smidmyulen,shi mi de mi he lun,Шмидмилен,Шмидмюлен,Шмідмюлен,Շմիդմյուլեն,施米德米赫伦', 49.2689800, 11.9242900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32008, 'Schmidgaden', 'Schmidgaden', 'Shmidgaden,ashmydgadn,shi mi de jia deng,Шмидгаден,Шмідгаден,اشمیدگادن,施米德加登', 49.4234000, 12.0924700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32009, 'Schmelz', 'Schmelz', '', 49.4333300, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32010, 'Schmeheim', 'Schmeheim', 'Schmeheim', 50.5666700, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32011, 'Schmargendorf', 'Schmargendorf', 'Berlin-Schmargendorf', 52.4751700, 13.2907100, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32012, 'Schmalstede', 'Schmalstede', 'Schmalstede', 54.2000000, 10.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32013, 'Schmallenberg', 'Schmallenberg', 'Schmallenberg,Shmalenberg,Shmallenberg,Smalenbergas,Smalmereg,ashmalnbrg,shi ma lun bei ge,shmalnbrgh,Šmalenbergas,Шмаленберг,Шмалленберг,اشمالنبرگ,شمالنبرغ,施马伦贝格', 51.1547300, 8.2850500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32014, 'Schmalkalden', 'Schmalkalden', 'Esmalcalda,Schmalkalden,Shmal''kal''den,Shmalkalden,Smalcalda,Smalcaldia,Smalkalda,Smalkaldy,ashmalkaldn,shi ma er ka er deng,smlqldn,Šmalkaldy,Шмалкалден,Шмалькальден,שמלקלדן,اشمالکالدن,施马尔卡尔登', 50.7213600, 10.4438600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32015, 'Schmalfeld', 'Schmalfeld', 'Schmalfeld', 53.8833300, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32016, 'Schmalensee', 'Schmalensee', 'Schmalensee', 54.0830200, 10.2705500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32017, 'Schmalenberg', 'Schmalenberg', '', 49.3333300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32018, 'Schlüsselfeld', 'Schlusselfeld', 'Schluesselfeld,Schlusselfeld,Schlüsselfeld,Shliselfeld,Shljussel''fel''d,Slyuselfeld,ashlwslfld,shi lu sai er fei er de,shlwslfld,shuryusseruferuto,Шлиселфелд,Шлюссельфельд,Շլյուսելֆելդ,اشلوسلفلد,شلوسلفلد,シュリュッセルフェルト,施吕塞尔费尔德', 49.7562100, 10.6187300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32019, 'Schlüchtern', 'Schluechtern', 'Gorad Shljukhtehrn,Schluechtern,Schlüchtern,Shlikhtern,Shljukhtern,ashlwshtrn,shi lu xi teng,shlwshtrn,shuryuhiterun,Горад Шлюхтэрн,Шлихтерн,Шлюхтерн,اشلوشترن,شلوشترن,シュリュヒテルン,施吕希滕', 50.3489100, 9.5253200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32020, 'Schluchsee', 'Schluchsee', '', 47.8166700, 8.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32021, 'Schlotheim', 'Schlotheim', 'Schlotheim,Shlotajm,Shlotkhajm,ashlwthaym,shi luo tai mu,shlwthaym,Шлотайм,Шлотхайм,Шлотхајм,اشلوتهایم,شلوتهايم,施洛泰姆', 51.2464300, 10.6584200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32022, 'Schlotfeld', 'Schlotfeld', 'Schlotfeld', 53.9561900, 9.5823100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32023, 'Schloßvippach', 'Schlossvippach', 'Shlosfipakh,Shlosfippakh,Shlosvipakh,shi luo si fei pa he,Шлосвипах,Шлосфипах,Шлосфиппах,施洛斯菲帕赫', 51.1049900, 11.1451200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32024, 'Schloßböckelheim', 'Schlossbockelheim', 'Schlossboeckelheim,Schlossböckelheim,Shlosbekelkhajm,Shlosbjokkel''khajm,shi luo si bo ke er hai mu,Шлосбекелхајм,Шлосбёккельхайм,施洛斯伯克尔海姆', 49.8000000, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32025, 'Schlöben', 'Schloben', 'Schloben,Schloeben,Schlöben,Shleben,Shljoben,shi lei ben,Шлебен,Шлёбен,施勒本', 50.8940500, 11.6890200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32026, 'Schlitz', 'Schlitz', 'Shlic,ashlyts,shurittsu,Шлиц,اشلیتس,シュリッツ', 50.6741600, 9.5610200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32027, 'Schliersee', 'Schliersee', 'Schliers,Schliersee,Shlirze,Slirze,shi li er sai,shlyrzy,Шлирзе,Шлірзе,Շլիրզե,شلیرزی,施利尔塞', 47.7362100, 11.8593600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32028, 'Schlierschied', 'Schlierschied', '', 49.8666700, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32029, 'Schlierbach', 'Schlierbach', '', 48.6736200, 9.5181100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32030, 'Schlier', 'Schlier', '', 47.7700400, 9.6735400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32031, 'Schliengen', 'Schliengen', 'Shlingen,shi lin gen,Шлинген,Шлінген,施林根', 47.7569800, 7.5764500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32032, 'Schlieben', 'Schlieben', 'Schlieben,Shliben,Sliben,Sliwin,ashlybn,shi li ben,shlybn,Шлибен,Շլիբեն,اشلیبن,شليبن,施利本', 51.7237900, 13.3830400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32033, 'Schlichting', 'Schlichting', 'Schlichting', 54.3105800, 9.0893900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32034, 'Schleusingen', 'Schleusingen', 'Schleusingen,Shlojzingen,ashlwyzyngn,shi luo yi xin gen,shlwyzynghn,Шлойзинген,Шлојзинген,اشلویزینگن,شلويزينغن,施洛伊辛根', 50.5107600, 10.7565800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32035, 'Schlettau', 'Schlettau', 'Schlettau,Shletau,Shlettau,Sletava,ashltaw,shi lai tao,shlytaw,Šletava,Шлетау,Шлеттау,اشلتاو,شليتاو,施莱陶', 50.5588200, 12.9526900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32036, 'Schleswig', 'Schleswig', 'Schleswig,Shlezvig,Sleeswig,Slesvig,Sliesthorp,Stadt Schleswig,WBG,Шлезвиг', 54.5215600, 9.5586000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32037, 'Schlesen', 'Schlesen', '', 54.3215300, 10.3341900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32038, 'Schlepzig', 'Schlepzig', 'Shlepcig,Slopisca,Slopišća,Słopišća,shi lai pu qi xi,Шлепциг,Շլեպցիգ,施莱普齐希', 52.0333300, 13.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32039, 'Bad Schlema', 'Bad Schlema', 'Niederschlema,Schlema', 50.6025700, 12.6728800, 'DE', '2016-01-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32040, 'Schleiz', 'Schleiz', 'Schleiz,Shlajc,ashlayts,shi lai ci,shlayts,Шлайц,Шлајц,اشلایتس,شلايتس,施莱茨', 50.5786600, 11.8102400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32041, 'Schleifreisen', 'Schleifreisen', 'Schleifreisen', 50.8833300, 11.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32042, 'Schleife', 'Schleife', 'Schleife,Slepo', 51.5333300, 14.5333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32043, 'Schleiden', 'Schleiden', 'Shlajden,Shljajden,Sjleie,ashlaydn,shi lai deng,shlaydn,Шлайден,Шлајден,Шляйден,اشلایدن,شلايدن,施莱登', 50.5289600, 6.4769200, 'DE', '2013-11-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32044, 'Schleid', 'Schleid', 'Shlajd,shi lai de,Шлайд,Шлајд,施莱德', 50.7000000, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32045, 'Schleid', 'Schleid', '', 50.0666700, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32046, 'Schleich', 'Schleich', '', 49.8166700, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32047, 'Schlehdorf', 'Schlehdorf', 'Schleedorf,Schlehdorf,Shledorf,Shlekhdorf,Sledorf,shldwrf,Шледорф,Шлехдорф,Շլեդորֆ,شلدورف', 47.6579500, 11.3149400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32048, 'Schlegel', 'Schlegel', '', 50.9777500, 14.8768600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32049, 'Schlegel', 'Schlegel', '', 50.4000000, 11.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32050, 'Schleching', 'Schleching', 'Shlekhing,Slexing,shi lai xing,shlshyng,Шлехинг,Шлехінг,Շլեխինգ,شلشینگ,施莱兴', 47.7209800, 12.3948100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32051, 'Schlat', 'Schlat', 'Shlat,Шлат', 48.6532100, 9.7062500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32052, 'Schlangenbad', 'Schlangenbad', 'Schlangenbad,Shlangenbad,shi lan gen ba de,shlangenbadi,Шлангенбад,შლანგენბადი,施兰根巴德', 50.0932200, 8.1031200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32053, 'Schlangen', 'Schlangen', '', 51.8097800, 8.8460500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32054, 'Schlammersdorf', 'Schlammersdorf', '', 49.8000000, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32055, 'Schlaitz', 'Schlaitz', 'Schlaitz', 51.6587100, 12.4283900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32056, 'Schlaitdorf', 'Schlaitdorf', 'Shlajtdorf,Slaytdorf,shi lai te duo fu,Шлайтдорф,Шлајтдорф,Շլայտդորֆ,施莱特多夫', 48.6043100, 9.2226800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32057, 'Schlagsdorf', 'Schlagsdorf', 'Schlagsdorf', 53.7336300, 10.8255600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32058, 'Schladt', 'Schladt', '', 50.0333300, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32059, 'Schladen', 'Schladen', 'Schladen,Shladen,shi la deng,Шладен,施拉登', 52.0221800, 10.5396700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32060, 'Schkopau', 'Schkopau', 'Schkopau,Shkopau,shi ke bao,Шкопау,施科保', 51.3918600, 11.9522400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32061, 'Schkölen', 'Schkoelen', 'Schkoelen,Schkolen,Schkölen,Shkelen,Shkjolen,ashkwln,shi ke lun,shkwln,Шкелен,Шкёлен,اشکولن,شكولن,施克伦', 51.0416600, 11.8214100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32062, 'Schkeuditz', 'Schkeuditz', 'Schkeuditz,Shkojdic,Skeidica,ashkwydyts,shi ke yi di ci,shkwydyts,Škeidica,Шкойдиц,Шкојдиц,اشکویدیتس,شكويديتس,施科伊迪茨', 51.3967800, 12.2214100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32063, 'Schirnding', 'Schirnding', 'Schirnding,Shirnding,shirundingu,xi er en ding,Ширндинг,シルンディング,席尔恩丁', 50.0820500, 12.2274200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32064, 'Schirmitz', 'Schirmitz', '', 49.6500000, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32065, 'Schirgiswalde', 'Schirgiswalde', 'Schirgiswalde,Serachow,Shirgisval''de,Shirgisvalde,Šěrachow,Ширгисвалде,Ширгисвальде,Шіргісвальде', 51.0764100, 14.4283400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32066, 'Schipkau', 'Schipkau', 'Schipkau,Sejkow,Shipkau,Sipkau,Tschipko,xi pu kao,Šejkow,Шипкау,Շիպկաու,席普考', 51.5176600, 13.8973800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32067, 'Schiphorst', 'Schiphorst', 'Schiphorst', 53.7081000, 10.4612400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32068, 'Schindhard', 'Schindhard', '', 49.1418300, 7.8221400, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32069, 'Schiltberg', 'Schiltberg', 'Shil''tberg,Shiltberg,Siltberg,shirutoberuku,xi er te bei ge,Шилтберг,Шильтберг,Շիլտբերգ,シルトベルク,席尔特贝格', 48.4629300, 11.2487600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32070, 'Schiltach', 'Schiltach', 'Schiltach,Shil''takh,Shiltakh,shyltakh,xi er ta,Шилтах,Шильтах,شيلتاخ,شیلتاخ,席尔塔', 48.2893200, 8.3416900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32071, 'Schillsdorf', 'Schillsdorf', 'Schillsdorf', 54.1166700, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32072, 'Schillingstedt', 'Schillingstedt', '', 51.2333300, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32073, 'Schillingsfürst', 'Schillingsfurst', 'Schillingsfurst,Schillingsfürst', 49.2877500, 10.2627600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32074, 'Schillingen', 'Schillingen', '', 49.6333300, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32075, 'Schillig', 'Schillig', 'Schillig,Shilling,Шиллинг', 53.7037800, 8.0217000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32076, 'Schildau', 'Schildau', 'Gneisenaustadt Schildau,Schildau,Shil''dau,Shildau,shyldaw,xi er dao,Шилдау,Шильдау,Шільдау,شيلداو,شیلداو,席尔道', 51.4572100, 12.9302400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32077, 'Schilda', 'Schilda', '', 51.6000000, 13.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32078, 'Schiffweiler', 'Schiffweiler', 'Shifvajler,xi fu wei lai er,Шифвайлер,Шифвајлер,席夫魏莱尔', 49.3666700, 7.1333300, 'DE', '2016-06-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32079, 'Schifferstadt', 'Schifferstadt', 'Schifferstadt,Schiwwerschdadd,Shifershtat,Shiffershtadt,shifashutatto,shyfrashtat,shyfrshtat,xi fei er si ta te,Шиферштат,Шифферштадт,شيفرشتات,شیفراشتات,シファーシュタット,席费尔斯塔特', 49.3841700, 8.3775000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32080, 'Schiffdorf', 'Schiffdorf', 'Gemeen Schippdoerp,Gemeen Schippdörp,Schiffdorf,Shifdorf,xi fu duo fu,Шифдорф,席夫多夫', 53.5333300, 8.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32081, 'Schiesheim', 'Schiesheim', '', 50.2772200, 8.0550000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32082, 'Schiersfeld', 'Schiersfeld', '', 49.7000000, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32083, 'Schierling', 'Schierling', 'Schierling,Shirling,Sirling,shyrlyng,xi ling,Ширлинг,Ширлінг,Շիրլինգ,شیرلینگ,希灵', 48.8342200, 12.1394600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32084, 'Schierensee', 'Schierensee', 'Schierensee', 54.2500000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32085, 'Schieren', 'Schieren', 'Schieren', 53.9436200, 10.3908800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32086, 'Scheyern', 'Scheyern', 'Scheyan,Seyern,Shaern,Shajern,Shejern,sha yi ai er en,shyrn,Шайерн,Шаєрн,Шајерн,Шейерн,Շեյերն,شیرن,沙伊埃尔恩', 48.5000000, 11.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32087, 'Scheuring', 'Scheuring', 'Shojring,Soyring,shao yi ling,shoiringu,shwyryng,Шойринг,Шойрінг,Шојринг,Շոյրինգ,شویرینگ,ショイリング,绍伊灵', 48.1676900, 10.8956900, 'DE', '2012-12-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32088, 'Scheuern', 'Scheuern', '', 50.0166700, 6.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32089, 'Scheuerfeld', 'Scheuerfeld', '', 50.7873600, 7.8412800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32090, 'Scheßlitz', 'Schesslitz', 'Schesslitz,Scheßlitz', 49.9756800, 11.0329900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32091, 'Scherstetten', 'Scherstetten', '', 48.1803200, 10.6400500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32092, 'Schernfeld', 'Schernfeld', 'Sernsfeld,Shernfel''d,Shernfeld,she er en fei er de,shrnfld,Шернфелд,Шернфельд,Շերնսֆելդ,شرنفلد,舍尔恩费尔德', 48.9000000, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32093, 'Schernberg', 'Schernberg', 'Schernberg', 51.3277400, 10.7692800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32094, 'Schermen', 'Schermen', '', 52.2320600, 11.8138200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32095, 'Schermbeck', 'Schermbeck', 'Schermbeck,Shermbek,she er en bei ke,Шермбек,舍尔恩贝克', 51.6833300, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32096, 'Schenklengsfeld', 'Schenklengsfeld', 'Shenklengsfel''d,Shenklengsfeld,shen ke lun si fei er de,Шенкленгсфелд,Шенкленгсфельд,申克伦斯费尔德', 50.8166700, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32097, 'Schenkenzell', 'Schenkenzell', 'Shenkencel,Shenkencell'',shen ken ce er,Шенкенцел,Шенкенцелль,申肯策尔', 48.3120200, 8.3721200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32098, 'Schenkendöbern', 'Schenkendoebern', 'Derbno,Schenkendoebern,Schenkendöbern,Senkendyobern,Shenkendebern,Shenkendjobern,shen ken de bei er en,Шенкендеберн,Шенкендёберн,Շենկենդյոբերն,申肯德贝尔恩', 51.9572300, 14.6354100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32099, 'Schenkenberg', 'Schenkenberg', '', 53.3666700, 13.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32100, 'Schenkelberg', 'Schenkelberg', '', 50.5836100, 7.7827800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32101, 'Schenefeld', 'Schenefeld', 'Schenefeld,Shenefel''d,Shenefeld,Шенефелд,Шенефельд', 54.0500000, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32102, 'Schellweiler', 'Schellweiler', 'Shel''vajler,Shelvajler,she er wei lei,Шелвајлер,Шельвайлер,舍尔韦勒', 49.5139500, 7.3916300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32103, 'Schellhorn', 'Schellhorn', '', 54.2295200, 10.2940200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32104, 'Schellerten', 'Schellerten', 'Castra Scelerata,Shelerten,Shellerten,she lai er teng,Шелертен,Шеллертен,舍莱尔滕', 52.1853000, 10.1022700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32105, 'Schelklingen', 'Schelklingen', 'Selklingen,Shel''klingen,Shelklingen,she er ke lin gen,shlklynghn,shlklyngn,Шелклинген,Шельклинген,Шельклінген,Շելկլինգեն,شلكلينغن,شلکلینگن,შელკლინგენი,舍尔克林根', 48.3757500, 9.7327300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32106, 'Scheitenkorb', 'Scheitenkorb', '', 50.0166700, 6.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32107, 'Scheinfeld', 'Scheinfeld', 'Saynfeld,Scheinfeld,Seinfeldas,Shajnfel''d,Shajnfeld,sha yin fei er de,shaynfld,Šeinfeldas,Шайнфельд,Шајнфелд,Շայնֆելդ,شاينفلد,شاینفلد,沙因费尔德', 49.6693100, 10.4655400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32108, 'Scheidt', 'Scheidt', '', 50.3386000, 7.9141000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32109, 'Scheiditz', 'Scheiditz', 'Scheiditz', 50.9052000, 11.7542600, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32110, 'Scheidegg', 'Scheidegg', 'Saydeg,Scheidegg,Shajdeg,Shajdegg,sha yi de ge,Шайдегг,Шајдег,Շայդեգ,沙伊德格', 47.5814100, 9.8482900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32111, 'Scheid', 'Scheid', '', 50.3590600, 6.4217800, 'DE', '2016-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32112, 'Scheibenhardt', 'Scheibenhardt', '', 48.9811700, 8.1399300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32113, 'Scheibenberg', 'Scheibenberg', 'Scheibenberg,Seibenberga,Shajbenberg,sha yi ben bei ge,shaybnbrg,shaybnbrgh,Šeibenberga,Шайбенберг,Шајбенберг,شايبنبرغ,شایبنبرگ,沙伊本贝格', 50.5402300, 12.9121500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32114, 'Scheggerott', 'Scheggerott', 'Scheggerott', 54.6666700, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32115, 'Scheeßel', 'Scheessel', 'Scheessel,Scheessl,Scheeßel,Scheeßl,Shesel,Shessel'',sheseru,Шесел,Шессель,シェーセル', 53.1666700, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32116, 'Scheer', 'Scheer', 'Sher,she er,shyr,Шер,شیر,舍尔', 48.0729200, 9.2948600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32117, 'Schechingen', 'Schechingen', 'Shekhingen,she xin gen,shekhingeni,Шехинген,Шехінген,შეხინგენი,舍欣根', 48.8734100, 9.9174400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32118, 'Schechen', 'Schechen', '', 47.9291100, 12.1239300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32119, 'Schauren', 'Schauren', '', 50.0166700, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32120, 'Schauren', 'Schauren', '', 49.8071900, 7.2372400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32121, 'Schaufling', 'Schaufling', 'Saufling,Shaufling,shao fu ling,shawflyng,Шауфлинг,Шауфлінг,Շաուֆլինգ,شاوفلینگ,绍夫灵', 48.8500000, 13.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32122, 'Schauerberg', 'Schauerberg', '', 49.3166700, 7.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32123, 'Schauenstein', 'Schauenstein', 'Schauenstein,Shauehnshtajn,Shauenshtajn,shao en si tai yin,shauenshutain,shawynshtayn,Шауенштайн,Шауенштајн,Шауэнштайн,شاون‌اشتاین,شاوينشتاين,シャウエンシュタイン,绍恩斯泰因', 50.2782600, 11.7416900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32124, 'Schashagen', 'Schashagen', 'Schashagen', 54.1333300, 10.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32125, 'Scharnhorst', 'Scharnhorst', '', 52.7166700, 10.2833300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32126, 'Scharnebeck', 'Scharnebeck', 'Scharnebeck,Sharnebek,sha er nei bei ke,Шарнебек,沙尔内贝克', 53.2923700, 10.5018800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32127, 'Scharfenstein', 'Scharfenstein', '', 50.7040500, 13.0565400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32128, 'Scharfbillig', 'Scharfbillig', '', 49.9323300, 6.5552300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32129, 'Scharbeutz', 'Scharbeutz', 'Scharbeutz,Sharbojc,sha er bo yi ci,Шарбойц,Шарбојц,沙尔博伊茨', 54.0333300, 10.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32130, 'Schapen', 'Schapen', 'Shapen,sha peng,Шапен,沙彭', 52.4000000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32131, 'Schankweiler', 'Schankweiler', '', 49.9000000, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32132, 'Schallstadt', 'Schallstadt', 'Salstadt,Shal''shtadt,Shall''shtadt,Shalshtat,sha er shi ta te,Шалльштадт,Шалштат,Шальштадт,Շալշտադտ,沙尔施塔特', 47.9585500, 7.7575500, 'DE', '2013-03-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32133, 'Schallodenbach', 'Schallodenbach', '', 49.5500000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32134, 'Schallbach', 'Schallbach', '', 47.6500000, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32135, 'Schalksmühle', 'Schalksmuehle', 'Schalksmuehle,Schalksmuhle,Schalksmühle,Shal''ksmjule,Shalksmile,sha er ke si mi he lai,Шалксмиле,Шальксмюле,沙尔克斯米赫莱', 51.2412000, 7.5279000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32136, 'Schalkholz', 'Schalkholz', 'Schalkholz', 54.2467800, 9.2574900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32137, 'Schalkham', 'Schalkham', 'Shal''kgam,Shal''kkham,Shalkkham,sha er ke ha mu,shalkham,Шалкхам,Шалькгам,Шалькхам,Շալքհամ,شالکهام,沙尔克哈姆', 48.4833300, 12.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32138, 'Schalkenmehren', 'Schalkenmehren', 'Shal''kenmeren,Shalkenmeren,sha er ken mei lun,Шалкенмерен,Шалькенмерен,沙尔肯梅伦', 50.1652700, 6.8607500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32139, 'Schalkenbach', 'Schalkenbach', '', 50.4948500, 7.1463600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32140, 'Schalkau', 'Schalkau', 'Schalkau,Shal''kau,Shalkau,sha er kao,shalkaw,Шалкау,Шалькау,شالكاو,شالکاو,沙尔考', 50.3953600, 11.0073200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32141, 'Schäftlarn', 'Schaftlarn', 'Sheftlarn,she fu te la er en,shftlarn,Шефтларн,Շեֆթլարն,شفتلارن,舍夫特拉尔恩', 47.9902700, 11.4559100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32142, 'Schafstedt', 'Schafstedt', 'Schafstedt', 54.0833300, 9.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32143, 'Schafstädt', 'Schafstaedt', 'Schafstadt,Schafstädt', 51.3813100, 11.7730200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32144, 'Schafflund', 'Schafflund', 'Schafflund', 54.7584500, 9.1832900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32145, 'Schaffhausen', 'Schaffhausen', '', 49.2562000, 6.8099900, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32146, 'Schackendorf', 'Schackendorf', '', 53.9583100, 10.2712400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32147, 'Schachtebich', 'Schachtebich', 'Schachtebich', 51.4000000, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32148, 'Schacht-Audorf', 'Schacht-Audorf', '', 54.3128200, 9.7158600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32149, 'Schaalby', 'Schaalby', 'Schaalby', 54.5500000, 9.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32150, 'Schaafheim', 'Schaafheim', 'Schaafheim,Shaafgajm,Shaafkhajm,Shafkhajm,sha fu hai mu,shafuhaimu,Шаафгайм,Шаафхайм,Шафхайм,Шафхајм,シャーフハイム,沙夫海姆', 49.9241700, 9.0094400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32151, 'Sayda', 'Sayda', 'Sayda,Zaida,Zajda,zayda,Зайда,Зајда,زايدا,زایدا', 50.7112300, 13.4217200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32152, 'Saxler', 'Saxler', '', 50.1333300, 6.9000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32153, 'Saustrup', 'Saustrup', 'Saustrup', 54.6666700, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32154, 'Saulgrub', 'Saulgrub', 'Saigra,Zaul''grub,Zaulgrub,shao er ge lu bu,zawlgrwb,Заулгруб,Заульгруб,Զաուլգրուբ,زاولگروب,绍尔格鲁布', 47.6664300, 11.0246900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32155, 'Saulgau', 'Saulgau', 'Bad Saulgau,Saulgau', 48.0167600, 9.5006400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32156, 'Sauldorf', 'Sauldorf', 'Sauldorf,Zaul''dorf,Zauldorf,shao er duo fu,Заулдорф,Заульдорф,绍尔多夫', 47.9437100, 9.1083300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32157, 'Sauerthal', 'Sauerthal', 'Zauehrtal'',Zauertal,shao ai er ta er,Зауертал,Зауэрталь,绍埃尔塔尔', 50.0855100, 7.8211500, 'DE', '2012-12-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32158, 'Sauerlach', 'Sauerlach', 'Zauehrlakh,Zauerlakh,Zauerlax,sawyrlakh,shao ai er la,Зауерлах,Зауэрлах,Զաուերլախ,ساوئرلاخ,绍埃尔拉', 47.9717100, 11.6538300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32159, 'Sauensiek', 'Sauensiek', 'Sauensiek,Sounsiek,Zauehnzik,Zauensik,shao en xi ke,zauenjiku,Зауенсик,Зауэнзик,ザウエンジーク,绍恩西克', 53.3833300, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32160, 'Satteldorf', 'Satteldorf', 'Zateldorf,Zattel''dorf,sa te er duo fu,zatterudorufu,Зателдорф,Заттельдорф,ザッテルドルフ,萨特尔多夫', 49.1695300, 10.0795700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32161, 'Satrup', 'Satrup', 'Satrup', 54.6923700, 9.6054900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32162, 'Satow-Oberhagen', 'Satow-Oberhagen', '', 53.9954500, 11.8846600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32163, 'Saßnitz', 'Sassnitz', 'Sassnitz,Saßnitz', 54.5157000, 13.6445100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32164, 'Sassenberg', 'Sassenberg', 'Sassenberg,Zasenberg,Zassenberg,Zassenberq,sa sen bei ge,zasnbrgh,zaznbrg,Засенберг,Зассенберг,زازنبرگ,زاسنبرغ,萨森贝格', 51.9922300, 8.0406800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32165, 'Sassen', 'Sassen', '', 50.2666700, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32166, 'Sasel', 'Sasel', '', 53.6538500, 10.1118400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32167, 'Sasbachwalden', 'Sasbachwalden', 'Zasbakhval''den,Zasbakhvalden,sa si ba wa er deng,Засбахвалден,Засбахвальден,萨斯巴瓦尔登', 48.6166700, 8.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32168, 'Sasbach', 'Sasbach', '', 48.6397100, 8.0937500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32169, 'Sasbach', 'Sasbach', '', 48.1383700, 7.6157600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32170, 'Sarzbüttel', 'Sarzbuttel', 'Sarzbuttel,Sarzbüttel', 54.1166700, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32171, 'Sarstedt', 'Sarstedt', 'Sarstedt,Zarshtedt,Zarshtet,sa er si te,zarashtt,zarshtyt,Зарштедт,Зарштет,زاراشتت,زارشتيت,萨尔斯特', 52.2349500, 9.8541100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32172, 'Sarmersbach', 'Sarmersbach', '', 50.2333300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32173, 'Sarlhusen', 'Sarlhusen', 'Sarlhusen', 54.0228400, 9.7929400, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32174, 'Sargenroth', 'Sargenroth', 'Zargenrot,sa er gen luo te,Заргенрот,萨尔根罗特', 49.9333300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32175, 'Sankt Wolfgang', 'Sankt Wolfgang', 'Sankt Wolfgang', 48.2166700, 12.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32176, 'Sankt Wendel', 'Sankt Wendel', 'Kreisstadt Sankt Wendel,Sankt Wendel,Sankt-Vendel'',Санкт-Вендель', 49.4663300, 7.1681400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32177, 'Sankt Thomas', 'Sankt Thomas', '', 50.0666700, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32178, 'Sankt Sebastian', 'Sankt Sebastian', '', 50.4107700, 7.5617500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32179, 'Sankt Peter-Ording', 'Sankt Peter-Ording', 'PSH,Sankt Peter-Ording,Sankt Peter-Oring,Sankt-Peter-Ording,St. Peter-Ording,sheng bi de-ao er ding,Санкт Петер-Ординг,Санкт-Петер-Ординг,圣彼得-奥尔丁', 54.3036300, 8.6413800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32180, 'Sankt Peter', 'Sankt Peter', 'Sankt Peter', 48.0147500, 8.0329400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32181, 'Sankt Michaelisdonn', 'Sankt Michaelisdonn', 'Saint Michaelisdonn,Sankt Michaelisdonn,Sankt Mikhaelisdon,Sankt-Mikhelisdon,sheng mi xia ai li si dong,Санкт Михаелисдон,Санкт-Михелисдон,圣米夏埃利斯东', 53.9833300, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32182, 'Sankt Martin', 'Sankt Martin', '', 49.3002800, 8.1052800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32183, 'Sankt Märgen', 'Sankt Margen', 'Sankt Margen,Sankt Märgen', 48.0080500, 8.0928300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32184, 'Sankt Margarethen', 'Sankt Margarethen', '', 53.8919900, 9.2530100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32185, 'Sankt Kilian', 'Sankt Kilian', 'Sankt Kilian', 50.5274900, 10.7630100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32186, 'Sankt Katharinen', 'Sankt Katharinen', '', 49.8666700, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32187, 'Sankt Julian', 'Sankt Julian', 'Sankt Julian,Sankt Julian-Obereisenbach,Sankt Julijan,Sankt-Julian,sheng you li an,Санкт Јулијан,Санкт-Юлиан,圣尤利安', 49.6166700, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32188, 'Sankt Johann', 'Sankt Johann', '', 50.3500000, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32189, 'Sankt Johann', 'Sankt Johann', '', 49.8675000, 8.0144400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32190, 'Sankt Johann', 'Sankt Johann', '', 48.4539700, 9.3439600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32191, 'Sankt Ingbert', 'Sankt Ingbert', 'Sankt Ingbert', 49.2769700, 7.1167200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32192, 'Sankt Goarshausen', 'Sankt Goarshausen', 'Saint Goarshausen,Sankt Goarshausen,Sankt Goarskhauzen,Sankt-Goarskhauzen,St. Goarshausen,sheng ge a er si hao sen,zankt ghwarshawzn,zankt gwarzhawzn,Санкт Гоарсхаузен,Санкт-Гоарсхаузен,زانكت غوارسهاوزن,زانکت گوارزهاوزن,ザンクト・ゴアールスハウゼン,圣戈阿尔斯豪森', 50.1583900, 7.7137400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32193, 'Sankt Goar', 'Sankt Goar', 'Sankt Goar,Sankt-Goar,sheng ge a er,zankt ghwar,zankt gwar,Санкт Гоар,Санкт-Гоар,زانكت غوار,زانکت گوار,ザンクト・ゴアー,圣戈阿尔', 50.1487800, 7.7072000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32194, 'Sankt Georgen im Schwarzwald', 'Sankt Georgen im Schwarzwald', 'Sankt Georgen,Sankt Georgen im Schwarzwald', 48.1271600, 8.3351300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32195, 'St. Georg', 'St. Georg', 'Sankt Georg', 53.5551300, 10.0123100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32196, 'Sankt Gangloff', 'Sankt Gangloff', 'Sankt Gangloff', 50.8552200, 11.8944600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32197, 'Sankt Egidien', 'Sankt Egidien', 'Saint Egidien,Sankt Egidien', 50.7861700, 12.6239500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32198, 'Sankt Blasien', 'Sankt Blasien', 'Saint Blasien,San Blasien,Sankt Blasien,St. Blasien', 47.7625200, 8.1271400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32199, 'Sankt Augustin', 'Sankt Augustin', 'Sankt Augustin,Sankt-Avgustin,Zankt-Augustin,sheng ao gu si ding,zankt agstyn,zankt awghstyn,Занкт-Аугустін,Санкт Аугустин,Санкт-Августин,زانكت آوغستين,زانکت آگستین,圣奥古斯丁', 50.7753800, 7.1970000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32200, 'Sankt Annen', 'Sankt Annen', '', 54.3464900, 9.0787000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32201, 'Sankt Andreasberg', 'Sankt Andreasberg', 'Saint-Andreasberg,Sankt Andreasberg,Sankt-Andreasberg,sheng an de li si bo ge,zankt andryasbrg,Санкт Андреасберг,Санкт-Андреасберг,زانکت آندریاسبرگ,聖安德里斯伯格', 51.7100400, 10.5186700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32202, 'Sankt Aldegund', 'Sankt Aldegund', '', 50.0833300, 7.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32203, 'Sankt Alban', 'Sankt Alban', '', 49.6833300, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32204, 'Sankelmark', 'Sankelmark', 'Sankelmark', 54.7180300, 9.4234400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32205, 'Alt-Sanitz', 'Alt-Sanitz', '', 53.8136300, 13.5878600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32206, 'Sangerhausen', 'Sangerhausen', 'Sangerhausen,Zangergauzen,Zangerkhauzen,jang-geohaujen,sang ge hao sen,zanghrhawzn,zangrhawzn,Зангергаузен,Зангерхаузен,زانغرهاوزن,زانگرهاوزن,桑格豪森,장거하우젠', 51.4722100, 11.2953300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32207, 'Sandstedt', 'Sandstedt', 'Gemeen Sands,Zandshtedt,Zandshtet,sang ci te,Зандштедт,Зандштет,桑茨特', 53.3598100, 8.5213700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32208, 'Sandhausen', 'Sandhausen', 'Sandhausen,Sondhause,Zandgauzen,Zandkhauzen,sang de hao sen,zantohauzen,Зандгаузен,Зандхаузен,ザントハウゼン,桑德豪森', 49.3427800, 8.6591700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32209, 'Sandesneben', 'Sandesneben', 'Sandesneben', 53.6833300, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32210, 'Sandersleben', 'Sandersleben', 'Sandersleben,Zandersleben,Зандерслебен', 51.6774500, 11.5679500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32211, 'Sandersdorf', 'Sandersdorf', 'Sandersdorf', 51.6284100, 12.2649200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32212, 'Sande', 'Sande', 'Sande', 53.5048900, 8.0141800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32213, 'Sandbostel', 'Sandbostel', 'Sandbossel,Zandbostel,Zandbostel'',sang de bo si te er,zantobosuteru,Зандбостел,Зандбостель,ザントボステル,桑德博斯特尔', 53.4093300, 9.1293000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32214, 'Sandberg', 'Sandberg', '', 50.3482400, 10.0081400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32215, 'Sandau', 'Sandau', 'Zandau,sang dao,zandaw,Зандау,زانداو,桑道', 52.7896800, 12.0458200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32216, 'Sand', 'Sand', '', 49.9858500, 10.5862000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32217, 'Samtens', 'Samtens', 'Zamtens,sa mu teng si,Замтенс,萨姆滕斯', 54.3548100, 13.2931100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32218, 'Samswegen', 'Samswegen', '', 52.2605900, 11.5617400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32219, 'Samerberg', 'Samerberg', 'Zamerberg,sa mo bei ge,zamrbrg,Замерберг,Զամերբերգ,زامربرگ,萨默贝格', 47.7765400, 12.1913900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32220, 'Salzweg', 'Salzweg', 'Zal''cveg,Zalcveg,sa er ci wei ge,saltswg,Залцвег,Зальцвег,Զալցվեգ,سالتسوگ,萨尔茨韦格', 48.6166700, 13.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32221, 'Salzwedel', 'Salzwedel', 'Salzwedel,Soltwedel,ZSQ,Zal''cvedel'',Zalcvedel,sa er ci wei de er,zaltsfydl,zaltswdl,Залцведел,Зальцведель,زالتسفيدل,زالتسودل,萨尔茨韦德尔', 52.8543500, 11.1525000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32222, 'Salzmünde', 'Salzmuende', 'Salzmunde,Salzmünde', 51.5266200, 11.8265000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32223, 'Salzkotten', 'Salzkotten', 'Zal''ckotten,Zalckoten,sa er ci ke teng,zaltsktn,zaltskwtn,Залцкотен,Зальцкоттен,زالتسكوتن,زالتسکتن,萨尔茨科滕', 51.6717000, 8.6009200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32224, 'Salzhemmendorf', 'Salzhemmendorf', 'Zal''ckhemmendorf,Zalckhemendorf,sa er ci hei men duo fu,zarutsuhenmendorufu,Залцхемендорф,Зальцхеммендорф,ザルツヘンメンドルフ,萨尔茨黑门多夫', 52.0670000, 9.5872000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32225, 'Salzhausen', 'Salzhausen', 'Zal''ckhauzen,Zalckhauzen,sa er ci hao sen,Залцхаузен,Зальцхаузен,萨尔茨豪森', 53.2233900, 10.1698100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32226, 'Salzburg', 'Salzburg', '', 50.6666700, 8.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32227, 'Salzbergen', 'Salzbergen', 'Salzbergen,Saoltbiaergen,Saoltbiärgen,Zal''cbergen,Zalcbergen,sa er ci bei er gen,Залцберген,Зальцберген,萨尔茨贝尔根', 52.3333300, 7.3500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32228, 'Salz', 'Salz', '', 50.5100000, 7.9636100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32229, 'Salz', 'Salz', '', 50.3084200, 10.2120500, 'DE', '2012-08-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32230, 'Salm', 'Salm', '', 50.1528700, 6.6905900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32231, 'Sallgast', 'Sallgast', 'Sallgast,Zalgast,Zalhozdz,Zall''gast,Załhozdź,sa er jia si te,Залгаст,Залльгаст,Զալգասթ,萨尔加斯特', 51.5887000, 13.8486100, 'DE', '2013-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32232, 'Salgen', 'Salgen', 'Zal''gen,Zalgen,sa er gen,Залген,Зальген,Զալգեն,萨尔根', 48.1306900, 10.4789000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32233, 'Salem', 'Salem', '', 53.6560000, 10.8263200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32234, 'Saldenburg', 'Saldenburg', 'Zal''denburg,Zaldenburg,sa er deng bao,Залденбург,Зальденбург,Զալդենբուրգ,萨尔登堡', 48.7731000, 13.3558600, 'DE', '2012-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32235, 'Salching', 'Salching', '', 48.8104700, 12.5704300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32236, 'Salach', 'Salach', 'Zalakh,Залах', 48.6919800, 9.7371500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32237, 'Sahms', 'Sahms', 'Sahms', 53.5254400, 10.5329600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32238, 'Sagard', 'Sagard', 'Zagard,sa jia er de,sgrd,Загард,سگرد,萨加尔德', 54.5255600, 13.5538700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32239, 'Saffig', 'Saffig', 'Zaffig,Zafig,sa fei xi,sffyg,Зафиг,Заффиг,سففیگ,萨菲希', 50.3833300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32240, 'Saerbeck', 'Saerbeck', 'Zarbek,Zerbek,sa ai er bei ke,sayrbk,zabekku,Зарбек,Зербек,سائربک,ザーベック,萨埃尔贝克', 52.1737200, 7.6339500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32241, 'Sachsenkam', 'Sachsenkam', 'Zakhsenkam,Zaksenkam,sa sen ka mu,schsnkm,zaksnkam,Заксенкам,Захсенкам,Զաքսենկամ,زاکسنکام,سچسنکم,萨森卡姆', 47.8054300, 11.6439600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32242, 'Sachsenhausen', 'Sachsenhausen', '', 51.2433800, 9.0097300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32243, 'Sachsenhausen', 'Sachsenhausen', '', 51.0500000, 11.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32244, 'Sachsenhagen', 'Sachsenhagen', 'Zakhsenkhagen,Zaksenkhagen,sa sen ha gen,zaksnhaghn,zakusenhagen,Заксенхаген,Захсенхаген,زاكسنهاغن,زاکسن‌هاگن,سچسنھاگیں,ザクセンハーゲン,萨森哈根', 52.3973400, 9.2679100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32245, 'Sachsen', 'Sachsen', '', 49.2899900, 10.6597100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32246, 'Saarwellingen', 'Saarwellingen', 'Saarvellingen,Saarwellingen,Sarrevailingue,Sarvelingen,Vailingua,sa er wei lin gen,sarwlngn,zarwlyngn,Саарвеллинген,Саарвеллінген,Сарвелинген,زارولینگن,سارولنگن,萨尔韦林根', 49.3543000, 6.8048700, 'DE', '2012-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32247, 'Saarlouis', 'Saarlouis', 'Saarlouis,Saarlui,Saarluis,Saarluise,Sarlouis,Sarrelouis,ZPT,Zarlui,jaleullu-i,sa er lu yi,sarlwys,zaarlui,zarlwyys,zarurui,Зарлуи,Саарлуис,Саарлуисе,Саарлуї,Сарлоуис,סארלואי,زارلوئیس,زارلوييس,سارلوئس,ზაარლუი,ザールルイ,萨尔路易,자를루이', 49.3136600, 6.7515400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32248, 'Saarhölzbach', 'Saarhoelzbach', '', 49.5158500, 6.6074200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32249, 'Saarburg', 'Saarburg', 'Saarburg,Saarmpournk,Sarburg,Sarrebourg,sa er bao,sarbrg,zaarburgi,zarbwrg,zarbwrgh,zaruburuku,Σάαρμπουργκ,Саарбург,Сарбург,زاربورغ,زاربورگ,ساربرگ,ზაარბურგი,ザールブルク,萨尔堡', 49.6064100, 6.5436500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32250, 'Saarbrücken', 'Saarbruecken', 'Gorad Saarbruken,SCN,Saarbrecken,Saarbrigge,Saarbrjuken,Saarbrjukken,Saarbrucken,Saarbruecken,Saarbruekken,Saarbrécken,Saarbrücken,Saarbrükken,Saarmpryken,Saravipons,Sarbriken,Sarbriukenas,Sarbruch,Sarebryken,Sarrebruck,Sarëbryken,Sárbrúch,Zarbrikene,Zārbrikene,jaleubeulwiken,jarabryukana,sa er bu lu ken,sar brukhkhein,sarabrukena,sarbrkn,sarbrwkn,sha bo qin,zarbrwkn,zaruburyukken,Σααρμπρύκεν,Горад Саарбрукен,Саарбрюкен,Саарбрюккен,Сарбрикен,Սաարբրյուքեն,זארבריקן,زاربروکن,ساربروكن,ساربروکن,ساربرکن,जारब्र्युकन,सारब्रुकेन,ซาร์บรึคเคิน,ზაარბრიუკენი,ザールブリュッケン,沙卜勤,萨尔布吕肯,자르브뤼켄', 49.2326200, 7.0098200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32251, 'Saara', 'Saara', '', 50.9328400, 12.4209600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32252, 'Saalstadt', 'Saalstadt', '', 49.3166700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32253, 'Saalfeld', 'Saalfeld', 'Gorad Zaal''fel''d,Saalfeld,Saalfeld/Saale,Zaal''fel''d,Zal''fel''d,Zalfeld,sa er fei er de,zalfld,zaruferuto,Горад Заальфельд,Заальфельд,Залфелд,Зальфельд,زالفلد,سالفیلڈ,ザールフェルト,萨尔费尔德', 50.6482600, 11.3653600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32254, 'Saal an der Saale', 'Saal an der Saale', 'Saal a. d. Saale,Saal an der Saale,Zaal''-an-der-Zaale,Zaal''-na-Zaale,Zaali Zaal,Zal an der Zale,Zal''-an-der-Zale,Зааль-ан-дер-Заале,Зааль-на-Заале,Зал ан дер Зале,Заль-ан-дер-Зале,Զաալի Զաալ,سال ان در سالے', 50.3167300, 10.3576900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32255, 'Saal', 'Saal', '', 54.3105100, 12.4993500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32256, 'Saal', 'Saal', '', 48.9009900, 11.9319600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32257, 'Rutsweiler an der Lauter', 'Rutsweiler an der Lauter', 'Rutsvajler na Lauteru,Rutsvajler-na-Lautere,lao te er he pan lu ci wei lei,Рутсвайлер-на-Лаутере,Рутсвајлер на Лаутеру,劳特尔河畔鲁茨韦勒', 49.5666700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32258, 'Ruthweiler', 'Ruthweiler', 'Rutvajler,lu te wei lei,Рутвайлер,Рутвајлер,鲁特韦勒', 49.5500000, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32259, 'Rüthnick', 'Ruthnick', 'Ruethnick,Rüthnick', 52.8812000, 12.9964800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32260, 'Rüthen', 'Ruethen', 'Riten,Rjuten,Ruethen,Ruihen,Rüthen,lu teng,rwtn,Ритен,Рютен,روتن,吕滕', 51.4909000, 8.4359600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32261, 'Rutesheim', 'Rutesheim', '', 48.8080800, 8.9453600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32262, 'Rustenfelde', 'Rustenfelde', 'Rustenfelde', 51.4000000, 10.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32263, 'Rust', 'Rust', '', 48.2666700, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32264, 'Rüssingen', 'Russingen', 'Ruessingen,Rüssingen', 49.6158300, 8.0883300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32265, 'Rüsselsheim', 'Ruesselsheim', 'Gorad Rusel''sgajm,Riselsheima,Riselskhajm,Rjussel''sgajm-am-Majn,Rjussel''skhajm,Rjusselskhajm,Rouselschaim,Ruesselsheim,Ruesselsheim am Main,Russelsheim,Rüsselsheim,Rüsselsheim am Main,lu sai er si hai mu,rwslshaym,rwslshyym,rwslzhaym,ryusserusuhaimu,Ρουσελσχάιμ,Горад Русельсгайм,Риселсхајм,Рюсселсхайм,Рюссельсгайм-ам-Майн,Рюссельсхайм,רוסלסהיים,روسلزهایم,روسلسهايم,リュッセルスハイム,吕塞尔斯海姆', 49.9895500, 8.4225100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32266, 'Rüscheid', 'Ruescheid', 'Ruescheid,Rüscheid', 50.5333300, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32267, 'Ruschberg', 'Ruschberg', '', 49.6197300, 7.2893400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32268, 'Ruppichteroth', 'Ruppichteroth', 'Rupikhterot,Ruppikhterot,lu pi xi te luo te,Рупихтерот,Руппихтерот,Руппіхтерот,鲁皮希特罗特', 50.8436700, 7.4840900, 'DE', '2011-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32269, 'Ruppertsweiler', 'Ruppertsweiler', '', 49.1970700, 7.6895700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32270, 'Ruppertshofen', 'Ruppertshofen', '', 50.2008600, 7.8055300, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32271, 'Ruppertshofen', 'Ruppertshofen', '', 48.8827500, 9.8150600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32272, 'Ruppertsecken', 'Ruppertsecken', '', 49.6500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32273, 'Ruppertsberg', 'Ruppertsberg', '', 49.4002800, 8.1961100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32274, 'Runkel', 'Runkel', 'Runkel,Runkel'',lun ke er,rwnkl,Рункел,Рункель,رونكل,رونکل,伦克尔', 50.4057400, 8.1545700, 'DE', '2013-08-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32275, 'Runding', 'Runding', 'Runding,Runting,lun ding,Рундинг,Рундінг,Ռունդինգ,伦丁', 49.2151300, 12.7620800, 'DE', '2012-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32276, 'Rümpel', 'Rumpel', 'Ruempel,Rumpel,Rümpel', 53.7833300, 10.3500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32277, 'Rumohr', 'Rumohr', 'Rumohr', 54.2556200, 10.0244900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32278, 'Rümmingen', 'Ruemmingen', 'Rimingen,Rjummingen,lu ming gen,Риминген,Рюмминген,Рюммінген,吕明根', 47.6412000, 7.6419800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32279, 'Rümmelsheim', 'Rummelsheim', 'Rimelskhajm,Rjummel''skhajm,lu mei er si hai mu,Римелсхајм,Рюммельсхайм,吕梅尔斯海姆', 49.9330700, 7.8597700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32280, 'Rummelsburg', 'Rummelsburg', 'Berlin-Rummelsburg', 52.5014600, 13.4934000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32281, 'Rumbach', 'Rumbach', '', 49.0966000, 7.7876500, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32282, 'Rülzheim', 'Ruelzheim', 'Ruelzheim,Rülzheim', 49.1531200, 8.2928700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32283, 'Rullstorf', 'Rullstorf', '', 53.2864500, 10.5297200, 'DE', '2011-09-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32284, 'Ruhwinkel', 'Ruhwinkel', 'Ruhwinkel,Rukhvinkel,Ruvinkel,Ruvinkel'',lu wen ke er,Рувинкел,Рувинкель,Рухвинкел,鲁温克尔', 54.1000000, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32285, 'Ruhstorf', 'Ruhstorf', '', 48.5397600, 12.6830500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32286, 'Rühstädt', 'Ruhstadt', 'Rikhshtet,Rishtet,Rjushtedt,lu he si te,Рихштет,Риштет,Рюштедт,吕赫斯特', 52.9166700, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32287, 'Ruhpolding', 'Ruhpolding', 'Ruahpading,Ruhpolding,Ruhpoldingi vald,Rupol''ding,Rupolding,Rupoldinga,Rupolting,Rūpoldinga,lu bo er ding,rwpwldyng,Руполдинг,Рупольдинг,Рупольдінг,Ռուփոլդինգ,روپولدینگ,鲁波尔丁', 47.7666700, 12.6500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32288, 'Ruhmannsfelden', 'Ruhmannsfelden', 'Ruemansfelden,Ruhmannsfelden,Rumannsfel''den,Rumansfel''den,Rumansfelden,lu man si fei er deng,rwmansfldn,Руманнсфельден,Румансфелден,Румансфельден,Ռումանսֆելդեն,رومانسفلدن,鲁曼斯费尔登', 48.9832700, 12.9834700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32289, 'Ruhland', 'Ruhland', 'Rolany,Ruhland,Ruland,Rólany,lu lan,rwhland,rwhlnd,Руланд,Ռուլանդ,روهلاند,روهلند,鲁兰', 51.4575500, 13.8664300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32290, 'Ruhla', 'Ruhla', 'Ruhla,Rula,rura,rwla,Рула,رولا,ルーラ', 50.8929600, 10.3657300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32291, 'Rühen', 'Ruhen', 'Rijen,Rjuehn,Ruehen,Ruhen,Rühen,lu heng,Ријен,Рюэн,吕亨', 52.4856000, 10.8864200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32292, 'Rügland', 'Rugland', 'Rigland,Rjugland,Rugland,Ryugland,Rügland,lu ge lan,ryukuranto,Ригланд,Рюгланд,Ռյուգլանդ,リュクラント,吕格兰', 49.4000000, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32293, 'Rügge', 'Rugge', 'Ruegge,Rugge,Rügge', 54.6833300, 9.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32294, 'Rugendorf', 'Rugendorf', 'Rugendorf,lu gen duo fu,rugendorufu,Ругендорф,Ռուգենդորֆ,ルーゲンドルフ,鲁根多夫', 50.2000000, 11.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32295, 'Rudow', 'Rudow', 'Berlin-Rudow', 52.4240700, 13.4852900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32296, 'Rudolstadt', 'Rudolstadt', 'Rudol''shtadt,Rudolphopolis,Rudolshhat,Rudolshtat,Rudolstadt,lu duo er si ta te,rwdwlshtat,Рудолштат,Рудолщат,Рудольштадт,رودل‌اشتات,رودولشتات,鲁多尔斯塔特', 50.7204300, 11.3404600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32297, 'Rüdnitz', 'Rudnitz', 'Ridnic,Rjudnic,lu de ni ci,Ридниц,Рюдниц,Ռյուդնից,吕德尼茨', 52.7213700, 13.6250200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32298, 'Rüdesheim am Rhein', 'Ruedesheim am Rhein', 'QSY,Rideskhajm na Rajni,Rjudesgajm-am-Rajn,Rjudeskhajm-am-Rajn,Rjudeskhajm-na-Rejne,Rudesheim,Rudesheim am Rhein,Ruedesheim am Rhein,Rüdesheim,Rüdesheim am Rhein,lai yin he pan lu de si hai mu,rwdzhaym am rayn,Ридесхајм на Рајни,Рюдесгайм-ам-Райн,Рюдесхайм-ам-Райн,Рюдесхайм-на-Рейне,رودزهایم آم راین,リューデスハイム・アム・ライン,莱茵河畔吕德斯海姆', 49.9821400, 7.9296400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32299, 'Rüdesheim', 'Rudesheim', 'Rideskhajm,Rjudeskhajm,Ruedesheim am Rhein,Ruedesheim an der Nahe,Rüdesheim am Rhein,Rüdesheim an der Nahe,lu de si hai mu,Ридесхајм,Рюдесхайм,吕德斯海姆', 49.8500000, 7.8166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32300, 'Ruderting', 'Ruderting', 'Ruderting,lu de ting,rwdrtyng,Рудертинг,Рудертінг,Ռուդերթինգ,رودرتینگ,鲁德廷', 48.6500000, 13.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32301, 'Rüdershausen', 'Rudershausen', 'Riderskhauzen,Rjuderskhauzen,lu de er si hao sen,ryudasuhauzen,Ридерсхаузен,Рюдерсхаузен,リューダースハウゼン,吕德尔斯豪森', 51.5833300, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32302, 'Rudersdorf', 'Rudersdorf', '', 51.1000000, 11.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32303, 'Rudersberg', 'Rudersberg', 'Rudersberg,lu de si bei ge,Рудерсберг,鲁德斯贝格', 48.8851500, 9.5292700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32304, 'Ruderatshofen', 'Ruderatshofen', 'Ruderatsgofen,Ruderatshofen,Ruderatskhofen,lu de la ci huo fen,ruderatsuhofen,Рудератсгофен,Рудератсхофен,Ռուդերատսհոֆեն,ルーデラーツホーフェン,鲁德拉茨霍芬', 47.8166700, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32305, 'Rüdenau', 'Rudenau', 'Ridenau,Rjudenau,Ryudenau,lu de nao,ryudenau,Риденау,Рюденау,Ռյուդենաու,リューデナウ,吕德瑙', 49.7113900, 9.1791700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32306, 'Rudelzhausen', 'Rudelzhausen', '', 48.6000000, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32307, 'Rückweiler', 'Ruckweiler', 'Rueckweiler,Rückweiler', 49.5833300, 7.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32308, 'Rückholz', 'Ruckholz', 'Rikkholc,Rjukgol''c,Rjukkhol''c,lu ke huo er ci,ryukkuhorutsu,Рикхолц,Рюкгольц,Рюкхольц,Ռյուկհոլց,リュックホルツ,吕克霍尔茨', 47.6666700, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32309, 'Rückersdorf', 'Rueckersdorf', '', 51.5695500, 13.5722600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32310, 'Rückersdorf', 'Ruckersdorf', '', 50.8219300, 12.2203200, 'DE', '2015-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32311, 'Rückersdorf', 'Ruckersdorf', '', 49.4975700, 11.2475100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32312, 'Rückeroth', 'Rueckeroth', 'Rueckeroth,Rückeroth', 50.5616700, 7.7452800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32313, 'Rüber', 'Ruber', 'Rueber,Rüber', 50.3000000, 7.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32314, 'Rübeland', 'Ruebeland', 'Rubeland,Rübeland', 51.7559100, 10.8466000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32315, 'Roxheim', 'Roxheim', 'Rokskhajm,luo ke si hai mu,Роксхайм,Роксхајм,罗克斯海姆', 49.8666700, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32316, 'Rövershagen', 'Roevershagen', 'Mittelrovershagen,Mittelrövershagen,Reverskhagen,Rjoverskhagen,Roevershagen,Rövershagen,lei fei er si ha gen,Реверсхаген,Рёверсхаген,勒费尔斯哈根', 54.1766800, 12.2427600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32317, 'Rötz', 'Roetz', 'Rec,Retz,Rjoc,Rotz,Rötz,lei ci,rwts,Рец,Рёц,Ռյոց,روتس,勒茨', 49.3431600, 12.5296300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32318, 'Rottweil', 'Rottweil', 'Rottovilla,Rottweil,Rotvajl,Rotvajl'',loteubail,luo te wei er,rtwayl,rwtfayl,rwtwwyyl,Ротвайл,Ротвайль,Ротвајл,רוטווייל,رتوایل,روتفايل,როტვაილი,罗特魏尔,로트바일', 48.1678300, 8.6271900, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32319, 'Rottleberode', 'Rottleberode', 'Rotleberode,Rottleberode,Ротлебероде', 51.5163600, 10.9465800, 'DE', '2017-07-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32320, 'Röttingen', 'Rottingen', 'Retingen,Rettingen,Rjottingen,Roettingen,Rottingen,Röttingen,lei ting gen,rettingen,rwtynghn,rwtyngn,Ретинген,Реттінген,Рёттинген,Ռյոթինգեն,روتينغن,روتینگن,レッティンゲン,勒廷根', 49.5096900, 9.9708200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32321, 'Rotthalmünster', 'Rotthalmunster', 'Minster,Rotalminster,Rottal''mjunster,Rotthalmuenster,Rotthalmünster,luo ta er ming si te er,rwthal mwnstr,Роталминстер,Роттальмюнстер,Ռոթալմյունսթեր,روتهال مونستر,罗塔尔明斯特尔', 48.3582500, 13.2016200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32322, 'Rotterode', 'Rotterode', 'Rotterode', 50.7122200, 10.5537400, 'DE', '2015-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32323, 'Rottendorf', 'Rottendorf', 'Rotendorf,Rottendorf,luo teng duo fu,rottendorufu,Ротендорф,Роттендорф,Ռոթենդորֆ,ロッテンドルフ,罗滕多夫', 49.7923000, 10.0259300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32324, 'Rottenburg an der Laaber', 'Rottenburg an der Laaber', 'Rotenburg an der Laber,Rottenburg,Rottenburg an der Laaber,Rottenburg-an-der-Laaber,Rottenburg-an-der-Laber,Rottenburg-na-Labere,rtnbwrg an dr labr,rwtnbwrgh an dr labr,Ротенбург ан дер Лабер,Роттенбург-ан-дер-Лаабер,Роттенбург-ан-дер-Лабер,Роттенбург-на-Лабере,Լաբերի Ռոթենբուրգ,رتنبورگ آن در لابر,روتنبورغ أن در لآبر', 48.7023300, 12.0271700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32325, 'Rottenburg', 'Rottenburg', '', 48.4762900, 8.9352800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32326, 'Rottenbuch', 'Rottenbuch', 'Raitenbuch,Rotenbukh,Rottenbuch,Rottenbukh,luo teng bu,rottenbufu,rwtnbwkh,Ротенбух,Роттенбух,Ռոթենբուխ,روتنبوخ,ロッテンブーフ,罗滕布', 47.7333300, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32327, 'Rottenbach', 'Rottenbach', 'Rottenbach', 50.6878200, 11.1667400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32328, 'Röttenbach', 'Rottenbach', '', 49.6642900, 10.9260700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32329, 'Röttenbach', 'Rottenbach', '', 49.1500000, 11.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32330, 'Rottenacker', 'Rottenacker', 'Rotenaker,Rottenaker,Rottenakker,luo te na ke er,Ротенакер,Роттенакер,Роттенаккер,Ռոթենակեր,როტენაკერი,罗特纳克尔', 48.2348500, 9.6895600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32331, 'Rottach-Egern', 'Rottach-Egern', 'Rotakh-Egern,Rottakh-Egern,Rottakh-Ehgern,luo ta-ai ge er en,rwtakh-agrn,Ротах-Егерн,Роттах-Егерн,Роттах-Эгерн,Ռոթախ Էգերն,روتاخ-اگرن,罗塔-埃格尔恩', 47.6896600, 11.7706500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32332, 'Rott', 'Rott', '', 50.6333300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32333, 'Rott', 'Rott', '', 47.9200800, 12.0877100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32334, 'Rott', 'Rott', 'Rot,Rott,rotto,rwt,Рот,Ротт,Ռոթ,روت,ロット', 47.9047000, 10.9729200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32335, 'Rötsweiler-Nockenthal', 'Roetsweiler-Nockenthal', 'Roetsweiler-Nockenthal,Rötsweiler-Nockenthal', 49.7166700, 7.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32336, 'Rothselberg', 'Rothselberg', 'Rotselberg,Rotzel''berg,luo te se er bei ge,Ротзельберг,Ротселберг,罗特瑟尔贝格', 49.5500000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32337, 'Röthlein', 'Rothlein', 'Retlajn,Retljajn,Rjotlajn,Roethlein,Röthlein,lei te lai yin,rwtlayn,Ретлајн,Ретляйн,Рётлайн,روتلاین,勒特莱因', 49.9833300, 10.2166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32338, 'Rothenstein', 'Rothenstein', '', 50.8500000, 11.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32339, 'Rothenfels', 'Rothenfels', 'Rotenfel''s,Rotenfels,Rothenfels,luo teng fei er si,rtnflz,rwtnflz,Ротенфелс,Ротенфельс,Ռոթենֆելս,رتنفلز,روتنفلز,罗滕费尔斯', 49.8913500, 9.5926000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32340, 'Rothenburg ob der Tauber', 'Rothenburg ob der Tauber', 'Rotenburg ob der Tauber,Rotenburg povrkh Taubera,Rotenburg-Tauber-langso,Rotenburg-na-Taubere,Rotenburg-na-Tauberi,Rotenburg-ob-der-Tauber,Rotenburga pie Tauberes,Rothenburg,Rothenburg nad Tauber,Rothenburg ob der Tauber,Rothenburg upon Tauber,Tauberei Rotenburg,lotenbuleukeu opeu deeo taubeo,luo teng bao,rtnbwrg ab dr tawbr,rwtnbwrgh ab dyr tawbr,Ротенбург об дер Таубер,Ротенбург поврх Таубера,Ротенбург-Таубер-лангсо,Ротенбург-на-Таубере,Ротенбург-на-Таубері,Ротенбург-об-дер-Таубер,Տաուբերեի Ռոտենբուրգ,ראטנבורג,רוטנבורג על הטאובר,رتنبورگ آب در تاوبر,روتنبورغ أب دير تاوبر,ローテンブルク・オプ・デア・タウバー,罗滕堡,로텐부르크 오프 데어 타우버', 49.3788500, 10.1871100, 'DE', '2016-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32341, 'Rothenburg', 'Rothenburg', 'Rothenburg,Rothenburg/Oberlausitz', 51.3340000, 14.9687400, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32342, 'Rothenbuch', 'Rothenbuch', 'Rotenbukh,Rotenbux,rotenbufu,Ротенбух,Ռոտենբուխ,ローテンブーフ', 49.9652800, 9.3938900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32343, 'Rothenberg', 'Rothenberg', 'Rotenberg,luo teng bei ge,rotenberuku,Ротенберг,ローテンベルク,罗滕贝格', 49.4991700, 8.9191700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32344, 'Röthenbach an der Pegnitz', 'Rothenbach an der Pegnitz', 'Retenbakh na Pegnicu,Retenbakh-an-der-Pegnic,Rjotenbakh-an-der-Pegnic,Roethenbach an der Pegnitz,Rothenbach,Röthenbach,Röthenbach an der Pegnitz,pei ge ni ci he pan lei teng ba he,rwtnbakh an dr bghnytz,rwtnbakh an dr pgnytz,Ретенбах на Пегницу,Ретенбах-ан-дер-Пегніц,Рётенбах-ан-дер-Пегниц,Պեգնիցի Ռյոթենբախ,روتنباخ آن در بغنيتز,روتنباخ آن در پگنیتز,佩格尼茨河畔勒滕巴赫', 49.4830100, 11.2411600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32345, 'Rothenbach', 'Rothenbach', '', 50.5641700, 7.9033300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32346, 'Röthenbach', 'Rothenbach', 'Retenbakh,Rjotenbakh,Rothenbach,Röthenbach,Ретенбах,Рётенбах,Ռյոթենբախ', 47.6230300, 9.9738700, 'DE', '2014-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32347, 'Rötha', 'Roetha', 'Reta,Rjota,Roetha,Rotha,Rötha,Rēta,lei ta,rwta,Рета,Рёта,Рөта,روتا,勒塔', 51.1978300, 12.4144700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32348, 'Roth', 'Roth', '', 50.7623000, 7.7001600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32349, 'Roth', 'Roth', '', 50.2669100, 7.8963400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32350, 'Roth', 'Roth', '', 50.0833300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32351, 'Roth', 'Roth', 'Rot,Рот', 49.9333300, 7.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32352, 'Roth', 'Roth', 'Rot,Rota,Roth,Roth bei Nuernberg,Roth bei Nürnberg,luo te,rosu,roto,rwt,rwth bay nwrnbrg,Рот,Рота,רות,روث بای نورنبرگ,ロス,ロート,罗特', 49.2476200, 11.0911100, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32353, 'Rötgesbüttel', 'Rotgesbuttel', 'Retgesbitel,Rjotgesbjuttel'',Roetgesbuettel,Rötgesbüttel,lei te ge si bi te er,Ретгесбител,Рётгесбюттель,勒特格斯比特尔', 52.4166700, 10.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32354, 'Roetgen', 'Roetgen', 'Li Reutxhene,Retgen,Rjotgen,Roetgen,Rotgen,Ruutsje,Rötgen,luo ai te gen,Ретген,Рётген,罗埃特根', 50.6500000, 6.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32355, 'Rotenhain', 'Rotenhain', '', 50.6000000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32356, 'Rotenburg an der Fulda', 'Rotenburg an der Fulda', 'Gorad Rotehnburg-na-Ful''dze,Rotemburgo do Fulda,Rotenburg,Rotenburg an der Fulda,Rotenburg na Fulda,Rotenburg-na-Ful''de,Rotenburg-na-Ful''di,rwtnbwrg an dr fwlda,rwtnbwrgh an dr fwlda,Горад Ротэнбург-на-Фульдзе,Ротенбург ан дер Фулда,Ротенбург на Фулда,Ротенбург-на-Фульде,Ротенбург-на-Фульді,روتنبورغ أن در فولدا,روتنبورگ آن در فولدا', 50.9955600, 9.7283800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32357, 'Rotenburg', 'Rotenburg', 'Rotenburg,Ротенбург', 53.1112500, 9.4108200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32358, 'Rot an der Rot', 'Rot an der Rot', 'Rot an der Rot,Rot-an-der-Rot,luo te he pan luo te,Рот ан дер Рот,Рот-ан-дер-Рот,罗特河畔罗特', 48.0129500, 10.0302600, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32359, 'Rot am See', 'Rot am See', 'Rot,Rot am See,Rot am Ze,Rot-am-Ze,bin hu luo te,Рот ам Зе,Рот-ам-Зе,ロート・アム・ゼー,滨湖罗特', 49.2500000, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32360, 'Rot', 'Rot', '', 47.9227800, 9.1048500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32361, 'Rostock', 'Rostock', 'Gorad Rostak,RLG,Roshhok,Roshtok,Rostochium,Rostock,Rostok,Rostoka,Rostokas,Roztok,loseutokeu,luo si tuo ke,rosutokku,rwstwk,rwstwq,rxs thxkh,Ρόστοκ,Горад Ростак,Росток,Рошток,Рощок,רוסטוק,روستوك,روستوک,روسٹاک,รอสทอค,როსტოკი,ロストック,罗斯托克,로스토크', 54.0887000, 12.1404900, 'DE', '2014-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32362, 'Roßwein', 'Rosswein', 'Rosswein,Rosvajn,Rosveina,Roswin,Roßwein,luo si wei yin,rswayn,rwsfayn,Росвайн,Росвајн,رسواین,روسفاين,罗斯韦因', 51.0658900, 13.1830800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32363, 'Roßtal', 'Rosstal', 'Rosstal,Rostal,Rostal'',Roßtal,luo si ta er,Ростал,Росталь,Ռոսթալ,罗斯塔尔', 49.3956700, 10.8884800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32364, 'Roßleben', 'Rossleben', 'Rosleben,Rossleben,Roßleben,luo si lai ben,rwslbn,rwslybn,Рослебен,روسلبن,روسليبن,罗斯莱本', 51.2988600, 11.4343500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32365, 'Roßlau', 'Rosslau', 'Roslau,Rosslau,Roßlau,luo si lao,Рослау,罗斯劳', 51.8873600, 12.2419200, 'DE', '2016-11-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32366, 'Roßla', 'Rossla', 'Rosla,Росла', 51.4633100, 11.0757600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32367, 'Roßhaupten', 'Rosshaupten', '', 48.4294300, 10.4691100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32368, 'Roßhaupten', 'Rosshaupten', 'Rosgaupten,Roshaupten,Roskhaupten,luo si hao pu teng,rosuhauputen,Росгауптен,Росхауптен,Ռոսհաուպտեն,ロスハウプテン,罗斯豪普滕', 47.6500000, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32369, 'Roßdorf', 'Rossdorf', '', 50.7000000, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32370, 'Roßdorf', 'Rossdorf', 'Rossdorf,Roßdorf', 49.8597200, 8.7616700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32371, 'Rossbach', 'Rossbach', '', 48.5833300, 12.9500000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32372, 'Roßbach', 'Rossbach', '', 50.6050600, 7.6818200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32373, 'Roßbach', 'Rossbach', '', 50.5750000, 7.4161100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32374, 'Roßbach', 'Rossbach', '', 48.6000000, 12.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32375, 'Rösrath', 'Roesrath', 'Resrat,Rjosrat,Roesrath,Roesrod,Rösrath,Rösrod,lei si la te,rsrath,rwsrat,Ресрат,Рёсрат,رسراث,روسرات,勒斯拉特', 50.8955900, 7.1817500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32376, 'Roskow', 'Roskow', 'Roskov,luo si ke,Росков,Ռոսկով,罗斯科', 52.4723700, 12.7188600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32377, 'Rositz', 'Rositz', 'Rositz,Rozic,luo xi ci,Розиц,罗西茨', 51.0172800, 12.3635400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32378, 'Rosenthal', 'Rosenthal', 'Berlin-Rosenthal,Rozental'',Розенталь', 52.5997600, 13.3777400, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32379, 'Rosenthal', 'Rosenthal', 'Rosenthal', 50.9743900, 8.8673600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32380, 'Rosenow', 'Rosenow', 'Rosenow', 53.6296600, 13.0384900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32381, 'Rosenkopf', 'Rosenkopf', '', 49.3500000, 7.4333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32382, 'Rosenheim', 'Rosenheim', 'Gorad Rozenkhajm,Pons Aeni,Rosenheim,Rousnam,Rozengajm,Rozenkhajm,ZPR,lojenhaim,luo sen hai mu,rozenhaimu,rznhaym,Горад Розенхайм,Розенгайм,Розенхайм,Розенхајм,رزنهایم,ローゼンハイム,罗森海姆,로젠하임', 47.8563700, 12.1224700, 'DE', '2015-10-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32383, 'Rosenfeld', 'Rosenfeld', '', 48.2863900, 8.7235700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32384, 'Rosendorf', 'Rosendorf', '', 50.7666700, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32385, 'Rosenberg', 'Rosenberg', 'Rozenberg,rozenberuku,Розенберг,ローゼンベルク', 49.4558300, 9.4730600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32386, 'Rosenberg', 'Rosenberg', '', 49.0189200, 10.0296000, 'DE', '2017-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32387, 'Roseburg', 'Roseburg', 'Roseburg', 53.5299800, 10.6264300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32388, 'Rosdorf', 'Rosdorf', '', 53.9780200, 9.7273900, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32389, 'Rosdorf', 'Rosdorf', 'Rosdorf,luo si duo fu,rosudorufu,Росдорф,ロスドルフ,罗斯多夫', 51.5000000, 9.9000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32390, 'Roscheid', 'Roscheid', '', 50.1166700, 6.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32391, 'Rosche', 'Rosche', 'Roshe,luo she,Роше,罗舍', 52.9866300, 10.7518400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32392, 'Roschbach', 'Roschbach', '', 49.2461100, 8.1188900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32393, 'Rosbach vor der Höhe', 'Rosbach vor der Hoehe', 'Rosbach,Rosbach vor der Hoehe,Rosbach vor der Höhe,Rosbakh for der Khee,Rosbakh-for-der-Gee,Rosbakh-for-der-Khjoeh,rwzbakh fwr dr hwyh,rwzbakh wr dr hwhh,shan qian luo si ba he,Росбах фор дер Хее,Росбах-фор-дер-Геє,Росбах-фор-дер-Хёэ,روزباخ فور در هويه,روزباخ ور در هوهه,ロスバッハ・フォア・デア・ヘーエ,山前罗斯巴赫', 50.3033200, 8.6897600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32394, 'Rosa', 'Rosa', '', 50.7120000, 10.2499900, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32395, 'Rorodt', 'Rorodt', '', 49.7666700, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32396, 'Ronshausen', 'Ronshausen', 'Ronsgauzen,Ronskhauzen,long si hao sen,Ронсгаузен,Ронсхаузен,龙斯豪森', 50.9500000, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32397, 'Ronsberg', 'Ronsberg', 'Ronsberg,long si bei ge,ronsuberuku,rwnzbrg,Ронсберг,Ռոնսբերգ,رونزبرگ,ロンスベルク,龙斯贝格', 47.8958000, 10.4157100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32398, 'Ronnenberg', 'Ronnenberg', 'Ronenberg,Ronnenberg,luo nen bei ge,rnnbwrg,rwnnbrgh,Роненберг,Ронненберг,رننبورگ,روننبرغ,罗嫩贝格', 52.3193900, 9.6554400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32399, 'Ronneburg', 'Ronneburg', 'Roneburg,Ronneburg,rnnbwrg,Ронебург,Роннебург,رننبورگ', 50.8634000, 12.1866600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32400, 'Rondeshagen', 'Rondeshagen', 'Rondeshagen', 53.7500000, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32401, 'Römstedt', 'Romstedt', 'Remshtet,Rjomshtedt,lei mu si te,Ремштет,Рёмштедт,勒姆斯特', 53.1000000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32402, 'Romrod', 'Romrod', 'Romrod,luo mu luo de,rmrwd,romuroto,rwmrwd,Ромрод,رمرود,رومرود,ロムロート,罗姆罗德', 50.7134100, 9.2201000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32403, 'Römnitz', 'Romnitz', 'Romnitz,Römnitz', 53.7166700, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32404, 'Rommerskirchen', 'Rommerskirchen', 'Romerskirkhen,Rommerskirchen,Rommerskirkhen,luo mei er si ji xing,Ромерскирхен,Роммерскирхен,Роммерскірхен,罗梅尔斯基兴', 51.0333300, 6.6833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32405, 'Rommersheim', 'Rommersheim', '', 50.2000000, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32406, 'Römhild', 'Roemhild', 'R''omkhild,Remkhild,Rjomkhil''d,Romhild,Römhild,lei mu xi er de,rwhyld,rwmhyld,Ремхилд,Рьомхилд,Рёмхильд,رومهيلد,روهیلد,勒姆希尔德', 50.3963900, 10.5388900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32407, 'Rollshausen', 'Rollshausen', '', 51.5666700, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32408, 'Röllbach', 'Rollbach', 'Rel''bakh,Relbakh,Rjol''bakh,Ryolbax,rerubahha,Релбах,Рельбах,Рёльбах,Ռյոլբախ,レルバッハ', 49.7730600, 9.2461100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32409, 'Roklum', 'Roklum', '', 52.0666300, 10.7408500, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32410, 'Roitzsch', 'Roitzsch', 'Roitzsch', 51.5752600, 12.2633100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32411, 'Roigheim', 'Roigheim', 'Gjorsbakh,Roigheim,Roigkhajm,Rojgajm,Rojgkhajm,lao ge hai mu,roikuhaimu,Гёрсбах,Роигхајм,Ройгайм,Ройгхайм,ロイクハイム,勞格海姆', 49.3647200, 9.3400000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32412, 'Röhrsen', 'Roehrsen', 'Rohrsen,Röhrsen', 52.7107800, 9.2313900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32413, 'Röhrnbach', 'Roehrnbach', 'Rernbakh,Rjornbakh,Roehrnbach,Ryornbax,Röhrnbach,lei he er en ba he,rwrnbakh,Рернбах,Рёрнбах,Ռյորնբախ,رورنباخ,勒赫尔恩巴赫', 48.7385900, 13.5227100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32414, 'Röhrmoos', 'Rohrmoos', 'Rermos,Rjormos,Roehrmoos,Ryormos,Röhrmoos,lei he er mo si,rwrmws,Рермос,Рёрмос,Ռյորմոս,رورموس,勒赫尔莫斯', 48.3296600, 11.4467200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32415, 'Röhrig', 'Rohrig', 'Rohrig,Röhrig', 51.3333300, 10.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32416, 'Rohrenfels', 'Rohrenfels', 'Rorenfel''s,Rorenfels,luo lun fei er si,rwrnfls,Роренфелс,Роренфельс,Ռորենֆելս,رورنفلس,罗伦费尔斯', 48.6865400, 11.1561900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32417, 'Rohrdorf', 'Rohrdorf', '', 48.5666700, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32418, 'Rohrdorf', 'Rohrdorf', '', 47.7971300, 12.1701000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32419, 'Rohrberg', 'Rohrberg', '', 52.7075300, 11.0409200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32420, 'Rohrberg', 'Rohrberg', '', 51.4166700, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32421, 'Rohrbach', 'Rohrbach', 'Rurbeke [a. 1250]', 51.0666700, 11.4000000, 'DE', '2014-12-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32422, 'Rohrbach', 'Rohrbach', '', 50.6000000, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32423, 'Rohrbach', 'Rohrbach', '', 49.8833300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32424, 'Rohrbach', 'Rohrbach', 'Rorbakh,Рорбах', 49.5833300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32425, 'Rohrbach', 'Rohrbach', '', 49.1366700, 8.1286100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32426, 'Rohrbach', 'Rohrbach', 'Rohrbach', 48.6166700, 11.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32427, 'Rohrbach', 'Rohrbach', '', 48.2893300, 12.5560300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32428, 'Rohr', 'Rohr', '', 50.5764400, 10.4972500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32429, 'Rohr', 'Rohr', '', 49.3411200, 10.8898100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32430, 'Rohr', 'Rohr', 'Rohr', 48.7676800, 11.9715200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32431, 'Röhl', 'Rohl', '', 49.9333300, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32432, 'Rögling', 'Rogling', '', 48.8500000, 10.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32433, 'Roggentin', 'Roggentin', '', 54.0707000, 12.2042400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32434, 'Roggendorf', 'Roggendorf', '', 53.6929200, 11.0144000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32435, 'Roggenburg', 'Roggenburg', '', 48.2758800, 10.2313600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32436, 'Rogätz', 'Rogatz', 'Rogaetz,Rogatz,Rogec,Rogätz,luo ge ci,Рогец,罗格茨', 52.3166700, 11.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32437, 'Röfingen', 'Rofingen', 'Refingen,Rjofingen,Roefingen,Ryofingen,Röfingen,Рефинген,Рефінген,Рёфинген,Ռյոֆինգեն', 48.4244200, 10.4426800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32438, 'Roes', 'Roes', '', 50.2428100, 7.2583600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32439, 'Rodleben', 'Rodleben', '', 51.8960700, 12.2006100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32440, 'Rödinghausen', 'Rodinghausen', 'Redingkhauzen,Rjodingkhauzen,Roedinghausen,Rödinghausen,lei ding hao sen,Редингхаузен,Рёдингхаузен,勒丁豪森', 52.2500000, 8.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32441, 'Roding', 'Roding', 'Roding,luo ding ge,rdyng  alman,Родинг,ردینگ، آلمان,罗丁格', 49.1942600, 12.5195600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32442, 'Rodewisch', 'Rodewisch', 'Rodevisa,Rodevish,Rodeviša,Rodewisch,luo de wei shi,rwdhfysh,rwdysh,Родевиш,رودهفيش,رودیش,罗德维施', 50.5308300, 12.4132900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32443, 'Rodershausen', 'Rodershausen', '', 49.9833300, 6.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32444, 'Rödern', 'Rodern', '', 49.9500000, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32445, 'Rodenberg', 'Rodenberg', 'Rodenberg,luo deng bei ge,rdnbrg,rodenberuku,rwdnbrgh,Роденберг,ردنبرگ,رودنبرغ,ローデンベルク,罗登贝格', 52.3115200, 9.3564000, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32446, 'Rodenbek', 'Rodenbek', 'Rodenbek', 54.2833300, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32447, 'Rodenbach', 'Rodenbach', 'Rodenbach', 50.1500000, 9.0333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32448, 'Rodenbach', 'Rodenbach', '', 49.5741400, 8.1069500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32449, 'Rodenbach', 'Rodenbach', '', 49.4728100, 7.6579200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32450, 'Rodenäs', 'Rodenas', 'Rodenas,Rodenäs', 54.8833300, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32451, 'Roden', 'Roden', '', 49.8955600, 9.6263900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32452, 'Rödelsee', 'Rodelsee', 'Redel''ze,Redelze,Rjodel''zee,Ryodelzi,lei de er sai,Ределзе,Редельзе,Рёдельзее,Ռյոդելզի,勒德尔塞', 49.7333300, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32453, 'Rödelmaier', 'Roedelmaier', 'Roedelmaier,Rödelmaier', 50.3198100, 10.2770300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32454, 'Rödelhausen', 'Rodelhausen', '', 50.0000000, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32455, 'Rodalben', 'Rodalben', 'Rodal''ben,Rodalben,luo da er ben,rdalbn,rodaruben,rwdalbn,Родалбен,Родальбен,ردآلبن,رودآلبن,ローダルベン,罗达尔本', 49.2394000, 7.6396200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32456, 'Rockstedt', 'Rockstedt', '', 51.2850600, 10.7618400, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32457, 'Röckingen', 'Roeckingen', 'Rekingen,Rekkingen,Rjokkingen,Ryokingen,lei jin gen,rekkingen,Рекинген,Реккінген,Рёккинген,Ռյոկինգեն,レッキンゲン,勒金根', 49.0553700, 10.5595100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32458, 'Rockhausen', 'Rockhausen', 'Rockhausen', 50.9015200, 11.0407900, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32459, 'Rockeskyll', 'Rockeskyll', '', 50.2500000, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32460, 'Rockenhausen', 'Rockenhausen', 'Rockenhausen,Roggehause,Rokenkhauzen,Rokkenkhauzen,luo ken hao sen,rwknhawzn,Рокенхаузен,Роккенхаузен,راکن‌هاوزن,روكنهاوزن,罗肯豪森', 49.6297400, 7.8213400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32461, 'Rockenberg', 'Rockenberg', 'Rokenberg,Rokkenberg,luo ken bei ge,rokkenberuku,Рокенберг,Роккенберг,ロッケンベルク,罗肯贝格', 50.4305000, 8.7368800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32462, 'Rochlitz', 'Rochlitz', 'Rochlica,Rochlitz,Rohlica,Rokhlic,luo li ci,rwkhlyts,rwshlyts,Рохлиц,روخليتس,روشلیتس,罗利茨', 51.0500700, 12.7975400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32463, 'Rochau', 'Rochau', 'Rochau', 52.7070700, 11.7446400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32464, 'Röblingen am See', 'Roeblingen am See', 'Roblingen,Roblingen am See,Roeblingen am See,Röblingen,Röblingen am See', 51.4594400, 11.6823100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32465, 'Röbel', 'Roebel', '', 53.3755500, 12.6037200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32466, 'Riveris', 'Riveris', '', 49.7166700, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32467, 'Rivenich', 'Rivenich', '', 49.8757800, 6.8451700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32468, 'Ritzerau', 'Ritzerau', 'Ritzerau', 53.6666700, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32469, 'Rittersheim', 'Rittersheim', '', 49.6647200, 8.0583300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32470, 'Rittersgrün', 'Rittersgruen', 'Rittersgruen,Rittersgrun,Rittersgrün', 50.4803100, 12.7933600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32471, 'Rittersdorf', 'Rittersdorf', '', 50.8166700, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32472, 'Rittersdorf', 'Rittersdorf', '', 50.0000000, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32473, 'Ritterhude', 'Ritterhude', 'Gemeen Hu''e,Gemeen Hu’e,Riterkhude,Ritterkhude,li te lu de,Ритерхуде,Риттерхуде,里特鲁德', 53.1828900, 8.7355000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32474, 'Ritschenhausen', 'Ritschenhausen', 'Ritschenhausen', 50.5101800, 10.4323300, 'DE', '2013-10-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32475, 'Rippershausen', 'Rippershausen', 'Rippershausen', 50.6000000, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32476, 'Riol', 'Riol', 'Riol', 49.7930100, 6.7921100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32477, 'Rinzenberg', 'Rinzenberg', '', 49.6833300, 7.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32478, 'Rinteln', 'Rinteln', 'Rintel''n,Rinteln,Stadt Rinteln,lin te er en,rinterun,ryntln,Ринтелн,Ринтельн,رينتلن,رینتلن,リンテルン,林特尔恩', 52.1860400, 9.0791700, 'DE', '2013-12-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32479, 'Rinnthal', 'Rinnthal', '', 49.2166700, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32480, 'Ringstedt', 'Ringstedt', '', 53.5609100, 8.8487100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32481, 'Ringsheim', 'Ringsheim', 'Ringsgajm,Ringskhajm,ling si hai mu,Рингсхайм,Рингсхајм,Рінгсгайм,灵斯海姆', 48.2476500, 7.7782300, 'DE', '2011-09-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32482, 'Ringsberg', 'Ringsberg', 'Ringsberg', 54.8069200, 9.5981000, 'DE', '2014-01-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32483, 'Ringleben', 'Ringleben', '', 51.3666700, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32484, 'Ringleben', 'Ringleben', '', 51.1000000, 10.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32485, 'Ringelai', 'Ringelai', 'Ringelaj,Ringelay,lin ge lai,rynglay,Рингелай,Рингелај,Рінгелай,Ռինգելայ,رینگلای,林格莱', 48.8133600, 13.4713000, 'DE', '2012-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32486, 'Rinchnach', 'Rinchnach', 'Rinkhnakh,Rinnakh,Rinxnax,lin xi na,rynsh nakh,Риннах,Ринхнах,Рінхнах,Ռինխնախ,رینش ناخ,林希纳', 48.9495600, 13.2010200, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32487, 'Rimsting', 'Rimsting', 'Rimsting,li mu si ting ge,rymstyng,Римстинг,Рімстінг,Ռիմսթինգ,ریمستینگ,里姆斯廷格', 47.8807800, 12.3371300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32488, 'Rimsberg', 'Rimsberg', '', 49.6500000, 7.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32489, 'Rimpar', 'Rimpar', 'Rimpar,lin pa er,rimupa,Римпар,Рімпар,Ռիմպար,リムパー,林帕尔', 49.8569200, 9.9570500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32490, 'Rimbach', 'Rimbach', 'Rimbach', 49.6250000, 8.7630600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32491, 'Rimbach', 'Rimbach', '', 49.2333300, 12.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32492, 'Rimbach', 'Rimbach', '', 48.4666700, 12.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32493, 'Rietz Neuendorf', 'Rietz Neuendorf', 'Rietz Neuendorf', 52.2275800, 14.1746300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32494, 'Rietschen', 'Rietschen', 'Recicy,Richen,Rietschen,Rietschen/Recicy,Rietschen/Rěčicy,Rietscheni vald,Rěčicy,li ci xing,Ричен,Річен,里茨兴', 51.4000000, 14.7833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32495, 'Riethnordhausen', 'Riethnordhausen', '', 51.0833300, 11.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32496, 'Riethgen', 'Riethgen', '', 51.2500000, 11.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32497, 'Rietberg', 'Rietberg', 'Rietberg,Ritberg,li te bei ge,rytbrg,rytbrgh,Ритберг,Рітберг,ريتبرغ,ریتبرگ,里特贝格', 51.8092400, 8.4284100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32498, 'Riesweiler', 'Riesweiler', 'Risvajler,li si wei lei,Рисвайлер,Рисвајлер,里斯韦勒', 49.9589800, 7.5567100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32499, 'Rieste', 'Rieste', 'Rieste,Riste,li si te,Ристе,里斯特', 52.4833300, 8.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32500, 'Riestedt', 'Riestedt', 'Riestadt,Riestedt', 51.4949600, 11.3602300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32501, 'Rieseby', 'Rieseby', 'Rieseby,Risby,Rizebi,li sai bi,Ризеби,里塞比', 54.5414000, 9.8168900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32502, 'Riesa', 'Riesa', 'IES,Riesa,Riza,Ryzawa,Rīza,li sa,ryza,Риза,Різа,ريزا,ریزا,里薩', 51.3077700, 13.2916800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32503, 'Riepsdorf', 'Riepsdorf', '', 54.2261100, 10.9724200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32504, 'Rieneck', 'Rieneck', 'Rieneck,Rinek,li nei ke,rynk,Ринек,Рінек,Ռինեկ,رينك,رینک,里内克', 50.0934900, 9.6479700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32505, 'Rielasingen-Worblingen', 'Rielasingen-Worblingen', 'Rilasingen-Vorblingen,Rilazingen-Vorblingen,li la xin gen-wo er bu lin gen,Рилазинген-Ворблинген,Риласинген-Ворблинген,Рілазінген-Ворблінген,里拉辛根-沃尔布林根', 47.7346500, 8.8401300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32506, 'Riekofen', 'Riekofen', '', 48.9166700, 12.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32507, 'Riehl', 'Riehl', '', 50.9668600, 6.9757200, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32508, 'Riegsee', 'Riegsee', '', 47.6986700, 11.2339100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32509, 'Riegenroth', 'Riegenroth', '', 50.0500000, 7.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32510, 'Riegelsberg', 'Riegelsberg', 'Rigel''sberg,Rigelsberg,li ge er si bei ge,ryglsbrg,Ригелсберг,Ригельсберг,Рігельсберг,ریگلسبرگ,里格尔斯贝格', 49.3000000, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32511, 'Riegel', 'Riegel', 'Riege,Riegel', 48.1511100, 7.7491500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32512, 'Riedlingen', 'Riedlingen', 'Redlinga,Ridlingen,li de lin gen,ridlingeni,ritoringen,rydlynghn,rydlyngn,Ридлинген,Рідлінген,Ռիդլինգեն,ريدلينغن,ریدلینگن,რიდლინგენი,リートリンゲン,里德林根', 48.1545500, 9.4755800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32513, 'Riedhausen', 'Riedhausen', 'Ridgauzen,Ridkhauzen,li de hao sen,Ридхаузен,Рідгаузен,里德豪森', 47.9093500, 9.4285200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32514, 'Riedering', 'Riedering', 'Ridering,li de ling,rydryng,Ридеринг,Рідерінг,Ռիդերինգ,ریدرینگ,里德灵', 47.8387400, 12.2077800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32515, 'Riederich', 'Riederich', 'Riderikh,li de li xi,Ридерих,Рідеріх,里德里希', 48.5602900, 9.2688300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32516, 'Rieder', 'Rieder', 'Rider,Ридер', 51.7333300, 11.1666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32517, 'Riedenheim', 'Riedenheim', '', 49.5572200, 9.9780600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32518, 'Riedenburg', 'Riedenburg', 'Rianbuach,Ridenburg,Riedenburg,li deng bao,rydnbwrg,rydnbwrgh,Риденбург,Ріденбург,Ռիդենբուրգ,ريدنبورغ,ریدنبورگ,里登堡', 48.9638300, 11.6888000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32519, 'Rieden an der Kötz', 'Rieden an der Kotz', '', 48.3849900, 10.2571100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32520, 'Rieden', 'Rieden', '', 50.4000000, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32521, 'Rieden', 'Rieden', 'Riden,Риден,Ріден,Ռիդեն', 49.3236100, 11.9420500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32522, 'Rieden', 'Rieden', '', 47.9500000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32523, 'Riedelberg', 'Riedelberg', '', 49.1833300, 7.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32524, 'Riede', 'Riede', 'Ride,Rier,ride,Риде,リーデ', 52.9666700, 8.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32525, 'Ried', 'Ried', '', 48.4769800, 11.2606000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32526, 'Ried', 'Ried', '', 48.2900700, 11.0438000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32527, 'Rickling', 'Rickling', 'Rickling', 54.0166700, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32528, 'Rickert', 'Rickert', 'Rickert', 54.3333300, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32529, 'Rickenbach', 'Rickenbach', '', 47.6189500, 7.9787300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32530, 'Richtenberg', 'Richtenberg', 'Richbarg,Rihtenberga,Rikhtenberg,li xi teng bei ge,ryshtnbrg,ryshtnbrgh,Рихтенберг,ريشتنبرغ,ریشتنبرگ,里希滕贝格', 54.2013100, 12.8940900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32531, 'Ribnitz-Damgarten', 'Ribnitz-Damgarten', 'Damgarten,Rebnica-Dabogora,Ribnic-Damgarten,Ribnica-Damgartene,Ribnitz-Damgarten,Rëbnica-Dãbògóra,li bu ni ci-da mu jia teng,rybnyts-damghartn,Рибниц-Дамгартен,ريبنيتس-دامغارتن,ریبنیتز-دام‌گارتن,里布尼茨-达姆加滕', 54.2422000, 12.4566600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32532, 'Ribbesbüttel', 'Ribbesbuttel', 'Ribbesbjuttel'',Ribbesbuettel,Ribbesbüttel,Ribesbitel,li bei si bi te er,Риббесбюттель,Рибесбител,里贝斯比特尔', 52.4343500, 10.5099700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32533, 'Rhumspringe', 'Rhumspringe', 'Rumshpringe,Rumspringe,lu mu si pu lin ge,rumushupuringe,Румспринге,Румшпринге,ルームシュプリンゲ,鲁姆斯普林格', 51.5833300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32534, 'Rhodt unter Rietburg', 'Rhodt unter Rietburg', 'Rodt-pod-Ritburgom,Rot pod Ritburgom,luo te weng te er li te bao,Родт-под-Ритбургом,Рот под Ритбургом,罗特翁特尔里特堡', 49.2697200, 8.1077800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32535, 'Rhinow', 'Rhinow', 'Rinov,li nuo fu,rynw,Ринов,Ռինով,رينو,رینو,里诺夫', 52.7509400, 12.3419400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32536, 'Rheurdt', 'Rheurdt', 'Rheurdt,Rjort,Rojrdt,Rojrt,luo yi er te,Ройрдт,Ројрт,Рёрт,罗伊尔特', 51.4666700, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32537, 'Rhens', 'Rhens', 'Rens,Rhens,lun si,rensu,rnz,rynz,Ренс,رنز,رينز,レンス,伦斯', 50.2812500, 7.6175000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32538, 'Rheinzabern', 'Rheinzabern', 'Rajnacabern,Rajncabern,Rejncabern,Rhoizawere,lai yin cha bei en,Райнцаберн,Рајнацаберн,Рейнцаберн,莱茵察贝恩', 49.1180600, 8.2780600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32539, 'Rheinsberg', 'Rheinsberg', 'Rajnsberg,Raynsberg,lai yin si bei ge,raynsbrgh,raynzbrg,Райнсберг,Рајнсберг,Ռայնսբերգ,راينسبرغ,راینزبرگ,赖因斯贝格', 53.0997200, 12.8988500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32540, 'Rheinfelden (Baden)', 'Rheinfelden (Baden)', 'Badisch-Rheinfelden,Rajnfel''den,Rheinfelden,Rheinfelden (Baden),Райнфельден', 47.5601300, 7.7871500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32541, 'Rheine', 'Rheine', 'Rajn,Rajne,Rene,Rheine,ZPQ,lai nei,laine,raynh,Райн,Райне,Рајне,راينه,赖内,라이네', 52.2850900, 7.4405500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32542, 'Rheinbrohl', 'Rheinbrohl', 'Rajnabrol,Rajnbrol'',Rejnbrol'',lai yin bu luo er,Райнброль,Рајнаброл,Рейнброль,赖因布罗尔', 50.5000000, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32543, 'Rheinbreitbach', 'Rheinbreitbach', 'Rajnabrajtbakh,Rajnbrajtbakh,Rejnbrajtbakh,lai yin bu lai te ba he,Райнбрайтбах,Рајнабрајтбах,Рейнбрайтбах,赖因布赖特巴赫', 50.6166700, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32544, 'Rheinböllen', 'Rheinbollen', 'Rajnabelen,Rajnbjollen,Rejnbjollen,Rheinboellen,Rheinböllen,lai yin bo lun,rainberen,raynbwln,Райнбёллен,Рајнабелен,Рейнбёллен,راينبولن,راینبولن,ラインベレン,赖因伯伦', 50.0112700, 7.6724900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32545, 'Rheinberg', 'Rheinberg', 'Rheinberg', 51.5464900, 6.5952500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32546, 'Rheinbach', 'Rheinbach', 'Rajnabakh,Rajnbakh,lai yin ba he,raynbakh,Райнбах,Рајнабах,راينباخ,راینباخ,莱茵巴赫', 50.6256200, 6.9491100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32547, 'Rheinau', 'Rheinau', '', 48.8717300, 8.1913300, 'DE', '2015-02-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32548, 'Rheden', 'Rheden', '', 52.0578400, 9.7871400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32549, 'Rhede', 'Rhede', 'Rede,Rhede,rydh,Реде,ريده', 53.0602000, 7.2712700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32550, 'Rhede', 'Rhede', 'Rede,Rhede,rdh,rydt,Реде,رده,ريدة', 51.8353700, 6.6960200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32551, 'Rheda-Wiedenbrück', 'Rheda-Wiedenbrueck', 'Red-Videnbrjuk,Reda-Videnbrik,Reda-Videnbrjuk,Rheda-Wiedenbrueck,Rheda-Wiedenbrück,lei da-wei deng bu lu ke,rda-wydnbwrk,Ред-Виденбрюк,Реда-Виденбрик,Реда-Виденбрюк,Реда-Віденбрюк,ردا-ویدنبورک,რედა-ვიდენბრიუკი,雷达-维登布吕克', 51.8496700, 8.3001700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32552, 'Rhaunen', 'Rhaunen', 'Raunen,lao nen,ruhaunen,Раунен,ルハウネン,劳嫩', 49.8638000, 7.3419800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32553, 'Rhade', 'Rhade', '', 53.3287200, 9.1135000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32554, 'Reutlingen', 'Reutlingen', 'Rejtlingen,Reutlingen,Roitlingenas,Roitlinken,Rojtlingen,ZPP,loiteulling-gen,luo yi te lin gen,roitoringen,rwytlynghn,rwytlyngn,Ρόιτλιγκεν,Рейтлинген,Ройтлинген,Ройтлінген,Ројтлинген,רויטלינגן,رويتلينغن,روٹلنگن,ロイトリンゲン,罗伊特林根,로이틀링겐', 48.4914400, 9.2042700, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32555, 'Reuth', 'Reuth', '', 50.6166700, 12.2166700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32556, 'Reuth', 'Reuth', '', 50.4696900, 11.9593900, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32557, 'Reuth', 'Reuth', '', 50.3000000, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32558, 'Reuth', 'Reuth', '', 49.9905200, 11.6948000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32559, 'Reut', 'Reut', '', 48.5917000, 13.1233200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32560, 'Reut', 'Reut', '', 48.3166700, 12.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32561, 'Reußenköge', 'Reussenkoge', 'Reussenkog,Reussenkoge,Reussenkuuge,Reußenkuuge,Reußenköge,Rojsenkege,Rojsenkjoge,luo yi sen ke ge,Ройсенкёге,Ројсенкеге,罗伊森克格', 54.6023000, 8.9027000, 'DE', '2012-04-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32562, 'Reußen', 'Reussen', '', 51.5010900, 12.1304400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32563, 'Reurieth', 'Reurieth', 'Reurieth', 50.4500000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32564, 'Reudelsterz', 'Reudelsterz', '', 50.3166700, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32565, 'Retzstadt', 'Retzstadt', '', 49.9125000, 9.8819400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32566, 'Retzow', 'Retzow', 'Recov,lei cuo,Рецов,Ռեցով,雷措', 52.6247800, 12.6855200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32567, 'Rettert', 'Rettert', '', 50.2313900, 7.9384800, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32568, 'Rettershain', 'Rettershain', '', 50.1500000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32569, 'Rettersen', 'Rettersen', '', 50.7000000, 7.5000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32570, 'Retterath', 'Retterath', '', 50.2666700, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32571, 'Rettenberg', 'Rettenberg', 'Retenberg,Rettenberg,lei teng bei ge,Ретенберг,Реттенберг,Ռեթենբերգ,雷滕贝格', 47.5742800, 10.2917300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32572, 'Rettenbach', 'Rettenbach', '', 49.0666700, 12.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32573, 'Rettenbach', 'Rettenbach', '', 48.4588100, 10.3523800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32574, 'Retschow', 'Retschow', 'Retschow', 54.0455200, 11.8778000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32575, 'Rethwisch', 'Rethwisch', '', 53.8670100, 9.5857400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32576, 'Rethen', 'Rethen', 'Rethene [a. 1301]', 52.3770700, 10.4785500, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32577, 'Rethem', 'Rethem', 'Retem,Rethem,lei te mu,rthaym,rytm,Ретем,رتهایم,ريتم,雷特姆', 52.7862100, 9.3786200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32578, 'Retgendorf', 'Retgendorf', '', 53.7292200, 11.5035900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32579, 'Reppenstedt', 'Reppenstedt', 'Repenshtet,Reppenshtedt,lei peng si te,Репенштет,Реппенштедт,雷彭斯特', 53.2500000, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32580, 'Rentweinsdorf', 'Rentweinsdorf', 'Rentvajnsdorf,lun te wei en si duo fu,Рентвайнсдорф,Рентвајнсдорф,Ռենթվայնսդորֆ,伦特韦恩斯多夫', 50.0634200, 10.7992200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32581, 'Renthendorf', 'Renthendorf', 'Rentendorf,Renthendorf,lun teng duo fu,Рентендорф,伦滕多夫', 50.8000000, 11.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32582, 'Renquishausen', 'Renquishausen', 'Renkviskhauzen,lun ku yi si hao sen,Ренквисхаузен,伦库伊斯豪森', 48.0833300, 8.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32583, 'Renningen', 'Renningen', 'Reningen,Renningen,lei ning gen,reningeni,rnynghn,rnyngn,Ренинген,Реннинген,Реннінген,Ռենինգեն,رنينغن,رنینگن,რენინგენი,雷宁根', 48.7697400, 8.9387100, 'DE', '2013-04-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32584, 'Rennertshofen', 'Rennertshofen', 'Renertskhofen,Rennertsgofen,Rennertshofen,Rennertskhofen,lei nei er ci huo fen,rnrtshwfn,Ренертсхофен,Реннертсгофен,Реннертсхофен,Ռենեթսհոֆեն,رنرتسهوفن,雷内尔茨霍芬', 48.7594300, 11.0454400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32585, 'Rennerod', 'Rennerod', 'Renerod,Rennerod,lei nei luo de,rnrwd,rynhrwd,Ренерод,Реннерод,رنرود,رينهرود,雷内罗德', 50.6082000, 8.0669700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32586, 'Rennau', 'Rennau', '', 52.2958800, 10.9120000, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32587, 'Renkenberge', 'Renkenberge', '', 52.9000000, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32588, 'Rengsdorf', 'Rengsdorf', 'Rengsdorf,lun si duo fu,rengusudorufu,Ренгсдорф,レングスドルフ,伦斯多夫', 50.5000000, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32589, 'Rendswühren', 'Rendswuhren', 'Rendswuehren,Rendswuhren,Rendswühren', 54.0833300, 10.1833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32590, 'Rendsburg', 'Rendsburg', 'Rendsborag,Rendsborg,Rendsbourg,Rendsburg,Rentsmpournk,lun ci bao,rndsbwrgh,rndzbrg,Ρέντσμπουργκ,Рендсбург,رندزبرگ,رندسبورغ,伦茨堡', 54.3066300, 9.6631300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32591, 'Renchen', 'Renchen', 'Renchen,Renkhen,lun xing,rnshn,Ренхен,رنشن,伦兴', 48.5885000, 8.0132100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32592, 'Remstädt', 'Remstadt', 'Remstadt,Remstaedt,Remstädt', 50.9789700, 10.6878100, 'DE', '2016-08-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32593, 'Remse', 'Remse', 'Remze,lei mu sai,Ремзе,雷姆塞', 50.8500000, 12.5666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32594, 'Remscheid', 'Remscheid', 'Remsaint,Remsayd,Remscheid,Remseidas,Remshajd,Remşayd,Remšeidas,ZPN,lei mu sha yi de,lemsyaiteu,remshaidi,remushaito,rmshayd,rmsyyd,Ρέμσαϊντ,Ремшайд,Ремшајд,רמשייד,رمشايد,رمشاید,ریمشیڈ,რემშაიდი,レムシャイト,雷姆沙伊德,렘샤이트', 51.1798300, 7.1925000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32595, 'Remptendorf', 'Remptendorf', 'Remptendorf,lun pu teng duo fu,Ремптендорф,伦普滕多夫', 50.5333300, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32596, 'Remmels', 'Remmels', 'Remmels', 54.1166700, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32597, 'Remlingen', 'Remlingen', '', 52.1136700, 10.6740800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32598, 'Remlingen', 'Remlingen', 'Remlingen,remuringen,Ремлинген,Ремлінген,Ռեմլինգեն,レムリンゲン', 49.8047700, 9.6948400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32599, 'Remagen', 'Remagen', 'Remagen,Rigomagus,lei ma gen,remagen,rmaghn,rmagn,Ремаген,رماغن,رماگن,ሬማገን,レマーゲン,雷马根', 50.5787900, 7.2270300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32600, 'Relsberg', 'Relsberg', 'Rel''sberg,Relsberg,lei er si bei ge,Релсберг,Рельсберг,雷尔斯贝格', 49.6000000, 7.6666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32601, 'Rellingen', 'Rellingen', 'Relingen,Rellingen,lei lin gen,Релинген,Реллинген,雷林根', 53.6500000, 9.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32602, 'Reitzenhain', 'Reitzenhain', '', 50.1500000, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32603, 'Reitwein', 'Reitwein', 'Rajtvajn,lai te wei yin,Райтвайн,Рајтвајн,Ռայթվայն,赖特韦因', 52.5009100, 14.5816900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32604, 'Reit im Winkl', 'Reit im Winkl', 'Rajt im Vinkl,Rajt-im-Vinkl'',Reiter Winke,lai te yi mu wen ke er,rayt aym wynkl,Райт-им-Винкль,Райт-ім-Вінкль,Рајт им Винкл,Ռայթ իմ Վինքլ,رایت ایم وینکل,赖特伊姆温克尔', 47.6772900, 12.4708600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32605, 'Reiskirchen', 'Reiskirchen', 'Rajskirkhen,Reiskirchen,lai si ji xing,raisukiruhyen,Райскирхен,Райскірхен,Рајскирхен,ライスキルヒェン,赖斯基兴', 50.6000000, 8.8333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32606, 'Reischach', 'Reischach', 'Rajshakh,Raysax,Reischoch,lai sha,rayshakh,Райшах,Рајшах,Ռայշախ,رایشاخ,赖沙', 48.2907300, 12.7262000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32607, 'Reisbach', 'Reisbach', 'Rajsbakh,Raysbax,Reisbach,Reischbo,lai si ba he,Райсбах,Рајсбах,Ռայսբախ,赖斯巴赫', 48.5700800, 12.6279900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32608, 'Reipoltskirchen', 'Reipoltskirchen', 'Rajpol''tskirkhen,Rajpoltskirkhen,lai bo er ci ji er xing,Райпольтскирхен,Рајполтскирхен,赖波尔茨基尔兴', 49.6333300, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32609, 'Reipeldingen', 'Reipeldingen', '', 50.0833300, 6.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32610, 'Reinstorf', 'Reinstorf', 'Rajnstorf,lai yin si tuo fu,Райнсторф,Рајнсторф,赖因斯托夫', 53.2344500, 10.5732300, 'DE', '2011-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32611, 'Reinstädt', 'Reinstadt', 'Reinstadt,Reinstaedt,Reinstädt', 50.8093000, 11.4742800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32612, 'Reinsfeld', 'Reinsfeld', 'Rajnsfel''d,Rajnsfeld,lai yin si fei er de,Райнсфельд,Рајнсфелд,赖因斯费尔德', 49.6833300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32613, 'Reinsdorf', 'Reinsdorf', '', 51.3333300, 11.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32614, 'Reinsdorf', 'Reinsdorf', '', 50.6977500, 12.5555500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32615, 'Reinsbüttel', 'Reinsbuettel', 'Reinsbuttel,Reinsbüttel', 54.1788100, 8.9116900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32616, 'Reinsberg', 'Reinsberg', 'Reinsberg', 51.0082300, 13.3654200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32617, 'Reinickendorf', 'Reinickendorf', 'Berlin-Reinickendorf,Reinickendorf,ryynyqndwrp,רייניקנדורף,رائینکنڈورف', 52.5666700, 13.3333300, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32618, 'Reinholterode', 'Reinholterode', 'Rengerode,Rheinholterode [< 1935]', 51.4219000, 10.1942800, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32619, 'Reinheim', 'Reinheim', 'Rajngajm,Rajnkhajm,Raynhaym,Reinheim,lai en hai mu,rainhaimu,raynhaym,Райнгайм,Райнхайм,Рајнхајм,راينهايم,راینهایم,ラインハイム,赖恩海姆', 49.8292300, 8.8357200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32620, 'Reinhardtsgrimma', 'Reinhardtsgrimma', 'Rajnkhardtsgrimma,Rajnkhartsgrima,Reinhardtsgrimma,Райнхардтсгримма,Рајнхартсгрима', 50.8927000, 13.7553400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32621, 'Reinhardshausen', 'Reinhardshausen', '', 51.1116600, 9.0751400, 'DE', '2016-01-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32622, 'Reinfeld', 'Reinfeld', 'Rajnfel''d,Rajnfeld,Reinfeld,lai yin fei er de,raynfld,Райнфельд,Рајнфелд,راينفلد,راینفلد، هول‌اشتاین,赖因费尔德', 53.8318400, 10.4912600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32623, 'Reinberg', 'Reinberg', '', 53.6748400, 13.1441700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32624, 'Reinbek', 'Reinbek', 'Rajnbek,Reinbeek,Reinbek,lai yin bei ke,raynbk,Райнбек,Рајнбек,راينبك,راینبک,赖因贝克', 53.5170300, 10.2488000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32625, 'Reimlingen', 'Reimlingen', '', 48.8166700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32626, 'Reimerath', 'Reimerath', '', 50.3000000, 6.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32627, 'Reilingen', 'Reilingen', 'Rajlingen,lai lin gen,rairingen,Райлинген,Райлінген,Рајлинген,ライリンゲン,賴林根', 49.2983300, 8.5641700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32628, 'Reil', 'Reil', '', 50.0166700, 7.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32629, 'Reifferscheid', 'Reifferscheid', '', 50.4052900, 6.8849900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32630, 'Reiffelbach', 'Reiffelbach', 'Rajfelbakh,Rajffel''bakh,lai fei er ba he,Райффельбах,Рајфелбах,赖费尔巴赫', 49.6833300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32631, 'Reiff', 'Reiff', '', 50.1000000, 6.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32632, 'Reiferscheid', 'Reiferscheid', '', 50.6500000, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32633, 'Reifenberg', 'Reifenberg', '', 49.2828300, 7.5095800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32634, 'Reidenhausen', 'Reidenhausen', '', 50.0500000, 7.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32635, 'Reichweiler', 'Reichweiler', 'Rajkhvajler,lai xi wei lai er,Райхвайлер,Рајхвајлер,赖希魏莱尔', 49.5333300, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32636, 'Reichsthal', 'Reichsthal', '', 49.6000000, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32637, 'Reichmannsdorf', 'Reichmannsdorf', '', 50.5496200, 11.2575800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32638, 'Reichling', 'Reichling', 'Rajkhling,Rayxling,lai xi ling,raihiringu,rayshlyng,Райхлинг,Райхлінг,Рајхлинг,Ռայխլինգ,رایشلینگ,ライヒリング,赖希灵', 47.9228000, 10.9284700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32639, 'Reichertshofen', 'Reichertshofen', 'Rajkhertsgofen,Rajkhertskhofen,Reichertzhofen,lai xie er ci huo fen,rayshrtshwfn,Райхертсгофен,Райхертсхофен,Рајхертсхофен,Ռայհերթսհոֆեն,رایشرتسهوفن,赖歇尔茨霍芬', 48.6577500, 11.4661200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32640, 'Reichertsheim', 'Reichertsheim', '', 48.2000000, 12.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32641, 'Reichertshausen', 'Reichertshausen', 'Rajkhertsgauzen,Rajkhertskhauzen,lai xie er ci hao sen,rayshrtshawzn,Райхертсгаузен,Райхертсхаузен,Рајхертсхаузен,Ռայհերթսհաուզեն,رایشرتسهاوزن,赖歇尔茨豪森', 48.4666700, 11.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32642, 'Reichertshausen', 'Reichertshausen', '', 47.8988200, 11.5584300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32643, 'Reichersbeuern', 'Reichersbeuern', 'Reichersbeuern,Reichersbeuren', 47.7666700, 11.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32644, 'Reichenwalde', 'Reichenwalde', 'Rajkhenval''de,Rajkhenvalde,Rayhenvalde,lai xing wa er de,Райхенвальде,Рајхенвалде,Ռայհենվալդե,赖兴瓦尔德', 52.2666700, 14.0000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32645, 'Reichenschwand', 'Reichenschwand', 'Rajkhenshvand,Rayxensvand,lai xing shi wan de,Райхеншванд,Рајхеншванд,Ռայխենշվանդ,赖兴施万德', 49.5138400, 11.3727400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32646, 'Reichenberg', 'Reichenberg', '', 50.1500000, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32647, 'Reichenberg', 'Reichenberg', 'Rajkhenberg,Rayxenberg,Reichenberg,raihyenberuku,raykhnbrgh,Райхенберг,Рајхенберг,Ռայխենբերգ,رايخنبرغ,ライヒェンベルク', 49.7319300, 9.9147800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32648, 'Reichenbach-Steegen', 'Reichenbach-Steegen', 'Rajkhenbakh-Shtegen,Steegen,lai xing ba he-si te gen,Райхенбах-Штеген,Рајхенбах-Штеген,赖兴巴赫-斯特根', 49.5000000, 7.5500000, 'DE', '2017-07-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32649, 'Reichenbach an der Fils', 'Reichenbach an der Fils', 'Rajkhenbakh an der Fils,Rajkhenbakh-an-der-Fil''s,Rajkhenbakh-na-Fil''se,Rayxenbax na Filse,Reichenbach,fei er si he pan lai xing ba he,Райхенбах-ан-дер-Фільс,Райхенбах-на-Фильсе,Рајхенбах ан дер Филс,Ռայխենբախ նա Ֆիլսե,菲尔斯河畔赖兴巴赫', 48.7101100, 9.4642900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32650, 'Reichenbach am Heuberg', 'Reichenbach am Heuberg', '', 48.1333300, 8.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32651, 'Reichenbach', 'Reichenbach', 'Reichenbach,Reichenbach/Oberlausitz', 51.1414400, 14.8027000, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32652, 'Reichenbach', 'Reichenbach', '', 50.8686100, 11.8780100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32653, 'Reichenbach/Vogtland', 'Reichenbach/Vogtland', 'Reichenbach,Reichenbach/Vogtland,Stadt Reichenbach/Vogtland', 50.6227900, 12.3034400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32654, 'Reichenbach', 'Reichenbach', '', 50.4242700, 11.4130300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32655, 'Reichenbach', 'Reichenbach', '', 49.6407300, 7.2866400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32656, 'Reichenbach', 'Reichenbach', 'Rajkhenbakh,Rajkhenbakh-am-Regen,Regeni Rayxenbax,Reichaboch,Reichenbach,Reichenbach am Regen,Richenbach,Райхенбах-ам-Реген,Рајхенбах,Ռեգենի Ռայխենբախ', 49.1833300, 12.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32657, 'Reichelsheim', 'Reichelsheim', '', 50.3563800, 8.8744600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32658, 'Reichelsheim', 'Reichelsheim', '', 49.7121100, 8.8389600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32659, 'Reichartshausen', 'Reichartshausen', 'Rajkhartsgauzen,Rajkhartskhauzen,lai xia er ci hao sen,raihyarutsuhauzen,Райхартсгаузен,Райхартсхаузен,Рајхартсхаузен,ライヒャルツハウゼン,赖夏尔茨豪森', 49.3550000, 8.9452800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32660, 'Reichardtswerben', 'Reichardtswerben', 'Reichardtswerben', 51.2485100, 11.9534900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32661, 'Reich', 'Reich', '', 50.0000000, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32662, 'Rehweiler', 'Rehweiler', 'Rekhvajler,Revajler,lei wei lei,Ревайлер,Рехвајлер,雷韦勒', 49.4856700, 7.4420700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32663, 'Rehren', 'Rehren', '', 52.2333300, 9.2333300, 'DE', '2011-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32664, 'Rehna', 'Rehna', 'Rehna,Rena,Rēna,rna,ryna,Рена,رنا,رينا', 53.7787700, 11.0492900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32665, 'Rehm-Flehde-Bargen', 'Rehm-Flehde-Bargen', 'Rehm-Flehde-Bargen', 54.2833300, 9.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32666, 'Rehlingen', 'Rehlingen', 'Relingen,Релинген', 53.1057200, 10.2209200, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32667, 'Rehling', 'Rehling', '', 48.4833300, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32668, 'Rehhorst', 'Rehhorst', 'Rehhorst', 53.8833300, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32669, 'Rehfelde', 'Rehfelde', 'Refel''de,Refelde,lei fei er de,Рефелде,Рефельде,Ռեֆելդե,雷费尔德', 52.5341700, 13.9088400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32670, 'Reher', 'Reher', '', 54.0666700, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32671, 'Rehe', 'Rehe', '', 50.6333300, 8.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32672, 'Rehden', 'Rehden', 'Reden,Rehrn,Rekhden,lei deng,Реден,Рехден,雷登', 52.6102400, 8.4809300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32673, 'Rehburg-Loccum', 'Rehburg-Loccum', 'Reburg-Lokkum,Reburg-Lokum,Rehburg-Loccum,Rekhburg-Lokkum,lei bao-luo ku mu,rbwrg-lkwm,reburuku=rokkumu,ryhbwrgh-lwkwm,Ребург-Локкум,Ребург-Локум,Рехбург-Локкум,ربورگ-لکوم,ريهبورغ-لوكوم,レーブルク＝ロックム,雷堡-洛库姆', 52.4695200, 9.1995700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32674, 'Rehborn', 'Rehborn', 'Reborn,Rekhborn,lei bo er en,Реборн,Рехборн,雷博尔恩', 49.7333300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32675, 'Rehbach', 'Rehbach', '', 49.8500000, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32676, 'Rehau', 'Rehau', 'Regau,Rehau,Rekhau,lei hao,reau,rhaw,Регау,Рехау,رهاو,レーアウ,雷豪', 50.2492100, 12.0342200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32677, 'Regnitzlosau', 'Regnitzlosau', 'Regniclozau,Regnitzlosau,lei ge ni ci luo shao,regunittsurozau,Регницлозау,Регніцлозау,レグニッツローザウ,雷格尼茨洛绍', 50.3000000, 12.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32678, 'Regis-Breitingen', 'Regis-Breitingen', 'Breitingen Regis,Regis-Brajtingen,Regis-Breitingen,Regisa-Breitingene,Rēgisa-Breitingene,lei ji si-bu lai ting gen,rgys-braytyngn,ryghys-braytynghn,Регис-Брайтинген,Регис-Брајтинген,ريغيس-برايتينغن,رگیس-برایتینگن,雷吉斯-布赖廷根', 51.0888300, 12.4384100, 'DE', '2015-08-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32679, 'Regesbostel', 'Regesbostel', '', 53.3833300, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32680, 'Regenstauf', 'Regenstauf', 'Regenshtauf,Regenstauf,lei gen si tao fu,rgnstawf,Регенстауф,Регенштауф,Ռեգենշթաուֆ,رگنستاوف,雷根斯陶夫', 49.1201400, 12.1302700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32681, 'Regensburg', 'Regensburg', 'Gorad Rehgensburg,Ratisbon,Ratisbona,Ratisbonne,Ratyzbona,Regensboerj,Regensburg,Regensburga,Regensburgas,Regensburgo,Regensbörj,Regenzburg,Rengschburg,Renkensmpournk,Rezno,Rēgensburga,Rėgensburgas,Rězno,ZPM,legenseubuleukeu,lei gen si bao,regensburgi,regensuburuku,rgnsbwrg,ryghnsbwrgh,rygnzbrg,Řezno,Ρέγκενσμπουργκ,Горад Рэгенсбург,Регензбург,Регенсбург,Реґенсбурґ,רגנסבורג,ريغنسبورغ,رگنسبورگ,ریگنزبرگ,რეგენსბურგი,レーゲンスブルク,雷根斯堡,레겐스부르크', 49.0151300, 12.1016100, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32682, 'Regen', 'Regen', 'Regen,rgn,Реген,رگن', 48.9719000, 13.1282400, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32683, 'Reeßum', 'Reessum', '', 53.1333300, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32684, 'Reesdorf', 'Reesdorf', '', 54.1833300, 10.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32685, 'Rees', 'Rees', 'Gorad Rehs,Rees,Res,Ress,lei si,ryz  alman,Горад Рэс,Рес,ریز، آلمان,雷斯', 51.7626300, 6.3977800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32686, 'Redwitz an der Rodach', 'Redwitz an der Rodach', 'Redvic an der Rodakh,Redvic-an-der-Rodakh,Redwitz,Redwitz an der Rodach,rdwyts an dr rwdakh,Редвиц ан дер Родах,Редвиц-ан-дер-Родах,Редвіц-ан-дер-Родах,Ռոդախի Ռեդվից,ردویتس ان در روداخ,レドヴィッツ・アン・デア・ローダッハ', 50.1732300, 11.2083300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32687, 'Rednitzhembach', 'Rednitzhembach', '', 49.3009500, 11.0799700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32688, 'Recklinghausen', 'Recklinghausen', 'Recklinghausen,Recklinghusium,Reklinghauzenas,Reklingkhauzen,Riaekelhusen,Riäkelhusen,lei ke lin hao sen,lekeullinghaujen,rekkuringuhauzen,rklynghawzn,Реклингхаузен,Реклінгхаузен,رکلینگهاوزن,ریکلنگہاؤسن,რეკლინგჰაუზენი,レックリングハウゼン,雷克林豪森,레클링하우젠', 51.6137900, 7.1973800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32689, 'Reckershausen', 'Reckershausen', '', 49.9833300, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32690, 'Reckenroth', 'Reckenroth', '', 50.2297200, 8.0230600, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32691, 'Reckendorf', 'Reckendorf', 'Rekendorf,Rekkendorf,lei ken duo fu,rekkendorufu,Рекендорф,Реккендорф,Ռեքենդորֆ,レッケンドルフ,雷肯多夫', 50.0166700, 10.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32692, 'Recke', 'Recke', '', 52.3688500, 7.7211600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32693, 'Rechtsupweg', 'Rechtsupweg', '', 53.5333300, 7.3333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32694, 'Rechtmehring', 'Rechtmehring', 'Rekhtmering,Rextmering,lei xi te mei ling,rshtmryng,Рехтмеринг,Рехтмерінг,Ռեխտմերինգ,رشتمرینگ,雷希特梅灵', 48.1166700, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32695, 'Rechtenstein', 'Rechtenstein', 'Rekhtenshtajn,Rextenstayn,lei xi teng si tai yin,Рехтенштайн,Рехтенштајн,Ռեխտենշտայն,რეხტენშტაინი,雷希滕斯泰因', 48.2407700, 9.5459200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32696, 'Rechtenbach', 'Rechtenbach', 'Rekhtenbakh,Rextenbax,lei xi teng ba he,Рехтенбах,Ռեխտենբախ,雷希滕巴赫', 49.9830600, 9.5083300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32697, 'Rechlin', 'Rechlin', 'REB,Rekhlin,Relin,lei xi lin,Релин,Рехлин,雷希林', 53.3354900, 12.7254300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32698, 'Rechenberg-Bienenmühle', 'Rechenberg-Bienenmuehle', 'Rechenberg-Bienenmuehle,Rechenberg-Bienenmühle,Rekhenberg-Binenmile,Rekhenberg-Binenmjule,lei xing bei ge-bi nen mi lei,Рехенберг-Биненмиле,Рехенберг-Биненмюле,雷兴贝格-比嫩米勒', 50.7377700, 13.5350200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32699, 'Rechberghausen', 'Rechberghausen', 'Rekhberggauzen,Rekhbergkhauzen,lei xi bei ge hao sen,Рехберггаузен,Рехбергхаузен,雷希贝格豪森', 48.7308000, 9.6441900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32700, 'Rech', 'Rech', '', 50.5166700, 7.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32701, 'Rayerschied', 'Rayerschied', '', 50.0166700, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32702, 'Raversbeuren', 'Raversbeuren', '', 49.9500000, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32703, 'Ravensburg', 'Ravensburg', 'QRB,Ravensbourg,Ravensburg,Ravensburgas,Ravenzburg,la fen si bao,labenseubuleukeu,rafnsbwrgh,rafnzbwrg,Равензбург,Равенсбург,رافنزبورگ,رافنسبورغ,拉芬斯堡,라벤스부르크', 47.7819800, 9.6106200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32704, 'Ravengiersburg', 'Ravengiersburg', '', 49.9333300, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32705, 'Rausdorf', 'Rausdorf', '', 53.5894200, 10.3304600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32706, 'Rausdorf', 'Rausdorf', '', 50.8666700, 11.6833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32707, 'Rauschwitz', 'Rauschwitz', '', 50.9666700, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32708, 'Rauschenberg', 'Rauschenberg', 'Rauschenberg', 50.8832900, 8.9186400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32709, 'Raunheim', 'Raunheim', 'Raungajm,Raunheim,Raunkhajm,luo yin hai mu,raunhaimu,rawnhaym,Раунгайм,Раунхайм,Раунхајм,راونهايم,راونهایم,ラウンハイム,罗因海姆', 50.0132000, 8.4525300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32710, 'Raumbach', 'Raumbach', 'Raumbakh,luo yin ba he,Раумбах,罗因巴赫', 49.7166700, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32711, 'Rauenberg', 'Rauenberg', 'Rauenberg', 49.2694300, 8.7034400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32712, 'Rauen', 'Rauen', 'Rauehn,Rauen,lao en,Рауен,Рауэн,Ռաուեն,劳恩', 52.3322700, 14.0279700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32713, 'Rauda', 'Rauda', 'Rauda', 50.9527500, 11.9424800, 'DE', '2015-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32714, 'Raubling', 'Raubling', 'Raubling,lao bu ling,rawblyng,Раублинг,Раублінг,Ռաուբլինգ,راوبلینگ,劳布灵', 47.7905000, 12.1108800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32715, 'Raubach', 'Raubach', '', 50.5748900, 7.6249600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32716, 'Rätzlingen', 'Ratzlingen', '', 52.9758300, 10.6754500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32717, 'Ratzert', 'Ratzert', '', 50.6500000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32718, 'Ratzeburg', 'Ratzeburg', 'Raceburg,Raceburgum,Ratceburg,Ratzebourg,Ratzeburg,Ratzeburgo,la ce bao,ratsbwrg,ratshbwrgh,Ратцебург,Рацебург,ראציבורג,راتسبورگ,راتسهبورغ,拉策堡', 53.6996500, 10.7725600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32719, 'Rattiszell', 'Rattiszell', '', 49.0257300, 12.6592400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32720, 'Rattenkirchen', 'Rattenkirchen', 'Ratenkirkhen,Rattenkirkhen,la teng ji xing,ratn kyrshn,Ратенкирхен,Раттенкирхен,Раттенкірхен,Ռաթենկիրխեն,راتن کیرشن,拉滕基兴', 48.2420500, 12.3150700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32721, 'Rattenberg', 'Rattenberg', '', 49.0861200, 12.7491200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32722, 'Rattelsdorf', 'Rattelsdorf', '', 50.8166700, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32723, 'Rattelsdorf', 'Rattelsdorf', 'Ratelsdorf,Rattel''sdorf,la te er si duo fu,ratterusudorufu,Рателсдорф,Раттельсдорф,Ռաթելսդորֆ,ラッテルスドルフ,拉特尔斯多夫', 50.0150200, 10.8885700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32724, 'Ratshausen', 'Ratshausen', 'Ratsgauzen,Ratskhauzen,la ci hao sen,Ратсгаузен,Ратсхаузен,拉茨豪森', 48.1937300, 8.7952000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32725, 'Ratingen', 'Ratingen', 'Ratingen,ZPJ,la ting gen,lating-en,ratlyngn,Ратинген,راتلینگن,拉廷根,라팅엔', 51.2972400, 6.8492900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32726, 'Rathsweiler', 'Rathsweiler', 'Ratsvajler,la ci wei lei,Ратсвайлер,Ратсвајлер,拉茨韦勒', 49.6000000, 7.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32727, 'Rathskirchen', 'Rathskirchen', '', 49.6166700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32728, 'Rathmannsdorf', 'Rathmannsdorf', 'Ratmansdorf,la te man si duo fu,Ратмансдорф,拉特曼斯多夫', 50.9299300, 14.1422400, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32729, 'Rathjensdorf', 'Rathjensdorf', '', 54.1833300, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32730, 'Rathenow', 'Rathenow', 'Ratenov,Ratenovia,Rathenow,la te nuo,latenopeu,ratnwa,ratynw,Ратенов,Ռատենով,راتنوا,راتينو,拉特诺,라테노프', 52.6065900, 12.3369600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32731, 'Rath', 'Rath', 'Rath/Heumar', 50.9237900, 7.0927000, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32732, 'Ratekau', 'Ratekau', 'Ratekau,Ратекау', 53.9500000, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32733, 'Rastow', 'Rastow', 'Rastov,la si tuo,Растов,拉斯托', 53.4570900, 11.4314500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32734, 'Rastorf', 'Rastorf', '', 54.2666700, 10.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32735, 'Rastenberg', 'Rastenberg', 'Rastenberg,la si teng bei ge,Растенберг,拉斯滕贝格', 51.1749600, 11.4202900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32736, 'Rastede', 'Rastede', 'Raastaee,Raastäe,Rastede,la si te de,Растеде,拉斯特德', 53.2500000, 8.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32737, 'Rastdorf', 'Rastdorf', '', 52.9134700, 7.7089400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32738, 'Rastatt', 'Rastatt', 'Rashhat,Rashtat,Rashtatt,Rastatt,ZRW,la shi ta te,lasyutateu,rashtat,rashtatt,rashutatto,rastat,Раштат,Раштатт,Ращат,راستات,راشتات,რაშტატი,ラシュタット,拉施塔特,라슈타트', 48.8585100, 8.2096500, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32739, 'Raßnitz', 'Rassnitz', '', 51.3908500, 12.0940600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32740, 'Rasdorf', 'Rasdorf', 'Rasdorf,Расдорф', 50.7166700, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32741, 'Rascheid', 'Rascheid', '', 49.7166700, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32742, 'Raschau', 'Raschau', 'Raschau,Rashau,Рашау', 50.5312700, 12.8331200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32743, 'Rantzau', 'Rantzau', '', 54.2500000, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32744, 'Rantrum', 'Rantrum', 'Rantrum', 54.4406200, 9.1287200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32745, 'Ransweiler', 'Ransweiler', '', 49.6666700, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32746, 'Ranstadt', 'Ranstadt', 'Ranshtadt,Ranshtat,Ranstadt,lan si ta te,ranshutatto,Ранштадт,Ранштат,ランシュタット,兰斯塔特', 50.3573900, 8.9837500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32747, 'Ranschbach', 'Ranschbach', '', 49.1958300, 8.0286100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32748, 'Rannungen', 'Rannungen', 'Rannungen,Ranungen,la nong gen,Раннунген,Ранунген,Ռանունգեն,拉农根', 50.1653700, 10.2048400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32749, 'Rannstedt', 'Rannstedt', '', 51.0833300, 11.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32750, 'Ranis', 'Ranis', 'Ranis,la ni si,ranys,Ранис,رانيس,رانیس,拉尼斯', 50.6613200, 11.5691200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32751, 'Rangsdorf', 'Rangsdorf', 'Rangsdorf,lang si duo fu,Рангсдорф,Ռանգսդորֆ,朗斯多夫', 52.2912600, 13.4194600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32752, 'Rangendingen', 'Rangendingen', 'Rangendingen,lan gen ding gen,Рангендинген,Рангендінген,兰根丁根', 48.3816800, 8.8894000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32753, 'Randersacker', 'Randersacker', 'Randersacker,Randerzaker,Randerzakker,lan de er sa ke er,randasuakka,Рандерзакер,Рандерзаккер,Ռանդերզաքեր,ランダースアッカー,兰德尔萨克尔', 49.7602100, 9.9827700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32754, 'Ramsthal', 'Ramsthal', 'Ramstal,Ramstal'',la mu si ta er,Рамстал,Рамсталь,Ռամսթալ,拉姆斯塔尔', 50.1403900, 10.0677700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32755, 'Ramstein-Miesenbach', 'Ramstein-Miesenbach', 'Gorad Ramshtajn-Mizenbakh,Ramschdaeae-Miesebach,Ramschdää-Miesebach,Ramshtajn-Mizenbakh,Ramstein,Ramstein-Miesenbach,la mu si tai yin-mi sen ba,ramshtayn-myznbakh,ramushutain=mizenbahha,Горад Рамштайн-Мізенбах,Рамштайн-Мизенбах,Рамштајн-Мизенбах,رامشتاين-ميزنباخ,رام‌اشتاین-میزنباخ,რამშტაინ-მიზენბახი,ラムシュタイン＝ミーゼンバッハ,拉姆斯泰因-米森巴', 49.4445200, 7.5553300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32756, 'Ramstedt', 'Ramstedt', '', 54.4000000, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32757, 'Ramsla', 'Ramsla', '', 51.0500000, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32758, 'Ramsin', 'Ramsin', '', 51.6109500, 12.2381200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32759, 'Ramsen', 'Ramsen', '', 49.5369400, 8.0133300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32760, 'Ramsau', 'Ramsau', '', 48.1727700, 12.2295700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32761, 'Ramsau', 'Ramsau', 'Ramsau,Рамсау', 47.6166700, 12.9000000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32762, 'Rammingen', 'Rammingen', '', 48.5181400, 10.1719700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32763, 'Rammenau', 'Rammenau', 'Ramenau,Rammenau,Rammenau vald,Ramnow,la mei nao,Раменау,Рамменау,拉梅瑙', 51.1500000, 14.1333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32764, 'Rammelsbach', 'Rammelsbach', 'Ramelsbakh,Rammel''sbakh,la mei er si ba,Рамелсбах,Раммельсбах,拉梅尔斯巴', 49.5417000, 7.4439200, 'DE', '2013-05-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32765, 'Ramhusen', 'Ramhusen', 'Ramhusen', 53.9500000, 9.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32766, 'Ramerberg', 'Ramerberg', '', 48.0180600, 12.1451300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32767, 'Rambin', 'Rambin', '', 54.3556600, 13.2044500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32768, 'Ramberg', 'Ramberg', '', 49.2602800, 8.0083300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32769, 'Ralingen', 'Ralingen', 'Ralingen,la lin gen,Ралинген,拉林根', 49.8166700, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32770, 'Raitenbuch', 'Raitenbuch', 'Rajtenbukh,lai teng bu,Райтенбух,Рајтенбух,Ռայթենբուխ,赖滕布', 49.0146800, 11.1248600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32771, 'Raisting', 'Raisting', '', 47.9166700, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32772, 'Raisdorf', 'Raisdorf', 'Raisdorf,Rajsdorf,Райсдорф,Рајсдорф', 54.2812700, 10.2491500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32773, 'Rain', 'Rain', '', 48.9049600, 12.4687100, 'DE', '2012-12-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32774, 'Rain', 'Rain', 'Rain', 48.6902900, 10.9161100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32775, 'Rahnsdorf', 'Rahnsdorf', 'Berlin-Rahnsdorf', 52.4411500, 13.6870800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32776, 'Rahden', 'Rahden', 'Raden,Rahden,Rakhden,raden,radn,Раден,Рахден,رادن,ラーデン', 52.4336700, 8.6126300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32777, 'Raguhn', 'Raguhn', 'Raguhn', 51.7116700, 12.2753100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32778, 'Raesfeld', 'Raesfeld', 'Raesfeld,Rasfel''d,Resfel''d,Resfeld,la ai si fei er de,Расфельд,Ресфелд,Ресфельд,拉埃斯费尔德', 51.7666700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32779, 'Radolfzell am Bodensee', 'Radolfzell am Bodensee', 'Radol''fcell'',Radolfcel am Bodenze,Radolfzell,Radolfzell am Bodensee,Radolphi Cella,bo deng hu pan la duo fu cai er,radwlftsl,Радолфцел ам Бодензе,Радольфцелль,رادولفتسل,رادولفتسل آم بودن‌زی,博登湖畔拉多夫采尔', 47.7419400, 8.9709800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32780, 'Radis', 'Radis', 'Radis', 51.7522600, 12.5145300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32781, 'Radibor', 'Radibor', 'Radibor,Radibor/Radwor,Radibori vald,Radwor,la di bo er,Радибор,Радібор,拉迪博尔', 51.2448100, 14.3984200, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32782, 'Radevormwald', 'Radevormwald', 'Radeformval''d,Radeformvald,Radevormwald,la de fu er mu wa er de,radfwrmwal,radhfwrmfald,Радеформвалд,Радеформвальд,رادفورموال,رادهفورمفالد,拉德福尔姆瓦尔德', 51.2021900, 7.3602700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32783, 'Radegast', 'Radegast', 'Radegast,Радегаст', 51.6565400, 12.0948500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32784, 'Radeburg', 'Radeburg', 'Radeburg,Radeburga,Rādeburga,la de bao,radbwrg,radhbwrgh,Радебург,رادبورگ,رادهبورغ,拉德堡', 51.2151600, 13.7281000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32785, 'Radebeul', 'Radebeul', 'Radebeile,Radebojl,Radebojl'',Radobyle,Rādebeile,la de bo yi er,radbwyl,radhbwyl,Радебойль,Радебојл,رادبویل,رادهبويل,拉德博伊尔', 51.1065400, 13.6604700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32786, 'Radeberg', 'Radeberg', 'Radeberg,Radeberga,Rādeberga,la de bei ge,radbrg,radhbrgh,Радеберг,رادبرگ,رادهبرغ,拉德贝格', 51.1111200, 13.9119900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32787, 'Rade', 'Rade', '', 54.0009000, 9.7416200, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32788, 'Raddestorf', 'Raddestorf', 'Raddestorf,Radestorf,la de si tuo fu,raddesutorufu,Раддесторф,Радесторф,ラッデストルフ,拉德斯托夫', 52.4500000, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32789, 'Radbruch', 'Radbruch', 'Radbrukh,la de bu lu,Радбрух,拉德布鲁', 53.3166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32790, 'Rackwitz', 'Rackwitz', 'Rackwitzi vald,Rakvic,la ke wei ci,Раквиц,拉克维茨', 51.4333300, 12.3833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32791, 'Racksen', 'Racksen', '', 50.7333300, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32792, 'Räckelwitz', 'Raeckelwitz', 'Raeckelwitz,Raeckelwitz/Worklecy,Raeckelwitzi vald,Rehkel''vic,Rekelvic,Rekkel''vic,Räckelwitz,Räckelwitz/Worklecy,Räckelwitzi vald,Worklecy,lei ke er wei ci,Рекелвиц,Реккельвиц,Рэкельвиц,雷克尔维茨', 51.2500000, 14.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32793, 'Räbke', 'Rabke', 'Rebke,lei bu ke,Ребке,雷布克', 52.1960300, 10.8787000, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32794, 'Raben Steinfeld', 'Raben Steinfeld', 'Raben Steinfeld', 53.6014100, 11.5048700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32795, 'Rabenholz', 'Rabenholz', 'Rabenholz', 54.7166700, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32796, 'Rabenau', 'Rabenau', 'Rabenau', 50.9648400, 13.6430500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32797, 'Rabel', 'Rabel', '', 54.7000000, 9.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32798, 'Raa-Besenbek', 'Raa-Besenbek', 'Raa-Besenbek', 53.7483700, 9.5945400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32799, 'Quitzdorf', 'Quitzdorf', '', 51.2833300, 14.7666700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32800, 'Quirnheim', 'Quirnheim', '', 49.5844400, 8.1263900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32801, 'Quirnbach', 'Quirnbach', '', 50.5208300, 7.7969400, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32802, 'Quirla', 'Quirla', 'Quirla', 50.8666700, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32803, 'Quierschied', 'Quierschied', 'Kvirshid,kui er xi de,Квиршид,Квіршид,奎尔希德', 49.3166700, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32804, 'Quiddelbach', 'Quiddelbach', '', 50.3500000, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32805, 'Quickborn', 'Quickborn', '', 54.0105800, 9.2089600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32806, 'Quickborn', 'Quickborn', 'Kvikborn,Quickborn,kfykbwrn,ku yi ke bo er en,kwyykbwrn,Квикборн,كفيكبورن,کوئیکبورن,库伊克博尔恩', 53.7283100, 9.9093400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32807, 'Quernheim', 'Quernheim', '', 52.4666700, 8.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32808, 'Quern', 'Quern', 'Kvaern,Kvern,Kværn,Quern,ku ai er en,Кверн,库埃尔恩', 54.7500000, 9.7166700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32809, 'Querfurt', 'Querfurt', 'Kverfurt,Querfurt,kfyrfwrt,ku ai er fu er te,kwyrfwrt,Кверфурт,كفيرفورت,کوئرفورت,库埃尔富尔特', 51.3812400, 11.6004700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32810, 'Querenhorst', 'Querenhorst', '', 52.3333300, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32811, 'Quellendorf', 'Quellendorf', 'Quellendorf', 51.7491600, 12.1279600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32812, 'Queis', 'Queis', '', 51.4762600, 12.1345500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32813, 'Queidersbach', 'Queidersbach', '', 49.3666700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32814, 'Quedlinburg', 'Quedlinburg', 'Gorad Kvedlinburg,Kvedlinburg,Kvedlinburgas,Queddelnborg,Quedlimburgo,Quedlinbourg,Quedlinburg,Quedlinburgum,Stadt Quedlinburg,keubedeullinbuleukeu,kfydlynbwrgh,kui de lin bao,kuvu~edorinburuku,kwydlyndbwrg,qwwdlynbwrg,Горад Кведлінбург,Кведлинбург,Кведлінбург,קוודלינבורג,كفيدلينبورغ,کوئدلیندبورگ,კვედლინბურგი,クヴェードリンブルク,奎德林堡,크베들린부르크', 51.7884300, 11.1500600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32815, 'Quaschwitz', 'Quaschwitz', 'Quaschwitz', 50.6833300, 11.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32816, 'Quarnstedt', 'Quarnstedt', '', 53.9548500, 9.7873600, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32817, 'Quarnbek', 'Quarnbek', 'Kvarnbek,Quarnbek,ku a er en bei ke,Кварнбек,库阿尔恩贝克', 54.3333300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32818, 'Quakenbrück', 'Quakenbrueck', 'IQuakenbrueck,IQuakenbrück,Kvakenbrik,Kvakenbrjuk,Quakenbruck,Quakenbrueck,Quakenbrück,Quokenbruegge,Quokenbrügge,kfaknbrwk,ku a ken bu lu ke,kwaknbwrk,Квакенбрик,Квакенбрюк,كفاكنبروك,کواکنبورک,库阿肯布吕克', 52.6750200, 7.9498300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32819, 'Pyrbaum', 'Pyrbaum', 'Pirbaum,Pyrbaum,pi er bao mu,Пирбаум,Փիրբաում,皮尔鲍姆', 49.2962200, 11.2865500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32820, 'Putzbrunn', 'Putzbrunn', '', 48.0757900, 11.7157200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32821, 'Püttlingen', 'Puettlingen', 'Pitlingen,Pjutlingen,Pjuttlingen,Puettlingen,Püttlingen,bwtlynghn,pi te lin gen,pwtlyngn,Питлинген,Пютлинген,Пюттлінген,بوتلينغن,پوتلینگن,皮特林根', 49.2855000, 6.8872300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32822, 'Putlitz', 'Putlitz', 'Putlic,bwtlytz,pu te li ci,pwtlytz,Путлиц,بوتليتز,پوتلیتز,普特利茨', 53.2489900, 12.0417900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32823, 'Putbus', 'Putbus', 'Podbes,Putbus,Putbusa,Pòdbes,pu te bu si,pwtbws,Путбус,پوتبوس,普特布斯', 54.3551100, 13.4763400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32824, 'Puschwitz', 'Puschwitz', 'Bosicy,Bóšicy,Puschwitz/Bosicy,Puschwitz/Bóšicy,Puschwitzi vald,Pushvic,pu shi wei ci,Пушвиц,Пушвіц,普施维茨', 51.2550100, 14.3011100, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32825, 'Puschendorf', 'Puschendorf', '', 49.5239800, 10.8319200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32826, 'Pürgen', 'Purgen', 'Pirgen,Pjurgen,pi er gen,pwrgn,pyurugen,Пирген,Пюрген,Փյուրգեն,پورگن,ピュルゲン,皮尔根', 48.0247200, 10.9221300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32827, 'Pünderich', 'Puenderich', 'Pinderikh,Pjunderikh,Puenderich,Pünderich,ping de li xi,Пиндерих,Пюндерих,平德里希', 50.0399700, 7.1280300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32828, 'Puls', 'Puls', 'Puls', 54.0833300, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32829, 'Pullenreuth', 'Pullenreuth', '', 49.9333300, 12.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32830, 'Pullach im Isartal', 'Pullach im Isartal', 'Pulakh im Izartal,Pullach,Pullakh,Pullakh-im-Izartal'',Pulloch im Isartoi,pwlakh,Пулах им Изартал,Пуллах,Пуллах-им-Изарталь,Իզարթալի Պուլախ,پولاخ,プラッハ・イム・イーザルタール', 48.0612200, 11.5214800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32831, 'Pulheim', 'Pulheim', 'Pul''gajm,Pul''khajm,Pulheim,Pulkhajm,Pullem,bwlhaym,pu er hai mu,pwlhaym,Пулхајм,Пульгайм,Пульхайм,بولهايم,پولهایم,普爾海姆', 50.9996500, 6.8063200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32832, 'Puderbach', 'Puderbach', 'Puderbach,Puderbakh,pu de er ba he,pudabahha,Пудербах,プダーバッハ,普德尔巴赫', 50.6000000, 7.6166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32833, 'Puchheim', 'Puchheim', 'Buachham,Puchheim,Pukhgajm,Pukhkhajm,Puxhaym,pu hai mu,pwkhhaym,Пухгайм,Пуххайм,Пуххајм,Պուխհայմ,پوخهایم,普海姆', 48.1500000, 11.3500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32834, 'Püchersreuth', 'Puchersreuth', 'Pikhersrojt,Pjukhersrojt,pi xie er si luo yi te,Пихерсројт,Пюхерсройт,Պյուխերսրոյթ,皮歇尔斯罗伊特', 49.7500000, 12.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32835, 'Prutting', 'Prutting', '', 47.8932100, 12.2023800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32836, 'Prümzurlay', 'Prumzurlay', 'Primcurlaj,Prjumcurlaj,Pruemzurlay,Prümzurlay,pu lu mu chu er lai,Примцурлај,Прюмцурлай,普吕姆楚尔莱', 49.8666700, 6.4333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32837, 'Prüm', 'Pruem', 'Prim,Prjum,Pruem,Prum,Prüm,prwm,pu lu mu,puryumu,Прим,Прюм,پروم,プリュム,普吕姆', 50.2078500, 6.4201900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32838, 'Prötzel', 'Protzel', 'Precel,Prjotcel'',pu lei ce er,Прецел,Прётцель,Պրյոտցել,普勒策尔', 52.6372300, 13.9878300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32839, 'Prosselsheim', 'Prosselsheim', 'Proselshaym,Proselskhajm,Prossel''sgajm,Prossel''skhajm,pu luo sai er si hai mu,purosserusuhaimu,Проселсхајм,Проссельсгайм,Проссельсхайм,Պրոսելսհայմ,プロッセルスハイム,普罗塞尔斯海姆', 49.8630900, 10.1266600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32840, 'Pronstorf', 'Pronstorf', 'Pronstorf,pu long si tuo er fu,Пронсторф,普龙斯托尔夫', 53.9500000, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32841, 'Pronsfeld', 'Pronsfeld', 'Pronsfel''d,Pronsfeld,pu long si fei er de,Пронсфелд,Пронсфельд,普龙斯费尔德', 50.1597700, 6.3404200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32842, 'Prohn', 'Prohn', '', 54.3690100, 13.0236900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32843, 'Probstzella', 'Probstzella', 'Probscela,Probscella,Probstzella,pu luo bu si ce la,Пробсцела,Пробсцелла,普罗布斯策拉', 50.5333300, 11.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32844, 'Probsteierhagen', 'Probsteierhagen', 'Probshtajerkhagen,Probstajerkhagen,Probsteierhagen,pu luo bu si tai ai la gen,Пробстайерхаген,Пробштајерхаген,普罗布斯泰埃拉根', 54.3615300, 10.2877200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32845, 'Pritzwalk', 'Pritzwalk', 'Pricval''k,Pricvalk,brytsfalk,prytzwak,pu li ci wa er ke,Прицвалк,Прицвальк,بريتسفالك,پریتزواک,普里茨瓦尔克', 53.1494500, 12.1740500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32846, 'Prittriching', 'Prittriching', 'Pritrikhing,Prittrikhing,prytryshyng,pu li te li xing,purittorihingu,Притрихинг,Пріттріхінг,Փրիտրիխինգ,پریتریشینگ,プリットリヒング,普里特里兴', 48.2007400, 10.9280100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32847, 'Prittitz', 'Prittitz', 'Prittitz', 51.1499600, 11.9302000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32848, 'Prisdorf', 'Prisdorf', 'Prisdorf', 53.6833300, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32849, 'Prinzhöfte', 'Prinzhofte', 'Princkhefte,Princkhjofte,pu lin ci he fu te,Принцхефте,Принцхёфте,普林茨赫夫特', 52.9500000, 8.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32850, 'Prinzenmoor', 'Prinzenmoor', 'Prinzenmoor', 54.2166700, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32851, 'Priestewitz', 'Priestewitz', 'Priestewitzi vald,Pristevic,pu li si te wei ci,Пристевиц,Прістевіц,普里斯特维茨', 51.2500000, 13.5166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32852, 'Priesendorf', 'Priesendorf', 'Prisendorf,Prizendorf,pu li sen duo fu,purizendorufu,Призендорф,Присендорф,Прізендорф,Պրիզենդորֆ,プリーゼンドルフ,普里森多夫', 49.9075000, 10.7118300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32853, 'Prien am Chiemsee', 'Prien am Chiemsee', 'Kimzeei Prin,Prean am Cheamsee,Prien,Prien am Chiemsee,Prin am Kimze,Prin-am-Kimze,Prin-am-Kimzee,ji mu hu pan pu lin,pyrn am shymzy,Прин ам Кимзе,Прин-ам-Кимзе,Прин-ам-Кимзее,Прін-ам-Кімзе,Կիմզեեի Պրին,پیرن ام شیمزی,基姆湖畔普林', 47.8560200, 12.3462300, 'DE', '2016-01-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32854, 'Prichsenstadt', 'Prichsenstadt', 'Prichsenstadt,Prikhsenshtat,Priksenshtadt,bryksnshtat,pu li xi sen si ta te,Приксенштадт,Прихсенштат,Пріксенштадт,Պրիքսենշթաթ,بريكسنشتات,پریزن‌اشتات,普里希森斯塔特', 49.8193300, 10.3477300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32855, 'Prezelle', 'Prezelle', 'Precele,Precelle,prtslh,pu lei ce lai,Прецеле,Прецелле,پرتسله,普雷策莱', 52.9666700, 11.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32856, 'Preußisch Oldendorf', 'Preussisch Oldendorf', 'Preussisch Oldendorf,Preußisch Oldendorf,Projsish Oldendorf,Projsish-Ol''dendorf,brwysysh awldndwrf,prwysysh awldndwrf,pu luo yi xi shi ao er deng duo fu,Пройсиш-Ольдендорф,Пройсіш-Ольдендорф,Пројсиш Олдендорф,برويسيش أولدندورف,پرویسیش اولدندورف,プロイシシュ・オルデンドルフ,普罗伊西施奥尔登多夫', 52.3058900, 8.4934100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32857, 'Pretzschendorf', 'Pretzschendorf', 'Prechendorf,Precshendorf,Pretzschendorf,pu lei ci xing duo fu,Прецшендорф,Пречендорф,普雷茨兴多夫', 50.8738500, 13.5249900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32858, 'Pretzsch', 'Pretzsch', 'Prech,Pretch,Pretzsch,Претч,Преч', 51.7146600, 12.8066300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32859, 'Pretzier', 'Pretzier', 'Pretzier', 52.8322400, 11.2610500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32860, 'Pretzfeld', 'Pretzfeld', 'Precfel''d,Precfeld,Precfeldas,pu lei ci fei er de,purettsuferuto,Прецфелд,Прецфельд,Փրեցֆելդ,プレッツフェルト,普雷茨费尔德', 49.7545400, 11.1743000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32861, 'Prettin', 'Prettin', 'Pretin,Prettin,Претин,Преттин', 51.6607700, 12.9235300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32862, 'Pressig', 'Pressig', 'Presig,Pressig,pu lei xi xi,pureshihi,Пресиг,Прессиг,Прессіг,Պրեսիգ,プレシヒ,普雷西希', 50.3524500, 11.3096900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32863, 'Presseck', 'Presseck', 'Presek,Presseck,Pressek,pu lei sai ke,puresekku,Пресек,Прессек,Պրեսեկ,プレセック,普雷塞克', 50.2280400, 11.5550800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32864, 'Pressath', 'Pressath', 'Presat,Pressat,Pressath,brsat,prsat,pu lei sa te,Пресат,Прессат,Պրեսաթ,برسات,پرسات,普雷萨特', 49.7685900, 11.9397200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32865, 'Prenzlauer Berg', 'Prenzlauer Berg Bezirk', 'Berlin-Prenzlauer Berg,Prenclauehr-Berg,Prenclauer-Berg,pu lun ci lao bei ge,Пренцлауер-Берґ,Пренцлауэр-Берг,פרנצלאואר ברג,プレンツラウアー・ベルク,普伦茨劳贝格', 52.5387800, 13.4244300, 'DE', '2013-03-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32866, 'Prenzlau', 'Prenzlau', 'Prenclau,Prenzlau,brntslaw,prntslaw,pu lun ci lao,Пренцлау,Պրենցլաու,פרנצלאו,برنتسلاو,پرنتسلاو,普伦茨劳', 53.3162500, 13.8626100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32867, 'Premnitz', 'Premnitz', 'Premnic,Premnitz,brymnts,prmnytz,pu lei mu ni ci,Премниц,Պրեմնից,بريمنتس,پرمنیتز,普雷姆尼茨', 52.5318400, 12.3484500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32868, 'Prem', 'Prem', '', 47.6833300, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32869, 'Preist', 'Preist', '', 49.9066100, 6.6317200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32870, 'Preischeid', 'Preischeid', '', 50.0333300, 6.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32871, 'Preetz', 'Preetz', '', 54.3501700, 12.9893600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32872, 'Preetz', 'Preetz', 'Prec,Preetz,bryyts,prytts,pu lei ci,Прец,برييتس,پریتتس,普雷茨', 54.2354000, 10.2779500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32873, 'Prebitz', 'Prebitz', 'Prebic,pu lei bi ci,purebittsu,Пребиц,Пребіц,Պրեբից,プレビッツ,普雷比茨', 49.8333300, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32874, 'Prath', 'Prath', '', 50.1833300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32875, 'Prasdorf', 'Prasdorf', 'Prasdorf', 54.3833300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32876, 'Prackenbach', 'Prackenbach', '', 49.0954300, 12.8261400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32877, 'Pracht', 'Pracht', '', 50.7603100, 7.6487100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32878, 'Poyenberg', 'Poyenberg', 'Poyenberg', 54.0333300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32879, 'Poxdorf', 'Poxdorf', '', 50.9666700, 11.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32880, 'Poxdorf', 'Poxdorf', '', 49.9364200, 11.1221100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32881, 'Poxdorf', 'Poxdorf', '', 49.6633500, 11.0707900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32882, 'Pouch', 'Pouch', '', 51.6232400, 12.4013300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32883, 'Pottum', 'Pottum', '', 50.6000000, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32884, 'Pöttmes', 'Pottmes', 'Bejmas,Petmes,Pettmes,Pjotmes,Poettmes,Pottmes,Pyotmes,Pöttmes,pettomesu,po te mei si,Петмес,Петтмес,Пётмес,Պյոտմես,ペットメス,珀特梅斯', 48.5838300, 11.0876200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32885, 'Pottiga', 'Pottiga', 'Potiga,Pottiga,bo di jia,Потига,Поттига,波蒂加', 50.4145900, 11.7405200, 'DE', '2012-04-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32886, 'Pottenstein', 'Pottenstein', 'Pottenstein', 49.7713100, 11.4078400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32887, 'Potsdam', 'Potsdam', 'Poczdam,Podstupim,Postupim,Potsdam,Potsdamo,Poztupimi,bo ci tan,pocheudam,potsudamu,pwtsdm,Πότσδαμ,Потсдам,פוטסדאם,פוטסדם,ポツダム,波茨坦,포츠담', 52.3988600, 13.0656600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32888, 'Postmünster', 'Postmunster', 'Postminster,Postmjunster,Postmuenster,Postmünster,bo si te ming si te er,pst mwnstr,Постминстер,Постмюнстер,Փոսթմյունսթեր,پست مونستر,波斯特明斯特尔', 48.4166700, 12.9000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32889, 'Postfeld', 'Postfeld', '', 54.2103700, 10.2127800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32890, 'Posterstein', 'Posterstein', 'Postershtajn,bo si te er si tai yin,Постерштайн,Постерштајн,波斯特尔斯泰因', 50.8666700, 12.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32891, 'Postau', 'Postau', 'Postau,bo si tao,pwstaw,Постау,Փոսթաու,پوستاو,波斯陶', 48.6500000, 12.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32892, 'Pößneck', 'Poessneck', 'Pesnek,Pjosnek,Poessneck,Pößneck,bwsnk,po si nei ke,pwsnk,Песнек,Пёснек,بوسنك,پوسنک,珀斯内克', 50.6935800, 11.5922900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32893, 'Pösing', 'Posing', 'Pezing,Pjozing,Pyozing,po xin ge,Пезинг,Пезінг,Пёзинг,Պյոզինգ,珀辛格', 49.2333300, 12.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32894, 'Poseritz', 'Poseritz', 'Poseritz,Pozeric,bo sai li ci,Позериц,波塞里茨', 54.2981100, 13.2749200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32895, 'Pöschendorf', 'Poschendorf', 'Poeschendorf,Poschendorf,Pöschendorf', 54.0374000, 9.4884500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32896, 'Porz am Rhein', 'Porz am Rhein', 'Koeln-Porz,Köln-Porz,Porz,Porz am Rhein', 50.8863700, 7.0583000, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32897, 'Porta Westfalica', 'Porta Westfalica', '', 52.2296100, 8.9161200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32898, 'Porschdorf', 'Porschdorf', '', 50.9418000, 14.1268700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32899, 'Pörnbach', 'Pornbach', 'Bembo,Pernbakh,Pjornbakh,Poernbach,Pyornbax,Pörnbach,po er en ba he,pwrnbakh,Пернбах,Пёрнбах,Պյորնբախ,پورنباخ,珀尔恩巴赫', 48.6166700, 11.4666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32900, 'Pörmitz', 'Pormitz', 'Pormitz,Pörmitz', 50.6166700, 11.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32901, 'Poppenricht', 'Poppenricht', 'Michaels Poppenricht,Poppenricht', 49.4755700, 11.7977800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32902, 'Poppenhausen', 'Poppenhausen', 'Popenkhauzen,Poppengauzen,Poppenkhauzen,Попенхаузен,Поппенгаузен,Поппенхаузен', 50.4879300, 9.8679500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32903, 'Poppenhausen', 'Poppenhausen', '', 50.0999900, 10.1424400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32904, 'Poppenbüttel', 'Poppenbuettel', 'Hamburg-Poppenbuettel,Hamburg-Poppenbüttel,Popenbitel,Попенбител', 53.6591700, 10.0847200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32905, 'Poppenbüll', 'Poppenbull', 'Poppenbull,Poppenbüll', 54.3608800, 8.7612000, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32906, 'Ponitz', 'Ponitz', 'Ponic,bo ni ci,Пониц,波尼茨', 50.8576200, 12.4230900, 'DE', '2014-05-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32907, 'Pomster', 'Pomster', '', 50.3534600, 6.8427700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32908, 'Pommersfelden', 'Pommersfelden', 'Pomersfelden,Pommersfel''den,bo mei er si fei er deng,ponmasuferuden,Померсфелден,Поммерсфельден,Պոմերսֆելդեն,ポンマースフェルデン,波梅尔斯费尔登', 49.7666700, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32909, 'Pommern', 'Pommern', '', 50.1666700, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32910, 'Pommerby', 'Pommerby', '', 54.7666700, 9.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32911, 'Pommelsbrunn', 'Pommelsbrunn', 'Pomelsbrun,Pommel''sbrunn,bo mei er si bu lun,Помелсбрун,Поммельсбрунн,Պոմելսբրուն,波梅尔斯布伦', 49.5043700, 11.5110100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32912, 'Pölzig', 'Polzig', 'Pelcig,Pjol''cig,Poelzig,Polzig,Pölzig,po er qi xi,Пелциг,Пёльциг,珀尔齐希', 50.9500000, 12.2000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32913, 'Polsingen', 'Polsingen', 'Pol''zingen,Polsingen,Polzingen,bo er xin gen,Полсинген,Пользинген,Пользінген,Պոլզինգեն,波尔辛根', 48.9206700, 10.7115000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32914, 'Polling', 'Polling', '', 48.2166700, 12.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32915, 'Polling', 'Polling', '', 47.8110200, 11.1324100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32916, 'Pollhagen', 'Pollhagen', '', 52.3852900, 9.1881300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32917, 'Pollenfeld', 'Pollenfeld', 'Polenfeld,Pollenfel''d,bo lun fei er de,pwlnfld,Поленфелд,Полленфельд,Պոլենֆելդ,پولنفلد,波伦费尔德', 48.9500000, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32918, 'Polleben', 'Polleben', '', 51.5796600, 11.5993100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32919, 'Polle', 'Polle', 'Pole,Polle,bo lai,pore,Поле,Полле,ポレ,波莱', 51.8987100, 9.4038600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32920, 'Poll', 'Poll', 'Koeln-Poll,Köln-Poll', 50.9125600, 6.9905700, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32921, 'Pölitz', 'Poelitz', '', 53.7730300, 10.3827600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32922, 'Pölich', 'Polich', 'Poelich,Pölich', 49.8000000, 6.8500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32923, 'Polch', 'Polch', 'Pol''kh,Polch,bo er xi,bwlkh,plsh,poruhi,Польх,بولخ,پلش,ポルヒ,波尔希', 50.2997300, 7.3131500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32924, 'Poing', 'Poing', '', 48.1700400, 11.8186300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32925, 'Pohnsdorf', 'Pohnsdorf', '', 54.2395500, 10.2489600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32926, 'Pohle', 'Pohle', '', 52.2662700, 9.3440400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32927, 'Pöhla', 'Poehla', 'Pohla,Pöhla', 50.5114300, 12.8188900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32928, 'Pöhl', 'Pohl', 'Pel,Pjol'',po he er,Пел,Пёль,Пөль,珀赫尔', 50.5500000, 12.1833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32929, 'Pöhl', 'Poehl', 'Poehl,Pohl,Pöhl', 50.3931100, 12.3290800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32930, 'Pohl', 'Pohl', '', 50.2500000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32931, 'Poggensee', 'Poggensee', '', 53.6500000, 10.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32932, 'Pogeez', 'Pogeez', 'Pogeez', 53.7511500, 10.7287500, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32933, 'Podelzig', 'Podelzig', 'Alt Podeizig,Podel''cig,Podelcig,bo de er qi xi,Поделциг,Подельциг,Պոդելցիգ,波德尔齐希', 52.4717500, 14.5346500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32934, 'Pocking', 'Pocking', 'Bocking,Pocking,Poking,Pokking,bo jin ge,bwkyngh,pkyng,Покинг,Поккинг,Поккінг,Պոքինգ,بوكينغ,پکینگ,波金格', 48.4014900, 13.3131500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32935, 'Pöcking', 'Pocking', 'Peking,Pekking,Pjoking,Pjokking,Pocking,Pöcking,po jin ge,pwkyng,Пекинг,Пеккінг,Пёккинг,Пёкінг,پوکینگ,珀金格', 47.9666700, 11.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32936, 'Pockau', 'Pockau', 'Pokau,Pokkau,bo kao,Покау,Поккау,波考', 50.7000000, 13.2333300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32937, 'Pobershau', 'Pobershau', 'Pobershau,Poberskhau,Поберсхау', 50.6407900, 13.2177600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32938, 'Pluwig', 'Pluwig', '', 49.6897600, 6.7123900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32939, 'Plütscheid', 'Plutscheid', '', 50.0833300, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32940, 'Plüderhausen', 'Pluderhausen', 'Pliderkhauzen,Pljudergauzen,Pljuderkhauzen,Pluederhausen,Plüderhausen,pu lu de lao sen,Плидерхаузен,Плюдергаузен,Плюдерхаузен,普吕德劳森', 48.7987500, 9.5958700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32941, 'Plötzky', 'Ploetzky', 'Plotzky,Plötzky', 52.0520700, 11.8020200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32942, 'Plötzkau', 'Plotzkau', '', 51.7500000, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32943, 'Plothen', 'Plothen', 'Ploten,Plothen,pu luo teng,Плотен,普洛滕', 50.6333300, 11.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32944, 'Plößberg', 'Plossberg', '', 49.9197700, 11.8688300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32945, 'Plön', 'Ploen', 'Plen,Pljon,Ploen,Ploena,Ploeoen,Plon,Plön,Plöön,Pløn,blwn,plwn,pu lun,Плен,Плён,بلون,پلون,پلێڤێن,普伦', 54.1624100, 10.4233300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32946, 'Plochingen', 'Plochingen', 'Plokhingen,Ploxingen,blwshynghn,plwshyngn,pu luo xin gen,Плохинген,Плохінген,Պլոխինգեն,بلوشينغن,پلوشینگن,普洛欣根', 48.7106700, 9.4194900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32947, 'Pliezhausen', 'Pliezhausen', 'Plicgauzen,Plickhauzen,pu li ci hao sen,Плицхаузен,Пліцгаузен,普利茨豪森', 48.5593400, 9.2074900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32948, 'Pliening', 'Pliening', 'Plining,plynyng,pu li ning,Плининг,Плінінг,پلینینگ,普利宁', 48.1955600, 11.8006900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32949, 'Pleystein', 'Pleystein', 'Bleistein,Plajshtajn,Plejshtajn,blayshtayn,pu lai si tai yin,Плайштайн,Плајштајн,Плейштайн,Պլեյշթայն,بلايشتاين,پلی‌اشتاین,普莱斯泰因', 49.6490700, 12.4063100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32950, 'Plettenberg', 'Plettenberg', 'Pletenberg,Plettenberg,Plettmert,Stadt Plettenberg,bltnbrgh,pltnbrg,pu lai teng bei ge,Плетенберг,Плеттенберг,بلتنبرغ,پلتنبرگ,普莱滕贝格', 51.2094900, 7.8726100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32951, 'Plessa', 'Plessa', 'Plesa,Plesow,Plessa,pu lai sa,Плеса,Плесса,Պլեսա,普莱萨', 51.4666700, 13.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32952, 'Pleizenhausen', 'Pleizenhausen', '', 50.0166700, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32953, 'Pleitersheim', 'Pleitersheim', '', 49.8333300, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32954, 'Pleisweiler-Oberhofen', 'Pleisweiler-Oberhofen', '', 49.1180600, 8.0077800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32955, 'Pleiskirchen', 'Pleiskirchen', 'Plajskirkhen,Playskirxen,Pleiskircha,Pljajskirkhen,plays kyrshn,pu lai si ji er xing,Плайскирхен,Плајскирхен,Пляйскірхен,Պլայսկիրխեն,پلایس کیرشن,普莱斯基尔兴', 48.3071300, 12.5983200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32956, 'Pleinfeld', 'Pleinfeld', 'Plajnfel''d,Plajnfeld,Playnfeld,Pleinfeld,Pljajnfel''d,pu lai yin fei er de,Плайнфельд,Плајнфелд,Пляйнфельд,Պլայնֆելդ,普莱因费尔德', 49.1047300, 10.9819400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32957, 'Plein', 'Plein', '', 50.0333300, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32958, 'Pleidelsheim', 'Pleidelsheim', 'Plajdel''skhajm,Plajdelskhajm,Pljajdel''sgajm,playdlshaym,pu lai de er si hai mu,Плайдельсхайм,Плајделсхајм,Пляйдельсгайм,پلایدلسهایم,普莱德尔斯海姆', 48.9592000, 9.2031100, 'DE', '2013-04-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32959, 'Pleckhausen', 'Pleckhausen', '', 50.5950600, 7.5421600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32960, 'Plauen', 'Plauen', 'Plauehn,Plauen,Plauenas,Plauene,Plavia Variscorum,Plavno,Plawno,Pławno,blawyn,peullauen,phe la xein,plauehn,plawyn,pu lao en,purauen,Плауен,Плауэн,פלאואן,بلاوين,پلاوئن,เพลาเอิน,プラウエン,普劳恩,플라우엔', 50.4973000, 12.1378200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32961, 'Plaue', 'Plaue', 'Plaue,Plaueh,blawh,plawh,pu lao ai,Плауе,Плауэ,بلاوه,پلاوه,普劳埃', 50.7783500, 10.8996900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32962, 'Plau am See', 'Plau am See', 'Plau,Plau am Ze,Plau-am-Ze,Plauamze,Plauamzē,bin hu pu lao,blaw am zyh,plaw am zy,Плау ам Зе,Плау-ам-Зе,بلاو آم زيه,پلاو آم زی,滨湖普劳', 53.4582100, 12.2624600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32963, 'Plattling', 'Plattling', 'Pladling,Platling,Plattling,blatlyngh,platlyng,pu la te ling,Платлинг,Платтлінг,Պլաթլինգ,بلاتلينغ,پلاتلینگ,普拉特灵', 48.7786600, 12.8750900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32964, 'Plattenburg', 'Plattenburg', 'Platenburg,Plattenburg,pu la teng bao,Платенбург,Платтенбург,普拉滕堡', 52.9591900, 12.0295100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32965, 'Platten', 'Platten', '', 49.9516100, 6.9531300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32966, 'Plate', 'Plate', '', 53.5514500, 11.5092700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32967, 'Plascheid', 'Plascheid', '', 50.0333300, 6.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32968, 'Plankstadt', 'Plankstadt', 'Plankshtadt,Plankshtat,Plankstadt,pu lan ke si ta te,purankushutatto,Планкштадт,Планкштат,プランクシュタット,普兰克斯塔特', 49.3944400, 8.5961100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32969, 'Plankenfels', 'Plankenfels', 'Plankenfel''s,Plankenfels,pu lan ken fei er si,purankenferusu,Планкенфелс,Планкенфельс,Պլանկենֆելս,プランケンフェルス,普兰肯费尔斯', 49.8833300, 11.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32970, 'Planegg', 'Planegg', 'Planeck,Planeg,Planegg,blangh,plang,pu la nei ge,Планег,Планегг,Պլանեգ,بلانغ,پلانگ,普拉内格', 48.1067200, 11.4248300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32971, 'Plaidt', 'Plaidt', 'Plajdt,Plajt,pu lai te,Плайдт,Плајт,普莱特', 50.3926000, 7.3925100, 'DE', '2011-08-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32972, 'Pittenhart', 'Pittenhart', 'Pitenkhart,Pittengart,Pittenkhart,Pittnhart,pi teng ha er te,pytnhart,Питенхарт,Питтенхарт,Піттенгарт,Փիթենհարթ,پیتنهارت,皮滕哈尔特', 47.9772400, 12.3899700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32973, 'Pittenbach', 'Pittenbach', '', 50.1833300, 6.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32974, 'Pirow', 'Pirow', '', 53.2166700, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32975, 'Pirna', 'Pirna', 'Perno,Pirna,Pěrno,pi er na,pyrna,Пирна,پیرنا,皮尔纳', 50.9584300, 13.9370200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32976, 'Pirmasens', 'Pirmasens', 'Baermesens,Bärmesens,Pirmasens,Pirmazens,Pirminisensna,ZPI,pi er ma sen si,pileumajenseu,pirumazensu,pyrmaznz,Пирмазенс,پیرمازنز,ピルマゼンス,皮尔马森斯,피르마젠스', 49.2014500, 7.6052900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32977, 'Pirk', 'Pirk', 'Pirk,Purk', 49.6333300, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32978, 'Pinzberg', 'Pinzberg', 'Pincberg,ping ci bei ge,pintsuberuku,Пинцберг,Пінцберг,Փինցբերգ,ピンツベルク,平茨贝格', 49.6897100, 11.1020700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32979, 'Pintesfeld', 'Pintesfeld', '', 50.1166700, 6.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32980, 'Pinnow', 'Pinnow', '', 53.6016400, 11.5457700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32981, 'Pinnow', 'Pinnow', '', 53.0619500, 14.0855900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32982, 'Pinneberg', 'Pinneberg', 'Pineberg,Pinebergas,Pinnbarg,Pinneberg,bynhbrgh,ping ne bei ge,pynbrg,Пинеберг,Пиннеберг,פינברג,بينهبرغ,پینبرگ,平讷贝格', 53.6673200, 9.7893600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32983, 'Pilsting', 'Pilsting', 'Pil''sting,Pilsting,pi er si ting ge,pylstyng,Пилстинг,Пильстинг,Пільстінг,Պիլսթինգ,پیلستینگ,皮尔斯廷格', 48.7011600, 12.6510500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32984, 'Pilsach', 'Pilsach', 'Pil''zakh,Pilzakh,pi er sa,Пилзах,Пильзах,Пільзах,Փիլզախ,皮尔萨', 49.3213700, 11.5031100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32985, 'Pillig', 'Pillig', '', 50.2391900, 7.3115700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32986, 'Piesport', 'Piesport', 'Pisport,pi si bo er te,Писпорт,皮斯波尔特', 49.8864000, 6.9164900, 'DE', '2012-09-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32987, 'Piesau', 'Piesau', 'Piesau,Pizau,pi shao,Пизау,皮绍', 50.5166700, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32988, 'Pielenhofen', 'Pielenhofen', 'Pilengofen,Pilenhofen,Pilenkhofen,pi lun huo fen,pylnhwfn,Пиленхофен,Піленгофен,Պիլենհոֆեն,پیلنهوفن,皮伦霍芬', 49.0723500, 11.9569900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32989, 'Piding', 'Piding', 'Au,Piding,pi ding,pydyng,Пидинг,Підінг,Պիդինգ,پیدینگ,皮丁', 47.7666700, 12.9166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32990, 'Philippsheim', 'Philippsheim', 'Philippsheim,Phillipsheim', 49.9500000, 6.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32991, 'Philippsthal', 'Philippsthal', '', 50.8394800, 10.0090600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32992, 'Philippsreut', 'Philippsreut', 'Filippsrojt,Filipsrojt,Philippsreut,fei li pu si luo yi te,fylypsrwyt,Филипсройт,Филипсројт,Філіппсройт,Ֆիլիպսրոյթ,فیلیپسرویت,菲利普斯罗伊特', 48.8666700, 13.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32993, 'Philippsburg', 'Philippsburg', 'Filippsburg,Filipsburg,Filisburgo,Philippsburg,fei li pu si bao,fylybsbwrgh,fylypsbpwrg,Филипсбург,Філіппсбург,فيليبسبورغ,فیلیپسبپورگ,ფილიპსბურგი,菲利普斯堡', 49.2317000, 8.4607400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32994, 'Pfungstadt', 'Pfungstadt', 'Gorad Pfungshtat,Pfungshtadt,Pfungshtat,Pfungstadt,bfwnghsshtat,fwngzashtat,pu feng si ta te,pufungushutatto,Горад Пфунгштат,Пфунгштадт,Пфунгштат,بفونغسشتات,فونگزاشتات,プフングシュタット,普丰斯塔特', 49.8055700, 8.6030700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32995, 'Pfullingen', 'Pfullingen', 'Pfulingen,Pfullingen,fwlyngn,pu fu lin gen,Пфулинген,Пфуллинген,Пфулінґен,فولینگن,普富林根', 48.4645800, 9.2279600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32996, 'Pfullendorf', 'Pfullendorf', 'Pfulendorf,Pfullendorf,fwlndwrf,pu fu lun duo er fu,pullendoleupeu,Пфулендорф,Пфуллендорф,فولندورف,ፉለንዶርፍ,普富伦多尔夫,풀렌도르프', 47.9261000, 9.2578000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32997, 'Pfronten', 'Pfronten', 'Pfronten,pu fu long teng,pufuronten,Пфронтен,Պֆրոնտեն,プフロンテン,普夫龙滕', 47.5822000, 10.5496200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32998, 'Pfronstetten', 'Pfronstetten', 'Pfronshteten,Pfronshtetten,pu fu long si te teng,Пфронштетен,Пфронштеттен,普夫龙斯特滕', 48.2764100, 9.3599500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(32999, 'Pfreimd', 'Pfreimd', 'Pfrajmd,Pfreimd,Pfrimbt,fraymd,pu fu lai mu de,Пфраймд,Пфрајмд,فرایمد,普夫赖姆德', 49.4911400, 12.1806900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33000, 'Pforzheim', 'Pforzheim', 'Gorad Pforckhajm,Pforcheimas,Pforckhajm,Pfortschaim,Pforzheim,Phorca,bfwrtshaym,fwrtshaym,poleucheuhaim,pu fu er ci hai mu,puforutsuhaimu,Πφόρτσχαϊμ,Горад Пфорцхайм,Пфорцхайм,Пфорцхајм,بفورتسهايم,فورتسهایم,فورزہائم,პფორცჰაიმი,プフォルツハイム,普福尔茨海姆,포르츠하임', 48.8843600, 8.6989200, 'DE', '2014-01-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33001, 'Pforzen', 'Pforzen', '', 47.9299700, 10.6135700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33002, 'Pfofeld', 'Pfofeld', 'Pfofel''d,Pfofeld,pu fu fei er de,Пфофелд,Пфофельд,Պֆոֆելդ,普福费尔德', 49.1059000, 10.8366400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33003, 'Pfiffelbach', 'Pfiffelbach', '', 51.0609800, 11.4421700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33004, 'Pferdingsleben', 'Pferdingsleben', 'Pferdingsleben', 50.9666700, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33005, 'Pfeffenhausen', 'Pfeffenhausen', 'Pfaffenhausen,Pfefenhauzen,Pfefenkhauzen,Pfeffengauzen,Pfeffenhausen,Pfeffenkhauzen,ffnhawzn,pu fei fen hao sen,Пфефенхаузен,Пфеффенгаузен,Пфеффенхаузен,Պֆեֆենհաուզեն,ففنهاوزن,普费芬豪森', 48.6646600, 11.9659400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33006, 'Pfeffelbach', 'Pfeffelbach', 'Pfefelbakh,Pfeffel''bakh,pu fei fei er ba he,Пфефелбах,Пфеффельбах,普费费尔巴赫', 49.5394800, 7.3276800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33007, 'Pfedelbach', 'Pfedelbach', 'Pfedel''bakh,Pfedelbach,Pfedelbakh,pu fei de er ba he,pufederubahha,Пфеделбах,Пфедельбах,プフェーデルバッハ,普费德尔巴赫', 49.1780600, 9.5050000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33008, 'Pfatter', 'Pfatter', 'Pfater,Pfatter,Pfeter,fatr,pu fa te er,Пфатер,Пфаттер,Պֆաթեր,فاتر,普法特尔', 48.9630900, 12.3825400, 'DE', '2012-08-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33009, 'Pfarrweisach', 'Pfarrweisach', 'Pfarrvajzakh,Pfarvajsakh,Pfarvajzakh,Pfarvayzax,pu fa er wei sa,Пфарвайзах,Пфарвајсах,Пфаррвайзах,Պֆարվայզախ,普法尔魏萨', 50.1500000, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33010, 'Pfarrkirchen', 'Pfarrkirchen', 'Pfarkirkhen,Pfarkirxen,Pfarrkirkhen,bfarkyrshn,farkyrshn,pu fa er ji er xing,Пфаркирхен,Пфарркірхен,Պֆարկիրխեն,بفاركيرشن,فارکیرشن,普法尔基尔兴', 48.4320500, 12.9381200, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33011, 'Pfalzgrafenweiler', 'Pfalzgrafenweiler', 'Pfal''cgrafenvajler,Pfalcgrafenvajler,pu fa er ci ge la fen wei lei,Пфалцграфенвајлер,Пфальцграфенвайлер,Պֆալցգրաֆենվայլեր,普法尔茨格拉芬韦勒', 48.5265000, 8.5658200, 'DE', '2013-02-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33012, 'Pfalzfeld', 'Pfalzfeld', 'Pfal''cfel''d,Pfalcfeld,pu fa er ci fei er de,Пфалцфелд,Пфальцфельд,普法尔茨费尔德', 50.1123200, 7.5785500, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33013, 'Pfakofen', 'Pfakofen', '', 48.8582200, 12.2274400, 'DE', '2012-08-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33014, 'Pfaffschwende', 'Pfaffschwende', 'Pfaffschwende', 51.2500000, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33015, 'Pfaffroda', 'Pfaffroda', '', 50.8613400, 12.5149700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33016, 'Pfaffroda', 'Pfaffroda', 'Pfafroda,pu fa fu luo da,Пфафрода,普法夫罗达', 50.7000000, 13.3500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33017, 'Pfaffing', 'Pfaffing', '', 48.0545600, 12.1091700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33018, 'Pfaffenweiler', 'Pfaffenweiler', 'Pfafenvajler,Pfafenvayler,Pfaffenvajler,Pfaffenweiler,pu fa fen wei lei,Пфафенвајлер,Пфаффенвайлер,Պֆաֆենվայլեր,普法芬韦勒', 47.9333300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33019, 'Pfaffen-Schwabenheim', 'Pfaffen-Schwabenheim', 'Pfafen-Shvabenkhajm,Pfaffen-Shvabenkhajm,pu fa fen-shi wa ben hai mu,Пфафен-Швабенхайм,Пфафен-Швабенхајм,Пфаффен-Швабенхайм,普法芬-施瓦本海姆', 49.8500000, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33020, 'Pfaffenhofen an der Roth', 'Pfaffenhofen an der Roth', 'Pfafenkhofen an der Rot,Pfaffengofen-an-der-Rot,Pfaffenhofen,Pfaffenhofen an der Roth,Pfaffenkhofen-an-der-Rot,Пфафенхофен ан дер Рот,Пфаффенгофен-ан-дер-Рот,Пфаффенхофен-ан-дер-Рот,Ռոթի Պֆաֆենհոֆեն', 48.3545400, 10.1618400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33021, 'Pfaffenhofen an der Ilm', 'Pfaffenhofen an der Ilm', 'Ilmei Pfafenxofen,Pfafenkhofen,Pfafenkhofen an der Ilm,Pfaffengofen-an-der-Il''m,Pfaffenhofen an der Ilm,Pfaffenkhofen-an-der-Il''m,Pfaffenkhofen-na-Il''me,Pfahofa,bfafnhwfn an dr alm,fafnhwfn an dr aylm,Пфафенхофен,Пфафенхофен ан дер Илм,Пфаффенгофен-ан-дер-Ільм,Пфаффенхофен-ан-дер-Ильм,Пфаффенхофен-на-Ильме,Իլմեի Պֆաֆենխոֆեն,بفافنهوفن أن در إلم,فافنهوفن آن در ایلم', 48.5305300, 11.5050000, 'DE', '2013-03-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33022, 'Pfaffenhofen', 'Pfaffenhofen', 'Pfafenkhofen,Pfaffengofen,Pfaffenkhofen,pufaffenhofen,Пфафенхофен,Пфаффенгофен,Пфаффенхофен,プファッフェンホーフェン', 49.0644400, 8.9763900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33023, 'Pfaffenhofen', 'Pfaffenhofen', '', 48.3933400, 11.2056300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33024, 'Pfaffenhausen', 'Pfaffenhausen', 'Pfafenhauzen,Pfafenkhauzen,Pfaffengauzen,Pfaffenkhauzen,pu fa fen hao sen,Пфафенхаузен,Пфаффенгаузен,Пфаффенхаузен,Պֆաֆենհաուզեն,普法芬豪森', 48.1187800, 10.4550400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33025, 'Peuschen', 'Peuschen', '', 50.6589300, 11.6448200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33026, 'Pettstadt', 'Pettstadt', 'Petshtadt,Petshtat,Petstadt,Pettshtadt,pei ci ta te,pettoshutatto,Петтштадт,Петштадт,Петштат,Պետշտադտ,ペットシュタット,佩茨塔特', 49.8299600, 10.9283900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33027, 'Petting', 'Petting', 'Petting', 47.9123200, 12.8151200, 'DE', '2012-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33028, 'Pettendorf', 'Pettendorf', 'Petendorf,Pettendorf', 49.3547500, 12.3592600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33029, 'Pettendorf', 'Pettendorf', 'Petendorf,Pettendorf,pei teng duo fu,ptndwrf,Петендорф,Петтендорф,Պեթենդորֆ,پتندورف,佩滕多夫', 49.0606500, 12.0078000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33030, 'Petriroda', 'Petriroda', 'Petriroda', 50.8666700, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33031, 'Peterslahr', 'Peterslahr', '', 50.6166700, 7.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33032, 'Petershausen', 'Petershausen', 'Bedashausn,Petersgauzen,Petershauzen,Peterskhauzen,pei te er si hao sen,ptrshawzn,Петерсгаузен,Петерсхаузен,Պետերսհաուզեն,پترسهاوزن,佩特尔斯豪森', 48.4096700, 11.4705600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33033, 'Petershagen', 'Petershagen', '', 52.5207800, 13.7874800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33034, 'Petershagen', 'Petershagen', 'Petersgagen,Petershagen,Peterskhagen,btrshaghn,pei te er si ha gen,petasuhagen,ptrshagn,Петерсгаген,Петерсхаген,بترسهاغن,پترسهاگن,ペータースハーゲン,佩特尔斯哈根', 52.3751300, 8.9653800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33035, 'Petersdorf', 'Petersdorf', '', 48.5166700, 11.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33036, 'Petersberg', 'Petersberg', '', 51.5965100, 11.9533000, 'DE', '2013-10-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33037, 'Petersberg', 'Petersberg', '', 50.9833300, 11.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33038, 'Petersberg', 'Petersberg', '', 50.5618700, 9.7131200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33039, 'Petersberg', 'Petersberg', '', 49.2333300, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33040, 'Petersaurach', 'Petersaurach', 'Petersaurach,Petersaurakh,Peterzaurakh,Peterzaurax,pei te er shao la,petasuauraha,Петерзаурах,Петерсаурах,Պետերզաուրախ,ペータースアウラハ,佩特尔绍拉', 49.3000000, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33041, 'Pessin', 'Pessin', 'Pesin,Pessin,pei xin,Песин,Пессин,Պեսսին,佩辛', 52.6424400, 12.6668100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33042, 'Perscheid', 'Perscheid', '', 50.0666700, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33043, 'Perlesreut', 'Perlesreut', 'Berlasreut,Perlesreut,Perlesrojt,pei er lai si luo yi te,prlsrwyt,Перлесройт,Перлесројт,Պերլեսրոյթ,پرلسرویت,佩尔莱斯罗伊特', 48.7818100, 13.4384000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33044, 'Perleberg', 'Perleberg', 'Perlberg,Perleberg,brlhbrgh,pei er lai bei ge,peleullebeleukeu,prlbrg,Перлеберг,برلهبرغ,پرلبرگ,佩尔莱贝格,페를레베르크', 53.0758300, 11.8573900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33045, 'Perl', 'Perl', '', 49.4716900, 6.3813400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33046, 'Perkam', 'Perkam', '', 48.8552800, 12.4397900, 'DE', '2012-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33047, 'Perasdorf', 'Perasdorf', '', 48.9500000, 12.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33048, 'Perach', 'Perach', '', 48.2666700, 12.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33049, 'Penzlin', 'Penzlin', 'Penclin,Pencline,Penclīne,Penzlin,bntslyn,peng ci lin,pntslyn,Пенцлин,بنتسلين,پنتسلین,彭茨林', 53.5040000, 13.0840700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33050, 'Penzing', 'Penzing', '', 48.0748100, 10.9274500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33051, 'Penzberg', 'Penzberg', 'Benschberg,Pencberg,Penzberg,bntzbrgh,peng ci bei ge,pentsuberuku,pntzbrg,Пенцберг,Պենցբերգ,بنتزبرغ,پنتزبرگ,ペンツベルク,彭茨贝格', 47.7529300, 11.3770000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33052, 'Pentling', 'Pentling', 'Pentling,peng te ling,pntlyng,Пентлинг,Пентлінг,Պենթլինգ,پنتلینگ,彭特灵', 48.9834300, 12.0587000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33053, 'Pennigsehl', 'Pennigsehl', '', 52.6418100, 9.0263000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33054, 'Pennewitz', 'Pennewitz', 'Penevic,Pennevic,Pennewitz,pei nei wei ci,Пеневиц,Пенневиц,佩内维茨', 50.6592400, 11.0538200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33055, 'Penkun', 'Penkun', 'Penkun,Penkuna,Pienkun,Piéńkùń,bnkwn,peng kun,pnkwn,Пенкун,بنكون,پنکون,彭昆', 53.2969500, 14.2361600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33056, 'Penig', 'Penig', 'Penig,Peniga,Pēniga,bynygh,pei ni xi,pnyg,Пениг,بينيغ,پنیگ,佩尼西', 50.9333600, 12.7042200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33057, 'Pemfling', 'Pemfling', 'Pemfling,pei mu fu ling,Пемфлинг,Пемфлінг,Պեմֆլինգ,佩姆夫灵', 49.2666700, 12.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33058, 'Pelm', 'Pelm', 'Pel''m,Pelm,pei er mu,Пелм,Пельм,佩尔姆', 50.2318800, 6.6907600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33059, 'Pellworm', 'Pellworm', 'Paelweerm,Pel''vorm,Pelvorm,Pelwerem,Pälweerm,pei er wo er mu,Пелворм,Пельворм,პელვორმი,佩尔沃尔姆', 54.5161000, 8.6451200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33060, 'Pellingen', 'Pellingen', '', 49.6755200, 6.6708500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33061, 'Peitz', 'Peitz', 'Pajc,Peitz/Picnjo,Picnjo,bayts,pai ci,payts,Пайц,Пајц,Պայց,بايتس,پایتس,派茨', 51.8584100, 14.4113800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33062, 'Peiting', 'Peiting', 'Pajting,Payting,Peiting,pai ting ge,paitingu,paytyng,Пайтинг,Пайтінг,Пајтинг,Պայտինգ,پایتینگ,パイティング,派廷格', 47.7954900, 10.9295100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33063, 'Peißenberg', 'Peissenberg', 'Pajsenberg,Pajssenberg,Paysenberg,Peissenberg,Peißenberg,pai sen bei ge,paisenberuku,paysnbrg,Пайсенберг,Пайссенберг,Пајсенберг,Պայսենբերգ,پایسنبرگ,パイセンベルク,派森贝格', 47.8046600, 11.0699000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33064, 'Peissen', 'Peissen', 'Peissen', 54.0261200, 9.6082500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33065, 'Peißen', 'Peissen', 'Peissen,Peißen', 51.7434700, 11.7575600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33066, 'Peißen', 'Peissen', '', 51.5026500, 12.0573700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33067, 'Peine', 'Peine', 'Paane,Pajne,Peine,ZPG,baynh,pai nei,paynh,Пайне,Пајне,باينه,پاینه,派内', 52.3192800, 10.2352000, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33068, 'Pegnitz', 'Pegnitz', 'Pegnic,Pegnitz,pegunittsu,pei ge ni ci,pgnyts,Пегниц,پگنیتس,ペグニッツ,佩格尼茨', 49.7521600, 11.5418700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33069, 'Pegestorf', 'Pegestorf', '', 51.9277500, 9.4968200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33070, 'Pegau', 'Pegau', 'Pegau,Pegava,Pēgava,bghaw,pei gao,pgaw,Пегау,بغاو,پگاو,佩高', 51.1671500, 12.2514400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33071, 'Peffingen', 'Peffingen', '', 49.9000000, 6.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33072, 'Pechbrunn', 'Pechbrunn', 'Pekhbrun,Pekhbrunn,pei xi bu lun,Пехбрун,Пехбрунн,Փեխբրուն,佩希布伦', 49.9666700, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33073, 'Päwesin', 'Pawesin', 'Pevezin,pei wei xin,Певезин,Պևեզին,佩韦辛', 52.5166700, 12.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33074, 'Pausa', 'Pausa', 'Pausa,Pausa/Vogtland', 50.5817200, 11.9973200, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33075, 'Paunzhausen', 'Paunzhausen', '', 48.4748600, 11.5646300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33076, 'Paulinenaue', 'Paulinenaue', 'Paulinenaue,Paulinenaueh,bao li nei nao ai,Паулиненауе,Паулиненауэ,Պաուլինենաուե,保利内瑙埃', 52.6770100, 12.7106700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33077, 'Pattensen', 'Pattensen', 'Patenzen,Pattenzen,Pattjehiusen,batnzn,pa teng sen,patnzn,Патензен,Паттензен,باتنزن,پاتنزن,帕滕森', 52.2644800, 9.7643600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33078, 'Patersdorf', 'Patersdorf', 'Patersdorf,pa te er si duo fu,patrsdwrf,Патерсдорф,Փաթերսդորֆ,پاترسدورف,帕特尔斯多夫', 49.0166700, 12.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33079, 'Patersberg', 'Patersberg', '', 50.1500000, 7.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33080, 'Pastetten', 'Pastetten', 'Pashteten,Pashtetten,pa si te teng,pasttn,Паштетен,Паштеттен,پاستتن,帕斯特滕', 48.1991100, 11.9436800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33081, 'Passow', 'Passow', 'Pasov,Passov,pa suo,Пасов,Пассов,Պասով,帕索', 53.1428600, 14.1141700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33082, 'Passau', 'Passau', 'Bassa,Batavia Bavariae,Båssa,Gorad Pasau,Pasau,Pasavia,Pasawa,Pasov,Passaou,Passau,Passavia,ZPF,pa shao,pasau,pasaw,passau,phas sea,psaw,Πάσσαου,Горад Пасау,Пасау,Пассау,پاساو,پساؤ,พาสเซา,パッサウ,帕绍,파사우', 48.5665000, 13.4312200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33083, 'Passade', 'Passade', 'Passade', 54.3666700, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33084, 'Paska', 'Paska', '', 50.6198500, 11.6290300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33085, 'Pasing', 'Pasing', '', 48.1414600, 11.4559900, 'DE', '2017-07-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33086, 'Pasewalk', 'Pasewalk', 'Pazeval''k,Pazevalk,Pazevalka,Pozdzewolk,Pòzdzewôłk,Pāzevalka,ZSK,bazhfalk,pa sai wa er ke,pazwak,Пазевалк,Пазевальк,بازهفالك,پازواک,帕塞瓦尔克', 53.5062700, 13.9899700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33087, 'Paschel', 'Paschel', '', 49.6333300, 6.6833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33088, 'Partenstein', 'Partenstein', 'Partenshtajn,Partenstein,pa er teng si tai yin,Партенштайн,Партенштајн,Պարտենշթայն,帕尔滕斯泰因', 50.0417600, 9.5199100, 'DE', '2013-02-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33089, 'Partenheim', 'Partenheim', '', 49.8838900, 8.0822200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33090, 'Parsberg', 'Parsberg', 'Parsberg,barsbrgh,pa er si bei ge,parsbrg,Парсберг,Փարսբերգ,بارسبرغ,پارسبرگ,帕尔斯贝格', 49.1607400, 11.7183400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33091, 'Parsau', 'Parsau', 'Parzau,pa er shao,Парзау,帕尔绍', 52.5347100, 10.8902000, 'DE', '2011-11-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33092, 'Parkstetten', 'Parkstetten', '', 48.9166700, 12.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33093, 'Parkstein', 'Parkstein', 'Parkstein', 49.7292100, 12.0675500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33094, 'Parchim', 'Parchim', 'Parchim,Parhima,Parkhim,SZW,barshym,pa er xi mu,parshym,prkym,Πάρχιμ,Пархим,פרכים,بارشيم,پارشیم,帕尔希姆', 53.4263100, 11.8487500, 'DE', '2016-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33095, 'Pappenheim', 'Pappenheim', 'Kleinschmalkalden,Pappenheim', 50.7963100, 10.4748900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33096, 'Pappenheim', 'Pappenheim', 'Papenkhajm,Pappengajm,Pappenham,Pappenkhajm,babnhaym,pa peng hai mu,Папенхајм,Паппенгайм,Паппенхайм,Պափենհայմ,بابنهايم,پاپن‌هایم,帕彭海姆', 48.9338300, 10.9743100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33097, 'Papendorf', 'Papendorf', 'Papendorf', 54.0352300, 12.1326300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33098, 'Papenburg', 'Papenburg', 'Papenbourg,Papenburg,Papenburgo,babnbwrgh,pa peng bao,papnbwrg,Папенбург,بابنبورغ,پاپنبورگ,帕彭堡', 53.0773800, 7.4044400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33099, 'Panzweiler', 'Panzweiler', '', 50.0166700, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33100, 'Pantenburg', 'Pantenburg', '', 50.0833300, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33101, 'Panten', 'Panten', 'Panten', 53.6666700, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33102, 'Panschwitz-Kuckau', 'Panschwitz-Kuckau', 'Pancicy-Kukow,Panschwitz-Kuckau,Panschwitz-Kuckau/Pancicy-Kukow,Panschwitz-Kuckau/Pančicy-Kukow,Panshvic-Kukau,Pančicy-Kukow,pan shi wei ci-ku kao,Паншвиц-Кукау,潘施维茨-库考', 51.2333300, 14.2000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33103, 'Pankow', 'Pankow', 'Berlin-Pankow,Pankov,Pankow,pankw,pnqw,Панков,פנקו,پانکو', 52.5692600, 13.4018600, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33104, 'Panker', 'Panker', 'Panker,pan ke er,Панкер,潘克尔', 54.3333300, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33105, 'Pampow', 'Pampow', '', 53.7551300, 12.6081500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33106, 'Palzem', 'Palzem', 'Pal''cem,Palcem,pa er ce mu,Палцем,Пальцем,帕尔策姆', 49.5666700, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33107, 'Palling', 'Palling', 'Paling,Palling,pa ling,palyng,Палинг,Паллинг,Паллінг,Փալինգ,پالینگ,帕灵', 48.0020400, 12.6370200, 'DE', '2012-09-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33108, 'Paitzdorf', 'Paitzdorf', '', 50.8500000, 12.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33109, 'Painten', 'Painten', 'Painten,Pajnten,pai yin teng,payntn,Пайнтен,Пајнтен,Պայնթեն,پاینتن,派因滕', 48.9973100, 11.8194700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33110, 'Pahlen', 'Pahlen', 'Pahlen', 54.2666700, 9.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33111, 'Pähl', 'Pahl', 'Paehl,Pel,Pel'',Pähl,peru,pl,Пел,Пель,Պել,پل,ペール', 47.9000000, 11.1833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33112, 'Padingbüttel', 'Padingbuettel', 'Padingbitel,Padingbjuttel'',Padingbueddel,Padingbüddel,pa ding bi te er,Падингбител,Падингбюттель,帕丁比特尔', 53.7000000, 8.5333300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33113, 'Paderborn', 'Paderborn', 'Gorad Padehrborn,PAD,Paderborn,Paderborna,Paderbornas,Paderbronna,Patterbuorn,Pāderborna,badrbwrn,pa de bo en,pa de xr bxrn,padaborun,padeoboleun,padrbwrn,Горад Падэрборн,Падерборн,بادربورن,پادربورن,پیڈربورن,ปาเดอร์บอร์น,პადერბორნი,パーダーボルン,帕德博恩,파더보른', 51.7190500, 8.7543900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33114, 'Padenstedt', 'Padenstedt', 'Padenstedt', 54.0500000, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33115, 'Oyten', 'Oyten', 'Eiten,Ojten,ao yi teng,oiten,Ойтен,Ојтен,オイテン,奥伊滕', 53.0500000, 9.0166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33116, 'Owschlag', 'Owschlag', 'Owschlag', 54.3933600, 9.5924300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33117, 'Owingen', 'Owingen', 'Ovingen,ao wen gen,ovingeni,Овинген,Овінген,Օվինգեն,ოვინგენი,奥温根', 47.8096700, 9.1717300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33118, 'Owen', 'Owen', 'Auen,Owen', 48.5874200, 9.4497800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33119, 'Oeversee', 'Oeversee', 'Eferze,Ehferzee,Ehverze,Everze,Oeversee,Oversee,Overso,Oversø,ao ai fei er sai,Översee,Еверзе,Еферзе,Эверзе,Эферзее,奥埃费尔塞', 54.7000000, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33120, 'Overath', 'Overath', 'Oferat,Overat,ao fei la te,awfrat,awfrras,Оверат,Оферат,أوفرات,اوفرراس,奥费拉特', 50.9327500, 7.2838900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33121, 'Oevenum', 'Oevenum', 'OEoewenem,Ovenum,Övenum,Ööwenem', 54.7102400, 8.5317400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33122, 'Ovelgönne', 'Ovelgonne', 'Ofel''gjonne,Ovel''gjonne,Ovelgene,ao fei er ge nei,Овелгене,Овельгённе,Офельгённе,奥费尔格内', 53.3418900, 8.4217900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33123, 'Utscheid', 'Utscheid', 'Outscheid,Utscheid', 50.0000000, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33124, 'Otzweiler', 'Otzweiler', 'Ocvajler,ao ci wei lei,Оцвайлер,Оцвајлер,奥茨韦勒', 49.7166700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33125, 'Ötzingen', 'Otzingen', '', 50.5000000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33126, 'Otzing', 'Otzing', 'Ocing,Otcing,ao qin ge,awtsyng,Отцинг,Оцинг,Օթցինգ,اوتسینگ,奥钦格', 48.7613400, 12.8087700, 'DE', '2012-11-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33127, 'Ottweiler', 'Ottweiler', 'Ottvajler,Otvailer,Otvajler,ao te wei lei,atwaylr,awtfaylr,ottovu~aira,Οτβάιλερ,Отвайлер,Отвајлер,Оттвайлер,أوتفايلر,اتوایلر,オットヴァイラー,奥特韦勒', 49.4013300, 7.1642400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33128, 'Ottrau', 'Ottrau', 'Otrau,Ottrau,ao te lao,ottorau,Отрау,Оттрау,オットラウ,奥特劳', 50.8059900, 9.3857500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33129, 'Ottobrunn', 'Ottobrunn', 'Otobrun,Ottobrunn,Ottomproun,ao tuo bu lun,awtwbrwn,Οττομπρούν,Отобрун,Оттобрунн,Օթոբրուն,اوتوبرون,奥托布伦', 48.0648900, 11.6632700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33130, 'Ottobeuren', 'Ottobeuren', 'Otobojren,Ottobeuren,Ottobojren,Ottobura,ao tuo bo yi lun,Отобојрен,Оттобойрен,Օթոբոյրեն,奥托博伊伦', 47.9413000, 10.2997100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33131, 'Otting', 'Otting', 'Oting,Otting,ao ting,ottingu,Отинг,Оттинг,Оттінг,Օթինգ,オッティング,奥廷', 48.8725000, 10.8001800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33132, 'Otterwisch', 'Otterwisch', '', 51.2000000, 12.6166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33133, 'Ottersweier', 'Ottersweier', 'Otersvajer,Ottersvaer,Ottersvajer,ao te er si wei ai er,Отерсвајер,Оттерсвайер,Оттерсваєр,奥特尔斯魏埃尔', 48.6702200, 8.1132300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33134, 'Otterstadt', 'Otterstadt', 'Oddaschdadt,Otershtat,Ottershtadt,ao te er si ta te,Отерштат,Оттерштадт,奥特尔斯塔特', 49.3722200, 8.4477800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33135, 'Ottersheim', 'Ottersheim', '', 49.6255600, 8.1086100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33136, 'Ottersheim', 'Ottersheim', '', 49.1912900, 8.2317600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33137, 'Ottersberg', 'Ottersberg', 'Gemeen Otterbarg,Otersberg,Ottersberg,ao te si bei ge,ottasuberuku,Отерсберг,Оттерсберг,オッタースベルク,奥特斯贝格', 53.1099000, 9.1440800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33138, 'Otterndorf', 'Otterndorf', 'Oterndoerp,Oterndorf,Oterndörp,Otterndorf,Vicus Lutrarum,ao te er en duo fu,atrndwrf,awtrndwrf,Отерндорф,Оттерндорф,أوترندورف,اترندورف,奥特尔恩多夫', 53.8090800, 8.9006800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33139, 'Otterfing', 'Otterfing', 'Oterfing,Otterfing,ao te er fen,awtrfyng,Отерфинг,Оттерфинг,Оттерфінг,Օթերֆինգ,اوترفینگ,奥特尔芬', 47.9089800, 11.6754600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33140, 'Otterberg', 'Otterberg', 'Oterberg,Otterberg,ao te bei ge,atrbwrg,awtrbrgh,ottaberuku,Отерберг,Оттерберг,أوتربرغ,اتربورگ,オッターベルク,奥特贝格', 49.5030100, 7.7699500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33141, 'Otterbach', 'Otterbach', '', 49.4855400, 7.7345000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33142, 'Otter', 'Otter', '', 53.2401500, 9.7424700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33143, 'Ottenstein', 'Ottenstein', 'Otenshtajn,Ottenshtajn,Ottenstein,ao teng si tai yin,ottenshutain,Отенштајн,Оттенштайн,オッテンシュタイン,奥滕斯泰因', 51.9470700, 9.4070000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33144, 'Ottensoos', 'Ottensoos', 'Otensos,Ottenzos,ao teng suo si,Отенсос,Оттензос,Օթենզոս,奥滕索斯', 49.5094900, 11.3415800, 'DE', '2014-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33145, 'Ottenhöfen im Schwarzwald', 'Ottenhofen im Schwarzwald', 'Otenkhefen im Shvarcvald,Ottengefen-im-Shvarcval''d,Ottenhoefen,Ottenhofen im Schwarzwald,Ottenhöfen,Ottenhöfen im Schwarzwald,Ottenkhjofen,hei lin shan qu ao teng he fen,Отенхефен им Шварцвалд,Оттенгефен-ім-Шварцвальд,Оттенхёфен,黑林山区奥滕赫芬', 48.5666700, 8.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33146, 'Ottenhofen', 'Ottenhofen', 'Otenkhofen,Ottengofen,Ottenhoefen im Schwarzwald,Ottenhöfen im Schwarzwald,Ottenkhofen,ao teng huo fen,awtnhwfn,Отенхофен,Оттенгофен,Оттенхофен,اوتنهوفن,奥滕霍芬', 48.2166700, 11.8833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33147, 'Ottenhofen', 'Ottenhofen', 'Ottenhoefen im Schwarzwald,Ottenhofen,Ottenhöfen im Schwarzwald', 48.7356000, 8.1298100, 'DE', '2015-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33148, 'Ottendorf-Okrilla', 'Ottendorf-Okrilla', 'Otendorf-Okrila,Ottendorf-Okrilla,Ottendorf-Okrilla vald,ao teng duo fu-ao ke li la,Отендорф-Окрила,Оттендорф-Окрилла,奥滕多夫-奥克里拉', 51.1833300, 13.8333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33149, 'Ottendorf', 'Ottendorf', '', 54.3408700, 10.0492600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33150, 'Ottendorf', 'Ottendorf', '', 50.8274800, 11.8250800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33151, 'Ottenbüttel', 'Ottenbuttel', 'Ottenbuettel,Ottenbuttel,Ottenbüttel', 53.9710700, 9.5041600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33152, 'Ottenbach', 'Ottenbach', '', 48.7364900, 9.7484400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33153, 'Ötisheim', 'Otisheim', 'Ehtiskhajm,Etisgajm,Etishaym,Etiskhajm,OEtisheim,e di si hai mu,Ötisheim,Етисхајм,Етісгайм,Этисхайм,Էտիսհայմ,厄蒂斯海姆', 48.9666700, 8.8000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33154, 'Ötigheim', 'Otigheim', 'Ehtigkhajm,Etigajm,Etigkhajm,OEtigheim,e di ge hai mu,Ötigheim,Етигхајм,Етігайм,Этигхайм,厄蒂格海姆', 48.8908500, 8.2344200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33155, 'Oststeinbek', 'Oststeinbek', 'Ostshtajnbek,Oststeinbek,ao si ci tai yin bei ke,Остштайнбек,Остштајнбек,奥斯茨泰因贝克', 53.5432100, 10.1693900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33156, 'Ostseebad Sellin', 'Ostseebad Sellin', 'Sellin,Zellin,Зеллин', 54.3784600, 13.6939400, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33157, 'Ostseebad Prerow', 'Ostseebad Prerow', 'Ostseebad Prerow am Darss,Ostseebad Prerow am Darß,Prerow', 54.4446900, 12.5767700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33158, 'Ostseebad Kühlungsborn', 'Ostseebad Kuehlungsborn', 'Arendsee,Kuehlungsborn,Kuhlungsborn,Kühlungsborn,Ostseebad Kuehlungsborn,Ostseebad Kuhlungsborn,Ostseebad Kühlungsborn', 54.1503500, 11.7599400, 'DE', '2016-05-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33159, 'Seeheilbad Graal-Müritz', 'Seeheilbad Graal-Mueritz', 'Graal-Muritz,Graal-Müritz,Ostseebad Graal-Muritz,Ostseebad Graal-Müritz', 54.2512400, 12.2513900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33160, 'Ostseebad Göhren', 'Ostseebad Goehren', 'Gohren,Göhren', 54.3414000, 13.7382300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33161, 'Ostseebad Dierhagen', 'Ostseebad Dierhagen', 'Dierhagen', 54.2924300, 12.3579900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33162, 'Ostseebad Boltenhagen', 'Ostseebad Boltenhagen', 'Boltenhagen', 53.9877900, 11.2019300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33163, 'Ostseebad Binz', 'Ostseebad Binz', 'Binc,Binz,Бинц', 54.3999500, 13.6105200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33164, 'Ostrohe', 'Ostrohe', 'Ostrohe', 54.2163100, 9.1253700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33165, 'Ostritz', 'Ostritz', 'Ostric,Ostrica,Wostrowc,astrytz,awztryts,Остриц,أوزتريتس,استریتز', 51.0145100, 14.9305900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33166, 'Östringen', 'Ostringen', 'Ehstringen,Estringen,OEstringen,Ostringen,awstrynghn,awstryngn,e si te lin gen,Östringen,Естринген,Естрінген,Эстринген,أوسترينغن,اوسترینگن,厄斯特林根', 49.2191100, 8.7119200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33167, 'Ostrhauderfehn', 'Ostrhauderfehn', 'Aastrauderfeen,Ostrauderfen,ao si te lao de er fei en,Остраудерфен,奥斯特劳德尔费恩', 53.1333300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33168, 'Ostrau', 'Ostrau', '', 51.2000000, 13.1666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33169, 'Ostrau', 'Ostrau', '', 51.2063900, 12.8842100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33170, 'Ostramondra', 'Ostramondra', '', 51.2000000, 11.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33171, 'Ostrach', 'Ostrach', 'Ostrach,Ostrakh,Острах', 47.9500000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33172, 'Ostochtersum', 'Ostochtersum', '', 53.6060500, 7.5264900, 'DE', '2011-03-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33173, 'Osthofen', 'Osthofen', 'Osthofen,Ostkhofen,ao si tuo fen,asthwfn,awsthwfn,osutohofen,Остхофен,أوستهوفن,استهوفن,オストホーフェン,奥斯托芬', 49.7038200, 8.3241900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33174, 'Ostheim vor der Rhön', 'Ostheim vor der Rhon', 'Ostajm-for-der-Rjon,Ostgajm,Ostheim,Ostheim v.d. Rhoen,Ostheim v.d. Rhön,Ostheim vor der Rhon,Ostheim vor der Rhön,Ostkhajm vor der Ren,Ostkhajm-for-der-Rjon,asthaym,awsthaym,lun shan qian ao si te hai mu,Остайм-фор-дер-Рён,Остгайм,Остхайм-фор-дер-Рён,Остхајм вор дер Рен,Ռյոնի Օսթհայմ,أوستهايم,استهایم,伦山前奥斯特海姆', 50.4599600, 10.2305700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33175, 'Ostheim', 'Ostheim', '', 50.9311700, 7.0441200, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33176, 'Osterzell', 'Osterzell', '', 47.8833300, 10.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33177, 'Osterwieck', 'Osterwieck', 'Ostervik,Osterwieck,ao si te er wei ke,awstrfyk,awytrwyk,Όστερβικ,Остервик,أوسترفيك,اویترویک,奥斯特尔维克', 51.9699000, 10.7104200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33178, 'Osterstedt', 'Osterstedt', 'Osterstedt', 54.1082500, 9.5743600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33179, 'Osterspai', 'Osterspai', 'Osterspai,Osterspaj,ao si te er si pai,Остерспай,Остерспај,奥斯特尔斯派', 50.2445300, 7.6122700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33180, 'Osterrönfeld', 'Osterronfeld', 'Osterenfeld,Osterrjonfel''d,Osterroenfeld,Osterronfeld,Osterrönfeld,ao si te lun fei er de,Остеренфелд,Остеррёнфельд,奥斯特伦费尔德', 54.2901300, 9.6990000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33181, 'Osterrade', 'Osterrade', '', 54.2000000, 9.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33182, 'Oster-Ohrstedt', 'Oster-Ohrstedt', 'Oster-Ohrstedt', 54.5151400, 9.2218900, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33183, 'Osterode am Harz', 'Osterode am Harz', 'Osteroda ad Harthicos montes,Osterode,Osterode am Harz,Osterode am Kharc,Osterode-am-Kharc,Ostroe,Stadt Osterode am Harz,awstrwdt am harts,awytrwdh am harts,ha ci shan lu ao si te luo de,Остероде,Остероде ам Харц,Остероде-ам-Харц,أوسترودة آم هارتس,اویتروده آم هارتس,哈茨山麓奥斯特罗德', 51.7268600, 10.2508900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33184, 'Osternienburg', 'Osternienburg', 'Osternienburg', 51.7938400, 12.0261600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33185, 'Osterhorn', 'Osterhorn', 'Osterhorn', 53.8666700, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33186, 'Osterholz-Scharmbeck', 'Osterholz-Scharmbeck', 'Oosterholt-Scharmbeek,Osterholz-Scharmbeck,Osterkhol''c-Sharmbek,Osterkholc-Sharmbek,Stadt Osterholz-Scharmbeck,ao si te luo er ci-sha er en bei ke,astrhwlz-sharmbrk,awstrhwlts-sharmbk,Остерхолц-Шармбек,Остерхольц-Шармбек,أوسترهولتس-شارمبك,استرهولز-شارمبرک,奥斯特罗尔茨-沙尔恩贝克', 53.2269800, 8.7952800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33187, 'Osterhofen', 'Osterhofen', 'Ostergofen,Osterhofen,Osterkhofen,ao si te luo fen,astrhwfn,awstrhwfn,Остергофен,Остерхофен,Օսթերհոֆեն,أوسترهوفن,استرهوفن,奥斯特罗芬', 48.7000000, 13.0222100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33188, 'Osterhever', 'Osterhever', 'Osterhever,Osterkhefer,Osterkhever,Uasterheewer,ao si te lei fei er,Østerhever,Остерхевер,Остерхефер,奥斯特雷费尔', 54.3854700, 8.7660000, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33189, 'Osterhausen', 'Osterhausen', 'Grossosterhausen,Großosterhausen,Osterhausen', 51.4541700, 11.5045600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33190, 'Osterfeld', 'Osterfeld', 'Osterfeld', 51.0801400, 11.9304700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33191, 'Ostereistedt', 'Ostereistedt', 'Oostereis,Osterajshtedt,Osterajshtet,ao si te lai si te,osutaaishutetto,Остерайштедт,Остерајштет,オスターアイシュテット,奥斯特赖斯特', 53.3000000, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33192, 'Oesterdeichstrich', 'Oesterdeichstrich', 'Oesterdeichstrich,Osterdeichstrich,Österdeichstrich', 54.1500000, 8.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33193, 'Ostercappeln', 'Ostercappeln', 'Ostercappeln,Osterkapeln,Osterkappel''n,ao si te er ka pei er en,Остеркапелн,Остеркаппельн,奥斯特尔卡佩尔恩', 52.3500000, 8.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33194, 'Osterby', 'Osterby', '', 54.8000000, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33195, 'Osterby', 'Osterby', '', 54.4500000, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33196, 'Osterburken', 'Osterburken', 'Osterburken,ao si te er bu er ken,astrbrwkn,awstrbwrkn,osutaburuken,Остербуркен,أوستربوركن,استربروکن,オスターブルケン,奥斯特尔布尔肯', 49.4299700, 9.4225200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33197, 'Osterburg', 'Osterburg', 'Osterburg,ao si te er bu er ge,astrbwrg,awstrbwrgh,Остербург,أوستربورغ,استربورگ,奥斯特尔布尔格', 52.7872100, 11.7529700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33198, 'Osterbruch', 'Osterbruch', '', 53.7780500, 8.9412200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33199, 'Osterberg', 'Osterberg', 'Osterberg,ao si te bei ge,Остерберг,Օսթերբերգ,奥斯特贝格', 48.1500000, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33200, 'Ostenfeld', 'Ostenfeld', '', 54.4640000, 9.2343000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33201, 'Osten', 'Osten', 'Osten', 53.7000000, 9.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33202, 'Ostelsheim', 'Ostelsheim', '', 48.7263300, 8.8481600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33203, 'Osteel', 'Osteel', 'Ostel,Ostel'',ao si te er,Остел,Остель,奥斯特尔', 53.5441700, 7.2540000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33204, 'Ostbevern', 'Ostbevern', 'Ostbefern,Ostbevern,Ostbiaerm,Ostbiärm,dong bei wo en,Остбеверн,Остбеферн,东贝沃恩', 52.0401800, 7.8422900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33205, 'Oßmanstedt', 'Ossmanstedt', 'Ossmannstedt,Ossmanstedt,Oßmannstedt,Oßmanstedt', 51.0181500, 11.4274600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33206, 'Oßling', 'Ossling', 'Osling,Ossling,Ossling/Woslink,Osslingi vald,Oßling/Wóslink,Oßlingi vald,Woslink,Wóslink,ao si ling,Ослинг,Осслинг,奥斯灵', 51.3599900, 14.1656700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33207, 'Osnabrück', 'Osnabrueck', 'Gorad Asnabruk,Osnabrik,Osnabrika,Osnabriukas,Osnabrjuk,Osnabruck,Osnabrueck,Osnabruga,Osnabrugensis,Osnabrück,Ossenbruegge,Ossenbrügge,ao si na bu lu ke,asnabrwk,awsnabrwk,oseunabeulwikeu,osunaburyukku,Горад Аснабрук,Оснабрик,Оснабрюк,אוסנבריק,أسنابروك,اسنابروک,اوسنابروک,ოსნაბრიუკი,オスナブリュック,奥斯纳布吕克,오스나브뤼크', 52.2726400, 8.0498000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33208, 'Osloß', 'Osloss', 'Osloss,Osloß', 52.4692500, 10.6801100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33209, 'Osdorf', 'Osdorf', '', 54.4333300, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33210, 'Oschersleben', 'Oschersleben', 'Oschersleben,Oscherslewwe,Oshersleben,Oskersleva,ao she er si lai ben,awksrzlbn,awshrslybn,oshasureben,Ошерслебен,أوشرسليبن,اوکسرزلبن,オシャースレーベン,奥舍尔斯莱本', 52.0303900, 11.2289800, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33211, 'Oeschebüttel', 'Oeschebuttel', 'Oeschebuttel,Oeschebüttel,Oschebuttel,Öschebüttel', 53.9891200, 9.7212800, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33212, 'Oschatz', 'Oschatz', 'Osaca,Oschatz,Oshac,Ossitium,Ošaca,Wosec,Woseč,ao sha ci,ashats,awshats,Ошац,أوشاتس,اشاتس,奥沙茨', 51.3000100, 13.1098400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33213, 'Osburg', 'Osburg', 'Osburg,ao si bao,Осбург,奥斯堡', 49.7166700, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33214, 'Ortrand', 'Ortrand', 'Ortrand,Wotran,Wótrań,ao er te lan de,artrand,awrtrand,Ортранд,Օրտրանդ,أورتراند,ارتراند,奥尔特兰德', 51.3750500, 13.7598200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33215, 'Ortenburg', 'Ortenburg', 'Ortenburg,Otnbuag,ao er teng bao,Ортенбург,Օրթենբուրգ,奥尔滕堡', 48.5459700, 13.2225000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33216, 'Ortenberg', 'Ortenberg', 'Ortenberg,Ortenburg', 50.3558400, 9.0560200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33217, 'Ortenberg', 'Ortenberg', '', 48.4515800, 7.9717800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33218, 'Orsingen-Nenzingen', 'Orsingen-Nenzingen', 'Nenzingen,Orsingen-Nencingen,Orzingen-Nencingen,ao er xin gen-nen qin gen,Орзинген-Ненцинген,Орзінген-Ненцинген,Орсинген-Ненцинген,奥尔辛根-嫩钦根', 47.8427200, 8.9590900, 'DE', '2017-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33219, 'Orsfeld', 'Orsfeld', '', 50.0333300, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33220, 'Oersdorf', 'Oersdorf', 'Oersdorf,Orsdorf,Örsdorf', 53.8391400, 9.9911200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33221, 'Orscholz', 'Orscholz', '', 49.5059300, 6.5250200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33222, 'Oersberg', 'Oersberg', 'Oersberg,Orsberg,Örsberg', 54.6666700, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33223, 'Ornbau', 'Ornbau', 'Ornbau,ao er en bao,arnbaw,awrnbaw,orunbau,Орнбау,Օրնբաու,أورنباو,ارنباو,オルンバウ,奥尔恩鲍', 49.1762300, 10.6579700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33224, 'Ormont', 'Ormont', 'Ormont,ao er meng te,Ормонт,奥尔蒙特', 50.3261700, 6.4423800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33225, 'Orlenbach', 'Orlenbach', '', 50.1666700, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33226, 'Oerlenbach', 'Oerlenbach', 'Ehrlenbakh,Erlenbakh,Erlenbax,Oerlenbach,Orlenbach,ao ai er lun ba he,Örlenbach,Ерленбах,Эрленбах,Էրլենբախ,奥埃尔伦巴赫', 50.1500000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33227, 'Orlamünde', 'Orlamuende', 'Orlamuende,Orlamunde,Orlamünde', 50.7748600, 11.5192900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33228, 'Orfgen', 'Orfgen', '', 50.6666700, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33229, 'Orenhofen', 'Orenhofen', '', 49.9000000, 6.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33230, 'Oerel', 'Oerel', 'Ehrel'',Erel,Oerel,Orel,e lei er,ereru,Örel,Ерел,Эрель,エレル,厄勒尔', 53.4833300, 9.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33231, 'Orbis', 'Orbis', '', 49.7000000, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33232, 'Oranienburg', 'Oranienburg', 'Arausionis castrum,Gorad Aranienburg,Oranienburg,Oraninburg,ao la ning bao,aranynbrg,awranynbwrgh,olanienbuleukeu,oranienburuku,Горад Араніенбург,Ораниенбург,Оранинбург,Оранієнбурґ,Օրանիենբուրգ,אורניינבורג,أورانينبورغ,ارانینبرگ,オラニエンブルク,奥拉宁堡,오라니엔부르크', 52.7557700, 13.2419700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33233, 'Oranienbaum', 'Oranienbaum', 'Oranienbaum', 51.7986000, 12.4058300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33234, 'Oppurg', 'Oppurg', 'Oppurg,Opurg,ao pu er ge,Оппург,Опург,奥普尔格', 50.7106500, 11.6528900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33235, 'Oppin', 'Oppin', 'Oppin', 51.5513600, 12.0327400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33236, 'Oppertshausen', 'Oppertshausen', '', 49.9500000, 7.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33237, 'Oppershausen', 'Oppershausen', '', 51.1333300, 10.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33238, 'Oppenweiler', 'Oppenweiler', 'Openvajler,Oppenvajler,ao peng wei lei,Опенвајлер,Оппенвайлер,奥彭韦勒', 48.9827000, 9.4585000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33239, 'Oppenheim', 'Oppenheim', 'Openkhajm,Oppengajm,Oppenheimium,Oppenkhajm,ao peng hai mu,awbnhaym,oppenhaimu,Опенхайм,Опенхајм,Оппенгайм,Оппенхайм,أوبنهايم,اپن‌هایم,オッペンハイム,奥彭海姆', 49.8547000, 8.3597400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33240, 'Oppenau', 'Oppenau', 'Openau,Oppenau,ao pei nao,apnaw,awbnaw,Опенау,Оппенау,أوبناو,اپناو,奥佩瑙', 48.4733200, 8.1597000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33241, 'Oppach', 'Oppach', 'Opakh,Oppach,Oppachi vald,Oppakh,Wopaka,ao pa,Опах,Оппах,奥帕', 51.0666700, 14.5000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33242, 'Opladen', 'Opladen', 'Opladen,Опладен', 51.0686300, 7.0038700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33243, 'Öpfingen', 'Opfingen', 'Ehpfingen,Epfingen,e pu fen gen,Епфинген,Епфінген,Эпфинген,Էպֆինգեն,ეპფინგენი,厄普芬根', 48.2863600, 9.8025900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33244, 'Opfenbach', 'Opfenbach', 'Opfenbakh,ao pu fen ba he,Опфенбах,Օփֆենբախ,奥普芬巴赫', 47.6333300, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33245, 'Onsdorf', 'Onsdorf', '', 49.6500000, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33246, 'Olzheim', 'Olzheim', '', 50.2723300, 6.4551100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33247, 'Ölsen', 'Olsen', '', 50.7333300, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33248, 'Olsdorf', 'Olsdorf', '', 49.9535400, 6.3822000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33249, 'Olsbrücken', 'Olsbruecken', '', 49.5388400, 7.6585700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33250, 'Olsberg', 'Olsberg', 'Ol''sberg,Olsberg,alsbrg  alman,ao er si bei ge,Олсберг,Ольсберг,السبرگ، آلمان,奥尔斯贝格', 51.3561300, 8.4889900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33251, 'Olpe', 'Olpe', 'Ol''pe,Olpe,alph  alman,Олпе,Ольпе,الپه، آلمان', 51.0289900, 7.8513900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33252, 'Olmscheid', 'Olmscheid', '', 50.0666700, 6.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33253, 'Ollmuth', 'Ollmuth', '', 49.6666700, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33254, 'Öllingen', 'Ollingen', '', 48.5286800, 10.1475900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33255, 'Ollendorf', 'Ollendorf', 'Olendorf,Ollendorf,ao lun duo fu,Олендорф,Оллендорф,奥伦多夫', 51.0333300, 11.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33256, 'Oelixdorf', 'Oelixdorf', 'Oelixdorf,Olixdorf,Ölixdorf', 53.9273800, 9.5638300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33257, 'Olfen', 'Olfen', 'Ol''fen,Olfen,alfn,ao er fen,Олфен,Ольфен,الفن,奥尔芬', 51.7078700, 7.3789300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33258, 'Oldisleben', 'Oldisleben', 'Ol''disleben,Oldisleben,ao er di si lai ben,Олдислебен,Ольдислебен,奥尔迪斯莱本', 51.3097500, 11.1711200, 'DE', '2013-04-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33259, 'Olderup', 'Olderup', 'Olderup', 54.5333300, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33260, 'Oldersbek', 'Oldersbek', 'Oldersbeck,Oldersbek', 54.4467900, 9.1692900, 'DE', '2012-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33261, 'Oldenswort', 'Oldenswort', 'Ol''densvort,Oldensvort,Oldenswort,ao er deng si wo te,Олденсворт,Ольденсворт,奥尔登斯沃特', 54.3724300, 8.9399600, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33262, 'Oldenhütten', 'Oldenhutten', 'Oldenhutten,Oldenhütten', 54.1500000, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33263, 'Oldendorf', 'Oldendorf', '', 53.9534100, 9.4585800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33264, 'Oldendorf', 'Oldendorf', '', 53.5833300, 9.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33265, 'Oldendorf', 'Oldendorf', '', 53.1558000, 10.2143100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33266, 'Oldenbüttel', 'Oldenbuttel', '', 54.1666700, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33267, 'Oldenburg in Holstein', 'Oldenburg in Holstein', 'Ol''denburg,Ol''denburg-in-Khol''shtajn,Oldemburgo,Oldenbourg en Holstein,Oldenburg,Oldenburg in Holstein,Oldenburg in Kholshtajn,Oldenburg vo Kholshtajn,Oldenburgum,awldnbwrgh an hwlshtayn,he er si tai yin de qu ao er deng bao,Олденбург во Холштајн,Олденбург ин Холштајн,Ольденбург,Ольденбург-ин-Хольштайн,أولدنبورغ إن هولشتاين,اولدنبورگ این هل‌اشتاین,荷尔斯泰因地区奥尔登堡', 54.2957600, 10.9015600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33268, 'Oldenburg', 'Oldenburg', 'Aldenboarch,Aldinborg,Byen Oldenburg,Gorad Ol''dehnburg,Ol''denburg,Oldemburgh,Oldemburgo,Oldenboerj,Oldenbourg,Oldenburg,Oldenburgas,Oldenburgo,Oldenburgum,Oldenbörj,Ollnborg,Ooldenbuurich,ao er deng bao,awldnbwrg,awldnbwrgh,oldenbuleukeu,oldenburgi,orudenburuku,Горад Ольдэнбург,Олденбург,Ольденбург,Өльдэнбург,אולדנבורג,أولدنبورغ,اولدنبورگ,اولڈنبرگ,ოლდენბურგი,オルデンブルク,奥尔登堡,올덴부르크', 53.1411800, 8.2146700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33269, 'Oldenborstel', 'Oldenborstel', 'Oldenborstel', 54.0666700, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33270, 'Olching', 'Olching', 'Oiching,Ol''khing,Olkhing,Olxing,ao er xing,awlshyng,Олхинг,Ольхинг,Ольхінг,Օլխինգ,اولشینگ,奥尔兴', 48.2000000, 11.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33271, 'Olbersleben', 'Olbersleben', '', 51.1500000, 11.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33272, 'Olbersdorf', 'Olbersdorf', 'Ol''bersdorf,Olbersdorf,Olbersdorfi vald,ao er bei er si duo fu,Олберсдорф,Ольберсдорф,奥尔贝尔斯多夫', 50.8730400, 14.7703500, 'DE', '2015-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33273, 'Olbernhau', 'Olbernhau', 'Ol''bernkhau,Olbernhau,Olbernhava,Olbernkhau,alwbrnhaw,ao er bei er en hao,awlbrnhaw,Олбернхау,Ольбернхау,أولبرنهاو,الوبرنهاو,奥尔贝尔恩豪', 50.6587000, 13.3425000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33274, 'Ohrum', 'Ohrum', 'Orum,ao lu mu,Орум,奥鲁姆', 52.1208400, 10.5628400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33275, 'Öhringen', 'Ohringen', 'Ehringen,Eringen,OEhringen,Ohringen,awrynghyn,awryngyn,e he lin gen,eringen,Öhringen,Еринген,Ерінген,Эринген,أورينغين,اورینگین,エーリンゲン,厄赫林根', 49.1988400, 9.5072000, 'DE', '2017-02-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33276, 'Ohrenbach', 'Ohrenbach', 'Orenbakh,Orenbax,ao lun ba he,orenbahha,Оренбах,Օրենբախ,オーレンバッハ,奥伦巴赫', 49.4705500, 10.2100800, 'DE', '2016-02-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33277, 'Ohorn', 'Ohorn', 'Okhorn,ao huo er en,Охорн,奥霍尔恩', 51.1719900, 14.0466900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33278, 'Öhningen', 'Ohningen', 'Ehningen,Eningen,OEhningen,Ohningen,e he ning gen,Öhningen,Енинген,Енінген,Энинген,Էնինգեն,厄赫宁根', 47.6618600, 8.8867400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33279, 'Ohne', 'Ohne', '', 52.2666700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33280, 'Ohmden', 'Ohmden', 'Omden,ao mu deng,Омден,Օմդեն,奥姆登', 48.6459900, 9.5269800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33281, 'Ohmbach', 'Ohmbach', 'Ombakh,ao en ba he,Омбах,奥恩巴赫', 49.4500000, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33282, 'Ohlweiler', 'Ohlweiler', '', 49.9666700, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33283, 'Ohlstadt', 'Ohlstadt', 'Ol''shtadt,Olshtat,Olstad,ao er si ta te,awlshtat,Олштат,Ольштадт,Օլշտադ,اولشتات,奥尔斯塔特', 47.6333300, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33284, 'Ohlsdorf', 'Ohlsdorf', 'Ohlsdoerp,Ohlsdorf,Ohlsdörp', 53.6259400, 10.0314500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33285, 'Ohlsbach', 'Ohlsbach', 'Ol''sbakh,Olsbakh,ao er si ba he,Олсбах,Ольсбах,奥尔斯巴赫', 48.4322200, 7.9938400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33286, 'Ohlenhard', 'Ohlenhard', '', 50.4500000, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33287, 'Oggelshausen', 'Oggelshausen', '', 48.0666700, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33288, 'Oftersheim', 'Oftersheim', 'Oftersgajm,Ofterskhajm,ao fu te er si hai mu,ofutasuhaimu,Офтерсгайм,Офтерсхайм,Офтерсхајм,オフタースハイム,奥夫特尔斯海姆', 49.3652800, 8.5830600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33289, 'Ofterschwang', 'Ofterschwang', 'Oftershvang,Oftersvang,ao fu te er shi wang,Офтершванг,Օֆտերշվանգ,奥夫特尔施旺', 47.5000000, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33290, 'Ofterdingen', 'Ofterdingen', 'Ofterdingen,ao fu te er ding gen,Офтердинген,Офтердінген,奥夫特尔丁根', 48.4166700, 9.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33291, 'Offstein', 'Offstein', 'Ofshtajn,ao fu si tai yin,Офштайн,Офштајн,奥夫斯泰因', 49.6061100, 8.2380600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33292, 'Offingen', 'Offingen', 'Offingen,Ofingen,ao fen gen,Офинген,Оффинген,Оффінген,Օֆինգեն,奥芬根', 48.4825800, 10.3624900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33293, 'Offenheim', 'Offenheim', '', 49.7255600, 8.0302800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33294, 'Offenhausen', 'Offenhausen', '', 49.4497100, 11.4131600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33295, 'Offenbüttel', 'Offenbuettel', 'Offenbuttel,Offenbüttel', 54.1703500, 9.3550000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33296, 'Offenburg', 'Offenburg', 'Ofenburg,Offenbourg,Offenburg,Offenburgum,ZPA,ao fen bao,awfnbwrg,awfnbwrgh,offenburuku,Офенбург,Оффенбург,אופנבורג,أوفنبورغ,اوفنبورگ,オッフェンブルク,奥芬堡', 48.4737700, 7.9449500, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33297, 'Offenberg', 'Offenberg', 'Ofenberg,Offenberg,ao fen bei ge,awfnbrg,Офенберг,Оффенберг,Օֆենբերգ,اوفنبرگ,奥芬贝格', 48.8619500, 12.8629300, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33298, 'Offenbach an der Queich', 'Offenbach an der Queich', 'Ofenbakh an der Kvajkh,Offenbach,Offenbach an der Queich,Offenbakh-an-der-Kvajkh,ku ai xi he pan ao fen ba he,Офенбах ан дер Квајх,Оффенбах-ан-дер-Квайх,オッフェンバッハ・アン・デア・クヴァイヒ,库艾希河畔奥芬巴赫', 49.1954600, 8.1977900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33299, 'Offenbach', 'Offenbach', 'Offenbach,Offenbach am Main', 50.1006100, 8.7664700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33300, 'Offenau', 'Offenau', 'Ofenau,Offenau,ao fei nao,offenau,Офенау,Оффенау,オッフェナウ,奥费瑙', 49.2458300, 9.1605600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33301, 'Oetzen', 'Oetzen', '', 53.0191700, 10.6757100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33302, 'Oettingen in Bayern', 'Oettingen in Bayern', 'Ehttingen-in-Bajern,Etingen in Bauern,Ettingen-in-Baern,Oettingen,Oettingen in Bavariya,Oettingen in Bayern,atyngn,awtynghn an bayrn,e ting gen,Етинген ин Бауерн,Еттінген-ін-Баєрн,Эттинген-ин-Байерн,Էթինգեն,أوتينغن إن بايرن,اتینگن,エッティンゲン・イン・バイエルン,厄廷根', 48.9527400, 10.6046500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33303, 'Oettersdorf', 'Oettersdorf', 'Oettersdorf', 50.6000000, 11.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33304, 'Oettern', 'Oettern', '', 50.9225100, 11.3580600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33305, 'Oerlinghausen', 'Oerlinghausen', 'Ehrlingkhauzen,Erlinggauzen,Erlingkhauzen,awrlynghhawzn,e ling hao sen,eruringuhauzen,Ерлингхаузен,Ерлінггаузен,Эрлингхаузен,أورلينغهاوزن,اورلینگ‌هاوزن,エルリングハウゼン,厄灵豪森', 51.9545300, 8.6622000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33306, 'Oer-Erkenschwick', 'Oer-Erkenschwick', 'Er-Erkenshvik,Oer-Erkenschwick,Or-Ehrkenshvik,Or-Erkensvik,Or-Erkenşvik,ao ai er-ai er ken shi wei ke,awr-arknshfyk,oa=eakenshuvu~ikku,Ер-Еркеншвик,Ер-Еркеншвік,Ор-Эркеншвик,أور-إركنشفيك,اور-ارکن‌اشویک,オーア＝エアケンシュヴィック,奥埃尔-埃尔肯施维克', 51.6419800, 7.2645100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33307, 'Oepfershausen', 'Oepfershausen', 'Ehpferskhauzen,Epferskhauzen,Oepfershausen,ao ai pu fei er si hao sen,Епферсхаузен,Эпферсхаузен,奥埃普费尔斯豪森', 50.6411300, 10.2408500, 'DE', '2013-06-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33308, 'Oelsnitz', 'Oelsnitz', 'Oelsnitz', 50.7258400, 12.7010000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33309, 'Oelsnitz', 'Oelsnitz', 'Oelsnitz im Vogtland,Oelsnitz/Vogtl.', 50.4147000, 12.1695000, 'DE', '2016-01-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33310, 'Oelsberg', 'Oelsberg', '', 50.1987700, 7.8369400, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33311, 'Oelde', 'Oelde', 'Ehl''de,El''de,Elde,Oelde,Ol''de,Stadt Oelde,awldh,e er de,Елде,Ельде,Ольде,Эльде,أولده,اولده,厄尔德', 51.8289000, 8.1472400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33312, 'Oedheim', 'Oedheim', 'Edgajm,Edkhajm,Ehdkhajm,Oedheim,ao ai de hai mu,etohaimu,Едгайм,Едхајм,Эдхайм,エートハイム,奥埃德海姆', 49.2402800, 9.2533300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33313, 'Oederan', 'Oederan', 'Ederan,Ederana,Ehderan,Oederan,Oederanum,awdhran,aydrn,e de lan,Ēderana,Едеран,Эдеран,آئدرن,أودهران,厄德兰', 50.8606400, 13.1716400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33314, 'Oechsen', 'Oechsen', 'Ehkhzen,Ekhzen,Okhzen,e ke sen,Ехзен,Охзен,Эхзен,厄克森', 50.7453100, 10.0628600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33315, 'Oebisfelde', 'Oebisfelde', 'Ebisfelde,Ehbisfel''de-Veferlingen,Oebisfelde,Ебисфелде,Эбисфельде-Веферлинген', 52.4342100, 10.9878600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33316, 'Odisheim', 'Odisheim', '', 53.6956500, 8.9428100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33317, 'Oederquart', 'Oederquart', 'Ederkuart,Ehderkvart,Oderquart,Oederquart,ao ai de er ku a er te,edakuvu~aruto,Öderquart,Едеркуарт,Эдеркварт,エーダークヴァルト,奥埃德尔库阿尔特', 53.8026700, 9.2368000, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33318, 'Odernheim', 'Odernheim', 'Odernheim,Odernheim am Glan', 49.7651100, 7.7042700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33319, 'Oderberg', 'Oderberg', 'Oderberg,Oderberga,adrbrg,ao de er bei ge,awdrbrgh,Одерберг,Օդերբերգ,أودربرغ,ادربرگ,奥德尔贝格', 52.8657100, 14.0450800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33320, 'Odenthal', 'Odenthal', 'Odental,Odental'',Odenthal,ao deng ta er,Одентал,Оденталь,奥登塔尔', 51.0333300, 7.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33321, 'Odenbach', 'Odenbach', 'Odenbakh,ao deng ba he,Оденбах,奥登巴赫', 49.6833300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33322, 'Odelzhausen', 'Odelzhausen', 'Odel''cgauzen,Odel''ckhauzen,Odelckhauzen,ao de er ci hao sen,awdltshawzn,Оделцхаузен,Одельцгаузен,Одельцхаузен,Օդելցհաուզեն,اودلتسهاوزن,奥德尔茨豪森', 48.3088900, 11.1988900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33323, 'Odderade', 'Odderade', 'Odderade', 54.1389200, 9.1940800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33324, 'Ockholm', 'Ockholm', 'E Hoolme,Ockholm,Okholm,Okkhol''m,Okkholm,ao ke huo er mu,Окхолм,Окхольм,奥克霍尔姆', 54.6666700, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33325, 'Ockfen', 'Ockfen', '', 49.6166700, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33326, 'Ockenheim', 'Ockenheim', '', 49.9437100, 7.9712700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33327, 'Ockenfels', 'Ockenfels', '', 50.5761000, 7.2753500, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33328, 'Ochtrup', 'Ochtrup', 'Ochtrup,Okhtrup,Oxtrup,aktrwp,ao te lu pu,awkhtrwb,Охтруп,أوختروب,اکتروپ,奥特鲁普', 52.2080200, 7.1898800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33329, 'Ochtendung', 'Ochtendung', 'Ochtendung,Okhtendung,ao teng dong,Охтендунг,奥滕东', 50.3500000, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33330, 'Ochsenhausen', 'Ochsenhausen', 'Ochsenhausen,Okhzenkhauzen,Oksengauzen,Oksenkhauzen,ao sen hao sen,awksnhawzn,Оксенгаузен,Оксенхаузен,Охзенхаузен,Օքսենհաուզեն,أوكسنهاوزن,اوکسن‌هاوزن,ოკსენჰაუზენი,奥森豪森', 48.0702900, 9.9503000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33331, 'Ochsenfurt', 'Ochsenfurt', 'Oksenfurt,Oxnfuat,ao sen fu er te,awksnfwrt,okuzenfuruto,Оксенфурт,Օքսենֆուրտ,أوكسنفورت,اوکسنفورت,オクゼンフルト,奥森富尔特', 49.6642900, 10.0622700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33332, 'Obrigheim', 'Obrigheim', 'Obrigheim', 49.5916100, 8.2048300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33333, 'Obrigheim', 'Obrigheim', 'Obrigheim', 49.3519400, 9.0908300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33334, 'Obing', 'Obing', 'Obing,ao bin,awbyng,Обинг,Обінг,Օբինգ,اوبینگ,奥宾', 48.0004900, 12.4052800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33335, 'Obhausen', 'Obhausen', 'Obhausen,Obkhauzen,ao bu hao sen,Обхаузен,奥布豪森', 51.3917200, 11.6531200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33336, 'Oberzissen', 'Oberzissen', '', 50.4500000, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33337, 'Oberwörresbach', 'Oberwoerresbach', '', 49.7833300, 7.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33338, 'Oberwolfach', 'Oberwolfach', 'Obervol''fakh,Obervolfakh,shang wo er fa,Оберволфах,Обервольфах,上沃尔法', 48.3166700, 8.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33339, 'Oberwiesen', 'Oberwiesen', '', 49.7000000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33340, 'Oberwies', 'Oberwies', '', 50.2886100, 7.7805600, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33341, 'Oberwiera', 'Oberwiera', 'Obervira,shang wei la,Обервира,上维拉', 50.8891300, 12.5441500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33342, 'Oberwesel', 'Oberwesel', 'Obervezel,Obervezel'',Oberwesel,awbrfyzl,awbrwzl,obavu~eseru,Обервезел,Обервезель,أوبرفيزل,اوبروزل,オーバーヴェセル', 50.1077700, 7.7252200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33343, 'Oberweißbach', 'Oberweissbach', 'Obervajsbakh,Oberweissbach,Oberweissbach/Thueringer Wald,Oberweißbach,Oberweißbach/Thüringer Wald,ao bo wei si ba he,awbrfaysbakh,awbrwaysbakh/twryngnrwald,Обервайсбах,Обервајсбах,أوبرفايسباخ,اوبروایسباخ/تورینگنروالد,奥伯韦斯巴赫', 50.5823100, 11.1438200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33344, 'Oberweis', 'Oberweis', '', 49.9666700, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33345, 'Oberweiler im Tal', 'Oberweiler im Tal', 'Obervajler im Tal,Obervajler-im-Tal'',gu de shang wei lei,Обервайлер-им-Таль,Обервајлер им Тал,谷地上魏勒', 49.5833300, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33346, 'Oberweiler', 'Oberweiler', '', 50.0500000, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33347, 'Oberweid', 'Oberweid', 'Obervajd,Oberweid,shang wei de,Обервайд,Обервајд,上魏德', 50.5904300, 10.0638100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33348, 'Oberwambach', 'Oberwambach', '', 50.6666700, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33349, 'Oberwallmenach', 'Oberwallmenach', '', 50.1666700, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33350, 'Heidstock', 'Heidstock', '', 49.2557100, 6.8815600, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33351, 'Oberviechtach', 'Oberviechtach', 'Oberfikhtakh,Oberviechtach,Obervikhtakh,Veichta,Viechtach,awbrfyshtakh,shang fei xi ta he,Обервихтах,Оберфихтах,Оберфіхтах,أوبرفيشتاخ,اوبرفیشتاخ,上菲希塔赫', 49.4580900, 12.4166900, 'DE', '2012-09-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33352, 'Oberursel', 'Oberursel', 'Oberursel', 50.2073100, 8.5774700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33353, 'Obertshausen', 'Obertshausen', 'Obertsgauzen,Obertshausen,Obertskhauzen,awbrtshawzn,oberutsuhauzen,shang ci hao sen,Обертсгаузен,Обертсхаузен,أوبرتسهاوزن,اوبرتس‌هاوزن,オーベルツハウゼン,上茨豪森', 50.0713900, 8.8512300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33354, 'Obertrubach', 'Obertrubach', 'Obertrubach,Obertrubakh,obatorubahha,shang te lu ba he,Обертрубах,Օբերթրուբախ,オーバートルバッハ,上特鲁巴赫', 49.7000000, 11.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33355, 'Obertraubling', 'Obertraubling', 'Obertraubling,awbrtrawblyng,shang te lao bu ling,Обертраублинг,Обертраублінг,Օբերթրաուբլինգ,اوبرتراوبلینگ,上特劳布灵', 48.9666700, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33356, 'Obertiefenbach', 'Obertiefenbach', '', 50.2419900, 7.8897300, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33357, 'Oberthulba', 'Oberthulba', 'Oberthulba,Obertul''ba,Obertulba,shang tu er ba,Обертулба,Обертульба,Օբերտուլբա,上图尔巴', 50.1990400, 9.9588200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33358, 'Oberthal', 'Oberthal', '', 49.5125700, 7.0838200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33359, 'Oberteuringen', 'Oberteuringen', 'Obertojringen,Obertoyringen,shang tuo yi lin gen,Обертойринген,Обертойрінген,Обертојринген,Օբերտոյրինգեն,ობერტოირინგენი,上托伊林根', 47.7240900, 9.4697900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33360, 'Obertaufkirchen', 'Obertaufkirchen', 'Obertaufkirkhen,awbrtawf kyrshn,shang tao fu ji xing,Обертауфкирхен,Обертауфкірхен,Օբերթաուֆկիրխեն,اوبرتاوف کیرشن,上陶夫基兴', 48.2604600, 12.2790400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33361, 'Obersüßbach', 'Obersussbach', 'Obersuessbach,Obersüßbach,Oberzisbakh,Oberzjusbakh,Oberzyusbax,shang xu si ba he,Оберзисбах,Оберзюсбах,Օբերզյուսբախ,上叙斯巴赫', 48.6166700, 11.9500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33362, 'Obersülzen', 'Obersulzen', 'Oberzilcen,Oberzjul''cen,shang xu er cen,Оберзилцен,Оберзюльцен,上叙尔岑', 49.5683300, 8.2113900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33363, 'Oberstreu', 'Oberstreu', '', 50.4033800, 10.2877500, 'DE', '2012-08-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33364, 'Oberstreit', 'Oberstreit', '', 49.8000000, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33365, 'Oberstenfeld', 'Oberstenfeld', 'Oberstenfel''d,Oberstenfeld,awbrshtnfld,shang si teng fei er de,Оберстенфелд,Оберстенфельд,اوبرشتنفلد,上斯滕费尔德', 49.0261100, 9.3208300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33366, 'Obersteinebach', 'Obersteinebach', '', 50.5833300, 7.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33367, 'Oberstedem', 'Oberstedem', '', 49.9333300, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33368, 'Oberstdorf', 'Oberstdorf', 'Oberstdorf,ao bo si duo fu,awbrshtdwrf,oberusutodorufu,Оберстдорф,Օբերստդորֆ,اوبرشتدورف,オーベルストドルフ,奥伯斯多夫', 47.4072400, 10.2793900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33369, 'Oberstaufenbach', 'Oberstaufenbach', 'Obershtaufenbakh,shang si tao fen ba he,Оберштауфенбах,上斯陶芬巴赫', 49.5159900, 7.5098800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33370, 'Oberstaufen', 'Oberstaufen', 'Obastaffa,Obershtaufen,Oberstaufen,shang si tao fen,Оберштауфен,Օբերշտաուֆեն,上斯陶芬', 47.5556800, 10.0224500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33371, 'Oberstadtfeld', 'Oberstadtfeld', '', 50.1761600, 6.7692400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33372, 'Oberstadt', 'Oberstadt', 'Oberstadt', 50.5553100, 10.5984400, 'DE', '2016-02-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33373, 'Oberstadion', 'Oberstadion', 'Obershtadion,Oberstadion,shang si ta di weng,Оберштадион,Оберштадіон,Օբերշտադիոն,ობერშტადიონი,上斯塔迪翁', 48.1859600, 9.6924100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33374, 'Obersontheim', 'Obersontheim', 'Obersontheim,Oberzontgajm,Oberzontkhajm,obazontohaimu,shang song tai mu,Оберзонтгайм,Оберзонтхайм,Оберзонтхајм,オーバーゾントハイム,上松泰姆', 49.0566700, 9.8991700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33375, 'Obersöchering', 'Obersochering', '', 47.7333300, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33376, 'Obersinn', 'Obersinn', 'Obersinn,Oberzin,Oberzinn,shang xin en,Оберзин,Оберзінн,Օբերզին,上辛恩', 50.2087500, 9.6154500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33377, 'Obersimten', 'Obersimten', '', 49.1666700, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33378, 'Oberschweinbach', 'Oberschweinbach', '', 48.2381700, 11.1557100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33379, 'Oberschwarzach', 'Oberschwarzach', 'Oberschwarzach,Obershvarcakh,awbrshwartsakh,shang shi wa er cha he,Обершварцах,اوبرشوارتساخ,上施瓦尔察赫', 49.8605100, 10.4099900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33380, 'Oberschöneweide', 'Oberschoneweide', 'Berlin-Oberschoneweide,Berlin-Oberschöneweide', 52.4610600, 13.5210800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33381, 'Oberschönegg', 'Oberschonegg', 'Obersheneg,Obershenegg,Obershjoneg,Obersyoneg,shang she nei ge,Обершенег,Обершенегг,Обершёнег,Օբերշյոնեգ,上舍内格', 48.1084600, 10.2984800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33382, 'Oberschöna', 'Oberschoena', 'Oberschoena,Oberschoena vald,Oberschona,Oberschöna,Oberschöna vald,Obershena,Obershjona,shang she na,Обершена,Обершёна,Обершөна,上舍纳', 50.8975900, 13.2537900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33383, 'Oberschneiding', 'Oberschneiding', 'Obershnajding,awbrshnaydyng,shang shi nai ding,Обершнайдинг,Обершнайдінг,Обершнајдинг,اوبرشنایدینگ,上施奈丁', 48.7957300, 12.6420000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33384, 'Oberschlettenbach', 'Oberschlettenbach', '', 49.1461200, 7.8718800, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33385, 'Oberschleißheim', 'Oberschleissheim', 'Obaschleissheim,Obaschleißheim,Oberschleissheim,Oberschleißheim,Obershlajskhajm,Obershljajsgajm,Oberslayshaym,awbrshlayshaym,shang shi lai si hai mu,Обершлайсхайм,Обершлајсхајм,Обершляйсгайм,Օբերշլայսհայմ,اوبرشلایسهایم,上施莱斯海姆', 48.2500000, 11.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33386, 'Oberscheinfeld', 'Oberscheinfeld', 'Obersaynfeld,Oberscheinfeld,Obershajnfel''d,Obershajnfeld,abrschynfld,shang sha yin fei er de,Обершайнфельд,Обершајнфелд,Օբերշայնֆելդ,ابرسچینفلد,上沙因费尔德', 49.7082900, 10.4341800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33387, 'Oberscheidweiler', 'Oberscheidweiler', '', 50.0833300, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33388, 'Ober-Saulheim', 'Ober-Saulheim', '', 49.8637600, 8.1352600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33389, 'Oberroth', 'Oberroth', '', 48.1758200, 10.1891300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33390, 'Oberrot', 'Oberrot', 'Oberot,Oberrot,ao bei luo te,obaroto,Оберот,Оберрот,オーバーロート,奥贝罗特', 49.0144400, 9.6672200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33391, 'Oberroßbach', 'Oberrossbach', '', 50.6544400, 8.0397200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33392, 'Oberrod', 'Oberrod', '', 50.5850000, 8.1272200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33393, 'Oberröblingen', 'Oberroeblingen', '', 51.4370500, 11.3075000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33394, 'Oberriexingen', 'Oberriexingen', 'Oberiksingen,Oberriexingen,Oberriksingen,ao bei li ke xin gen,awbrryksynghn,awbrryksyngn,Обериксинген,Оберриксинген,Оберріксінген,أوبرريكسينغن,اوبرریکسینگن,奥贝里克辛根', 48.9265200, 9.0270100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33395, 'Oberrieden', 'Oberrieden', '', 48.0888600, 10.4261100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33396, 'Oberried', 'Oberried', '', 47.9333300, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33397, 'Oberreute', 'Oberreute', '', 47.5630300, 9.9444900, 'DE', '2013-12-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33398, 'Oberreißen', 'Oberreissen', '', 51.0870100, 11.4128700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33399, 'Oberreidenbach', 'Oberreidenbach', '', 49.7068400, 7.4612700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33400, 'Oberreichenbach', 'Oberreichenbach', '', 49.5894600, 10.7689200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33401, 'Oberreichenbach', 'Oberreichenbach', '', 48.7333300, 8.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33402, 'Ober-Ramstadt', 'Ober-Ramstadt', 'Ober-Ramshtadt,Ober-Ramshtat,Ober-Ramstadt,awbr-ramshtat,oba=ramushutatto,shang la mu si ta te,Обер-Рамштадт,Обер-Рамштат,أوبر-رامشتات,اوبر-رام‌اشتات,オーバー＝ラムシュタット,上拉姆斯塔特', 49.8307800, 8.7488700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33403, 'Oberraden', 'Oberraden', '', 50.5500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33404, 'Oberpöring', 'Oberporing', 'Oberpering,Oberpjoring,Oberpyoring,awbrpwryng,shang po ling,Оберперинг,Оберперінг,Оберпёринг,Օբերպյորինգ,اوبرپورینگ,上珀灵', 48.7017800, 12.8248200, 'DE', '2012-11-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33405, 'Oberpleichfeld', 'Oberpleichfeld', '', 49.8769400, 10.0868200, 'DE', '2012-10-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33406, 'Oberpierscheid', 'Oberpierscheid', '', 50.0666700, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33407, 'Oberpframmern', 'Oberpframmern', 'Oberpframern,Oberpframmern,awbrframrn,shang pu fu la mo en,Оберпфрамерн,Оберпфраммерн,اوبرفرامرن,上普夫拉默恩', 48.0220200, 11.8133100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33408, 'Oberottmarshausen', 'Oberottmarshausen', '', 48.2371600, 10.8575400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33409, 'Oberotterbach', 'Oberotterbach', 'Oberoterbakh,Oberotterbakh,ao bei luo te er ba he,Оберотербах,Обероттербах,奥贝罗特尔巴赫', 49.0704400, 7.9695500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33410, 'Oberostendorf', 'Oberostendorf', 'Oberostendorf,obaosutendorufu,shang ao si teng duo fu,Оберостендорф,Օբերոսթենդորֆ,オーバーオステンドルフ,上奥斯滕多夫', 47.9436000, 10.7427000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33411, 'Oberoppurg', 'Oberoppurg', 'Oberoppurg', 50.7000000, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33412, 'Ober-Olm', 'Ober-Olm', 'Ober-Ol''m,Ober-Olm,Owwer-Olm,Ulmena Superior,shang ao er mu,Обер-Олм,Обер-Ольм,上奥尔姆', 49.9372200, 8.1888900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33413, 'Oberöfflingen', 'Oberofflingen', '', 50.0666700, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33414, 'Obernzenn', 'Obernzenn', 'Oberncen,Oberncenn,Obernzenn,shang en cen,Обернцен,Обернценн,Օբերնցեն,上恩岑', 49.4519300, 10.4667000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33415, 'Obernzell', 'Obernzell', 'Obanzoi,Oberncel,Oberncel'',Oberncell'',awbrnzl,shang en ce er,Обернцел,Обернцелль,Обернцель,Օբերնցել,اوبرنزل,上恩策尔', 48.5548500, 13.6372900, 'DE', '2011-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33416, 'Obernkirchen', 'Obernkirchen', 'Obernkirchen,Obernkirkhen,ao bo en ji xing,awbrnkyrshn,oberunkiruhyen,Обернкирхен,أوبرنكيرشن,اوبرنکیرشن,オーベルンキルヒェン,奥伯恩基兴', 52.2721000, 9.1291200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33417, 'Obernhof', 'Obernhof', '', 50.3166700, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33418, 'Obernheim-Kirchenarnbach', 'Obernheim-Kirchenarnbach', '', 49.3500000, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33419, 'Obernheim', 'Obernheim', 'Oberngajm,Obernkhajm,shang en hai mu,Обернгайм,Обернхайм,Обернхајм,上恩海姆', 48.1629700, 8.8611300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33420, 'Obernfeld', 'Obernfeld', 'Obernfel''d,Obernfeld,oberunferuto,shang en fei er de,Обернфелд,Обернфельд,オーベルンフェルト,上恩费尔德', 51.5500000, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33421, 'Oberneukirchen', 'Oberneukirchen', 'Obernojkirkhen,Obernoykirxen,ao bo nuo yi ji xing,awbrnwy kyrshn,Обернойкирхен,Обернойкірхен,Обернојкирхен,Օբերնոյկիրխեն,اوبرنوی کیرشن,奥伯诺伊基兴', 48.1833300, 12.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33422, 'Oberneisen', 'Oberneisen', '', 50.3255500, 8.0772200, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33423, 'Oberndorf', 'Oberndorf', '', 53.7500000, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33424, 'Oberndorf', 'Oberndorf', '', 49.7166700, 7.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33425, 'Oberndorf', 'Oberndorf', '', 48.6691800, 10.8674900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33426, 'Oberndorf', 'Oberndorf', '', 48.2905000, 8.5722100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33427, 'Obernburg am Main', 'Obernburg am Main', 'Mayni Obernburg,Obernburg,Obernburg am Main,Obernburg na Majni,Obernburg-am-Majn,Obernburg-na-Majne,awbrnbwrg am mayn,awbrnbwrgh am mayn,mei yin he pan ao bo en bao,Обернбург,Обернбург на Мајни,Обернбург-ам-Майн,Обернбург-на-Майне,Մայնի Օբերնբուրգ,أوبرنبورغ آم ماين,اوبرنبورگ آم ماین,オーベルンブルク・アム・マイン,美因河畔奥伯恩堡', 49.8357700, 9.1310100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33428, 'Obernbreit', 'Obernbreit', 'Obernbrajt,shang en bu lai te,Обернбрайт,Обернбрајт,Օբերնբրայթ,上恩布赖特', 49.6586300, 10.1642400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33429, 'Obernau', 'Obernau', '', 50.6666700, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33430, 'Obermoschel', 'Obermoschel', 'Obermoshel,Obermoshel'',Owwamoschl,awbrmshl,awbrmwshl,obamosheru,shang mo she er,Обермошел,Обермошель,أوبرموشل,اوبرمشل,オーバーモシェル,上莫舍尔', 49.7279700, 7.7726600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33431, 'Ober-Mörlen', 'Ober-Morlen', 'Ober-Merlen,Ober-Mjorlen,Ober-Moerlen,Ober-Mörlen,oba=meruren,shang mo lun,Обер-Мерлен,Обер-Мёрлен,オーバー＝メルレン,上默伦', 50.3735000, 8.6908700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33432, 'Obermichelbach', 'Obermichelbach', 'Obermikhel''bakh,Obermikhelbakh,Obermixelbax,shang mi xie er ba he,Обермихелбах,Обермихельбах,Оберміхельбах,Օբերմիխելբախ,上米歇尔巴赫', 49.5311700, 10.9089100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33433, 'Obermeitingen', 'Obermeitingen', '', 48.1468500, 10.8062600, 'DE', '2012-12-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33434, 'Obermehler', 'Obermehler', 'Obermeler,shang mei lai er,Обермелер,上梅莱尔', 51.2699600, 10.5975400, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33435, 'Obermaßfeld-Grimmenthal', 'Obermassfeld-Grimmenthal', 'Grimmenthal,Obermasfel''d-Grimmental'',Obermasfeld-Grimental,Obermassfeld-Grimmenthal,Obermaßfeld-Grimmenthal,shang ma si fei er de-ge li men ta er,Обермасфелд-Гриментал,Обермасфельд-Гримменталь,上马斯费尔德-格里门塔尔', 50.5289800, 10.4396300, 'DE', '2013-10-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33436, 'Obermarchtal', 'Obermarchtal', 'Marchtallum,Obermarkhtal,Obermarkhtal'',Obermarxtal,shang ma er xi ta er,Обермархтал,Обермархталь,Օբերմարխտալ,ობერმარხტალი,上马尔希塔尔', 48.2327900, 9.5723500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33437, 'Obermaiselstein', 'Obermaiselstein', '', 47.4500000, 10.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33438, 'Oberlungwitz', 'Oberlungwitz', 'Oberlungvic,Oberlungvica,Oberlungwitz,awbrlwnghfts,awbrlwngwts,shang long wei ci,Оберлунгвиц,أوبرلونغفتس,اوبرلونگوتس,上隆维茨', 50.7823000, 12.7078900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33439, 'Oberlichtenau', 'Oberlichtenau', 'Oberlichtenau', 51.2187500, 13.9899200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33440, 'Oberleichtersbach', 'Oberleichtersbach', 'Oberlajkhtersbakh,Oberlayxtersbax,Oberljajkhtersbakh,shang lai xi te er si ba he,Оберлайхтерсбах,Оберлајхтерсбах,Оберляйхтерсбах,Օբերլայխտերսբախ,上莱希特尔斯巴赫', 50.2833300, 9.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33441, 'Oberlauch', 'Oberlauch', '', 50.1666700, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33442, 'Oberlascheid', 'Oberlascheid', '', 50.2500000, 6.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33443, 'Langfurth', 'Langfurth', 'Langfurt,Langfurth,Oberlangfurth,lang fu er te,rangufuruto,Лангфурт,Լանգֆուրտ,ラングフルト,朗富尔特', 49.1011200, 10.4535900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33444, 'Oberlangen', 'Oberlangen', '', 52.8500000, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33445, 'Oberlahr', 'Oberlahr', '', 50.6230000, 7.5168800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33446, 'Oberkotzau', 'Oberkotzau', 'Oberkocau,Oberkotcau,Oberkotzau,awbrkwtsaw,obakottsu~au,shang ke cao,Оберкотцау,Оберкоцау,اوبرکوتساو,オーバーコッツァウ,上科曹', 50.2623600, 11.9348400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33447, 'Ober Kostenz', 'Ober Kostenz', '', 49.9500000, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33448, 'Oberkochen', 'Oberkochen', 'Oberkokhen,awbrkwkhn,shang ke heng,Оберкохен,أوبركوخن,اوبرکوخن,ობერკოხენი,上科亨', 48.7837900, 10.1051900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33449, 'Oberkirn', 'Oberkirn', '', 49.8833300, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33450, 'Oberkirch', 'Oberkirch', 'Oberkirkh,awbrkyrsh,Оберкирх,Оберкірх,أوبركيرش,اوبرکیرش', 48.5324100, 8.0786400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33451, 'Oberkatz', 'Oberkatz', 'Oberkac,shang ka ci,Оберкац,上卡茨', 50.6000000, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33452, 'Oberkail', 'Oberkail', 'Oberkajl,Oberkajl'',shang kai er,Оберкайль,Оберкајл,上凯尔', 50.0333300, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33453, 'Oberjettingen', 'Oberjettingen', '', 48.5746800, 8.7763600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33454, 'Oberirsen', 'Oberirsen', '', 50.7166700, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33455, 'Oberickelsheim', 'Oberickelsheim', 'Oberikelskhajm,Oberikkel''sgajm,Oberikkel''skhajm,ao bei li ke er si hai mu,Оберикелсхајм,Обериккельсхайм,Оберіккельсгайм,Օբերիքելսհայմ,奥贝里克尔斯海姆', 49.6000000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33456, 'Oberhosenbach', 'Oberhosenbach', '', 49.8166700, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33457, 'Oberhof', 'Oberhof', 'Obergof,Oberhof,Oberhofa,Oberkhof,ao bei luo fu,awbrhwf  alman,obahofu,Обергоф,Оберхоф,اوبرهوف، آلمان,オーバーホーフ,奥贝罗夫', 50.7043500, 10.7271600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33458, 'Ober-Hilbersheim', 'Ober-Hilbersheim', '', 49.9000000, 8.0288900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33459, 'Oberheldrungen', 'Oberheldrungen', 'Oberheldrungen', 51.2833300, 11.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33460, 'Oberheimbach', 'Oberheimbach', '', 50.0166700, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33461, 'Oberhausen-Rheinhausen', 'Oberhausen-Rheinhausen', 'Obergauzen-Rajngauzen,Oberhausen-Rheinhausen,Oberkhauzen-Rajnakhauzen,Oberkhauzen-Rajnkhauzen,ao bei lao sen-lai yin hao sen,Обергаузен-Райнгаузен,Оберхаузен-Райнхаузен,Оберхаузен-Рајнахаузен,奥贝劳森-赖因豪森', 49.2738900, 8.4716700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33462, 'Oberhausen an der Appel', 'Oberhausen an der Appel', '', 49.7166700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33463, 'Oberhausen', 'Oberhausen', 'Obergauzen,Oberhausen,Oberhauzen,Oberhauzenas,Oberhauzene,Oberkhauzen,Omperchaouzen,Overhus,ao bo hao sen,awbrhawzn,obahauzen,obeohaujen,oberhauzeni,Ομπερχάουζεν,Обергаузен,Оберхаузен,אוברהאוזן,أوبرهاوزن,اوبرهاوزن,ობერჰაუზენი,オーバーハウゼン,奥伯豪森,오버하우젠', 51.4780500, 6.8625000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33464, 'Oberhausen', 'Oberhausen', '', 49.0969400, 8.0583300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33465, 'Oberhausen', 'Oberhausen', '', 48.7220100, 11.1115100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33466, 'Oberhausen', 'Oberhausen', '', 47.7833300, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33467, 'Oberharmersbach', 'Oberharmersbach', 'Obergarmersbakh,Oberkharmersbakh,shang ha er mo si ba he,Обергармерсбах,Оберхармерсбах,上哈尔默斯巴赫', 48.3735800, 8.1254200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33468, 'Oberhambach', 'Oberhambach', '', 49.6833300, 7.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33469, 'Oberhain', 'Oberhain', 'Oberhain', 50.6333300, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33470, 'Oberhaid', 'Oberhaid', '', 50.1261400, 11.8051400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33471, 'Oberhaid', 'Oberhaid', '', 49.9324700, 10.8147100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33472, 'Oberhaching', 'Oberhaching', 'Obergakhing,Oberhaxing,Oberkhakhing,awbrhakhyng,shang ha xing,Обергахінг,Оберхахинг,Օբերհախինգ,اوبرهاخینگ,上哈兴', 48.0245500, 11.5974400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33473, 'Obergurig', 'Obergurig', 'Hornja Horka,Hornja Hórka', 51.1329400, 14.4048800, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33474, 'Obergünzburg', 'Obergunzburg', 'Obergincburg,Obergjuncburg,Oberguenzburg,Obergunzburg,Obergünzburg,obagyuntsuburuku,shang jin ci bao,Обергинцбург,Обергюнцбург,Օբերգյունցբուրգ,オーバーギュンツブルク,上金茨堡', 47.8454500, 10.4182100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33475, 'Obergröningen', 'Obergroningen', 'Obergreningen,Obergrjoningen,obergreningeni,shang ge lei ning gen,Обергренинген,Обергренінген,Обергрёнинген,ობერგრენინგენი,上格勒宁根', 48.8944900, 9.9093900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33476, 'Obergriesbach', 'Obergriesbach', 'Obergrisbakh,Obergrisbax,obagurisubahha,shang ge li si ba he,Обергрисбах,Обергрісбах,Օբերգրիսբախ,オーバーグリースバッハ,上格里斯巴赫', 48.4230500, 11.0685000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33477, 'Obergeckler', 'Obergeckler', '', 49.9666700, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33478, 'Ober-Flörsheim', 'Ober-Florsheim', '', 49.6830600, 8.1552800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33479, 'Oberfischbach', 'Oberfischbach', 'Oberfishbakh,shang fei shi ba he,Оберфишбах,上菲施巴赫', 50.2491300, 7.9552200, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33480, 'Oberfell', 'Oberfell', '', 50.2603800, 7.4446100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33481, 'Obererbach', 'Obererbach', '', 50.4500000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33482, 'Oberelz', 'Oberelz', '', 50.2666700, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33483, 'Oberelsbach', 'Oberelsbach', 'Oberel''sbakh,Oberelsbach,Oberelsbakh,Oberelsbax,shang ai er si ba he,Оберелсбах,Оберельсбах,Օբերելսբախ,上埃尔斯巴赫', 50.4411800, 10.1169200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33484, 'Oberelbert', 'Oberelbert', '', 50.3916700, 7.8172200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33485, 'Oberdürenbach', 'Oberdurenbach', '', 50.4666700, 7.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33486, 'Oberdreis', 'Oberdreis', '', 50.6256900, 7.6658900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33487, 'Oberdorla', 'Oberdorla', 'Oberdorla,shang duo er la,Обердорла,上多尔拉', 51.1658500, 10.4216300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33488, 'Oberdolling', 'Oberdolling', 'Obadolling,Oberdoling,Oberdolling,awbrdwlyng,shang duo ling,Обердолинг,Обердоллинг,Обердоллінг,Օբերդոլինգ,اوبردولینگ,上多灵', 48.8294300, 11.5933000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33489, 'Oberdischingen', 'Oberdischingen', 'Oberdishingen,Oberdisingen,oberdishingeni,shang di xin gen,Обердишинген,Обердішинген,Օբերդիշինգեն,ობერდიშინგენი,上迪欣根', 48.3000000, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33490, 'Oberding', 'Oberding', 'Obading,Oberding,ao bo ding,awbrdyng,Обердинг,Обердінг,اوبردینگ,奥伯丁', 48.3166700, 11.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33491, 'Oberdiebach', 'Oberdiebach', 'Oberdibakh,shang di ba he,Обердибах,上迪巴赫', 50.0333300, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33492, 'Oberderdingen', 'Oberderdingen', 'Oberderdingen,shang de er ding gen,Обердердинген,Обердердінген,上德尔丁根', 49.0655600, 8.8030600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33493, 'Oberdachstetten', 'Oberdachstetten', 'Oberdakhshteten,Oberdakhshtetten,Oberdakshtetten,Oberdaksteten,obadahashutetten,shang da si te teng,Обердакштеттен,Обердахштетен,Обердахштеттен,Օբերդակշտետեն,オーバーダハシュテッテン,上达斯特滕', 49.4166700, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33494, 'Obercunnersdorf', 'Obercunnersdorf', '', 50.9171100, 13.5601500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33495, 'Oberbrombach', 'Oberbrombach', '', 49.7000000, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33496, 'Oberbösa', 'Oberboesa', 'Oberbosa,Oberbösa', 51.2893000, 11.0170000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33497, 'Oberboihingen', 'Oberboihingen', 'Oberboihingen,Oberboikhingen,Oberbojgingen,Oberbojkhingen,Oberboyxingen,shang bo yi xin gen,Обербоихинген,Обербойгінген,Обербойхинген,Օբերբոյխինգեն,上博伊欣根', 48.6500000, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33498, 'Oberbillig', 'Oberbillig', '', 49.7093800, 6.5066500, 'DE', '2015-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33499, 'Oberbiel', 'Oberbiel', '', 50.5532000, 8.4279700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33500, 'Oberbettingen', 'Oberbettingen', '', 50.2833300, 6.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33501, 'Oberbergkirchen', 'Oberbergkirchen', 'Oberbergirkhen,Oberbergkirkhen,Oberbergkirxen,Oberberkirkhen,awbrbrg kyrshn,shang bei ge ji xing,Обербергирхен,Обербергкирхен,Обербергкірхен,Оберберкирхен,Օբերբերգկիրխեն,اوبربرگ کیرشن,上贝格基兴', 48.3000000, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33502, 'Oberbachheim', 'Oberbachheim', '', 50.2463100, 7.7479600, 'DE', '2012-06-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33503, 'Oberaula', 'Oberaula', 'Oberaula,obaaura,shang ao la,Обераула,オーバーアウラ,上奥拉', 50.8500000, 9.4666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33504, 'Oberaudorf', 'Oberaudorf', 'Oberaudorf,awbr awdwrf,shang ao duo fu,Обераудорф,Օբերաուդորֆ,اوبر اودورف,上奥多夫', 47.6482200, 12.1724200, 'DE', '2012-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33505, 'Oberau', 'Oberau', 'Oberau,ao bei lao,awbraw,Оберау,Օբերաու,اوبراو,奥贝劳', 47.5597900, 11.1391900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33506, 'Oberasbach', 'Oberasbach', 'Oberasbakh,Oberasbax,awbrasbakh,shang a si ba he,Оберасбах,Օբերասբախ,أوبراسباخ,اوبرآسباخ,上阿斯巴赫', 49.4227500, 10.9576600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33507, 'Oberarnbach', 'Oberarnbach', '', 49.3833300, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33508, 'Oberammergau', 'Oberammergau', 'Obaammagau,Oberamergau,Oberammergau,ZOX,awbr amrgaw,shang a ma gao,Оберамергау,Обераммергау,Օբերամերգաու,אובראמרגאו,اوبر آمرگاو,上阿瑪高', 47.5981200, 11.0669200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33509, 'Altenbuch', 'Altenbuch', 'Altenbuch,Oberaltenbuch,Unteraltenbuch', 49.8333300, 9.4000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33510, 'Oberalben', 'Oberalben', 'Oberal''ben,Oberalben,ao bei la er ben,Обералбен,Оберальбен,奥贝拉尔本', 49.5833300, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33511, 'Oberahr', 'Oberahr', '', 50.5000000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33512, 'Nützen', 'Nutzen', 'Nutzen,Nützen', 53.8666700, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33513, 'Nutteln', 'Nutteln', '', 53.9877800, 9.3867700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33514, 'Nußloch', 'Nussloch', 'Nuslokh,Nussloch,Nußloch,nu si luo,nusurohho,Нуслох,ヌスロッホ,努斯洛', 49.3238900, 8.6955600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33515, 'Nusse', 'Nusse', 'Nusse', 53.6565400, 10.5839100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33516, 'Nußdorf am Inn', 'Nussdorf am Inn', 'Inni Nusdorf,Nusdorf am In,Nusdorf-am-Inn,Nusdorf-na-Inne,Nussdorf,Nussdorf a. Inn,Nußdorf,Nußdorf a. Inn,nwsdwrf am ayn,yin he pan nu si duo fu,Нусдорф ам Ин,Нусдорф-ам-Інн,Нусдорф-на-Инне,Իննի Նուսդորֆ,نوسدورف ام این,因河畔努斯多夫', 47.7423200, 12.1561100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33517, 'Nußdorf', 'Nussdorf', 'Nussdorf (Chiemgau),Nußdorf (Chiemgau)', 47.9056400, 12.5960800, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33518, 'Nußbaum', 'Nussbaum', 'Nussbaum,Nußbaum', 49.8000000, 7.6166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33519, 'Nußbach', 'Nussbach', 'Nusbakh,nu si ba he,Нусбах,努斯巴赫', 49.6333300, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33520, 'Nusplingen', 'Nusplingen', 'Nusplingen,nu si pu lin gen,Нусплинген,Нусплінген,努斯普林根', 48.1326400, 8.8915400, 'DE', '2013-05-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33521, 'Nusbaum', 'Nusbaum', '', 49.9166700, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33522, 'Nürtingen', 'Nurtingen', 'Nirtingen,Njurtingen,Nuertingen,Nurtinga,Nyurtingen,Nürtingen,ni er ting gen,nwrtynghn,nwrtyngn,Ниртинген,Нюртинген,Нюртінген,Նյուրտինգեն,نورتينغن,نورتینگن,尼尔廷根', 48.6256500, 9.3420300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33523, 'Nürnberg', 'Nuernberg', 'Gorad Njurnberg,NUE,Neurenberch,Neurenberg,Niamberg,Nirnberg,Nirnberga,Niurnbergas,Njurnberg,Norimberg,Norimberga,Norimberk,Norimbèrga,Norymberga,Nuernbarg,Nuernberg,Nuernberq,Nuremberg,Nuremberga,Nurembergo,Nuremburg,Nurembèrg,Nurenberg,Nurenbergo,Nurenburg,Nurnberg,Nyremberg,Nyremberge,Nyremvergi,Nyrëmberg,Nyurnberg,Nyurnbérg,Núremberg,Nürnbarg,Nürnberg,Nürnberq,n''yurnabarga,niu lun bao,niurnbergi,niyuramperk,nurem beirk,nwileunbeleukeu,nwrnbrg,nwrnbyrgh,nyrnbrg,nyurunberuku,nywrmbrg,Νυρεμβέργη,Νυρεμβεργη,Горад Нюрнберг,Нирнберг,Нюрнберг,Нӳрнберг,נירנבערג,נירנברג,نورنبرگ,نورنبيرغ,نۆریمبێرگ,نیورمبرگ,न्युर्नबर्ग,நியூரம்பெர்க்,นูเรมเบิร์ก,เนือร์นแบร์ก,ნიურნბერგი,ニュルンベルク,纽伦堡,뉘른베르크', 49.4542100, 11.0775200, 'DE', '2015-01-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33524, 'Nürburg', 'Nurburg', 'Nirburg,Njurburg,Nurburg,Nürburg,ni er bao,nyuruburuku,Нирбург,Нюрбург,ニュルブルク,尼尔堡', 50.3333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33525, 'Nünschweiler', 'Nuenschweiler', '', 49.2235300, 7.5071900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33526, 'Nünchritz', 'Nunchritz', 'Ninkhric,Njunkhric,Nuenchritz,Nuenchritzi vald,Nünchritz,Nünchritzi vald,ning xi li ci,Нинхриц,Нюнхриц,Нюнхріц,宁希里茨', 51.2999300, 13.3855500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33527, 'Nümbrecht', 'Nuembrecht', 'Nimbrekht,Njumbrekht,Nuembrecht,Numbrecht,Nümbrecht,ning bu lei xi te,Нимбрехт,Нюмбрехт,宁布雷希特', 50.9042700, 7.5406300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33528, 'Nufringen', 'Nufringen', 'Nufringen,nu fu lin gen,nupringeni,Нуфринген,Нуфрінген,Նուֆրինգեն,ნუფრინგენი,努夫林根', 48.6225300, 8.8900900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33529, 'Nüdlingen', 'Nudlingen', 'Nidlingen,Njudlingen,Nuedlingen,Nyudlingen,Nüdlingen,ni de lin gen,Нидлинген,Нюдлинген,Нюдлінген,Նյուդլինգեն,尼德林根', 50.2206300, 10.1229600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33530, 'Nudersdorf', 'Nudersdorf', '', 51.9302500, 12.5955400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33531, 'Nübel', 'Nubel', 'Nuebel,Nübel', 54.5666700, 9.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33532, 'Nübbel', 'Nubbel', 'Nubbel,Nuebbel,Nübbel', 54.2666700, 9.6166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33533, 'Notzingen', 'Notzingen', 'Nocingen,Notcingen,nuo qin gen,Нотцинген,Ноцинген,Նոտցինգեն,诺钦根', 48.6707600, 9.4572100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33534, 'Nottuln', 'Nottuln', 'Nottul''n,Notuln,nuo tu er en,Ноттульн,Нотулн,诺图尔恩', 51.9333300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33535, 'Nottleben', 'Nottleben', 'Nottleben', 50.9666700, 10.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33536, 'Nottfeld', 'Nottfeld', 'Nottfeld', 54.6166700, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33537, 'Nottensdorf', 'Nottensdorf', '', 53.4833300, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33538, 'Nothweiler', 'Nothweiler', '', 49.0666700, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33539, 'Nostorf', 'Nostorf', 'Nostorf,nuo si tuo er fu,Носторф,诺斯托尔夫', 53.4065600, 10.6540800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33540, 'Nossen', 'Nossen', 'Nosen,Nosene,Nossen,Nosyn,nuo sen,nwsn,nzn,Носен,Носсен,نزن,نوسن,诺森', 51.0579800, 13.2965200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33541, 'Nörvenich', 'Norvenich', 'Nerfenikh,Nervenikh,Njorfenikh,Noervenich,Norvenich,Nörvenich,QOE,nei er fei ni xi,nerufenihhi,Нервених,Нерфених,Нерфеніх,Нёрфених,ネルフェニッヒ,内尔费尼希', 50.8060400, 6.6395200, 'DE', '2016-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33542, 'Nortrup', 'Nortrup', 'Nortrup,nuo er te lu pu,Нортруп,诺尔特鲁普', 52.6150300, 7.8607200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33543, 'Nortorf', 'Nortorf', 'Nortorf,nrtrwf,nuo er tuo er fu,nwrtwrf,Норторф,نرتروف,نورتورف,诺尔托尔夫', 54.1673800, 9.8543700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33544, 'Nortmoor', 'Nortmoor', 'Nortmor,nuo er te mo er,Нортмор,诺尔特莫尔', 53.2460800, 7.5717800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33545, 'Northeim', 'Northeim', 'Northeim,Nortkhajm,Nuurten,norutohaimu,nrthaym,nuo er tai mu,nwrthaym,Нортхайм,Нортхајм,نرتهایم,نورتهايم,ノルトハイム,诺尔泰姆', 51.7066200, 9.9999700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33546, 'Nörtershausen', 'Nortershausen', '', 50.2166700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33547, 'Nörten-Hardenberg', 'Noerten-Hardenberg', 'Nerten-Khardenberg,Njorten-Khardenberg,Noerten-Hardenberg,Noerten-Harenbarg,Nörten-Hardenberg,Nörten-Harenbarg,nei er teng-ha deng bei ge,neruten=harudenberuku,Нертен-Харденберг,Нёртен-Харденберг,Нөртен-Харденберг,ネルテン＝ハルデンベルク,内尔滕-哈登贝格', 51.6287800, 9.9359300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33548, 'Norstedt', 'Norstedt', 'Norstedt', 54.5833300, 9.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33549, 'Norken', 'Norken', '', 50.6727800, 7.8977800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33550, 'Norheim', 'Norheim', 'Norkhajm,nuo lai mu,Норхайм,Норхајм,诺赖姆', 49.8109100, 7.8147800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33551, 'Nordwalde', 'Nordwalde', 'Nordval''de,Nordvalde,Nordwalde,nuo de wa er de,Нордвалде,Нордвальде,诺德瓦尔德', 52.0833300, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33552, 'Nordstemmen', 'Nordstemmen', 'Nordshtemmen,Nordstemen,nuo er ci te men,Нордстемен,Нордштеммен,诺尔茨特门', 52.1619600, 9.7835000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33553, 'Nordsehl', 'Nordsehl', '', 52.3500000, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33554, 'Nordrach', 'Nordrach', 'Nordrakh,nuo er de la,Нордрах,诺尔德拉', 48.4000000, 8.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33555, 'Nördlingen', 'Noerdlingen', 'N''ordlingen,Nerdlingen,Nerntlin''nken,Njordlingen,Noerdlingen,Nyordlingen,Nördlingen,ne de lin gen,nerutoringen,noeleuteulling-gen,nwrdlynghn,nwrdlyngn,Νέρντλινγκεν,Нердлинген,Нердлінген,Ньордлинген,Нёрдлинген,Նյորդլինգեն,نوردلينغن,نوردلینگن,ネルトリンゲン,讷德林根,뇌르틀링겐', 48.8512200, 10.4886800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33556, 'Nordleda', 'Nordleda', 'Lee,Nordleda,nuo de lai da,Нордледа,诺德莱达', 53.7666700, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33557, 'Nordkirchen', 'Nordkirchen', 'Nordkirkhen,bei ji xing,Нордкирхен,Нордкірхен,北基兴', 51.7382700, 7.5219700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33558, 'Nordhorn', 'Nordhorn', 'Nordhorn,Nordkhorn,Nothoorn,nuo de huo en,nwrdhwrn,Нордхорн,نوردهورن,諾德霍恩', 52.4308100, 7.0683300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33559, 'Nordholz', 'Nordholz', 'Noordholt,Nordkhol''c,Nordkholc,nuo er de huo er ci,Нордхолц,Нордхольц,诺尔德霍尔茨', 53.7833300, 8.6000000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33560, 'Nordhofen', 'Nordhofen', '', 50.5166700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33561, 'Nordheim', 'Nordheim', '', 49.8587000, 10.1854500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33562, 'Nordheim', 'Nordheim', 'Nordgajm,Nordheim,Nordkhajm,norutohaimu,Нордгайм,Нордхайм,Нордхајм,ノルトハイム', 49.1086100, 9.1277800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33563, 'Nordhausen', 'Nordhausen', 'Nordhausen,Nordkhauzen,bei hao sen,noleuteuhaujen,norutohauzen,nwrdhawzn,Нордхаузен,נורדהאוזן,نوردهاوزن,ノルトハウゼン,北豪森,노르트하우젠', 51.5018000, 10.7957000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33564, 'Nordhastedt', 'Nordhastedt', 'Nordhastedt,Nordkhashtedt,Nordkhashtet,nuo er de ha si te,Нордхаштедт,Нордхаштет,诺尔德哈斯特', 54.1666700, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33565, 'Nordhalben', 'Nordhalben', 'Nordgal''ben,Nordhalben,Nordkhal''ben,Nordkhalben,bei ha er ben,norutoharuben,Нордгальбен,Нордхалбен,Нордхальбен,Նորդհալբեն,ノルトハルベン,北哈尔本', 50.3741100, 11.5099200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33566, 'Nordhackstedt', 'Nordhackstedt', 'Nordhackstedt', 54.7333300, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33567, 'Norderwöhrden', 'Norderwohrden', 'Norderverden,Nordervjorden,Norderwohrden,Norderwöhrden,nuo er de er wei he er deng,Нордерверден,Нордервёрден,诺尔德尔韦赫尔登', 54.2000000, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33568, 'Norderstedt', 'Norderstedt', 'Nordershtedt,Nordershtet,Norderstedt,Norderstedt Stadt,ZOV,nrdrashtt,nuo de shi tai te,nwrdrshtyt,nwrdrstt,Нордерштедт,Нордерштет,נורדרשטט,نردراشتت,نوردرشتيت,諾德施泰特', 53.6859000, 9.9804100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33569, 'Norderstapel', 'Norderstapel', 'Norderstapel', 54.3600200, 9.2407600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33570, 'Norderney', 'Norderney', 'NRD,Norderney', 53.7082800, 7.1581900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33571, 'Norderheistedt', 'Norderheistedt', 'Norderheistedt', 54.2500000, 9.1500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33572, 'Norderbrarup', 'Norderbrarup', 'Norderbrarup', 54.6539700, 9.7685700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33573, 'Nordenham', 'Nordenham', 'Nordenham,Nordenkham,Nordenkhame,Stadt Nordenham,nuo er deng ha mu,nwrdnham,nwrdnhaym,Норденхам,Норденхаме,نوردنهام,نوردنهایم,诺尔登哈姆', 53.4861000, 8.4809300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33574, 'Nordendorf', 'Nordendorf', 'Nordendorf,nuo er deng duo fu,Нордендорф,Նորդենդորֆ,诺尔登多夫', 48.5947800, 10.8318300, 'DE', '2012-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33575, 'Norden', 'Norden', 'NOD,Noerden,Norden,Nörden,nwrdn,Норден,نوردن', 53.5955200, 7.2063900, 'DE', '2017-01-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33576, 'Norddorf', 'Norddorf', '', 54.6796900, 8.3329600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33577, 'Norddeich', 'Norddeich', '', 54.2166700, 8.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33578, 'Norddeich', 'Norddeich', 'Norddajkh,Норддайх', 53.6134900, 7.1604300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33579, 'Norath', 'Norath', '', 50.1333300, 7.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33580, 'Nonnweiler', 'Nonnweiler', 'Nonnvajler,Nonnweiler,Nonvajler,nong wei lei,Нонвайлер,Нонвајлер,Ноннвайлер,农韦勒', 49.6076200, 6.9698600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33581, 'Nonnenhorn', 'Nonnenhorn', 'Nonenhorn,Nonenkhorn,Nonnengorn,Nonnenkhorn,nuo nen huo er en,Ноненхорн,Нонненгорн,Нонненхорн,Նոնենհորն,诺嫩霍尔恩', 47.5738600, 9.6103800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33582, 'Nomborn', 'Nomborn', '', 50.4333300, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33583, 'Nohra', 'Nohra', '', 51.4333300, 10.7000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33584, 'Nohra', 'Nohra', 'Nohra', 50.9613600, 11.2597100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33585, 'Nohn', 'Nohn', 'Non,nuo en,Нон,诺恩', 50.3333300, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33586, 'Nohfelden', 'Nohfelden', 'Nofel''den,Nofelden,Nokhfelden,nuo fei er deng,Нофелден,Нофельден,Нохфелден,诺费尔登', 49.5869300, 7.1428300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33587, 'Nohen', 'Nohen', '', 49.6333300, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33588, 'Noer', 'Noer', 'Noer', 54.4666700, 10.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33589, 'Nöda', 'Noda', '', 51.0666700, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33590, 'Nochern', 'Nochern', '', 50.1666700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33591, 'Nobitz', 'Nobitz', 'Nobic,nuo bi ci,Нобиц,诺比茨', 50.9762100, 12.4860500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33592, 'Nöbdenitz', 'Nobdenitz', 'Nebdenic,Njobdenic,Noebdenitz,Nöbdenitz,nei bu de ni ci,Небдениц,Нёбдениц,内布德尼茨', 50.8666700, 12.2833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33593, 'Nitz', 'Nitz', '', 50.3333300, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33594, 'Nittendorf', 'Nittendorf', 'Nitendorf,Nittendorf,ni teng duo fu,nytndwrf,Нитендорф,Ниттендорф,Ніттендорф,Նիթենդորֆ,نیتندورف,尼滕多夫', 49.0245900, 11.9612600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33595, 'Nittenau', 'Nittenau', 'Nitenau,Nittenau,ni te nao,nytnaw,Нитенау,Ниттенау,Ніттенау,نيتناو,نیتناو,尼特瑙', 49.1942500, 12.2674100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33596, 'Nittel', 'Nittel', 'Nettel,Nitel,Nittel'',Nëttel,ni te er,Нител,Ниттель,尼特尔', 49.6500000, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33597, 'Nisterberg', 'Nisterberg', '', 50.6833300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33598, 'Nister', 'Nister', '', 50.6758300, 7.8383300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33599, 'Nirmsdorf', 'Nirmsdorf', '', 51.0944400, 11.4702000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33600, 'Nippes', 'Nippes', '', 50.9654500, 6.9531400, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33601, 'Nindorf', 'Nindorf', '', 54.1333300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33602, 'Nindorf', 'Nindorf', '', 54.0833300, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33603, 'Nimsreuland', 'Nimsreuland', '', 50.1333300, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33604, 'Nimshuscheid', 'Nimshuscheid', '', 50.1000000, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33605, 'Nimritz', 'Nimritz', 'Nimritz', 50.7000000, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33606, 'Nikolassee', 'Nikolassee', 'Berlin-Nikolassee,Nicolassee,Nikolassee,Nikolasze,Николасзе', 52.4344000, 13.2009500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33607, 'Nievern', 'Nievern', '', 50.3333300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33608, 'Nieste', 'Nieste', '', 51.3166700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33609, 'Niesky', 'Niesky', 'Niska,Niski,Nīski,ni si ji,nyzky,Ниски,Ніскі,نيزكي,نیزکی,尼斯基', 51.2924100, 14.8210700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33610, 'Niesgrau', 'Niesgrau', 'Niesgrau', 54.7500000, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33611, 'Nierstein', 'Nierstein', '', 49.8700300, 8.3364700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33612, 'Niersbach', 'Niersbach', '', 49.9402000, 6.7407600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33613, 'Niepars', 'Niepars', '', 54.3144700, 12.9244700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33614, 'Nienstädt', 'Nienstadt', 'Nienstaedt,Nienstädt', 52.2924200, 9.1644000, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33615, 'Nienhagen', 'Nienhagen', 'Nhg', 54.1486900, 12.1743400, 'DE', '2014-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33616, 'Nienhagen', 'Nienhagen', 'Indago nova [a. 1228],Nienhagen (Baixa Saxonia),Nienhagen (Baixa Saxônia),Nienhagen (Bassa Sassonia),Nienhagen (Dolna Saksonia),Nienhagen (Landkreis Celle),Nienhagen (Nedersaksen),Nienhagen  Lower Saxony,Nienhogen,Ninkhagen (Kelle),Ninkhagen (Okrug Cele),Нинхаген (Келле),Нинхаген (Округ Целе)', 52.5570500, 10.1021000, 'DE', '2014-08-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33617, 'Nienbüttel', 'Nienbuttel', 'Nienbuttel,Nienbüttel', 54.0296900, 9.4145100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33618, 'Nienburg', 'Nienburg', 'Gorad Ninburg,Nienborg,Nienburg,Nienburg/Weser,Nijnburg,Ninburg,Ninburga pie Vezeres,Nīnburga pie Vēzeres,ninburuku/vu~eza,ning bu er ge,nynbwrg,nynbwrgh,Горад Нінбург,Нийнбург,Нинбург,نينبورغ,نینبورگ,ニーンブルク/ヴェーザー,宁布尔格', 52.6461000, 9.2208600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33619, 'Nienburg/Saale', 'Nienburg/Saale', 'Nienburg,Nienburg (Saale)', 51.8374700, 11.7697900, 'DE', '2017-07-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33620, 'Nienborstel', 'Nienborstel', 'Nienborstel', 54.1333300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33621, 'Niemegk', 'Niemegk', 'Niemegk,Nimeg,Nimegk,Nimek,ni mei ge ke,nymghk,nymgk,Нимег,Нимегк,Нимек,Նիմեգկ,نيمغك,نیمگک,尼梅格克', 52.0738800, 12.6894700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33622, 'Niemberg', 'Niemberg', 'Niemberg', 51.5503500, 12.0908900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33623, 'Niehl', 'Niehl', '', 49.9577400, 6.3552500, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33624, 'Nieheim', 'Nieheim', 'Nieheim,Nigajm,Nikhajm,ni hai mu,nihaimu,nyhaym,Нихайм,Нихајм,Нігайм,نيهايم,نیهایم,ニーハイム,尼海姆', 51.8049900, 9.1130200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33625, 'Niederzissen', 'Niederzissen', 'Nidercisen,Nidercissen,nidatsu~issen,xia qi sen,Нидерцисен,Нидерциссен,ニーダーツィッセン,下齐森', 50.4587600, 7.2181000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33626, 'Niederzimmern', 'Niederzimmern', '', 51.0047600, 11.1902800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33627, 'Niederzier', 'Niederzier', 'Nidercir,Niederzier,xia qi er,Нидерцир,Нідерцир,下齐尔', 50.8833300, 6.4666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33628, 'Niederwörresbach', 'Niederworresbach', 'Niderveresbakh,Nidervjorresbakh,xia wei lei si ba he,Нидервересбах,Нидервёрресбах,下韦雷斯巴赫', 49.7666700, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33629, 'Niederwinkling', 'Niederwinkling', '', 48.8833300, 12.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33630, 'Nieder-Wiesen', 'Nieder-Wiesen', '', 49.7333300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33631, 'Niederwiesa', 'Niederwiesa', 'Nidervisa,Niderviza,Niederwiesa,Niederwiesa vald,xia wei sa,Нидервиза,Нидервиса,下维萨', 50.8666700, 13.0166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33632, 'Niederwerth', 'Niederwerth', 'Nidervert,xia wei er te,Нидерверт,下韦尔特', 50.4000000, 7.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33633, 'Niederwerrn', 'Niederwerrn', 'Nidervern,Niderverrn,nydrwrn,xia wei er en,Нидерверн,Нідерверрн,نیدرورن,下韦尔恩', 50.0614900, 10.1827000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33634, 'Niederweis', 'Niederweis', 'Niederweis', 49.8699700, 6.4671700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33635, 'Niederweiler', 'Niederweiler', '', 50.0333300, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33636, 'Niederweiler', 'Niederweiler', '', 49.9000000, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33637, 'Niederwambach', 'Niederwambach', '', 50.6333300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33638, 'Niederwallmenach', 'Niederwallmenach', '', 50.1666700, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33639, 'Niederviehbach', 'Niederviehbach', 'Niderfibakh,Niderfibax,Nidervikhbakh,nydrfybakh,xia fei he ba he,Нидервихбах,Нидерфибах,Нідерфібах,Նիդերֆիբախ,نیدرفیباخ,下菲赫巴赫', 48.6166700, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33640, 'Niedertiefenbach', 'Niedertiefenbach', '', 50.2553800, 7.8970200, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33641, 'Niedertaufkirchen', 'Niedertaufkirchen', 'Nidertaufkirkhen,nydrtawf kyrshn,xia tao fu ji xing,Нидертауфкирхен,Нідертауфкірхен,Նիդերթաուֆկիրխեն,نیدرتاوف کیرشن,下陶夫基兴', 48.3333300, 12.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33642, 'Niedert', 'Niedert', '', 50.1333300, 7.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33643, 'Niederstriegis', 'Niederstriegis', 'Niederstriegis', 51.0824300, 13.1492500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33644, 'Niederstotzingen', 'Niederstotzingen', 'Nidershtotcingen,Niderstocingen,Niderstotsingen,Niderştotsingen,nydrshtwtsnghn,nydrztwtsngn,xia si tuo qin gen,Нидерстоцинген,Нидерштотцинген,Нідерштотцинген,نيدرشتوتسنغن,نیدرزتوتسنگن,下斯托钦根', 48.5412700, 10.2350500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33645, 'Niederstetten', 'Niederstetten', 'Nidershteten,Nidershtetten,Niederstetten,nidashutetten,nydrashttn,nydrshtytn,xia si te teng,Нидерштетен,Нидерштеттен,Нідерштеттен,نيدرشتيتن,نیدراشتتن,ニーダーシュテッテン,下斯特滕', 49.4000000, 9.9194400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33646, 'Niedersteinebach', 'Niedersteinebach', '', 50.6001800, 7.5069200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33647, 'Niederstedem', 'Niederstedem', '', 49.9333300, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33648, 'Niederstaufenbach', 'Niederstaufenbach', 'Nidershtaufenbakh,Niderstaufenbakh,xia si tao fen ba he,Нидерстауфенбах,Нидерштауфенбах,下斯陶芬巴赫', 49.5333300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33649, 'Niederstadtfeld', 'Niederstadtfeld', '', 50.1605100, 6.7597000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33650, 'Niedersohren', 'Niedersohren', '', 49.9333300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33651, 'Niederschönhausen', 'Niederschonhausen', 'Berlin-Niederschonhausen,Berlin-Niederschönhausen,Nidershjonkhauzen,Нидершёнхаузен', 52.5848300, 13.4027200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33652, 'Niederschöneweide', 'Niederschoneweide', 'Berlin-Niederschoneweide,Berlin-Niederschöneweide,Niederschoneweide,Niederschöneweide', 52.4556400, 13.5155400, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33653, 'Niederschönenfeld', 'Niederschonenfeld', 'Nidershenenfel''d,Nidershenenfeld,Nidershjonenfel''d,Nidersyonenfeld,nidashenenferuto,xia she nen fei er de,Нидершененфелд,Нидершёненфельд,Нідершененфельд,Նիդերշյոնենֆելդ,ニーダーシェーネンフェルト,下舍嫩费尔德', 48.7166700, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33654, 'Niederschöna', 'Niederschoena', '', 50.9667100, 13.4191000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33655, 'Niederschlettenbach', 'Niederschlettenbach', '', 49.0833300, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33656, 'Niederscheidweiler', 'Niederscheidweiler', '', 50.0666700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33657, 'Niedersayn', 'Niedersayn', '', 50.5302800, 7.8319400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33658, 'Niedersachswerfen', 'Niedersachswerfen', 'Niedersachswerfen,Saswerp [a. 1235]', 51.5506200, 10.7659400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33659, 'Niederroßla', 'Niederrossla', 'Niderosla,Niderrosla,ni de luo si la,Нидеросла,Нидерросла,尼德罗斯拉', 51.0333300, 11.4833300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33660, 'Niederroßbach', 'Niederrossbach', 'Niederrossbach,Niederroßbach', 50.6416700, 8.0344400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33661, 'Niederrieden', 'Niederrieden', '', 48.0576000, 10.1832100, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33662, 'Niederreißen', 'Niederreissen', '', 51.0989400, 11.4110600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33663, 'Niederraden', 'Niederraden', '', 49.9833300, 6.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33664, 'Niederpierscheid', 'Niederpierscheid', '', 50.0833300, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33665, 'Niederotterbach', 'Niederotterbach', '', 49.0602800, 8.0455600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33666, 'Niederorschel', 'Niederorschel', 'Niderorshel,Niderorshel'',Niederorschel,ni de luo er she er,Нидероршел,Нидероршель,尼德罗尔舍尔', 51.3722200, 10.4237200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33667, 'Nieder-Olm', 'Nieder-Olm', 'Nider-Ol''m,Nider-Olm,nida=orumu,nydr-alm,nydr-awlm,xia ao er mu,Нидер-Олм,Нидер-Ольм,نيدر-أولم,نیدر-الم,ニーダー＝オルム,下奥尔姆', 49.9116600, 8.2053300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33668, 'Niederöfflingen', 'Niederofflingen', 'Nidereflingen,Niderjoflingen,Niederoefflingen,Niederöfflingen,ni de lei fu lin gen,Нидерефлинген,Нидерёфлинген,尼德勒夫林根', 50.0666700, 6.8833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33669, 'Niedernwöhren', 'Niedernwohren', 'Niedernwoehren,Niedernwöhren', 52.3521400, 9.1478800, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33670, 'Niedernhausen', 'Niedernhausen', 'Niderngauzen,Nidernkhauzen,Niedernhausen,xia en hao sen,Нидернхаузен,Нідернгаузен,下恩豪森', 50.1630700, 8.3133800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33671, 'Niedernhall', 'Niedernhall', '', 49.2951600, 9.6160400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33672, 'Niederneisen', 'Niederneisen', '', 50.3333300, 8.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33673, 'Niederndodeleben', 'Niederndodeleben', 'Nedderndo''lae,Nedderndo''lä,Niderndodeleben,Niederndodeleben,Нидерндоделебен', 52.1341600, 11.5008500, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33674, 'Niedernberg', 'Niedernberg', 'Nidernberg,Niedernberg,ni deng bei ge,niderunberuku,Нидернберг,Нідернберг,Նիդերնբերգ,ニーデルンベルク,尼登贝格', 49.9122200, 9.1369400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33675, 'Niedermurach', 'Niedermurach', 'Nidermurakh,nydrmwrakh,xia mu la,Нидермурах,Нідермурах,نیدرموراخ,下穆拉', 49.4499900, 12.3761000, 'DE', '2012-09-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33676, 'Niedermoschel', 'Niedermoschel', '', 49.7333300, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33677, 'Niedermohr', 'Niedermohr', '', 49.4589900, 7.4695500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33678, 'Niedermerz', 'Niedermerz', '', 50.8815100, 6.2665100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33679, 'Niederlauer', 'Niederlauer', '', 50.2941100, 10.1771200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33680, 'Niederlauch', 'Niederlauch', '', 50.1666700, 6.4333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33681, 'Niederlangen', 'Niederlangen', '', 52.8571200, 7.2819900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33682, 'Niederkumbd', 'Niederkumbd', '', 50.0166700, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33683, 'Niederkrüchten', 'Niederkruchten', 'Niderkrikhten,Niderkrjukhten,Niederkirchen,Niederkruchten,Niederkruechten,Niederkrüchten,nydrkrwkhtn,xia ke lu xi teng,Нидеркрихтен,Нидеркрюхтен,Нідеркрюхтен,نيدركروختن,下克吕希滕', 51.2000000, 6.2166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33684, 'Nieder Kostenz', 'Nieder Kostenz', 'Nider Kostenc,Nider-Kostenc,xia ke si teng ci,Нидер Костенц,Нидер-Костенц,下科斯滕茨', 49.9500000, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33685, 'Niederklein', 'Niederklein', '', 50.7940000, 8.9969400, 'DE', '2016-03-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33686, 'Niederkirchen bei Deidesheim', 'Niederkirchen bei Deidesheim', 'Niederkirchen,Niederkirchen bei Deidesheim', 49.4150000, 8.2100000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33687, 'Niederkirchen', 'Niederkirchen', '', 49.5833300, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33688, 'Niederkassel', 'Niederkassel', 'Neddekaassel,Neddekaaßel,Niderkasel,Niderkassel'',Niederkassel,bonn-niederholtdorf,nydrkasl,xia ka sai er,Нидеркасел,Нидеркассель,Нідеркассель,نيدركاسل,نیدرکاسل,下卡塞尔', 50.8150300, 7.0377700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33689, 'Niederirsen', 'Niederirsen', '', 50.7500000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33690, 'Nieder-Ingelheim', 'Nieder-Ingelheim', 'Ingelheim-Mitte,Nieder-Ingelheim', 49.9775600, 8.0724600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33691, 'Niederhosenbach', 'Niederhosenbach', 'Niderkhozenbakh,xia huo sen ba he,Нидерхозенбах,下霍森巴赫', 49.8000000, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33692, 'Niederhorbach', 'Niederhorbach', '', 49.1152800, 8.0341700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33693, 'Niederhofen', 'Niederhofen', '', 50.5666700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33694, 'Nieder-Hilbersheim', 'Nieder-Hilbersheim', '', 49.9133300, 8.0419400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33695, 'Niederheimbach', 'Niederheimbach', 'Niderkhajmbakh,xia hai mu ba he,Нидерхаймбах,Нидерхајмбах,下海姆巴赫', 50.0333300, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33696, 'Niederhausen an der Appel', 'Niederhausen an der Appel', 'Niederhausen,Niederhausen an der Appel', 49.7500000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33697, 'Niederhausen', 'Niederhausen', 'Niderkhauzen,ni de lao sen,Нидерхаузен,尼德劳森', 49.8000000, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33698, 'Niederhambach', 'Niederhambach', '', 49.6833300, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33699, 'Nieder-Gründau', 'Nieder-Gruendau', 'Niedergruendau,Niedergründau', 50.2109700, 9.1080100, 'DE', '2017-03-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33700, 'Niedergörsdorf', 'Niedergorsdorf', 'Nidergersdorf,Nidergjorsdorf,Nidergyorsdorf,xia ge er si duo fu,Нидергерсдорф,Нидергёрсдорф,Նիդերգյորսդորֆ,下格尔斯多夫', 51.9794300, 12.9854100, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33701, 'Niedergeckler', 'Niedergeckler', '', 49.9666700, 6.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33702, 'Niedergebra', 'Niedergebra', '', 51.4228500, 10.6001100, 'DE', '2013-10-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33703, 'Niederfüllbach', 'Niederfuellbach', 'Niderfilbakh,Niderfjul''bakh,Niderfjull''bakh,Niderfyulbax,Niederfuellbach,Niederfullbach,Niederfüllbach,nidafu~yurubahha,xia fei er ba he,Нидерфилбах,Нидерфюлльбах,Нідерфюльбах,Նիդերֆյուլբախ,ニーダーフュルバッハ,下菲尔巴赫', 50.2200200, 10.9908600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33704, 'Niederfrohna', 'Niederfrohna', '', 50.9000000, 12.7166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33705, 'Niederfischbach', 'Niederfischbach', 'Niderfishbakh,naydrfyshbakh,xia fei shi ba he,Нидерфишбах,نایدرفیشباخ,下菲施巴赫', 50.8500000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33706, 'Niederfinow', 'Niederfinow', 'Niderfinov,xia fei nuo,Нидерфинов,Նիդերֆինով,下菲诺', 52.8336800, 13.9284300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33707, 'Niederfell', 'Niederfell', 'Niderfel,Niderfell'',xia fei er,Нидерфел,Нидерфелль,下费尔', 50.2833300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33708, 'Niedereschach', 'Niedereschach', 'Niderehshakh,Nidereshakh,ni de lei sha,Нидерешах,Нидерэшах,Нідерешах,尼德雷沙', 48.1333300, 8.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33709, 'Niedererbach', 'Niedererbach', '', 50.4261000, 7.9742500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33710, 'Niederelbert', 'Niederelbert', '', 50.4077500, 7.8099000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33711, 'Niederdürenbach', 'Niederdurenbach', '', 50.4500000, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33712, 'Niederdreisbach', 'Niederdreisbach', '', 50.7495500, 7.9235200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33713, 'Niederdorla', 'Niederdorla', 'Niderdorla,Niederdorla,xia duo er la,Нидердорла,下多尔拉', 51.1602500, 10.4482000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33714, 'Niederdorfelden', 'Niederdorfelden', 'Niderdorfel''den,Niderdorfelden,nidadoruferuden,xia duo er fei er deng,Нидердорфелден,Нидердорфельден,Нідердорфельден,ニーダードルフェルデン,下多尔费尔登', 50.1941500, 8.8000500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33715, 'Niederdorf', 'Niederdorf', '', 50.7262300, 12.7858700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33716, 'Niedercunnersdorf', 'Niedercunnersdorf', 'Cunnersdorf,Neider Cunnersdorf,Niedercunnersdorf', 51.0539800, 14.6583000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33717, 'Niederburg', 'Niederburg', '', 50.1166700, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33718, 'Niederbrombach', 'Niederbrombach', '', 49.6833300, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33719, 'Niederbreitbach', 'Niederbreitbach', 'Niderbrajtbakh,xia bu lai te ba he,Нидербрайтбах,Нидербрајтбах,下布赖特巴赫', 50.5305100, 7.4209900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33720, 'Niederbösa', 'Niederbosa', 'Niederbosa,Niederbösa', 51.2666700, 11.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33721, 'Niederbiel', 'Niederbiel', '', 50.5550500, 8.3984500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33722, 'Niederbergkirchen', 'Niederbergkirchen', '', 48.3166700, 12.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33723, 'Niederbachheim', 'Niederbachheim', '', 50.2481800, 7.7657700, 'DE', '2012-06-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33724, 'Niederaula', 'Niederaula', 'Nideraula,Niederaula,xia ao la,Нидераула,Нідераула,下奥拉', 50.8000000, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33725, 'Niederau', 'Niederau', 'Niderau,Niederau vald,Нидерау,Нідерау', 51.1773000, 13.5456300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33726, 'Aschau im Chiemgau', 'Aschau im Chiemgau', 'Aschau,Aschau im Cheamgau,Aschau im Chiemgau,Ashau im Kimgau,Ashau-im-Khimgau,Ashau-im-Kimgau,Kimgaui Asau,Niederaschau,Niederaschau im Chiemgau,ashaw aym shymgaw,Ашау им Кимгау,Ашау-им-Кимгау,Ашау-им-Химгау,Ашау-ім-Кімгау,Կիմգաուի Աշաու,آشاو ایم شیمگاو', 47.7768900, 12.3229700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33727, 'Niederalteich', 'Niederalteich', 'Altaha inferior,Niadaoida,Nideral''tajkh,Nideraltajkh,Niederaltaich,ni de la er tai xi,nydraltaysh,Нидералтајх,Нидеральтайх,Нідеральтайх,Նիդերալթայխ,نیدرالتایش,尼德拉尔泰希', 48.7656400, 13.0241200, 'DE', '2013-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33728, 'Niederalben', 'Niederalben', 'Nideral''ben,Nideralben,ni de la er ben,Нидералбен,Нидеральбен,尼德拉尔本', 49.6000000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33729, 'Niederaichbach', 'Niederaichbach', 'Niderajkhbakh,Niderayxbax,nydrayshbakh,xia ai xi ba he,Нидерайхбах,Нидерајхбах,Нідерайхбах,Նիդերայխբախ,نیدرایشباخ,下艾希巴赫', 48.6000000, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33730, 'Niederahr', 'Niederahr', '', 50.4919400, 7.8611100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33731, 'Niedenstein', 'Niedenstein', 'Nidenshtajn,Niedenstein,Niederstein,ni deng si tai yin,nidenshutain,nydnshtayn,Ниденштайн,Ниденштајн,Ніденштайн,نيدنشتاين,نیدن‌اشتاین,ニーデンシュタイン,尼登斯泰因', 51.2334200, 9.3102900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33732, 'Nieby', 'Nieby', '', 54.7666700, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33733, 'Niebüll', 'Niebuell', 'Naibel,Nibil,Nibjull'',Nibol,Nibøl,Niebuell,Niebull,Niebüll,ni bi er,nybwl,Нибил,Нибюлль,نيبول,نیبول,尼比尔', 54.7866300, 8.8285400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33734, 'Nieblum', 'Nieblum', 'Niblum,Njiblem,ni bu lu mu,Ниблум,尼布卢姆', 54.6918900, 8.4908900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33735, 'Nideggen', 'Nideggen', 'Nidegen,Nideggen,ni de gen,nydgn,nydyghn,Нидегген,Нидеген,Нідегген,نيديغن,نیدگن,尼德根', 50.6926800, 6.4843700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33736, 'Nidderau', 'Nidderau', 'Nidderau,Niderau,ni de lao,nidderau,nydraw,Ниддерау,Нидерау,Ніддерау,نيدراو,نیدراو,ニッデラウ,尼德劳', 50.2380500, 8.8670400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33737, 'Nidda', 'Nidda', 'Nida,Nidda,ni da,nyda  hsn,Нида,Нидда,نیدا، هسن,尼达', 50.4133000, 9.0063800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33738, 'Nickenich', 'Nickenich', 'Nikenikh,Nikkenikh,ni ke ni xi,Никених,Никкених,尼克尼希', 50.4142100, 7.3272800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33739, 'Ney', 'Ney', '', 50.1833300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33740, 'Newel', 'Newel', '', 49.8124000, 6.5830400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33741, 'Neversdorf', 'Neversdorf', 'Neversdorf', 53.8666700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33742, 'Neverin', 'Neverin', 'Neferin,Neverin,nei fei lin,Неферин,内费林', 53.6206700, 13.3366000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33743, 'Neuzelle', 'Neuzelle', 'Nojcele,Nojcelle,Nowa Cala,xin ce lei,Нойцелле,Нојцеле,Նոյցելլե,新策勒', 52.0901600, 14.6480400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33744, 'Neu Zauche', 'Neu Zauche', 'Neu Zauche/Nowa Niwa,Noj Caukhe,Noj-Caukhe,Nowa Niwa,Noy Zauxe,xin cao hei,Ной-Цаухе,Ној Цаухе,Նոյ Զաուխե,新曹黑', 51.9275700, 14.0881200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33745, 'Neu Wulmstorf', 'Neu Wulmstorf', 'Noj Vulmstorf,Noj-Vul''mstorf,Vosshusen,xin wu er mu si tuo fu,Ной-Вульмсторф,Ној Вулмсторф,新武尔姆斯托夫', 53.4666700, 9.8000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33746, 'Neuwittenbek', 'Neuwittenbek', 'Neuwittenbek', 54.3666700, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33747, 'Winsen (Aller)', 'Winsen (Aller)', '', 52.6836700, 9.9095000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33748, 'Neuwied', 'Neuwied', 'Neuweid,Neuwied,Nojvid,ZOU,noivu~ito,nwyfyd,nwywwyd,nwywyd,xin wei de,Нойвид,Нойвід,Нојвид,נויוויד,نويفيد,نویوید,ノイヴィート,新維德', 50.4336000, 7.4705700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33749, 'Neuweiler', 'Neuweiler', 'Neuweiler,Nojvajler,Novumvillare,Noyvayler,xin wei lei,Нойвайлер,Нојвајлер,Նոյվայլեր,新魏勒', 48.6666700, 8.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33750, 'Neu-Ulm', 'Neu-Ulm', 'Gorad Noj-Ul''m,Nei-Ulm,Neu Ulm,Neu-Ulm,Noea Ulma,Noj-Ul''m,Noj-Ulm,Nova Ulma,Noy Owlm,Nuevo Ulm,Nuova Ulma,Nöa Ulma,Subdistrikto Neu-Ulm,ZOT,noiulleum,noiurumu,nwy-awlm,xin wu er mu,Горад Ной-Ульм,Ной-Ульм,Ној-Улм,Նոյ Ուլմ,נוי-אולם,نوي-أولم,نوی-اولم,ノイウルム,新乌尔姆,노이울름', 48.3927900, 10.0111200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33751, 'Neutrebbin', 'Neutrebbin', 'Nojtrebbin,Nojtrebin,Noytrebin,xin te lei bin,Нойтреббин,Нојтребин,Նոյտրեբին,新特雷宾', 52.6648200, 14.2280200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33752, 'Neutraubling', 'Neutraubling', 'Neutraubling,Nojtraubling,nwytrawblyng,nwytrawblyngh,xin te lao bu ling,Нойтраублинг,Нойтраублінг,Нојтраублинг,Նոյթրաուբլինգ,نويتراوبلينغ,نویتراوبلینگ,新特劳布灵', 48.9873700, 12.2010000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33753, 'Neustrelitz', 'Neustrelitz', 'Neistrelica,Neištrēlica,Neustrelitz,Nieg Strelitz,Nojshtrelic,Nojshtrelice,Nojstrelic,Nojštrelic,Stadt Neustrelitz,nuo yi si te lei li ci,nwyshtrylytz,nwystrlyz,Нойштрелиц,Нойштрелице,Нојштрелиц,נוישטרליץ,نويشتريليتز,نوی‌اشترلیتز,诺伊斯特雷利茨', 53.3613000, 13.0729200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33754, 'Neustadt in Holstein', 'Neustadt in Holstein', 'Neustadt,Neustadt en Holstein,Niestadt in Holsteen,Nojshtadt,Nojshtat in Kholshtajn,huo er si tai yin de qu nuo yi si ta te,Нойштадт,Нојштат ин Холштајн,نوی‌اشتات این هل‌اشتاین,霍尔斯泰因地区诺伊斯塔特', 54.1070700, 10.8145000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33755, 'Neustadt-Glewe', 'Neustadt-Glewe', 'Neistate-Gleve,Neištate-Glēve,Neustadt in Mecklenburg,Neustadt-Glewe,Nojshtadt-Gleve,Nojshtat-Gleve,QGW,nuo yi si ta te-ge lai wei,nwyshtat-ghlyfh,Нойштадт-Глеве,Нојштат-Глеве,نويشتات-غليفه,نوی‌اشتات-گلوه,诺伊斯塔特-格莱韦', 53.3784600, 11.5926400, 'DE', '2016-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33756, 'Neustadt bei Coburg', 'Neustadt bei Coburg', 'Neustadt,Neustadt b.Coburg,Neustadt bei Coburg,Nojshtadt-Koburg,Nojshtadt-baj-Koburg,Nojshtat baj Koburg,ke bao fu jin nuo yi si ta te,nwyshtat bay kwbwrgh,Нойштадт-Кобург,Нойштадт-бай-Кобург,Нојштат бај Кобург,Նոյշթաթ Կոբուրգ,نويشتات باي كوبورغ,نوی‌اشتات بای کبورگ,ノイシュタット・バイ・コーブルク,科堡附近诺伊斯塔特', 50.3297500, 11.1205800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33757, 'Neustadt', 'Neustadt', 'Naischdadt,Neustadt,Neustadt an der Haardt,Neustadt an der Weinstrasse,Neustadt an der Weinstraße,Neustadt ce la Vinstrato,Neustadt ĉe la Vinstrato,Nojshhat an der Vajnshhrase,Nojshtadt-an-der-Vajnshtrase,Nojshtadt-an-der-Vajnshtrasse,Nojshtat an der Vajnshtrase,pu tao jiu zhi lu shang de xin cheng,Нойштадт-ан-дер-Вайнштрасе,Нойштадт-ан-дер-Вайнштрассе,Нойщат ан дер Вайнщрасе,Нојштат ан дер Вајнштрасе,نوی‌اشتات آن در واین‌اشترایه,葡萄酒之路上的新城', 49.3500900, 8.1388600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33758, 'Neustadt an der Waldnaab', 'Neustadt an der Waldnaab', 'Naistadl,Neustadel,Neustadt,Neustadt a.d.Waldnaab,Neustadt an der Waldnaab,Nojshtadt-an-der-Val''dnaab,Nojshtadt-na-Val''dnabe,Nojshtat na Valdnabu,nwyshtat an dr faldnab,Нойштадт-ан-дер-Вальднааб,Нойштадт-на-Вальднабе,Нојштат на Валднабу,Վալդնաբի Նոյշթաթ,نويشتات أن در فالدناب,نوی‌اشتات آن در والدناب', 49.7328700, 12.1777300, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33759, 'Neustadt an der Donau', 'Neustadt an der Donau', 'Danubi Noystadt,Neistod an da Doana,Neustadt,Neustadt a.d.Donau,Neustadt an der Donau,Nojshtadt-an-der-Donau,Nojshtadt-na-Dunae,Nojshtat na Dunavu,nwyshtat an dr dwnaw,Нойштадт-ан-дер-Донау,Нойштадт-на-Дунае,Нојштат на Дунаву,Դանուբի Նոյշտադտ,نويشتات أن در دوناو,نوی‌اشتات آن در دانوب', 48.8070500, 11.7695200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33760, 'Neustadt an der Aisch', 'Neustadt an der Aisch', 'Gorad Nojshtat-na-Ajshy,Neustadt,Neustadt an der Aisch,Nojshtadt-an-der-Ajsh,Nojshtadt-na-Ajshe,Nojshtadt-na-Ajshi,Nojshtat an der Ajsh,ai shi he pan nuo yi si ta te,nwyshtat an dr aysh,nyystʼt ʼn dʻr ʼyys,Горад Нойштат-на-Айшы,Нойштадт-ан-дер-Айш,Нойштадт-на-Айше,Нойштадт-на-Айші,Нојштат ан дер Ајш,Այշի Նոյշթաթ,ניישטאט אן דער אײש,نويشتات أن در آيش,نوی‌اشتات آن در آیش,艾施河畔诺伊斯塔特', 49.5795300, 10.6112600, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33761, 'Neustadt am Rübenberge', 'Neustadt am Ruebenberge', 'Neustadt,Neustadt am Rubenberge,Neustadt am Ruebenberge,Neustadt am Rübenberge,Niestadt,Nojshhat am Rjubenberge,Nojshtadt-am-Rjubenberge,Nojshtat am Ribenberge,lu ben shan lu nuo yi shi ta te,nwyshtat am rwbnbrghh,Нойштадт-ам-Рюбенберге,Нойщат ам Рюбенберге,Нојштат ам Рибенберге,نويشتات آم روبنبرغه,نوی‌اشتات آم روبنبرگه,吕本山麓诺伊施塔特', 52.5046200, 9.4587100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33762, 'Neustadt am Rennsteig', 'Neustadt am Rennsteig', 'Neustadt,Neustadt am Rennsteig,Nojshtadt-am-Renshtajg,Nojshtat am Renshtajg,Nojshtat na Renshtajg,lun si tai xi de qu nuo yi si ta te,Нойштадт-ам-Ренштайг,Нојштат ам Ренштајг,Нојштат на Ренштајг,伦斯泰希地区诺伊斯塔特', 50.5833300, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33763, 'Neustadt am Main', 'Neustadt am Main', 'Neustadt,Neustadt a. Main,Neustadt am Main,Neustadt ce Majno,Neustadt ĉe Majno,Nojshtadt-am-Majn,Nojshtadt-na-Majne,Nojshtat na Majni,mei yin he pan nuo yi si ta te,Нойштадт-ам-Майн,Нойштадт-на-Майне,Нојштат на Мајни,Մայնի Նոյշթաթ,美因河畔诺伊斯塔特', 49.9302100, 9.5680800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33764, 'Neustadt', 'Neustadt', '', 53.5519600, 9.9855800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33765, 'Neue Neustadt', 'Neue Neustadt', 'Hieronymusstadt,Magdeburg-Neustadt,Neue Neustadt,Nojshtadt,Нойштадт', 52.1500000, 11.6333300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33766, 'Neustadt/Harz', 'Neustadt/Harz', 'Neustadt,Nojshtadt,Nojshtat,Нойштадт,Нојштат', 51.5666700, 10.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33767, 'Neustadt in Sachsen', 'Neustadt in Sachsen', 'Neistate Saksija,Neištate Saksijā,Neustadt en Saksio,Neustadt i Sachsen,Neustadt i. Sa.,Neustadt in Sachsen,Nojshhat,Nojshtadt,Nojshtat in Zakhsen,Nojshtat vo Saksonija,nwyshtat an zaksn,nwy‌ashtat ayn zaksn,Нойштадт,Нойщат,Нојштат во Саксонија,Нојштат ин Захсен,نويشتات إن زاكسن,نوی‌اشتات این زاکسن', 51.0284400, 14.2178500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33768, 'Neustadt (Hessen)', 'Neustadt (Hessen)', 'Neustadt in Hessen,Nojshtadt,Нойштадт', 50.8500000, 9.1166700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33769, 'Neustadt/Westerwald', 'Neustadt/Westerwald', '', 50.6296500, 8.0402300, 'DE', '2017-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33770, 'Neustadt Vogtland', 'Neustadt Vogtland', 'Neustadt Vogtl.,Neustadt/Vogtl.,Neustadt/Vogtland', 50.4610000, 12.3322400, 'DE', '2015-11-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33771, 'Neuss', 'Neuss', 'Gorad Nojs,Neuss,Neuß,Noisas,Nojs,Novaesium,Nuess,Nueuess,Nuus,Nüss,Nüüß,noiseu,noisi,noisu,nuo yi si,nwys,nyws,Горад Нойс,Нойс,Нојс,نويس,نویس,نیوس,ნოისი,ノイス,诺伊斯,노이스', 51.1980700, 6.6850400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33772, 'Neusorg', 'Neusorg', 'Nojsorg,Nojzorg,nuo yi suo er ge,Нойзорг,Нојсорг,诺伊索尔格', 49.9333300, 11.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33773, 'Neusitz', 'Neusitz', 'Nojzic,noijittsu,nuo yi xi ci,Нойзиц,Нойзіц,Нојзиц,Նոյզից,ノイジッツ,诺伊西茨', 49.3718500, 10.2255900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33774, 'Neusiß', 'Neusiss', 'Neusiss,Neusiß,Nojzis,nuo yi xi si,Нойзис,Нојзис,诺伊西斯', 50.7500000, 10.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33775, 'Neuschönau', 'Neuschonau', 'Neuschoenau,Neuschönau,Nojshenau,Nojshjonau,Noysenau,nuo yi she nao,nwyshwnaw,Нойшенау,Нойшёнау,Нојшенау,Նոյշենաու,نویشوناو,诺伊舍瑙', 48.8841900, 13.4757600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33776, 'Neusalza-Spremberg', 'Neusalza-Spremberg', 'Neizalca-Spremberga,Neizalca-Špremberga,Neusalza,Neusalza-Spremberg,Nojsalca-Shpremberg,Nojzal''ca-Shpremberg,Nojzalca-Shpremberg,Nowosolc-Hrodk,Nowosólc-Hródk,nwyzalsa-ashprmbrg,nwyzaltsa-shbrmbrgh,xin sa er cha-si pu lun bei ge,Нойзалца-Шпремберг,Нойзальца-Шпремберг,Нојзалца-Шпремберг,Нојсалца-Шпремберг,نويزالتسا-شبرمبرغ,نویزالسا-اشپرمبرگ,新萨尔察-斯普伦贝格', 51.0394500, 14.5356000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33777, 'Neuruppin', 'Neuruppin', 'Neuruppin,Neuruppino,Nojrupin,Nojruppin,Reppin,Rupina,noilupin,nuo yi lu ping,nwyrwpyn,Нойрупин,Нойруппин,Нойруппін,Нојрупин,نویروپین,诺伊鲁平,노이루핀', 52.9281500, 12.8031100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33778, 'Neuried', 'Neuried', '', 48.0932200, 11.4656100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33779, 'Neureichenau', 'Neureichenau', 'Nojrajkhenau,Noyrayxenau,nuo yi lai xie nao,nwyrayshnaw,Нойрайхенау,Нојрајхенау,Նոյրայխենաու,نویرایشناو,诺伊赖歇瑙', 48.7486100, 13.7469900, 'DE', '2011-07-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33780, 'Neupotz', 'Neupotz', 'Nojpoc,nuo yi bo ci,Нойпоц,Нојпоц,诺伊波茨', 49.1177800, 8.3194400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33781, 'Neupetershain', 'Neupetershain', 'Nojpeterskhajn,Nowe Wiki,Noypetershayn,xin pei te er si hai en,Нойпетерсхайн,Нојпетерсхајн,Նոյպետերսհայն,新佩特尔斯海恩', 51.6080000, 14.1650700, 'DE', '2013-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33782, 'Neuötting', 'Neuotting', 'Neiaeding,Neiäding,Neu Oetting,Neuoetting,Neuotting,Neuötting,Nojehtting,Nojeting,Nojetting,Nojjotting,Noyoting,nuo yi e ting ge,nwyawtyng,nwyawtyngh,Нойеттінг,Нойэттинг,Нойёттинг,Нојетинг,Նոյոտինգ,نوياوتينغ,نویاوتینگ,诺伊厄廷格', 48.2410200, 12.6899800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33783, 'Neunkirchen am Sand', 'Neunkirchen am Sand', 'Neunkirchen,Neunkirchen am Sand', 49.5246400, 11.3195500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33784, 'Neunkirchen am Potzberg', 'Neunkirchen am Potzberg', 'Neunkirchen,Neunkirchen am Potzberg,Nojnkirkhen am Pocberg,Nojnkirkhen-am-Pocberg,bo ci bei ge shan lu nuo yin ji xing,Нойнкирхен-ам-Поцберг,Нојнкирхен ам Поцберг,波茨贝格山麓诺因基兴', 49.5000000, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33785, 'Neunkirchen am Main', 'Neunkirchen am Main', 'Neunkirchen,Neunkirchen am Main', 49.9230000, 11.6479300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33786, 'Neunkirchen', 'Neunkirchen', 'Neunkirchen,Nojnkirkhen,xin ji xing,Нойнкирхен,Нойнкірхен,Нојнкирхен,新基兴', 50.8000000, 8.0000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33787, 'Neunkirchen', 'Neunkirchen', '', 50.5469400, 8.1038900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33788, 'Neunkirchen', 'Neunkirchen', 'Nojnkirkhen,noinkiruhyen,Нойнкирхен,Нойнкірхен,Нојнкирхен,ノインキルヒェン', 49.8000000, 9.4000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33789, 'Neunkirchen', 'Neunkirchen', '', 49.7500000, 6.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33790, 'Neunkirchen', 'Neunkirchen', '', 49.3869400, 9.0105600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33791, 'Neunkirchen', 'Neunkirchen', 'Neunkirchen,Noinkirchenas,Nojnkirkhen,noinkiruhyen,nuo yin ji xing,nwykyrshn,nwynqyrkn,nxyn kheiyr chein,Нойнкирхен,Нойнкірхен,Нојнкирхен,נוינקירכן,نویکیرشن,นอยน์เคียร์เชิน,ノインキルヒェン,諾因基興', 49.3444900, 7.1804500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33792, 'Neunkhausen', 'Neunkhausen', '', 50.7072200, 7.9027800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33793, 'Neunheilingen', 'Neunheilingen', '', 51.1923900, 10.6752900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33794, 'Neundorf', 'Neundorf', 'Neundorf', 51.8208000, 11.5748400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33795, 'Neunburg vorm Wald', 'Neunburg vorm Wald', 'Neuburg,Neunburg vorm Wald,Nojnburg vorm Vald,Nojnburg-form-Val''d,nuo yin bu er ge fu er mu wa er de,nwynbwrg frm wald,Нойнбург-форм-Вальд,Нојнбург ворм Валд,نوینبورگ فرم والد,诺因布尔格福尔姆瓦尔德', 49.3478200, 12.3862100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33796, 'Neumünster', 'Neumuenster', 'EUM,Naimuenster,Naimünster,Neumuenster,Neumunster,Neumünster,Niemuenster,Niemünster,Nojminster,Nojmjunster,Novum Monasterium,noimwinseuteo,noimyunsuta,nywmnstr,xin ming si te,Ноймюнстер,Нојминстер,نوی‌مونستر,نیومنستر,ノイミュンスター,新明斯特,노이뮌스터', 54.0747700, 9.9819500, 'DE', '2017-01-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33797, 'Neumühle', 'Neumuehle', '', 53.6317100, 11.3708500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33798, 'Neumarkt-Sankt Veit', 'Neumarkt-Sankt Veit', 'Neumarkt,Neumarkt Sankt Beit,Neumarkt an der Rott,Neumarkt-Sankt Veit,Neumarkt-Sankt Viet,Nojmarkt-Sankt Fajt,Nojmarkt-Sankt-Fajt,Nojmarkt-Zankt-Fajt,nuo yi ma er ke te-sheng fa yi te,nwymark-znkt fayt,nwymarkt-zankt fayt,Ноймаркт-Занкт-Файт,Ноймаркт-Санкт-Файт,Нојмаркт-Санкт Фајт,Նոյմարքթ Սանքթ Ֆայթ,نويماركت-زانكت فايت,نویمارک-زنکت فایت,诺伊马尔克特-圣法伊特', 48.3605100, 12.5072300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33799, 'Neumarkt in der Oberpfalz', 'Neumarkt in der Oberpfalz', 'Aukstutinio Pfalco Noimarktas,Aukštutinio Pfalco Noimarktas,Neumarkt,Neumarkt i.d.OPf.,Neumarkt in der Oberpfalz,Nojmarkt,Nojmarkt in der Oberpfalc,Nojmarkt-in-der-Oberpfal''c,Stadt Neumarkt in der Oberpfalz,nuo yi ma ke te,nwymarkt an dr awbrfalts,nwymarkt ayn dr awbrfaltz,Ноймаркт,Ноймаркт-ин-дер-Оберпфальц,Нојмаркт ин дер Оберпфалц,Նոյմարքթ,نويماركت إن در أوبرفالتس,نویمارکت این در اوبرفالتز,诺伊马克特', 49.2802800, 11.4627800, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33800, 'Neumark', 'Neumark', 'Brandeburgo Oriental,Brandenburg Oriental,Nojmark,Nouvelle Marche,Nowa Marchia,nuo yi ma er ke,nwymark,Ноймарк,نويمارك,نوی‌مارک,诺伊马尔克', 50.6601000, 12.3561900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33801, 'Neulußheim', 'Neulussheim', 'Nailosse,Neulussheim,Neulußheim,Nojlusgajm,Nojluskhajm,noirusuhaimu,nuo yi lu si hai mu,Нойлусгайм,Нойлусхайм,Нојлусхајм,ノイルスハイム,诺伊卢斯海姆', 49.2980600, 8.5183300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33802, 'Neulewin', 'Neulewin', 'Nojlevin,Noylevin,nuo yi lai wen,Нойлевин,Нојлевин,Նոյլևին,诺伊莱温', 52.7243400, 14.2792200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33803, 'Neuler', 'Neuler', 'Nojler,noileri,nuo yi lai er,Нойлер,Нојлер,ნოილერი,诺伊莱尔', 48.9280300, 10.0688800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33804, 'Neuleiningen', 'Neuleiningen', 'Nojlajningen,xin lai ning gen,Нойлайнинген,Нојлајнинген,新莱宁根', 49.5416700, 8.1388900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33805, 'Neulehe', 'Neulehe', 'Nojleeh,Nojlekhe,nuo yi lai e,Нойлеэ,Нојлехе,诺伊莱厄', 53.0044900, 7.4142800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33806, 'Neukloster', 'Neukloster', 'Neiklostere,Neukloster,Nojkloster,nuo yi ke luo si te er,nwyklwstr,Нойклостер,Нојклостер,نويكلوستر,نویکلوستر,诺伊克洛斯特尔', 53.8654800, 11.6851200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33807, 'Neukirchen vorm Wald', 'Neukirchen vorm Wald', 'Neukirchen,Neukirchen vorm Wald', 48.6833300, 13.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33808, 'Neukirchen-Balbini', 'Neukirchen-Balbini', 'Neukirchen,Neukirchen-Balbini,Nojkirkhen-Bal''bini,Nojkirkhen-Balbini,nuo yi ji er xing-ba er bi ni,nwykyrshn-balbyny,Нойкирхен-Бальбини,Нойкірхен-Бальбіні,Нојкирхен-Балбини,نویکیرشن-بالبینی,诺伊基尔兴-巴尔比尼', 49.2910100, 12.4364300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33809, 'Neukirchen', 'Neukirchen', '', 54.8666700, 8.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33810, 'Neukirchen', 'Neukirchen', 'Nojkirkhen,Нойкирхен,Нојкирхен', 54.3238500, 11.0144000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33811, 'Neukirchen', 'Neukirchen', '', 54.2146500, 10.5538100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33812, 'Neukirchen', 'Neukirchen', 'Neukirchen', 50.8690600, 9.3465500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33813, 'Neukirchen', 'Neukirchen', 'Neukirchen/Pleisse,Neukirchen/Pleiße', 50.8018800, 12.3841600, 'DE', '2017-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33814, 'Neukirchen', 'Neukirchen', 'Neukirchen,Neukirchen/Erzgebirge', 50.7795500, 12.8675500, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33815, 'Neukirchen', 'Neukirchen', 'Neukirchen,Neukirchen b. Hl. Blut', 49.2601500, 12.9692100, 'DE', '2016-02-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33816, 'Neukirchen', 'Neukirchen', 'Neukirchen b. Hl. Blut,Neukirchen-Haggn', 48.9750600, 12.7554700, 'DE', '2016-01-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33817, 'Neukirch', 'Neukirch', '', 51.2833300, 13.9833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33818, 'Neukirch/Lausitz', 'Neukirch/Lausitz', 'Neukirch,Nojkirkh,Wjazonca,Wjazońca,Нойкирх,Нойкірх,Нојкирх', 51.0972700, 14.3078900, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33819, 'Neukirch', 'Neukirch', 'Neukirch', 47.6573800, 9.7033300, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33820, 'Neukieritzsch', 'Neukieritzsch', 'Neukieritzsch,Neukieritzschi vald,Nojkirich,Nojkiricsh,nuo yi ji li ci xi,Нойкирич,Нојкирицш,诺伊基里茨希', 51.1499500, 12.4109000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33821, 'Neu Kaliß', 'Neu Kaliss', '', 53.1746600, 11.2944600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33822, 'Neukalen', 'Neukalen', 'Neikalene,Neikālene,Nojkalen,nu ka lun,nwykaln,Нойкален,Нојкален,نويكالن,نویکالن,努卡倫', 53.8227500, 12.7901500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33823, 'Neu Isenburg', 'Neu Isenburg', 'Neu Isenburg,Neu-Isenburg,Neulsenburg,Noj-Izenburg,Ной-Изенбург', 50.0483200, 8.6940600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33824, 'Neuhütten', 'Neuhutten', 'Neuhuetten,Neuhütten', 50.0000000, 9.4166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33825, 'Neuhütten', 'Neuhuetten', '', 49.6426600, 7.0149700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33826, 'Neuhofen', 'Neuhofen', 'Neuhofen', 49.4277800, 8.4247200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33827, 'Neuhof an der Zenn', 'Neuhof an der Zenn', 'Neuhof,Neuhof an der Zenn,Nojgof-an-der-Cenn,Nojkhof an der Cen,Nojkhof-an-der-Cen,cai en he pan nuo yi huo fu,Нойгоф-ан-дер-Ценн,Нойхоф-ан-дер-Цен,Нојхоф ан дер Цен,Ցենի Նոյխոֆ,采恩河畔诺伊霍夫', 49.4569000, 10.6454800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33828, 'Heringsdorf', 'Heringsdorf', 'HDF,Heringsdorf', 53.9500000, 14.1666700, 'DE', '2017-01-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33829, 'Neuhof', 'Neuhof', '', 51.9833300, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33830, 'Neuhof', 'Neuhof', '', 50.4531300, 9.6175000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33831, 'Neuhemsbach', 'Neuhemsbach', 'Nojehmsbakh,Nojkhemsbakh,xin hei mu si ba he,Нойхемсбах,Нойэмсбах,Нојхемсбах,新黑姆斯巴赫', 49.5166700, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33832, 'Neuheilenbach', 'Neuheilenbach', '', 50.1166700, 6.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33833, 'Neuhaus-Schierschnitz', 'Neuhaus-Schierschnitz', 'Nojkhaus-Shirshnic,nuo yi hao si-xi er shi ni ci,Нойхаус-Ширшниц,Нојхаус-Ширшниц,诺伊豪斯-席尔施尼茨', 50.3123700, 11.2401900, 'DE', '2013-11-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33834, 'Neuhausen ob Eck', 'Neuhausen ob Eck', 'Neuhausen,Nojkhauzen ob Ek,Nojkhauzen-ob-Ehkk,nuo yi hao sen ao bu ai ke,Нойхаузен-об-Экк,Нојхаузен об Ек,诺伊豪森奥布埃克', 47.9725700, 8.9275900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33835, 'Neuhausen auf den Fildern', 'Neuhausen auf den Fildern', 'Neuhausen,Neuhausen auf den Fildern,Nojgauzen-auf-den-Fil''dern,Nojkhauzen auf den Fildern,Nojkhauzen-auf-den-Fil''dern,Noyhauzen auf den Fildern,nuo yi hao sen ao fu deng fei er de er en,Нойгаузен-ауф-ден-Фільдерн,Нойхаузен-ауф-ден-Фильдерн,Нојхаузен ауф ден Филдерн,Նոյհաուզեն աուֆ դեն Ֆիլդերն,诺伊豪森奥夫登菲尔德尔恩', 48.6833300, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33836, 'Neuhausen', 'Neuhausen', 'Khojkhauzen,Neuhausen,Neuhausen/Erzgebirge,Neuhauseni vald,Nojkhauzen,Нойхаузен,Нојхаузен,Хојхаузен', 50.6764700, 13.4675000, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33837, 'Neuhausen', 'Neuhausen', '', 48.7926000, 8.7764900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33838, 'Neuhausen', 'Neuhausen', '', 47.8375400, 8.7744900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33839, 'Neuhäusel', 'Neuhaeusel', 'Neuhaeusel,Neuhäusel', 50.3836000, 7.7096000, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33840, 'Neuhaus an der Pegnitz', 'Neuhaus an der Pegnitz', 'Neuhaus,Neuhaus an der Pegnitz,Nojgaus-an-der-Pegnic,Nojkhaus an der Pegnic,Nojkhaus-na-Pegnice,Нойгаус-ан-дер-Пегніц,Нойхаус-на-Пегнице,Нојхаус ан дер Пегниц,Պեգնիցի Նոյհաուս', 49.6279900, 11.5506600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33841, 'Neuhaus an der Oste', 'Neuhaus an der Oste', 'Neuhaus,Neuhaus (Oste),Neuhaus an der Oste', 53.8004300, 9.0334800, 'DE', '2017-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33842, 'Neuhaus am Rennweg', 'Neuhaus am Rennweg', 'Neuhaus,Neuhaus am Rennsteig,Neuhaus am Rennweg,Nojkhaus am Renveg,Nojkhaus na Renveg,Nojkhaus-am-Renveg,Nojkhaus-na-Renvege,lun wei ge de qu nuo yi hao si,Нойхаус-ам-Ренвег,Нойхаус-на-Ренвеге,Нојхаус ам Ренвег,Нојхаус на Ренвег,نویهاوس آم رن‌وگ,伦韦格地区诺伊豪斯', 50.5100600, 11.1378700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33843, 'Neuhaus', 'Neuhaus', '', 50.6833300, 10.9333300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33844, 'Neuharlingersiel', 'Neuharlingersiel', 'Neeharlingersiel,Nojkharlingersil,Nojkharlingerzil'',xin ha lin ge xi er,Нойхарлингерзиль,Нојхарлингерсил,新哈林格西尔', 53.6999300, 7.7028800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33845, 'Neuhardenberg', 'Neuhardenberg', 'Marxwalde,Nojkhardenberg,Noyhardenberg,xin ha deng bei ge,Нойхарденберг,Нојхарденберг,Նոյհարդենբերգ,新哈登贝格', 52.5960100, 14.2376800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33846, 'Neugersdorf', 'Neugersdorf', 'Neugersdorf,Nojgersdorf,Nowe Jezercy,Nowe Jěžercy,Нойгерсдорф,Нојгерсдорф', 50.9772900, 14.6088100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33847, 'Neugernsdorf', 'Neugernsdorf', 'Neugernsdorf', 50.7166700, 12.1333300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33848, 'Neufraunhofen', 'Neufraunhofen', 'Nojfraungofen,Nojfraunkhofen,Noyfraunhofen,nuo yi fu luo yin huo fen,nwyfrawnhwfn,Нойфраунгофен,Нойфраунхофен,Нојфраунхофен,Նոյֆրաունհոֆեն,نویفراونهوفن,诺伊夫罗因霍芬', 48.4000000, 12.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33849, 'Neufra', 'Neufra', 'Nojfra,nuo yi fu la,Нойфра,Нојфра,诺伊夫拉', 48.2477400, 9.1831100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33850, 'Neufra', 'Neufra', '', 48.1288000, 9.4755400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33851, 'Neuffen', 'Neuffen', 'Nojfen,Nojffen,Noyfen,Noyffen,nuo yi fen,nwyfn,Нойфен,Нойффен,Нојфен,Նոյֆեն,نويفن,نویفن,诺伊芬', 48.5546000, 9.3755000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33852, 'Neufelderkoog', 'Neufelderkoog', 'Neufelderkoog', 53.9000000, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33853, 'Neufeld', 'Neufeld', '', 53.9000000, 9.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33854, 'Neufahrn bei Freising', 'Neufahrn bei Freising', 'Neufahrn,Neufahrn apud Freising,Neufahrn bei Freising,Nojfarn baj Frajsinga,Nojfarn-Frajzing,Nojfarn-baj-Frajzing,Noyfarn Frayzing,fu lai xing fu jin nuo yi fa er en,nwyfarn bay frayzyng,Нойфарн-Фрайзинг,Нойфарн-бай-Фрайзінг,Нојфарн бај Фрајсинга,Նոյֆարն Ֆրայզինգ,نویفارن بای فرایزینگ,弗赖兴附近诺伊法尔恩', 48.3158800, 11.6631600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33855, 'Neufahrn', 'Neufahrn', '', 48.2558700, 12.4407800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33856, 'Neuerkirch', 'Neuerkirch', '', 50.0166700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33857, 'Neuerburg', 'Neuerburg', '', 50.0010200, 6.9482800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33858, 'Neuental', 'Neuental', 'Noental'',Nojental,Nojental'',noientaru,nuo yi en ta er,Нойенталь,Ноєнталь,Нојентал,ノイエンタール,诺伊恩塔尔', 51.0000000, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33859, 'Neuenstein', 'Neuenstein', 'Neuenstein', 49.2049000, 9.5800000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33860, 'Neuenstadt am Kocher', 'Neuenstadt am Kocher', 'Burg Neuenstadt,Neuenstadt,Neuenstadt am Kocher,Noenshtadt-am-Kokher,Nojenshtadt-am-Kokher,Nojenshtat am Kokher,nuo yi en si ta te a mu ke hei er,nwynshtat am kwkhr,Нойенштадт-ам-Кохер,Ноєнштадт-ам-Кохер,Нојенштат ам Кохер,نوينشتات آم كوخر,نوین‌اشتات آم کوخر,ノイエンシュタット・アム・コッハー,诺伊恩斯塔特阿姆科黑尔', 49.2349800, 9.3321500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33861, 'Neuensalz', 'Neuensalz', 'Nojenzal''c,Nojenzalc,nuo yi en sa er ci,Нойензальц,Нојензалц,诺伊恩萨尔茨', 50.5000000, 12.2166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33862, 'Neuenrade', 'Neuenrade', 'Neuenrade,Niggenroe,Noenrade,Nojenrade,nuo yi en la de,nwynradh,Нойенраде,Ноєнраде,Нојенраде,نوينراده,نوینراده,诺伊恩拉德', 51.2827800, 7.7825000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33863, 'Neuenmarkt', 'Neuenmarkt', 'Noenmarkt,Nojenmarkt,noienmarukuto,nuo en ma ke te,Нойенмаркт,Ноєнмаркт,Нојенмаркт,Նոյենմարքթ,ノイエンマルクト,诺恩马克特', 50.0919300, 11.5803300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33864, 'Neuenkirchen', 'Neuenkirchen', 'Nojenkirkhen,Нойенкирхен,Нојенкирхен', 54.2365500, 8.9915100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33865, 'Neuenkirchen', 'Neuenkirchen', '', 53.7769700, 8.8936100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33866, 'Neuenkirchen', 'Neuenkirchen', '', 53.5972900, 13.3694200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33867, 'Neuenkirchen', 'Neuenkirchen', '', 53.5166700, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33868, 'Neuenkirchen', 'Neuenkirchen', '', 53.2317300, 8.5266500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33869, 'Neuenkirchen', 'Neuenkirchen', '', 53.0325900, 9.7064200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33870, 'Neuenkirchen', 'Neuenkirchen', '', 52.7762900, 8.7504400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33871, 'Neuenkirchen', 'Neuenkirchen', '', 52.5103700, 8.0637100, 'DE', '2012-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33872, 'Neuenkirchen', 'Neuenkirchen', '', 52.4171000, 7.8388800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33873, 'Neuenkirchen', 'Neuenkirchen', '', 52.2447200, 7.3718300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33874, 'Neuenkirchen', 'Neuenkirchen', '', 52.1377800, 8.3883500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33875, 'Neuenhagen', 'Neuenhagen', '', 52.5298500, 13.6891400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33876, 'Neuengörs', 'Neuengors', 'Neuengoers,Neuengors,Neuengörs', 53.9000000, 10.3833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33877, 'Neuengönna', 'Neuengonna', 'Neuengonna,Neuengönna,Nojengena,Nojengjonna,nuo yi en ge na,Нойенгённа,Нојенгена,诺伊恩格纳', 50.9833300, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33878, 'Neuendorf', 'Neuendorf', '', 50.2833300, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33879, 'Neuendorf', 'Neuendorf', '', 50.0333300, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33880, 'Neuendettelsau', 'Neuendettelsau', 'Nojendetelzau,Nojendettel''zau,Noyendetelzau,noiendetteruzau,nuo yi en de te er shao,Нойендеттельзау,Нојендетелзау,Նոյենդետելզաու,ノイエンデッテルザウ,诺伊恩德特尔绍', 49.2833300, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33881, 'Neuendeich', 'Neuendeich', 'Neuendeich', 53.6833300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33882, 'Neuenbürg', 'Neuenburg', 'Neuenburg,Neuenbürg,Noenbjurg,Nojenbirg,Nojenbjurg,Noyenbyurg,nuo yi en bi er ge,nwynbwrg,nwynbwrgh,Нойенбюрг,Ноєнбюрг,Нојенбирг,Նոյենբյուրգ,نوينبورغ,نوینبورگ,诺伊恩比尔格', 48.8451600, 8.5957400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33883, 'Neuenburg am Rhein', 'Neuenburg am Rhein', 'Neueburg,Neuenburg,Neuenburg am Rhein,Neuenburg del Rin,Noenburg-am-Rajn,Nojenburg am Rajn,Nojenburg-am-Rajn,Reyni Noyenburg,lai yin he pan nuo yi en bao,nwynbwrg am rayn,nwynbwrgh am rayn,Нойенбург-ам-Райн,Ноєнбург-ам-Райн,Нојенбург ам Рајн,Ռեյնի Նոյենբուրգ,نوينبورغ آم راين,نوینبورگ آم راین,莱茵河畔诺伊恩堡', 47.8143100, 7.5600500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33884, 'Neuenbrook', 'Neuenbrook', 'Altendorf,Neuenbrook', 53.8607300, 9.5320300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33885, 'Neu Duvenstedt', 'Neu Duvenstedt', 'Neu Duvenstedt', 54.3666700, 9.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33886, 'Neudrossenfeld', 'Neudrossenfeld', 'Neu Dressenfeld,Neudrossenfeld,Nojdrosenfeld,Nojdrossenfel''d,Noydrosenfeld,noidorossenferuto,nuo yi de luo sen fei er de,Нойдроссенфельд,Нојдросенфелд,Նոյդրոսենֆելդ,ノイドロッセンフェルト,诺伊德罗森费尔德', 50.0166700, 11.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33887, 'Neudorf-Bornstein', 'Neudorf-Bornstein', 'Neudorf,Neudorf-Bornstein', 54.4333300, 9.9500000, 'DE', '2017-07-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33888, 'Neudietendorf', 'Neudietendorf', 'Neudietendorf,Nojditendorf,Нойдитендорф,Нојдитендорф', 50.9125000, 10.9134600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33889, 'Neudenau', 'Neudenau', 'Neudenau,Nojdenau,noidenau,nuo yi de nao,nwydnaw,Нойденау,Нојденау,نويدناو,نویدناو,ノイデナウ,诺伊德瑙', 49.2918100, 9.2697500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33890, 'Neu Darchau', 'Neu Darchau', 'Noj Darkhau,Noj-Darkhau,nwy darshaw,xin da er xiao,Ной-Дархау,Ној Дархау,نوی دارشاو,新达尔肖', 53.2290100, 10.8852900, 'DE', '2011-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33891, 'Neuburg an der Donau', 'Neuburg an der Donau', 'Danubi Noyburg,Neiburg an da Donau,Neubourg-sur-le-Danube,Neuburg,Neuburg a.d.Donau,Neuburg an der Donau,Neuburg-Donau,Neuburgo do Danubio,Neuburgo do Danúbio,Nojburg na Dunav,Nojburg na Dunavu,Nojburg-an-der-Donau,Nojburg-na-Dunae,niu yin bao,nwybwrg an dr dwnaw,nwybwrgh an dr dwnaw,Нойбург на Дунав,Нойбург-ан-дер-Донау,Нойбург-на-Дунае,Нојбург на Дунаву,Դանուբի Նոյբուրգ,نويبورغ آن در دوناو,نویبورگ آن در دوناو,ノイブルク・アン・デア・ドナウ,纽因堡', 48.7321800, 11.1870900, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33892, 'Neuburg', 'Neuburg', '', 53.4067700, 11.9174200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33893, 'Neuburg', 'Neuburg', 'Neuburg,Neuburg am Rhein', 48.9893300, 8.2471500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33894, 'Neuburg', 'Neuburg', 'Neuburg am Inn', 48.5065400, 13.4471800, 'DE', '2015-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33895, 'Neuburg', 'Neuburg', '', 47.7705600, 10.3556300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33896, 'Neubulach', 'Neubulach', 'Nojbulakh,Noybulax,nuo yi bu la,nwybwlakh,Нойбулах,Нојбулах,Նոյբուլախ,نويبولاخ,نویبولاخ,诺伊布拉', 48.6609200, 8.6961100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33897, 'Neubukow', 'Neubukow', 'Neibukova,Neibūkova,Neubukow,Nojbukov,nwybwkw,xin bu ke,Нойбуков,Нојбуков,نويبوكو,نویبوکو,新布科', 54.0317700, 11.6739100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33898, 'Neubrunn', 'Neubrunn', '', 50.5000000, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33899, 'Neubrunn', 'Neubrunn', 'Neubrunn', 49.7308800, 9.6716100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33900, 'Neubrück', 'Neubrueck', 'Castrum Brugghe [a. 1321],Nieenbruegge,Nieenbrügge,Nienbrigge,Nienbrueck [a. 1654],Nienbrück [a. 1654]', 52.3708800, 10.4176100, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33901, 'Neubrück', 'Neubrueck', '', 51.1343400, 6.6385700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33902, 'Neubrandenburg', 'Neubrandenburg', 'FNB,Neibrandenburga,Neubrandenbourg,Neubrandenburg,Noibrandenburgas,Nojbrandenburg,Nojbrandenburge,Nuevo Brandeburgo,noibeulandenbuleukeu,noiburandenburuku,nwybrndnbwrg,xin bo lan deng bao,Нойбранденбург,Нойбранденбурге,Нојбранденбург,نویبرندنبورگ,ノイブランデンブルク,新勃兰登堡,노이브란덴부르크', 53.5641400, 13.2753200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33903, 'Neubörger', 'Neuborger', '', 52.9581500, 7.4483900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33904, 'Neubiberg', 'Neubiberg', 'Neibiberg,Nojbiberg,Noybiberg,nwybybrg,xin bi bei ge,Нойбиберг,Нойбіберг,Нојбиберг,Նոյբիբերգ,نویبیبرگ,新比贝格', 48.0771000, 11.6581200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33905, 'Neubeuern', 'Neubeuern', 'Neupeurn,Nojboern,Nojbojern,Noyboyern,nuo yi bo yi ai er en,nwybwyrn,Нойбойерн,Нойбоєрн,Нојбојерн,Նոյբոյերն,نویبویرن,诺伊博伊埃尔恩', 47.7736800, 12.1400200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33906, 'Neuberend', 'Neuberend', 'Neuberend', 54.5500000, 9.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33907, 'Neu-Bamberg', 'Neu-Bamberg', 'Noj-Bamberg,xin ban bei ge,Ной-Бамберг,Ној-Бамберг,新班贝格', 49.7985900, 7.9239000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33908, 'Neu-Anspach', 'Neu-Anspach', 'Noj-Anspakh,nwy-anshbakh,xin an si pa he,Ной-Анспах,Ној-Анспах,نوي-أنشباخ,نوی-آن‌اشپاخ,新安斯帕赫', 50.3166700, 8.5000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33909, 'Neualbenreuth', 'Neualbenreuth', '', 49.9803700, 12.4437300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33910, 'Netzschkau', 'Netzschkau', 'Nechkau,Neckava,Necshkau,Netzschkau,Nečkava,nei ci xi kao,ntsshkaw,Нецшкау,Нечкау,نتسشكاو,نتسشکاو,内茨希考', 50.6141100, 12.2438200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33911, 'Netzbach', 'Netzbach', '', 50.3166700, 8.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33912, 'Nettetal', 'Nettetal', 'Netetal,Nettetal,Nettetal'',nei te ta er,nttal,ntytal,Нететал,Неттеталь,نتتال,نتيتال,内特塔尔', 51.3166700, 6.2833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33913, 'Nettersheim', 'Nettersheim', 'Neterskhajm,Netterskhajm,nei te er si hai mu,Нетерсхајм,Неттерсхайм,内特尔斯海姆', 50.4937200, 6.6289600, 'DE', '2012-10-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33914, 'Nettelsee', 'Nettelsee', 'Nettelsee', 54.1763600, 10.1926300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33915, 'Netphen', 'Netphen', 'Netfen,Netphen,Netpkhen,nei te fen,ntfn,Нетпхен,Нетфен,نتفن,内特芬', 50.9166700, 8.1000000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33916, 'Nesselwang', 'Nesselwang', 'Neselvang,Nessel''vang,Nesselwang,nei sai er wang,nesseruvu~angu,Неселванг,Нессельванг,Նեսելվանգ,ネッセルヴァング,内塞尔旺', 47.6234200, 10.5024300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33917, 'Neschwitz', 'Neschwitz', 'Neschwitz/Njeswacidlo,Neschwitz/Njeswačidło,Neshvic,Njeswacidlo,Njeswačidło,nei shi wei ci,Нешвиц,Нешвіц,内施维茨', 51.2705600, 14.3290000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33918, 'Nerzweiler', 'Nerzweiler', 'Nercvajler,nei er ci wei lei,Нерцвайлер,Нерцвајлер,内尔茨韦勒', 49.6000000, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33919, 'Nersingen', 'Nersingen', 'Nersingen,Nerzingen,nei er xin gen,Нерзинген,Нерзінген,Нерсинген,Ներզինգեն,内尔辛根', 48.4282900, 10.1235600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33920, 'Neroth', 'Neroth', 'Nerot,nei luo te,Нерот,内罗特', 50.1960200, 6.7468900, 'DE', '2011-07-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33921, 'Neritz', 'Neritz', '', 53.7833300, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33922, 'Neresheim', 'Neresheim', 'Neresgajm,Neresheimi vald,Nereskhajm,nei lei si hai mu,nereshaimi,nrzhaym,nyrshaym,Нересгайм,Нересхайм,Нересхајм,نرزهایم,نيرسهايم,ნერესჰაიმი,内雷斯海姆', 48.7551100, 10.3304100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33923, 'Nerenstetten', 'Nerenstetten', '', 48.5288800, 10.0991000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33924, 'Nerdlen', 'Nerdlen', '', 50.2333300, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33925, 'Nerchau', 'Nerchau', 'Nerkhau,Нерхау', 51.2709400, 12.7891200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33926, 'Nentershausen', 'Nentershausen', 'Nentershausen', 51.0166700, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33927, 'Nentershausen', 'Nentershausen', '', 50.4166700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33928, 'Nennslingen', 'Nennslingen', 'Nennslingen,Nenslingen,nen si lin gen,Неннслінген,Ненслинген,Նենսլինգեն,嫩斯林根', 49.0470900, 11.1305200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33929, 'Nennhausen', 'Nennhausen', 'Nenhauzen,Nenkhauzen,nen hao sen,Ненхаузен,Նենհաուզեն,嫩豪森', 52.6000000, 12.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33930, 'Nenndorf', 'Nenndorf', '', 53.5833300, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33931, 'Nellingen', 'Nellingen', 'Nelingen,Nellingen,nei lin gen,nelingeni,Нелинген,Неллинген,Неллінген,Նելինգեն,ნელინგენი,内林根', 48.5419600, 9.7905300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33932, 'Neitersen', 'Neitersen', 'Najtersen,Najterzen,nai te er sen,naytrzn,Найтерзен,Најтерсен,نایترزن,奈特尔森', 50.6685200, 7.5851300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33933, 'Neinstedt', 'Neinstedt', 'Neinstedt', 51.7495000, 11.0872100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33934, 'Neidlingen', 'Neidlingen', 'Najdlingen,Naydlingen,nai de lin gen,Найдлинген,Найдлінген,Најдлинген,Նայդլինգեն,奈德林根', 48.5786500, 9.5645400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33935, 'Neidhartshausen', 'Neidhartshausen', 'Najdkhartskhauzen,nai de ha er ci hao sen,Найдхартсхаузен,Најдхартсхаузен,奈德哈尔茨豪森', 50.6833300, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33936, 'Neidenstein', 'Neidenstein', 'Najdenshtajn,nai deng si tai yin,naidenshutain,Найденштайн,Најденштајн,ナイデンシュタイン,奈登斯泰因', 49.3166700, 8.8847200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33937, 'Neidenfels', 'Neidenfels', '', 49.3888900, 8.0463900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33938, 'Neidenbach', 'Neidenbach', '', 50.1000000, 6.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33939, 'Neichen', 'Neichen', '', 50.2666700, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33940, 'Nehren', 'Nehren', '', 50.0833300, 7.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33941, 'Nehren', 'Nehren', '', 48.4309700, 9.0699000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33942, 'Nehmten', 'Nehmten', 'Nehmten', 54.1000000, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33943, 'Nehms', 'Nehms', 'Nehms', 54.0166700, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33944, 'Negernbötel', 'Negernbotel', 'Negernbotel,Negernbötel', 53.9833300, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33945, 'Negenharrie', 'Negenharrie', 'Negenharrie', 54.1428800, 10.0743900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33946, 'Negenborn', 'Negenborn', '', 51.8833300, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33947, 'Neetze', 'Neetze', 'Nece,Netce,nei ce,Нетце,Неце,内策', 53.2652100, 10.6213400, 'DE', '2011-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33948, 'Neenstetten', 'Neenstetten', 'Nenshteten,Nenshtetten,nen si te teng,Ненштетен,Ненштеттен,Նենշտեթեն,ნეენშტეტენი,嫩斯特滕', 48.5467900, 10.0196600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33949, 'Neef', 'Neef', '', 50.1000000, 7.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33950, 'Neckarzimmern', 'Neckarzimmern', 'Neckarzimmern,Nekarcimern,Nekkarcimmern,nei ka er qi mei er en,nekkatsu~inmerun,Некарцимерн,Неккарциммерн,ネッカーツィンメルン,内卡尔齐梅尔恩', 49.3191700, 9.1327800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33951, 'Neckarwestheim', 'Neckarwestheim', 'Neckarwestheim,Nekarvestkhajm,Nekkarvestgajm,Nekkarvestkhajm,nei ka er wei si tai mu,nekkavu~esutohaimu,Некарвестхајм,Неккарвестгайм,Неккарвестхайм,ネッカーヴェストハイム,内卡尔韦斯泰姆', 49.0469400, 9.1900000, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33952, 'Neckartenzlingen', 'Neckartenzlingen', 'Nekartenclingen,Nekkartenclingen,nei ka er teng ci lin gen,Некартенцлинген,Неккартенцлинген,Неккартенцлінген,Նեքարտենցլինգեն,内卡尔滕茨林根', 48.5898100, 9.2347800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33953, 'Neckartailfingen', 'Neckartailfingen', 'Nekartajlfingen,Nekkartajl''fingen,nei ka er tai er fen gen,Некартајлфинген,Неккартайльфинген,Неккартайльфінген,Նեքարտայլֆինգեն,内卡尔泰尔芬根', 48.6117200, 9.2637100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33954, 'Neckarsulm', 'Neckarsulm', 'Neckarsulm,Nekarsulm,Nekarzulm,Nekkarzul''m,Nekkarzulm,nei ka er su er mu,nekaleujulleum,nekkazurumu,nkazawlm,nykarswlm,Некарзулм,Некарсулм,Неккарзульм,نيكارسولم,نکازاولم,ネッカーズルム,内卡尔苏尔姆,네카르줄름', 49.1891200, 9.2252700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33955, 'Neckarsteinach', 'Neckarsteinach', 'Neckarsteinach,Neggerschdanisch,Neggerschdånisch,Nekarshtajnakh,Nekkarshtajnakh,nei ka er si tai na,nekkashutainaha,nkaashtaynnakh,nykarshtaynakh,Некарштајнах,Неккарштайнах,نيكارشتايناخ,نکااشتاینناخ,ネッカーシュタイナハ,内卡尔斯泰纳', 49.4073500, 8.8434200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33956, 'Neckargerach', 'Neckargerach', 'Nekargerakh,Nekkargerakh,nei ka er ge la,nekkageraha,Некаргерах,Неккаргерах,ネッカーゲラハ,内卡尔格拉', 49.4000000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33957, 'Neckargemünd', 'Neckargemund', 'Neckargemuend,Neckargemund,Neckargemünd,Nekargemind,Nekkargemjund,nei ka er ge ming de,nekkagemyunto,nkagmwnd,nykarghymwnd,Некаргеминд,Неккаргемюнд,نيكارغيموند,نکاگموند,ネッカーゲミュント,内卡尔格明德', 49.3889900, 8.7959000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33958, 'Neckarbischofsheim', 'Neckarbischofsheim', 'Neckar-bischofshein,Neckarbischofsheim,Nekarbishofskhajm,Nekkarbishofsgajm,Nekkarbishofskhajm,nei ka er bi shao fu si hai mu,nekkabishofusuhaimu,nkarbyshwfzhaym,nykarbyshwfshaym,Некарбишофсхајм,Неккарбишофсхайм,Неккарбішофсгайм,نيكاربيشوفسهايم,نکاربیشوفزهایم,ネッカービショフスハイム,内卡尔比绍夫斯海姆', 49.2962500, 8.9638000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33959, 'Nebra', 'Nebra', 'Nebra,Nebra-sur-Unstrut,mbra,nei bu la,nybra,Небра,مبرا,نيبرا,内布拉', 51.2881000, 11.5774900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33960, 'Nebelschütz', 'Nebelschuetz', 'Nebel''shjuc,Nebelschuetz/Njebjelcicy,Nebelschuetzi vald,Nebelschütz/Njebjelčicy,Nebelschützi vald,Nebelshic,Njebjelcicy,Njebjelčicy,nei bei er xu ci,Небелшиц,Небельшюц,内贝尔许茨', 51.2622700, 14.1584900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33961, 'Nebel', 'Nebel', '', 54.6508500, 8.3537300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33962, 'Nazza', 'Nazza', 'Naca,Nacca,Nazza,na cha,Наца,Нацца,纳察', 51.1146900, 10.3347500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33963, 'Nauwalde', 'Nauwalde', '', 51.4183700, 13.4097400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33964, 'Nausnitz', 'Nausnitz', 'Nausnitz', 50.9500000, 11.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33965, 'Nausitz', 'Nausitz', 'Nausitz', 51.3166700, 11.3333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33966, 'Nauroth', 'Nauroth', '', 50.6992700, 7.8754300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33967, 'Nauort', 'Nauort', '', 50.4666700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33968, 'Naunhof', 'Naunhof', 'Naunhof,Naunhofa,Naunkhof,Neunhof,nawnhwf,nuo yin huo fu,Наунхоф,ناونهوف,诺因霍夫', 51.2777000, 12.5882700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33969, 'Naunheim', 'Naunheim', '', 50.2500000, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33970, 'Naundorf', 'Naundorf', '', 51.2571800, 13.1081000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33971, 'Naumburg', 'Naumburg', 'Gorad Naumburg,Naumburg,naumuburuku,nawmbwrg,Горад Наўмбург,Наумбург,ناومبورگ,ナウムブルク', 51.2481600, 9.1656900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33972, 'Naumburg', 'Naumburg', 'Gorad Naumburg,Naumberg,Naumborg,Naumbourg,Naumburg,Naumburg an der Saale,Naumburg/Saale,Naumburgo,Stadt Naumburg,nao mu bao,naumbuleukeu,naumuburuku,nawmbwrg,nawmbwrgh,Горад Наўмбург,Наумбург,ناومبورغ,ناومبورگ,ナウムブルク,瑙姆堡,나움부르크', 51.1498700, 11.8097900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33973, 'Nauheim', 'Nauheim', 'Naugajm,Naukhajm,nao hai mu,nauhaimu,Наугайм,Наухайм,Наухајм,ナウハイム,瑙海姆', 49.9508300, 8.4633300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33974, 'Nauendorf', 'Nauendorf', '', 51.6017800, 11.8852500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33975, 'Nauendorf', 'Nauendorf', '', 50.8945300, 11.1810800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33976, 'Nauen', 'Nauen', 'Nauehn,Nauen,nao en,Науен,Науэн,Նաուեն,瑙恩', 52.6070100, 12.8737400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33977, 'Nattheim', 'Nattheim', 'Natkhajm,Nattgajm,Nattkhajm,na tai mu,Наттгайм,Наттхайм,Натхајм,纳泰姆', 48.6996300, 10.2420900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33978, 'Nattenheim', 'Nattenheim', '', 50.0166700, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33979, 'Natendorf', 'Natendorf', '', 53.0798000, 10.4703100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33980, 'Nastätten', 'Nastaetten', 'Nashteten,Nashtetten,Nastaetten,Nastätten,na si te teng,naashttn,nashtytn,nashutetten,Наштетен,Наштеттен,نااشتتن,ناشتيتن,ナシュテッテン,纳斯特滕', 50.1988300, 7.8589200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33981, 'Nassau', 'Nassau', 'Nassau', 50.3145300, 7.8002500, 'DE', '2015-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33982, 'Nasingen', 'Nasingen', '', 49.9666700, 6.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33983, 'Narsdorf', 'Narsdorf', 'Narsdorf,Narsdorfi vald,na er si duo fu,Нарсдорф,纳尔斯多夫', 51.0166700, 12.7166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33984, 'Nanzdietschweiler', 'Nanzdietschweiler', 'Nancdichvajler,Nanzdietschweiler,Nanzdiezweiler,nan ci di ci xi wei lei,Нанцдичвайлер,Нанцдичвајлер,楠茨迪茨希韦勒', 49.4500000, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33985, 'Nannhausen', 'Nannhausen', '', 49.9666700, 7.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33986, 'Nandlstadt', 'Nandlstadt', 'Nandelstatt,Nandl''shtadt,Nandlshtat,Nandlstadt,nan de er shi ta te,nandl ashtat,Нандлштат,Нандльштадт,Նանդլշթաթ,ناندل اشتات,楠德尔施塔特', 48.5364400, 11.8073000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33987, 'Namborn', 'Namborn', 'Namborn,nan bo en,Намборн,楠博恩', 49.5216600, 7.1407000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33988, 'Nalbach', 'Nalbach', 'Nal''bakh,Nalbakh,na er ba he,nalbakh,Налбах,Нальбах,نالباخ,纳尔巴赫', 49.3833300, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33989, 'Naila', 'Naila', 'Naila,Najla,naira,nayla,Найла,Најла,نایلا,ナイラ', 50.3303400, 11.7046300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33990, 'Nahrendorf', 'Nahrendorf', 'Narendorf,na lun duo fu,Нарендорф,纳伦多夫', 53.1738900, 10.8138100, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33991, 'Nahe', 'Nahe', 'Nahe', 53.8000000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33992, 'Nagold', 'Nagold', 'Nagol''d,Nagold,na ge er de,nagld,Наголд,Нагольд,ناگلد,纳戈尔德', 48.5498000, 8.7236600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33993, 'Nagel', 'Nagel', '', 49.9833300, 11.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33994, 'Nackenheim', 'Nackenheim', 'Nakenkhajm,Nakkenkhajm,na ken hai mu,Накенхајм,Наккенхайм,纳肯海姆', 49.9152800, 8.3388900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33995, 'Nack', 'Nack', '', 49.7463900, 8.0027800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33996, 'Nachtsheim', 'Nachtsheim', 'Nakhtskhajm,na ci hai mu,Нахтсхайм,Нахтсхајм,纳茨海姆', 50.3166700, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33997, 'Nachterstedt', 'Nachterstedt', 'Nachterstedt', 51.8008100, 11.3348900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33998, 'Nachrodt-Wiblingwerde', 'Nachrodt-Wiblingwerde', 'Nakhrodt-Viblingverde,Narodt-Viblingverde,na he luo te-wei bu ling wei de,Народт-Виблингверде,Нахродт-Виблингверде,纳赫罗特-维布灵韦德', 51.3166700, 7.6166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(33999, 'Nabburg', 'Nabburg', 'Nabburg,Naburg,na bao,nabwrg,nabwrgh,Наббург,Набург,نابورغ,نابورگ,纳堡', 49.4534700, 12.1799600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34000, 'Mylau', 'Mylau', 'Milau,Milava,Mylau,Mīlava,maylw,mi lao,Милау,مایلو,米劳', 50.6186100, 12.2653500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34001, 'Muxerath', 'Muxerath', '', 49.9833300, 6.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34002, 'Mutzschen', 'Mutzschen', 'Muchen,Mucshen,mwtsshn,Муцшен,Мучен,موتسشن', 51.2615900, 12.8912500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34003, 'Mützenich', 'Mutzenich', '', 50.2500000, 6.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34004, 'Mutterstadt', 'Mutterstadt', 'Mutershtat,Muttershtadt,Mutterstadt,mu te er si ta te,Мутерштат,Муттерштадт,穆特尔斯塔特', 49.4413900, 8.3561100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34005, 'Mutterschied', 'Mutterschied', '', 49.9833300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34006, 'Mutlangen', 'Mutlangen', 'Mutlangen,mu te lan gen,Мутланген,მუტლანგენი,穆特兰根', 48.8258800, 9.7971400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34007, 'Musweiler', 'Musweiler', '', 50.0166700, 6.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34008, 'Mustin', 'Mustin', '', 53.6833300, 10.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34009, 'Müssen', 'Mussen', '', 53.4924400, 10.5640400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34010, 'Muschwitz', 'Muschwitz', 'Muschwitz', 51.1929600, 12.1206500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34011, 'Müschenbach', 'Muschenbach', '', 50.6833300, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34012, 'Müsch', 'Musch', '', 50.3833300, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34013, 'Murrhardt', 'Murrhardt', 'Murgardt,Murkhardt,Murkhart,mu la er te,mwhardt,mwrhart,Мургардт,Мурхардт,Мурхарт,مورهارت,موهاردت,穆拉尔特', 48.9819100, 9.5704700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34014, 'Murr', 'Murr', '', 48.9620700, 9.2592400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34015, 'Murnau am Staffelsee', 'Murnau am Staffelsee', 'Murnau,Murnau am Shtafelze,Murnau am Stafelzey,Murnau-am-Shtaffel''ze,Murnau-am-Shtaffel''zee,mwrnaw am ashtaflzy,si ta fei er hu pan mu er nao,Мурнау ам Штафелзе,Мурнау-ам-Штаффельзе,Мурнау-ам-Штаффельзее,Մուրնաու ամ Շտաֆելզեյ,مورناو ام اشتافلزی,斯塔费尔湖畔穆尔瑙', 47.6808500, 11.2012500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34016, 'Mürlenbach', 'Murlenbach', 'Mirlenbakh,Mjurlenbakh,mi er lun ba he,Мирленбах,Мюрленбах,米尔伦巴赫', 50.1500000, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34017, 'Murg', 'Murg', '', 47.5549200, 8.0218200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34018, 'Münzenberg', 'Muenzenberg', 'Mincenberg,Mjuncenberg,Muenzenberg,Münzenberg,ming cen bei ge,mwntsnbrg,mwntsnbrgh,myuntsu~enberuku,Минценберг,Мюнценберг,مونتسنبرغ,مونتسنبرگ,ミュンツェンベルク,明岑贝格', 50.4534600, 8.7743000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34019, 'Münster-Sarmsheim', 'Muenster-Sarmsheim', 'Muenster-Sarmsheim,Münster-Sarmsheim', 49.9434100, 7.8942600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34020, 'Münstermaifeld', 'Muenstermaifeld', 'Gorad Mjunstehrmajfel''d,Minstermajfeld,Mjunstermajfel''d,Muenstermaifeld,Munstermaifeld,Münstermaifeld,ming si te er mai fei er de,mwnstrmayfld,myunsutamaiferuto,Горад Мюнстэрмайфельд,Минстермајфелд,Мюнстермайфельд,مونسترمايفلد,مونسترمایفلد,ミュンスターマイフェルト,明斯特尔迈费尔德', 50.2463800, 7.3620800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34021, 'Münsterhausen', 'Munsterhausen', 'Minsterkhauzen,Mjunstergauzen,Mjunsterkhauzen,Muensterhausen,Munsterhausen,Münsterhausen,ming si te lao sen,Минстерхаузен,Мюнстергаузен,Мюнстерхаузен,Մյունսթերհաուզեն,明斯特劳森', 48.3097300, 10.4550000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34022, 'Münsterdorf', 'Munsterdorf', 'Munsterdorf,Münsterdorf', 53.9023200, 9.5412300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34023, 'Münsterappel', 'Munsterappel', 'Muensterappel,Münsterappel', 49.7333300, 7.8833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34024, 'Munster', 'Munster', 'Mounster,Munste,Munster,mwnstr  nydrzaksn,Μούνστερ,Мунстер,مونستر، نیدرزاکسن', 52.9856900, 10.0875600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34025, 'Münster', 'Muenster', 'FMO,Gorad Mjunstehr,Minster,Minstere,Miunsteris,Mjunster,Moenster,Monasterium,Muenster,Munistri,Munster,Mynster,Mönster,Münster,ming si te,mwinseuteo,mwnstr,mynstr,myunsuta,Μύνστερ,Горад Мюнстэр,Минстер,Мюнстер,מינסטר,مونستر,მიუნსტერი,ミュンスター,明斯特,뮌스터', 51.9623600, 7.6257100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34026, 'Münster', 'Munster', 'Muenster,Münster', 49.9227800, 8.8677800, 'DE', '2015-01-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34027, 'Münster', 'Muenster', '', 48.6225300, 10.9017200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34028, 'Münster', 'Munster', '', 48.2290400, 10.6362300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34029, 'Münsingen', 'Munsingen', 'Minsingen,Mjunzingen,Muensingen,Münsingen,mwnzyngn,Минсинген,Мюнзинген,مونزینگن', 48.4112600, 9.4970400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34030, 'Münsing', 'Munsing', 'Minsing,Mjunzing,Muensing,Myunzing,Münsing,ming xin ge,mwnzyng,Минсинг,Мюнзинг,Мюнзінг,Մյունզինգ,مونزینگ,明辛格', 47.9000000, 11.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34031, 'Munningen', 'Munningen', '', 48.9166700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34032, 'Münnerstadt', 'Munnerstadt', 'Minershtat,Mjunnershtadt,Muennerstadt,Munnerstadt,Münnerstadt,mi nei er si ta te,mwnrashtat,Минерштат,Мюннерштадт,مونراشتات,米内尔斯塔特', 50.2463600, 10.2018700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34033, 'Munkbrarup', 'Munkbrarup', 'Munkbrarup,meng ke bu la lu pu,Мункбраруп,蒙克布拉鲁普', 54.8000000, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34034, 'Münk', 'Munk', '', 50.3000000, 7.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34035, 'Mündersbach', 'Mundersbach', '', 50.6063900, 7.7341700, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34036, 'Munderkingen', 'Munderkingen', 'Munderkingen,meng de er jin gen,mwndrkynghn,mwndrkyngn,Мундеркинген,Мундеркінген,Մունդերկինգեն,موندركينغن,موندرکینگن,მუნდერკინგენი,蒙德尔金根', 48.2356800, 9.6439800, 'DE', '2012-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34037, 'Hannoversch Münden', 'Hannoversch Muenden', 'Hann. Muenden,Hann. Münden,Hann.Muenden,Hann.Münden,Hannoverisch-Munden,Hannoverisch-Münden,Hannoversch Muenden,Hannoversch Münden,Muenden,Munden,Münden,Stadt Hann. Muenden,Stadt Hann. Münden,ハン・ミュンデン', 51.4150500, 9.6504600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34038, 'Mundelsheim', 'Mundelsheim', 'Mundel''sgajm,Mundel''skhajm,Mundelskhajm,meng de er si hai mu,mwndlshaym,Мунделсхајм,Мундельсгайм,Мундельсхайм,موندلشایم,蒙德尔斯海姆', 49.0008300, 9.2077800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34039, 'Münchweiler an der Rodalbe', 'Muenchweiler an der Rodalbe', 'Muenchweiler an der Rodalb,Munchweiler,Munchweiler Rodalb,Munchweiler an der Rodalbe,Münchweiler,Münchweiler Rodalb,Münchweiler an der Rodalb,Münchweiler an der Rodalbe', 49.2179800, 7.7029500, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34040, 'Münchweiler an der Alsenz', 'Munchweiler an der Alsenz', 'Minkhvajler na Anlsenci,Mjunkhvajler-na-Al''zence,Munchweiler,Munchweiler Alsenz,Munchweiler an der Alsenz,Münchweiler,Münchweiler Alsenz,Münchweiler an der Alsenz,a er sen ci he pan ming xi wei lei,Минхвајлер на Анлсенци,Мюнхвайлер-на-Альзенце,阿尔森茨河畔明希韦勒', 49.5500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34041, 'Münchweiler am Klingbach', 'Munchweiler am Klingbach', 'Munchweiler,Munchweiler am Klingbach,Münchweiler,Münchweiler am Klingbach', 49.1500000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34042, 'Münchwald', 'Munchwald', 'Minkhvald,Mjunkhval''d,ming xi wa er de,Минхвалд,Мюнхвальд,明希瓦尔德', 49.9000000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34043, 'Münchsteinach', 'Muenchsteinach', 'Minkhshtajnakh,Mjunkhshtajnakh,Mjunkstajnakh,ming xi si tai na,Минхштајнах,Мюнкстайнах,Мюнхштайнах,Մյունկսթայնախ,明希斯泰纳', 49.6393700, 10.5950200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34044, 'Münchsmünster', 'Munchsmunster', 'Minkhsminster,Minsminsta,Mjunksmjunster,Munchsmunster,Münchsmünster,ming xi si ming si te er,mwnshsmwnstr,Минхсминстер,Мюнксмюнстер,Մյունքսմյունսթեր,مونشسمونستر,明希斯明斯特尔', 48.7666700, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34045, 'Münchhausen', 'Muenchhausen', 'Minkhauzen,Mjunkhgauzen,Mjunkhgauzen-am-Kristenberg,Muenchhausen am Christenberg,Munchhausen,Münchhausen,Münchhausen am Christenberg,myunhihauzen,Минхаузен,Мюнхгаузен,Мюнхгаузен-ам-Крістенберг,ミュンヒハウゼン', 50.9608100, 8.7183700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34046, 'Münchenbernsdorf', 'Muenchenbernsdorf', 'Minkhenbernsdorf,Mjunkhenbernsdorf,Munchenbernsdorf,Münchenbernsdorf,ming xing bei er en si duo fu,mwnshnbrnzdwrf,Минхенбернсдорф,Мюнхенбернсдорф,مونشنبرنزدورف,明兴贝尔恩斯多夫', 50.8211400, 11.9322600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34047, 'Munich', 'Munich', 'Gorad Mjunkhen,Lungsod ng Muenchen,Lungsod ng München,MUC,Minca,Minche,Minga,Minhen,Minhene,Minkhen,Miunchenas,Mjunkhen,Mnichov,Mnichow,Mníchov,Monachium,Monacho,Monaco de Baviera,Monaco di Baviera,Monaco e Baviera,Monacu,Monacu di Baviera,Monacum,Muenchen,Muenegh,Muenhen,Muenih,Munchen,Munhen,Munic,Munich,Munich ed Baviera,Munih,Munike,Munique,Munix,Munkeno,Munkhen,Munîh,Mynihu,Myunxen,Myunxén,Mònacu,Mùnich ëd Baviera,Múnic,Múnich,München,Münegh,Münhen,Münih,mi wnik,mi''unikha,miunkheni,miyunik,mu ni hei,mwinhen,mwnykh,mynkn,myunhen,myunik,myunikha,myunsena,mywnkh,mywnykh,Μόναχο,Горад Мюнхен,Минхен,Мюнхен,Мүнхен,Мүнхэн,Мӱнхен,Մյունխեն,מינכן,مونیخ,ميونخ,ميونيخ,میونخ,म्युन्शेन,म्यूनिख,মিউনিখ,மியூனிக்,ಮ್ಯೂನಿಕ್,มิวนิก,မြူးနစ်ချ်မြို့,მიუნხენი,ミュンヘン,慕尼黑,뮌헨', 48.1374300, 11.5754900, 'DE', '2014-01-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34048, 'Münchehofe', 'Muenchehofe', 'Minkhekhofe,Mjunkhekhofe,Myunhehofe,ming xie huo fei,Минхехофе,Мюнхехофе,Մյունհեհոֆե,明歇霍费', 52.1472700, 13.8343100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34049, 'Müncheberg', 'Muencheberg', 'Minkheberg,Mjunkheberg,Muencheberg,Muncheberg,Myunxeberg,Müncheberg,ming xie bei ge,mwnshnbrg,mwnshnbrgh,Минхеберг,Мюнхеберг,Մյունխեբերգ,مونشنبرغ,مونشنبرگ,明歇贝格', 52.5070400, 14.1371600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34050, 'Münchberg', 'Munchberg', 'Minkhberg,Mjunkhberg,Muenchberg,Munchberg,Münchberg,ming xi bei ge,mwnshbrg,mwnshbrgh,myunhiberuku,Минхберг,Мюнхберг,مونشبرغ,مونشبرگ,ミュンヒベルク,明希贝格', 50.1895200, 11.7882300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34051, 'Mülverstedt', 'Mulverstedt', '', 51.1166700, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34052, 'Mulsum', 'Mulsum', '', 53.6666700, 8.5500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34053, 'Mülsen', 'Mulsen', 'Milzen,Mjul''zen,Muelsen,Mülsen,mi er sen,Милзен,Мюльзен,米尔森', 50.7500000, 12.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34054, 'Müllrose', 'Muellrose', 'Miloraz,Milrose,Milroze,Miłoraz,Mjull''roze,Muellrose,Mullrose,Myuleroze,Müllrose,mi er luo sai,mwlrwzh,Милрозе,Милросе,Мюлльрозе,Մյուլերոզե,مولروزه,米尔罗塞', 52.2473600, 14.4179400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34055, 'Müllheim', 'Mullheim', 'Milkhajm,Mjul''khajm,Muellheim,Mulheim,Müllheim,mwlhaym,Милхајм,Мюльхайм,مولهایم', 47.8082000, 7.6303500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34056, 'Müllenbach', 'Mullenbach', '', 50.3166700, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34057, 'Müllenbach', 'Muellenbach', 'Milenbakh,Mjullenbakh,Muellenbach,Müllenbach,Миленбах,Мюлленбах', 50.2214700, 7.0661300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34058, 'Mülheim', 'Muelheim', 'ESS,Milchaim,Mjul''khajm-na-Rure,Moelm,Moeln,Muelheim,Muelheim (Ruhr),Muelheim an der Ruhr,Mulheim,Mulheim-on-Ruhr,Mölm,Möln,Mülheim,Mülheim (Ruhr),Mülheim an der Ruhr,Mülheim-on-Ruhr,Μιλχάιμ,Мюльхайм-на-Руре,מילהיים על הרוהר', 51.4321800, 6.8796700, 'DE', '2016-07-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34059, 'Mulfingen', 'Mulfingen', 'Mul''fingen,Mulfingen,mu er fen gen,murufingen,Мулфинген,Мульфинген,Мульфінген,ムルフィンゲン,穆尔芬根', 49.3402800, 9.8008300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34060, 'Muldenstein', 'Muldenstein', 'Muldenstein', 51.6719200, 12.3454800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34061, 'Muldenhammer', 'Muldenhammer', '', 50.4500000, 12.4833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34062, 'Mulda', 'Mulda', 'Mulda,Mulda-Randeck,Mulda/Sachsen', 50.8078900, 13.4147700, 'DE', '2017-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34063, 'Mülbach', 'Mulbach', 'Muhlbach,Mulbach,Mühlbach,Mülbach', 49.9687800, 6.4046900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34064, 'Mühltroff', 'Muehltroff', 'Miltrof,Mjul''trof,Muhltroff,Mühltroff,mi he er te luo fu,mwltrwf,Милтроф,Мюльтроф,مولتروف,米赫尔特罗夫', 50.5391900, 11.9282800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34065, 'Mühl Rosin', 'Muehl Rosin', 'Muehl Rosin,Mühl Rosin', 53.7638300, 12.2138800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34066, 'Mühlpfad', 'Muhlpfad', '', 50.1209200, 7.5554600, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34067, 'Mühlingen', 'Muhlingen', 'Milingen,Mjulingen,Muhlingen,Mühlingen,mi he lin gen,Милинген,Мюлинген,Мюлінген,米赫林根', 47.9166700, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34068, 'Mühlheim am Bach', 'Muhlheim am Bach', 'Muehlheim,Mühlheim', 48.3786300, 8.6973500, 'DE', '2017-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34069, 'Mühlheim am Main', 'Muehlheim am Main', 'Milkhajm na Majni,Mjul''gajm-am-Majn,Mjul''khajm-am-Majn,Mjul''khajm-na-Majne,Muehlheim,Mühlheim,mei yin he pan mi he er hai mu,mwlhaym am mayn,Милхајм на Мајни,Мюльгайм-ам-Майн,Мюльхайм-ам-Майн,Мюльхайм-на-Майне,مولهايم آم ماين,مولهایم آم ماین,ミュールハイム・アム・マイン,美因河畔米赫尔海姆', 50.1166700, 8.8333300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34070, 'Stuttgart Mühlhausen', 'Stuttgart Muehlhausen', '', 48.8423200, 9.2302800, 'DE', '2015-12-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34071, 'Mühlhausen', 'Muehlhausen', 'Milkhauzen,Mjul''khauzen,Mjulkhauzen,Muehlhausen,Muehlhausen/Thueringen,Muhlhausen,Mulhusa Thuringorum,Mühlhausen,Mühlhausen/Thüringen,Thomas-Muntzer-Stadt-Muhlhausen,Thomas-Müntzer-Stadt-Mühlhausen,mi er hao sen,miulhauzeni,mwilhaujen,mwlhawzn,Милхаузен,Мюлхаузен,Мюльхаузен,מילהאוזן,مولهاوزن,მიულჰაუზენი,米尔豪森,뮐하우젠', 51.2089600, 10.4527500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34072, 'Mühlhausen', 'Muhlhausen', 'Milkhauzen,Mjul''gauzen,Mjul''khauzen,Muhlhausen,Mühlhausen,myuruhauzen,Милхаузен,Мюльгаузен,Мюльхаузен,ミュールハウゼン', 49.7544300, 10.7756300, 'DE', '2013-04-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34073, 'Mühlhausen', 'Muhlhausen', 'Milkhauzen,Mjul''gauzen,Mjul''khauzen,Muehlhausen,Mühlhausen,myuruhauzen,Милхаузен,Мюльгаузен,Мюльхаузен,ミュールハウゼン', 49.2486100, 8.7266700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34074, 'Mühlhausen', 'Muhlhausen', 'Muehlhausen', 49.1694700, 11.4466400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34075, 'Mühlhausen', 'Muhlhausen', '', 48.5766100, 9.6573300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34076, 'Mühlenrade', 'Muhlenrade', 'Muhlenrade,Mühlenrade', 53.6000000, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34077, 'Mühlen Eichsen', 'Muehlen Eichsen', 'Milen Ajkhsen,Milen Ajkhzen,Mjulen-Ajkhzen,Muehlen Eichsen,Muhlen Eichsen,Mühlen Eichsen,mi he lun ai xi sen,Милен Ајхзен,Милен Ајхсен,Мюлен-Айхзен,米赫伦艾希森', 53.7577500, 11.2500600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34078, 'Mühlenbarbek', 'Muhlenbarbek', 'Muhlenbarbek,Mühlenbarbek', 53.9577800, 9.6672600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34079, 'Mühlenbach', 'Muhlenbach', '', 48.2500000, 8.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34080, 'Mühldorf', 'Muehldorf', 'Muehldorf,Muhldorf,Muhldorf am Inn,Mühldorf,Mühldorf am Inn', 48.2467000, 12.5215500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34081, 'Mühlberg', 'Muehlberg', 'Milberg,Mjul''berg,Muehlberg ved Elben,Muehlberg/Elbe,Muhlberg,Myulberg,Mühlberg,Mühlberg ved Elben,Mühlberg/Elbe,mi he er bei ge,mwlbrg,mwlbrgh,Милберг,Мюльберг,Մյուլբերգ,مولبرغ,مولبرگ,米赫尔贝格', 51.4345300, 13.2217700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34082, 'Mühlau', 'Muhlau', 'Muehlau,Mühlau', 50.9000000, 12.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34083, 'Mühlacker', 'Muhlacker', 'Milaker,Mjulakker,Muehlacker,Muhlacker,Myulaker,Mühlacker,mi he la ke er,mwlakr,Милакер,Мюлаккер,Մյուլակեր,مولآكر,مول‌آکر,米赫拉克尔', 48.9475400, 8.8367500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34084, 'Mühbrook', 'Muehbrook', 'Muhbrook,Mühbrook', 54.1567800, 10.0123600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34085, 'Muggensturm', 'Muggensturm', 'Mugenshturm,Muggenshturm,Muggensturm,mu gen si tu er mu,Муггенстурм,Муггенштурм,Мугенштурм,穆根斯图尔姆', 48.8666700, 8.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34086, 'Müggelheim', 'Muggelheim', 'Berlin-Muggelheim,Berlin-Müggelheim', 52.4113700, 13.6640300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34087, 'Mügeln', 'Muegeln', 'Migeln,Migelne,Mjugel''n,Muegeln,Mugeln,Mügeln,Mīgelne,mi ge er en,mwghln,mwgln,Мигелн,Мюгельн,موغلن,موگلن,米格尔恩', 51.2361900, 13.0456700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34088, 'Mudershausen', 'Mudershausen', '', 50.2833300, 8.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34089, 'Mudersbach', 'Mudersbach', '', 50.8251500, 7.9434700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34090, 'Mudenbach', 'Mudenbach', '', 50.6666700, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34091, 'Müden', 'Muden', 'Miden,Mie''en,Mjuden,Mueden,Mueden (Aller),Mutha,Müden,Müden (Aller),mi deng,Миден,Мюден,米登', 52.5277100, 10.3601100, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34092, 'Mudau', 'Mudau', 'Mudau,mu dao,mudau,Мудау,ムーダウ,穆道', 49.5344400, 9.2044400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34093, 'Mückeln', 'Muckeln', '', 50.0833300, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34094, 'Mücka', 'Mucka', 'Mika,Mikow,Mjuka,Mucka,Muecka vald,Muecka/Mikow,Mücka,Mücka vald,Mücka/Mikow,Мика,Мюка', 51.3166700, 14.7000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34095, 'Mucheln', 'Mucheln', '', 54.2500000, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34096, 'Mücheln', 'Muecheln', 'Mikheln,Mjukhel''n,Mucheln,Muecheln,Mücheln,mi xie er en,mwshln,Михелн,Мюхельн,موشلن,米歇尔恩', 51.2968800, 11.8075900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34097, 'Much', 'Much', 'Much', 50.9038300, 7.4030600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34098, 'Mözen', 'Mozen', 'Mozen,Mözen', 53.9166700, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34099, 'Moxa', 'Moxa', 'Moxa', 50.6500000, 11.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34100, 'Mötzingen', 'Motzingen', 'Moetzingen,Mötzingen', 48.5332000, 8.7744700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34101, 'Mötzing', 'Motzing', 'Mecing,Metcing,Mjotcing,Moetzing,Mötzing,mo qin ge,mwtsyng,Метцинг,Мецинг,Мётцинг,Մյոթցինգ,موتسینگ,默钦格', 48.8935000, 12.3736100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34102, 'Möttingen', 'Mottingen', 'Metingen,Mettingen,Mjottingen,Moettingen,Möttingen,mettingen,mo ting gen,Метинген,Меттінген,Мёттинген,Մյոթինգեն,メッティンゲン,默廷根', 48.8092400, 10.5902200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34103, 'Motten', 'Motten', '', 50.3956100, 9.7725100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34104, 'Mössingen', 'Mossingen', 'Gorad Mjosingen,Mesingen,Messingen,Mjossingen,Moessingen,Mössingen,mo xin gen,mwsynghn,mwsyngn,Горад Мёсінген,Месинген,Мессінген,Мёссинген,موسينغن,موسینگن,默辛根', 48.4056700, 9.0541900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34105, 'Moßbach', 'Mossbach', 'Mossbach,Moßbach', 50.6833300, 11.8166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34106, 'Möser', 'Moser', 'Moeser,Möser', 52.2139700, 11.7927900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34107, 'Moselkern', 'Moselkern', 'Mozel''kern,Mozelkern,mo sai er ke er en,Мозелкерн,Мозелькерн,莫塞尔克尔恩', 50.1943700, 7.3708400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34108, 'Moschheim', 'Moschheim', '', 50.4825000, 7.8416700, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34109, 'Mosbruch', 'Mosbruch', '', 50.2666700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34110, 'Mosbach', 'Mosbach', 'Mosbach,Mosbach in Baden,Mosbakh,Mossbach,mo si ba he,mosubahha,msbakh,mwsbakh,Мосбах,مسباخ,موسباخ,モースバッハ,莫斯巴赫', 49.3535700, 9.1510600, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34111, 'Morsum', 'Morsum', '', 52.9534700, 9.0796200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34112, 'Mörstadt', 'Morstadt', 'Moerstadt,Mörstadt', 49.6619400, 8.2547200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34113, 'Morshausen', 'Morshausen', '', 50.2000000, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34114, 'Mörsfeld', 'Morsfeld', '', 49.7500000, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34115, 'Mörsdorf', 'Moersdorf', '', 50.8699600, 11.7980200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34116, 'Mörsdorf', 'Moersdorf', 'Mersdorf,Mjorsdorf,Moersdorf,Mörsdorf,mo er si duo fu,Мерсдорф,Мёрсдорф,默尔斯多夫', 50.1000000, 7.3500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34117, 'Mörschied', 'Moerschied', '', 49.7881000, 7.3043500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34118, 'Morschheim', 'Morschheim', '', 49.6966700, 8.0261100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34119, 'Morscheid', 'Morscheid', '', 49.7333300, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34120, 'Mörschbach', 'Morschbach', '', 50.0166700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34121, 'Morsbach', 'Morsbach', 'Morsbakh,mo er si ba he,Морсбах,莫尔斯巴赫', 50.8666500, 7.7278700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34122, 'Mörlenbach', 'Morlenbach', 'Merlenbakh,Mjorlenbakh,Moerlenbach,Morlenbach,Mörlenbach,merurenbahha,mo lun ba he,Мерленбах,Мёрленбах,メルレンバッハ,默伦巴赫', 49.5991700, 8.7347200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34123, 'Mörlen', 'Morlen', 'Moerlen,Mörlen', 50.6980600, 7.8844400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34124, 'Moritzheim', 'Moritzheim', '', 50.0500000, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34125, 'Moritzburg', 'Moritzburg', 'Eisenberg', 51.1592200, 13.6802100, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34126, 'Moringen', 'Moringen', 'Moringen,mo lin gen,moringen,mryngn,mwrynghn,Моринген,مرینگن,مورينغن,モーリンゲン,莫林根', 51.6991500, 9.8710700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34127, 'Mörel', 'Morel', 'Morel,Mörel', 54.1166700, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34128, 'Morbach', 'Morbach', 'Morbach', 49.8077200, 7.1271400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34129, 'Moosthenning', 'Moosthenning', 'Mostening,Mostenning,mo si te ning ge,mwstnyng,Мостенинг,Мостеннинг,Мостеннінг,Մոսթենինգ,موستنینگ,莫斯特宁格', 48.6765900, 12.4973700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34130, 'Moosinning', 'Moosinning', 'Mosining,Mozinning,mo xi ning ge,mwsynyng,Мозиннинг,Мозіннінг,Мосининг,موسینینگ,莫西宁格', 48.2770800, 11.8444600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34131, 'Moosburg', 'Moosburg', 'Moosburg,Moosburg an der Isar,Mosburg', 48.4708900, 11.9381100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34132, 'Moosbach', 'Moosbach', 'Moosbach,Mosbach,Mosbakh,Mosbax,Мосбах,Մոսբախ', 49.5890900, 12.4103600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34133, 'Moosach', 'Moosach', '', 48.0321300, 11.8751000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34134, 'Moos', 'Moos', '', 48.7514900, 12.9611200, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34135, 'Moos', 'Moos', '', 47.7243900, 8.9347900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34136, 'Moorweg', 'Moorweg', 'Morveg,mo er wei ge,Морвег,莫尔韦格', 53.6333300, 7.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34137, 'Moorrege', 'Moorrege', 'Moorrege,Morege,Morrege,mo lei ge,Мореге,Морреге,莫雷格', 53.6666700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34138, 'Moorhusen', 'Moorhusen', '', 53.9590500, 9.3834800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34139, 'Moorenweis', 'Moorenweis', 'Morenvajs,Morenvays,mo lun wei si,mwrnways,Моренвайс,Моренвајс,Մորենվայս,مورنوایس,莫伦魏斯', 48.1556100, 11.0785100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34140, 'Moordiek', 'Moordiek', 'Moordiek', 53.9140500, 9.6534400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34141, 'Monzingen', 'Monzingen', 'Moncingen,meng qin gen,Монцинген,蒙钦根', 49.7976300, 7.5928400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34142, 'Monzernheim', 'Monzernheim', '', 49.7213900, 8.2283300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34143, 'Monzelfeld', 'Monzelfeld', '', 49.8923700, 7.0731800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34144, 'Möntenich', 'Montenich', '', 50.2212900, 7.2992100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34145, 'Montabaur', 'Montabaur', 'Mons Tabor,Montabaur,Montebaur,meng ta bao er,montabaua,montabaueo,mwntabawr,Монтабаур,مونتاباور,モンタバウアー,蒙塔鲍尔,몬타바우어', 50.4358800, 7.8232000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34146, 'Monstab', 'Monstab', 'Monshtab,Monstab,meng si ta bu,Монштаб,蒙斯塔布', 51.0000000, 12.3500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34147, 'Monsheim', 'Monsheim', 'Monsheim,Monskhajm,meng si hai mu,Монсхайм,Монсхајм,蒙斯海姆', 49.6372200, 8.2119400, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34148, 'Mönsheim', 'Monsheim', 'Moensheim,Mönsheim', 48.8666700, 8.8666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34149, 'Monschau', 'Monschau', 'Mondjoye,Monschau,Monshau,Montjoie,meng shao,mnshaw,mwnshaw,Моншау,منشاو,مونشاو,蒙绍', 50.5546200, 6.2400100, 'DE', '2017-01-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34150, 'Monreal', 'Monreal', '', 50.3000000, 7.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34151, 'Mönkloh', 'Moenkloh', 'Moenkloh,Monkloh,Mönkloh', 53.8902300, 9.7877100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34152, 'Mönkhagen', 'Monkhagen', 'Monkhagen,Mönkhagen', 53.9000000, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34153, 'Mönkeberg', 'Monkeberg', 'Menkeberg,Mjonkeberg,Moenkeberg,Mönkeberg,men ke bei ge,Менкеберг,Мёнкеберг,门克贝格', 54.3500000, 10.1833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34154, 'Monheim am Rhein', 'Monheim am Rhein', 'Monheim,Monheim am Rhein', 51.0916200, 6.8921700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34155, 'Monheim', 'Monheim', 'Mongajm,Monhaym,Monheim,Monkhajm,Monnheim,meng hai mu,mnhaym,monhaimu,mwnhaym,Монгайм,Монхайм,Монхајм,Մոնհայմ,منهایم,مونهايم,مونہايیم,モンハイム,蒙海姆', 48.8438900, 10.8583400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34156, 'Mönchweiler', 'Moenchweiler', 'Menkhvajler,Mjonkhvajler,Moenchweiler,Mönchweiler,men xi wei lei,Менхвайлер,Менхвајлер,Мёнхвайлер,门希韦勒', 48.1004000, 8.4221900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34157, 'Mönchsroth', 'Monchsroth', 'Menkhsrot,Menksrot,Mjonksrot,Moenchsroth,Myonksrot,Mönchsroth,men xi si luo te,menhisuroto,Менксрот,Менхсрот,Мёнксрот,Մյոնկսրոտ,メンヒスロート,门希斯罗特', 49.0185100, 10.3585600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34158, 'Mönchsdeggingen', 'Monchsdeggingen', 'Deggingen,Menkhsdegingen,Menksdeggingen,Mjonksdeggingen,Moenchsdeggingen,Monchsdeggingen,Mönchsdeggingen,men xi si de jin gen,menhisudeggingen,Менксдеггінген,Менхсдегинген,Мёнксдеггинген,Մյոնքսդեգինգեն,メンヒスデッギンゲン,门希斯德金根', 48.7760500, 10.5804300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34159, 'Mönchpfiffel-Nikolausrieth', 'Monchpfiffel-Nikolausrieth', 'Monchpfiffel-Nikolausrieth,Mönchpfiffel-Nikolausrieth', 51.3833300, 11.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34160, 'Mönchhagen', 'Moenchhagen', 'Moenchhagen,Monchhagen,Mönchhagen', 54.1514600, 12.2167000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34161, 'Mönchenholzhausen', 'Monchenholzhausen', 'Menkhenkholckhauzen,Mjonkhenkhol''ckhauzen,Moenchenholzhausen,Mönchenholzhausen,men xing huo er ci hao sen,Менхенхолцхаузен,Мёнхенхольцхаузен,门兴霍尔茨豪森', 50.9666700, 11.1500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34162, 'Mönchengladbach', 'Moenchengladbach', 'Jlabbach,M''onkhengladbakh,Men''chen''nklantmpach,Menchengladbachas,Menhengladbaha,Menkhengladbakh,Mjonkhengladbakh,Moenchengladbach,Monchengladbach,Muenchen-Gladbach,Mönchengladbach,dwsldwrf,mein chen klad bakh,men xing ge la de ba he,menhyenguratobahha,menkhengladbakhi,mnsngldbk,moenhengeullateubaheu,mwnshnghladbakh,myonsanagladabakha,Μενχενγκλάντμπαχ,Менхенгладбах,Мьонхенгладбах,Мёнхенгладбах,מנשנגלדבך,دوسلدورف,مونشنغلادباخ,مونشن‌گلادباخ,म्योन्शनग्लाडबाख,เมินเชนกลัดบัค,მენხენგლადბახი,メンヒェングラートバッハ,门兴格拉德巴赫,묀헨글라트바흐', 51.1853900, 6.4417200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34163, 'Mönchberg', 'Monchberg', 'Menkhberg,Mjonkhberg,Moenchberg,Monchberg,Myonxberg,Mönchberg,men xi bei ge,menhiberuku,Менхберг,Мёнхберг,Մյոնխբերգ,メンヒベルク,门希贝格', 49.7932600, 9.2685800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34164, 'Mommenheim', 'Mommenheim', '', 49.8802800, 8.2650000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34165, 'Mömlingen', 'Momlingen', 'Memlingen,Mjomlingen,Moemlingen,Myomlingen,Mömlingen,memuringen,mo mu lin gen,Мемлинген,Мемлінген,Мёмлинген,Մյոմլինգեն,メムリンゲン,默姆林根', 49.8597200, 9.0833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34166, 'Mömbris', 'Mombris', 'Membris,Mjombris,Moembris,Mombris,Myombris,Mömbris,memuburisu,men bu li si,Мембрис,Мембріс,Мёмбрис,Մյոմբրիս,メムブリス,门布里斯', 50.0692100, 9.1637100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34167, 'Molzhain', 'Molzhain', '', 50.7500000, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34168, 'Mölsheim', 'Molsheim', '', 49.6466700, 8.1694400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34169, 'Molschleben', 'Molschleben', 'Mol''shleben,Molschleben,Molshleben,mo er shi lai ben,Молшлебен,Мольшлебен,莫尔施莱本', 51.0000000, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34170, 'Molsberg', 'Molsberg', '', 50.4833300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34171, 'Mölln', 'Moelln', 'Gorad Mjol''n,Meln,Mjol''n,Moelln,Molln,Mölln,mo er en,mwln,Горад Мёльн,Мелн,Мёльн,مولن,默尔恩', 53.6170200, 10.6874200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34172, 'Möllenhagen', 'Moellenhagen', 'Melenkhagen,Mjollenkhagen,Moellenhagen,Möllenhagen,mo lun ha gen,Меленхаген,Мёлленхаген,默伦哈根', 53.5238800, 12.9286800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34173, 'Molfsee', 'Molfsee', 'Mol''fze,Molfsee,Molfze,mo er fu sai,Молфзе,Мольфзе,莫尔夫塞', 54.2666700, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34174, 'Molbergen', 'Molbergen', 'Mol''bergen,Molbergen,Molbiergen,mo er bei er gen,Молберген,Мольберген,莫尔贝尔根', 52.8580500, 7.9254800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34175, 'Moisburg', 'Moisburg', 'Gemeen Mesborg,Moisburg,Mojsburg,mo yi si bao,Моисбург,Мойсбург,莫伊斯堡', 53.4062000, 9.6988000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34176, 'Möhrendorf', 'Mohrendorf', 'Merendorf,Mjorendorf,Moehrendorf,Mohrendorf,Möhrendorf,merendorufu,mo he lun duo fu,Мерендорф,Мёрендорф,メーレンドルフ,默赫伦多夫', 49.6333300, 11.0000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34177, 'Möhrenbach', 'Moehrenbach', 'Merenbakh,Mjorenbakh,Mohrenbach,Möhrenbach,mo he lun ba he,Меренбах,Мёренбах,默赫伦巴赫', 50.6233500, 10.9956500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34178, 'Möhnsen', 'Mohnsen', 'Mohnsen,Möhnsen', 53.5666700, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34179, 'Mohlsdorf', 'Mohlsdorf', 'Mohlsdorf', 50.6697400, 12.2651900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34180, 'Möhlau', 'Moehlau', 'Mohlau,Möhlau', 51.7312600, 12.3528200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34181, 'Möglingen', 'Moglingen', 'Meglingen,Mjoglingen,Moeglingen,Möglingen,mo ge lin gen,mwglyngn,Меглинген,Меглінген,Мёглинген,موگلینگن,默格林根', 48.8874100, 9.1269400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34182, 'Mögglingen', 'Mogglingen', 'Megglingen,Meglingen,Mjogglingen,Moegglingen,Mögglingen,meglingeni,Мегглінген,Меглинген,Мёгглинген,მეგლინგენი', 48.8232000, 9.9625000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34183, 'Mogendorf', 'Mogendorf', 'Mogendorf,mo gen duo fu,Могендорф,莫根多夫', 50.4944400, 7.7597200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34184, 'Moers', 'Moers', 'Gorad Mjors,M''ors,Mers,Mersas,Meurs,Mjors,Moers,Mors,Mörs,Mėrsas,ZON,meirs,mo er si,moeleuseu,mwrz,mwyrs,myrs,Горад Мёрс,Мерс,Морс,Мьорс,Мёрс,مئرس,مورز,مويرس,เมิร์ส,默爾斯,뫼르스', 51.4534200, 6.6326000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34185, 'Mödingen', 'Moedingen', 'Medingen,Mjodingen,Myodingen,mo ding gen,mwdyngn,Мединген,Медінген,Мёдинген,Մյոդինգեն,مودینگن,默丁根', 48.6432700, 10.4317300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34186, 'Mockrehna', 'Mockrehna', 'Mokrena,mo ke lei na,Мокрена,莫克雷纳', 51.5075700, 12.8141800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34187, 'Möckmühl', 'Mockmuhl', 'Mekmil,Mekmjul'',Mjokmjul'',Mockmuhl,Moeckmuehl,Möckmühl,mekkumyuru,mo ke mi he er,mwkmwl,Мекмил,Мекмюль,Мёкмюль,موكمول,موکمول,メックミュール,默克米赫尔', 49.3249000, 9.3583700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34188, 'Möckern', 'Moeckern', 'M''okern,Mekern,Mjokkern,Mockern,Moeckern,Möckern,Tessen,mo ke er en,mwkrn,Мекерн,Мьокерн,Мёккерн,Тессен,موكرن,موکرن,默克尔恩', 52.1409900, 11.9520300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34189, 'Möckern', 'Moeckern', '', 50.8500000, 11.7666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34190, 'Mochau', 'Mochau', '', 51.1333300, 13.1833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34191, 'Moabit', 'Moabit', 'Berlin-Moabit,Maabit,Moabit,Маабіт,Моабит', 52.5263500, 13.3390300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34192, 'Mixdorf', 'Mixdorf', 'Miksdorf,mi ke si duo fu,Миксдорф,Միքսդորֆ,米克斯多夫', 52.2000000, 14.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34193, 'Mitwitz', 'Mitwitz', 'Mitvic,Mitwitz,mi te wei ci,mitovu~ittsu,Митвиц,Мітвіц,Միթվից,ミトヴィッツ,米特维茨', 50.2511100, 11.2081800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34194, 'Mittweida', 'Mittweida', 'Mittweida,Mitvajda,Mitveida,mi te wei da,mytfayda,mytwyda,Митвайда,Митвајда,Мітвайда,ميتفايدا,میتویدا,米特魏达', 50.9862200, 12.9753700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34195, 'Mitterteich', 'Mitterteich', 'Miederdeich,Mitertajkh,Mittertajkh,Mitterteich,mi te er tai xi,mytrtaysh,Митертајх,Миттертайх,Міттертайх,Միթերթայխ,ميترتايش,میترتایش,米特尔泰希', 49.9514100, 12.2420600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34196, 'Mitterskirchen', 'Mitterskirchen', 'Miterskirkhen,Mittaskircha,Mitterskirkhen,mi te er si ji er xing,mytrskyrshn,Митерскирхен,Миттерскирхен,Міттерскірхен,Միթերսկիրխեն,میترسکیرشن,米特尔斯基尔兴', 48.3500000, 12.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34197, 'Mitterfels', 'Mitterfels', 'Middafejs,Milerfels,Miterfels,Mitterfel''s,Mitterfels,mi te er fei er si,mytrfls,Митерфелс,Миттерфельс,Міттерфельс,میترفلس,米特尔费尔斯', 48.9763300, 12.6784800, 'DE', '2014-08-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34198, 'Mittenwalde', 'Mittenwalde', '', 53.1833300, 13.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34199, 'Mittenwalde', 'Mittenwalde', 'Chudowina,Mitenvalde,Mittenval''de,mytnfaldt,mytnwaldh,Митенвалде,Миттенвальде,Միտենվալդե,ميتنفالدة,میتنوالده', 52.2600700, 13.5394500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34200, 'Mittenwald', 'Mittenwald', 'Mitenvald,Mittawoid,Mittenval''d,QWD,mi teng wa er de,mitten''vu~aruto,mytnwald,Митенвалд,Миттенвальд,Міттенвальд,Միթենվալդ,מיטנוואלד,میتنوالد,ミッテンヴァルト,米滕瓦尔德', 47.4422000, 11.2618700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34201, 'Mittenaar', 'Mittenaar', 'Mitenar,Mittenaar,Mittenar,mi te na er,Митенар,Миттенар,Міттенаар,米特纳尔', 50.7000000, 8.3833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34202, 'Mittelstrimmig', 'Mittelstrimmig', 'Mitelstrimig,Mittel''shtrimmig,Mittelstrimmig,mi te er si te li mi xi,Мителстримиг,Миттельштриммиг,米特尔斯特里米希', 50.0833300, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34203, 'Mittelstetten', 'Mittelstetten', '', 48.2500000, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34204, 'Mittelstenahe', 'Mittelstenahe', '', 53.6500000, 9.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34205, 'Mittelsömmern', 'Mittelsommern', '', 51.2000000, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34206, 'Mittelsinn', 'Mittelsinn', 'Mitelzin,Mittel''zin,Mittel''zinn,Mittelsin,Mittelsinn,Mittlesin,mi te er xin,Мителзин,Миттельзин,Міттельзінн,Միթելզին,米特尔辛', 50.1922300, 9.6169900, 'DE', '2013-02-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34207, 'Mittelschöntal', 'Mittelschontal', 'Schontal,Schöntal', 48.9461500, 9.3952000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34208, 'Mittelreidenbach', 'Mittelreidenbach', '', 49.7263800, 7.4417000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34209, 'Mittelpöllnitz', 'Mittelpollnitz', 'Mitelpelnic,Mittel''pjol''nic,Mittelpollnitz,Mittelpöllnitz,mi te er po er ni ci,Мителпелниц,Миттельпёльниц,米特尔珀尔尼茨', 50.7500000, 11.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34210, 'Mittelnkirchen', 'Mittelnkirchen', '', 53.5422500, 9.6231900, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34211, 'Mittelneufnach', 'Mittelneufnach', '', 48.1764200, 10.5975400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34212, 'Mittelhof', 'Mittelhof', 'Mittelhof', 50.7751700, 7.8046600, 'DE', '2012-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34213, 'Mittelherwigsdorf', 'Mittelherwigsdorf', 'Mitelkhervigsdorf,Mittel''khervigsdorf,Mittelherwigsdorf,Mittelherwigsdorfi vald,mi te er hei er wei ge si duo fu,Мителхервигсдорф,Миттельхервигсдорф,米特尔黑尔维格斯多夫', 50.9166700, 14.7666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34214, 'Mitteleschenbach', 'Mitteleschenbach', 'Miteleshenbakh,Mitelsenbax,Mitteleshenbakh,mi te lai shen ba he,mitteruesshenbahha,Мителешенбах,Миттелешенбах,Міттелешенбах,Միտելշենբախ,ミッテルエッシェンバッハ,米特莱申巴赫', 49.2118600, 10.7978400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34215, 'Mittelbrunn', 'Mittelbrunn', '', 49.3666700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34216, 'Mittelbiberach', 'Mittelbiberach', 'Mitelbiberakh,Mittel''biberakh,mi te er bi bei la,Мителбиберах,Миттельбиберах,Міттельбіберах,Միթելբիբերախ,მიტელბიბერახი,米特尔比贝拉', 48.0833300, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34217, 'Mittegroßefehn', 'Mittegrossefehn', 'Grossefehn,Mittegrossefehn,Mittegroßefehn', 53.3916500, 7.5660200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34218, 'Mistelgau', 'Mistelgau', 'Mistel''gau,Mistelgau,mi si te er gao,misuterugau,Мистелгау,Мистельгау,Містельгау,Միսթելգաու,ミステルガウ,米斯特尔高', 49.9126000, 11.4658600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34219, 'Mistelbach', 'Mistelbach', '', 49.9126000, 11.5126400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34220, 'Misselwarden', 'Misselwarden', '', 53.6752600, 8.5164600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34221, 'Misselberg', 'Misselberg', '', 50.3069400, 7.7694400, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34222, 'Mirow', 'Mirow', '', 53.5051000, 11.5029400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34223, 'Mintraching', 'Mintraching', 'Mintrakhing,ming te la xing,myntrakhyng,Минтрахинг,Мінтрахінг,Մինթրախինգ,مینتراخینگ,明特拉兴', 48.9535700, 12.2420900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34224, 'Minheim', 'Minheim', '', 49.8649300, 6.9369200, 'DE', '2012-09-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34225, 'Minfeld', 'Minfeld', 'Minfel''d,Minfeld,ming fei er de,Минфелд,Минфельд,明费尔德', 49.0716700, 8.1452800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34226, 'Minderlittgen', 'Minderlittgen', '', 50.0166700, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34227, 'Minden', 'Minden', 'Minden,Minn,min dein,minden,ming deng,mndn,myndn,Минден,Мінден,مندن,میندن,มินเดิน,ミンデン,明登', 52.2895300, 8.9145500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34228, 'Minden', 'Minden', '', 49.8333300, 6.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34229, 'Mindelstetten', 'Mindelstetten', 'Mindel''shtetten,Mindelshteten,Mindelsteten,ming de er si te teng,myndlshttn,Минделштетен,Миндельштеттен,Міндельштеттен,Մինդելշտետեն,میندلشتتن,明德尔斯特滕', 48.8500000, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34230, 'Mindelheim', 'Mindelheim', 'Mindel''gajm,Mindel''khajm,Mindelhaym,Mindelheim,Mindelhemium,Mindelkhajm,mindelhaimi,ming de er hai mu,myndlhaym,Минделхајм,Миндельхайм,Міндельгайм,Մինդելհայմ,ميندلهايم,میندلهایم,მინდელჰაიმი,明德尔海姆', 48.0457800, 10.4922200, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34231, 'Milz', 'Milz', 'Milz', 50.3776000, 10.5375700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34232, 'Groß Miltzow', 'Gross Miltzow', 'Gros Milcov,Gros-Mil''cov,Gross Miltzow,Groß Miltzow,Miltzow,da mi er cuo,Грос Милцов,Грос-Мильцов,大米尔措', 53.5356500, 13.5935400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34233, 'Miltenberg', 'Miltenberg', 'Mil''tenberg,Miltenberg,mi er teng bei ge,mirutenberuku,myltnbrg,myltnbrgh,Милтенберг,Мильтенберг,Мільтенберг,Միլթենբերգ,ميلتنبرغ,میلتنبرگ,ミルテンベルク,米尔滕贝格', 49.7045200, 9.2672500, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34234, 'Miltach', 'Miltach', 'Mil''takh,Miltakh,mi er ta,Милтах,Мильтах,Мільтах,Միլթախ,米尔塔', 49.1619600, 12.7684300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34235, 'Milmersdorf', 'Milmersdorf', 'Mil''mersdorf,Milmersdorf,mi er mei er si duo fu,Милмерсдорф,Мильмерсдорф,Мільмерсдорф,Միլմերսդորֆ,米尔梅尔斯多夫', 53.1118500, 13.6415000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34236, 'Mildstedt', 'Mildstedt', 'Melst,Mil''dshtedt,Mildshtet,Mildsted,Mildstedt,mi er ci te,Милдштет,Мильдштедт,米尔茨特', 54.4666700, 9.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34237, 'Mildenau', 'Mildenau', 'Mil''denau,Mildenau,Mildenau vald,mi er de nao,Милденау,Мильденау,米尔德瑙', 50.5868900, 13.0726300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34238, 'Milda', 'Milda', '', 50.8559200, 11.4635500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34239, 'Mihla', 'Mihla', 'Mila,Мила', 51.0761700, 10.3317500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34240, 'Mietingen', 'Mietingen', 'Mitingen,mi ting gen,Митинген,Мітінген,Միտինգեն,მიტინგენი,米廷根', 48.1833300, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34241, 'Mieste', 'Mieste', '', 52.4822600, 11.2064000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34242, 'Miesitz', 'Miesitz', 'Miesitz', 50.7333300, 11.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34243, 'Miesbach', 'Miesbach', 'Gorad Misbakh,Miaschboch,Misbakh,Misbax,mi si ba,myzbakh,Горад Місбах,Мисбах,Місбах,Միսբախ,ميزباخ,میزباخ,米斯巴', 47.7890300, 11.8338200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34244, 'Miellen', 'Miellen', '', 50.3333300, 7.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34245, 'Mielkendorf', 'Mielkendorf', 'Mielkendorf', 54.2833300, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34246, 'Miehlen', 'Miehlen', '', 50.2257400, 7.8319600, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34247, 'Midlum', 'Midlum', '', 54.7151000, 8.5216100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34248, 'Midlum', 'Midlum', '', 53.7313500, 8.6169500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34249, 'Mickhausen', 'Mickhausen', 'Mikgauzen,Mikhauzen,Mikkhauzen,mi ke hao sen,Микхаузен,Мікгаузен,Միկհաուզեն,米克豪森', 48.2417100, 10.6402600, 'DE', '2017-04-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34250, 'Michendorf', 'Michendorf', 'Mikhendorf,mi xing duo fu,Михендорф,米兴多夫', 52.3135200, 13.0299600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34251, 'Michelstadt', 'Michelstadt', 'Gorad Mikhel''shtat,Michelstadt,Mikhel''shtadt,Mikhelshhat,Mikhelshtat,mi xie er si ta te,mihyerushutatto,myshlshtat,Горад Міхельштат,Михелштат,Михелщат,Михельштадт,Міхельштадт,מיכלשטאט,ميشلشتات,میشل‌اشتات,ミヒェルシュタット,米歇尔斯塔特', 49.6756900, 9.0037300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34252, 'Michelsneukirchen', 'Michelsneukirchen', 'Mikhel''snojkirkhen,Mikhelsnojkirkhen,Mixelsnoykirxen,mi xie er si nuo yi ji xing,Михелснојкирхен,Михельснойкирхен,Міхельснойкірхен,Միխելսնոյկիրխեն,米歇尔斯诺伊基兴', 49.1229100, 12.5528400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34253, 'Michelfeld', 'Michelfeld', 'Michelfeld,Mikhel''fel''d,Mikhelfeld,mi xie er fei er de,mihyeruferuto,Михелфелд,Михельфельд,Міхельфельд,ミヒェルフェルト,米歇尔费尔德', 49.0975000, 9.6786100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34254, 'Michelbach an der Bilz', 'Michelbach an der Bilz', 'Michelbach,Michelbach an der Bilz,Mikhel''bakh-an-der-Bil''c,Mikhel''bakh-na-Bil''ce,Mikhelbakh an der Bilc,mi xie er ba an de er bi er ci,Михелбах ан дер Билц,Михельбах-на-Бильце,Міхельбах-ан-дер-Більц,ミヒェルバッハ・アン・デア・ビルツ,米歇尔巴安德尔比尔茨', 49.0702800, 9.7625000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34255, 'Michelbach', 'Michelbach', '', 50.0166700, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34256, 'Michelau', 'Michelau', '', 50.1623300, 11.1120700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34257, 'Michelau', 'Michelau', '', 49.9055600, 10.4306400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34258, 'Meyn', 'Meyn', 'Meyn', 54.7580200, 9.2226100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34259, 'Meyenburg', 'Meyenburg', '', 53.0452400, 14.2369100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34260, 'Meuspath', 'Meuspath', '', 50.3500000, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34261, 'Meuselwitz', 'Meuselwitz', 'Meuselwitz,Mojzel''vic,Mojzelvic,mo yi sai er wei ci,mwyzlfyts,mwyzlwyts,Мойзельвиц,Мојзелвиц,مويزلفيتس,مویزلویتس,莫伊塞尔维茨', 51.0431500, 12.2993500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34262, 'Meuselbach', 'Meuselbach', 'Meuselbach,Meuselbach-Schwarzmuhle,Meuselbach-Schwarzmühle', 50.5715200, 11.0914300, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34263, 'Meusebach', 'Meusebach', 'Meusebach', 50.8166700, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34264, 'Meura', 'Meura', 'Meura,Mojra,mo yi la,Мойра,Мојра,莫伊拉', 50.5833300, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34265, 'Meudt', 'Meudt', '', 50.4988900, 7.8950000, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34266, 'Metzingen', 'Metzingen', 'Gorad Mecyngen,Mecingen,Mecingene,Metcingen,Metsin''nken,mai qin gen,mtsyngn,mtznjn,Μέτσινγκεν,Горад Мецынген,Метцинген,Мецинген,متزنجن,متسینگن,麦琴根', 48.5369500, 9.2833000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34267, 'Metzenhausen', 'Metzenhausen', '', 49.9666700, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34268, 'Metzels', 'Metzels', '', 50.6469600, 10.4345700, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34269, 'Mettweiler', 'Mettweiler', '', 49.5833300, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34270, 'Mettmann', 'Mettmann', 'Metman,Mettman,Mettmann,mei te man,mtman,Метман,Меттман,متمان,梅特曼', 51.2504000, 6.9753600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34271, 'Mettlach', 'Mettlach', 'Metlakh,Mettlakh,mei te la,mtlakh,Метлах,Меттлах,متلاخ,მეტლახი,梅特拉', 49.4935500, 6.5968600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34272, 'Mettingen', 'Mettingen', 'Metingen,Mettingen,mei ting gen,Метинген,Меттинген,Меттінген,梅廷根', 52.3166700, 7.7833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34273, 'Metterich', 'Metterich', '', 49.9800000, 6.5894400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34274, 'Mettenheim', 'Mettenheim', '', 49.7400000, 8.3258300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34275, 'Mettenheim', 'Mettenheim', '', 48.2666700, 12.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34276, 'Mettendorf', 'Mettendorf', '', 49.9478400, 6.3300300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34277, 'Metten', 'Metten', 'Meten,Metten,mei teng,mtn,Метен,Меттен,Մեթեն,متن,梅滕', 48.8551200, 12.9155400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34278, 'Metelen', 'Metelen', 'Metelen,mei te lun,Метелен,梅特伦', 52.1443400, 7.2127000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34279, 'Meßstetten', 'Messstetten', 'Messstetten,Messstettin,Meßstetten,Meßstettin', 48.1831700, 8.9656500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34280, 'Meßkirch', 'Messkirch', 'Meskirkh,Messkirch,Messkirkh,Meßkirch,mei si ji xi,mesukiruhi,mskyrsh,Мескирх,Месскирх,مسکیرش,メスキルヒ,梅斯基希', 47.9945700, 9.1147900, 'DE', '2013-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34281, 'Messingen', 'Messingen', '', 52.4666700, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34282, 'Messerich', 'Messerich', '', 49.9333300, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34283, 'Messenkamp', 'Messenkamp', '', 52.2600200, 9.3801800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34284, 'Messel', 'Messel', 'Mesel,Messel'',mei sai er,messeru,Месел,Мессель,メッセル,梅塞尔', 49.9383300, 8.7405600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34285, 'Mesenich', 'Mesenich', '', 50.1000000, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34286, 'Mesekenhagen', 'Mesekenhagen', 'Mezekenkhagen,mei sai ken ha gen,Мезекенхаген,梅塞肯哈根', 54.1484600, 13.3184300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34287, 'Mescherin', 'Mescherin', 'Meserin,Mesherin,mei she lin,Мешерин,Мешерін,Մեշերին,梅舍林', 53.2472400, 14.4300300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34288, 'Meschede', 'Meschede', 'Meschede,Meshede,mei she de,mshdh,myshydh,Мешеде,مشده,ميشيده,梅舍德', 51.3502000, 8.2833200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34289, 'Merzweiler', 'Merzweiler', 'Mercvajler,mei er ci wei lei,Мерцвайлер,Мерцвајлер,梅尔茨韦勒', 49.6666700, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34290, 'Merzkirchen', 'Merzkirchen', 'Merckirkhen,mei er ci ji er xing,Мерцкирхен,梅尔茨基尔兴', 49.5833300, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34291, 'Merzig', 'Merzig', 'Mercig,Mercige,Merzig,Merzig am Saar,mei er qi xi,mertsigi,merutsu~ihi,mrtsyg,mrtsygh,mrzyg,Мерциг,Мерциге,Мерціг,מרציג,مرتسيغ,مرتسیگ,მერციგი,メルツィヒ,梅尔齐希', 49.4433100, 6.6387400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34292, 'Merzhausen', 'Merzhausen', 'Mercgauzen,Merckhauzen,Merzhausen,mei er ci hao sen,Мерцгаузен,Мерцхаузен,Մերցհաուզեն,梅尔茨豪森', 47.9666700, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34293, 'Merzenich', 'Merzenich', 'Mercenikh,mei er ce ni xi,Мерцених,Мерценіх,梅尔策尼希', 50.8268100, 6.5249300, 'DE', '2011-12-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34294, 'Merzen', 'Merzen', 'Mercen,mei er cen,Мерцен,梅尔岑', 52.4833300, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34295, 'Merzdorf', 'Merzdorf', '', 51.4000000, 13.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34296, 'Merzalben', 'Merzalben', 'Mercal''ben,Mercalben,Merzalwe,mei er cha er ben,Мерцалбен,Мерцальбен,梅尔察尔本', 49.2446700, 7.7307700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34297, 'Merxheim', 'Merxheim', 'Merkskhajm,mei er ke si hai mu,Мерксхайм,Мерксхајм,梅尔克斯海姆', 49.7929700, 7.5601000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34298, 'Mertloch', 'Mertloch', '', 50.2694800, 7.3081400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34299, 'Mertingen', 'Mertingen', 'Mertingen,mei er ting gen,merutingen,Мертинген,Мертінген,Մերթինգեն,メルティンゲン,梅尔廷根', 48.6569500, 10.8055700, 'DE', '2012-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34300, 'Mertesheim', 'Mertesheim', '', 49.5716700, 8.1355600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34301, 'Mertesdorf', 'Mertesdorf', 'Mertesdorf,mei er te si duo fu,Мертесдорф,მერტესდორფი,梅尔特斯多夫', 49.7721200, 6.7329000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34302, 'Mertendorf', 'Mertendorf', 'Mertendorf,Mertendorf (Naumburg),Mertendorf (bei Naumburg),Mirtendorp [a. 1206],mei er teng duo fu,Мертендорф,Мертендорф (Наумбург),梅尔滕多夫', 51.1188300, 11.8583700, 'DE', '2014-12-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34303, 'Mertendorf', 'Mertendorf', '', 51.0000000, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34304, 'Merseburg', 'Merseburg', 'Mersebourg,Merseburg,Merseburga,Merzeburg,Mjezybor,mei ze bao,mrsybwrgh,mrzbwrg,Мерзебург,מרזבורג,مرسيبورغ,梅泽堡', 51.3547800, 11.9892300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34305, 'Merschbach', 'Merschbach', '', 49.8000000, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34306, 'Mermuth', 'Mermuth', '', 50.1666700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34307, 'Merlscheid', 'Merlscheid', '', 50.1333300, 6.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34308, 'Merklingen', 'Merklingen', 'Merklingen,mei er ke lin gen,Мерклинген,Мерклінген,Մերկլինգեն,მერკლინგენი,梅尔克林根', 48.5113500, 9.7549600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34309, 'Merkendorf', 'Merkendorf', 'Merkendorf,Merkendorf i Mittelfranken,merukendorufu,mrkndwrf,Меркендорф,مرکندورف,メルケンドルフ', 49.2036100, 10.7041600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34310, 'Merkenbach', 'Merkenbach', '', 50.6562600, 8.2951300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34311, 'Merkelbach', 'Merkelbach', 'Merkelbach,Merkelbeck', 50.6455600, 7.7697200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34312, 'Mering', 'Mering', 'Mering,Moringen,mei lin,meringu,Меринг,Мерінг,メーリング,梅林', 48.2656000, 10.9846100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34313, 'Merenberg', 'Merenberg', 'Merenberg,mei lun bei ge,Меренберг,Меренберґ,梅伦贝格', 50.5070700, 8.1919400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34314, 'Merdingen', 'Merdingen', 'Merdingen,mei er ding gen,Мердинген,Мердінген,Մերդինգեն,梅尔丁根', 48.0166700, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34315, 'Merchweiler', 'Merchweiler', 'Merkhvajler,mei er xi wei lei,Мерхвайлер,Мерхвајлер,梅尔希韦勒', 49.3500000, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34316, 'Merching', 'Merching', 'Merkhing,Merxing,mei er xing,meruhingu,Мерхинг,Мерхінг,Մերխինգ,メルヒング,梅尔兴', 48.2459400, 10.9853000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34317, 'Meppen', 'Meppen', 'Mepen,Meppen,mbn,mpn,Мепен,Меппен,مبن,مپن', 52.6906400, 7.2909700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34318, 'Menteroda', 'Menteroda', 'Menteroda,men te luo da,Ментерода,门特罗达', 51.3076300, 10.5632300, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34319, 'Menslage', 'Menslage', 'Menslage,men si la ge,Менслаге,门斯拉格', 52.6833300, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34320, 'Menningen', 'Menningen', '', 49.8333300, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34321, 'Mengkofen', 'Mengkofen', 'Mengofen,Menkofen,men ke fen,mngkwfn,Менгофен,Менкофен,Մենգոֆեն,منگکوفن,门科芬', 48.7189400, 12.4404700, 'DE', '2012-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34322, 'Mengerskirchen', 'Mengerskirchen', 'Mengerskirchen,Mengerskirkhen,men ge er si ji xing,Менгерскирхен,Менгерскірхен,门格尔斯基兴', 50.5639200, 8.1555500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34323, 'Mengersgereuth-Hämmern', 'Mengersgereuth-Haemmern', 'Mengersgereuth,Mengersgereuth-Hammern,Mengersgereuth-Hämmern,Mengersgerojt-Khemern,Mengersgerojt-Khemmern,Менгерсгеройт-Хеммерн,Менгерсгеројт-Хемерн', 50.3973000, 11.1164900, 'DE', '2017-07-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34324, 'Mengerschied', 'Mengerschied', '', 49.9166700, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34325, 'Mengenich', 'Mengenich', 'Bocklemuend,Bocklemuend / Mengenich,Bocklemünd,Bocklemünd / Mengenich,Mengenich', 50.9785000, 6.8673700, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34326, 'Mengen', 'Mengen', 'Mengen,men gen,mngn  alman,Менген,منگن، آلمان,门根', 48.0495100, 9.3300500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34327, 'Mendig', 'Mendig', 'Mendig,Mending,men di xi,mendihi,mndyg,mndygh,Мендиг,منديغ,مندیگ,メンディヒ,门迪希', 50.3666700, 7.2833300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34328, 'Menden', 'Menden', 'Menden,Mennen,men deng,mndn,Менден,مندن,门登', 51.4433700, 7.7782500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34329, 'Memmingerberg', 'Memmingerberg', 'Memingerberg,Memmingerberg,mei ming ge bei ge,Мемингерберг,Меммингерберг,Меммінгерберг,Մեմինգերբերգ,梅明格贝格', 47.9880300, 10.2229500, 'DE', '2012-11-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34330, 'Memmingen', 'Memmingen', 'FMM,Gorad Memingen,Memingen,Memmingen,mei ming gen,memingen,mmyngn,Горад Мемінген,Меминген,Мемминген,Меммінген,ممینگن,ሜሚንገን,メミンゲン,梅明根', 47.9837200, 10.1852700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34331, 'Memmelsdorf', 'Memmelsdorf', 'Memelsdorf,Memmel''sdorf,mei mo er si duo fu,menmerusudorufu,Мемелсдорф,Меммельсдорф,Մեմելսդորֆ,メンメルスドルフ,梅默尔斯多夫', 49.9301200, 10.9592100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34332, 'Melsungen', 'Melsungen', 'Mel''zungen,Melsungen,Melzungen,mei er song gen,meruzungen,mlzwnghn,mlzwngn,Мелзунген,Мельзунген,Մելզունգեն,ملزونغن,ملزونگن,メルズンゲン,梅尔松根', 51.1302900, 9.5523600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34333, 'Melsdorf', 'Melsdorf', 'Melsdorf', 54.3166700, 10.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34334, 'Melsbach', 'Melsbach', '', 50.4833300, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34335, 'Melpers', 'Melpers', '', 50.5500000, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34336, 'Mellrichstadt', 'Mellrichstadt', 'Mel''rikhshtadt,Mell''rikstadt,Mellrichstadt,Melrikhshtat,mei er li xi si ta te,mlrysh ashtat,Мелльрикстадт,Мелрихштат,Мельрихштадт,Мельріхштадт,Մելրիխշթաթ,ملريش اشتات,ملریش‌اشتات,梅尔里希斯塔特', 50.4284900, 10.3033400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34337, 'Mellinghausen', 'Mellinghausen', '', 52.7069700, 8.8970400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34338, 'Mellingen', 'Mellingen', '', 50.9412300, 11.3964000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34339, 'Am Mellensee', 'Am Mellensee', 'Am Melenze,Am-Mellenze,Mellen,a mu mei lun sai,am mlnzh,Ам Мелензе,Ам-Меллензе,Ամ Մելենզե,آم ملنزه,阿姆梅伦塞', 52.1833300, 13.4000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34340, 'Mellenbach-Glasbach', 'Mellenbach-Glasbach', 'Melenbakh-Glasbakh,Mellenbach-Glasbach,Mellenbakh-Glasbakh,mei lun ba-ge la si ba he,Меленбах-Гласбах,Мелленбах-Гласбах,梅伦巴-格拉斯巴赫', 50.6166700, 11.1000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34341, 'Melle', 'Melle', 'Mele,Melle,Mellea,mei lei,mlh  alman,mylh,Меле,Мелле,مله، آلمان,ميله,梅勒', 52.2019700, 8.3382600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34342, 'Meldorf', 'Meldorf', 'Mel''dorf,Meldoerp,Meldorf,Meldörp,mei er duo fu,mldwrf,Мелдорф,Мельдорф,ملدورف,梅尔多夫', 54.0918200, 9.0687000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34343, 'Melchow', 'Melchow', 'Mel''khov,Melkhov,mei er xiao,Мелхов,Мельхов,Մելչով,梅尔肖', 52.7761300, 13.7064700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34344, 'Melbeck', 'Melbeck', '', 53.1833300, 10.4000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34345, 'Melbach', 'Melbach', '', 50.3790800, 8.8092600, 'DE', '2017-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34346, 'Meitzendorf', 'Meitzendorf', '', 52.2130800, 11.5617400, 'DE', '2014-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34347, 'Meitingen', 'Meitingen', 'Majtingen,Meitinga,Meitingen,mai ting gen,Майтинген,Майтінген,Мајтинген,Մայթինգեն,迈廷根', 48.5458600, 10.8517900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34348, 'Meißenheim', 'Meissenheim', 'Majsengajm,Majsenkhajm,Майсенгайм,Майсенхайм,Мајсенхајм', 48.4103500, 7.7726600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34349, 'Meissen', 'Meissen', 'Majsen,Meissen,Meißen,Mejsen,Misen,Misnia,Misno,Miśnia,Mišno,Míšeň,mai sen,maisen,maysn,mayysn,mi sen,myysn,Майсен,Мајсен,Мейсен,מייסן,مائیسن,مايسن,مایسن,ไมเซน,マイセン,迈森,마이센', 51.1615800, 13.4737000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34350, 'Meisenheim', 'Meisenheim', 'Majzenkhajm,Meisenheim,mai sen hai mu,mayznhaym,Майзенхайм,Мајзенхајм,مايزنهايم,مایزنهایم,迈森海姆', 49.7072100, 7.6676500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34351, 'Meisburg', 'Meisburg', '', 50.1166700, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34352, 'Meiningen', 'Meiningen', 'Mainin''nken,Mainingia,Majningen,Meiningen,Stadt Meiningen,mai ning gen,mainingen,maynynghn,maynyngn,myynyngn,Μάινινγκεν,Майнинген,Майнінген,Мајнинген,מיינינגן,ماينينغن,ماینینگن,マイニンゲン,迈宁根', 50.5678700, 10.4152100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34353, 'Meinheim', 'Meinheim', 'Majngajm,Majnkhajm,Maynhaym,mai yin hai mu,Майнгайм,Майнхайм,Мајнхајм,Մայնհայմ,迈因海姆', 49.0333300, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34354, 'Meinerzhagen', 'Meinerzhagen', 'Majnercgagen,Majnerckhagen,Meinerzhagen,mai nei er ci ha gen,maynrtshaghn,Майнерцгаген,Майнерцхаген,Мајнерцхаген,ماينرتسهاغن,ماینرتس‌هاگن,迈内尔茨哈根', 51.1074000, 7.6483800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34355, 'Meinersen', 'Meinersen', 'Maansse,Maanssen,Maanße,Maanßen,Mansse,Meinsse,Meinße,Mānße', 52.4743600, 10.3524700, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34356, 'Meine', 'Meine', 'Mainum,Majne,mai nei,Майне,Мајне,迈内', 52.3849300, 10.5393200, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34357, 'Meinborn', 'Meinborn', '', 50.5000000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34358, 'Meiderich', 'Meiderich', 'Meiderich,Meiderich/Beeck', 51.4666700, 6.7666700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34359, 'Mehrstetten', 'Mehrstetten', 'Mershteten,Mershtetten,mei er si te teng,Мерштетен,Мерштеттен,梅尔斯特滕,梅爾斯特滕', 48.3760900, 9.5660000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34360, 'Mehringen', 'Mehringen', 'Mehringen', 51.7266300, 11.5126400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34361, 'Mehring', 'Mehring', '', 49.8000000, 6.8333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34362, 'Mehring', 'Mehring', '', 48.1833300, 12.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34363, 'Mehrhoog', 'Mehrhoog', '', 51.7382600, 6.5116400, 'DE', '2012-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34364, 'Mehren', 'Mehren', 'Mehren', 50.6833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34365, 'Mehren', 'Mehren', 'Meren,mei lun,Мерен,梅倫', 50.1833300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34366, 'Mehna', 'Mehna', 'Mehna', 50.9666700, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34367, 'Mehmels', 'Mehmels', '', 50.6333300, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34368, 'Mehltheuer', 'Mehltheuer', '', 50.5453000, 12.0370000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34369, 'Mehlmeisel', 'Mehlmeisel', 'Mel''majzel'',Melmajzel,Melmayzel,mei er mai sai er,merumaizeru,Мелмајзел,Мельмайзель,Մելմայզել,メールマイゼル,梅尔迈塞尔', 49.9742100, 11.8620000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34370, 'Mehlingen', 'Mehlingen', 'Mehlingen,Melingen,Мелинген', 49.4913600, 7.8546700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34371, 'Mehlbek', 'Mehlbek', 'Mehlbek', 54.0045600, 9.4345300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34372, 'Mehlbach', 'Mehlbach', '', 49.5166700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34373, 'Meggerdorf', 'Meggerdorf', 'Meggerdorf', 54.3500000, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34374, 'Megesheim', 'Megesheim', '', 48.9333300, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34375, 'Meezen', 'Meezen', 'Meezen', 54.0500000, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34376, 'Meersburg', 'Meersburg', 'Meersburg,Mersburg,Neersburg,measuburuku,meeoseubuleukeu,meersburgi,mei er si bao,myrzbwrg,Мерсбург,Մեերսբուրգ,میرزبورگ,მეერსბურგი,メーアスブルク,梅尔斯堡,메어스부르크', 47.6941900, 9.2711300, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34377, 'Meerfeld', 'Meerfeld', '', 50.0942100, 6.7565100, 'DE', '2016-10-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34378, 'Meerdorf', 'Meerdorf', 'Maerdoerp,Meerdorp,Märdörp', 52.3458300, 10.3174500, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34379, 'Meerbusch', 'Meerbusch', 'Meerbusch,Merbush,ZOK,mei er bu shi,myrbwsh,Мербуш,ميربوش,میربوش,梅尔布施', 51.2611800, 6.6717000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34380, 'Meerbeck', 'Meerbeck', '', 52.3417400, 9.1506700, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34381, 'Meerane', 'Meerane', 'Meerane,Merane,Meranė,Mērane,mei la nei,myranh,Меране,ميرانه,میرانه,梅拉内', 50.8468800, 12.4647300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34382, 'Meeder', 'Meeder', '', 50.3211800, 10.9069700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34383, 'Medelby', 'Medelby', 'Medelby', 54.8123400, 9.1731400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34384, 'Medebach', 'Medebach', 'Medebach,Medebakh,mdbakh,mei de ba,mydhbakh,Медебах,مدباخ,ميدهباخ,梅德巴', 51.1971300, 8.7063500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34385, 'Meddewade', 'Meddewade', 'Meddewade', 53.8095800, 10.4400500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34386, 'Meddersheim', 'Meddersheim', 'Medderskhajm,Mederskhajm,mei de er si hai mu,Меддерсхайм,Медерсхајм,梅德尔斯海姆', 49.7763600, 7.6170800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34387, 'Medard', 'Medard', 'Medard,mei da er de,Медард,梅达尔德', 49.6666700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34388, 'Mecklenburg', 'Mecklenburg', 'Dorf Mecklenburg,Mecklenburg,Mecklenburg Dorf', 53.8427000, 11.4633000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34389, 'Meckesheim', 'Meckesheim', 'Meckesheim,Mekeskhajm,Mekkesgajm,Mekkeskhajm,mei ke si hai mu,mekkesuhaimu,Мекесхајм,Меккесгайм,Меккесхайм,メッケスハイム,梅克斯海姆', 49.3216700, 8.8194400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34390, 'Meckenheim', 'Meckenheim', 'Meckem,Meckenheim,Mekenkhajm,Mekkenkhajm,mei ken hai mu,mknhaym,Мекенхајм,Меккенхайм,مکنهایم,梅肯海姆', 50.6238800, 7.0294200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34391, 'Meckenheim', 'Meckenheim', 'Meckenheim,Meehenheim,Mekkenkhajm,Меккенхайм', 49.4044400, 8.2391700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34392, 'Meckenbeuren', 'Meckenbeuren', 'Meckenbeuren,Mekenbojren,Mekkenbojren,mei ken bo yi lun,Мекенбојрен,Меккенбойрен,Մեքենբոյրեն,მეკენბოირენი,梅肯博伊伦', 47.7000000, 9.5666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34393, 'Meckenbach', 'Meckenbach', '', 49.7833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34394, 'Meckenbach', 'Meckenbach', '', 49.6166700, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34395, 'Meckel', 'Meckel', '', 49.8897700, 6.5171200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34396, 'Mechterstädt', 'Mechterstaedt', 'Mechterstadt,Mechterstaedt,Mechterstädt,Mekhtershtedt,Mekhtershtet,Мехтерштедт,Мехтерштет', 50.9420100, 10.5238000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34397, 'Mechtersen', 'Mechtersen', 'Mechtsen,Mekhterzen,mei xi te er sen,Мехтерзен,梅希特尔森', 53.2833300, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34398, 'Mechow', 'Mechow', '', 53.7166700, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34399, 'Mechernich', 'Mechernich', 'Mechernich,Mekhernikh,mei xie er ni xi,mshrnysh,Мехерних,Мехерніх,مشرنيش,مشرنیش,梅歇尔尼希', 50.5930400, 6.6522400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34400, 'Mechelroda', 'Mechelroda', '', 50.9112600, 11.3780600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34401, 'Mayschoß', 'Mayschoss', 'Majshos,Mayschoss,Mayschoß,mai shao si,Майшос,Мајшос,迈绍斯', 50.5207700, 7.0168800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34402, 'Mayen', 'Mayen', 'Majen,Mayen,mai en,maien,mayn,mayn ,Майен,Майєн,Мајен,ماين,ماین،,マイエン,迈恩', 50.3279700, 7.2227700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34403, 'Maxsain', 'Maxsain', '', 50.5431600, 7.7851200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34404, 'Maxhütte-Haidhof', 'Maxhutte-Haidhof', 'Maksgjutte-Gajdgof,Makskhite-Khajdkhof,Makskhjutte-Khajdkhof,Maxhuette-Haidhof,Maxhutte,Maxhutte-Haidhof,Maxhütte,Maxhütte-Haidhof,ma ke si xu te-hai de huo fu,mkshwth-haydhwf,Максгютте-Гайдгоф,Максхите-Хајдхоф,Максхютте-Хайдхоф,مكسهوته-هايدهوف,مکسهوته-هایدهوف,马克斯许特-海德霍夫', 49.1996300, 12.0922900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34405, 'Maxdorf', 'Maxdorf', 'Maksdorf,ma ke si duo fu,makkusudorufu,Максдорф,マックスドルフ,马克斯多夫', 49.4880600, 8.2916700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34406, 'Mauth', 'Mauth', 'Maut,Mauth,mao te,mawt,Маут,Մաութ,ماوت,毛特', 48.8897200, 13.5845900, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34407, 'Mauschbach', 'Mauschbach', '', 49.1833300, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34408, 'Maulburg', 'Maulburg', 'Maul''burg,Maulburg,mao er bao,Маулбург,Маульбург,毛尔堡', 47.6463100, 7.7821000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34409, 'Maulbronn', 'Maulbronn', 'Maul,Maul''bronn,Maulbron,Maulbronn,mao er bu long,mauruburon,mawlbrwn,Маулброн,Маульбронн,Մաուլբրոն,ماولبرون,マウルブロン,毛尔布龙', 48.9995800, 8.8033700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34410, 'Mauerstetten', 'Mauerstetten', '', 47.8935800, 10.6712700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34411, 'Mauern', 'Mauern', 'Mauehrn,Mauern,Mauren,mao ai er en,mawyrn,Мауерн,Мауэрн,Մաուերն,ماوئرن,毛埃尔恩', 48.5166700, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34412, 'Mauer', 'Mauer', 'Mauehr,Mauer,mao e,maua,Мауер,Мауэр,マウアー,毛厄', 49.3408300, 8.8002800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34413, 'Mauel', 'Mauel', '', 50.0666700, 6.4000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34414, 'Mauden', 'Mauden', '', 50.7166700, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34415, 'Mauchenheim', 'Mauchenheim', '', 49.7180600, 8.0461100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34416, 'Matzerath', 'Matzerath', '', 50.1500000, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34417, 'Matzenbach', 'Matzenbach', 'Macenbakh,Matcenbakh,ma cen ba he,Матценбах,Маценбах,马岑巴赫', 49.5000000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34418, 'Mattstedt', 'Mattstedt', '', 51.0500000, 11.5166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34419, 'Masthorn', 'Masthorn', '', 50.1500000, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34420, 'Mastershausen', 'Mastershausen', 'Masterskhauzen,ma si te er si hao sen,Мастерсхаузен,马斯特尔斯豪森', 50.0666700, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34421, 'Maßweiler', 'Massweiler', 'Massweiler,Maßweiler', 49.2666700, 7.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34422, 'Massing', 'Massing', 'Masing,Massing,Maszing,ma xing,masyng,Масинг,Массинг,Массінг,Մասինգ,ماسینگ,马兴', 48.3911800, 12.6094700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34423, 'Masserberg', 'Masserberg', 'Maserberg,Masserberg,Mazerberg,ma se er bei ge,Мазерберг,Масерберг,Массерберг,马瑟尔贝格', 50.5198100, 10.9708700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34424, 'Massenbachhausen', 'Massenbachhausen', 'Massenbakhgauzen,Massenbakhkhauzen,Mazenbakhauzen,ma sen ba hao sen,massenbahhahauzen,Мазенбахаузен,Массенбахгаузен,Массенбаххаузен,マッセンバッハハウゼン,马森巴豪森', 49.1777800, 9.0433300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34425, 'Maßbach', 'Massbach', 'Masbakh,Masbax,Massbach,Maßbach,ma si ba he,Масбах,Մասբախ,马斯巴赫', 50.1832100, 10.2752200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34426, 'Maselheim', 'Maselheim', 'Mazel''gajm,Mazel''khajm,Mazelhaym,Mazelkhajm,ma sai er hai mu,mazelhaimi,Мазелхајм,Мазельгайм,Мазельхайм,Մազելհայմ,მაზელჰაიმი,马塞尔海姆', 48.1333300, 9.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34427, 'Masburg', 'Masburg', '', 50.2406500, 7.1173600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34428, 'Marzling', 'Marzling', 'Marcling,ma er ci ling,martslyng,Марцлинг,Марцлінг,Մարցլինգ,مارتسلینگ,马尔茨灵', 48.4090400, 11.7938200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34429, 'Marzhausen', 'Marzhausen', '', 50.6911100, 7.7558300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34430, 'Marzahn', 'Marzahn', 'Berlin-Marzahn,marzaہn-ہylrzڈwrf,mrzʼn,מרצאן,مارزاہن-ہیلرزڈورف', 52.5452500, 13.5698300, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34431, 'Marxheim', 'Marxheim', 'Marksgajm,Markskhajm,ma er ke si hai mu,marukusuhaimu,Марксгайм,Марксхайм,Մարքսհայմ,マルクスハイム,马尔克斯海姆', 48.7415300, 10.9450400, 'DE', '2012-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34432, 'Marxen', 'Marxen', '', 53.3121100, 10.0041500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34433, 'Martinstein', 'Martinstein', 'Martinshtajn,ma er ting si tai yin,Мартинштайн,Мартинштајн,马尔廷斯泰因', 49.8000000, 7.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34434, 'Martinshöhe', 'Martinshohe', 'Martinshoehe,Martinshöhe', 49.3666700, 7.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34435, 'Martinsheim', 'Martinsheim', 'Martinsgajm,Martinskhajm,ma er ting si hai mu,Мартинсхайм,Мартинсхајм,Мартінсгайм,Մարթինսհայմ,马尔廷斯海姆', 49.6235000, 10.1487900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34436, 'Martinroda', 'Martinroda', '', 50.8000000, 10.0666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34437, 'Martinroda', 'Martinroda', '', 50.7233400, 10.8890200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34438, 'Martinhagen', 'Martinhagen', '', 51.2868800, 9.2861100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34439, 'Marth', 'Marth', 'Marth', 51.3833300, 10.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34440, 'Martfeld', 'Martfeld', 'Martfel''d,Martfeld,Mattfeld,ma er te fei er de,Мартфелд,Мартфельд,马尔特费尔德', 52.8757200, 9.0608100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34441, 'Martensrade', 'Martensrade', 'Martensrade', 54.2833300, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34442, 'Marsberg', 'Marsberg', 'Eresburg,Marsberg,ma er si bei ge,mrsbwrg,mrsbwrgh,Марсберг,مرسبورغ,مرسبورگ,ማርስበርግ,马尔斯贝格', 51.4617100, 8.8494900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34443, 'Marquartstein', 'Marquartstein', 'Markvartshtajn,Marquartstoa,ma er ku a er ci tai yin,markwartshtayn,Марквартштайн,Марквартштајн,Մարկվարթշթայն,مارکوارتشتاین,马尔库阿尔茨泰因', 47.7585700, 12.4621900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34444, 'Marpingen', 'Marpingen', 'Marpingen,ma er ping gen,Марпинген,Марпінген,马尔平根', 49.4522800, 7.0582000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34445, 'Maroth', 'Maroth', '', 50.5772200, 7.6897200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34446, 'Marolterode', 'Marolterode', '', 51.2333300, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34447, 'Maroldsweisach', 'Maroldsweisach', 'Marol''dsvajzakh,Maroldsvajsakh,Maroldsweisach,ma luo er ci wei sa,Маролдсвајсах,Марольдсвайзах,马罗尔茨魏萨', 50.1957800, 10.6600300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34448, 'Marnheim', 'Marnheim', 'Marnkhajm,ma en hai mu,Марнхайм,Марнхајм,马恩海姆', 49.6327800, 8.0400000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34449, 'Marnerdeich', 'Marnerdeich', 'Marnerdeich', 53.9500000, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34450, 'Marlow', 'Marlow', '', 54.1543900, 12.5726100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34451, 'Marloffstein', 'Marloffstein', 'Marloffshtajn,Marlofshtajn,ma er luo fu si tai yin,marofushutain,Марлоффштайн,Марлофштайн,Марлофштајн,マーロフシュタイン,马尔洛夫斯泰因', 49.6179400, 11.0632300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34452, 'Marl', 'Marl', '', 52.4833300, 8.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34453, 'Marl', 'Marl', 'Alt-Marl,Marl,Marl'',ma er,marl  alman,Марл,Марль,مارل، آلمان,马尔', 51.6567100, 7.0903800, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34454, 'Markvippach', 'Markvippach', 'Marctvipeche [a. 1221],de Vichbeke [a. 1234]', 51.0789400, 11.1749800, 'DE', '2014-12-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34455, 'Marktzeuln', 'Marktzeuln', 'Markcojln,Marktcojl''n,ma er ke cuo yi er en,marktswyln,marukutotsu~oirun,Марктцойльн,Маркцојлн,Մարքթցոյլն,مارکتسویلن,マルクトツォイルン,马尔克措伊尔恩', 50.1667300, 11.1669200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34456, 'Markt Wald', 'Markt Wald', 'Markt Vald,Markt Wald,Markt-Val''d,ma er ke te wa er de,Маркт Валд,Маркт-Вальд,Մարքթ Վալդ,马尔克特瓦尔德', 48.1368000, 10.5819800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34457, 'Marktsteft', 'Marktsteft', 'Marktsteft,Marktstett,ma er ke ci te fu te,marktshtft,Марктстефт,Մարքթսթեֆտ,ماركتشتفت,مارک‌اشتفل,马尔克茨特夫特', 49.6960600, 10.1362600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34458, 'Markt Schwaben', 'Markt Schwaben', 'Markt Shvaben,Markt Swaben,Markt-Shvaben,Schwabe,ma ke te shi wa ben,markt shwabn,Маркт Швабен,Маркт-Швабен,مارکت شوابن,马克特施瓦本', 48.1894900, 11.8691000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34459, 'Marktschorgast', 'Marktschorgast', 'Markchorgast,Marktschorgast,Marktshorgast,ma er ke ci xiao er jia si te,marukutoshorugasuto,Марктшоргаст,Маркчоргаст,Մարքթշորգասթ,マルクトショルガスト,马尔克茨肖尔加斯特', 50.0947500, 11.6546500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34460, 'Marktschellenberg', 'Marktschellenberg', 'Markchelenberg,Marktschellenberg,Marktschellnberg,Marktselenberg,Marktshellenberg,Schellenberg,ma ke te xie lun bei ge,markt shlnbrg,Марктшелленберг,Маркчеленберг,Մարկտշելենբերգ,مارکت شلنبرگ,马克特谢伦贝格', 47.6965700, 13.0434000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34461, 'Markt Rettenbach', 'Markt Rettenbach', 'Markt Retenbakh,Markt Rettenbach,Markt-Rettenbakh,ma er ke te lei teng ba he,Маркт Ретенбах,Маркт-Реттенбах,Մարքթ Ռեթենբախ,马尔克特雷滕巴赫', 47.9473300, 10.3960800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34462, 'Marktredwitz', 'Marktredwitz', 'Harktrednitz,Marktredvic,Marktredwitz,Martredwitz,ma ke te lei de wei ci,marktrdfyts,marukutoredovu~ittsu,Марктредвиц,Марктредвіц,Մարկտրեդվից,ماركتردفيتس,مارک‌ردویتس,マルクトレドヴィッツ,马克特雷德维茨', 50.0044300, 12.0859300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34463, 'Marktoffingen', 'Marktoffingen', '', 48.9256600, 10.4707800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34464, 'Marktoberdorf', 'Marktoberdorf', 'Marktoberdorf,ma ke te ao bo duo fu,markt awbrdwrf,marukutoobadorufu,Марктобердорф,Մարքտոբերդորֆ,ماركت أوبردورف,مارکت‌اوبردورف,マルクトオーバードルフ,马克特奥伯多夫', 47.7796400, 10.6171300, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34465, 'Markt Nordheim', 'Markt Nordheim', 'Markt Nordheim,Markt Nordkhajm,Markt-Nordgajm,Markt-Nordkhajm,ma er ke te nuo er de hai mu,Маркт Нордхајм,Маркт-Нордгайм,Маркт-Нордхайм,Մարքթ Նորդհայմ,马尔克特诺尔德海姆', 49.5909500, 10.3556400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34466, 'Marktleuthen', 'Marktleuthen', 'Marktleuthen,Marktljojten,Marktlojten,Marktlyoyten,ma er ke te luo yi teng,marktlwytn,marukutoroiten,Марктлойтен,Марктлојтен,Марктлёйтен,Մարկտլյոյտեն,ماركتلويتن,مارکت‌لویتن,マルクトロイテン,马尔克特洛伊滕', 50.1300700, 12.0022600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34467, 'Marktleugast', 'Marktleugast', 'Markt Lengast,Marktleugast,Marktljojgast,Marktlojgast,ma er ke te luo yi jia si te,markt lwygast,marukutoroigasuto,Марктлойгаст,Марктлојгаст,Марктлёйгаст,Մարքթլոյգասթ,مارکت لویگاست,マルクトロイガスト,马尔克特洛伊加斯特', 50.1730600, 11.6338900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34468, 'Marktl', 'Marktl', 'Markhl,Marktl,Marktl am Inn,Marktl'',Марктль', 48.2551600, 12.8447000, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34469, 'Markt Indersdorf', 'Markt Indersdorf', 'Markt Indersdorf,Markt-Indersdorf,ma ke te yin de si duo fu,markt ayndrsdwrf,Маркт Индерсдорф,Маркт-Індерсдорф,Маркт-Индерсдорф,Մարկտ Ինդերսդորֆ,مارکت ایندرسدورف,马克特因德斯多夫', 48.3605800, 11.3778900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34470, 'Marktheidenfeld', 'Marktheidenfeld', 'Marktajdenfel''d,Marktgajdenfel''d,Marktheidenfeld,Marktkhajdenfel''d,Marktkhajdenfeld,ma er ke tai deng fei er de,markt haydnfld,Марктайденфельд,Марктгайденфельд,Марктхайденфельд,Марктхајденфелд,Մարքթհայդենֆելդ,ماركت هايدنفلد,مارکت‌هایدنفلد,马尔克泰登费尔德', 49.8454000, 9.6035900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34471, 'Marktgraitz', 'Marktgraitz', 'Marktgraitz,Marktgrajc,ma er ke te ge lai ci,markt grayts,marukutoguraitsu,Марктграйц,Марктграјц,Մարքթգրայց,مارکت گرایتس,マルクトグライツ,马尔克特格赖茨', 50.1835800, 11.1944100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34472, 'Markt Erlbach', 'Markt Erlbach', 'Markt Erlbach,Markt Erlbakh,Markt-Ehrl''bakh,Markt-Erl''bakh,ma er ke te ai er ba he,Маркт Ерлбах,Маркт-Ерльбах,Маркт-Эрльбах,Մարքթ Էրլբախ,马尔克特埃尔巴赫', 49.4936700, 10.6526500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34473, 'Marktbreit', 'Marktbreit', 'Marktbrajt,ma ke te bu lai te,markt brayt,Марктбрайт,Марктбрајт,Մարքթբրայթ,ماركت برايت,مارکت‌برایت,马克特布赖特', 49.6654100, 10.1481100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34474, 'Markt Bibart', 'Markt Bibart', 'Markt Bibart', 49.6478700, 10.4249200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34475, 'Markt Berolzheim', 'Markt Berolzheim', 'Berolzheim,Markt Berolckhajm,Markt-Berol''cgajm,Markt-Berol''ckhajm,ma er ke te bei luo er ci hai mu,Маркт Беролцхајм,Маркт-Берольцгайм,Маркт-Берольцхайм,Մարկտ Բերոլցհայմ,马尔克特贝罗尔茨海姆', 49.0095500, 10.8447300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34476, 'Marktbergel', 'Marktbergel', 'Marktbergel,Marktbergel'',ma ke te bei ge er,Марктбергел,Марктбергель,Մարքթբերգել,马克特贝格尔', 49.4415600, 10.3635500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34477, 'Marksuhl', 'Marksuhl', 'Marksuhl,Marksul,Markzul,Markzul'',ma ke su er,Маркзул,Маркзуль,Марксул,马克苏尔', 50.9166700, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34478, 'Markranstädt', 'Markranstaedt', 'Markranshtedt,Markranshtet,Markranstaedt,Markranstete,Markranstädt,Markranštete,ma ke lan si tai te,markranshtd,markranshtyt,Маркранштедт,Маркранштет,ماركرانشتيت,مارکرانشتد,马克兰斯泰特', 51.3014600, 12.2202000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34479, 'Markneukirchen', 'Markneukirchen', 'Markneikirhene,Markneukirchen,Marknojkirkhen,ma er ke nuo yi ji er xing,marknwykyrshn,Маркнойкирхен,Маркнојкирхен,ماركنويكيرشن,مارک‌نویکیرشن,马尔克诺伊基尔兴', 50.3114400, 12.3295100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34480, 'Marklohe', 'Marklohe', 'Lohe,Markloeh,Marklohe,Marklokhe,ma er ke luo hei,marukuroe,Марклохе,Марклоэ,マルクローエ,马尔克洛黑', 52.6685700, 9.1421900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34481, 'Marklkofen', 'Marklkofen', 'Markl''kofen,Marklkofen,ma er ke er ke fen,marklkwfn,Марклкофен,Марклькофен,Մարքլքոֆեն,مارکلکوفن,马尔克尔科芬', 48.5500000, 12.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34482, 'Markkleeberg', 'Markkleeberg', 'Markkleberg,Markkleeberg,Markkleeberg West,Markleberg,Markleberga,Marklēberga,ma ke lai bei ge,mark klybrgh,Маркклеберг,Марклеберг,مارك كليبرغ,مارک‌کلیبرگ,马克莱贝格', 51.2755000, 12.3690600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34483, 'Märkisches Viertel', 'Markisches Viertel', 'Berlin-Maerkisches Viertel,Berlin-Märkisches Viertel,Markisches Viertel,Märkisches Viertel', 52.5984100, 13.3576600, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34484, 'Markgröningen', 'Markgroningen', 'Markgr''oningen,Markgreningen,Markgrjoningen,Markgroeningen,Markgronningen,Markgröningen,ma er ke ge lei ning gen,markghrwnynghn,Маркгренинген,Маркгрьонинген,Маркгрёнинген,ماركغرونينغن,مارک‌گرونینگن,马尔克格勒宁根', 48.9049300, 9.0805900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34485, 'Markersdorf', 'Markersdorf', '', 51.1333300, 14.8833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34486, 'Markersbach', 'Markersbach', 'Markersbach', 50.5354500, 12.8614900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34487, 'Markdorf', 'Markdorf', 'Markdorf,ma ke duo fu,markdwrf,Маркдорф,Մարկդորֆ,ماركدورف,مارکدورف,მარკდორფი,马克多夫', 47.7191600, 9.3902800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34488, 'Marisfeld', 'Marisfeld', 'Marisfel''d,Marisfeld,ma li si fei er de,Марисфелд,Марисфельд,马里斯费尔德', 50.5558700, 10.5726800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34489, 'Maring-Noviand', 'Maring-Noviand', '', 49.9333300, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34490, 'Marienwerder', 'Marienwerder', '', 52.8420800, 13.5992700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34491, 'Mariental', 'Mariental', 'Mariental,Marienthal', 52.2759300, 10.9837100, 'DE', '2012-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34492, 'Marienrachdorf', 'Marienrachdorf', '', 50.5500000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34493, 'Marienheide', 'Marienheide', 'Marienheide,Marienkhajde,Marijenkhajde,Maringajde,ma lin hai de,Мариенхайде,Маријенхајде,Марінгайде,马林海德', 51.0831700, 7.5308700, 'DE', '2012-06-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34494, 'Marienhausen', 'Marienhausen', '', 50.5638900, 7.6927800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34495, 'Marienhagen', 'Marienhagen', '', 52.0371800, 9.6868500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34496, 'Marienhafe', 'Marienhafe', 'Marienhafe,Marienkhafe,Marinkhafe,Mariënhafe,ma lin ha fei,Мариенхафе,Маринхафе,马林哈费', 53.5227400, 7.2730600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34497, 'Marienfels', 'Marienfels', '', 50.2404000, 7.8132500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34498, 'Marienfelde', 'Marienfelde', 'Berlin-Marienfelde,Marienfel''de,Мариенфельде', 52.4186800, 13.3672300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34499, 'Mariendorf', 'Mariendorf', 'Berlin-Mariendorf,Mariendorf,Мариендорф', 52.4378000, 13.3810900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34500, 'Marienberg', 'Marienberg', 'Marienberg,Marienberga,Marinberg,ma lin bei ge,marynbrg,marynbrgh,Мариенберг,Маринберг,Марієнберг,مارينبرغ,مارینبرگ,马林贝格', 50.6505100, 13.1612200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34501, 'Mariaposching', 'Mariaposching', '', 48.8333300, 12.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34502, 'Margetshöchheim', 'Margetshochheim', 'Margetsgekhgajm,Margetshoechheim,Margetshyoxhaym,Margetshöchheim,Margetskhekhkhajm,Margetskhjokhgajm,Margetskhjokhkhajm,ma er ge ci he xia yi mu,marugetsuhehihaimu,Маргетсгехгайм,Маргетсхеххајм,Маргетсхёхгайм,Маргетсхёххайм,Մարգետսհյոխհայմ,マルゲーツヘーヒハイム,马尔格茨赫夏伊姆', 49.8375000, 9.8638900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34503, 'Marburg an der Lahn', 'Marburg an der Lahn', 'Marbourg,Marburg,Marburg an der Lahn,Marburgo,Marmpournk,maruburuku,Μάρμπουργκ,Марбург,マールブルク', 50.8090400, 8.7706900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34504, 'Marbach am Neckar', 'Marbach am Neckar', 'Gorad Marbakh-na-Nekary,Marbach,Marbach de Neckar,Marbachum,Marbakh na Nekar,Marbakh na Nekaru,Marbakh-am-Nekkar,ma er ba he,marbakh,marbakh am nka,Горад Марбах-на-Некары,Марбах на Некар,Марбах на Некару,Марбах-ам-Неккар,مارباخ,مارباخ آم نکا,مارباخ ئام نێکا,馬爾巴赫', 48.9396400, 9.2599500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34505, 'Manubach', 'Manubach', '', 50.0333300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34506, 'Mantel', 'Mantel', 'Mantel', 49.6541200, 12.0407400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34507, 'Mansfeld', 'Mansfeld', 'Lutherstadt Mansfeld,Mansfel''d,Mansfeld,Mansfeld-Lutherstadt,Manssfeld [a. 1650],Manßfeld [a. 1650],man si fei er de,mansfyld,mansuferuto,manzfyld,Мансфелд,Мансфельд,مانزفیلد,مانسفيلد,マンスフェルト,曼斯费尔德', 51.5923400, 11.4522300, 'DE', '2014-12-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34508, 'Manschnow', 'Manschnow', '', 52.5499000, 14.5533200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34509, 'Mannstedt', 'Mannstedt', '', 51.1333300, 11.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34510, 'Mannheim', 'Mannheim', 'Gorad Mangejm,MHG,Man''chaim,Man''geym,Man''géym,Mangejm,Manhajmi,Manheima,Manheimas,Manhemium,Mankhajm,Mannheim,Monnem,man hai mu,man him,manaha''ima,manhaim,manhaimi,manhaimu,manhaym,mnhyym,Μάνχαϊμ,Горад Мангейм,Мангейм,Манхайм,Манхајм,מנהיים,مانهايم,مانهایم,मानहाइम,มันไฮม์,მანჰაიმი,ማንሃይም,マンハイム,曼海姆,만하임', 49.4891000, 8.4669400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34511, 'Mannebach', 'Mannebach', '', 50.2833300, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34512, 'Mannebach', 'Mannebach', '', 49.6333300, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34513, 'Manhagen', 'Manhagen', 'Manhagen', 54.2000000, 10.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34514, 'Manderscheid', 'Manderscheid', '', 50.0967200, 6.8098100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34515, 'Manderscheid', 'Manderscheid', '', 50.1000000, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34516, 'Mandern', 'Mandern', '', 49.6000000, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34517, 'Mandel', 'Mandel', 'Mandel,Mandel'',man de er,Мандел,Мандель,曼德尔', 49.8549400, 7.7729500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34518, 'Manching', 'Manching', 'IGS,Manhing,Mankhing,man xing,manshyng,Манхинг,Манхінг,Մանհինգ,مانشینگ,曼兴', 48.7165600, 11.4939300, 'DE', '2013-05-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34519, 'Mamming', 'Mamming', 'Maming,Mamming,Maniing,ma ming ge,mamyng,Маминг,Мамминг,Маммінг,Մամինգ,مامینگ,马明格', 48.6517400, 12.6078400, 'DE', '2012-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34520, 'Mammendorf', 'Mammendorf', 'Mamendorf,Mammadarf,Mammendorf,ma men duo fu,mamndwrf,Мамендорф,Маммендорф,Մամենդորֆ,مامندورف,马门多夫', 48.2083600, 11.1632600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34521, 'Mammelzen', 'Mammelzen', '', 50.7000000, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34522, 'Malterdingen', 'Malterdingen', 'Mal''terdingen,Malterdingen,ma er te er ding gen,Малтердинген,Мальтердинген,Мальтердінген,Մալտերդինգեն,马尔特尔丁根', 48.1571900, 7.7860800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34523, 'Malsfeld', 'Malsfeld', 'Mal''sfel''d,Malsfeld,ma er si fei er de,marusuferuto,Малсфелд,Мальсфельд,マールスフェルト,马尔斯费尔德', 51.0908300, 9.5388900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34524, 'Malschwitz', 'Malschwitz', 'Mal''shvic,Malesecy,Malešecy,Malschwitz,Malschwitz/Malesecy,Malschwitz/Malešecy,Malshvic,ma er shi wei ci,Малшвиц,Мальшвиц,Мальшвіц,马尔施维茨', 51.2375900, 14.5216300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34525, 'Malsch', 'Malsch', 'Mal''sh,Malsh,marushu,Малш,Мальш,マルシュ', 49.2472200, 8.6827800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34526, 'Malsch', 'Malsch', '', 48.8833300, 8.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34527, 'Malliß', 'Malliss', 'Malis,Mallis,Malliss,Mallisz,Malliß,ma li si,Малис,Маллис,马利斯', 53.2113200, 11.3271600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34528, 'Malgersdorf', 'Malgersdorf', 'Mal''gersdorf,Malgersdorf,ma er ge si duo fu,malgrsdwrf,Малгерсдорф,Мальгерсдорф,Մալգերսդորֆ,مالگرسدورف,马尔格斯多夫', 48.5333300, 12.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34529, 'Malente', 'Malente', 'Bad Malente,Eutin mit Malente,Malente,ma lun te,Маленте,马伦特', 54.1722600, 10.5596800, 'DE', '2016-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34530, 'Malchow', 'Malchow', 'Mal''khov,Malhova,Malkhov,ma er xiao,malchw,Малхов,Мальхов,مالچو,马尔肖', 53.4747700, 12.4221000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34531, 'Malching', 'Malching', 'Mal''khing,Malkhing,Malxing,ma er xing,malshyng,Малхинг,Мальхинг,Мальхінг,Մալխինգ,مالشینگ,马尔兴', 48.3122600, 13.1874600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34532, 'Malchin', 'Malchin', 'Mal''khin,Malchin,Malhine,Malhīne,Malkhin,ma er xin,malshyn,Малхин,Мальхин,مالشين,مالشین,马尔欣', 53.7399000, 12.7653900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34533, 'Malborn', 'Malborn', '', 49.7166700, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34534, 'Malbergweich', 'Malbergweich', '', 50.0552700, 6.5539400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34535, 'Malberg', 'Malberg', '', 50.0500000, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34536, 'Maitzborn', 'Maitzborn', '', 49.9333300, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34537, 'Maitenbeth', 'Maitenbeth', 'Majtenbet,Moabeth,mai teng bei te,maytnbt,Майтенбет,Мајтенбет,Մայթենբեթ,مایتنبت,迈滕贝特', 48.1505300, 12.0933500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34538, 'Maisborn', 'Maisborn', '', 50.0822900, 7.5813400, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34539, 'Maisach', 'Maisach', '', 48.2166700, 11.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34540, 'Mainzweiler', 'Mainzweiler', '', 49.4171400, 7.1180400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34541, 'Mainz', 'Mainz', 'Gorad Majnc,Maeaenz,Maganza,Magonza,Maguncia,Maguntzia,Magunza,Magúncia,Maianca,Maiança,Mainca,Maincas,Maints,Mainz,Majenco,Majnc,Majnci,Mayence,Mayns,Meenz,Mogontiacum,Moguncia,Moguncja,Moguntiacum,Mogúncia,Mohuc,Mohuč,Määnz,ma''intsa,maincheu,maintsi,maintsu,maynts,maynz,mei yin ci,mins,myynz,Μάιντς,Горад Майнц,Майнц,Мајнц,מיינץ,مائنز,ماينتس,ماینتس,माइंत्स,ไมนซ์,მაინცი,ማይንጽ,マインツ,美因茨,마인츠', 49.9841900, 8.2791000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34542, 'Maintal', 'Maintal', 'Gorad Majntal'',Maintal,Majntal,Majntal'',mai yin ta er,maintaru,mayntal,Μάινταλ,Горад Майнталь,Майнталь,Мајнтал,ماينتال,ماینتال,マインタール,迈因塔尔', 50.1500000, 8.8333300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34543, 'Mainstockheim', 'Mainstockheim', 'Majnshtokgajm,Majnshtokkhajm,Majnstokkhajm,mai yin si tuo ke hai mu,Майнстокхайм,Майнштокгайм,Майнштокхайм,Мајнштокхајм,Մայնսթոքհայմ,迈因斯托克海姆', 49.7715600, 10.1480700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34544, 'Mainleus', 'Mainleus', 'Mainleus,Majnljojs,Majnlojs,Maynloys,mai yin luo yi si,mainroisu,maynlwys,Майнлойс,Майнлёйс,Мајнлојс,Մայնլոյս,ماینلویس,マインロイス,迈因洛伊斯', 50.0998700, 11.3766400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34545, 'Mainhardt', 'Mainhardt', 'Mainhardt,Majngardt,Majnkhardt,mai yin ha er te,mainharuto,Майнгардт,Майнхардт,Мајнхардт,マインハルト,迈因哈尔特', 49.0761100, 9.5563900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34546, 'Mainburg', 'Mainburg', 'Mainburg,Majnburg,Maynburg,Moaburg,mai yin bao,maynbwrg,maynbwrgh,Майнбург,Мајнбург,Մայնբուրգ,ماينبورغ,ماینبورگ,迈因堡', 48.6418200, 11.7809300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34547, 'Mainbernheim', 'Mainbernheim', 'Majnberngajm,Majnbernkhajm,Maynbernhaym,mai yin bei er en hai mu,maynbrnhaym,Майнбернгайм,Майнбернхайм,Мајнбернхајм,Մայնբերնհայմ,ماينبرنهايم,ماینبرنهایم,迈因贝尔恩海姆', 49.7079400, 10.2190000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34548, 'Mainaschaff', 'Mainaschaff', 'Majnashaf,Majnashaff,Maynasaf,mai na sha fu,main''ashaffu,Майнашаф,Майнашафф,Мајнашаф,Մայնաշաֆ,マインアシャッフ,迈纳沙夫', 49.9816700, 9.0900000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34549, 'Maikammer', 'Maikammer', 'Majkamer,Majkammer,mai ka mei er,maikanma,Майкаммер,Мајкамер,マイカンマー,迈卡梅尔', 49.3052800, 8.1316700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34550, 'Maihingen', 'Maihingen', '', 48.9274500, 10.4986700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34551, 'Maierhöfen', 'Maierhofen', 'Maergefen,Maierhofen,Maierhöfen,Majerkhjofen,Majrkhefen,Mayerhofen,Mayerhyofen,Mayerhöfen,mai ai lei fen,Майерхёфен,Маєргефен,Мајрхефен,Մայերհյոֆեն,迈埃勒芬', 47.6500000, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34552, 'Mähring', 'Mahring', 'Mahring,Mering,Mähring,Меринг,Мерінг,Մերինգ', 49.9109500, 12.5244800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34553, 'Mahlsdorf', 'Mahlsdorf', 'Berlin-Mahlsdorf', 52.5093500, 13.6137300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34554, 'Mahlberg', 'Mahlberg', 'Mahlberg,Mal''berg,Malberg,malbrg,malbrgh,Малберг,Мальберг,مالبرغ,مالبرگ', 48.2863900, 7.8141100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34555, 'Magstadt', 'Magstadt', 'Magshtadt,Magshtat,Magstadt,ma ge si ta te,Магштадт,Магштат,Մագշտադտ,მაგშტადტი,马格斯塔特', 48.7447100, 8.9667500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34556, 'Magdeburg', 'Magdeburg', 'CSO,Dzewin,Dźěwin,Gorad Magdehburg,Maagdenburg,Madeborch,Magathaburg [a. 936],Magdeboerj,Magdeborg,Magdeborgh,Magdebourg,Magdebourgo,Magdebuag,Magdeburg,Magdeburga,Magdeburgas,Magdeburgh,Magdeburgo,Magdeburgu,Magdeburgum,Magdeburk,Magdebörj,Makekepuka,Meideborg,Meyburch [a. 1275],ma ge de bao,magadeburga,magdbwrg,magdeburgi,mageudebuleukeu,maghdybwrgh,mak de bur k,makdeburga,makudeburuku,mgdbwrg,Μαγδεβούργο,Горад Магдэбург,Магдебург,מגדבורג,ماغديبورغ,ماگدبورگ,مگڈیبرگ,माक्देबुर्ग,मागदेबुर्ग,มักเดบูร์ก,მაგდებურგი,マクデブルク,马格德堡,마그데부르크', 52.1277300, 11.6291600, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34557, 'Magdala', 'Magdala', '', 50.9069800, 11.4480100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34558, 'Mackenrodt', 'Mackenrodt', '', 49.7166700, 7.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34559, 'Mackenrode', 'Mackenrode', '', 51.3000000, 10.0666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34560, 'Mackenbach', 'Mackenbach', '', 49.4666700, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34561, 'Macken', 'Macken', '', 50.1833300, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34562, 'Machern', 'Machern', 'Macherni vald,Makhern,ma hei er en,Махерн,马黑尔恩', 51.3666700, 12.6333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34563, 'Maasholm', 'Maasholm', 'Maasholm,Masholm,Maskhol''m,Maskholm,ma si huo er mu,Масхолм,Масхольм,马斯霍尔姆', 54.6833300, 9.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34564, 'Maasen', 'Maasen', '', 52.6922000, 8.8845100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34565, 'Maasbüll', 'Maasbuell', 'Masbil,Masbjull'',Masbol,Masbøl,Moosbel,ma si bi er,Масбил,Масбюлль,马斯比尔', 54.7767400, 9.5242400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34566, 'Lykershausen', 'Lykershausen', '', 50.2000000, 7.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34567, 'Lychen', 'Lychen', 'Likhen,Lixen,Lychen,li xing,lwshn,Лихен,Ліхен,Լիխեն,لوشن,利兴', 53.2124200, 13.3148300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34568, 'Luxem', 'Luxem', '', 50.3333300, 7.1000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34569, 'Lützow', 'Luetzow', '', 53.6534500, 11.1758200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34570, 'Lützkampen', 'Lutzkampen', 'Letschkampen,Lickampen,Ljuckampen,Lëtschkampen,lu ci kan peng,Лицкампен,Люцкампен,吕茨坎彭', 50.1500000, 6.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34571, 'Lutzingen', 'Lutzingen', 'Lucingen,Lutcingen,lu qin gen,lwtsyngn,Лутцинген,Луцинген,Լուտցինգեն,لوتسینگن,卢钦根', 48.6500000, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34572, 'Lutzhorn', 'Lutzhorn', '', 53.8249900, 9.7690500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34573, 'Lutzerath', 'Lutzerath', 'Lucerat,Lutcerat,lu ce la te,Лутцерат,Луцерат,卢策拉特', 50.1269500, 7.0074000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34574, 'Lützen', 'Luetzen', 'Licen,Ljutcen,Luetzen,Lützen,lu cen,lwtsn,Лицен,Лютцен,لوتسن,吕岑', 51.2567100, 12.1416400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34575, 'Lützelbach', 'Luetzelbach', '', 49.7423300, 8.7668700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34576, 'Lütz', 'Lutz', 'Luetz,Lütz', 50.1666700, 7.3500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34577, 'Lutterbek', 'Lutterbek', 'Lutterbek', 54.4000000, 10.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34578, 'Lutter am Barenberge', 'Lutter am Barenberge', 'Luter am Barenberge,Luter na Barenberge,Lutter,Lutter am Barenberge,Lutter am Barje,Lutter an Barenbarge,Lutter-am-Barenberge,Luttere [a. 1270],Lutterun [~ a. 1000],ba lun shan lu lu te,Лутер ам Баренберге,Лутер на Баренберге,Луттер-ам-Баренберге,巴伦山麓卢特', 51.9894300, 10.2693000, 'DE', '2011-03-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34579, 'Lutter', 'Lutter', '', 51.3333300, 10.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34580, 'Lütjenwestedt', 'Lutjenwestedt', 'Luetjenwestedt,Lutjenwestedt,Lütjenwestedt', 54.1333300, 9.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34581, 'Lütjensee', 'Lutjensee', 'Luetjensee,Lutiensee,Lutjensee,Lütiensee,Lütjensee', 53.6500000, 10.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34582, 'Lütjenholm', 'Luetjenholm', 'Lutjenholm,Lütjenholm', 54.6833300, 9.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34583, 'Lütjenburg', 'Luetjenburg', 'Litjenburg,Ljutenburg,lu te yan bao,lwtynbwrg,lwtynbwrgh,Литјенбург,Лютенбург,لوتينبورغ,لوتینبورگ,吕特延堡', 54.2918800, 10.5894500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34584, 'Lütetsburg', 'Lutetsburg', 'Litetsburg,Ljutetsburg,Lutetsburg,Lütetsburg,lu te ci bao,Литетсбург,Лютетсбург,吕特茨堡', 53.6000000, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34585, 'Lütau', 'Lutau', 'Lutau,Lütau', 53.4333300, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34586, 'Lustadt', 'Lustadt', 'Loschd,Lushtadt,Lushtat,lu si ta te,Луштадт,Луштат,卢斯塔特', 49.2447600, 8.2740700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34587, 'Lürschau', 'Lurschau', 'Lurschau,Lürschau', 54.5500000, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34588, 'Lupburg', 'Lupburg', 'Lupburg,Luppurg,lu pu bao,Лупбург,Լուպբուրգ,卢普堡', 49.1551000, 11.7564000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34589, 'Lunzig', 'Lunzig', '', 50.7132500, 12.0929400, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34590, 'Lunzenau', 'Lunzenau', 'Luncenau,Luncenava,Luncznaw,Lunzenau,lun ce nao,lwntsnaw,Лунценау,لونتسناو,伦策瑙', 50.9626900, 12.7559400, 'DE', '2016-10-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34591, 'Lunestedt', 'Lunestedt', 'Luneshtedt,Luneshtet,Lunestedt,Luunst,Лунештедт,Лунештет', 53.4362100, 8.7519300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34592, 'Lünen', 'Luenen', 'Hliunon,Linen,Ljunen,Luenen,Lunen,Lünen,lu nen,lwinen,lwnn,ryunen,Линен,Люнен,لونن,リューネン,吕嫩,뤼넨', 51.6163400, 7.5287200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34593, 'Lüneburg', 'Lueneburg', 'Glain,Gorad Ljuneburg,Lineburg,Ljuneburg,Luemborg,Lueneburg,Luneberg,Lunebourg,Luneburg,Luneburgo,Luneburgum,Lyneburgu,Lynempournk,Lümborg,Lüneburg,lu ne bao,lu nei bao,lwinebuleukeu,lwnbwrg,lwnbwrgh,lynbwrg,ryuneburuku,Λύνεμπουργκ,Горад Люнебург,Линебург,Люнебург,לינבורג,لونبورغ,لونبورگ,リューネブルク,吕内堡,吕讷堡,뤼네부르크', 53.2509000, 10.4140900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34594, 'Lünebach', 'Lunebach', 'Linebakh,Ljunebakh,lu nei ba he,Линебах,Люнебах,吕内巴赫', 50.1333300, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34595, 'Lunden', 'Lunden', 'Lunden,lun deng,Лунден,伦登', 54.3313100, 9.0252300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34596, 'Lumpzig', 'Lumpzig', 'Lumpzig', 50.9500000, 12.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34597, 'Lülsfeld', 'Luelsfeld', '', 49.8681400, 10.3213200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34598, 'Luisenthal', 'Luisenthal', 'Luisental,Luizental,Luizental'',lu yi sen ta er,Луизентал,Луизенталь,Луисентал,卢伊森塔尔', 50.7833300, 10.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34599, 'Luhnstedt', 'Luhnstedt', 'Luhnstedt', 54.1666700, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34600, 'Luhe-Wildenau', 'Luhe-Wildenau', 'Lue,Luhe,Luhe-Wildenau', 49.5836700, 12.1492100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34601, 'Luhden', 'Luhden', '', 52.2253800, 9.0925600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34602, 'Lügde', 'Luegde', 'Ligde,Ljugde,Luegde,Lügde,lu ge de,lwghdh,lwjh,ryukude,Лигде,Люгде,لوجه,لوغده,リュクデ,吕格德', 51.9582800, 9.2470600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34603, 'Lugau', 'Lugau', 'Henneckestadt Lugau,Lugau,Lugava,Lūgava,lagaw  artzgbyrgh,lu gao,Лугау,لاگاو، ارتزگبیرگه,卢高', 50.7384300, 12.7486100, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34604, 'Lug', 'Lug', '', 49.1833300, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34605, 'Lüerdissen', 'Luerdissen', 'Lueerdissen,Lüerdissen', 51.9527300, 9.6245400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34606, 'Ludwigswinkel', 'Ludwigswinkel', '', 49.0833300, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34607, 'Ludwigsstadt', 'Ludwigsstadt', 'Ljudvigsshtadt,Ludvigsshtat,Ludwigsstadt,Ludwigstadt,lu de wei xi si shi ta te,lwdfyghsshtat,lwdwygsshtat,rutovu~ihisushutatto,Лудвигсштат,Людвигсштадт,Людвігсштадт,Լյուդվիգշթաթ,لودفيغسشتات,لودویگسشتات,ルートヴィヒスシュタット,路德维希斯施塔特', 50.4860500, 11.3873400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34608, 'Ludwigslust', 'Ludwigslust', 'Ljudvigsljust,Ljudvigslust,Ludvigslust,Ludvigsluste,Ludwigslust,lu de wei xi lu si te,lwdfyghslwst,lwdwygzlwst,Лудвигслуст,Людвигслюст,Людвіґслуст,لودفيغسلوست,لودویگزلوست,路德维希卢斯特', 53.3291700, 11.4971400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34609, 'Ludwigshöhe', 'Ludwigshohe', '', 49.8166700, 8.3436100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34610, 'Ludwigshafen am Rhein', 'Ludwigshafen am Rhein', 'Liudvigshafenas prie Reino,Ljudvigsgafen-na-Rejni,Ljudvigskhafen-na-Rejne,Lountvichschafen,Ludovici Portus Rhenanus,Ludvigskhafen,Ludvigskhafen na Rajni,Ludwichshafe,Ludwigshafen,Ludwigshafen am Rhein,Ludwigshafen sul Reno,Luedviqshafen,Lüdviqshafen,lu de wei xi gang,ludaviksahaphena,luteubihiseuhapen,lwdfyghshafn,lwdwygshafn,rainis ludvigshapeni,rutovu~ihhisuhafen,rutovu~ihisuhafen,Λουντβιχσχάφεν,Лудвигсхафен,Лудвигсхафен на Рајни,Людвигсхафен-на-Рейне,Людвіґсгафен-на-Рейні,לודוויגסהאפן,لودفيغسهافن,لودویگسهافن,لڈوگشافن,लुडविक्सहाफेन,რაინის ლუდვიგსჰაფენი,ルートヴィッヒスハーフェン,ルートヴィヒスハーフェン,路德维希港,루트비히스하펜', 49.4812100, 8.4464100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34611, 'Ludwigsfelde', 'Ludwigsfelde', 'Ljudvigsfel''de,Ludvigsfelde,Ludwigsfelde,Lyudvigsfelde,lu de wei xi fei er de,lwdfyghsfyldh,lwdwygzfldh,Лудвигсфелде,Людвигсфельде,Людвігсфельде,Լյուդվիգսֆելդե,لودفيغسفيلده,لودویگزفلده,路德维希费尔德', 52.3032200, 13.2540500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34612, 'Ludwigsburg', 'Ludwigsburg', 'Gorad Ljudvigsburg,Liudvigsburgas,Ljudvigsburg,Lountvinksmpournk,Ludoviciburgum,Ludvigsburg,Ludwigsbourg,Ludwigsburg,Ludwigsburgo,Luedviqsburq,Luisburgo,Lüdviqsburq,lu de wei xi bao,lud wics bur k,lwdfyghsbwrgh,lwdwygzwbwrg,rutovu~ihisuburuku,Λούντβιγκσμπουργκ,Горад Людвігсбург,Лудвигсбург,Людвигсбург,Людвігсбург,لودفيغسبورغ,لودویگزوبورگ,ลุดวิจส์บูร์ก,ルートヴィヒスブルク,路德维希堡', 48.8973100, 9.1916100, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34613, 'Lüdinghausen', 'Luedinghausen', 'Lidingkhauzen,Ljudinggauzen,Ljudingkhauzen,Ludinghausen,Luedinghausen,Luenkhusen,Lüdinghausen,Lünkhusen,lu ding hao sen,lwdynghhawzn,Лидингхаузен,Людингхаузен,Людінггаузен,لودينغهاوزن,لودینگ‌هاوزن,吕丁豪森', 51.7683000, 7.4437900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34614, 'Lüdersfeld', 'Ludersfeld', 'Lidersfeld,Ljudersfel''d,lu de er si fei er de,ryudasuferuto,Лидерсфелд,Людерсфельд,リューダースフェルト,吕德尔斯费尔德', 52.3599300, 9.2542200, 'DE', '2016-04-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34615, 'Lüdersdorf', 'Luedersdorf', '', 53.8683500, 11.7490200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34616, 'Lüdersburg', 'Ludersburg', 'Luedersburg,Lüdersburg', 53.3214200, 10.5742000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34617, 'Lüderitz', 'Luederitz', '', 52.5091200, 11.7430100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34618, 'Lüder', 'Luder', 'Lueder,Lüder', 52.8087800, 10.6660900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34619, 'Lüdenscheid', 'Luedenscheid', 'Leudenscheid,Lidenshajd,Liudolvescetha,Ljudenshajd,Ludenscheid,Luedenscheid,Luensche,Lüdenscheid,Lünsche,lu deng sha yi de,lwdnshayd,Лиденшајд,Люденшайд,لودنشايد,لودن‌شاید,吕登沙伊德', 51.2197700, 7.6273000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34620, 'Luckenwalde', 'Luckenwalde', 'Luckenwalde,Lukenvalde,Lukkenval''de,Stadt Luckenwalde,lu ken wa er de,lukenbalde,lwknfaldh,lwknwaldh,Лукенвалде,Луккенвальде,Լուկենվալդե,لوكنفالده,لوکنوالده,卢肯瓦尔德,루켄발데', 52.0902900, 13.1677200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34621, 'Lückenburg', 'Lueckenburg', '', 49.7333300, 6.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34622, 'Luckenbach', 'Luckenbach', '', 50.7000000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34623, 'Luckau', 'Luckau', 'Luccavia,Luckau,Lukau,Lukava,Lukkau,Lukow,lu kao,lwkaw,Łukow,Лукау,Луккау,Լուկաու,لوكاو,لوکاو,卢考', 51.8524500, 13.7073500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34624, 'Lucka', 'Lucka', 'Lucka,Luka,Lúčka,Лука', 51.0972700, 12.3333600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34625, 'Lüchow', 'Luchow', '', 53.6833300, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34626, 'Lüchow', 'Luechow', 'Likhov,Ljukhov,Luchow,Luechow,Lüchow,lu xiao,lwshw,Лихов,Люхов,لوشو,呂肖', 52.9681100, 11.1539700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34627, 'Lübz', 'Luebz', 'Libc,Libca,Ljubc,Luebz,Lübz,lu bu ci,lwbts,Либц,Любц,لوبتس,吕布茨', 53.4626100, 12.0291700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34628, 'Lübtheen', 'Luebtheen', 'Libten,Libtena,Libtēna,Ljubten,Lubtheen,Lübtheen,lu bu teng,lwbtyn,Либтен,Любтен,لوبتين,لوبتین,吕布滕', 53.3011800, 11.0836800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34629, 'Lübstorf', 'Luebstorf', 'Luebstorf,Lübstorf', 53.7256100, 11.4147100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34630, 'Lübow', 'Luebow', 'Lubow,Luebow,Lübow', 53.8525600, 11.5244000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34631, 'Lubmin', 'Lubmin', 'Lubmin,lu bu ming,Лубмин,卢布明', 54.1350900, 13.6168700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34632, 'Lübeck', 'Luebeck', 'Gorad Ljubek,Libek,Libeka,Limpek,Liubekas,Ljubek,Lubeca,Lubecca,Lubeck,Lubeck Hansestadt,Lubeka,Lubeko,Lubëcca,Luebeca,Luebeck,Lybeku,Lyypekki,Lübeca,Lübeck,Lübeck Hansestadt,Lībeka,lu bei ke,lux bekh,lwbk,lwbyk,lwibekeu,lybq,lyubeka,ryubekku,Λίμπεκ,Горад Любек,Либек,Любек,ליבק,لوبيك,لوبک,ल्युबेक,ลือเบค,ლიუბეკი,リューベック,吕贝克,뤼베크', 53.8689300, 10.6872900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34633, 'Lübbow', 'Lubbow', '', 52.9115900, 11.1809900, 'DE', '2011-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34634, 'Lübberstedt', 'Lubberstedt', 'Gemeen Luebbs,Gemeen Lübbs,Libershtet,Ljubbershtedt,Lubberstadt,Lubberstedt,Lupperstadt,Lübberstedt,lu bei er si te,Либерштет,Любберштедт,吕贝尔斯特', 53.3333300, 8.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34635, 'Lübbenau', 'Luebbenau', 'Libenau,Ljubbenau,Lubbenau,Lubnjow,Luebbenau,Luebbenau/Lubnjow,Luebbenau/Spreewald,Lyubenau,Lübbenau,Lübbenau/Lubnjow,Lübbenau/Spreewald,lu bei nao,lwbnaw,lwbynaw,Либенау,Люббенау,Լյուբենաու,لوبناو,لوبيناو,吕贝瑙', 51.8621700, 13.9516800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34636, 'Lübben', 'Luebben', 'Liben,Libene,Ljubben,Lubben,Lubin,Luebben,Lyuben,Lübben,lwbn,lwiben,Либен,Люббен,Լյուբեն,لوبن,뤼벤', 51.9381400, 13.8882600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34637, 'Lübbecke', 'Luebbecke', 'Hlidbeki,Libeke,Ljubbekke,Lubbecke,Luebbecke,Lübbecke,lwbkh,lwbykh,ryubekke,Либеке,Люббекке,لوبيكه,لوبکه,リュベッケ', 52.3069900, 8.6142300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34638, 'Lübars', 'Lubars', 'Berlin-Luebars,Berlin-Lübars', 52.6159100, 13.3535000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34639, 'Loxstedt', 'Loxstedt', 'Gemeen Lox,Loksshtedt,Loksshtet,Loxstedt,luo ke si te te,Локсштедт,Локсштет,洛克斯特特', 53.4666700, 8.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34640, 'Löwenstein', 'Loewenstein', 'L''ovenshhajn,Levenshtajn,Ljovenshtajn,Loewenstein,Lowenstein,Löwenstein,lei wen si tai yin,lwfnshtayn,lwwnstyyn,revu~enshutain,Левенштайн,Левенштајн,Льовенщайн,Лёвенштайн,לוונשטיין,لوفنشتاين,لوون‌اشتاین,レーヴェンシュタイン,勒文斯泰因', 49.0955800, 9.3800000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34641, 'Löwenstedt', 'Loewenstedt', 'Joeoemst,Jöömst,Levenshtet,Ljovenshtedt,Loewenstedt,Lovensted,Lowenstedt,Löwenstedt,Løvensted,lei wen si te,Левенштет,Лёвенштедт,勒文斯特', 54.6216300, 9.1726400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34642, 'Lötzbeuren', 'Lotzbeuren', '', 49.9333300, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34643, 'Lottstetten', 'Lottstetten', 'Lotshteten,Lotshtetten,Lottshtetten,luo ci te teng,Лоттштеттен,Лотштетен,Лотштеттен,洛茨特滕', 47.6333300, 8.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34644, 'Lottorf', 'Lottorf', 'Lottorf', 54.4500000, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34645, 'Lotte', 'Lotte', '', 52.2833300, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34646, 'Lostau', 'Lostau', '', 52.2087100, 11.7379500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34647, 'Lößnitz', 'Loessnitz', 'Loessnitz,Lossnitz,Lößnitz', 50.6218100, 12.7314700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34648, 'Loßburg', 'Lossburg', 'Losburg,Lossburg,Loßburg,luo si bao,Лосбург,Լոսբուրգ,洛斯堡', 48.4000000, 8.4500000, 'DE', '2016-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34649, 'Lösnich', 'Loesnich', 'Lesnikh,Ljosnikh,Loesnich,Lösnich,lei si ni xi,Лесних,Лёсних,勒斯尼希', 49.9666700, 7.0333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34650, 'Losheim', 'Losheim', 'Losheim,Losheim am See', 49.5099000, 6.7454900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34651, 'Lörzweiler', 'Lorzweiler', 'Loerzweiler,Lörzweiler', 49.8983300, 8.2947200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34652, 'Lorup', 'Lorup', 'Loorpe,Lorup,luo lu pu,Лоруп,洛鲁普', 52.9249500, 7.6433900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34653, 'Lorscheid', 'Lorscheid', 'Lorshajd,luo er sha yi de,Лоршайд,Лоршајд,洛尔沙伊德', 49.7333300, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34654, 'Lorsch', 'Lorsch', 'Lors,Lorsch,Lorsh,Lorş,lrsh,luo er shi,lwrsh,rorushu,Лорш,لرش,لورش,ロルシュ,洛尔施', 49.6500000, 8.5666700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34655, 'Lörrach', 'Loerrach', 'L''orrakh,Lerakh,Lerrakh,Ljorrakh,Loerrach,Lorrach,Lörrach,loerrach,lrakh,luo la he,lwrakh,lörrach,Лерах,Леррах,Льоррах,Лёррах,لراخ,لوراخ,罗拉赫', 47.6149700, 7.6645700, 'DE', '2015-08-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34656, 'Lorch', 'Lorch', 'Lorkh,lrsh,Лорх,لرش', 48.7983300, 9.6914000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34657, 'Löptin', 'Loptin', 'Loeptin,Loptin,Löptin', 54.1833300, 10.2166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34658, 'Loose', 'Loose', '', 54.5166700, 9.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34659, 'Loop', 'Loop', 'Loop', 54.1500000, 9.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34660, 'Looft', 'Looft', 'Looft', 54.0287300, 9.5236000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34661, 'Lonsheim', 'Lonsheim', '', 49.7786100, 8.0766700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34662, 'Lonsee', 'Lonsee', 'Lonze,Lonzee,long sai,lonzee,Лонзе,Лонзее,Լոնզեե,ლონზეე,隆塞', 48.5434000, 9.9199900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34663, 'Lonnig', 'Lonnig', '', 50.3100200, 7.4050900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34664, 'Lonnerstadt', 'Lonnerstadt', 'Lonershtat,Lonnershtadt,Lonnerstadt,luo nei er si ta te,ron''nashutatto,Лонерштат,Лоннерштадт,ロンナーシュタット,洛内尔斯塔特', 49.6988200, 10.7671100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34665, 'Löningen', 'Loeningen', 'Leningen,Ljoningen,Loeningen,Loningen,Löningen,lei ning gen,lwnnghn,lwnnyng,Ленинген,Лёнинген,لوننغن,لوننینگ,勒宁根', 52.7367800, 7.7580900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34666, 'Longuich', 'Longuich', '', 49.8084100, 6.7683200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34667, 'Longkamp', 'Longkamp', 'Longamp,Lonkamp,long ge kan pu,Лонгамп,Лонкамп,隆格坎普', 49.8904400, 7.1176400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34668, 'Longen', 'Longen', '', 49.8000000, 6.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34669, 'Lommatzsch', 'Lommatzsch', 'Hlomac,Hłomač,Lomacsh,Lommaca,Lommach,Lommatzsch,Lommača,lmatssh,luo ma ci xi,lwmatssh,Ломацш,Ломмач,لماتسش,لوماتسش,洛马茨希', 51.1953700, 13.3091700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34670, 'Lollschied', 'Lollschied', '', 50.2563700, 7.8690400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34671, 'Löllbach', 'Lollbach', 'Lelbakh,Ljol''bakh,lei er ba he,Лелбах,Лёльбах,勒尔巴赫', 49.6833300, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34672, 'Lollar', 'Lollar', 'Lolar,Lollar,llar,luo la er,Лолар,Лоллар,للار,洛拉尔', 50.6465200, 8.7049500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34673, 'Loitzendorf', 'Loitzendorf', '', 49.0845600, 12.6559100, 'DE', '2013-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34674, 'Loitz', 'Loitz', '', 53.4420500, 13.3880200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34675, 'Loit', 'Loit', 'Loit', 54.6166700, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34676, 'Loiching', 'Loiching', 'Loikhing,Lojkhing,Loyxing,luo yi xing,lwyshyng,Лоихинг,Лойхинг,Лойхінг,Лөйхинг,Լոյխինգ,لویشینگ,洛伊兴', 48.6166700, 12.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34677, 'Lohsa', 'Lohsa', 'Laz,Lohsa,Lohsa/Laz,Lohsa/Łaz,Loza,luo sa,Łaz,Лоза,洛萨', 51.3833300, 14.4000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34678, 'Lohrheim', 'Lohrheim', '', 50.3166700, 8.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34679, 'Lohra', 'Lohra', 'Lohra,Lora,luo la,rora,Лора,ローラ,洛拉', 50.7333300, 8.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34680, 'Lohr am Main', 'Lohr am Main', 'Loa,Lohr,Lohr a. Main,Lohr am Main,Lor na Majni,Lor-am-Majn,Mayni Lor,lwr  alman,mei yin he pan luo er,Лор на Мајни,Лор-ам-Майн,Մայնի Լոր,لور، آلمان,美因河畔洛尔', 49.9892200, 9.5722300, 'DE', '2013-11-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34681, 'Lohnweiler', 'Lohnweiler', 'Lonvajler,luo en wei lei,Лонвайлер,Лонвајлер,洛恩韦勒', 49.6333300, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34682, 'Lohnsfeld', 'Lohnsfeld', '', 49.5500000, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34683, 'Lohne', 'Lohne', 'Loehne,Lohne,Lone,Löhne,lnh  alman,luo nei,lwnh,Лоне,لنه، آلمان,لونه,洛内', 52.6662500, 8.2375000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34684, 'Lohne', 'Lohne', '', 52.4977800, 7.2262900, 'DE', '2016-05-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34685, 'Löhne', 'Loehne', 'Lene,Ljone,Loehne,Lohne,Löhne,lei ne,lwnh,lwnh  nwrdrayn-wstfaln,rene,Лене,Лёне,لونه,لونه، نوردراین-وستفالن,レーネ,勒讷', 52.1884800, 8.6922000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34686, 'Löhnberg', 'Lohnberg', 'Lenberg,Ljonberg,Loehnberg,Löhnberg,lun bei ge,Ленберг,Лёнберг,伦贝格', 50.5129900, 8.2720200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34687, 'Lohmen', 'Lohmen', '', 50.9883100, 14.0026800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34688, 'Lohmar', 'Lohmar', 'Lohmar,Lomar,Luhme,lmar,luo ma er,Ломар,لمار,洛马尔', 50.8386800, 7.2139900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34689, 'Löhma', 'Lohma', 'Lohma,Löhma', 50.6116700, 11.8520200, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34690, 'Lohkirchen', 'Lohkirchen', '', 48.3166700, 12.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34691, 'Lohfelden', 'Lohfelden', 'Crumbach,Krumbach,Lofel''den,Lofelden,Lofelnten,Lohfelden,luo fei er deng,roferuden,Λοφέλντεν,Лофелден,Лофельден,ローフェルデン,洛费尔登', 51.2666700, 9.5333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34692, 'Lohe-Föhrden', 'Lohe-Fohrden', 'Lohe-Foehrden,Lohe-Fohrden,Lohe-Föhrden', 54.3333300, 9.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34693, 'Lohberg', 'Lohberg', '', 49.1760400, 13.1054900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34694, 'Lohbarbek', 'Lohbarbek', 'Loharbek,Lohbarbek', 53.9454800, 9.6354800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34695, 'Löffingen', 'Loffingen', 'Leffingen,Lefingen,Ljoffingen,Loeffingen,Loffingen,Lyofingen,Löffingen,lei fen gen,lwfynghn,lwfyngn,Лефинген,Леффінген,Лёффинген,Լյոֆինգեն,لوفينغن,لوفینگن,勒芬根', 47.8840500, 8.3438400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34696, 'Loffenau', 'Loffenau', 'Lofenau,Loffenau,luo fei nao,Лофенау,Лоффенау,洛费瑙', 48.7721400, 8.3846300, 'DE', '2011-11-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34697, 'Löf', 'Lof', 'Loef,Löf', 50.2333300, 7.4333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34698, 'Lödla', 'Lodla', 'Lodla,Lödla', 51.0000000, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34699, 'Loddin', 'Loddin', 'Loddin,Lodin,luo ding,Лоддин,Лодин,洛丁', 54.0225200, 14.0075400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34700, 'Lockstedt', 'Lockstedt', '', 54.0000000, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34701, 'Löcknitz', 'Loecknitz', '', 53.2869400, 11.7810800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34702, 'Lochum', 'Lochum', '', 50.6055600, 7.8659700, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34703, 'Löchgau', 'Lochgau', 'Lekhgau,Ljokhgau,Lochgau,Loechgau,Löchgau,lei xi gao,lwksgaw,Лехгау,Лёхгау,لوکسگاو,勒希高', 49.0036100, 9.1063900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34704, 'Lochau', 'Lochau', '', 51.3973800, 12.0530300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34705, 'Loburg', 'Loburg', 'Loburg,Лобург', 52.1150900, 12.0784000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34706, 'Lobstädt', 'Lobstaedt', 'Lobstadt,Lobstädt', 51.1336100, 12.4486100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34707, 'Löbnitz', 'Lobnitz', '', 51.5923800, 12.4634700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34708, 'Löbichau', 'Lobichau', 'Lebikhau,Ljobikhau,Lobichau,Löbichau,lei bi xiao,Лебихау,Лёбихау,勒比肖', 50.8938300, 12.2636600, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34709, 'Löberschütz', 'Loberschutz', 'Loberschutz,Löberschütz', 50.9666700, 11.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34710, 'Löberitz', 'Loeberitz', '', 51.6539300, 12.1465500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34711, 'Bad Lobenstein', 'Bad Lobenstein', 'Bad Lobenshhajn,Bad Lobenshtajn,Bad Lobenstein,Bad-Lobenshtajn,Lobenstein,Moorbad Lobenstein,ba te luo ben shi tai yin,bad lwbnshtayn,Бад Лобенштајн,Бад Лобенщайн,Бад-Лобенштайн,باد لوبنشتاين,باد لوبن‌اشتاین,巴特洛本施泰因', 50.4522300, 11.6393000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34712, 'Löbejün', 'Loebejuen', 'Labejum,Lobejun,Löbejün', 51.6353300, 11.9010600, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34713, 'Löbau', 'Loebau', 'L''obau,Lebau,Lebava,Ljobau,Lobau,Lobava,Lobavia,Loebau,Lubij,Löbau,Lēbava,lei bao,lwba,Лебау,Льобау,Лёбау,لوبا,勒鲍', 51.0995400, 14.6673800, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34714, 'Litzendorf', 'Litzendorf', 'Licendorf,Litcendorf,li cen duo fu,rittsu~endorufu,Литцендорф,Лицендорф,Літцендорф,Լիտցենդորֆ,リッツェンドルフ,利岑多夫', 49.9144400, 11.0102800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34715, 'List', 'List', 'List,List auf Sylt,Listas,lyst  almanya,risuto,Лист,ليست، ألمانيا,リスト', 55.0191700, 8.4313200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34716, 'Lissendorf', 'Lissendorf', 'Lissendorf,Lizendorf,li sen duo fu,Лизендорф,Лиссендорф,利森多夫', 50.3166700, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34717, 'Lippstadt', 'Lippstadt', 'Lip''stant,Lippshtadt,Lippshtadte,Lippstadt,Lipshhat,Lipshtat,li pu shi ta te,lybshtat,Λίπσταντ,Липпштадт,Липпштадте,Липштат,Липщат,Ліппштадт,ليبشتات,لیپ‌اشتات,利普施塔特', 51.6736900, 8.3448200, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34718, 'Lipprechterode', 'Lipprechterode', '', 51.4576900, 10.5534800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34719, 'Lipporn', 'Lipporn', '', 50.1333300, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34720, 'Linz am Rhein', 'Linz am Rhein', 'Linc am Rajn,Linc-am-Rajn,Linc-na-Rejne,Linz,Linz am Rhein,lai yin he pan lin ci,lynts am rayn,Линц ам Рајн,Линц-ам-Райн,Линц-на-Рейне,لينتس آم راين,لینتس آم راین,リンツ・アム・ライン,莱茵河畔林茨', 50.5688400, 7.2844500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34721, 'Lintig', 'Lintig', '', 53.6034100, 8.8787600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34722, 'Linthe', 'Linthe', '', 52.1500000, 12.7833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34723, 'Linsburg', 'Linsburg', 'Linsburg,lin si bao,rinsuburuku,Линсбург,リンスブルク,林斯堡', 52.5935400, 9.3026200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34724, 'Linnich', 'Linnich', 'Linikh,Linnich,Linnikh,li ni xi,lynysh,Линих,Линних,Лінніх,لينيش,لینیش,利尼希', 50.9800200, 6.2704900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34725, 'Linkenbach', 'Linkenbach', '', 50.5833300, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34726, 'Lingerhahn', 'Lingerhahn', '', 50.0941900, 7.5645600, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34727, 'Lingenfeld', 'Lingenfeld', 'Lingefeld,Lingenfel''d,Lingenfeld,lin gen fei er de,Лингенфелд,Лингенфельд,林根费尔德', 49.2538900, 8.3386100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34728, 'Lingen', 'Lingen', 'Gorad Lingen,Lingen,lin gen,lynghn,lyngn,ringen,Горад Лінген,Линген,لينغن,لینگن,リンゲン,林根', 52.5214300, 7.3184500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34729, 'Lindwedel', 'Lindwedel', '', 52.6078400, 9.6873700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34730, 'Lindow', 'Lindow', 'Lindov,lin duo fu,lyndw,Линдов,لیندو,林多夫', 52.9668900, 12.9849800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34731, 'Lindlar', 'Lindlar', 'Lenkeln,Lindlar,lin de la er,Линдлар,Ліндлар,林德拉尔', 51.0195900, 7.3775800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34732, 'Lindig', 'Lindig', 'Lindig', 50.7833300, 11.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34733, 'Lindhorst', 'Lindhorst', 'Lindkhorst,lin de huo er si te,rintohorusuto,Линдхорст,リントホルスト,林德霍尔斯特', 52.3578900, 9.2831900, 'DE', '2016-04-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34734, 'Lindewitt', 'Lindewitt', 'Lindewitt', 54.7000000, 9.2000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34735, 'Lindewerra', 'Lindewerra', 'Lindewerra', 51.3166700, 9.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34736, 'Lindenschied', 'Lindenschied', '', 49.9000000, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34737, 'Lindenkreuz', 'Lindenkreuz', '', 50.8500000, 11.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34738, 'Lindenfels', 'Lindenfels', 'Lindenfel''s,Lindenfels,lin deng fei er si,lyndnflz,rindenferusu,Линденфелс,Линденфельс,Лінденфельс,ليندنفلز,لیندنفلز,リンデンフェルス,林登费尔斯', 49.6836900, 8.7815100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34739, 'Lindenberg', 'Lindenberg', '', 49.3802800, 8.0986100, 'DE', '2013-11-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34740, 'Lindenau', 'Lindenau', 'Lindenau,lin de nao,Линденау,Լինդենաու,林德瑙', 51.4000000, 13.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34741, 'Linden', 'Linden', '', 54.2500000, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34742, 'Linden', 'Linden', '', 50.6000000, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34743, 'Linden', 'Linden', '', 49.3500000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34744, 'Lindberg', 'Lindberg', 'Lindberg,lin de bei ge,lyndbrg,Линдберг,Ліндберг,Լինդբերգ,لیندبرگ,林德贝格', 49.0368000, 13.2542300, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34745, 'Lindau', 'Lindau', '', 54.3833300, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34746, 'Lindau', 'Lindau', 'Lindau', 52.0375100, 12.1078800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34747, 'Lindau', 'Lindau', 'Lindau,Lindau Bodensee,Lindau saar,Lindavia,Lintaou,lin dao,linada''u,lindau,lyndaw,rindau,Λιντάου,Линдау,Ліндау,Լինդաու,لينداو,لینداو,লিনডাউ,ლინდაუ,リンダウ,林道', 47.5461200, 9.6843100, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34748, 'Lind', 'Lind', '', 50.5000000, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34749, 'Lind', 'Lind', '', 50.3166700, 7.0333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34750, 'Linau', 'Linau', 'Linau', 53.6444600, 10.4685300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34751, 'Limburgerhof', 'Limburgerhof', 'Limburgerkhof,lin bu er ge huo fu,Лимбургерхоф,林布尔格霍夫', 49.4244400, 8.3919400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34752, 'Limburg an der Lahn', 'Limburg an der Lahn', 'Gorad Limburg-na-Lane,Limburg,Limburg an der Lahn,Limburg na Lan,Limburg na Lani,Limburg-an-der-Lan,Limburg-na-Lane,Limburgo del Lahn,Limburgo sulla Lahn,Limburgum ad Lahnam,lan he pan lin bao,limbuleukeuandeeolan,lymbwrg an dr lan,lymbwrgh an dr lan,Горад Лімбург-на-Лане,Лимбург на Лан,Лимбург на Лани,Лимбург-ан-дер-Лан,Лимбург-на-Лане,Лімбург-ан-дер-Лан,ليمبورغ آن در لان,لیمبورگ آن در لان,兰河畔林堡,림부르크안데어란', 50.3836000, 8.0503000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34753, 'Limbach-Oberfrohna', 'Limbach-Oberfrohna', 'Limbach,Limbach-Oberfrohna,Limbaha-Oberfrona,Limbakh-Oberfrona,lin ba-ao bei er fu luo na,lymbakh-awbrfrwna,Лимбах-Оберфрона,Лімбах-Оберфрона,ليمباخ-أوبرفرونا,لیمباخ-اوبرفرونا,林巴-奥贝尔夫罗纳', 50.8588200, 12.7616500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34754, 'Limbach', 'Limbach', '', 50.7000000, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34755, 'Limbach', 'Limbach', '', 50.5833300, 12.2500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34756, 'Limbach', 'Limbach', 'Limbakh,Лимбах', 49.7333300, 7.5500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34757, 'Limbach', 'Limbach', '', 49.4619400, 9.2111100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34758, 'Lilienthal', 'Lilienthal', 'Leendaal,Liliental,Liliental'',Lilienthal,Lilintal,Лилиентал,Лилиенталь,Лилинтал', 53.1419300, 8.9033800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34759, 'Lietzen', 'Lietzen', '', 52.4699200, 14.3400800, 'DE', '2013-05-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34760, 'Lieth', 'Lieth', '', 54.1560000, 9.0608100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34761, 'Ließem', 'Liessem', '', 50.0333300, 6.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34762, 'Lieskau', 'Lieskau', 'Lieskau', 51.5039500, 11.8620800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34763, 'Lieser', 'Lieser', '', 49.9166700, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34764, 'Liesenich', 'Liesenich', '', 50.0833300, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34765, 'Lirstal', 'Lirstal', 'Lierstall,Lirstal', 50.2500000, 7.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34766, 'Lierschied', 'Lierschied', 'Lierscheid,Lierschied', 50.1666700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34767, 'Lierfeld', 'Lierfeld', '', 50.1333300, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34768, 'Liepe', 'Liepe', '', 52.8621300, 13.9694600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34769, 'Lienen', 'Lienen', 'Linen,li nen,Линен,Лінен,利嫩', 52.1500000, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34770, 'Lieg', 'Lieg', '', 50.1333300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34771, 'Liebstedt', 'Liebstedt', 'Libshtedt,Libshtet,li bu si te,Либштедт,Либштет,利布斯特', 51.0500000, 11.4000000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34772, 'Liebstadt', 'Liebstadt', 'Libshhat,Libshtadt,Libshtat,Libstate,Liebstadt,Lībštate,li bu si ta te,lybshtat,Либштадт,Либштат,Либщат,ليبشتات,لیب‌اشتات,利布斯塔特', 50.8641700, 13.8569400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34773, 'Liebshausen', 'Liebshausen', '', 50.0333300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34774, 'Lieberose', 'Lieberose', 'Liberoze,Lieberose,Luboraz,Līberoze,li bei luo sai,lybrwzh,Либерозе,Լիբերոզե,ليبروزه,لیبروزه,利贝罗塞', 51.9849100, 14.2998700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34775, 'Liebenwalde', 'Liebenwalde', 'Libenval''de,Libenvalde,li ben wa er de,lybnfaldh,lybnwaldh,Либенвалде,Либенвальде,Լիբենվալդե,ليبنفالده,لیبنوالده,利本瓦尔德', 52.8712500, 13.3946500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34776, 'Liebenstein', 'Liebenstein', 'Libenshtajn,li ben si tai yin,Либенштайн,Либенштајн,利本斯泰因', 50.7666700, 10.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34777, 'Liebenscheid', 'Liebenscheid', 'Libenshajd,li ben sha yi de,Либеншайд,Либеншајд,利本沙伊德', 50.6972200, 8.0983300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34778, 'Liebenburg', 'Liebenburg', 'Libenburg,li ben bao,Либенбург,利本堡', 52.0217600, 10.4316900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34779, 'Liebenau', 'Liebenau', 'Laeiwenah,Libenau,Läiwenah,leĭvənɔː [IPA],ribenau,Либенау,リーベナウ', 52.6036200, 9.0971900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34780, 'Liebenau', 'Liebenau', 'Liebenau', 51.4969900, 9.2820700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34781, 'Lichterfelde', 'Lichterfelde', 'Gross Lichterfelde,Groß Lichterfelde', 52.4333000, 13.3076200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34782, 'Lichtentanne', 'Lichtentanne', 'Likhtentane,Likhtentanne,li xi teng ta nei,Лихтентане,Лихтентанне,利希滕塔内', 50.6925500, 12.4258500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34783, 'Lichtenstein', 'Lichtenstein', 'Callnberg,Lichenstein,Lichtenstein,Lichtenstein-Callnberg,Lihtensteina,Lihtenšteina,Likhtenshtajn,lyshtnshtayn,Лихтенштайн,Лихтенштајн,ليشتنشتاين,لیشتن‌اشتاین، زاکسن', 50.7565900, 12.6302500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34784, 'Lichtenrade', 'Lichtenrade', 'Berlin-Lichtenrade,Likhtenrade,Лихтенраде', 52.3984400, 13.4063700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34785, 'Lichtenfels', 'Lichtenfels', 'Likhtenfel''s,Likhtenfels,li xi teng fei er si,lyshtnflz  bayrn,rihitenferusu,Лихтенфелс,Лихтенфельс,لیشتنفلز، بایرن,リヒテンフェルス,利希滕费尔斯', 50.1456700, 11.0592800, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34786, 'Lichtenborn', 'Lichtenborn', '', 50.1166700, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34787, 'Lichtenberg', 'Lichtenberg', 'Berlin-Lichtenberg,Lichtenberg,lkhtnbrg,lyktnbrg,ליכטנברג,لختنبرگ', 52.5139500, 13.4997500, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34788, 'Lichtenberg', 'Lichtenberg', 'Lichtenbergi vald,Likhtenberg,Swetla,Swětła,Лихтенберг', 51.1833300, 13.9666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34789, 'Lichtenberg', 'Lichtenberg', 'Lichtenberg/Erzgebirge', 50.8349200, 13.4247800, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34790, 'Lichtenberg', 'Lichtenberg', '', 50.3833500, 11.6762400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34791, 'Lichtenau', 'Lichtenau', 'Lichtenau', 51.6170700, 8.8966500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34792, 'Lichtenau', 'Lichtenau', '', 49.1597900, 10.3793500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34793, 'Lichtenau', 'Lichtenau', 'Lichtenau,Likhtenau,lyshtanw,lyshtnaw,Лихтенау,Ліхтенау,ليشتناو,لیشتانو', 48.7260700, 8.0048600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34794, 'Lichte', 'Lichte', 'Lichte,Likhte,li xi te,Лихте,利希特', 50.5166700, 11.1833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34795, 'Lich', 'Lich', 'Likh,li xi,lysh,Лих,لیش,利希', 50.5208500, 8.8156700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34796, 'Lexgaard', 'Lexgaard', 'Lexgaard', 54.8333300, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34797, 'Leverkusen', 'Leverkusen', 'Laevverkuuse,Leberkouzen,Leverkusen,Leverkuzen,Leverkuzenas,Leverkuzene,Leverkūzene,Lävverkuuse,Lėverkuzenas,ZOA,lbrqwzn,le fexr khu sein,lebeokujen,lei wo ku sen,lwrkwzn,lyfrkwzn,lywrkwsn,rebakuzen,Λεβερκούζεν,Леверкузен,לברקוזן,لورکوزن,ليفركوزن,لیورکوسن,เลเฟอร์คูเซิน,ლევერკუზენი,レバークーゼン,勒沃库森,레버쿠젠', 51.0303000, 6.9843200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34798, 'Leutkirch im Allgäu', 'Leutkirch im Allgau', 'Leutkirch,Leutkirch im Allgaeu,Leutkirch im Allgau,Leutkirch im Allgäu,Lojtkirkh im Algoj,Lojtkirkh-im-All''goj,a er ge yi de qu luo yi te ji xi,lwytkyrsh am alghwy,lwytkyrsh aym algaw,Лойткирх-им-Алльгой,Лойткірх-ім-Алльгой,Лојткирх им Алгој,لويتكيرش إم آلغوي,لویتکیرش ایم آلگاو,阿尔戈伊地区洛伊特基希', 47.8267200, 10.0205000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34799, 'Leutesdorf', 'Leutesdorf', 'Leutesdorf,Lojtesdorf,luo yi te si duo fu,Лойтесдорф,Лојтесдорф,洛伊特斯多夫', 50.4500000, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34800, 'Leutershausen', 'Leutershausen', 'Leutershausen,Lojtersgauzen,Lojterskhauzen,Loytershauzen,luo yi te er si hao sen,lwytrshawzn,lwytrzhawzn,roitasuhauzen,Лойтерсгаузен,Лойтерсхаузен,Лојтерсхаузен,Լոյտերսհաուզեն,لويترسهاوزن,لویترزهاوزن,ロイタースハウゼン,洛伊特尔斯豪森', 49.2986900, 10.4118900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34801, 'Leutersdorf', 'Leutersdorf', '', 50.9500000, 14.6500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34802, 'Leutersdorf', 'Leutersdorf', '', 50.5166700, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34803, 'Leuterod', 'Leuterod', '', 50.4958300, 7.8188900, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34804, 'Leutenthal', 'Leutenthal', '', 51.0500000, 11.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34805, 'Leutenberg', 'Leutenberg', 'Leutenberg,Lojtenberg,luo yi teng bei ge,lwytnbrg,lwytnbrgh,Лойтенберг,Лојтенберг,لويتنبرغ,لویتنبرگ,洛伊滕贝格', 50.5635400, 11.4561900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34806, 'Leutenbach', 'Leutenbach', '', 49.7095000, 11.1722400, 'DE', '2017-06-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34807, 'Leutenbach', 'Leutenbach', '', 48.8879100, 9.3926700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34808, 'Leupoldsgrün', 'Leupoldsgrun', 'Leopol''dsgrjun,Lojpol''dsgrjun,Lojpoldsgrin,luo yi bo er ci ge lin,lwypwldsgrwn,roiporutsuguryun,Леопольдсгрюн,Лойпольдсгрюн,Лојполдсгрин,لویپولدسگرون,ロイポルツグリュン,洛伊波尔茨格林', 50.3000000, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34809, 'Leuna', 'Leuna', 'Leuna,Lojna,luo yi na,lwyna,Лойна,Лојна,لوينا,لوینا,洛伊纳', 51.3178300, 12.0158900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34810, 'Leun', 'Leun', 'Gorad Lojn,Lojn,luo yin,lwyn,Горад Лойн,Лойн,Лојн,لوين,لوین,洛因', 50.5512900, 8.3583600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34811, 'Leuchtenberg', 'Leuchtenberg', 'Leuchtenberg,Lojkhtenberg,luo yi xi teng bei ge,Лойхтенберг,Лојхтенберг,Լյոխթենբերգ,洛伊希滕贝格', 49.5973700, 12.2584000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34812, 'Leubsdorf', 'Leubsdorf', '', 50.8000000, 13.1666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34813, 'Leubsdorf', 'Leubsdorf', '', 50.5500000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34814, 'Leubnitz', 'Leubnitz', '', 50.7231300, 12.3566000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34815, 'Letzlingen', 'Letzlingen', 'Leclingen,Letzlingen,Лецлинген', 52.4461500, 11.4851800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34816, 'Lettweiler', 'Lettweiler', '', 49.7333300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34817, 'Letschin', 'Letschin', 'Lechin,lai ci xin,Лечин,Լեչին,莱茨欣', 52.6437900, 14.3600700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34818, 'Leopoldshöhe', 'Leopoldshohe', 'Leopol''dsgee,Leopol''dskhjoeh,Leopoldshoehe,Leopoldshöhe,Leopoldskhekhe,lai ao bo er ci he hei,reoporutsuhee,Леополдсхехе,Леопольдсгеє,Леопольдсхёэ,レーオポルツヘーエ,莱奥波尔茨赫黑', 52.0124600, 8.6983400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34819, 'Leonberg', 'Leonberg', '', 49.9470800, 12.2852000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34820, 'Leonberg', 'Leonberg', 'Leomontium,Leonberg,Leonberq,Leonsberg,lai weng bei ge,leonbergi,liyonperku,lywnbrg,lywnbrgh,Леонберг,Լեոնբերգ,لئونبرگ,ليونبرغ,லியோன்பெர்கு,ლეონბერგი,莱翁贝格', 48.8000000, 9.0166700, 'DE', '2012-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34821, 'Lenzkirch', 'Lenzkirch', 'Lenckirkh,lun ci ji xi,Ленцкирх,Ленцкірх,伦茨基希', 47.8683200, 8.2021100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34822, 'Lenzen', 'Lenzen', '', 53.0917600, 11.4745300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34823, 'Lenting', 'Lenting', 'Lenting,lntyng,lun ting,Лентинг,Лентінг,Լենտինգ,لنتینگ,伦廷', 48.8102900, 11.4586800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34824, 'Lentföhrden', 'Lentfohrden', 'Lentfoehrden,Lentfohrden,Lentföhrden', 53.8666700, 9.8833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34825, 'Lenterode', 'Lenterode', 'Lenterode', 51.3333300, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34826, 'Lensahn', 'Lensahn', 'Lensahn,Lenzan,lun sa en,Лензан,伦萨恩', 54.2165200, 10.8832600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34827, 'Lennestadt', 'Lennestadt', 'Leneshtat,Lenneshtadt,Lennestadt,Stadt Lennestadt,lai nei si ta te,lynhshtat,Ленештат,Леннештадт,لنه‌اشتات,لينهشتات,莱内斯塔特', 51.1172100, 8.0670700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34828, 'Lenne', 'Lenne', '', 51.8938700, 9.6829900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34829, 'Lenggries', 'Lenggries', 'Lenggrias,Lenggris,Lengris,lngrys,lun li si,Ленггріс,Ленгрис,Լենգրիս,لنگریس,伦里斯', 47.6833300, 11.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34830, 'Lengfeld', 'Lengfeld', '', 50.5333300, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34831, 'Lengerich', 'Lengerich', 'Lengerich,Lengerich Dorf,Lengerikhe,Ленгерихе', 52.5538100, 7.5316400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34832, 'Lengerich', 'Lengerich', 'Lengerich', 52.1866100, 7.8604300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34833, 'Lengenwang', 'Lengenwang', '', 47.7000000, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34834, 'Lengenfeld', 'Lengenfeld', 'Lengenfeld', 50.5694000, 12.3640800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34835, 'Lengenbostel', 'Lengenbostel', '', 53.3000000, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34836, 'Lengefeld', 'Lengefeld', 'Lengefel''d,Lengefeld,Lengefelde,lngfld,lnghhfld,lun ge fei er de,Ленгефелд,Ленгефельд,لنغهفلد,لنگفلد,伦格费尔德', 50.7191100, 13.1929000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34837, 'Lengede', 'Lengede', 'Lengede,lun ge de,Ленгеде,伦格德', 52.2048700, 10.3077500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34838, 'Lengdorf', 'Lengdorf', 'Lengdorf,lngdwrf,lun duo fu,Ленгдорф,لنگدورف,伦多夫', 48.2573700, 12.0497300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34839, 'Lemwerder', 'Lemwerder', 'Lemverder,Lemwerder,XLW,lai mu wei er de er,Лемвердер,莱姆韦尔德尔', 53.1666700, 8.6166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34840, 'Lemsahl-Mellingstedt', 'Lemsahl-Mellingstedt', '', 53.6899800, 10.0964800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34841, 'Lemnitz', 'Lemnitz', 'Lemnitz', 50.7217900, 11.8332200, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34842, 'Lemgo', 'Lemgo', 'Lemge,Lemgo,lai mu ge,lmghw,lmgw,remugo,Лемго,لمغو,لمگو,レムゴー,莱姆戈', 52.0278600, 8.8990100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34843, 'Lemförde', 'Lemfoerde', 'Lemferde,Lemfjorde,Lemfoerde,Lemforde,Lemförde,lai mu fu er de,Лемферде,Лемфёрде,莱姆弗尔德', 52.4655700, 8.3762100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34844, 'Lembruch', 'Lembruch', '', 52.5333300, 8.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34845, 'Lemberg', 'Lemberg', '', 49.1730900, 7.6511100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34846, 'Leiwen', 'Leiwen', 'Lajven,Лайвен,Лајвен', 49.8166700, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34847, 'Leitzweiler', 'Leitzweiler', 'Lajcvajler,lai ci wei lei,Лайцвайлер,Лајцвајлер,莱茨韦勒', 49.5833300, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34848, 'Leitzkau', 'Leitzkau', '', 52.0581800, 11.9520300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34849, 'Leißling', 'Leissling', 'Leissling,Leißling', 51.1826000, 11.9095400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34850, 'Leisnig', 'Leisnig', 'Lajsnig,Leisnig,Leisniga,Lesnik,Lěsnik,lai si ni xi,layznyg,layznygh,Лайсниг,Лайсніг,Лајсниг,لايزنيغ,لایزنیگ,莱斯尼希', 51.1574300, 12.9279000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34851, 'Leisel', 'Leisel', '', 49.7166700, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34852, 'Leipzig', 'Leipzig', 'Gorad Lejpcyg,LEJ,Laeipcig,Lajpcig,Lajpcigu,Lajpcik,Leipciga,Leipcigas,Leipsia,Leipzig,Lejpcig,Leypsiq,Leypzig,Lipcse,Lipekika,Lipsca,Lipsia,Lipsk,Lipsko,Läipcig,Léypzig,Lípsia,la''ipajhisa,la''ipasisa,lai bi xi,laipcik,laipeuchihi,laiptsigi,laybzygh,laypzsh,laypzyg,lip sik,lipajiga,liph sik,lypzsh,lyypzyg,raiputsu~ihi,Λειψία,Горад Лейпцыг,Лайпциг,Лајпциг,Лейпциг,Լայպցիգ,לייפציג,لائپزش,لايبزيغ,لایپزیگ,لیپزش,लाइपझिश,लिपजिग,লাইপ্‌ৎসিশ,ਲਾਈਪਸਿਸ਼,லைப்சிக்,ไลป์ซิก,ไลพ์ซิก,လိုက်ပဆစ်မြို့,ლაიფციგი,ላይፕጽግ,ライプツィヒ,莱比锡,萊比錫,라이프치히', 51.3396200, 12.3712900, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34853, 'Leipheim', 'Leipheim', 'Lajpkhajm,Layphaym,Ljajpgajm,lai pu hai mu,laybhaym,layphaym,Лайпхайм,Лајпхајм,Ляйпгайм,Լայպհայմ,لايبهايم,لایپهایم,莱普海姆', 48.4500400, 10.2227800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34854, 'Leinzell', 'Leinzell', 'Lajncel,Lajncell'',Ljajncell'',lai yin ce er,laintseli,Лайнцелль,Лајнцел,Ляйнцелль,ლაინცელი,莱因策尔', 48.8494100, 9.8775000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34855, 'Leinsweiler', 'Leinsweiler', '', 49.1833300, 8.0191700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34856, 'Leiningen', 'Leiningen', '', 50.1333300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34857, 'Leinfelden-Echterdingen', 'Leinfelden-Echterdingen', 'Lajnfel''den-Ehkhterdingen,Lajnfelden-Ekhterdingen,Laynfelden Exterdingen,Laynfelden-Exterdingen,Leinfelden-Echterdingen,Ljajnfel''den-Ekhterdingen,lai yin fei er deng-ai xi te er ding gen,laynfldn-ashtrdynghn,laynfldn-ashtrdyngn,Лайнфельден-Эхтердинген,Лајнфелден-Ехтердинген,Ляйнфельден-Ехтердінген,Լայնֆելդեն Էխտերդինգեն,لاينفلدن-إشتردينغن,لاینفلدن-اشتردینگن,莱因费尔登-埃希特尔丁根', 48.6940600, 9.1680900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34858, 'Leinefelde', 'Leinefelde', '', 51.3879600, 10.3262000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34859, 'Leinburg', 'Leinburg', 'Lajnburg,Laynburg,Leinburg,Ljajnburg,lai yin bao,Лайнбург,Лајнбург,Ляйнбург,Լայնբուրգ,莱因堡', 49.4516700, 11.3100000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34860, 'Leimersheim', 'Leimersheim', '', 49.1242100, 8.3453100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34861, 'Leimen', 'Leimen', 'Laime,Lajmen,Leimen,Ljajmen,lai men,laymn,raimen,Лаймен,Лајмен,Ляймен,لايمن,لایمن,ライメン,萊門', 49.3473700, 8.6873300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34862, 'Leimen', 'Leimen', '', 49.2737300, 7.7686300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34863, 'Leimbach', 'Leimbach', 'Lajmbakh,Лаймбах,Лајмбах', 50.8166700, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34864, 'Leimbach', 'Leimbach', '', 50.4039200, 6.9277400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34865, 'Leimbach', 'Leimbach', '', 50.0166700, 6.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34866, 'Leiferde', 'Leiferde', 'Lajferde,Leiffer,lai fei er de,Лайферде,Лајферде,莱费尔德', 52.4394800, 10.4346100, 'DE', '2011-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34867, 'Leiferde', 'Leiferde', 'Leifer', 52.2044500, 10.5084200, 'DE', '2011-03-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34868, 'Leienkaul', 'Leienkaul', '', 50.2166700, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34869, 'Leidersbach', 'Leidersbach', 'Lajdersbakh,Laydersbax,Ljajdersbakh,lai de er si ba he,raidasubahha,Лайдерсбах,Лајдерсбах,Ляйдерсбах,Լայդերսբախ,ライダースバッハ,莱德尔斯巴赫', 49.9013900, 9.2216700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34870, 'Leidenborn', 'Leidenborn', '', 50.1333300, 6.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34871, 'Leichlingen', 'Leichlingen', 'Lajkhlingen,Leichlinga,Leichlingen,Ljajkhlingen,lai xi lin gen,layshlynghn,layshlyngn,Лайхлинген,Лајхлинген,Ляйхлінген,لايشلينغن,لایشلینگن,莱希林根', 51.1062800, 7.0187300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34872, 'Leiblfing', 'Leiblfing', '', 48.7756500, 12.5179300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34873, 'Leibertingen', 'Leibertingen', 'Lajbertingen,Ljajbertingen,lai bei er ting gen,Лайбертинген,Лајбертинген,Ляйбертінген,莱贝尔廷根', 48.0426300, 9.0130800, 'DE', '2013-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34874, 'Lehrte', 'Lehrte', 'Lehrte,Lerte,lai er te,lrth,Лерте,لرته,莱尔特', 52.3719300, 9.9791900, 'DE', '2014-08-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34875, 'Lehrensteinsfeld', 'Lehrensteinsfeld', 'Lerenshtajnsfel''d,Lerenshtajnsfeld,lai lun si tai yin si fei er de,rerenshutainsuferuto,Леренштайнсфельд,Леренштајнсфелд,レーレンシュタインスフェルト,莱伦斯泰因斯费尔德', 49.1311100, 9.3272200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34876, 'Lehre', 'Lehre', '', 52.3333300, 10.6666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34877, 'Lehrberg', 'Lehrberg', 'Lehrberg,Lerberg,lai er bei ge,reruberuku,Лерберг,Լերբերգ,レールベルク,莱尔贝格', 49.3456800, 10.5110100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34878, 'Lehnstedt', 'Lehnstedt', '', 50.9333300, 11.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34879, 'Lehmrade', 'Lehmrade', 'Lehmrade', 53.5939100, 10.7496500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34880, 'Lehmkuhlen', 'Lehmkuhlen', 'Lehmkuhlen,Lemkulen,lai mu ku lun,Лемкулен,莱姆库伦', 54.2333300, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34881, 'Lehmen', 'Lehmen', 'Lemen,lai men,Лемен,莱门', 50.2833300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34882, 'Lehesten', 'Lehesten', '', 50.9833300, 11.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34883, 'Lehe', 'Lehe', '', 54.3414300, 9.0237400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34884, 'Lehe', 'Lehe', '', 53.0000000, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34885, 'Legden', 'Legden', 'Legden,lai ge deng,Легден,莱格登', 52.0333300, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34886, 'Legau', 'Legau', 'Legau,lai gao,Легау,Լեգաու,莱高', 47.8562800, 10.1298100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34887, 'Leezen', 'Leezen', 'Leezen', 53.8666700, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34888, 'Leezen', 'Leezen', '', 53.6626500, 11.4987400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34889, 'Leezdorf', 'Leezdorf', '', 53.5500000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34890, 'Leese', 'Leese', 'Leze,reze,Лезе,レーゼ', 52.5000000, 9.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34891, 'Leer', 'Leer', 'Hleri,Leer,Ler,Leri,Lier,lr,lr  nydrzaksn,lyr,rea,Лер,לר,لر، نیدرزاکسن,لير,レーア', 53.2315700, 7.4610000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34892, 'Leegebruch', 'Leegebruch', 'Legebrukh,Legebrux,lai ge bu lu,Легебрух,Լեգեբրուխ,莱格布鲁', 52.7234000, 13.1930400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34893, 'Lederhose', 'Lederhose', '', 50.8000000, 11.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34894, 'Leck', 'Leck', 'Leck', 54.7666700, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34895, 'Lechbruck', 'Lechbruck', '', 47.7016200, 10.7949300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34896, 'Lebusa', 'Lebusa', 'Lebusa,Lebuza,lai bu sa,Лебуза,Лебуса,Լեբուզա,莱布萨', 51.7957200, 13.4206800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34897, 'Lebus', 'Lebus', 'Lebus,Lebusium,Lubusz,lai bu si,lbws,lybws,Лебус,Լեբուս,لبوس,ليبوس,莱布斯', 52.4271900, 14.5323500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34898, 'Lebrade', 'Lebrade', 'Lebrade', 54.2166700, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34899, 'Lebach', 'Lebach', 'Lebach,Lebakh,lbakh,lybakh,Лебах,لباخ,ليباخ', 49.4112200, 6.9098800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34900, 'Lawitz', 'Lawitz', '', 52.1070300, 14.6415100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34901, 'Lawalde', 'Lawalde', 'Laval''de,Lavalde,Lewald,Lěwałd,la wa er de,Лавалде,Лавальде,拉瓦尔德', 51.0833300, 14.6000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34902, 'Lautzenhausen', 'Lautzenhausen', '', 49.9333300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34903, 'Lautzenbrücken', 'Lautzenbrucken', '', 50.6736100, 7.9644400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34904, 'Lautrach', 'Lautrach', 'Lautrakh,lao te la he,Лаутрах,Լաութրախ,劳特拉赫', 47.8980500, 10.1180600, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34905, 'Lautertal', 'Lautertal', 'Lautertal,Lautertal'',rautataru,Лаутертал,Лаутерталь,ラウタータール', 50.5833300, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34906, 'Lautert', 'Lautert', '', 50.1666700, 7.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34907, 'Lautersheim', 'Lautersheim', '', 49.5872200, 8.0983300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34908, 'Lauterhofen', 'Lauterhofen', 'Lautergofen,Lauterhofen,Lauterkhofen,lao te luo fen,Лаутергофен,Лаутерхофен,Լաութերհոֆեն,劳特罗芬', 49.3684000, 11.6029400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34909, 'Lauterecken', 'Lauterecken', 'Lauterecken,Lautereken,Lauterekken,lao te lei ken,lawtrakn,rautaekken,Лаутерекен,Лаутереккен,لاوترإكن,لاوتراکن,ラウターエッケン,劳特雷肯', 49.6499300, 7.5926500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34910, 'Lauterbach', 'Lauterbach', '', 51.0666700, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34911, 'Lauterbach', 'Lauterbach', 'Lauterbach,Lauterbakh,lao te er ba he,lawtrbakh,rautabahha,Лаутербах,لاوترباخ,ラウターバッハ,劳特尔巴赫', 50.6355800, 9.3977700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34912, 'Lauterbach', 'Lauterbach', '', 49.1844500, 6.7437800, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34913, 'Lauterbach/Schwarzwald', 'Lauterbach/Schwarzwald', 'Lauterbach', 48.2299900, 8.3424000, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34914, 'Lauterach', 'Lauterach', '', 48.2562000, 9.5803400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34915, 'Lauter', 'Lauter', 'Lauter,Lauter/Sachsen,lawtr,lawtr  zaksn,Лаутер,لاوتر,لاوتر، زاکسن', 50.5626400, 12.7351300, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34916, 'Lauter', 'Lauter', '', 49.9731700, 10.7884200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34917, 'Lautenbach', 'Lautenbach', '', 48.4818500, 8.0273200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34918, 'Lautenbach', 'Lautenbach', '', 48.5207100, 8.1151400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34919, 'Laußnitz', 'Laussnitz', 'Lausnic,Laussnitzi vald,Laußnitzi vald,Luznica,lao si ni ci,Łužnica,Лаусниц,劳斯尼茨', 51.2500000, 13.8833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34920, 'Laußig', 'Laussig', 'Lausig,Laussigi vald,Laußigi vald,lao xi xi,Лаусиг,劳西希', 51.5467600, 12.6293000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34921, 'Lauschied', 'Lauschied', 'Laushid,lao xi de,Лаушид,劳席德', 49.7333300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34922, 'Lauscha', 'Lauscha', 'Lauscha', 50.4768700, 11.1596200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34923, 'Laurenburg', 'Laurenburg', '', 50.3322200, 7.9113900, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34924, 'Laupheim', 'Laupheim', 'Laupgajm,Lauphaym,Laupheim,Laupkhajm,lao pu hai mu,lawbhaym,lawphaym,Лаупгайм,Лаупхайм,Лаупхајм,Լաուպհայմ,לאופהיים,لاوبهايم,لاوپهایم,ლაუპჰაიმი,劳普海姆', 48.2278600, 9.8787400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34925, 'Lauperath', 'Lauperath', '', 50.0833300, 6.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34926, 'Laumersheim', 'Laumersheim', 'Laumerskhajm,lao mei er si hai mu,Лаумерсхайм,Лаумерсхајм,劳梅尔斯海姆', 49.5540500, 8.2353800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34927, 'Lauingen', 'Lauingen', 'Lauingen,Lavinoen,lao yin gen,lawynghn,lawyngn,Лауинген,Лауїнген,Լաուինգեն,لاوينغن,لاوینگن,劳因根', 48.5677500, 10.4270600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34928, 'Laugna', 'Laugna', 'Laugna,lao ge na,lawgna,Лаугна,Լաուգնա,لاوگنا,劳格纳', 48.5333300, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34929, 'Lauffen am Neckar', 'Lauffen am Neckar', 'Laufen am Nekar,Laufen na Nekaru,Lauffen,Lauffen am Neckar,Lauffen-am-Nekkar,Laviacum,lawfn am nka,lawfn am nykar,nei ka he pan lao fen,Лауфен ам Некар,Лауфен на Некару,Лауффен-ам-Неккар,لاوفن آم نيكار,لاوفن آم نکا,ラウフェン・アム・ネッカー,内卡河畔劳芬', 49.0734000, 9.1456700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34930, 'Laufersweiler', 'Laufersweiler', 'Langersweiler,Laufersvajler,Laufersweiler,lao fu er si wei lei,Лауферсвайлер,Лауферсвајлер,劳弗尔斯韦勒', 49.8964900, 7.3050200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34931, 'Laufenburg', 'Laufenburg', 'Klein Laufenburg,Laufenburg,Laufenburg in Baden,lawfnbwrg  alman,Лауфенбург,لاوفنبورگ، آلمان', 47.5651200, 8.0604500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34932, 'Laufen', 'Laufen', 'Laffa an da Soizach,Laufen,Laufen (Salzach),Lauffen,lao fen,lawfn,lawfn  alman,Лауфен,Լաուֆեն,لاوفن,لاوفن، آلمان,劳芬', 47.9356800, 12.9285600, 'DE', '2013-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34933, 'Laufeld', 'Laufeld', '', 50.0833300, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34934, 'Laufdorf', 'Laufdorf', '', 50.5160500, 8.4598200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34935, 'Lauf an der Pegnitz', 'Lauf an der Pegnitz', 'Lauf,Lauf an da Pegnitz,Lauf an der Pegnic,Lauf an der Pegnitz,Lauf-an-der-Pegnic,lawf an dr bghnytz,lawf an dr pgnytz,pei ge ni ci he pan lao fu,Лауф ан дер Пегниц,Лауф-ан-дер-Пегниц,Лауф-ан-дер-Пегніц,Պեգնիցի Լաուֆ,لاوف آن در بغنيتز,لاوف آن در پگنیتز,佩格尼茨河畔劳夫', 49.5138600, 11.2824700, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34936, 'Laufach', 'Laufach', 'Laufach,Laufakh,Laufax,lao fa,raufahha,Лауфах,Լաուֆախ,ラウファッハ,劳法', 50.0166700, 9.3000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34937, 'Lauf', 'Lauf', 'Lauf,Лауф', 48.6500000, 8.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34938, 'Lauenhagen', 'Lauenhagen', '', 52.3554700, 9.2063700, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34939, 'Lauenburg', 'Lauenburg', 'Lauenberg,Lauenburg', 53.3719900, 10.5565400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34940, 'Lauenbrück', 'Lauenbruck', 'Lauehnbrjuk,Lauenbrik,Lauenbruech,Lauenbrueck,Lauenbrüch,Lauenbrück,lao en bu lu ke,rauenburyukku,Лауенбрик,Лауэнбрюк,ラウエンブリュック,劳恩布吕克', 53.2000000, 9.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34941, 'Lauenau', 'Lauenau', 'Lauehnau,Lauenau,lao ai nao,rauenau,Лауенау,Лауэнау,ラウエナウ,劳埃瑙', 52.2739300, 9.3692800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34942, 'Laudenbach', 'Laudenbach', 'Laudenbakh,Laudenbax,raudenbahha,Лауденбах,Լաուդենբախ,ラウデンバッハ', 49.7458300, 9.1761100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34943, 'Laudenbach', 'Laudenbach', 'Laudenbakh,raudenbahha,Лауденбах,ラウデンバッハ', 49.6133300, 8.6538900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34944, 'Lauchröden', 'Lauchroeden', '', 50.9937100, 10.1569400, 'DE', '2015-09-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34945, 'Lauchheim', 'Lauchheim', 'Laukhgajm,Laukhkhajm,lakhhaym,lao hai mu,laukhhaimi,lawkhhaym,Лаухгайм,Лауххайм,Лауххајм,لاخهایم,لاوخهايم,ლაუხჰაიმი,劳海姆', 48.8713500, 10.2422200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34946, 'Lauchhammer', 'Lauchhammer', 'Lauchhammer,Lauchhammer East,Lauhamer,Laukhamer,Laukhkhammer,Luchow,Stadt Lauchhammer,lao ha mei er,lawkhhamr,lawkhhmr,Łuchow,Лаухамер,Лауххаммер,Լաուհամեր,لاوخهامر,لاوخهمر,劳哈梅尔', 51.4881300, 13.7662300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34947, 'Laucha', 'Laucha', 'Laucha,Laucha an der Unstrut', 51.2242200, 11.6798800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34948, 'Laubenheim', 'Laubenheim', 'Laubenkhajm,lao ben hai mu,Лаубенхайм,Лаубенхајм,劳本海姆', 49.9166700, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34949, 'Lauben', 'Lauben', '', 48.0592800, 10.2901400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34950, 'Lauben', 'Lauben', '', 47.7833300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34951, 'Laubach', 'Laubach', 'Laubakh,lao ba he,lawbakh  alman,raubahha,Лаубах,لاوباخ، آلمان,ラウバッハ,劳巴赫', 50.5419600, 8.9903400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34952, 'Laubach', 'Laubach', '', 50.2327700, 7.0733300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34953, 'Laubach', 'Laubach', '', 50.0500000, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34954, 'Lathen', 'Lathen', 'Laten,la teng,raten,Латен,ラーテン,拉滕', 52.8666700, 7.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34955, 'Latendorf', 'Latendorf', 'Latendorf', 54.0000000, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34956, 'Lastrup', 'Lastrup', 'Lastrup,la si te lu pu,Ластруп,拉斯特鲁普', 52.7946800, 7.8671500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34957, 'Lassan', 'Lassan', 'Lassan', 53.9487400, 13.8521900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34958, 'Lasel', 'Lasel', '', 50.1166700, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34959, 'Lascheid', 'Lascheid', '', 50.1166700, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34960, 'Lasbek', 'Lasbek', 'Lasbek,Lasbek-Dorf,la si bei ke,Ласбек,拉斯贝克', 53.7333300, 10.3666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34961, 'Lappersdorf', 'Lappersdorf', 'Lapersdorf,Lappersdorf,la po si duo fu,laprsdwrf,Лаперсдорф,Лапперсдорф,Լափերսդորֆ,لاپرسدورف,拉珀斯多夫', 49.0469400, 12.0913000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34962, 'Lanze', 'Lanze', '', 53.3871300, 10.6049200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34963, 'Lanz', 'Lanz', 'Lanc,lan ci,Ланц,兰茨', 53.0744200, 11.5990800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34964, 'Lanstrop', 'Lanstrop', '', 51.5750400, 7.5675200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34965, 'Lankwitz', 'Lankwitz', 'Berlin-Lankwitz,Lankvic,Ланквиц', 52.4362300, 13.3459000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34966, 'Lankow', 'Lankow', '', 53.6498300, 11.3691300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34967, 'Lankau', 'Lankau', 'Lankau', 53.6666700, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34968, 'Langwieden', 'Langwieden', '', 49.3833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34969, 'Langweiler', 'Langweiler', '', 49.7833300, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34970, 'Langweiler', 'Langweiler', 'Langvajler,Лангвайлер,Лангвајлер', 49.6666700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34971, 'Langweid', 'Langweid', 'Langweid,Langweid am Lech', 48.4909500, 10.8531000, 'DE', '2015-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34972, 'Langwedel', 'Langwedel', '', 54.2103300, 9.9276100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34973, 'Langwedel', 'Langwedel', 'Langvedel,Langvedel'',Langwedel,lang wei de er,ranguvu~ederu,Лангведел,Лангведель,ラングヴェーデル,朗韦德尔', 52.9786400, 9.1854200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34974, 'Langula', 'Langula', 'Langula', 51.1500100, 10.4167000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34975, 'Langsur', 'Langsur', 'Langsur,Langzur,Laser,lang su er,Лангзур,Лангсур,朗苏尔', 49.7244200, 6.4990600, 'DE', '2015-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34976, 'Langstedt', 'Langstedt', 'Langstedt', 54.6166700, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34977, 'Langscheid', 'Langscheid', '', 50.3833300, 7.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34978, 'Langquaid', 'Langquaid', 'Langkvajd,Langquaid,Langquaidt,Langvajd,Lankwatt,lang ku ai de,langkwayd,Лангвајд,Лангквайд,Լանգքվայդ,لانگکواید,朗库艾德', 48.8231800, 12.0513400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34979, 'Langlingen', 'Langlingen', 'Langeln,Langlingen,lang lin gen,Ланглинген,朗林根', 52.5559300, 10.2829100, 'DE', '2014-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34980, 'Langgöns', 'Langgons', 'Lang Gons,Lang Göns,Langens,Langgens,Langgjons,Langgoens,Langgons,Langgöns,lan gen si,rangugensu,Ланггенс,Ланггёнс,Лангенс,ラングゲンス,兰根斯', 50.5000000, 8.6666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34981, 'Langewiesen', 'Langewiesen', 'Langevisen,Langevizen,Langewiesen,lan ge wei sen,langhhfyzn,langwyzn,Лангевизен,Лангевисен,لانغهفيزن,لانگویزن,兰格维森', 50.6725200, 10.9710200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34982, 'Langewahl', 'Langewahl', '', 52.3333300, 14.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34983, 'Langerwehe', 'Langerwehe', 'Langervee,Langerveeh,Langervekhe,Langerwehe,lan ge er wei hei,Лангервее,Лангервехе,Лангервеэ,兰格尔韦黑', 50.8166700, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34984, 'Langerringen', 'Langerringen', 'Langeringen,Langerringen,lan ge lin gen,Лангеринген,Лангерринген,Лангеррінген,Լանգերինգեն,兰格林根', 48.1459000, 10.7589400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34985, 'Langeoog', 'Langeoog', 'LGO,Langeog,Langeooch,Langeoog,Langereach,lan ge ao ge,langeoogi,lanjh awkh,Лангеог,لانجه أوخ,لانگه‌اگ,ლანგეოოგი,兰格奥格', 53.7500000, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34986, 'Langenzenn', 'Langenzenn', 'Langencen,Langencenn,Langenzenn,lan gen cen,langtsn,Лангенцен,Лангенценн,لانگتسن,兰根岑', 49.4946300, 10.7923000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34987, 'Langenwolschendorf', 'Langenwolschendorf', 'Langenwolschendorf', 50.6354600, 11.9541600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34988, 'Langenwetzendorf', 'Langenwetzendorf', 'Langenvecendorf,Langenvetcendorf,Langenwetzendorf,lan gen wei cen duo fu,Лангенветцендорф,Лангенвецендорф,兰根韦岑多夫', 50.6788400, 12.0940700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34989, 'Langenthal', 'Langenthal', '', 49.8333300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34990, 'Langenstein', 'Langenstein', 'Langenstein', 51.8555100, 10.9882200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34991, 'Langensendelbach', 'Langensendelbach', '', 49.6405100, 11.0710400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34992, 'Langenselbold', 'Langenselbold', 'Langenselbold,Langenzel''bol''d,lang gen sai er bo de,langhnzlbwld,langnzlbwld,rangenzeruboruto,Лангензельбольд,Лангенселболд,لانغنزلبولد,لانگنزلبولد,ランゲンゼルボルト,朗根塞尔博德', 50.1765700, 9.0400300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34993, 'Langenscheid', 'Langenscheid', '', 50.3559800, 7.9516600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34994, 'Langenpreising', 'Langenpreising', 'Langapreising,Langenprajsing,Langenprajzing,lan gen pu lai xing,langn prayzyng,Лангенпрайзинг,Лангенпрайзінг,Лангенпрајсинг,لانگن پرایزینگ,兰根普赖兴', 48.4256900, 11.9721700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34995, 'Langenorla', 'Langenorla', 'Langenorla,lan ge nuo er la,Лангенорла,兰格诺尔拉', 50.7406700, 11.5802300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34996, 'Langenneufnach', 'Langenneufnach', 'Langennojfnakh,Langennoyfnax,Langenojfnakh,lan ge nuo yi fu na,Лангеннойфнах,Лангенојфнах,Լանգեննոյֆնախ,兰格诺伊夫纳', 48.2666700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34997, 'Langenmosen', 'Langenmosen', 'Langenmoosen,Langenmosen,Langenmozen,lan gen mo sen,langnmwzn,Лангенмозен,Лангенмосен,Լանգենմոզեն,لانگنموزن,兰根莫森', 48.6065800, 11.2137800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34998, 'Langenlonsheim', 'Langenlonsheim', 'Langenlonskhajm,lan gen long si hai mu,Лангенлонсхайм,Лангенлонсхајм,兰根隆斯海姆', 49.9000000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(34999, 'Langenleuba-Niederhain', 'Langenleuba-Niederhain', 'Langenleuba-Niederhain,Langenlojba-Niderkhajn,Niederhain,lan gen luo yi ba-ni de lai yin,Лангенлойба-Нидерхайн,Лангенлојба-Нидерхајн,兰根洛伊巴-尼德赖因', 50.9599100, 12.5885700, 'DE', '2014-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35000, 'Langenlehsten', 'Langenlehsten', 'Langenlehsen', 53.5010100, 10.7406800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35001, 'Langenhorn', 'Langenhorn', '', 53.6655600, 10.0013700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35002, 'Langenhorn', 'Langenhorn', 'E Hoorne,Langenkhorn,Langhorn,Лангенхорн', 54.6666700, 8.9166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35003, 'Langenhahn', 'Langenhahn', '', 50.5833300, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35004, 'Langenhagen', 'Langenhagen', 'Langenhagen,Langenhogen,Langenkhagen,Nienhagen [a. 1312],lang gen ha gen,langhnhaghn,langnhagn,Лангенхаген,لانغنهاغن,لانگنهاگن,朗根哈根', 52.4475800, 9.7374100, 'DE', '2014-07-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35005, 'Langenfeld', 'Langenfeld', 'Langefaeael,Langefääl,Langenfel''d,Langenfeld,ZNX,lang gen fei er de,langnfld,Лангенфелд,Лангенфельд,لانگنفلد,朗根费尔德', 51.1082100, 6.9483100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35006, 'Langenfeld', 'Langenfeld', '', 50.3769200, 7.0916500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35007, 'Langenfeld', 'Langenfeld', '', 49.6166700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35008, 'Langeneß', 'Langeness', 'A Naeaes,A Nääs,Langenaes,Langenes,Langeness,Langeneß,Langenæs,Nees,lan ge nei si,langenesi,Лангенес,ლანგენესი,兰格内斯', 54.6404600, 8.5918300, 'DE', '2013-12-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35009, 'Langenenslingen', 'Langenenslingen', 'Langenenslingen,Langeneslingen,lan ge nen si lin gen,langenenslingeni,Лангененслинген,Лангененслінген,Лангенеслинген,Լանգենեսլինգեն,ლანგენენსლინგენი,兰格嫩斯林根', 48.1485100, 9.3776500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35010, 'Langeneichstädt', 'Langeneichstaedt', '', 51.3453700, 11.7433000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35011, 'Langendorf', 'Langendorf', '', 53.1009300, 11.2557900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35012, 'Langendorf', 'Langendorf', 'Langendorf', 51.1797200, 11.9614000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35013, 'Langenburg', 'Langenburg', 'Langenbourg,Langenburg,lan gen bao,langhnbwrgh,langnbwrg,rangenburuku,Лангенбург,لانغنبورغ,لانگنبورگ,ランゲンブルク,兰根堡', 49.2540100, 9.8567300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35014, 'Langenbogen', 'Langenbogen', 'Langenbogen', 51.4830000, 11.7778600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35015, 'Langenbernsdorf', 'Langenbernsdorf', 'Langenbernsdorf,lan gen bei er en si duo fu,Лангенбернсдорф,兰根贝尔恩斯多夫', 50.7558300, 12.3266900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35016, 'Langenberg', 'Langenberg', '', 51.7720600, 8.3180900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35017, 'Langenbach bei Marienberg', 'Langenbach bei Marienberg', 'Langenbach,Langenbach bei Marienberg', 50.6380600, 7.9478700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35018, 'Langenbach bei Kirburg', 'Langenbach bei Kirburg', 'Langenbach,Langenbach bei Kirburg', 50.7000000, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35019, 'Langenbach', 'Langenbach', 'Langenbakh,Лангенбах', 49.4935500, 7.3277100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35020, 'Langenbach', 'Langenbach', 'Langenbakh,Langenbax,langn bakh,Лангенбах,Լանգենբախ,لانگن باخ', 48.4333300, 11.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35021, 'Langenau', 'Langenau', 'Langenau,lan ge nao,langenau,langhnaw,langnaw,Лангенау,Լանգենաու,لانغناو,لانگناو,ლანგენაუ,兰格瑙', 48.4961600, 10.1184900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35022, 'Langenargen', 'Langenargen', 'Arguna,Langenargen,lan ge na er ge en,langenargeni,Лангенарген,Լանգենարգեն,ლანგენარგენი,兰格纳尔格恩', 47.5985800, 9.5416300, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35023, 'Langenaltheim', 'Langenaltheim', 'Langenal''tgajm,Langenal''tkhajm,Langenalthaym,Langenaltkhajm,lan ge na er tai mu,Лангеналтхајм,Лангенальтгайм,Лангенальтхайм,Լանգենալտհայմ,兰格纳尔泰姆', 48.8931800, 10.9310700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35024, 'Langen', 'Langen', '', 53.6055400, 8.5950900, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35025, 'Langen', 'Langen', '', 52.5398500, 7.4674000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35026, 'Langen', 'Langen', 'Gorad Langen,Langen,langhn,langn,rangen,Горад Ланген,Ланген,لانغن,لانگن,ランゲン', 49.9895500, 8.6685200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35027, 'Langelsheim', 'Langelsheim', 'Langel''skhajm,Langelheim,Langelsheim,Langelskhajm,lan ge er si hai mu,langhlshaym,langlzhaym,Лангелсхајм,Лангельсхайм,لانغلسهايم,لانگلزهایم,兰格尔斯海姆', 51.9378900, 10.3326400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35028, 'Langeln', 'Langeln', '', 53.7928800, 9.8626300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35029, 'Langeln', 'Langeln', 'Langeln', 51.9118800, 10.7943600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35030, 'Langdorf', 'Langdorf', '', 49.0150200, 13.1465100, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35031, 'Langballig', 'Langballig', 'Langbalig,Langballe,Langballig,lang ba li xi,Лангбалиг,Лангбаллиг,朗巴利希', 54.8000000, 9.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35032, 'Landstuhl', 'Landstuhl', 'Landshtul,Landshtul'',Landstuhl,Londschduul,lan ci tu er,lanteusyutul,lndashtwl,lndstwl,rantoshuto~uru,Ландштул,Ландштуль,לנדשטול,لنداشتول,ラントシュトゥール,兰茨图尔,란트슈툴', 49.4130600, 7.5702100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35033, 'Landshut', 'Landshut', 'Gorad Landsgut,Landishuta,Landsgut,Landshuad,Landshut,Landshutas,Landskhut,Lantschout,QLG,lan ci hu te,lan dshuth,lancheuhuteu,landshwt,rantsufuto,Λάντσχουτ,Горад Ландсгут,Ландсгут,Ландсхут,Լանդսհուտ,لاندسهوت,ลันด์สฮูท,ლანდსჰუტი,ランツフート,兰茨胡特,란츠후트', 48.5296100, 12.1617900, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35034, 'Landscheide', 'Landscheide', '', 53.9201100, 9.2529200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35035, 'Landscheid', 'Landscheid', '', 49.9833300, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35036, 'Landsberied', 'Landsberied', 'Landsberid,Landschbariad,Maisach,lan ci bei li de,lndsbryd,Ландсберид,Ландсберід,Լանդսբերիդ,لندسبرید,兰茨贝里德', 48.1666700, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35037, 'Landsberg', 'Landsberg', 'Landsberg,Landsberg bei Halle', 51.5269800, 12.1607600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35038, 'Landsberg am Lech', 'Landsberg am Lech', 'Landsberg,Landsberg am Lech,Landsberg am Lekh,Landsberg-am-Lekh,Landsbergium,Lexi Landsberg,lai xi he pan lan ci bei ge,landsbrg am lsh,landsbrgh am lsh,Ландсберг ам Лех,Ландсберг-ам-Лех,Լեխի Լանդսբերգ,لاندسبرغ آم لش,لاندسبرگ آم لش,ランツベルク・アム・レヒ,莱希河畔兰茨贝格', 48.0481900, 10.8828200, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35039, 'Landrecht', 'Landrecht', 'Landrecht', 53.9333300, 9.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35040, 'Landolfshausen', 'Landolfshausen', 'Landol''fskhauzen,Landolfskhauzen,lan duo fu si hao sen,randorufusuhauzen,Ландолфсхаузен,Ландольфсхаузен,ランドルフスハウゼン,兰多夫斯豪森', 51.5333300, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35041, 'Landkern', 'Landkern', '', 50.1938800, 7.1536900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35042, 'Landesbergen', 'Landesbergen', 'Landesbergen,lan de si bei er gen,randesuberugen,Ландесберген,ランデスベルゲン,兰德斯贝尔根', 52.5559800, 9.1250500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35043, 'Landensberg', 'Landensberg', 'Landensberg,lan deng si bei ge,Ланденсберг,Լանդենսբերգ,兰登斯贝格', 48.4344400, 10.5242200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35044, 'Landau in der Pfalz', 'Landau in der Pfalz', 'Landau,Landau in der Pfalz,Ландау,לנדאו', 49.1984400, 8.1169200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35045, 'Landau an der Isar', 'Landau an der Isar', 'Izardagy Landau,Izari Landau,Landau,Landau an der Izar,Landau-an-der-Izar,Landavium ad Isaram,landaw an dr ayzar,yi sa er he pan lan dao,Изардағы Ландау,Ландау,Ландау ан дер Изар,Ландау-ан-дер-Ізар,Ландау-ан-дер-Изар,Իզարի Լանդաու,لانداو آن در إيزار,لانداو آن در ایزار,伊萨尔河畔兰道', 48.6724900, 12.6931600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35046, 'Lamstedt', 'Lamstedt', 'Gemeen Loomst,Lamshtedt,Lamshtet,Ламштедт,Ламштет', 53.6333300, 9.1000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35047, 'Lamspringe', 'Lamspringe', 'Lamshpringe,Lamspringe,la mu si pu lin ge,Ламспринге,Ламшпринге,拉姆斯普林格', 51.9607100, 10.0110500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35048, 'Lampertswalde', 'Lampertswalde', 'Lampertsval''de,Lampertsvalde,Lampertswalde vald,lan pei er ci wa er de,Лампертсвалде,Лампертсвальде,兰佩尔茨瓦尔德', 51.3110800, 13.6769400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35049, 'Lampertheim', 'Lampertheim', 'Gorad Lampertkhajm,Lambade,Lampertgajm,Lampertheim,Lampertkhajm,Låmbade,lamprthaym  alman,lan pei er tai mu,ramupatohaimu,Горад Лампертхайм,Лампертгайм,Лампертхайм,Лампертхајм,لامپرتهایم، آلمان,ラムパートハイム,兰佩尔泰姆', 49.5978600, 8.4725000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35050, 'Lampaden', 'Lampaden', '', 49.6500000, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35051, 'Lammershagen', 'Lammershagen', 'Lammershagen', 54.2833300, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35052, 'Lamerdingen', 'Lamerdingen', 'Lamerdingen,la mei er ding gen,ramadingen,Ламердинген,Ламердінген,Լամերդինգեն,ラマーディンゲン,拉梅尔丁根', 48.0919500, 10.7398200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35053, 'Lambsheim', 'Lambsheim', 'Lambsheim,Lambskhajm,Lomsem,lan bu si hai mu,ranpusuhaimu,Ламбсхайм,Ламбсхајм,ランプスハイム,兰布斯海姆', 49.5136100, 8.2877800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35054, 'Lambsborn', 'Lambsborn', '', 49.3666700, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35055, 'Lambrechtshagen', 'Lambrechtshagen', 'Lambrechtshagen,Lambrekhtkhagen,Lambrekhtskhagen,lan bu lei xi ci ha gen,Ламбрехтсхаген,Ламбрехтхаген,兰布雷希茨哈根', 54.1020800, 12.0164500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35056, 'Lambrecht', 'Lambrecht', 'Lambrecht', 49.3705500, 8.0726400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35057, 'Lambertsberg', 'Lambertsberg', '', 50.0833300, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35058, 'Lam', 'Lam', 'Lam,Лам,Լամ', 49.1966500, 13.0505100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35059, 'Lalling', 'Lalling', 'Laling,Lalling,la ling,lalyng,Лалинг,Лаллинг,Лаллінг,Լալինգ,لالینگ,拉灵', 48.8452500, 13.1400800, 'DE', '2011-08-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35060, 'Lalendorf', 'Lalendorf', 'Lalendorf,la lun duo fu,Лалендорф,拉伦多夫', 53.7577400, 12.3898300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35061, 'Laichingen', 'Laichingen', 'Lajkhingen,Layxingen,lai xin gen,laikhingeni,layshnghn,layshngn,Лайхинген,Лайхінген,Лајхинген,Լայխինգեն,لايشنغن,لایشنگن,ლაიხინგენი,莱欣根', 48.4893900, 9.6861200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35062, 'Lahr', 'Lahr', '', 50.1250900, 7.3653900, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35063, 'Lahr', 'Lahr', '', 49.9333300, 6.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35064, 'Lahr', 'Lahr', 'LHA,Lahr,Lahr/Schwarzwald,Lar,la er,lar,lar  badn-wwrtmbrg,Лар,لار,لار، بادن-وورتمبرگ,拉尔', 48.3404200, 7.8688600, 'DE', '2013-03-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35065, 'Lahnstein', 'Lahnstein', 'Lahnstein,Lahnstenium,Lanshhajn,Lanshtajn,la en si tai yin,lanshtayn,ranshutain,Ланштайн,Ланштајн,Ланщайн,لانشتاين,لان‌اشتاین,ラーンシュタイン,拉恩斯泰因', 50.3000000, 7.6166700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35066, 'Lahn', 'Lahn', '', 52.8166700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35067, 'Lähden', 'Laehden', 'Lahden,Leden,Lekhden,Lähden,lai deng,Леден,Лехден,莱登', 52.7454700, 7.5703600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35068, 'Lägerdorf', 'Lagerdorf', 'Laegerdorf,Lagerdorf,Lägerdorf', 53.8833300, 9.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35069, 'Lage', 'Lage', '', 52.4666700, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35070, 'Lage', 'Lage', 'Lage,la ge,lagh  nwrdrayn-wstfaln,laghh,rage,Лаге,لاغه,لاگه، نوردراین-وستفالن,ラーゲ,拉格', 51.9922300, 8.7930100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35071, 'Bad Laer', 'Bad Laer', 'Bad Laer,Bad-Lar,Laer,ba te la er,Бад Лаер,Бад-Лар,巴特拉尔', 52.1000000, 8.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35072, 'Laer', 'Laer', 'Laer,Lar,Ler,la ai er,Лаер,Лар,Лер,拉埃尔', 52.0555500, 7.3577500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35073, 'Ladenburg', 'Ladenburg', 'Ladenburg,Ladenburgo,Lopodunum,la deng bao,ladnbwrg,ladnbwrgh,radenburuku,Ладенбург,لادنبورغ,لادنبورگ,ラーデンブルク,拉登堡', 49.4730700, 8.6089600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35074, 'Ladelund', 'Ladelund', 'Laaloenj,Ladelund,Låålönj,la de lun de,Ладелунд,拉德伦德', 54.8408400, 9.0213500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35075, 'Ladbergen', 'Ladbergen', 'Ladbergen,la de bei er gen,Ладберген,拉德贝尔根', 52.1333300, 7.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35076, 'Lachendorf', 'Lachendorf', 'Lachendorf,Lakhendorf,la heng duo fu,Лахендорф,拉亨多夫', 52.6166700, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35077, 'Lachen', 'Lachen', '', 47.9459000, 10.2394300, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35078, 'Laboe', 'Laboe', 'Labjo,Labo,Laboe,la bo ai,Лабо,Лабё,拉博埃', 54.4000000, 10.2166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35079, 'Laberweinting', 'Laberweinting', 'Labervajnting,la bo wei en ting,labrwayntyng,Лабервайнтинг,Лабервайнтінг,Лабервајнтинг,لابرواینتینگ,拉伯韦恩廷', 48.8000000, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35080, 'Labenz', 'Labenz', 'Labenz', 53.7097600, 10.5212500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35081, 'Laatzen', 'Laatzen', 'Laatzen,Lacen,Latcen,la cen,latsn,rattsu~en,Латцен,Лацен,لآتسن,لاتسن,ラッツェン,拉岑', 52.3150600, 9.7973900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35082, 'Bad Laasphe', 'Bad Laasphe', 'Bad Laasphe,Bad Lasfe,Bad-Laasfe,Bad-Lasfe,Laasphe,ba te la si fei,bad lasfh,Бад Ласфе,Бад-Лаасфе,Бад-Ласфе,باد لاسفه,巴特拉斯费', 50.9313900, 8.4250200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35083, 'Laasdorf', 'Laasdorf', '', 50.8713600, 11.6725000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35084, 'Laar', 'Laar', '', 52.6166700, 6.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35085, 'Laar', 'Laar', '', 52.3558100, 8.2538800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35086, 'Laage', 'Laage', 'Laage,Lage,Lāge,lagh,laghh,Лаге,لآغه,لاگه', 53.9256000, 12.3469400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35087, 'Kyritz', 'Kyritz', 'Kiric,Kyritz,ji li ci,kwryts,kyrytz,Кириц,Կիրից,كوريتس,کیریتز,基里茨', 52.9421200, 12.3970400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35088, 'Kyllburgweiler', 'Kyllburgweiler', '', 50.0500000, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35089, 'Kyllburg', 'Kyllburg', 'Kil''burg,Kilburg,Killburg,Kyllburg,ji er bao,kiruburuku,kwlbwrgh,kylbwrg,Килбург,Кильбург,كولبورغ,کیلبورگ,キルブルク,基爾堡', 50.0386400, 6.5947800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35090, 'Kutzleben', 'Kutzleben', '', 51.2000000, 10.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35091, 'Kutzenhausen', 'Kutzenhausen', '', 48.3420200, 10.6945900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35092, 'Kutenholz', 'Kutenholz', 'Kutenhult,Kutenkhol''c,Kutenkholc,ku teng huo er ci,kutenhorutsu,Кутенхолц,Кутенхольц,クーテンホルツ,库滕霍尔茨', 53.4815200, 9.3211800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35093, 'Kusterdingen', 'Kusterdingen', '', 48.5229100, 9.1197700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35094, 'Küsten', 'Kuesten', 'Kisten,Kjusten,kwstn,qu si teng,Кистен,Кюстен,کوستن,屈斯滕', 52.9777900, 11.0624000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35095, 'Kusey', 'Kusey', 'Kusey', 52.5798700, 11.0905600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35096, 'Kusel', 'Kusel', 'Cosla,Kuesel,Kusel,Kuzel,Kuzel'',Küsel,ku sai er,kuzeru,kwzl,Кузел,Кузель,كوزل,کوزل,クーゼル,库塞尔', 49.5377200, 7.4047200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35097, 'Kurtscheid', 'Kurtscheid', '', 50.5333300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35098, 'Kürten', 'Kurten', 'Kirten,Kjurten,Kuerten,Kurten,Kürten,qu er teng,Киртен,Кюртен,屈尔滕', 51.0500000, 7.2666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35099, 'Seiffen', 'Seiffen', 'Seiffen,Seiffen/Erzgebirge,Seiffeni vald,Zajfen,sai fen,Зайфен,Зајфен,塞芬', 50.6500000, 13.4500000, 'DE', '2017-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35100, 'Kurort Oybin', 'Kurort Oybin', 'Kurort Oybin,Oybin', 50.8410500, 14.7412400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35101, 'Kurort Oberwiesenthal', 'Kurort Oberwiesenthal', 'Kurort Oberwiesenthal,Obervizental'',Oberwiesenthal,Обервизенталь', 50.4194300, 12.9683600, 'DE', '2016-03-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35102, 'Kurort Jonsdorf', 'Kurort Jonsdorf', 'Johnsdorf,Jonsdorf,Kurort Jonsdorf', 50.8575100, 14.7092200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35103, 'Kurort Gohrisch', 'Kurort Gohrisch', 'Gohrisch', 50.9123400, 14.1068700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35104, 'Kürnbach', 'Kurnbach', 'Kirnbakh,Kjurnbakh,Kurnbach,Kürnbach,qu er en ba he,Кирнбах,Кюрнбах,屈尔恩巴赫', 49.0775000, 8.8455600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35105, 'Kürnach', 'Kurnach', 'Kuernach,Kürnach', 49.8500000, 10.0333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35106, 'Kueps Oberfranken', 'Kueps Oberfranken', 'Kueps,Kueps Oberfranken,Kups,Küps', 50.1926500, 11.2759900, 'DE', '2016-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35107, 'Kuppenheim', 'Kuppenheim', 'Cuppenheim,Kupenkhajm,Kuppengajm,Kuppenheim,Kuppenkhajm,ku peng hai mu,kwbnhaym,kwpnhaym,Купенхајм,Куппенгайм,Куппенхайм,كوبنهايم,کوپنهایم,库彭海姆', 48.8279400, 8.2541700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35108, 'Kupferzell', 'Kupferzell', 'Kupfercel,Kupfercell'',Kupferzell,ku pu fei er ce er,kupufatsu~eru,Купферцел,Купферцелль,クプファーツェル,库普费尔策尔', 49.2277800, 9.6900000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35109, 'Kupferberg', 'Kupferberg', 'Kupferberg,ku pu fu bei ge,kupufaberuku,kwbfrbrg,kwbfrbrgh,Купферберг,Քուպֆերբերգ,كوبفربرغ,کوبفربرگ,クプファーベルク,库普弗贝格', 50.1396000, 11.5776200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35110, 'Künzing', 'Kunzing', 'Kuenzing,Künzing,Quintanis', 48.6666700, 13.0833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35111, 'Künzelsau', 'Kuenzelsau', 'Kincelsau,Kjuncel''zau,Kuenzelsau,Kunzelsau,Künzelsau,jin ce er shao,kwntsalw,kwntslzaw,kyuntsu~eruzau,Кинцелсау,Кюнцельзау,كونتسلزاو,کونتسالو,キュンツェルザウ,金策尔绍', 49.2818000, 9.6835200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35112, 'Künzell', 'Kunzell', 'Kincel,Kjuncell'',Kuenzell,Künzell,jin ce er,Кинцел,Кюнцелль,Күнселль,金策尔', 50.5442000, 9.7179200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35113, 'Kunreuth', 'Kunreuth', '', 50.2332100, 11.5311900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35114, 'Kunreuth', 'Kunreuth', 'Kunrojt,kun luo yi te,kunroito,Кунройт,Кунројт,Քունրոյտ,クンロイト,昆罗伊特', 49.6824000, 11.1433100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35115, 'Kundert', 'Kundert', '', 50.7186100, 7.7919400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35116, 'Kümmersbruck', 'Kummersbruck', 'Kimersbruk,Kjummersbruk,Kuemmersbruck,Kümmersbruck,qu mei er si bu lu ke,Кимерсбрук,Кюммерсбрук,Քյումերսբրուկ,屈梅尔斯布鲁克', 49.4191700, 11.8883300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35117, 'Kummerfeld', 'Kummerfeld', 'Kumerfeld,Kummerfel''d,ku mei er fei er de,Кумерфелд,Куммерфельд,库梅尔费尔德', 53.6926200, 9.7909900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35118, 'Kumhausen', 'Kumhausen', 'Kumgauzen,Kumkhauzen,ku mu hao sen,kwmhawzn,Кумгаузен,Кумхаузен,Քումհաուզեն,کومهاوزن,库姆豪森', 48.5093800, 12.1563700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35119, 'Kümbdchen', 'Kuembdchen', '', 49.9833300, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35120, 'Külsheim', 'Kulsheim', 'Kilskhajm,Kjul''sgajm,Kjul''skhajm,Kuelsheim,Kulsheim,Külsheim,kwlshaym,kwlzhaym,kyurusuhaimu,qu er si hai mu,Килсхајм,Кюльсгайм,Кюльсхайм,كولسهايم,کولزهایم,キュルスハイム,屈尔斯海姆', 49.6694200, 9.5236100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35121, 'Kulpin', 'Kulpin', 'Kulpin', 53.7099200, 10.6950200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35122, 'Kulmbach', 'Kulmbach', 'Culmbach,Kul''mbakh,Kulmbach,Kulmbakh,Kulmbax,Stadt Kulmbach,ku er mu ba he,kurumubahha,kwlmbakh,Кулмбах,Кульмбах,Կուլմբախ,كولمباخ,کولمباخ,クルムバッハ,庫爾姆巴赫', 50.1006800, 11.4503200, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35123, 'Kulmain', 'Kulmain', 'Culmain,Kul''majn,Kulmain,Kulmajn,ku er mai yin,Кулмајн,Кульмайн,Քուլմայն,库尔迈因', 49.9000000, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35124, 'Küllstedt', 'Kuellstedt', 'Kilshtet,Kjul''shtedt,Kullstadt,Kullstedt,Küllstedt,qu er si te,Килштет,Кюльштедт,屈尔斯特', 51.2758200, 10.2804000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35125, 'Kükels', 'Kukels', 'Kuekels,Kukels,Kükels', 53.9000000, 10.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35126, 'Kühsen', 'Kuhsen', 'Kuehsen,Kuhsen,Kühsen', 53.6833300, 10.6166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35127, 'Kührstedt', 'Kuehrstedt', '', 53.5774700, 8.8009100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35128, 'Kühren', 'Kuhren', '', 54.1987800, 10.2595600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35129, 'Kuhnhöfen', 'Kuhnhoefen', '', 50.5333300, 7.8630600, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35130, 'Kühndorf', 'Kuehndorf', 'Kindorf,Kjundorf,qu he en duo fu,Киндорф,Кюндорф,屈赫恩多夫', 50.6082600, 10.4919100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35131, 'Kühlenthal', 'Kuhlenthal', '', 48.5666700, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35132, 'Kuhfelde', 'Kuhfelde', 'Kufel''de,Kufelde,Kukhfelde,ku fei er de,Куфелде,Куфельде,Кухфелде,库费尔德', 52.7833300, 11.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35133, 'Kühdorf', 'Kuhdorf', '', 50.7067900, 12.1106200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35134, 'Kühbach', 'Kuhbach', 'Kikhbakh,Kjubakh,Kyubax,kyubahha,qu he ba he,Кихбах,Кюбах,Կյուբախ,キューバッハ,屈赫巴赫', 48.4910100, 11.1869100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35135, 'Kuhardt', 'Kuhardt', '', 49.1458300, 8.3144400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35136, 'Kudensee', 'Kudensee', 'Kudensee', 53.9333300, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35137, 'Kuden', 'Kuden', 'Kuden,ku deng,Куден,库登', 53.9666700, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35138, 'Kuddewörde', 'Kuddeworde', 'Kuddewoerde,Kuddeworde,Kuddewörde', 53.5833300, 10.4000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35139, 'Kuchen', 'Kuchen', '', 48.6358300, 9.7998900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35140, 'Kubschütz', 'Kubschutz', 'Kubschuetz/Kubsicy,Kubschutz,Kubschütz,Kubschütz/Kubšicy,Kubshic,Kubshjuc,Kubsicy,Kubšicy,ku bu xu ci,Кубшиц,Кубшюц,库布许茨', 51.1666700, 14.5000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35141, 'Krüzen', 'Kruzen', 'Kruzen,Krüzen', 53.4000000, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35142, 'Krunkel', 'Krunkel', '', 50.5833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35143, 'Krün', 'Kruen', 'Krin,Krjun,Kruen,Krun,Krunn,Krün,Krünn,krwn,Крин,Крюн,Քրյուն,کرون', 47.5051500, 11.2792400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35144, 'Krumstedt', 'Krumstedt', 'Krumstedt', 54.0666700, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35145, 'Krumpa', 'Krumpa', 'Crumpa,Krumpa', 51.2972400, 11.8441200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35146, 'Krummwisch', 'Krummwisch', 'Krummwisch', 54.3333300, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35147, 'Krummesse', 'Krummesse', 'Krumese,Krummesse,ke lu mei sai,Крумесе,Круммессе,克鲁梅塞', 53.7833300, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35148, 'Krummennaab', 'Krummennaab', 'Krumenab,Krumennaab,Krummennaab,Krummennab,ke lu mei na bu,Круменаб,Крумменнааб,Крумменнаб,Քրումենաբ,克鲁梅纳布', 49.8333300, 12.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35149, 'Krummendiek', 'Krummendiek', '', 53.9466500, 9.4165500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35150, 'Krummendeich', 'Krummendeich', '', 53.8308100, 9.2037900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35151, 'Krummenau', 'Krummenau', 'Krumenau,Krummenau,ke lu mei nao,Круменау,Крумменау,克鲁梅瑙', 49.8833300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35152, 'Krümmel', 'Krummel', 'Kruemmel,Krümmel', 50.5372200, 7.7247200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35153, 'Krummbek', 'Krummbek', '', 54.3833300, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35154, 'Krumbach', 'Krumbach', 'Krumbakh,Krumbax,ke lun ba he,krwmbakh,Крумбах,Կրումբախ,كرومباخ,کرومباخ,克倫巴赫', 48.2418200, 10.3632000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35155, 'Krukow', 'Krukow', '', 53.4166700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35156, 'Kruft', 'Kruft', 'Kruft,ke lu fu te,Круфт,克鲁夫特', 50.3833300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35157, 'Kruchten', 'Kruchten', 'Cruchten,Kruchten', 49.9000000, 6.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35158, 'Kröv', 'Krov', 'Krev,Krjof,Kroev,Kröv,ke lei fu,kurefu,Крев,Крёф,クレフ,克勒夫', 49.9833300, 7.0833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35159, 'Krottelbach', 'Krottelbach', 'Krotelbakh,Krottel''bakh,ke luo te er ba he,Кротелбах,Кроттельбах,克罗特尔巴赫', 49.4666700, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35160, 'Krostitz', 'Krostitz', 'Kroshtic,Krostic,Krostitz,Krostitzi vald,ke luo si di ci,Кростиц,Кроштиц,克罗斯蒂茨', 51.4620800, 12.4536000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35161, 'Kröslin', 'Kroeslin', 'Kreslin,Krjoslin,Kroslin,Kröslin,ke lei si lin,Креслин,Крёслин,克勒斯林', 54.1166200, 13.7506700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35162, 'Kropstädt', 'Kropstaedt', 'Kropstadt,Kropstädt', 51.9630700, 12.7455000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35163, 'Kroppenstedt', 'Kroppenstedt', 'Kropenshtet,Kroppenshtedt,Kroppenstedt,ke luo peng si te,krwbnshtyt,Кропенштет,Кроппенштедт,كروبنشتيت,کرپن‌اشتت,克罗彭斯特', 51.9421100, 11.3084100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35164, 'Kroppen', 'Kroppen', 'Kroeppen,Kropen,Kropnja,Kroppen,Kröppen,ke luo peng,Кропен,Кроппен,Կրոփեն,克罗彭', 51.3833300, 13.8000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35165, 'Kröppen', 'Kroppen', '', 49.1500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35166, 'Kröppelshagen-Fahrendorf', 'Kroeppelshagen-Fahrendorf', 'Kroeppelshagen-Fahrendorf,Kroppelshagen,Kroppelshagen-Fahrendorf,Kroppelshausen,Kröppelshagen,Kröppelshagen-Fahrendorf,Kröppelshausen', 53.4897900, 10.3169700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35167, 'Kroppach', 'Kroppach', 'Kropakh,Kroppakh,ke luo pa,Кропах,Кроппах,克罗帕', 50.6955600, 7.7402800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35168, 'Kropp', 'Kropp', 'Krop,Kropp,ke luo pu,Кроп,克罗普', 54.4166700, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35169, 'Kröpelin', 'Kroepelin', 'Krepelin,Krepeline,Krjopelin,Kroepelin,Kroeplin,Kropelin,Kröpelin,Krēpelīne,ke lei pei lin,krwblyn,krwplyng,Крепелин,Крёпелин,Крөпелин,كروبلين,کروپلینگ,克勒佩林', 54.0696300, 11.7947300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35170, 'Kronweiler', 'Kronweiler', '', 49.6500000, 7.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35171, 'Kronsmoor', 'Kronsmoor', 'Kronsmoor', 53.9076200, 9.5938900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35172, 'Kronshagen', 'Kronshagen', 'Kronshagen,Kronskhagen,ke long sha gen,Кронсхаген,克龙沙根', 54.3333300, 10.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35173, 'Kronsgaard', 'Kronsgaard', 'Kronsgaard', 54.7333300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35174, 'Kronprinzenkoog', 'Kronprinzenkoog', 'Kronprincenkog,Kronprinzenkoog,ke long pu lin cen ke ge,Кронпринценког,克龙普林岑科格', 53.9666700, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35175, 'Kronburg', 'Kronburg', 'Kronburg,ke long bao,Кронбург,Կրոնբուրգ,克龙堡', 47.9043200, 10.1572000, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35176, 'Kronberg', 'Kronberg', 'Cronberg in Taunus,Kronberg im Taunus', 50.1842400, 8.5232000, 'DE', '2016-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35177, 'Kronau', 'Kronau', '', 49.2225000, 8.6311100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35178, 'Kronach', 'Kronach', 'Crana,Kronakh,Kronax,kironac,krwnakh,kuronaha,Кронах,Կրոնախ,كروناخ,کروناخ,கிரோனாச்,クローナハ', 50.2396300, 11.3330800, 'DE', '2013-02-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35179, 'Krombach', 'Krombach', '', 51.3000000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35180, 'Krombach', 'Krombach', '', 50.0831900, 9.2060900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35181, 'Krölpa', 'Krolpa', 'Krelpa,Krjol''pa,Kroelpa,Krölpa,ke lei er pa,Крелпа,Крёльпа,克勒尔帕', 50.6774300, 11.5384800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35182, 'Krokau', 'Krokau', 'Krokau', 54.4000000, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35183, 'Krogaspe', 'Krogaspe', 'Krogaspe', 54.1333300, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35184, 'Kritzmow', 'Kritzmow', '', 54.0523700, 12.0531100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35185, 'Kriftel', 'Kriftel', 'Kriftel,Kriftel'',ke li fu te er,kurifuteru,Крифтел,Крифтель,Кріфтель,クリフテル,克里夫特尔', 50.0840800, 8.4697700, 'DE', '2012-12-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35186, 'Kriegsfeld', 'Kriegsfeld', '', 49.7099200, 7.9168700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35187, 'Kriebstein', 'Kriebstein', 'Kribshtajn,ke li bu si tai yin,Крибштайн,Крибштајн,克里布斯泰因', 51.0500000, 13.0166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35188, 'Kriebitzsch', 'Kriebitzsch', 'Kribich,Kribitch,Kriebitzsch,ke li bi ci xi,Крибитч,Крибич,克里比茨希', 51.0234700, 12.3331800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35189, 'Krickenbach', 'Krickenbach', '', 49.3666700, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35190, 'Kreuzwertheim', 'Kreuzwertheim', 'Kreuzwertheim,Krojcvertajm,Krojcvertgajm,Krojcvertkhajm,ke luo yi ci wei te hai mu,Кройцвертайм,Кройцвертгайм,Кройцвертхайм,Кројцвертхајм,Քրոյցվերթհայմ,克罗伊茨韦特海姆', 49.7681800, 9.5181900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35191, 'Kreuztal', 'Kreuztal', 'Kreuztal,Kreuzthal,Krojctal,Krojctal'',ke luo yi ci ta er,krwytstal,krwyztal,Кройцталь,Кројцтал,كرويتستال,کرویزتال,克罗伊茨塔尔', 50.9677500, 7.9884800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35192, 'Kreuzebra', 'Kreuzebra', 'Kreuzebra,Krojcebra,ke luo yi ce bu la,Кройцебра,Кројцебра,克罗伊策布拉', 51.3500000, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35193, 'Kreuzberg', 'Bezirk Kreuzberg', 'Berlin-Kreuzberg,Kreizberg,Krojcberg,Mons Crucis,ke luo yi ci bei ge,krayetsaberga,qrwyzbrg,Кройцберг,קרויצברג,ক্রয়েৎসবের্গ,克罗伊茨贝格', 52.4997300, 13.4033800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35194, 'Kreuzau', 'Kreuzau', 'Kreuzau,Kreuzau uber Duren,Kreuzau über Düren,Krojcau,ke luo yi cao,Кройцау,Кројцау,克罗伊曹', 50.7469900, 6.4906900, 'DE', '2013-04-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35195, 'Kreuth', 'Kreuth', 'Kreuth,Krojt,ke luo yi te,krwyt,Кройт,Кројт,Քրոյթ,کرویت,კროითი,克罗伊特', 47.6408500, 11.7448500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35196, 'Kreut', 'Kreut', 'Kreuth', 47.7986800, 11.4831200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35197, 'Kretzschau', 'Kretzschau', 'Kretzschau', 51.0500000, 12.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35198, 'Kretz', 'Kretz', '', 50.3957400, 7.3624900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35199, 'Kressbronn am Bodensee', 'Kressbronn am Bodensee', 'Kresbron,Kresbron am Bodenze,Kressbronn,Kressbronn am Bodensee,Kressbronn-am-Bodenze,bo deng hu bin ke lei si bu long,Кресброн,Кресброн ам Бодензе,Крессбронн-ам-Бодензе,Կրեսբրոն,კრესბრონ-ამ-ბოდენზეე,博登湖滨克雷斯布龙', 47.5976000, 9.5970700, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35200, 'Krempermoor', 'Krempermoor', 'Krempermoor', 53.8771000, 9.4808400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35201, 'Kremperheide', 'Kremperheide', 'Kremperheide', 53.8872100, 9.4780900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35202, 'Krempel', 'Krempel', '', 54.3166700, 9.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35203, 'Krempe', 'Krempe', 'Krempe', 53.8369400, 9.4883100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35204, 'Kremmen', 'Kremmen', 'Kremen,Kremmen,ke lei men,krmn,krymn,Кремен,Креммен,Կրեմեն,كريمن,کرمن,کێرمێن,克雷门', 52.7621600, 13.0251500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35205, 'Kreischa', 'Kreischa', 'Krajsha,ke lai sha,Крайша,Крајша,克赖沙', 50.9453400, 13.7551400, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35206, 'Kreiensen', 'Kreiensen', 'Krajenzen,Krajnsen,Kreiensen,Kreinsen,Kreinssen,ke lai en sen,kuraienzen,Крайензен,Крајнсен,クライエンゼン,克赖恩森', 51.8536300, 9.9648100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35207, 'Krefeld', 'Krefeld', 'Crefeld,Gorad Krehfel''d,Krefel''d,Krefeld,Krefeld-Uerdingen,Krefeldas,Krefelde,Krefelnt,Krieevel,Krievel,Krēfelde,Krėfeldas,QKF,ke lei fei er de,keulepelteu,kher fel d,krfld,kryfld,kureferuto,qrpld,Κρέφελντ,Горад Крэфельд,Крефелд,Крефельд,Կրեֆելդ,קרפלד,كريفلد,کرفلد,کریفیلڈ,เครเฟลด์,კრეფელდი,クレフェルト,クレーフェルト,克雷费尔德,크레펠트', 51.3364500, 6.5538100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35208, 'Krebeck', 'Krebeck', 'Krebek,kurebekku,Кребек,クレーベック', 51.5833300, 10.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35209, 'Krautscheid', 'Krautscheid', '', 50.0666700, 6.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35210, 'Krautheim', 'Krautheim', '', 51.0833300, 11.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35211, 'Krautheim', 'Krautheim', 'Krautheim', 49.3878900, 9.6355300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35212, 'Krauthausen', 'Krauthausen', 'Krautauzen,Krauthausen,Krautkhauzen,ke lao tao sen,Краутаузен,Краутхаузен,克劳陶森', 51.0166700, 10.2666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35213, 'Krauschwitz', 'Krauschwitz', 'Kruswica,Krušwica', 51.5215300, 14.7121100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35214, 'Krauchenwies', 'Krauchenwies', 'Kraukhenvis,ke lao heng wei si,Краухенвис,Краухенвіс,克劳亨维斯', 48.0165100, 9.2475700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35215, 'Kratzenburg', 'Kratzenburg', '', 50.1833300, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35216, 'Kranzberg', 'Kranzberg', 'Crantsperg,Krancberg,ke lan ci bei ge,krants brg,Кранцберг,Կրանցբերգ,کرانتس برگ,克兰茨贝格', 48.4061300, 11.6124600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35217, 'Kranichfeld', 'Kranichfeld', 'Kranichfeld,Kranikhfel''d,Kranikhfeld,ke la ni xi fei er de,kranyshfld,Кранихфелд,Кранихфельд,كرانيشفلد,کرانیشفلد,克拉尼希费尔德', 50.8544600, 11.2005700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35218, 'Kranenburg', 'Kranenburg', '', 53.6065100, 9.2060200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35219, 'Kranenburg', 'Kranenburg', 'Cranenburg,Kranenburg', 51.7833300, 6.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35220, 'Kramerhof', 'Kramerhof', '', 54.3536600, 13.0541200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35221, 'Krakow am See', 'Krakow am See', 'Krakov am Ze,Krakov-am-Ze,Krakov-am-Zee,Krakovamze,Krakovamzē,Krakow,Krakow am See,bin hu ke la ke,krakw am zy,krakw am zyh,Краков ам Зе,Краков-ам-Зе,Краков-ам-Зее,كراكو آم زيه,کراکو آم زی,滨湖克拉科', 53.6516300, 12.2703400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35222, 'Kraja', 'Kraja', '', 51.4500000, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35223, 'Krailling', 'Krailling', 'Krailling,Krajling,Krajlling,ke lai ling,kraylyng,Крайллинг,Крайллінг,Крајлинг,کرایلینگ,克赖灵', 48.1000000, 11.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35224, 'Kraiburg am Inn', 'Kraiburg am Inn', 'Craiburg,Ini Krayburg,Kraiberg,Kraiburg,Krajburg,Krajburg am In,Krajburg-am-Inn,Krajburg-na-Inne,Kroaburg am Inn,kraybwrg,yin he pan ke lai bao,Крайбург,Крайбург-ам-Инн,Крайбург-на-Инне,Крајбург ам Ин,Ինի Կրայբուրգ,کرایبورگ,因河畔克赖堡', 48.1819100, 12.4307300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35225, 'Krähenberg', 'Krahenberg', '', 49.3333300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35226, 'Kraftsdorf', 'Kraftsdorf', 'Craffestorp [a. 1256],Kraftsdorf,ke la fu ci duo fu,Крафтсдорф,克拉夫茨多夫', 50.8757400, 11.9294400, 'DE', '2014-12-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35227, 'Kraftisried', 'Kraftisried', 'Kraftisrid,ke la fu di si li de,kurafutisurito,Крафтисрид,Крафтісрід,Քրաֆտիսրիդ,クラフティスリート,克拉夫蒂斯里德', 47.7793000, 10.4708600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35228, 'Kradenbach', 'Kradenbach', '', 50.2500000, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35229, 'Kraam', 'Kraam', '', 50.7000000, 7.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35230, 'Koxhausen', 'Koxhausen', '', 49.9833300, 6.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35231, 'Köwerich', 'Kowerich', '', 49.8333300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35232, 'Kötzting', 'Kotzting', 'Koetzting,Kotzting,Kötzting', 49.1764900, 12.8551500, 'DE', '2015-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35233, 'Kötzschau', 'Koetzschau', 'Kecshau,Kjochau,Kjocshau,Koetzschau,Kotzschau,Kötzschau,Кецшау,Кёцшау,Кёчау', 51.3124400, 12.1304400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35234, 'Kotzenbüll', 'Kotzenbull', 'Kotzenbull,Kotzenbüll', 54.3332900, 8.9045000, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35235, 'Kotzen', 'Kotzen', '', 52.6333300, 12.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35236, 'Kottweiler-Schwanden', 'Kottweiler-Schwanden', '', 49.4833300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35237, 'Kötterichen', 'Kotterichen', '', 50.2400700, 6.9843000, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35238, 'Kottenheim', 'Kottenheim', 'Kotenkhajm,Kottenkhajm,ke teng hai mu,Котенхајм,Коттенхайм,科滕海姆', 50.3500000, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35239, 'Kottenborn', 'Kottenborn', 'Cottenborn,Kottenborn', 50.3500000, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35240, 'Köthen', 'Koethen', 'Cothen,Cothena,Cöthen,K''oten,KOQ,Keten,Kjoten,Koethen,Kothen,Köthen,ke teng,keten,koeten,kwtn,qtn,Кетен,Кьотен,Кётен,קטן,كوتن,کوتن,ケーテン,克滕,쾨텐', 51.7518500, 11.9709300, 'DE', '2017-01-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35241, 'Chostlarn', 'Chostlarn', 'Chostlarn,Kosslarn,Kößlarn', 48.3714400, 13.1206400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35242, 'Kossa', 'Kossa', '', 51.6170700, 12.6819700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35243, 'Kospoda', 'Kospoda', 'Kospoda', 50.7166700, 11.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35244, 'Koserow', 'Koserow', 'Koserow,Koserow/Insel Usedom,Kozerov,ke sai luo,Козеров,科塞罗', 54.0518900, 14.0019700, 'DE', '2017-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35245, 'Kosel', 'Kosel', '', 54.5058000, 9.7565300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35246, 'Korweiler', 'Korweiler', '', 50.1000000, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35247, 'Korschenbroich', 'Korschenbroich', 'Korshenbroikh,Korshenbrojkh,Korsjebrooch,ke er shen bu luo yi xi,krshnbrwysh,kwrshnbrwysh,Коршенброих,Коршенбройх,كورشنبرويش,کرشنبرویش,科尔申布罗伊希', 51.1913900, 6.5135200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35248, 'Körperich', 'Koerperich', 'Kerperikh,Kjorperikh,ke er pei li xi,Керперих,Кёрперих,克尔佩里希', 49.9244900, 6.2597300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35249, 'Kornwestheim', 'Kornwestheim', 'Kornvestgajm,Kornvesthaym,Kornvestkhajm,Kornwestheim,Kornwestheimium,ke er en wei si tai mu,krwnwsthaym,kwrnfsthaym,Корнвестгайм,Корнвестхайм,Корнвестхајм,كورنفستهايم,کرونوستهایم,科尔恩韦斯泰姆', 48.8615800, 9.1856900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35250, 'Korntal', 'Korntal', '', 48.8321800, 9.1214000, 'DE', '2010-11-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35251, 'Körner', 'Korner', 'Koerner,Körner', 51.2333300, 10.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35252, 'Korlingen', 'Korlingen', '', 49.7271400, 6.7247500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35253, 'Körle', 'Korle', 'Kerle,Kjorle,Koerle,Körle,ke er lai,kerure,Керле,Кёрле,ケルレ,克尔莱', 51.1666700, 9.5166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35254, 'Kördorf', 'Kordorf', '', 50.2873700, 7.9211400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35255, 'Kordel', 'Kordel', '', 49.8333300, 6.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35256, 'Körborn', 'Korborn', 'Kerborn,Kjorborn,ke er bo er en,Керборн,Кёрборн,克尔博尔恩', 49.5666700, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35257, 'Korbach', 'Korbach', 'Gorad Korbakh,Koerbach,Korbakh,Körbach,korubahha,kwrbakh,Горад Корбах,Корбах,كورباخ,کورباخ,コルバッハ', 51.2756100, 8.8730000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35258, 'Korb', 'Korb', '', 48.8430300, 9.3625800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35259, 'Kopp', 'Kopp', '', 50.1833300, 6.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35260, 'Köpenick', 'Kopenick Bezirk', 'Berlin-Koepenick,Berlin-Köpenick,Copenicum,Kjopenik,Kopenik,Verwaltungsbezirk Kopenick,Verwaltungsbezirk Köpenick,Копенік,Кёпеник', 52.4455000, 13.5745500, 'DE', '2012-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35261, 'Berlin Köpenick', 'Berlin Koepenick', 'Berlin-Kopenick,Berlin-Köpenick,Koepenick,Köpenick', 52.4425400, 13.5822800, 'DE', '2012-06-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35262, 'Konzell', 'Konzell', 'Koncel,Koncel'',Koncell'',kong ce er,kwntsl,Концел,Концелль,Концель,کونتسل,孔策尔', 49.0724000, 12.7111400, 'DE', '2012-09-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35263, 'Konz', 'Konz', 'Conz,Konc,Konz,koncheu,kong ci,kontsu,ktz,kwnts,Конц,كونتس,کتز,კონცი,コンツ,孔茨,콘츠', 49.7004500, 6.5765200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35264, 'Konstanz', 'Konstanz', 'Constanca,Constance,Constanta,Constantia,Constanza,Constança,Constanța,Costansa,Costanza,Costnitz,Gorad Kanstanc,Konstanc,Konstanca,Konstancas,Konstancja,Konstanco,Konstantia,Konstantza,Konstanz,Kostnica,Kostnice,Kostnitz,QKZ,kang si tan ci,knstants,konseutancheu,konstensa,konsutantsu,kwnstans,qwnstnz,Κωνσταντία,Горад Канстанц,Констанц,קונסטנץ,كونستانس,کنستانتس,کونسٹانس,कॉन्स्टेंस,კონსტანცი,コンスタンツ,康斯坦茨,콘스탄츠', 47.6603300, 9.1758200, 'DE', '2016-11-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35265, 'Konradsreuth', 'Konradsreuth', 'Konradsrojt,knradsrwyt,kong la ci luo yi te,konratsuroito,Конрадсройт,Конрадсројт,کنرادسرویت,コンラーツロイト,孔拉茨罗伊特', 50.2666700, 11.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35266, 'Konradshöhe', 'Konradshohe', '', 52.5853500, 13.2275800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35267, 'Konradsreuth', 'Konradsreuth', 'Konradsreuth', 49.7417900, 12.2962800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35268, 'Könnern', 'Koennern', 'Kenern,Kjonnern,Koennern,Konnern,Könnern,ke nei er en,kwnrn,Кенерн,Кённерн,كونرن,کونرن,克内尔恩', 51.6712000, 11.7706800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35269, 'Konken', 'Konken', 'Konken,kong ken,Конкен,孔肯', 49.5088000, 7.3539300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35270, 'Könitz', 'Koenitz', '', 50.6497900, 11.4880900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35271, 'Königs Wusterhausen', 'Koenigs Wusterhausen', 'Kenigs Vusterkhauzen,Kenigs-Vusterkhauzen,Kenigsvusterhauzene,Kjonigs-Vusterkhauzen,Koenigs Wusterhausen,Konigs Wusterhausen,Königs Wusterhausen,Kēnigsvusterhauzene,Parsk,ke ni xi si wu si te hao sen,kwnyghz fwstrhawzn,kwnygz wwstrhawzn,Кенигс Вустерхаузен,Кенігс-Вустерхаузен,Кёнигс-Вустерхаузен,Քյոնիգս Վուստերհաուզեն,קניגס ווסטרהאוזן,كونيغز فوسترهاوزن,کونیگز ووسترهاوزن,柯尼希斯武斯特豪森', 52.3014100, 13.6330000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35272, 'Königswinter', 'Koenigswinter', 'K''onigsvinter,Kenigsvinter,Kjonigsvinter,Koenigsvinter,Koenigswinter,Konigswinter,Königsvinter,Königswinter,ke ni ge si wen te er,kwnyghsfyntr,kwnygzwyntr,Кенигсвинтер,Кенігсвінтер,Кьонигсвинтер,Кёнигсвинтер,كونيغسفينتر,کونیگزوینتر,克尼格斯温特尔', 50.6837600, 7.1867500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35273, 'Königswartha', 'Konigswartha', 'Kenigsvarta,Kjonigsvarta,Koenigswartha,Koenigswartha vald,Koenigswartha/Rakecy,Konigswartha,Königswartha,Königswartha vald,Königswartha/Rakecy,Rakecy,ke ni ge si wa er ta,Кенигсварта,Кенігсварта,Кёнигсварта,克尼格斯瓦尔塔', 51.3102800, 14.3279700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35274, 'Königswalde', 'Konigswalde', 'Kenigsvalde,Kjonigsval''de,Koenigswalde,Koenigswalde vald,Königswalde,Königswalde vald,ke ni ge si wa er de,Кенигсвалде,Кёнигсвальде,克尼格斯瓦尔德', 50.5500000, 13.0500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35275, 'Königstein im Taunus', 'Koenigstein im Taunus', 'Kenigshtajn na Taunusu,Kenigshtajn-im-Taunus,Kjonigshtajn,Koenigstein im Taunus,Konigstein,Königstein,Königstein im Taunus,kwnyghshtayn am tawnws,tao nu si shan qu ke ni xi shi tai yin,Кенигштајн на Таунусу,Кенігштайн-ім-Таунус,Кёнигштайн,كونيغشتاين إم تاونوس,کونیگ‌اشتاین ایم تاونوس,陶努斯山区柯尼希施泰因', 50.1794300, 8.4713200, 'DE', '2016-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35276, 'Königstein', 'Koenigstein', 'K''onigshhajn,Kenigshtajn,Kenigsteina,Kjonigshtajn,Koenigstein,Koenigstein/Saechsische Schweiz,Kralowc,Königstein/Sächsische Schweiz,Kēnigšteina,kwnyghshtayn,kwnygshtayn,Кенигштајн,Кьонигщайн,Кёнигштайн,كونيغشتاين,کونیگشتاین', 50.9157000, 14.0718600, 'DE', '2016-05-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35277, 'Königstein', 'Koenigstein', 'Kenigshtajn,Kjonigshtajn,Koenigstein (Oberpfalz),Königstein (Oberpfalz),Кенигштајн,Кенігштайн,Кёнигштайн,Քյոնիգշտայն', 49.6085400, 11.6314300, 'DE', '2016-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35278, 'Königsmoor', 'Konigsmoor', 'Kenigsmor,Kjonigsmor,ke ni ge si mo er,Кенигсмор,Кёнигсмор,克尼格斯莫尔', 53.2262800, 9.6796400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35279, 'Königslutter am Elm', 'Koenigslutter am Elm', 'Gorad Kjonigslutehr-na-Ehl''me,Kenigsluter am Elm,Kjonigslutter-am-Ehl''m,Koenigslutter am Elm,Konigslutter,Konigslutter am Elm,Königslutter,Königslutter am Elm,Luttera Regalis,ai er mu shan lu ke ni ge si lu te er,kwnyghslwtr,kwnygzlwtr,Горад Кёнігслутэр-на-Эльме,Кенигслутер ам Елм,Кёнигслуттер-ам-Эльм,كونيغسلوتر,کونیگزلوتر,埃尔姆山麓克尼格斯卢特尔', 52.2511600, 10.8168300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35280, 'Königshügel', 'Konigshugel', 'Konigshugel,Königshügel', 54.3333300, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35281, 'Bad Königshofen im Grabfeld', 'Bad Konigshofen im Grabfeld', 'Bad Kenigskhofen im Grabfeld,Bad Konigshofen,Bad Konigshofen im Grabfeld,Bad Königshofen,Bad Königshofen im Grabfeld,Bad-Kenigsgofen,Bad-Kjonigskhofen-im-Grabfel''d,Konigshofen,Konigshofen im Grabfeld,Königshofen,Königshofen im Grabfeld,ba te ke ni xi si huo fen,bad knygshwfn aym grabfld,bad kwnyghshwfn,bada konigsofana,Бад Кенигсхофен им Грабфелд,Бад-Кенігсгофен,Бад-Кёнигсхофен-им-Грабфельд,Գրաբֆելդի Բադ Քյոնիգսհոֆեն,باد كونيغسهوفن,باد کنیگسهوفن ایم گرابفلد,بیڈ کونگشوفن,बाड कोनिग्शोफ़न,巴特柯尼希斯霍芬', 50.3008200, 10.4688700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35282, 'Königsheim', 'Konigsheim', 'Kenigskhajm,Kjonigskhajm,ke ni xi si hai mu,Кенигсхајм,Кёнигсхайм,柯尼希斯海姆', 48.1000000, 8.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35283, 'Königshain', 'Konigshain', 'Kenigsgajn,Kenigskhajn,Kjonigskhajn,Koenigshaini vald,Kralowski haj,Königshaini vald,ke ni ge si hai en,Кенигсхајн,Кенігсгайн,Кёнигсхайн,克尼格斯海恩', 51.1833300, 14.8666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35284, 'Königsfeld', 'Konigsfeld', '', 51.0666700, 12.7500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35285, 'Königsfeld', 'Koenigsfeld', '', 50.4979200, 7.1771200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35286, 'Königsfeld', 'Konigsfeld', '', 49.9460300, 11.1652000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35287, 'Königsfeld im Schwarzwald', 'Konigsfeld im Schwarzwald', 'Kenigsfel''d-im-Shvarcval''d,Kenigsfeld im Shvarcvald,Kjonigsfel''d,Koenigsfeld,Koenigsfeld im Schwarzwald,Konigsfeld,Königsfeld,Königsfeld im Schwarzwald,hei lin shan qu ke ni ge si fei er de,Кенигсфелд им Шварцвалд,Кенігсфельд-ім-Шварцвальд,Кёнигсфельд,黑林山区克尼格斯费尔德', 48.1381400, 8.4197300, 'DE', '2016-05-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35288, 'Königseggwald', 'Konigseggwald', 'Kenigsegvald,Kenigzeggval''d,Kjonigzegval''d,ke ni xi sai ge wa er de,Кенигсегвалд,Кенігзеггвальд,Кёнигзегвальд,柯尼希塞格瓦尔德', 47.9333300, 9.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35289, 'Königsee', 'Koenigsee', 'Kenigze,Kjonigzee,Koenigsee,Konigsee,Konigssee,Königsee,Königssee,ke ni ge sai,kwnyghzyh,kwnygzy,Кенигзе,Кёнигзее,كونيغزيه,کونیگزی,克尼格塞', 50.6614300, 11.0974800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35290, 'Königsdorf', 'Konigsdorf', 'Koenigsdorf,Königsdorf', 47.8154600, 11.4806300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35291, 'Königsbrunn', 'Konigsbrunn', 'Kenigsbrun,Kenigsbrunn,Kjonigsbrunn,Konigsbrunn,Königsbrunn,ke ni xi si bu lun,kwnyghsbrwn,kwnygzbrwn,Кенигсбрун,Кенігсбрунн,Кёнигсбрунн,Քյոնիգսբրուն,كونيغسبرون,کونیگزبرون,柯尼希斯布伦', 48.2750600, 10.8917800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35292, 'Königsbrück', 'Konigsbruck', 'K''onigsbrjuk,Kenigsbrik,Kenigsbrika,Kinspork,Kjonigsbrjuk,Koenigsbrueck,Konigsbruck,Königsbrück,Kēnigsbrika,ke ni ge si bu lu ke,kwnyghsbrwk,kwnygzbrwk,Кенигсбрик,Кьонигсбрюк,Кёнигсбрюк,كونيغسبروك,کونیگزبروک,克尼格斯布吕克', 51.2645100, 13.9054000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35293, 'Königsbronn', 'Konigsbronn', 'Abbaye de Koenigsbronn,Abbaye de Königsbronn,Abdij Koenigsbronn,Abdij Königsbronn,Kjonigsbron,Kloster Koenigsbronn,Kloster Königsbronn,Koenigsbronn,Koenigsbronn Abbey,Königsbronn,Königsbronn Abbey,ke ni xi si bu long,Кёнигсброн,柯尼希斯布龙', 48.7431700, 10.1119300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35294, 'Königsau', 'Koenigsau', '', 49.8500000, 7.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35295, 'Königheim', 'Konigheim', 'Keniggajm,Kenigkhajm,Kjonigkhajm,Koenigheim,Konigheim,Königheim,ke ni xi hai mu,kenihihaimu,Кенигхајм,Кеніггайм,Кёнигхайм,ケーニヒハイム,柯尼希海姆', 49.6202800, 9.5958300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35296, 'Köngernheim', 'Kongernheim', 'Koengernheim,Köngernheim', 49.8458300, 8.2466700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35297, 'Köngen', 'Kongen', 'Kengen,Kjongen,Koengen,Kongen,Kyongen,Köngen,ken gen,Кенген,Кёнген,Կյոնգեն,肯根', 48.6833300, 9.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35298, 'Kommen', 'Kommen', '', 49.8833300, 7.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35299, 'Kolverath', 'Kolverath', 'Colverath,Kolverath', 50.2666700, 6.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35300, 'Köln', 'Koeln', 'Augusta Ubiorum,CGN,Cologna,Cologne,Colonha,Colonia,Colonia Agrippina,Colonia Agrippinensis,Colonia Claudia Ara Agrippinensium,Colònia,Colônia,Cołogna,Culonia,Cwlen,Gorad Kjol''n,K''oln,Kel''n,Keln,Kelnas,Kelne,Kelni,Keulen,Kiolns,Kjol''n,Koelle,Koeln,Kol''n,Kolin nad Rynem,Kolin nad Rynom,Koln,Koloin,Kolon,Kolonia,Kolonjo,Kolín nad Rýnem,Kolín nad Rýnom,Kyoln,Këlni,Kölle,Köln,Lungsod ng Cologne,Oppidum Ubiorum,gu long,kalana,kalon,ke long,kerun,kholoy,kln,klwn,koelleun,koln,kolon,kwlwn,kwlwnya,kyolna,qln,Ķelne,Κολωνία,Горад Кёльн,Келн,Кельн,Кьолн,Кёльн,Кӧльн,Көлн,Քյոլն,קלן,קעלן,كولونيا,کلن,کلون,کولون,क्योल्न,ਕਲਨ,கோல்ன்,కొలోన్,ಕಲೋನ್,โคโลญ,კელნი,ኮልን,ケルン,古龍,科隆,쾰른', 50.9333300, 6.9500000, 'DE', '2013-12-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35301, 'Kollweiler', 'Kollweiler', 'Koll''vajler,Kolvajler,Колвајлер,Колльвайлер', 49.5166700, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35302, 'Kollow', 'Kollow', 'Kollow', 53.4666700, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35303, 'Kölln-Reisiek', 'Kolln-Reisiek', 'Koelln-Reisiek,Kolln-Reisiek,Kölln-Reisiek', 53.7574800, 9.6977200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35304, 'Kollnburg', 'Kollnburg', 'Kol''nburg,Koll''nburg,Kolnburg,ke er en bao,kln bwrg,Колльнбург,Колнбург,Кольнбург,Քոլնբուրգ,کلن بورگ,科尔恩堡', 49.0466400, 12.8612100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35305, 'Kollmoor', 'Kollmoor', 'Kollmoor', 53.9202300, 9.5941100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35306, 'Kollmar', 'Kollmar', 'Kollmar', 53.7293600, 9.4788000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35307, 'Kollig', 'Kollig', '', 50.2666700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35308, 'Kölleda', 'Koelleda', 'Keleda,Kjolleda,Koelleda,Kolleda,Kölleda,ke lai da,klda,kwlyda,Келеда,Кёлледа,كوليدا,کلدا,克莱达', 51.1874500, 11.2448800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35309, 'Kolkwitz', 'Kolkwitz', 'Golkojce,Gołkojce,Kol''kvic,Kolkvic,Kolkwitz,Kolkwitz/Golkojce,Kolkwitz/Gołkojce,ke er ke wei ci,Колквиц,Кольквиц,Կոլկվից,科尔克维茨', 51.7500000, 14.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35310, 'Kolkerheide', 'Kolkerheide', 'Kolkerheide', 54.6166700, 9.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35311, 'Kolitzheim', 'Kolitzheim', 'Kolicgajm,Kolickhajm,ke li ci hai mu,kwlytshaym,Колицхайм,Колицхајм,Коліцгайм,کولیتسهایم,科利茨海姆', 49.9166700, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35312, 'Koldenbüttel', 'Koldenbuttel', 'Kol''denbjuttel'',Koldenbitel,Koldenbjutel,Koldenbuttel,Koldenbyttel,Koldenbüttel,Kombueddel,Kombüddel,Koolnbuetel,Koolnbütel,ke er deng bi te er,Колденбител,Колденбютел,Кольденбюттель,科尔登比特尔', 54.3833300, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35313, 'Kölbingen', 'Kolbingen', '', 50.5500000, 7.9333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35314, 'Kolbingen', 'Kolbingen', 'Kol''bingen,Kolbingen,ke er bin gen,Колбинген,Кольбинген,科尔宾根', 48.0522700, 8.8895700, 'DE', '2013-05-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35315, 'Kolbermoor', 'Kolbermoor', 'Koiwamoor,Kol''bermor,Kolbermoor,Kolbermor,ke er bei er mo er,klbrmwr,kwlbrmwr,Колбермор,Кольбермор,Կոլբերմոր,كولبرمور,کلبرمور,科尔贝尔莫尔', 47.8496500, 12.0669600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35316, 'Köhn', 'Kohn', 'Koehn,Kohn,Köhn', 54.3500000, 10.4500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35317, 'Köhlen', 'Koehlen', '', 53.5410700, 8.8752400, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35318, 'Kohlberg', 'Kohlberg', 'Kohlberg,Kol''berg,Kolberg,Колберг,Кольберг,Կոհլբերգ', 49.5912100, 12.0194800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35319, 'Kohlberg', 'Kohlberg', '', 48.5584500, 9.3357600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35320, 'Köfering', 'Kofering', 'Kefering,Kjofering,Koefering,Kyofering,Köfering,ke fu ling,kwfryng,Кеферинг,Кеферінг,Кёферинг,Կյոֆերինգ,کوفرینگ,克弗灵', 48.9333300, 12.2000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35321, 'Ködnitz', 'Koednitz', 'Kednic,Kjodnic,Koednitz,Ködnitz,ke de ni ci,kedonittsu,kwdnyts,Кедниц,Кедніц,Кёдниц,Քյոդնից,کودنیتس,ケドニッツ,克德尼茨', 50.1000000, 11.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35322, 'Köditz', 'Koditz', '', 50.3333300, 11.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35323, 'Kodersdorf', 'Kodersdorf', 'Kodersdorf,Kodersdorfi vald,Kodrecy,ke de er si duo fu,Кодерсдорф,科德尔斯多夫', 51.2427200, 14.8933600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35324, 'Ködderitzsch', 'Koedderitzsch', '', 51.0833300, 11.5000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35325, 'Kochel', 'Kochel', '', 47.6592600, 11.3682700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35326, 'Koblenz', 'Koblenz', 'Coblenca,Coblence,Coblentz,Coblenz,Coblenza,Coblença,Confluentes,Gorad Koblenc,Koblenc,Koblencas,Koblenci,Koblencja,Koblenco,Koblentza,Koblenz,Komplents,ZNV,ke bu lun ci,kobeullencheu,koburentsu,kwblns,kwblnts,kwblnz,qwblnz,Κόμπλεντς,Горад Кобленц,Кобленц,קובלנץ,كوبلنس,کوبلنتس,کوبلنز,コブレンツ,科布倫茨,코블렌츠', 50.3535700, 7.5788300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35327, 'Koberg', 'Koberg', 'Koberg', 53.6339300, 10.5235700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35328, 'Knöringen', 'Knoringen', '', 49.2377800, 8.1444400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35329, 'Knopp-Labach', 'Knopp-Labach', '', 49.3333300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35330, 'Knittlingen', 'Knittlingen', 'Knitlingen,Knittlingen,ke ni te lin gen,knytlynghn,knytlyngn,Книтлинген,Кніттлінген,Կնիտլինգեն,كنيتلينغن,کنیتلینگن,克尼特林根', 49.0248700, 8.7560600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35331, 'Knittelsheim', 'Knittelsheim', '', 49.1916700, 8.2513900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35332, 'Knetzgau', 'Knetzgau', 'Knecgau,Knetzgau,ke nei ci gao,Кнецгау,Կնեցգաու,克内茨高', 49.9833300, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35333, 'Kneitlingen', 'Kneitlingen', 'Knajtlingen,ke nai te lin gen,Кнайтлинген,Кнајтлинген,克奈特林根', 52.1747700, 10.7619700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35334, 'Knau', 'Knau', 'Knau,ke nao,Кнау,克瑙', 50.6503300, 11.7196700, 'DE', '2013-12-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35335, 'Klütz', 'Kluetz', 'Klic,Klica,Kljuc,Kluetz,Klutz,Klütz,ke lu ci,klwts,klwtz,Клиц,Клюц,كلوتس,کلوتز,克吕茨', 53.9647000, 11.1636700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35336, 'Klüsserath', 'Kluesserath', 'Kliserat,Kljusserat,Kluesserath,Klusserath,Klüsserath,ke lu sai la te,Клисерат,Клюссерат,克吕塞拉特', 49.8450000, 6.8508600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35337, 'Kluse', 'Kluse', '', 52.9363300, 7.3409300, 'DE', '2011-09-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35338, 'Kludenbach', 'Kludenbach', '', 49.9833300, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35339, 'Klötze', 'Kloetze', 'Klece,Kljotce,Kloetze,Klotze,Klötze,ke lei ce,klwtsh,klwtzh,Клеце,Клётце,كلوتسه,کلوتزه,克勒策', 52.6272500, 11.1642400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35340, 'Klotten', 'Klotten', 'Kloten,Klotten,Клотен,Клоттен', 50.1666700, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35341, 'Kloster Veßra', 'Kloster Vessra', 'Kloster Fesra,Kloster Vesra,Kloster-Fesra,ke luo si te er fei si la,Клостер Весра,Клостер Фесра,Клостер-Фесра,克洛斯特尔费斯拉', 50.5000000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35342, 'Klostermansfeld', 'Klostermansfeld', 'Kloster Mansfield,Klostermansfel''d,Klostermansfeld,ke luo si te er man si fei er de,Клостермансфелд,Клостермансфельд,克洛斯特尔曼斯费尔德', 51.5833300, 11.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35343, 'Klosterlechfeld', 'Klosterlechfeld', '', 48.1558600, 10.8298600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35344, 'Klosterkumbd', 'Klosterkumbd', '', 50.0333300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35345, 'Klixbüll', 'Klixbuell', 'Klaegsbol,Klasbel,Kleksbel,Kliksbil,Kliksbjull'',Klixbuell,Klixbull,Klixbüll,Klægsbøl,ke li ke si bi er,Кликсбил,Кликсбюлль,克利克斯比尔', 54.8033900, 8.8957000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35346, 'Klitten', 'Klitten', 'Kletno,Kliten,Klitten,Klětno,Клитен,Клиттен,Кліттен', 51.3510900, 14.6052600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35347, 'Klipphausen', 'Klipphausen', 'Klipgauzen,Klipkhauzen,Klipphausen,Klipphauseni vald,ke li fu sen,Клипхаузен,Кліпгаузен,克利福森', 51.0684100, 13.5137400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35348, 'Klinkrade', 'Klinkrade', 'Klinkrade', 53.7166700, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35349, 'Klink', 'Klink', '', 53.4775800, 12.6213100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35350, 'Klings', 'Klings', 'Klings,ke ling si,Клингс,克灵斯', 50.6500000, 10.1166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35351, 'Klingenthal', 'Klingenthal', 'Klingental,Klingental'',Klingentale,Klingenthal,Klingentāle,ke lin gen ta er,klynghntal,klyngltal,Клингентал,Клингенталь,كلينغنتال,کلینگلتال,克林根塔尔', 50.3596300, 12.4646300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35352, 'Klingenmünster', 'Klingenmunster', 'Klingenminster,Klingenmjunster,Клингенминстер,Клингенмюнстер', 49.1405600, 8.0186100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35353, 'Klingenberg am Main', 'Klingenberg am Main', 'Klingenberg,Klingenberg am Main,Klingenberg na Majni,Klingenberg-am-Majn,Klingenberg-na-Majne,Mayni Klingenberg,klynghnbrgh am mayn,klyngnbrg am mayn,mei yin he pan ke lin gen bei ge,Клингенберг на Мајни,Клингенберг-на-Майне,Клінгенберг-ам-Майн,Մայնի Կլինգենբերգ,كلينغنبرغ آم ماين,کلینگنبرگ آم ماین,クリンゲンベルク・アム・マイン,美因河畔克林根贝格', 49.7850700, 9.1802500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35354, 'Klingelbach', 'Klingelbach', '', 50.2755100, 7.9696600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35355, 'Klietz', 'Klietz', 'Klietz', 52.6683500, 12.0681200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35356, 'Klieken', 'Klieken', 'Klieken', 51.8880600, 12.3707000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35357, 'Kliding', 'Kliding', '', 50.1166700, 7.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35358, 'Kleve', 'Kleve', '', 54.2951000, 9.1240800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35359, 'Kleve', 'Kleve', '', 53.9666700, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35360, 'Kleve', 'Kleve', 'Cleeve,Cleve,Cleveris,Cleves,Clèves,Cléveris,Kleef,Kleve,keullebe,kurefe,Клеве,クレーフェ,클레베', 51.7882600, 6.1386500, 'DE', '2017-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35361, 'Klettstedt', 'Klettstedt', '', 51.1500000, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35362, 'Klettbach', 'Klettbach', 'Kletbakh,ke lai te ba he,Клетбах,克莱特巴赫', 50.9166700, 11.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35363, 'Kletkamp', 'Kletkamp', 'Kletkamp', 54.2500000, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35364, 'Klempau', 'Klempau', 'Klempau', 53.7666700, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35365, 'Klein Zecher', 'Klein Zecher', 'Klein Zecher', 53.5833300, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35366, 'Klein Wittensee', 'Klein Wittensee', 'Klein Wittensee', 54.3833300, 9.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35367, 'Klein-Winternheim', 'Klein-Winternheim', 'Klajn-Vinternkhajm,xiao wen te er en hai mu,Клайн-Винтернхайм,Клајн-Винтернхајм,小温特尔恩海姆', 49.9383300, 8.2119400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35368, 'Klein Wesenberg', 'Klein Wesenberg', 'Klein Wesenberg', 53.8166700, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35369, 'Kleinwenden', 'Kleinwenden', 'Grosslohra-Kleinwenden,Großlohra-Kleinwenden,Kleinwenden', 51.4161100, 10.6590200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35370, 'Kleinwelsbach', 'Kleinwelsbach', '', 51.1833300, 10.6666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35371, 'Klein Wanzleben', 'Klein Wanzleben', 'Klajn-Vancleben,Klein Wanzleben,Littjen Wanzlae,Littjen Wanzleben,Littjen Wanzlä,Zuckerdorf Klein Wanzleben,Клайн-Ванцлебен', 52.0700500, 11.3659400, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35372, 'Kleinwallstadt', 'Kleinwallstadt', 'Klajnvall''shtadt,Klajnvalshtat,Kleinwallstadt,Kljajnval''shtadt,kurain''vu~arushutatto,xiao wa er si ta te,Клайнвалльштадт,Клајнвалштат,Кляйнвальштадт,Կլայնվալշթաթ,クラインヴァルシュタット,小瓦尔斯塔特', 49.8746400, 9.1692700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35373, 'Kleinsteinhausen', 'Kleinsteinhausen', '', 49.2000000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35374, 'Kleinsendelbach', 'Kleinsendelbach', '', 49.5955800, 11.1577300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35375, 'Klein Schwülper', 'Klein Schwuelper', '', 52.3415300, 10.4290300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35376, 'Kleinschwabhausen', 'Kleinschwabhausen', '', 50.9316000, 11.4611400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35377, 'Klein Rönnau', 'Klein Roennau', 'Klein Roennau,Klein Ronnau,Klein Rönnau', 53.9666700, 10.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35378, 'Klein Rogahn', 'Klein Rogahn', '', 53.6053400, 11.3457900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35379, 'Kleinrinderfeld', 'Kleinrinderfeld', '', 49.7002800, 9.8447200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35380, 'Klein Rheide', 'Klein Rheide', 'Klein Rheide', 54.4500000, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35381, 'Klein Reken', 'Klein Reken', '', 51.7871000, 7.0436700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35382, 'Klein Pampau', 'Klein Pampau', '', 53.5124500, 10.5891000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35383, 'Kleinostheim', 'Kleinostheim', 'Klajnostajm,Klajnostkhajm,Kljajnostgajm,kurain''osutohaimu,xiao ao si te hai mu,Клайностайм,Клайностхайм,Клајностхајм,Кляйностгайм,Կլայնոսթհայմ,クラインオストハイム,小奥斯特海姆', 50.0000000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35384, 'Kleinobringen', 'Kleinobringen', '', 51.0333300, 11.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35385, 'Klein Nordende', 'Klein Nordende', 'Klajn Nordende,Klajn-Nordende,Klein Nordende,xiao nuo deng de,Клайн-Норденде,Клајн Норденде,小诺登德', 53.7221900, 9.6542400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35386, 'Kleinniedesheim', 'Kleinniedesheim', '', 49.5869400, 8.3222200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35387, 'Kleinneuhausen', 'Kleinneuhausen', '', 51.1500000, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35388, 'Kleinmölsen', 'Kleinmolsen', 'Klajnmelsen,Klajnmelzen,Klajnmjol''zen,Kleinmoelsen,Kleinmölsen,xiao mo er sen,Клайнмёльзен,Клајнмелзен,Клајнмелсен,小默尔森', 51.0333300, 11.1166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35389, 'Klein Meckelsen', 'Klein Meckelsen', '', 53.3000000, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35390, 'Kleinmaischeid', 'Kleinmaischeid', '', 50.5134500, 7.6083000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35391, 'Kleinmachnow', 'Kleinmachnow', 'Klajnmakhnov,Klajnmanov,Klaynmaxnov,Kljajnmakhnov,xiao ma he nuo,Клайнмахнов,Клајнманов,Клајнмахнов,Кляйнмахнов,Կլայնմախնով,小马赫诺', 52.4078600, 13.2251400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35392, 'Kleinlangheim', 'Kleinlangheim', 'Klajnlangkhajm,Kleinlangheim,Kljajnlangajm,xiao lang hai mu,Клайнлангхайм,Клајнлангхајм,Кляйнлангайм,Քլայնլանգհայմ,小朗海姆', 49.7708700, 10.2843000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35393, 'Kleinlangenfeld', 'Kleinlangenfeld', '', 50.2666700, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35394, 'Kleinkarlbach', 'Kleinkarlbach', 'Klaekarlbach,Klajnkarlbakh,Kläkarlbach,xiao ka er ba he,Клайнкарлбах,Клајнкарлбах,小卡尔巴赫', 49.5386100, 8.1497200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35395, 'Kleinkahl', 'Kleinkahl', 'Klajnkal,Klajnkal'',Klaynkal,Kljajnkal'',kurainkaru,xiao ka er,Клайнкаль,Клајнкал,Кляйнкаль,Կլայնկալ,クラインカール,小卡尔', 50.1166700, 9.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35396, 'Kleinich', 'Kleinich', 'Klajnikh,ke lai ni xi,Клайних,Клајних,克莱尼希', 49.9000000, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35397, 'Kleinheubach', 'Kleinheubach', 'Klajnkhojbakh,Klaynhoybax,Kleinheubach,Kljajngojbakh,kurainhoibahha,xiao huo yi ba he,Клайнхойбах,Клајнхојбах,Кляйнгойбах,Կլայնհոյբախ,クラインホイバッハ,小霍伊巴赫', 49.7210900, 9.2134600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35398, 'Klein Gusborn', 'Klein Gusborn', '', 53.0833100, 11.1932300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35399, 'Klein Gladebrügge', 'Klein Gladebrugge', 'Klein Gladebrugge,Klein Gladebrügge', 53.9166700, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35400, 'Kleinfurra', 'Kleinfurra', '', 51.4155600, 10.7645400, 'DE', '2012-08-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35401, 'Kleinfischlingen', 'Kleinfischlingen', '', 49.2633300, 8.1869400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35402, 'Kleineutersdorf', 'Kleineutersdorf', 'Kleineutersdorf', 50.7833300, 11.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35403, 'Kleinebersdorf', 'Kleinebersdorf', 'Kleinebersdorf', 50.8166700, 11.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35404, 'Kleinbundenbach', 'Kleinbundenbach', '', 49.3166700, 7.4333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35405, 'Kleinbrembach', 'Kleinbrembach', '', 51.1333300, 11.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35406, 'Kleinbodungen', 'Kleinbodungen', '', 51.4666700, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35407, 'Kleinbockedra', 'Kleinbockedra', 'Kleinbockedra', 50.8500000, 11.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35408, 'Kleinblittersdorf', 'Kleinblittersdorf', 'Klajnblitersdorf,Klajnblittersdorf,Kljajnblittersdorf,xiao bu li te er si duo fu,Клайнблиттерсдорф,Клајнблитерсдорф,Кляйнбліттерсдорф,小布利特尔斯多夫', 49.1578000, 7.0373400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35409, 'Klein Berßen', 'Klein Berssen', 'Klajn Bersen,Klajn-Bersen,xiao bei er sen,Клайн-Берсен,Клајн Берсен,小贝尔森', 52.7679700, 7.4618200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35410, 'Klein Bennebek', 'Klein Bennebek', 'Klein Bennebek', 54.4000000, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35411, 'Kleinbartloff', 'Kleinbartloff', 'Kleinbartloff', 51.3500000, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35412, 'Klein Barkau', 'Klein Barkau', 'Klein Barkau', 54.2333300, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35413, 'Kleinaitingen', 'Kleinaitingen', '', 48.2185000, 10.8692300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35414, 'Klausen', 'Klausen', '', 49.9000000, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35415, 'Klausdorf', 'Klausdorf', '', 54.3089900, 10.2137200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35416, 'Klappholz', 'Klappholz', 'Klappholz', 54.6166700, 9.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35417, 'Klanxbüll', 'Klanxbuell', 'Klangsbel,Klangsbol,Klangsbøl,Klanksbil,Klanksbjull'',ke lan ke si bi er,Кланксбил,Кланксбюлль,克兰克斯比尔', 54.8636900, 8.6770600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35418, 'Klamp', 'Klamp', 'Klamp', 54.3000000, 10.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35419, 'Kladow', 'Kladow', 'Berlin-Kladow,Cladow', 52.4542300, 13.1444500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35420, 'Kitzscher', 'Kitzscher', 'Kicere,Kicher,Kicsher,Kitzscher,Kičere,ji ci xie er,kytsshr,Кицшер,Кичер,كيتسشر,کیتسشر,基茨歇尔', 51.1644400, 12.5526000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35421, 'Kitzingen', 'Kitzingen', 'KZG,Kicingen,Kitcingen,Kitzinga,Kitzingen,ji qin gen,kytsynghn,kytsyngn,Китцинген,Кицинген,Кітцінґен,Քիթցինգեն,كيتسينغن,کیتسینگن,基钦根', 49.7397300, 10.1507200, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35422, 'Kitzen', 'Kitzen', 'Kitzen', 51.2217200, 12.2234900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35423, 'Kittlitz', 'Kittlitz', '', 53.6640700, 10.9169800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35424, 'Kist', 'Kist', '', 49.7427800, 9.8438900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35425, 'Kißlegg', 'Kisslegg', 'Kisleg,Kislegg,Kisslegg,ji si lai ge,Кислег,Кіслегг,基斯莱格', 47.7889400, 9.8838300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35426, 'Kissing', 'Kissing', '', 48.3037500, 10.9708800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35427, 'Kissenbrück', 'Kissenbruck', 'Kisenbrik,Kissenbrjuk,Kissenbruck,Kissenbrueck,Kissenbruga,Kissenbrück,Kissinbruck,Kissinbrück,ji sen bu lu ke,Кисенбрик,Киссенбрюк,基森布吕克', 52.1095600, 10.5899600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35428, 'Kisselbach', 'Kisselbach', '', 50.0500000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35429, 'Kisdorf', 'Kisdorf', 'Kisdorf,Kizdorf,ji si duo fu,Киздорф,Кисдорф,基斯多夫', 53.8166700, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35430, 'Kirtorf', 'Kirtorf', 'Kirthoff,Kirtorf,ji er tuo fu,kirutorufu,kyrtwrf,Кирторф,Кірторф,كيرتورف,کیرتورف,キルトルフ,基尔托夫', 50.7694200, 9.1038900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35431, 'Kirschweiler', 'Kirschweiler', '', 49.7500000, 7.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35432, 'Kirschroth', 'Kirschroth', 'Kirshrot,ji er shi luo te,Киршрот,基尔施罗特', 49.7666700, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35433, 'Kirschkau', 'Kirschkau', 'Kirschkau', 50.6048700, 11.8870800, 'DE', '2014-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35434, 'Kirschau', 'Kirschau', 'Kirshau,Korzym,Киршау,Кіршау', 51.0931700, 14.4284000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35435, 'Kirsbach', 'Kirsbach', '', 50.3333300, 7.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35436, 'Kirrweiler', 'Kirrweiler', 'Kirvajler,Kirvajler Lauterekken,Кирвайлер Лаутереккен,Кирвајлер', 49.6333300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35437, 'Kirrweiler', 'Kirrweiler', 'Kirrweiler,Kirvajler,ji er wei lei,Кирвайлер,Кирвајлер,基尔韦勒', 49.3012400, 8.1628800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35438, 'Kirn', 'Kirn', 'Kiere,Kirn,ji er en,Кирн,基尔恩', 49.7891200, 7.4576500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35439, 'Kirkel', 'Kirkel', 'Kirkel,Kirkel'',ji er ke er,kyrkl,Киркел,Киркель,Кіркель,کیرکل,基尔克尔', 49.2833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35440, 'Kirf', 'Kirf', 'Kirf,ji er fu,Кирф,基尔夫', 49.5500000, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35441, 'Kirchzell', 'Kirchzell', 'Kirchzell,Kirkhcel,Kirkhcel'',Kirkhcell'',ji er xi ce er,kiruhitsu~eru,Кирхцел,Кирхцелль,Кірхцель,Կիրխցել,キルヒツェル,基尔希策尔', 49.6180000, 9.1778500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35442, 'Kirchzarten', 'Kirchzarten', 'Kirchzarten,Kirkhcarten,ji er xi cha er teng,Кирхцартен,Кірхцартен,Կիրխցարտեն,基尔希察尔滕', 47.9666700, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35443, 'Kirchworbis', 'Kirchworbis', 'Kirchworbis', 51.4112200, 10.3962500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35444, 'Kirchweiler', 'Kirchweiler', '', 50.2301900, 6.7452600, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35445, 'Kirchweidach', 'Kirchweidach', 'Kirkhvajdakh,Kirxvaydax,ji er xi wei da,kyrsh waydakh,Кирхвайдах,Кирхвајдах,Кірхвайдах,Կիրխվայդախ,کیرش وایداخ,基尔希魏达', 48.0857500, 12.6453000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35446, 'Kirchwalsede', 'Kirchwalsede', 'Karkwals,Kirkhval''zede,Kirkhvalzede,ji er xi wa er sai de,kiruhivu~aruzede,Кирхвалзеде,Кирхвальзеде,キルヒヴァルゼーデ,基尔希瓦尔塞德', 53.0166700, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35447, 'Kirchtimke', 'Kirchtimke', '', 53.2500000, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35448, 'Kirchseeon', 'Kirchseeon', 'Kirkhzeon,Kirkseon,ji er xi sai weng,kyrshzywn,Кирксеон,Кирхзеон,Кірхзеон,کیرشزیون,基尔希塞翁', 48.0714300, 11.8887500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35449, 'Kirchseelte', 'Kirchseelte', '', 52.9500000, 8.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35450, 'Kirchroth', 'Kirchroth', 'Kirkhrot,Kirrot,ji er xi luo te,kyrshrwt,Киррот,Кирхрот,Кірхрот,کیرشروت,基尔希罗特', 48.9500000, 12.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35451, 'Kirchnüchel', 'Kirchnuchel', 'Kirchnuchel,Kirchnüchel', 54.2000000, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35452, 'Kirchlinteln', 'Kirchlinteln', 'Karklinteln,Kirchlinteln,Kirkhlintel''n,Kirlinteln,ji er xi lin te er en,kiruhirinterun,Кирлинтелн,Кирхлинтельн,キルヒリンテルン,基尔希林特尔恩', 52.9423600, 9.3181100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35453, 'Kirchlengern', 'Kirchlengern', 'Kirkhlengern,Kirlengern,ji xi lun ge en,kiruhirengerun,Кирленгерн,Кирхленгерн,Кірхленгерн,キルヒレンゲルン,基希伦格恩', 52.2000000, 8.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35454, 'Kirchlauter', 'Kirchlauter', 'Kirkhlauter,Kirlauter,ji er xi lao te er,Кирлаутер,Кирхлаутер,Кірхлаутер,Կիրխլաութեր,基尔希劳特尔', 50.0443000, 10.7177600, 'DE', '2012-12-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35455, 'Kirchhundem', 'Kirchhundem', 'Kirchhundem,Kirchhunden,Kirkhgundem,Kirkhkhundem,Kirkhundem,ji er xun de mu,Кирхундем,Кирххундем,Кірхгундем,基尔逊德姆', 51.0855600, 8.0889300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35456, 'Kirchheim unter Teck', 'Kirchheim unter Teck', 'Kirchheim,Kirkhajm pod Tekom,Kirkhgajm-unter-Tek,Kirkhkhajm-unter-Tekk,Kirxhaym unter Tek,kyrshhaym awntr tk,tai ke shan xia ji er xia yi mu,Кирхајм под Теком,Кирхгайм-унтер-Тек,Кирххайм-унтер-Текк,Кірхгайм-унтер-Тек,Կիրխհայմ ունտեր Տեկ,كيرشهايم اونتر تك,کیرشهایم اونتر تک,泰克山下基尔夏伊姆', 48.6468300, 9.4537800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35457, 'Kirchheimbolanden', 'Kirchheimbolanden', 'Kircheimbolanden,Kirchheimbolanden,Kirkhgajmbolanden,Kirkhkhajmbolanden,ji er xia yin bo lan deng,kiruhihaimuboranden,kyrshhaymbwlandn,Кирхгаймболанден,Кирххаймболанден,Кирххајмболанден,كيرشهايمبولاندن,کیرشهایمبولاندن,キルヒハイムボーランデン,基尔夏因博兰登', 49.6624900, 8.0151300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35458, 'Kirchheim bei München', 'Kirchheim bei Muenchen', 'Kirchheim,Kirkhgajm-Mjunkhen,Kirkhgajm-baj-Mjunkhen,Kirkhkhajm baj Minkhen,Kirkhkhajm-Mjunkhen,Kirxhaym Myunxen,kyrshhaym bay mwnshn,mu ni hei fu jin ji xi hai mu,Кирхгайм-Мюнхен,Кирххайм-Мюнхен,Кирххајм бај Минхен,Кірхгайм-бай-Мюнхен,Կիրխհայմ Մյունխեն,کیرشهایم بای مونشن,慕尼黑附近基希海姆', 48.1765600, 11.7556300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35459, 'Kirchheim an der Weinstraße', 'Kirchheim an der Weinstrasse', 'Kaerschm,Kirchheim,Kirchheim an der Eck,Kirchheim an der Weinstrasse,Kirchheim an der Weinstraße,Kirkhajm na Vinskom Putu,Kirkhgajm,Kirkhkhajm,Kärschm,wei yin si te la sai pang ji er xia yi mu,Кирхајм на Винском Путу,Кирхгайм,Кирххайм,韦因斯特拉塞旁基尔夏伊姆', 49.5372200, 8.1808300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35460, 'Kirchheim am Ries', 'Kirchheim am Ries', 'Kirchheim,Kirkhgajm-am-Ris,Kirkhkhajm am Ris,Kirkhkhajm-na-Rise,li si de qu ji er xia yi mu,Кирххайм-на-Рисе,Кирххајм ам Рис,Кірхгайм-ам-Ріс,კირხჰაიმ-ამ-რისი,里斯地区基尔夏伊姆', 48.8792200, 10.4002800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35461, 'Kirchheim am Neckar', 'Kirchheim am Neckar', 'Kirchheim,Kirchheim am Neckar,Kirkhgajm-am-Nekkar,Kirkhkhajm am Nekar,Kirkhkhajm-am-Nekkar,kyrshhaym am nkar,nei ka he pan ji er xia yi mu,Кирххайм-ам-Неккар,Кирххајм ам Некар,Кірхгайм-ам-Неккар,کیرشهایم آم نکار,内卡河畔基尔夏伊姆', 49.0450000, 9.1422200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35462, 'Kirchheim', 'Kirchheim', '', 50.8833300, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35463, 'Kirchheim', 'Kirchheim', 'Kirchheim', 50.8333300, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35464, 'Kirchheim', 'Kirchheim', '', 49.6560700, 9.8578300, 'DE', '2012-10-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35465, 'Kirchheim', 'Kirchheim', '', 48.1749000, 10.4746100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35466, 'Kirchheilingen', 'Kirchheilingen', 'Kirchheilingen,Kirchhelingen', 51.1820600, 10.7087800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35467, 'Kirchhaslach', 'Kirchhaslach', 'Kirkhaslakh,Kirkhgaslakh,Kirkhkhaslakh,Kirxhaslax,ji er xia si la,Кирхаслах,Кирхгаслах,Кирххаслах,Кірхгаслах,Կիրխհասլախ,基尔夏斯拉', 48.1504000, 10.3101500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35468, 'Kirchham', 'Kirchham', '', 48.3463800, 13.2671900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35469, 'Kirchhain', 'Kirchhain', 'Kirchhain,Kirkhajn,Kirkhgajn,Kirkhkhajn,ji er xia yin,kiruhihain,kyrshhayn,Кирхајн,Кирхгайн,Кирххайн,Кірхгайн,كيرشهاين,کیرشهاین,キルヒハイン,基尔夏因', 50.8272000, 8.9280600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35470, 'Kirchgellersen', 'Kirchgellersen', '', 53.2333300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35471, 'Kirchgandern', 'Kirchgandern', 'Kirchgandern', 51.3843900, 9.9619200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35472, 'Kirchenthumbach', 'Kirchenthumbach', 'Kirchenthumbach,Kirkhentumbakh,Kirxentumbax,Tumbach,ji xing tong ba he,Кирхентумбах,Кірхентумбах,Կիրխենտումբախ,基兴通巴赫', 49.7486600, 11.7254200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35473, 'Kirchentellinsfurt', 'Kirchentellinsfurt', 'Kirkhentelinsfurt,Kirkhentellinsfurt,ji er xing te lin si fu er te,Кирхентелинсфурт,Кирхентеллинсфурт,Кірхентеллінсфурт,基尔兴特林斯富尔特', 48.5331500, 9.1473200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35474, 'Kirchensittenbach', 'Kirchensittenbach', 'Kirkhensitenbakh,Kirkhenzittenbakh,ji xing xi teng ba he,Кирхензиттенбах,Кирхенситенбах,Кірхензіттенбах,Կիրխենզիթենբախ,基兴西滕巴赫', 49.5560100, 11.4222600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35475, 'Kirchenpingarten', 'Kirchenpingarten', '', 49.9333300, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35476, 'Kirchenlamitz', 'Kirchenlamitz', 'Kirchenlamitz,Kirkhenlamic,ji xing la mi ci,kiruhyenramittsu,kyrshnlamyts,kyrshnlamytz,Кирхенламиц,Кірхенламіц,Կիրխենլամից,كيرشنلاميتس,کیرشنلامیتز,キルヒェンラミッツ,基兴拉米茨', 50.1519000, 11.9483100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35477, 'Kirchendemenreuth', 'Kirchendemenreuth', '', 49.7833300, 12.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35478, 'Kirchen', 'Kirchen', 'Chiricheim,Kirchen,Kirchen an der Sieg,Kirkhen,ji xing,kiruhyen,kyrshn,Кирхен,كيرشن,کیرشن,キルヒェン,基兴', 50.8084900, 7.8863400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35479, 'Eiselfing', 'Eiselfing', 'Kircheiselfing', 48.0411400, 12.2427200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35480, 'Kircheib', 'Kircheib', 'Kirkhajb,ji er xia yi bu,kyrshayb,Кирхайб,Кирхајб,کیرشایب,基尔夏伊布', 50.7092100, 7.4596700, 'DE', '2011-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35481, 'Kirchehrenbach', 'Kirchehrenbach', 'Kirkherenbakh,ji er xie lun ba he,kiruhierenbahha,Кирхеренбах,Кірхеренбах,Քիրխեհրենբախ,キルヒエーレンバッハ,基尔歇伦巴赫', 49.7333300, 11.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35482, 'Kirchdorf im Wald', 'Kirchdorf im Wald', 'Kirchdorf,Kirchdorf im Wald,Kirkhdorf im Vald,Kirkhdorf-im-Val''d,Valdi Kirxdorf,kyrsh dwrf aym wald,Кирхдорф им Валд,Кирхдорф-им-Вальд,Кірхдорф-ім-Вальд,Վալդի Կիրխդորֆ,کیرش دورف ایم والد', 48.9104800, 13.2661400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35483, 'Kirchdorf am Inn', 'Kirchdorf am Inn', 'Kirchdorf,Kirchdorf am Inn', 48.2475500, 12.9845300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35484, 'Kirchdorf', 'Kirchdorf', 'Kierchdorf', 52.5952300, 8.8349000, 'DE', '2017-04-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35485, 'Kirchdorf', 'Kirchdorf', '', 48.7710100, 11.9036800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35486, 'Kirchdorf', 'Kirchdorf', '', 48.4594200, 11.6543800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35487, 'Kirchdorf', 'Kirchdorf', '', 48.1754200, 12.1964600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35488, 'Kirchdorf', 'Kirchdorf', '', 48.0766700, 10.1262900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35489, 'Kirchbrak', 'Kirchbrak', 'Kirkhbrak,ji er xi bu la ke,kiruhiburaku,Кирхбрак,キルヒブラーク,基尔希布拉克', 51.9658500, 9.5751000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35490, 'Kirchberg an der Murr', 'Kirchberg an der Murr', 'Kirchberg,Kirkhberg an der Muri,Kirkhberg-an-der-Mur,Kirkhberg-na-Mure,mu er he pan ji er xi bei ge,Кирхберг ан дер Мури,Кирхберг-на-Муре,Кірхберг-ан-дер-Мур,穆尔河畔基尔希贝格', 48.9429700, 9.3408300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35491, 'Kirchberg an der Jagst', 'Kirchberg an der Jagst', 'Kirchberg,Kirchberg an der Jagst,Kirkhberg an der Jagst,Kirkhberg-an-der-Jagst,Kirkhberg-na-Jagste,kyrshbrg an dr yagst,kyrshbrgh an dr yaghst,ya ge si te he pan ji xi bei ge,Кирхберг ан дер Јагст,Кирхберг-на-Ягсте,Кірхберг-ан-дер-Ягст,كيرشبرغ أن در ياغست,کیرشبرگ ان در یاگست,キルヒベルク・アン・デア・ヤクスト,亚格斯特河畔基希贝格', 49.2005600, 9.9822600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35492, 'Kirchberg an der Iller', 'Kirchberg an der Iller', 'Ileri Kirxberg,Kirchberg,Kirchberg an der Iller,Kirkhberg na Ileru,Kirkhberg-an-der-Iller,Kirkhberg-na-Illere,yi lai er he pan ji er xi bei ge,Кирхберг на Илеру,Кирхберг-на-Иллере,Кірхберг-ан-дер-Іллер,Իլերի Կիրխբերգ,კირხბერგ-ან-დერ-ილერი,伊莱尔河畔基尔希贝格', 48.1333300, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35493, 'Kirchberg', 'Kirchberg', 'Erlbach-Kirchberg,Kirchberg', 50.7614100, 12.7648100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35494, 'Kirchberg', 'Kirchberg', 'Kirchberg', 50.6219000, 12.5244900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35495, 'Kirchberg', 'Kirchberg', 'Kirchberg,Kirchberg (Hunsrueck),Kirchberg (Hunsrück),Kirkhberg,ji xi bei ge,kiruhiberuku,kyrshbrg,kyrshbrgh,Кирхберг,كيرشبرغ,کیرشبرگ,キルヒベルク,基希贝格', 49.9439500, 7.4070000, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35496, 'Kirchberg', 'Kirchberg', 'Kirchberg,Kirchberg im Wald', 48.9000600, 13.1820000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35497, 'Kirchberg', 'Kirchberg', '', 48.4000000, 12.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35498, 'Kirchbarkau', 'Kirchbarkau', 'Kirchbarkau', 54.2109100, 10.1442200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35499, 'Kirchardt', 'Kirchardt', 'Kirchardt,Kirkhardt,ji er xia er te,kiruhyaruto,Кирхардт,Кірхардт,キルヒャルト,基尔夏尔特', 49.2050000, 8.9916700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35500, 'Kirchanschöring', 'Kirchanschoring', 'Anscharing,Kirkhanshering,Kirkhanshjoring,ji xian she ling,kyrshanshwryng,Кирханшеринг,Кирханшёринг,Кірханшерінг,Քիրխանշյորինգ,کیرشانشورینگ,基先舍灵', 47.9530300, 12.8343500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35501, 'Kirburg', 'Kirburg', '', 50.6833300, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35502, 'Kippenheim', 'Kippenheim', 'Kipenkhajm,Kippengajm,Kippenkhajm,ji peng hai mu,qypnhyym,Кипенхајм,Киппенхайм,Кіппенгайм,קיפנהיים,基彭海姆', 48.2956400, 7.8251000, 'DE', '2011-09-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35503, 'Kinzenburg', 'Kinzenburg', '', 50.1166700, 6.3500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35504, 'Kinsau', 'Kinsau', '', 47.8833300, 10.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35505, 'Kinheim', 'Kinheim', '', 49.9666700, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35506, 'Kindsbach', 'Kindsbach', '', 49.4166700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35507, 'Kinderbeuern', 'Kinderbeuern', '', 50.0093500, 7.0235500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35508, 'Kindenheim', 'Kindenheim', '', 49.6111100, 8.1641700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35509, 'Kindelbrück', 'Kindelbrueck', 'Kindel''brjuk,Kindelbrik,Kindelbruck,Kindelbrück,jin de er bu lu ke,kyndlbrwk,Кинделбрик,Киндельбрюк,كيندلبروك,کیندلبروک,金德尔布吕克', 51.2617100, 11.0899900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35510, 'Kiliansroda', 'Kiliansroda', '', 50.9146700, 11.3716200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35511, 'Kieselbronn', 'Kieselbronn', 'Kiselbron,Kizel''bron,Kizel''bronn,Kizelbron,ji sai er bu long,Кизельброн,Киселброн,Кізельбронн,Կիզելբրոն,基塞尔布龙', 48.9333300, 8.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35512, 'Kierspe', 'Kierspe', 'Kierspe,Kirspe,ji er si pei,kyrashpy,kyrshbt,Кирспе,Кірспе,كيرشبة,کیراشپی,基尔斯佩', 51.1340300, 7.5907500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35513, 'Kienberg', 'Kienberg', '', 48.0348100, 12.4633000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35514, 'Kiel', 'Kiel', 'Gorad Kil'',KEL,Kiel,Kielia,Kielo,Kil,Kil'',Kile,Kilo,Kilonia,Kyle,Kylis,Kíl,ji er,khil,kil,kila,kiru,kyl,qyl,Ķīle,Κίελο,Горад Кіль,Кил,Киль,Кіль,Քիլ,קיל,كيل,کیل,कील,কিল,คีล,კილი,キール,基尔,킬', 54.3213300, 10.1348900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35515, 'Kiefersfelden', 'Kiefersfelden', 'Kifersfel''den,Kifersfelden,ji fei er si fei er deng,kyfrsfldn,Киферсфелден,Киферсфельден,Кіферсфельден,Կիֆերսֆելդեն,کیفرسفلدن,基费尔斯费尔登', 47.6140900, 12.1909600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35516, 'Kiedrich', 'Kiedrich', 'Kidrikh,Kiedrich,ji de li xi,Кидрих,Кідріх,基德里希', 50.0396500, 8.0853100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35517, 'Kiebitzreihe', 'Kiebitzreihe', 'Kiebitzreihe', 53.7833300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35518, 'Kickeshausen', 'Kickeshausen', '', 50.0666700, 6.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35519, 'Kevelaer', 'Kevelaer', 'Gorad Kevelar,Kefeler,Kevelaer,Kevelar,Kevern,ke fei la ai er,kwlayr,kyfhlyr,Горад Кевелар,Кевелаер,Кевелар,Кефелер,كيفهلير,کولائر,克费拉埃尔', 51.5824300, 6.2460300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35520, 'Ketzin', 'Ketzin', 'Kecin,Ketzin,Ketzin/Havel,ktsyn/hawl,kytsyn,Кецин,Կեցին,كيتسين,کتسین/هاول', 52.4780900, 12.8453000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35521, 'Kettig', 'Kettig', '', 50.4000000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35522, 'Kettershausen', 'Kettershausen', 'Keterskhauzen,Kettersgauzen,Ketterskhauzen,ke te er si hao sen,Кетерсхаузен,Кеттерсгаузен,Кеттерсхаузен,Քեթերսհաուզեն,克特尔斯豪森', 48.1833300, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35523, 'Kettenkamp', 'Kettenkamp', 'Ketenkamp,Kettenkamp,ke teng kan pu,Кетенкамп,Кеттенкамп,克滕坎普', 52.5833300, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35524, 'Kettenheim', 'Kettenheim', '', 49.7216700, 8.1133300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35525, 'Kettenhausen', 'Kettenhausen', '', 50.7166700, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35526, 'Ketsch', 'Ketsch', 'Kech,Ketsch,ke ci xi,ketchu,Кеч,ケッチュ,克茨希', 49.3677800, 8.5311100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35527, 'Kestert', 'Kestert', '', 50.1833300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35528, 'Kesten', 'Kesten', '', 49.9000000, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35529, 'Kessin', 'Kessin', '', 53.7292800, 13.3077300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35530, 'Kesseling', 'Kesseling', 'Keseling,Kesseling,kai se ling,Кеселинг,Кесселинг,凯瑟灵', 50.4833300, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35531, 'Kesfeld', 'Kesfeld', '', 50.1500000, 6.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35532, 'Kescheid', 'Kescheid', '', 50.6666700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35533, 'Kerzenheim', 'Kerzenheim', 'Kercenkhajm,ke er cen hai mu,Керценхайм,Керценхајм,克尔岑海姆', 49.5763900, 8.0597200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35534, 'Kerschenbach', 'Kerschenbach', '', 50.3500000, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35535, 'Kerpen', 'Kerpen', 'Kerpe,Kerpen,ke er peng,Керпен,克尔彭', 50.8699100, 6.6969100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35536, 'Kerben', 'Kerben', '', 50.3166700, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35537, 'Keppeshausen', 'Keppeshausen', '', 49.9666700, 6.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35538, 'Kenzingen', 'Kenzingen', 'Kencingen,Kenzingen,ken qin gen,kntsynghn,kntsyngn,Кенцинген,Քենցինգեն,كنتسينغن,کنتسینگن,肯钦根', 48.1963000, 7.7697400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35539, 'Kenn', 'Kenn', '', 49.8000000, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35540, 'Kempten (Allgäu)', 'Kempten (Allgaeu)', 'Kempten', 47.7267400, 10.3138900, 'DE', '2016-09-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35541, 'Kempfeld', 'Kempfeld', 'Kempfel''d,Kempfeld,ken pu fei er de,Кемпфелд,Кемпфельд,肯普费尔德', 49.7899100, 7.2463400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35542, 'Kempenich', 'Kempenich', 'Kempenikh,ken pei ni xi,Кемпених,肯佩尼希', 50.4202400, 7.1169800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35543, 'Kempen', 'Kempen', 'Kempen,ken peng,kmpn  alman,Кемпен,کمپن، آلمان,肯彭', 51.3643200, 6.4185800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35544, 'Kemnitz', 'Kemnitz', '', 54.0772300, 13.5352800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35545, 'Kemnath', 'Kemnath', 'Kemmath Stadt,Kemnat,Kemnath,ke mu na te,kmnath,Кемнат,کمناث,克姆纳特', 49.8700700, 11.8907700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35546, 'Kemmern', 'Kemmern', 'Kemern,Kemmern,kai mo en,kenmerun,Кемерн,Кеммерн,Կեմերն,ケンメルン,凯默恩', 49.9548600, 10.8778400, 'DE', '2011-06-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35547, 'Kemmenau', 'Kemmenau', '', 50.3500000, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35548, 'Kemberg', 'Kemberg', 'Kemberg,ken bei ge,kmbrg,kmbrgh,Кемберг,كمبرغ,کمبرگ,肯贝格', 51.7718900, 12.6322700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35549, 'Kelsterbach', 'Kelsterbach', 'Kel''sterbakh,Kelsterbach,Kelsterbakh,QLH,ke er si te er ba he,kerusutabahha,klshtrbakh,Келстербах,Кельстербах,كلشترباخ,کلشترباخ,ケルスターバッハ,克尔斯特尔巴赫', 50.0613500, 8.5291600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35550, 'Kellmünz', 'Kellmunz', '', 48.1215900, 10.1281100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35551, 'Kellinghusen', 'Kellinghusen', 'Kelingkhuzen,Kellinghusen,Kellingkhuzen,kai ling hu sen,klynghwzn,kylynghhwzn,Келингхузен,Келлингхузен,كيلينغهوزن,کلینگهوزن,凯灵胡森', 53.9520200, 9.7195900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35552, 'Kellenhusen', 'Kellenhusen', 'Kellenhusen', 54.1933800, 11.0616500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35553, 'Kellenbach', 'Kellenbach', 'Kelenbakh,Kellenbakh,ke lun ba he,Келенбах,Келленбах,克伦巴赫', 49.8500000, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35554, 'Kella', 'Kella', 'Kella', 51.2333300, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35555, 'Kell', 'Kell', '', 49.6342500, 6.8239000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35556, 'Kelkheim (Taunus)', 'Kelkheim (Taunus)', 'Kelkheim,Kelkheim (Taunus),Stadt Kelkheim (Taunus)', 50.1370300, 8.4502000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35557, 'Kelheim', 'Kelheim', 'Kel''gajm,Kel''khajm,Kelhaym,Kelheim,Kelkhajm,ke er hai mu,klhaym,Келхайм,Келхајм,Кельгайм,Кельхайм,Կելհայմ,كلهايم,کلهایم,ኬልሃይም,克尔海姆', 48.9172500, 11.8861800, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35558, 'Kelbra', 'Kelbra', 'Kel''bra,Kelbra,ke er bu la,klbra,Келбра,Кельбра,كلبرا,کلبرا,克尔布拉', 51.4352800, 11.0414300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35559, 'Kelberg', 'Kelberg', 'Kehlberg,Kel''berg,Kelberg,ke er bei ge,keruberuku,Келберг,Кельберг,ケルベルク,克尔贝格', 50.2916400, 6.9195000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35560, 'Keitum', 'Keitum', 'Kairem,Kejtum', 54.8933300, 8.3708300, 'DE', '2014-09-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35561, 'Keila', 'Keila', '', 50.6373800, 11.6618200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35562, 'Keidelheim', 'Keidelheim', '', 49.9833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35563, 'Kehrig', 'Kehrig', '', 50.2833300, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35564, 'Kehmstedt', 'Kehmstedt', '', 51.4666700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35565, 'Kehlbach', 'Kehlbach', '', 50.2592200, 7.7588400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35566, 'Kehl', 'Kehl', 'Kehl,Kehl am Rhein,Kehl im Hanauerland,Kel,Kel'',Kiel,Stadt Kehl,kai er,keru,kl  badn-wwrtmyrg,kyhl,Кел,Кель,كيهل,کل، بادن-وورتمیرگ,ケール,凱爾', 48.5729700, 7.8152300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35567, 'Kefferhausen', 'Kefferhausen', 'Keferkhauzen,Kefferhausen,Kefferkhauzen,ke fei lao sen,Кеферхаузен,Кефферхаузен,克费劳森', 51.3166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35568, 'Kefenrod', 'Kefenrod', 'Kefenrod,ke fen luo de,kefenroto,Кефенрод,ケーフェンロート,克芬罗德', 50.3447500, 9.2114100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35569, 'Kayna', 'Kayna', 'Kayna', 50.9941400, 12.2371000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35570, 'Kayhude', 'Kayhude', 'Kayhude', 53.7562900, 10.1323200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35571, 'Kavelstorf', 'Kavelstorf', 'Kavelsdorf,Kavelstorf', 54.0059600, 12.1908200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35572, 'Kausen', 'Kausen', '', 50.7414600, 7.8676000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35573, 'Kaulsdorf', 'Kaulsdorf', 'Berlin-Kaulsdorf', 52.5173200, 13.5887100, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35574, 'Kaulsdorf', 'Kaulsdorf', 'Kaul''sdorf,Kaulsdorf,kao er si duo fu,Каулсдорф,Каульсдорф,考尔斯多夫', 50.6167000, 11.4329500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35575, 'Kaufering', 'Kaufering', 'Kaufering,kao fu ling,kauferingu,kawfryng,Кауферинг,Кауферінг,Քաուֆերինգ,کاوفرینگ,カウフェリング,考弗灵', 48.0912100, 10.8791300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35576, 'Kaufbeuren', 'Kaufbeuren', 'Kaufbeiren,Kaufbeuren,Kaufbojren,kao fu bo yi lun,kaufuboiren,kawfbwyrn,Кауфбойрен,Кауфбојрен,کاوفبویرن,カウフボイレン,考夫博伊伦', 47.8823800, 10.6219200, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35577, 'Kauern', 'Kauern', '', 50.7166700, 12.0833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35578, 'Kaub', 'Kaub', 'Kaub,kao bu,kaupu,kawb,kwab,Кауб,كاوب,کواب,カウプ,考布', 50.0883100, 7.7606900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35579, 'Katzwinkel', 'Katzwinkel', '', 50.2500000, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35580, 'Katzweiler', 'Katzweiler', '', 49.5000000, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35581, 'Katzhütte', 'Katzhuette', 'Kackhite,Kackhjutte,Katzhuette,Katzhutte,Katzhütte,ka ci xu te,Кацхите,Кацхютте,卡茨许特', 50.5519100, 11.0529300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35582, 'Katzenelnbogen', 'Katzenelnbogen', 'Kacenelnbogen,Katcenel''nbogen,Katcenelnbogen,Katzenelnbogen,Katzenelnbogn,ka ce nei er en bo gen,katsn alnbwghn,kattsu~en''erunbogen,Катценелнбоген,Катценельнбоген,Каценелнбоген,كاتسن إلنبوغن,کتسن‌البوگتن,カッツェンエルンボーゲン,卡策内尔恩博根', 50.2674500, 7.9732200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35583, 'Katzenbach', 'Katzenbach', '', 49.6452000, 7.8088500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35584, 'Kattendorf', 'Kattendorf', 'Kattendorf', 53.8432000, 10.0228700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35585, 'Katharinenheerd', 'Katharinenheerd', 'Katharinenheerd', 54.3333300, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35586, 'Katharinenberg', 'Katharinenberg', '', 51.1813700, 10.2608400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35587, 'Kastorf', 'Kastorf', '', 53.7456900, 10.5672300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35588, 'Kastl', 'Kastl', '', 49.8333300, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35589, 'Kastl', 'Kastl', 'Castel,Kastl,Kastl'',Markt Kastl,Кастл,Кастль', 49.3696000, 11.6826100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35590, 'Kastl', 'Kastl', '', 48.2000000, 12.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35591, 'Kastel-Staadt', 'Kastel-Staadt', '', 49.5666700, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35592, 'Kastellaun', 'Kastellaun', 'Kastelaun,Kastellaun,ka si te luo yin,kastlawn,kastlwan,kasuteraun,Кастелаун,Кастеллаун,كاستلاون,کاستلوان,カステラウン,卡斯特洛因', 50.0692200, 7.4415400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35593, 'Kassel', 'Kassel', 'Cassala,Cassel,Castellum,Chasalla [a. 913],Gorad Kasel'',KSF,Kasel,Kasele,Kaseli,Kaselis,Kaselo,Kassel,Kassel'',ka sai er,ka sai er shi,kasel,kasl,kasseru,khas seil,kysl,Κάσσελ,Горад Касель,Касел,Кассель,קאסל,كاسل,کاسل,کیسل,คัสเซิล,კასელი,カッセル,卡塞尔,卡塞爾市,카셀', 51.3166700, 9.5000000, 'DE', '2016-01-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35594, 'Kasseedorf', 'Kasseedorf', 'Kasedorf,Kassedorf,Kasseedorf,ka sai duo fu,Каседорф,Касседорф,卡塞多夫', 54.1666700, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35595, 'Kasseburg', 'Kasseburg', 'Kasseburg', 53.5674700, 10.4165300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35596, 'Käshofen', 'Kashofen', 'Kaeshofen,Käshofen', 49.3333300, 7.4166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35597, 'Kasendorf', 'Kasendorf', 'Kasendorf,Kazendorf,ka sen duo fu,kazendorufu,kazndwrf,Казендорф,Կազենդորֆ,کازندورف,カーゼンドルフ,卡森多夫', 50.0366500, 11.3520300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35598, 'Kasel-Golzig', 'Kasel-Golzig', 'Kazel''-Gol''cig,Kazel-Golcig,ka sai er-ge er qi xi,Казел-Голциг,Казель-Гольциг,Կասել Գոլցիգ,卡塞尔-戈尔齐希', 51.9333300, 13.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35599, 'Kasel', 'Kasel', '', 49.7617000, 6.7322200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35600, 'Kasdorf', 'Kasdorf', '', 50.2064300, 7.7842400, 'DE', '2012-06-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35601, 'Kaschenbach', 'Kaschenbach', '', 49.8760500, 6.4798700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35602, 'Karwitz', 'Karwitz', '', 53.0833300, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35603, 'Karstädt', 'Karstaedt', 'Karshtedt,Karshtet,ka er shi ta te,Карштедт,Карштет,卡爾施塔特', 53.1621500, 11.7424200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35604, 'Karsdorf', 'Karsdorf', 'Carsdorf,Karsdorf,ka er si duo fu,Карсдорф,卡尔斯多夫', 51.2713400, 11.6577500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35605, 'Karsbach', 'Karsbach', 'Karsbakh,Karsbax,ka er si ba he,Карсбах,Կարսբախ,卡尔斯巴赫', 50.0409100, 9.7853400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35606, 'Karow', 'Karow', 'Berlin-Karow,Karov,Каров', 52.6090400, 13.4811700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35607, 'Karolinenkoog', 'Karolinenkoog', 'Karolinenkoog', 54.2833300, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35608, 'Karlum', 'Karlum', 'Karlum', 54.8333300, 8.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35609, 'Karlstadt', 'Karlstadt', 'Karlshtadt,Karlshtadt-am-Majn,Karlshtat,Karlstadt,Karlstadt am Main,Karlstadt-sur-le-Main,ka er shi ta te,karlshtat am mayn,Карлштадт,Карлштадт-ам-Майн,Карлштат,Կարլշթաթ,كارلشتات آم ماين,کارل‌اشتات آم ماین,卡尔施塔特', 49.9603400, 9.7723900, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35610, 'Karlsruhe', 'Karlsruhe', 'Carlsruhe,Carolsruha,FKB,Gorad Karlsrueh,Kallsruh,Karlsroue,Karlsrue,Karlsrueh,Karlsruhe,Karlsruje,Karlsrūe,Karlsrūjė,ka er si lu e,kaleulseulue,karlsaruha,karlsrwh,karlsrwhh,karusurue,qrlsrwhh,Καρλσρούη,Горад Карлсруэ,Карлсруе,Карлсруэ,קרלסרוהה,كارلسروه,کارلزروہے محل,کارلسروهه,कार्ल्सरूह,კარლსრუე,カールスルーエ,卡尔斯鲁厄,카를스루에', 49.0093700, 8.4044400, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35611, 'Karlskron', 'Karlskron', 'Karlskron,ka er si ke long,karlskrwn,Карлскрон,Կարլսկրոն,کارلسکرون,卡尔斯克龙', 48.6833300, 11.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35612, 'Karlshuld', 'Karlshuld', 'Karlsgul''d,Karlskhul''d,Karlskhuld,Karlsxuld,ka er si hu er de,karlshwld,Карлсгульд,Карлсхулд,Карлсхульд,Կարլսխուլդ,کارلسهولد,卡尔斯胡尔德', 48.6819000, 11.2850300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35613, 'Karlshorst', 'Karlshorst', 'Berlin-Karlshorst,Karlskhorst,Карлсхорст,კარლსჰორსტი', 52.4841900, 13.5318500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35614, 'Karlshausen', 'Karlshausen', 'Carlshausen,Karlshausen', 50.0237600, 6.2282100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35615, 'Karlshagen', 'Karlshagen', 'Carlshagen,Karlshagen,Karlskhagen,ka er si ha gen,Карлсхаген,卡尔斯哈根', 54.1110700, 13.8319300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35616, 'Bad Karlshafen', 'Bad Karlshafen', 'Bad Karlskhafen,Bad-Karlsgafen,Bad-Karlskhafen,Carlshafen,Karlshafen,Korlshoawen,ba te ka er si ha fen,bad karlshafn,bad karlzhafn,Бад Карлсхафен,Бад-Карлсгафен,Бад-Карлсхафен,باد كارلسهافن,باد کارلزهافن,バート・カールスハーフェン,巴特卡尔斯哈芬', 51.6426300, 9.4547700, 'DE', '2017-02-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35617, 'Karlsfeld', 'Karlsfeld', 'Karlsfejd,Karlsfel''d,Karlsfeld,ka er si fei er de,karlsfld,Карлсфелд,Карлсфельд,Կարլսֆելդ,کارلسفلد,卡尔斯费尔德', 48.2166700, 11.4666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35618, 'Karlsdorf', 'Karlsdorf', '', 50.8000000, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35619, 'Karl', 'Karl', '', 50.0500000, 6.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35620, 'Karby', 'Karby', 'Karby', 54.6237200, 9.9732300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35621, 'Karben', 'Karben', 'Karben,ka er ben,karbn,karuben,Карбен,كاربن,کاربن,カルベン,卡尔本', 50.2301900, 8.7715500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35622, 'Karbach', 'Karbach', '', 50.1500000, 7.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35623, 'Karbach', 'Karbach', 'Karbach,Karbakh,Karbax,Карбах,Կարբախ', 49.8670100, 9.6380600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35624, 'Kapsweyer', 'Kapsweyer', '', 49.0438900, 8.0216700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35625, 'Kappelrodeck', 'Kappelrodeck', 'Kapelrodek,Kappel''rodek,ka pei er luo de ke,Капелродек,Каппельродек,卡佩尔罗德克', 48.5918200, 8.1169200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35626, 'Kappeln', 'Kappeln', 'Kapellen,Kapeln,Kappalen,Kappel,Kappel''n,ka pei er en,kabln,kapln,Капелн,Каппельн,كابلن,کاپلن,卡佩尔恩', 54.6612200, 9.9313000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35627, 'Kappeln', 'Kappeln', 'Kapeln,Kappel''n,Капелн,Каппельн', 49.6833300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35628, 'Kappel', 'Kappel', 'Kappel', 50.0000000, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35629, 'Kaperich', 'Kaperich', '', 50.2500000, 7.0333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35630, 'Kapellen-Drusweiler', 'Kapellen-Drusweiler', '', 49.1016700, 8.0311100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35631, 'Kapellendorf', 'Kapellendorf', 'Kapelendorf,Kapellendorf,ka pei lun duo fu,Капелендорф,Капеллендорф,卡佩伦多夫', 50.9746400, 11.4687000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35632, 'Kanzem', 'Kanzem', '', 49.6667300, 6.5783200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35633, 'Kanzach', 'Kanzach', '', 48.0779600, 9.5588800, 'DE', '2011-09-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35634, 'Kannawurf', 'Kannawurf', 'Cannawurf,Kannawurf', 51.2666700, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35635, 'Kankelau', 'Kankelau', 'Kankelau', 53.5500000, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35636, 'Kandern', 'Kandern', 'Kandern,kan de er en,kandrn,Кандерн,كاندرن,کاندرن,坎德尔恩', 47.7139300, 7.6623700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35637, 'Kandel', 'Kandel', 'Kandel', 49.0827700, 8.1972000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35638, 'Kamsdorf', 'Kamsdorf', 'Kamsdorf,ka mu si duo fu,Камсдорф,卡姆斯多夫', 50.6431200, 11.4540100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35639, 'Kamp-Lintfort', 'Kamp-Lintfort', 'Kamp-Lintfort,Lapangan Terbang Kamp-Lintfort,kamb-lyntfwrt,kan pu-lin te fu er te,kmp-lyntfwrt,Камп-Линтфорт,Камп-Лінтфорт,كامب-لينتفورت,کمپ-لینتفورت,坎普-林特福尔特', 51.5046700, 6.5458700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35640, 'Kamp-Bornhofen', 'Kamp-Bornhofen', 'Kamp-Bornkhofen,kan pu-bo er en huo fen,Камп-Борнхофен,坎普-博尔恩霍芬', 50.2228200, 7.6236400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35641, 'Kammerstein', 'Kammerstein', 'Kamershtajn,Kammershtajn,ka mei er si tai yin,kanmashutain,Камерштајн,Каммерштайн,Կամերշթայն,カンマーシュタイン,卡梅尔斯泰因', 49.2931700, 10.9727700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35642, 'Kammerforst', 'Kammerforst', 'Cammerforst,Kammerforst', 51.1216300, 10.4232800, 'DE', '2012-05-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35643, 'Kammerforst', 'Kammerforst', '', 50.4630000, 7.6760000, 'DE', '2013-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35644, 'Kamern', 'Kamern', '', 52.7485000, 12.1125100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35645, 'Kamenz', 'Kamenz', 'Camentia,Kamenc,Kamenca,Kamenec,Kamenz/Kamjenc,Kamjenc,Kamjeńc,Kāmenca,ka men ci,kamnts,kamynz,Каменц,كامينز,کامنتس,卡门茨', 51.2679800, 14.0937400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35646, 'Kamen', 'Kamen', 'Kamen,ka men,kamen,kamn,Камен,كامن,کامن,カーメン,卡門', 51.5923100, 7.6638000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35647, 'Kalübbe', 'Kalubbe', '', 54.1166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35648, 'Kaltenwestheim', 'Kaltenwestheim', 'Kaltenwestheim', 50.6099100, 10.1169200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35649, 'Kaltensundheim', 'Kaltensundheim', 'Kal''tenzundkhajm,Kaltensundheim,Kaltensundkhajm,Kaltenzundkhajm,ka er teng sun de hai mu,Калтензундхајм,Калтенсундхајм,Кальтензундхайм,卡尔滕孙德海姆', 50.6061900, 10.1564000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35650, 'Kaltennordheim', 'Kaltennordheim', 'Kal''tennordkhajm,Kaltennordheim,Kaltenordkhajm,ka er te nuo er de hai mu,kaltn nwrdhaym,Калтенордхајм,Кальтеннордхайм,كالتن نوردهايم,کالتن‌نوردهایم,卡尔特诺尔德海姆', 50.6264900, 10.1591500, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35651, 'Kaltenlengsfeld', 'Kaltenlengsfeld', 'Kal''tenlengsfel''d,Kaltenlengsfeld,ka er teng lun si fei er de,Калтенленгсфелд,Кальтенленгсфельд,卡尔滕伦斯费尔德', 50.6409200, 10.1922200, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35652, 'Kaltenkirchen', 'Kaltenkirchen', 'Kal''tenkirkhen,Kaltenkirchen,Kaltenkirkhen,Koldenkarken,Kolenkarken,ka er teng ji er xing,kaltnkyrshn,Калтенкирхен,Кальтенкирхен,كالتنكيرشن,کالتن‌کیرشه,卡尔滕基尔兴', 53.8329200, 9.9581000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35653, 'Kaltenholzhausen', 'Kaltenholzhausen', '', 50.3000000, 8.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35654, 'Kaltenengers', 'Kaltenengers', '', 50.4166700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35655, 'Kaltenborn', 'Kaltenborn', '', 50.4000000, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35656, 'Kalt', 'Kalt', '', 50.2672900, 7.3946600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35657, 'Kallstadt', 'Kallstadt', 'Kal''shtadt,Kallschdadt,Kalshtat,ka er si ta te,Калштат,Кальштадт,卡尔斯塔特', 49.4908300, 8.1761100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35658, 'Kallmünz', 'Kallmunz', 'Kal''mjunc,Kall''mjunc,Kallmuenz,Kallmunz,Kallmünz,Kalminc,Kalmunz,ka er ming ci,kalmwnts,Калльмюнц,Калминц,Кальмюнц,Կալմյունց,کالمونتس,卡尔明茨', 49.1609400, 11.9605100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35659, 'Kallmerode', 'Kallmerode', 'Kal''merode,Kallmerode,Kalmerode,ka er mei luo de,Калмероде,Кальмероде,卡尔梅罗德', 51.3500000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35660, 'Kall', 'Kall', 'Kall', 50.5422300, 6.5629700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35661, 'Kalkofen', 'Kalkofen', '', 49.7333300, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35662, 'Kalkhorst', 'Kalkhorst', 'Kal''kkhorst,Kalkkhorst,ka er ke huo er si te,Калкхорст,Калькхорст,卡尔克霍尔斯特', 53.9701200, 11.0446900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35663, 'Kalkar', 'Kalkar', 'Calkar,Kal''kar,Kalkar,kalkar,karuka,Калкар,Калькар,كالكار,کالکار,カルカー', 51.7390700, 6.2910100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35664, 'Kalenborn', 'Kalenborn', '', 50.5500000, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35665, 'Kalenborn', 'Kalenborn', 'Calenborn,Kalenborn', 50.2666700, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35666, 'Kalefeld', 'Kalefeld', 'Kalefel''d,Kalefeld,ka lai fei er de,kareferuto,Калефелд,Калефельд,カーレフェルト,卡莱费尔德', 51.8000000, 10.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35667, 'Kalchreuth', 'Kalchreuth', 'Kal''khrojt,Kalchreuth,Kalrojt,ka er xi luo yi te,karuhiroito,Калројт,Кальхройт,カルヒロイト,卡尔希罗伊特', 49.5578500, 11.1335000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35668, 'Kalbsrieth', 'Kalbsrieth', 'Kalbsrieth', 51.3421700, 11.3402800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35669, 'Kalbe', 'Kalbe', '', 53.2933500, 9.5506100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35670, 'Kalbe', 'Kalbe', 'Calbe,Kal''be,Kalbe,ka er bei,kalbh,kalbt,Калбе,Кальбе,كالبة,کالبه,卡爾貝', 52.6565600, 11.3845600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35671, 'Kakenstorf', 'Kakenstorf', '', 53.3031700, 9.7628900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35672, 'Kaisheim', 'Kaisheim', 'Caesarea,Kaisheim,Kajsgajm,Kajskhajm,Kaysersheim,Kayshaym,kai si hai mu,kaisuhaimu,Кайсгайм,Кайсхайм,Кајсхајм,Կայսհայմ,カイスハイム,凯斯海姆', 48.7675100, 10.7963900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35673, 'Kaiserslautern', 'Kaiserslautern', 'KLT,Kaiserlautern,Kaiserslantern,Kaiserslautern,Kaizerslauternas,Kajzerslautern,kai sa si lao teng,kaijeoseullauteleun,kaizasurauterun,ki se xrs lea theirn,Кайзерслаутерн,Кајзерслаутерн,קייזרסלאוטרן,کائزرسلائوٹرن,ไกเซอร์สเลาเทิร์น,カイザースラウテルン,凯撒斯劳滕,카이저슬라우테른', 49.4430000, 7.7716100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35674, 'Kaisersesch', 'Kaisersesch', 'Kaisersech,Kaisersesch,Kajzerzesh,kai sai er sai shi,kaizazesshu,kayzrzks,kayzrzysh,Кайзерзеш,Кајзерзеш,كايزرزيش,کایزرزکس,カイザーゼッシュ,凯塞尔塞施', 50.2314800, 7.1386400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35675, 'Kaisersbach', 'Kaisersbach', 'Kajzersbakh,kai sai er si ba he,Кайзерсбах,Кајзерсбах,凯塞尔斯巴赫', 48.9302300, 9.6389800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35676, 'Kaisborstel', 'Kaisborstel', 'Kaisborstel', 54.0136700, 9.4811600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35677, 'Kail', 'Kail', '', 50.1833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35678, 'Kaifenheim', 'Kaifenheim', 'Kajfenkhajm,kai fen hai mu,Кайфенхайм,Кајфенхајм,凯芬海姆', 50.2450100, 7.2264300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35679, 'Kahl am Main', 'Kahl am Main', 'Kahl,Kal na Majni,Kal''-am-Majn,Kal''-na-Majne,Majndagy Kal'',Mayni Kal,mei yin he pan ka er,Кал на Мајни,Каль-ам-Майн,Каль-на-Майне,Майндагы Каль,Մայնի Կալ,カール・アム・マイン,美因河畔卡尔', 50.0698100, 9.0055300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35680, 'Kahla', 'Kahla', 'Kahla', 50.8065100, 11.5851600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35681, 'Kadenbach', 'Kadenbach', '', 50.3833300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35682, 'Kaden', 'Kaden', '', 50.5480600, 7.9150000, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35683, 'Kabelhorst', 'Kabelhorst', 'Kabelhorst', 54.2166700, 10.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35684, 'Kaarst', 'Kaarst', 'Kaarst,Kaasch,Kaasj,Karst,ka er si te,karst,Каарст,Карст,كارست,کارست,卡尔斯特', 51.2292900, 6.6188300, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35685, 'Kaaks', 'Kaaks', 'Kaaks', 53.9900400, 9.4696200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35686, 'Jüterbog', 'Jueterbog', 'Iutrebocum,Jiterbog,Jjuterbog,Jueterbog,Juterbog,Jüterbog,Yuterbog,yu te bo ge,ywtrbwgh,ywtrbwrg,Јитербог,Йютербог,Ютербог,Յուտերբոգ,يوتربوغ,یوتربورگ,于特博格', 51.9960700, 13.0797900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35687, 'Jürgenshagen', 'Juergenshagen', '', 53.9541700, 11.8966500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35688, 'Jünkerath', 'Juenkerath', 'Jinkerat,Junkerat,Junkerath,Jünkerath,yin ke la te,yunkerato,Јинкерат,Юнкерат,ユンケラート,因克拉特', 50.3441200, 6.5813800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35689, 'Jungingen', 'Jungingen', 'Jungingen,rong jin gen,Јунгинген,Юнгинген,Юнгінген,容金根', 48.3278700, 9.0409500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35690, 'Juliusburg', 'Juliusburg', 'Juliusburg', 53.4166700, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35691, 'Jülich', 'Juelich', 'Iuliacum,Jilikh,Joellesch,Juelich,Julich,Julichas,Juliers,Julikh,Jöllesch,Jülich,yu li xi,ywlysh,Јилих,Юлих,Юліх,يوليش,یولیش,于利希', 50.9214900, 6.3626700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35692, 'Julbach', 'Julbach', '', 48.2543000, 12.9579300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35693, 'Juist', 'Juist', 'JUI,Jjust,Juist,Just,Júst,yawst,you yi si te,Јуист,Йюст,ياوست,იუსტი,尤伊斯特', 53.6778700, 6.9957500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35694, 'Jühnde', 'Juhnde', 'Barlissen,Jinde,Junde,yu he en de,yunde,Јинде,Юнде,ユーンデ,于赫恩德', 51.4666700, 9.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35695, 'Jugenheim', 'Jugenheim', '', 49.8936200, 8.0846800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35696, 'Judenbach', 'Judenbach', 'Judenbakh,you deng ba he,Јуденбах,Юденбах,尤登巴赫', 50.3959100, 11.2209900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35697, 'Jucken', 'Jucken', '', 50.0500000, 6.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35698, 'Jückelberg', 'Juckelberg', 'Juckelberg,Jückelberg', 50.9270300, 12.6288300, 'DE', '2014-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35699, 'Jüchsen', 'Juechsen', 'Juchsen,Jüchsen', 50.4799300, 10.5018300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35700, 'Jüchen', 'Juchen', 'Jikhen,Jjukhen,Juche,Juchen,Juchenas,Juechen,Jüchen,yu xing,Јихен,Йюхен,于兴', 51.1000000, 6.5000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35701, 'Jübek', 'Juebek', 'Jibek,Jubek,Juebek,Jydbaek,Jydbæk,Jübek,yu bei ke,Јибек,Юбек,于贝克', 54.5570900, 9.3977300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35702, 'Jübar', 'Juebar', 'Jibar,Jubar,yu ba er,Јибар,Юбар,于巴尔', 52.6890400, 10.9089800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35703, 'Jörl', 'Joerl', 'Joerl,Jorl,Jörl', 54.6000000, 9.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35704, 'Jork', 'Jork', 'Gemeen Joerk,Gemeen Jörk,Jork,yoruku,yue er ke,Јорк,Йорк,ヨルク,约尔克', 53.5319800, 9.6807600, 'DE', '2013-01-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35705, 'Jördenstorf', 'Joerdenstorf', 'Jordenstorf,Jördenstorf', 53.8782300, 12.6161900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35706, 'Jonaswalde', 'Jonaswalde', '', 50.8333300, 12.3000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35707, 'Joldelund', 'Joldelund', 'Joldelund', 54.6500000, 9.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35708, 'Jöhstadt', 'Joehstadt', 'Jekhshtat,Jeshtat,Jestate,Jjoshtadt,Johstadt,Jöhstadt,Jēštate,yue he si ta te,ywnshtat,Јехштат,Јештат,Йёштадт,يونشتات,یون‌اشتات,约赫斯塔特', 50.5122900, 13.0946000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35709, 'Jöhlingen', 'Joehlingen', '', 49.0321800, 8.5735000, 'DE', '2013-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35710, 'Johannisthal', 'Johannisthal', 'Berlin-Johannisthal,Jokhannistal'',Йоханнисталь', 52.4465300, 13.5066000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35711, 'Johanniskirchen', 'Johanniskirchen', 'Joganniskirkhen,Jokhaniskirkhen,Jokhanniskirkhen,Yohaniskirxen,yue ha ni si ji er xing,ywhanyskyrshn,Јоханискирхен,Йоганніскірхен,Йоханнискирхен,Յոհանիսկիրխեն,یوهانیسکیرشن,约哈尼斯基尔兴', 48.5333300, 12.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35712, 'Johanngeorgenstadt', 'Johanngeorgenstadt', 'Johanngeorgenstadt,Johanngeorgenstate,Johanngeorgenštate,Jokhangeorgenshtadt,Jokhangeorgenshtat,yue han ge ao er gen si ta te,ywhanghywrghnshtat,Јохангеоргенштат,Йохангеоргенштадт,يوهانغيورغنشتات,یوهانگیورگن‌اشتات,约汉格奥尔根斯塔特', 50.4325400, 12.7114000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35713, 'Johannesberg', 'Johannesberg', '', 50.0315900, 9.1425200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35714, 'Jockgrim', 'Jockgrim', 'Jokgrim,yue ke ge li mu,Јокгрим,Йокгрим,约克格里姆', 49.0928800, 8.2746800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35715, 'Joachimsthal', 'Joachimsthal', 'Ioakhimstal'',Joahimstale,Joahimstāle,Joakhimstal,yue a xi mu si ta er,ywakhymstal,ywakhymztal,Јоахимстал,Иоахимсталь,Յոչիմստալ,يواخيمستال,یواخیمزتال,约阿希姆斯塔尔', 52.9794500, 13.7449300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35716, 'Jever', 'Jever', 'Geverae,Jever,i~efa,ye fei er,yfr,yfyr,Јевер,Йевер,يفير,یفر,イェファー,耶费尔', 53.5736800, 7.8980600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35717, 'Jevenstedt', 'Jevenstedt', 'Jefenshtedt,Jefenshtet,Jevenshtedt,Jevenshtet,Jevenstedt,ye fen si te,Јевенштет,Јефенштет,Йевенштедт,Йефенштедт,耶芬斯特', 54.2333300, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35718, 'Jetzendorf', 'Jetzendorf', 'Etcendorf,Jecendorf,ye cen duo fu,ytsndwrf,Єтцендорф,Јецендорф,Етцендорф,Ետցենդորֆ,یتسندورف,耶岑多夫', 48.4333300, 11.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35719, 'Jettenbach', 'Jettenbach', 'Jetenbakh,Jettenbach,Jettenbakh,Jetterbach,Јетенбах,Йеттенбах', 49.5348200, 7.5571800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35720, 'Jettenbach', 'Jettenbach', '', 48.1666700, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35721, 'Jestetten', 'Jestetten', 'Eshtetten,Jeshteten,Jeshtetten,ye si te teng,Єштеттен,Јештетен,Йештеттен,耶斯特滕', 47.6500000, 8.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35722, 'Jesteburg', 'Jesteburg', 'Gemeen Jesborg,Jesteburg,ye si te bao,Јестебург,Йестебург,耶斯特堡', 53.3096600, 9.9526200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35723, 'Jeßnitz', 'Jessnitz', 'Jesnic,Jessnitz,Jeßnitz,ysnyz,Јесниц,Йесниц,יסניץ', 51.6830700, 12.2999200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35724, 'Jessen', 'Jessen', 'Jessen', 51.7933700, 12.9576200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35725, 'Jesewitz', 'Jesewitz', 'Jesewitzi vald,Jezevic,ye sai wei ci,Језевиц,Йезевиц,耶塞维茨', 51.4227600, 12.5631200, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35726, 'Jesenwang', 'Jesenwang', 'Ezenvang,Jezenvang,ye sen wang,yznwang,Єзенванг,Језенванг,Езенванг,یزنوانگ,耶森旺', 48.1666700, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35727, 'Jesberg', 'Jesberg', 'Esberg,Jesberg,i~esuberuku,ye si bei ge,Єсберг,Јесберг,Йесберг,イェスベルク,耶斯贝格', 51.0000000, 9.1500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35728, 'Jerxheim', 'Jerxheim', 'Jerkskhajm,ye er ke si hai mu,Јерксхајм,Йерксхайм,耶尔克斯海姆', 52.0817200, 10.8984400, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35729, 'Jersbek', 'Jersbek', 'Jersbek,ye er si bei ke,Јерсбек,Йерсбек,耶尔斯贝克', 53.7333300, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35730, 'Jerrishoe', 'Jerrishoe', 'Jerrishoe', 54.6567000, 9.3691800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35731, 'Jerichow', 'Jerichow', 'Jerichow,Jerikhov,ye li xiao fu,yryshw,yyryshw,Јерихов,Йерихов,ييريشو,یریشو,耶里肖夫', 52.5004900, 12.0238300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35732, 'Jengen', 'Jengen', 'Engen,Jengen,i~engen,yan gen,Єнген,Јенген,Енген,Ենգեն,イェンゲン,延根', 47.9993400, 10.7257500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35733, 'Jenalöbnitz', 'Jenaloebnitz', 'Jenalobnitz,Jenalöbnitz', 50.9500000, 11.7000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35734, 'Jena', 'Jena', 'Ena,Gorad Iena,Iena,Iéna,Jena,Jena (Thueringen),Jéna,Jēna,Jėna,ZJS,iena,i~ena,jena,jyna,ye na,yena,yna,yyna,yynh,Ιένα,Єна,Јена,Горад Іена,Йена,יינה,جینا,يينا,ینا,जेना,জেনা,იენა,イェーナ,耶拿,예나', 50.9287800, 11.5899000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35735, 'Jemgum', 'Jemgum', 'Jemgum,Jemmingen,ye mu gu mu,ymjwm,Јемгум,Йемгум,يمجوم,耶姆古姆', 53.2666700, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35736, 'Jembke', 'Jembke', 'Jembke,yan bu ke,Јембке,Йембке,延布克', 52.5000000, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35737, 'Jelmstorf', 'Jelmstorf', '', 53.1013200, 10.5223700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35738, 'Jeckenbach', 'Jeckenbach', 'Jekenbakh,Jekkenbakh,ye ken ba he,Јекенбах,Йеккенбах,耶肯巴赫', 49.7166700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35739, 'Jävenitz', 'Jaevenitz', '', 52.5241000, 11.4990900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35740, 'Jatznick', 'Jatznick', 'Jatznick', 53.5795100, 13.9395500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35741, 'Jarmen', 'Jarmen', 'Jarmen,Jarmene,Jeromino,ya er men,yarmn,Јармен,Ярмен,يارمن,یارمن,亚尔门', 53.9238500, 13.3403200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35742, 'Jardelund', 'Jardelund', 'Jardelund', 54.8333300, 9.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35743, 'Jänschwalde', 'Janschwalde', 'Ensvalde,Jaenschwalde,Jaenschwalde/Jansojce,Janschwalde,Jansojce,Janšojce,Jenshval''de,Jenshvalde,Jänschwalde,Jänschwalde/Janšojce,yan shi wa er de,Јеншвалде,Йеншвальде,Ենշվալդե,جانسچوالدے,延施瓦尔德', 51.8606600, 14.4981300, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35744, 'Janneby', 'Janneby', 'Janneby', 54.6333300, 9.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35745, 'Jandelsbrunn', 'Jandelsbrunn', 'Jandel''sbrunn,Jandelsbrun,Yandelsbrun,jndlsbrnn,yandlsbrwn,yang de er si bu lun,Јанделсбрун,Яндельсбрунн,Յանդելսբրուն,جندلسبرنن,یاندلسبرون,扬德尔斯布伦', 48.7333300, 13.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35746, 'Jamlitz', 'Jamlitz', 'Jamlic,Jemjelnica,ya mu li ci,Јамлиц,Ямлиц,Յամլից,جملٹز,亚姆利茨', 51.9913100, 14.3610000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35747, 'Jameln', 'Jameln', 'Jamel''n,Jameln,jmln,ya mei er en,yamln,Јамелн,Ямельн,جملن,یاملن,亚梅尔恩', 53.0500000, 11.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35748, 'Jakobsweiler', 'Jakobsweiler', '', 49.6166700, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35749, 'Jacobsdorf', 'Jacobsdorf', 'Jacobsdorf,Jakobsdorf,Yakobsdorf,jkwbsdwrf,ya ke bu si duo fu,Јакобсдорф,Якобсдорф,Յակոբսդորֆ,جکوبسدورف,亚科布斯多夫', 52.3333300, 14.3500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35750, 'Jahrsdorf', 'Jahrsdorf', 'Jarsdorf,ya er si duo fu,Јарсдорф,Ярсдорф,جہرسدورف,亚尔斯多夫', 54.0666700, 9.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35751, 'Jahnsdorf', 'Jahnsdorf', 'Jahnsdorf,Jahnsdorf/Erzgebirge', 50.7450900, 12.8541400, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35752, 'Jagstzell', 'Jagstzell', 'Jagscel,Jagstcell'',jgstzll,ya ge si ce er,Јагсцел,Ягстцелль,جگستزلل,იაგსტცელი,亚格斯策尔', 49.0305500, 10.0975100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35753, 'Jagsthausen', 'Jagsthausen', 'Jagstauzen,Jagstgauzen,Jagsthausen,Jagstkhauzen,ya ge si tao sen,yakusutohauzen,Јагстаузен,Ягстгаузен,Ягстхаузен,جگستھوسن,ヤクストハウゼン,亚格斯陶森', 49.3105600, 9.4683300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35754, 'Jagel', 'Jagel', '', 54.4565200, 9.5375900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35755, 'Jachenau', 'Jachenau', 'Jakhenau,Yaxenau,jchnw,ya hei nao,yakhnaw,Јахенау,Яхенау,Յախենաու,جچنو,یاخناو,亚黑瑙', 47.6057400, 11.4338100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35756, 'Itzstedt', 'Itzstedt', 'Itzstedt', 53.8080000, 10.1579700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35757, 'Itzehoe', 'Itzehoe', 'Icekho,Itcekho,Itcekhoe,atshwhh,atshwyh,yi ce huo ai,yzhw,Итцехо,Итцехое,Ицехо,יצהו,إتسهويه,اتسهوهه,伊策霍埃', 53.9209900, 9.5152900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35758, 'Ittlingen', 'Ittlingen', 'Itlingen,Ittlingen,ittoringen,yi te lin gen,Іттлінген,Итлинген,Иттлинген,イットリンゲン,伊特林根', 49.1908300, 8.9308300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35759, 'Itterbeck', 'Itterbeck', '', 52.5061800, 6.8035400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35760, 'Issum', 'Issum', 'Issum,Isum,yi su mu,Іссум,Иссум,Исум,伊苏姆', 51.5333300, 6.4333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35761, 'Issigau', 'Issigau', 'Isigau,Issigau,aysygaw,ishigau,yi xi gao,Іссігау,Исигау,Иссигау,ایسیگاو,イシガウ,伊西高', 50.3752500, 11.7207000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35762, 'Issersheilingen', 'Issersheilingen', '', 51.2000000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35763, 'Isseroda', 'Isseroda', '', 50.9565100, 11.2200500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35764, 'Isselburg', 'Isselburg', 'Iselburg,Issel''burg,Isselburg,Isselburq,aslbwrgh,ayzlbwrg,yi sai er bao,İsselburq,Іссельбург,Иселбург,Иссельбург,إسلبورغ,ایزلبورگ,伊塞尔堡', 51.8323200, 6.4642800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35765, 'Isselbach', 'Isselbach', '', 50.4000000, 7.9000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35766, 'Ispringen', 'Ispringen', 'Ispringen,yi si pu lin gen,Іспрінген,Испринген,Իսպրինգեն,伊斯普林根', 48.9166700, 8.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35767, 'Isny im Allgäu', 'Isny im Allgau', 'Isna,Isni,Isni im Algoj,Isni-im-All''goj,Isny,Isny im Allgaeu,Isny im Allgau,Isny im Allgäu,a er ge yi de qu yi si ni,asny am alghwy,ayzny am alga,Існи-ім-Алльгой,Исни,Исни им Алгој,Исни-им-Алльгой,إسني إم آلغوي,ایزنی ام آلگا,阿尔戈伊地区伊斯尼', 47.6926000, 10.0385700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35768, 'Ismaning', 'Ismaning', 'Ismaning,aysmanyng,yi si ma ning,Ісманінг,Исманинг,Իսմանինգ,ایسمانینگ,伊斯马宁', 48.2333300, 11.6833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35769, 'Isert', 'Isert', '', 50.7333300, 7.7000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35770, 'Isernhagen Farster Bauerschaft', 'Isernhagen Farster Bauerschaft', '', 52.4709300, 9.8417900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35771, 'Iserlohn', 'Iserlohn', 'Iserlaun,Iserlohn,Iserlon,Izerlon,Izerlonas,ZNR,ayzlwn,azrlwn,ijeollon,izaron,yi se long,Ізерлон,Изерлон,Исерлон,إزرلون,ایزلون,イーザーローン,伊瑟隆,이절론', 51.3754700, 7.7028100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35772, 'Isenbüttel', 'Isenbuttel', 'Isenbitel,Isenbuettel,Isenbüttel,Izenbjuttel'',yi sen bi te er,Изенбюттель,Исенбител,伊森比特尔', 52.4333300, 10.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35773, 'Isenburg', 'Isenburg', '', 50.4833300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35774, 'Isen', 'Isen', 'Isen,Isena,Izen,Jarna,ayzn,Ізен,Изен,Исен,ایزن', 48.2120300, 12.0567200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35775, 'Irxleben', 'Irxleben', 'Irksleben,Irxleben,Иркслебен', 52.1668900, 11.4806400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35776, 'Irsee', 'Irsee', 'Irsee,Irze,Irzee,Irzey,iruze,yi er sai,Ірзе,Ирзе,Ирзее,Իրզեյ,イルゼー,伊尔塞', 47.9081500, 10.5717700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35777, 'Irschenberg', 'Irschenberg', 'Irschenberg,Irsenberg,Irshenberg,ayrshnbrg,yi er shen bei ge,Іршенберг,Иршенберг,Իրշենբերգ,ایرشنبرگ,伊尔申贝格', 47.8333300, 11.9166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35778, 'Irsch', 'Irsch', '', 49.7262000, 6.6980600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35779, 'Irsch', 'Irsch', 'Irisch,Irsch', 49.6048700, 6.5954700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35780, 'Irrhausen', 'Irrhausen', '', 50.0666700, 6.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35781, 'Irndorf', 'Irndorf', 'Irndorf,Irrendorf,yi en duo fu,Ирндорф,伊恩多夫', 48.0666700, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35782, 'Irrel', 'Irrel', 'Irel,Irrel'',iareru,yi lei er,Ирел,Иррель,イアレル,伊雷尔', 49.8453900, 6.4570500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35783, 'Irmtraut', 'Irmtraut', '', 50.5500000, 8.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35784, 'Irmenach', 'Irmenach', 'Irmenakh,yi er mei na,Ирменах,伊尔梅纳', 49.9241700, 7.1887400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35785, 'Irlbach', 'Irlbach', '', 48.8412800, 12.7513500, 'DE', '2012-09-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35786, 'Irchenrieth', 'Irchenrieth', '', 49.6228600, 12.2249500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35787, 'Ipsheim', 'Ipsheim', 'Ipsgajm,Ipshaym,Ipsheim,Ipskhajm,yi pu si hai mu,Іпсгайм,Ипсхайм,Ипсхајм,Իպսհայմ,伊普斯海姆', 49.5275000, 10.4817600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35788, 'Ippesheim', 'Ippesheim', 'Ipeskhajm,Ippesgajm,Ippeskhajm,yi pei si hai mu,Іппесгайм,Ипесхајм,Иппесхайм,Իփեսհայմ,伊佩斯海姆', 49.6021400, 10.2255200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35789, 'Ippenschied', 'Ippenschied', '', 49.8666700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35790, 'Iphofen', 'Iphofen', 'Ipgofen,Ipkhofen,abhwfn,ayphwfn,yi fu fen,Іпгофен,Ипхофен,Իփհոֆեն,إبهوفن,ایپهوفن,伊福芬', 49.7023900, 10.2603700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35791, 'Inzlingen', 'Inzlingen', 'Inclingen,yin ci lin gen,Інцлінген,Инцлинген,因茨林根', 47.5885100, 7.6909400, 'DE', '2013-04-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35792, 'Inzigkofen', 'Inzigkofen', 'Incigkofen,Incigofen,Incikofen,yin qi ge ke fen,Інцигофен,Инцигкофен,Инцикофен,因齐格科芬', 48.0703400, 9.1799800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35793, 'Inzell', 'Inzell', 'Incel,Incel'',Incell'',Inzell,Ynzell,ayntsl,yin ce er,Інцель,Инцел,Инцелль,Ինցել,اینتسل,因策尔', 47.7630200, 12.7514600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35794, 'Insul', 'Insul', '', 50.4333300, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35795, 'Insingen', 'Insingen', 'Insingen,Inzingen,injingen,yin xin gen,Інзінген,Инзинген,Инсинген,Ինզինգեն,インジンゲン,因辛根', 49.3000000, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35796, 'Insheim', 'Insheim', '', 49.1580600, 8.1472200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35797, 'Inning am Holz', 'Inning am Holz', 'Inning,Inning am Holz', 48.3468700, 12.0750600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35798, 'Inning am Ammersee', 'Inning am Ammersee', 'Ining am Amerze,Inning,Inning-am-Ammerze,a mo hu pan yin ning,aynyng am amrzy,Іннінг-ам-Аммерзе,Ининг ам Амерзе,Иннинг-ам-Аммерзе,اینینگ ام آمرزی,阿默湖畔因宁', 48.0763600, 11.1523200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35799, 'Innernzell', 'Innernzell', 'Inerncel,Innerncel'',Innerncell'',aynrntsl,yi nei er en ce er,Іннернцель,Инернцел,Иннернцелль,Իններնցել,اینرنتسل,伊内尔恩策尔', 48.8515000, 13.2753900, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35800, 'Ingolstadt', 'Ingolstadt', 'IGS,Ingol''shtadt,Ingolshhat,Ingolshtat,Ingolstadt,ingorushutatto,Инголштат,Инголщат,Ингольштадт,インゴルシュタット', 48.7650800, 11.4237200, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35801, 'Ingoldingen', 'Ingoldingen', 'Ingol''dingen,Ingoldingen,ingoldingeni,yin ge er ding gen,Інгольдінген,Инголдинген,Ингольдинген,Ինգոլդինգեն,ინგოლდინგენი,因戈尔丁根', 48.0255200, 9.7419500, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35802, 'Ingersleben', 'Ingersleben', 'Ingersleben', 50.9216700, 10.9364600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35803, 'Ingenried', 'Ingenried', '', 47.8166700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35804, 'Ingendorf', 'Ingendorf', '', 49.9333300, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35805, 'Ingelheim am Rhein', 'Ingelheim am Rhein', 'Angulisamum,Ingel''khajm-am-Rajn,Ingelheim,Ingelheim am Rhein,Ingelkhajm am Rejn,Ingelkhajm na Rajni,anghlhaym am rayn,aynglhaym am rayn,lai yin he pan yin ge er hai mu,Ингелхайм ам Рейн,Ингелхајм на Рајни,Ингельхайм-ам-Райн,אינגלהיים אם ריין,إنغلهايم آم راين,اینگلهایم آم راین,インゲルハイム・アム・ライン,莱茵河畔因格尔海姆', 49.9707800, 8.0588300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35806, 'Ingelfingen', 'Ingelfingen', 'Ingel''fingen,Ingelfingen,anghlfynghn,aynglfyngl,ingerufingen,yin ge er fen gen,Інгельфінген,Ингелфинген,Ингельфинген,إنغلفينغن,اینگلفینگل,インゲルフィンゲン,因格尔芬根', 49.3002800, 9.6530300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35807, 'Ingeleben', 'Ingeleben', '', 52.1066100, 10.8733700, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35808, 'Inden', 'Inden', 'Inden', 50.8430600, 6.3600400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35809, 'Inchenhofen', 'Inchenhofen', 'Inchenhofen,Inkhengofen,Inkhenkhofen,Inxenhofen,Leahad,inhyenhofen,yin xing huo fen,Інхенгофен,Инхенхофен,Ինխենհոֆեն,インヒェンホーフェン,因兴霍芬', 48.5128800, 11.1145800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35810, 'Imsweiler', 'Imsweiler', '', 49.6000000, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35811, 'Imsbach', 'Imsbach', 'Imsbakh,yi mu si ba he,Имсбах,伊姆斯巴赫', 49.5833300, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35812, 'Impflingen', 'Impflingen', '', 49.1622200, 8.1130600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35813, 'Immesheim', 'Immesheim', '', 49.6363900, 8.1052800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35814, 'Immert', 'Immert', '', 49.7666700, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35815, 'Immerath', 'Immerath', '', 50.1333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35816, 'Immenstedt', 'Immenstedt', '', 54.5404500, 9.1604300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35817, 'Immenstedt', 'Immenstedt', '', 54.1833300, 9.3000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35818, 'Immenstadt im Allgäu', 'Immenstadt im Allgau', 'Immenstadt,Immenstadt im Allgau,Immenstadt im Allgäu', 47.5599600, 10.2139400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35819, 'Immenstaad am Bodensee', 'Immenstaad am Bodensee', 'Imenstad,Imenstad am Bodenze,Immenshtad,Immenshtad-am-Bodenze,Immenstaad,Immenstaad am Bodensee,bo deng hu bin yi men si ta de,Імменштад,Именстад ам Бодензе,Имменштад,Имменштад-ам-Бодензе,Իմենշտադ,იმენშტაად-ამ-ბოდენზეე,博登湖滨伊门斯塔德', 47.6666700, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35820, 'Immenreuth', 'Immenreuth', '', 49.9000000, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35821, 'Immenhausen', 'Immenhausen', 'Imenkhauzen,Immengauzen,Immenkhauzen,amnhawzn,aymnhawzn,inmenhauzen,yi men hao sen,Імменгаузен,Именхаузен,Имменхаузен,إمنهاوزن,ایمنهاوزن,インメンハウゼン,伊门豪森', 51.4276300, 9.4801700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35822, 'Immendingen', 'Immendingen', 'Imendingen,Immendingen,yi men ding gen,Имендинген,Иммендинген,伊门丁根', 47.9333300, 8.7333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35823, 'Immelborn', 'Immelborn', 'Imelborn,Immel''born,Immelborn,yi mei er bo er en,Имелборн,Иммельборн,伊梅尔博尔恩', 50.7922900, 10.2781200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35824, 'Ilvesheim', 'Ilvesheim', 'Il''fesgajm,Il''feskhajm,Ilveskhajm,Ilwese,irufesuhaimu,yi er fei si hai mu,Ільфесгайм,Илвесхајм,Ильфесхайм,イルフェスハイム,伊尔费斯海姆', 49.4740400, 8.5674000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35825, 'Ilshofen', 'Ilshofen', 'Il''sgofen,Il''skhofen,Ilshofen,Ilskhofen,alshwfn,aylzhwfn,irusuhofen,yi er si huo fen,Ільсгофен,Илсхофен,Ильсхофен,إلسهوفن,ایلزهوفن,イルスホーフェン,伊尔斯霍芬', 49.1701500, 9.9182500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35826, 'Ilsfeld', 'Ilsfeld', 'Il''sfel''d,Ilsfeld,irusuferuto,yi er si fei er de,Ільсфельд,Илсфелд,Ильсфельд,イルスフェルト,伊尔斯费尔德', 49.0554800, 9.2459800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35827, 'Ilsenburg', 'Ilsenburg', 'Il''zenburg,Ilsenburg,Ilzenburg,alsnbwrgh,aylznbrg,yi er sen bu er ge,Илзенбург,Илсенбург,Ильзенбург,إلسنبورغ,ایلزنبرگ,伊尔森布尔格', 51.8669500, 10.6781700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35828, 'Ilmmünster', 'Ilmmunster', 'Il''mmjunster,Ilminster,aylmwnstr,yi er ming si te er,Ільммюнстер,Илминстер,Ильммюнстер,Իլմյունսթեր,ایلمونستر,伊尔明斯特尔', 48.4833300, 11.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35829, 'Ilmenau', 'Ilmenau', 'Il''menau,Ilmenau,Stadt Ilmenau,almynaw,aylmnaw,irumenau,yi er mo nao,Илменау,Ильменау,إلميناو,ایلمناو,イルメナウ,伊尔默瑙', 50.6832200, 10.9185800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35830, 'Illschwang', 'Illschwang', 'Il''shvang,Ill''shvang,Ilshvang,Ilsvang,yi er shi wang,Ільшванг,Илльшванг,Илшванг,Իլշվանգ,伊尔施旺', 49.4500000, 11.6833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35831, 'Illmensee', 'Illmensee', 'Il''menzee,Ill''menze,Ilmenze,yi er men sai,Ілльмензе,Илмензе,Ильмензее,伊尔门塞', 47.8622900, 9.3723500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35832, 'Illingen', 'Illingen', 'Ilingen,Illingen,Іллінген,Илинген,Иллинген', 49.3736200, 7.0475800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35833, 'Illingen', 'Illingen', '', 48.9561600, 8.9245900, 'DE', '2013-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35834, 'Illesheim', 'Illesheim', 'ILH,Ileshaym,Ileskhajm,Illesgajm,Illeskhajm,yi lai si hai mu,Іллесгайм,Илесхајм,Иллесхайм,Իլեսհայմ,伊莱斯海姆', 49.4802000, 10.3816500, 'DE', '2017-01-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35835, 'Illertissen', 'Illertissen', 'Ilertisen,Ilertiseno,Illertissen,alrtysn,aylrtysn,yi lai er di sen,Іллертіссен,Илертисен,Иллертиссен,Իլերթիսեն,إلرتيسن,ایلرتیسن,伊莱尔蒂森', 48.2233600, 10.1034700, 'DE', '2011-04-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35836, 'Illerrieden', 'Illerrieden', 'Ileriden,Illerriden,ilerideni,yi lai li deng,Іллерріден,Илериден,Иллерриден,Իլերիդեն,ილერიდენი,伊莱里登', 48.2701700, 10.0515500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35837, 'Illerich', 'Illerich', '', 50.2000000, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35838, 'Ilfeld', 'Ilfeld', 'Il''fel''d,Ilfeld,Ilfeld-Wiegersdorf,Илфелд,Ильфельд', 51.5757000, 10.7846900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35839, 'Ilbesheim', 'Ilbesheim', '', 49.6900000, 8.0752800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35840, 'Ilbesheim', 'Ilbesheim', 'Ibenstadt,Ilbesheim,Jlbesheim', 49.1827700, 8.0536300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35841, 'Ilberstedt', 'Ilberstedt', 'Ilberstedt', 51.8000000, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35842, 'Ihrlerstein', 'Ihrlerstein', 'Ihrlerstoa,Irlershtajn,Irlerstayn,yi er lai er si tai yin,Ірлерштайн,Ирлерштайн,Ирлерштајн,Իրլերշտայն,伊尔莱尔斯泰因', 48.9333300, 11.8666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35843, 'Ihringen', 'Ihringen', 'Ihringen,Iringen,Ірінген,Иринген,Իրինգեն', 48.0430300, 7.6476000, 'DE', '2013-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35844, 'Ihlow', 'Ihlow', '', 51.8671700, 13.3376900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35845, 'Ihlienworth', 'Ihlienworth', 'Gemeen Helmworth,Ilienvort,Ilinvort,yi lin wo er te,Илиенворт,Илинворт,伊林沃尔特', 53.7333300, 8.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35846, 'Iggingen', 'Iggingen', 'Iggingen,Igingen,igingeni,yi jin gen,Іггінген,Иггинген,Игинген,იგინგენი,伊金根', 48.8316700, 9.8789400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35847, 'Iggensbach', 'Iggensbach', 'Igensbakh,Igensbax,Iggensbakh,aygnsbakh,yi gen si ba he,Іггенсбах,Иггенсбах,Игенсбах,Իգենսբախ,ایگنسباخ,伊根斯巴赫', 48.7301400, 13.1422900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35848, 'Igersheim', 'Igersheim', 'Igersgajm,Igerskhajm,igasuhaimu,yi ge er si hai mu,Ігерсгайм,Игерсхайм,Игерсхајм,イガースハイム,伊格尔斯海姆', 49.4944400, 9.8169400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35849, 'Igensdorf', 'Igensdorf', 'Igensdorf,igensudorufu,yi gen si duo fu,Ігенсдорф,Игенсдорф,イゲンスドルフ,伊根斯多夫', 49.6232200, 11.2313700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35850, 'Igel', 'Igel', 'Igel,Igel'',igeli,yi ge er,Игел,Игель,იგელი,伊格尔', 49.7103300, 6.5549800, 'DE', '2015-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35851, 'Ifta', 'Ifta', 'Ifta,yi fu ta,Ифта,伊夫塔', 51.0666700, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35852, 'Iffezheim', 'Iffezheim', 'Ifeckhajm,Iffecgajm,Iffeckhajm,yi fei ci hai mu,Іффецгайм,Ифецхајм,Иффецхайм,伊费茨海姆', 48.8216700, 8.1431000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35853, 'Iffeldorf', 'Iffeldorf', 'Ifeldorf,Iffedorf,Iffel''dorf,ayfldwrf,ifferudorufu,yi fu er duo fu,Іффельдорф,Ифелдорф,Иффельдорф,Իֆելդորֆ,ایفلدورف,イッフェルドルフ,伊弗尔多夫', 47.7666700, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35854, 'Idstein', 'Idstein', 'Gorad Idshtajn,Idshhajn,Idshtajn,Idstayn,Idstein,adshtayn,aydashtayn,yi ci tai yin,İdştayn,Ідштайн,Горад Ідштайн,Идштайн,Идштајн,Идщайн,إدشتاين,ایداشتاین,伊茨泰因', 50.2177300, 8.2667900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35855, 'Idstedt', 'Idstedt', 'Idshtedt,Idshtet,Idstedt,Isted,yi ci te,Идштедт,Идштет,伊茨特', 54.5833300, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35856, 'Idesheim', 'Idesheim', '', 49.8755100, 6.5753900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35857, 'Idenheim', 'Idenheim', '', 49.9000000, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35858, 'Iden', 'Iden', '', 52.7798200, 11.9129600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35859, 'Idelberg', 'Idelberg', '', 50.7166700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35860, 'Idar-Oberstein', 'Idar-Oberstein', 'Idar-Obershhajn,Idar-Obershtajn,Idar-Oberstein,Idara-Obersteina,Idāra-Oberšteina,aydar-awbrashtayn,aydar-awbrshtayn,ida=obashutain,yi da er-ao bo shi tai yin,Идар-Оберштайн,Идар-Оберштајн,Идар-Оберщайн,إيدار-أوبرشتاين,ایدار-اوبراشتاین,იდარ-ობერშტაინი,イダー＝オーバーシュタイン,伊达尔-奥伯施泰因', 49.7144300, 7.3077600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35861, 'Icking', 'Icking', 'Iking,Ikking,aykyng,yi jing,Іккінг,Икинг,Иккинг,Իքինգ,ایکینگ,伊京', 47.9500000, 11.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35862, 'Ichtershausen', 'Ichtershausen', 'Ichtershausen,Ikhterskhauzen,yi xi te er si hao sen,Ихтерсхаузен,伊希特尔斯豪森', 50.8760200, 10.9702800, 'DE', '2012-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35863, 'Ichstedt', 'Ichstedt', 'Ichstedt', 51.3833300, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35864, 'Ichenhausen', 'Ichenhausen', 'Ikhengauzen,Ikhenkhauzen,Ixenhauzen,ashnhawzn,yi xing hao sen,Іхенгаузен,Ихенхаузен,Իխենհաուզեն,إشنهاوزن,ایشن‌هاوزن,伊兴豪森', 48.3711900, 10.3070600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35865, 'Ibbenbüren', 'Ibbenbueren', 'Ibbenbjuren,Ibbenbueren,Ibbenbüren,Ibenbiren,aybnbwrn,aynnbwrnn,yi ben bi lun,Іббенбюрен,Иббенбюрен,Ибенбирен,إيبنبورن,ایننبورنن,伊本比伦', 52.2796400, 7.7145700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35866, 'Ibach', 'Ibach', '', 47.7333300, 8.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35867, 'Huy-Neinstedt', 'Huy-Neinstedt', '', 51.9658500, 10.9145700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35868, 'Hüven', 'Hueven', 'Khiven,Khjufen,xu fen,Хивен,Хюфен,许芬', 52.7833300, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35869, 'Hüttlingen', 'Huttlingen', 'Huettlingen,Hüttlingen', 48.8926600, 10.1006400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35870, 'Hüttisheim', 'Huttisheim', 'Huettisheim,Hüttisheim', 48.2796500, 9.9424600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35871, 'Hutthurm', 'Hutthurm', 'Gutturm,Huading,Hutthurm,Hutthurm Markt,Khutturm,Khuturm,hu tu er mu,hwthwrn,Гуттурм,Хуттурм,Хутурм,Հութուրմ,هوتهورن,胡图尔姆', 48.6727600, 13.4714600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35872, 'Hütterscheid', 'Hutterscheid', '', 50.0000000, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35873, 'Hüttenrode', 'Huettenrode', 'Huettenroe,Huttenrode,Hüttenrode,Hüttenroe,Khitenrode,Khjuttenrode,Хитенроде,Хюттенроде', 51.7688000, 10.9038400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35874, 'Hütten', 'Hutten', 'Hutten,Hütten', 54.4333300, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35875, 'Hütten', 'Hutten', '', 50.0166700, 6.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35876, 'Hüttblek', 'Huttblek', 'Huettblek,Huttblek,Hüttblek', 53.8333300, 10.0666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35877, 'Hütschenhausen', 'Hutschenhausen', 'Huetschenhausen,Hütschenhausen', 49.4166700, 7.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35878, 'Husum', 'Husum', 'Guzum,Huesem,Husum,Hüsem,Khusum,Khuzum,QHU,hu su mu,hwswm,Гузум,Хузум,Хусум,هوسوم,胡苏姆', 54.4858000, 9.0523900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35879, 'Husum', 'Husum', 'Khusum,Khuzum,fuzumu,Хузум,Хусум,フーズム', 52.5666700, 9.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35880, 'Husby', 'Husby', 'Huesby,Hüsby', 54.7666700, 9.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35881, 'Hüsby', 'Husby', '', 54.5000000, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35882, 'Hürup', 'Hurup', 'Huerup,Hurup,Hyrup,Hürup,Khirup,Khjurup,xu lu pu,Хируп,Хюруп,许鲁普', 54.7500000, 9.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35883, 'Hürth', 'Huerth', 'Gjurt,Hiurtas,Huerth,Hürth,Khirt,Khjurt,ZNP,hwrt,xu er te,Гюрт,Хирт,Хюрт,هورت,许尔特', 50.8707900, 6.8676100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35884, 'Hürtgenwald', 'Hurtgenwald', 'Gjurtgenval''d,Huertgenwald,Hurtgenwald,Hürtgenwald,Khirtgenvald,Khjurtgenval''d,xu er te gen wa er de,Гюртгенвальд,Хиртгенвалд,Хюртгенвальд,许尔特根瓦尔德', 50.7166700, 6.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35885, 'Hurlach', 'Hurlach', 'Gurlakh,Hurlax,Khurlakh,fururahha,hu er la,hwrlakh,Гурлах,Хурлах,Հուրլախ,هورلاخ,フルラッハ,胡尔拉', 48.1183800, 10.8111500, 'DE', '2012-12-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35886, 'Hupperath', 'Hupperath', '', 50.0000000, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35887, 'Hunzel', 'Hunzel', '', 50.2490200, 7.8372900, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35888, 'Hünxe', 'Huenxe', 'Gjunkse,Huenxe,Hünxe,Khinkse,Khjunkse,xin ke sai,Гюнксе,Хинксе,Хюнксе,欣克塞', 51.6340500, 6.6974100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35889, 'Hungenroth', 'Hungenroth', '', 50.1333300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35890, 'Hungen', 'Hungen', 'Gungen,Khungen,fungen,hong gen,hwnghn,hwngn,Гунген,Хунген,هونغن,هونگن,フンゲン,洪根', 50.4736800, 8.8932600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35891, 'Hünfeld', 'Huenfeld', 'Gjunfel''d,Huenfeld,Hünfeld,Khinfeld,Khjunfel''d,Khjunfeld,hwinpelteu,hwnfld,xin fei er de,Гюнфельд,Хинфелд,Хюнфелд,Хюнфельд,هونفلد,欣费尔德,휜펠트', 50.6796600, 9.7672700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35892, 'Hundsdorf', 'Hundsdorf', '', 50.4700600, 7.7022000, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35893, 'Hundsbach', 'Hundsbach', 'Khundsbakh,hong ci ba he,Хундсбах,洪茨巴赫', 49.7166700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35894, 'Hundsangen', 'Hundsangen', 'Khundsangen,Khundzangen,hong can gen,Хундзанген,Хундсанген,洪灿根', 50.4500000, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35895, 'Hunding', 'Hunding', '', 48.8422700, 13.1768100, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35896, 'Hundhaupten', 'Hundhaupten', 'Hundhaupten', 50.8333300, 11.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35897, 'Hundeshagen', 'Hundeshagen', 'Hundeshagen,Khundeskhagen,hong de si ha gen,Хундесхаген,洪德斯哈根', 51.4333300, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35898, 'Hunderdorf', 'Hunderdorf', '', 48.8916200, 12.6738200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35899, 'Hunderdorf', 'Hunderdorf', 'Gunderdorf,Khunderdorf,hong de duo fu,hwndrdwrf,Гундердорф,Хундердорф,هوندردورف,洪德多夫', 48.9500000, 12.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35900, 'Humptrup', 'Humptrup', 'Humptrup', 54.8666700, 8.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35901, 'Hümpfershausen', 'Humpfershausen', 'Khimpferskhauzen,Khjumpferskhauzen,xin pu fei er si hao sen,Химпферсхаузен,Хюмпферсхаузен,欣普费尔斯豪森', 50.6666700, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35902, 'Hummelshain', 'Hummelshain', 'Hummelshain', 50.7666700, 11.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35903, 'Hummelsbüttel', 'Hummelsbuettel', '', 53.6477300, 10.0414900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35904, 'Hummelfeld', 'Hummelfeld', 'Hummelfeld', 54.4666700, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35905, 'Hümmel', 'Hummel', '', 50.4666700, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35906, 'Humboldtkolonie', 'Humboldtkolonie', 'Humboldt/Gremberg', 50.9318200, 6.9946900, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35907, 'Hülsede', 'Hulsede', 'Huelsede,Hülsede,Khilsede,Khjul''zede,hyuruzede,xu er sai de,Хилседе,Хюльзеде,ヒュルゼーデ,许尔塞德', 52.2495100, 9.3614700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35908, 'Hüllhorst', 'Huellhorst', 'Gjull''gorst,Huellhorst,Hüllhorst,Khilkhorst,Khjull''khorst,hyuruhorusuto,xu er huo er si te,Гюлльгорст,Хилхорст,Хюлльхорст,ヒュルホルスト,许尔霍尔斯特', 52.2833300, 8.6666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35909, 'Hülben', 'Hulben', 'Gjul''ben,Huelben,Hülben,Khilben,Khjul''ben,xu er ben,Гюльбен,Хилбен,Хюльбен,许尔本', 48.5198200, 9.4079000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35910, 'Huje', 'Huje', 'Huje', 53.9772300, 9.4344100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35911, 'Huisheim', 'Huisheim', 'Gujsgajm,Huyshaym,Khuiskhajm,Khujskhajm,hu yi si hai mu,hyusuhaimu,Гуйсгайм,Хуисхајм,Хуйсхайм,Հույսհայմ,ヒュースハイム,胡伊斯海姆', 48.8251000, 10.7033100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35912, 'Huglfing', 'Huglfing', '', 47.7666700, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35913, 'Hügelsheim', 'Hugelsheim', 'Gjugel''sgajm,Huegelsheim,Hugelsheim,Hügelsheim,Khigelskhajm,Khjugel''skhajm,xu ge er si hai mu,Гюгельсгайм,Хигелсхајм,Хюгельсхайм,许格尔斯海姆', 48.8000000, 8.1166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35914, 'Hüfingen', 'Hufingen', 'Gjufingen,Huefingen,Hüfingen,Khifingen,Khjufingen,hwfynghn,hwfyngn,xu fen gen,Гюфінген,Хифинген,Хюфинген,هوفينغن,هوفینگن,许芬根', 47.9254300, 8.4883100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35915, 'Hüffler', 'Huffler', 'Hueffler,Hüffler,Khifler,Khjufler,xu fu lai er,Хифлер,Хюфлер,许夫莱尔', 49.5000000, 7.3833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35916, 'Hüffenhardt', 'Huffenhardt', 'Gjuffengardt,Huffenhardt,Huffenhartheim,Hüffenhardt,Hüffenhartheim,Khifenkhardt,Khjuffenkhardt,hyuffenharuto,xu fen ha er te,Гюффенгардт,Хифенхардт,Хюффенхардт,ヒュッフェンハルト,许芬哈尔特', 49.2919400, 9.0816700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35917, 'Hüffelsheim', 'Hueffelsheim', 'Hueffelsheim,Hüffelsheim,Khifelskhajm,Khjuffel''skhajm,xu fei er si hai mu,Хифелсхајм,Хюффельсхайм,许费尔斯海姆', 49.8166700, 7.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35918, 'Hude', 'Hude', '', 54.3833300, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35919, 'Hude', 'Hude', 'Hude,Khude,Худе', 53.1076600, 8.4632200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35920, 'Huede', 'Huede', 'Hude,Huede,Hüde', 52.4958800, 8.3580400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35921, 'Hückeswagen', 'Hueckeswagen', 'Gjukkesvagen,Huckeswagen,Hueckeswagen,Hückeswagen,Khikesvagen,Khjukkesvagen,hwkswagn,hwkysfaghn,xu ke si wa gen,Гюккесваген,Хикесваген,Хюккесваген,هوكيسفاغن,هوکسواگن,许克斯瓦根', 51.1497900, 7.3447100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35922, 'Hückelhoven', 'Hueckelhoven', 'Gjukkel''gofen,Huckelhoven,Hueckelhoven,Hukkelhaove,Hückelhoven,Khikelkhoven,Khjukkel''khofen,hwklhwfn,xu ke er huo fen,Гюккельгофен,Хикелховен,Хюккельхофен,هوكلهوفن,هوکلهوفن,许克尔霍芬', 51.0555000, 6.2265800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35923, 'Hüblingen', 'Hublingen', '', 50.5666700, 8.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35924, 'Hübingen', 'Huebingen', '', 50.3586100, 7.8461100, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35925, 'Hoym', 'Hoym', '', 51.7829200, 11.3124400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35926, 'Hoyerswerda', 'Hoyerswerda', 'Goersverda,Hojerice,Hojersverda,Hojeřice,Hoyerswerda,Hoyerswerda/Wojerecy,Hoyerwerda,Khojersverda,Wojerce,Wojerecy,Worjejce,Wórjejce,hoierusuvu~eruda,huo ye si wei da,hwyrsfyrda,khwyrzwrda,Гоєрсверда,Хойерсверда,Хојерсверда,خویرزوردا,هويرسفيردا,ホイエルスヴェルダ,霍耶斯韦达', 51.4378700, 14.2354900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35927, 'Hoyershausen', 'Hoyershausen', 'Khojerskhauzen,huo yi er si hao sen,Хойерсхаузен,Хојерсхаузен,霍伊尔斯豪森', 52.0188600, 9.7534600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35928, 'Hoyerhagen', 'Hoyerhagen', '', 52.8333300, 9.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35929, 'Hoya', 'Hoya', 'Hoya,Hoya an Weser,Khoja,Khojja,hoya,hwya,hwya  alman,qiu lan shu,Хойа,Хойя,Хоя,Хоја,هويا,هویا، آلمان,ホーヤ,球兰属', 52.8078100, 9.1402800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35930, 'Höxter', 'Hoexter', 'Hoexter,Hoxaria,Huscaria,Huxaria,Huxori,Höxter,Khekster,Khjokster,he ke si te er,hwkstr,Хекстер,Хёкстер,هوکستر,赫克斯特尔', 51.7750100, 9.3815500, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35931, 'Hövelhof', 'Hovelhof', 'Gefel''gof,Hoevelhof,Hovelhof,Hövelhof,Khevelkhof,Khjofel''khof,he fei er huo fu,Гефельгоф,Хевелхоф,Хёфельхоф,赫费尔霍夫', 51.8166700, 8.6500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35932, 'Hövede', 'Hoevede', 'Hovede,Hövede', 54.2500000, 9.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35933, 'Höttingen', 'Hottingen', 'Gettingen,Hoettingen,Höttingen,Khetingen,Khjottingen,he ting gen,Геттінген,Хетинген,Хёттинген,Հյոթինգեն,赫廷根', 49.0626200, 11.0053000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35934, 'Hottenbach', 'Hottenbach', 'Khotenbakh,Khottenbakh,huo teng ba he,Хотенбах,Хоттенбах,霍滕巴赫', 49.8249200, 7.2976000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35935, 'Hötensleben', 'Hotensleben', 'Hoetensleben,Hoitenslewwe,Hokinaslofu,Hokinaslouu,Hokinasloŭu,Hokinasluvu,Hokinnesleuo [a. 1016],Hokinnesleŭo [a. 1016],Hoszensleue [a. 1226],Hoszensleŭe [a. 1226],Hottensleve [a. 1311],Hozeneslove [~a. 1150],Hötensleben,Hōkinasluvu,Khetensleben,Khjotensleben,he teng si lai ben,Хетенслебен,Хётенслебен,赫滕斯莱本', 52.1197400, 11.0223800, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35936, 'Hostenbach', 'Hostenbach', '', 49.2637600, 6.8143900, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35937, 'Hosten', 'Hosten', '', 49.9000000, 6.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35938, 'Hoßkirch', 'Hosskirch', 'Goskirkh,Hooskirch,Hosskirch,Hoßkirch,Khoskirkh,huo si ji er xi,hwskyrsh,Госкірх,Хоскирх,هوسکیرش,霍斯基尔希', 47.9500000, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35939, 'Höslwang', 'Hoslwang', 'Hoeslwang,Höslwang', 47.9537800, 12.3291500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35940, 'Hosenfeld', 'Hosenfeld', 'Gozenfel''d,Khosenfeld,Khozenfel''d,huo sen fei er de,Гозенфельд,Хозенфельд,Хосенфелд,霍森费尔德', 50.5050200, 9.4796600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35941, 'Hösbach', 'Hosbach', 'Gesbakh,Hoesbach,Hosbach,Hyosbax,Hösbach,Khesbakh,Khjosbakh,he si ba he,hesubahha,Гесбах,Хесбах,Хёсбах,Հյոսբախ,ヘスバッハ,赫斯巴赫', 50.0064600, 9.2076500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35942, 'Hörup', 'Hoerup', 'Hoerup,Horup,Hörup', 54.7426800, 9.1024200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35943, 'Horstmar', 'Horstmar', 'Gorstmar,Khorstmar,huo er si te ma er,hwrstmar,Горстмар,Хорстмар,هورستمار,霍尔斯特马尔', 52.0809800, 7.3053900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35944, 'Hörsten', 'Horsten', '', 54.2333300, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35945, 'Hörstel', 'Hoerstel', 'Gerstel'',Hoerstel,Horstel,Hörstel,Kherstel,Khjorstel'',he er si te er,hwrstl,Герстель,Херстел,Хёрстель,هورستل,赫尔斯特尔', 52.2976300, 7.5838200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35946, 'Horstedt', 'Horstedt', '', 54.5249400, 9.0665100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35947, 'Horstedt', 'Horstedt', '', 53.1833300, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35948, 'Horst', 'Horst', 'Horst', 53.8119500, 9.6230700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35949, 'Hörselgau', 'Hoerselgau', 'Hoerselgau,Horselgau,Hörselgau,Kherselgau,Kherzelgau,Khjorzel''gau,he se er gao,Херзелгау,Херселгау,Хёрзельгау,赫瑟爾高', 50.9198800, 10.5844400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35950, 'Hörschhausen', 'Hoerschhausen', '', 50.2500000, 6.9333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35951, 'Hörscheid', 'Horscheid', '', 50.2166700, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35952, 'Horschbach', 'Horschbach', 'Khorshbakh,huo er shi ba he,Хоршбах,霍尔施巴赫', 49.5833300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35953, 'Horrweiler', 'Horrweiler', '', 49.9000000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35954, 'Horrenberg', 'Horrenberg', '', 49.2804000, 8.7808700, 'DE', '2010-11-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35955, 'Horperath', 'Horperath', '', 50.2500000, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35956, 'Hornstorf', 'Hornstorf', 'Hornstorf', 53.9099400, 11.5321400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35957, 'Hornsömmern', 'Hornsommern', '', 51.2166700, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35958, 'Hörnsheim', 'Hoernsheim', '', 50.5182800, 8.6297600, 'DE', '2013-01-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35959, 'Hornhausen', 'Hornhausen', 'Hornhausen', 52.0451000, 11.1710400, 'DE', '2011-06-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35960, 'Horneburg', 'Horneburg', '', 53.5067200, 9.5754600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35961, 'Hornburg', 'Hornburg', 'Hornburg', 52.0309500, 10.6049000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35962, 'Hornberg', 'Hornberg', 'Gornberg,Hornberg,Khornberg,huo en bei ge,hwrnbrg,hwrnbrgh,Горнберг,Хорнберг,هورنبرغ,هورنبرگ,霍恩贝格', 48.2106800, 8.2327500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35963, 'Hornbek', 'Hornbek', 'Hornbek', 53.5666700, 10.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35964, 'Horn-Bad Meinberg', 'Horn-Bad Meinberg', 'Horn-Bad Meinberg,Khorn-Bad Majnberg,Хорн-Бад Майнберг', 51.8855000, 8.9624400, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35965, 'Hornbach', 'Hornbach', 'Hornbach,Khornbakh,horunbahha,huo en ba he,hwrnbakh,Хорнбах,هورنباخ,ホルンバッハ,霍恩巴赫', 49.1877800, 7.3688300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35966, 'Horn', 'Horn', 'Haeoern,Horn,Horn (Horn-Bad Meinberg),Hornon,Häoern', 51.8715100, 8.9451000, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35967, 'Horn', 'Horn', '', 50.0500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35968, 'Hormersdorf', 'Hormersdorf', 'Hormersdorf', 50.6740600, 12.8819400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35969, 'Horka', 'Horka', 'Horka', 51.3000000, 14.9000000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35970, 'Horka', 'Horka', 'Horki,Hórki', 51.2634200, 14.2552300, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35971, 'Höringen', 'Hoeringen', '', 49.5556600, 7.7960200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35972, 'Horhausen', 'Horhausen', '', 50.5874500, 7.5302800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35973, 'Horhausen', 'Horhausen', '', 50.3666700, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35974, 'Hörgertshausen', 'Horgertshausen', 'Gergertsgauzen,Khergertskhauzen,Khjorgertskhauzen,he er ge er ci hao sen,Гергертсгаузен,Хергертсхаузен,Хёргертсхаузен,Հյորգերթսհաուզեն,赫尔格尔茨豪森', 48.5500000, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35975, 'Horgenzell', 'Horgenzell', 'Gorgencell'',Khorgencel,Khorgencell'',huo er gen ce er,Горгенцелль,Хоргенцел,Хоргенцелль,霍尔根策尔', 47.8000000, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35976, 'Horgau', 'Horgau', 'Gorgau,Horgau,Khorgau,huo er gao,Горгау,Хоргау,Հորգաու,霍尔高', 48.3950700, 10.6828300, 'DE', '2012-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35977, 'Hördt', 'Hordt', 'Hoerdt,Hördt,Kherdt,Khjordt,Хердт,Хёрдт', 49.1658300, 8.3263900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35978, 'Hörden', 'Hoerden', 'Hoerden am Harz,Huern,Hörden am Harz,Hürn', 51.6683500, 10.2837200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35979, 'Horbruch', 'Horbruch', '', 49.8833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35980, 'Horben', 'Horben', 'Gorben,Horben,Khorben,huo er ben,Горбен,Хорбен,Հորբեն,霍尔本', 47.9333300, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35981, 'Horb am Neckar', 'Horb am Neckar', 'Gorb-am-Nekkar,Horb,Khorb am Nekar,Khorb-am-Nekkar,Khorb-na-Nekkare,hrb am nka,hwrb am nykar,nei ka he pan huo er bu,Горб-ам-Неккар,Хорб ам Некар,Хорб-ам-Неккар,Хорб-на-Неккаре,Նեքարի Հորբ,هرب ام نکا,هورب آم نيكار,内卡河畔霍尔布', 48.4442300, 8.6913000, 'DE', '2014-07-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35982, 'Horbach', 'Horbach', '', 50.3730600, 7.8527800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35983, 'Horbach', 'Horbach', '', 49.8166700, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35984, 'Horbach', 'Horbach', '', 49.3333300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35985, 'Horath', 'Horath', '', 49.8108500, 6.9859300, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35986, 'Hopsten', 'Hopsten', 'Gopsten,Khopsten,huo pu si teng,hwbstn,Гопстен,Хопстен,هوبستن,霍普斯滕', 52.3817000, 7.6015600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35987, 'Hoppstädten', 'Hoppstadten', 'Hoppstaedten,Hoppstädten,Khopshtedten,Khopshteten,huo pu si te teng,Хопштедтен,Хопштетен,霍普斯特滕', 49.7000000, 7.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35988, 'Hoppegarten', 'Hoppegarten', 'Hopegarten,Khopegarten,Khoppegarten,huo pei jia er teng,Хопегартен,Хоппегартен,Հոպեգարտեն,霍佩加尔滕', 52.5166700, 13.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35989, 'Höpfingen', 'Hopfingen', 'Gepfingen,Hoepfingen,Höpfingen,Khepfingen,Khjopfingen,he pu fen gen,hepufingen,Гепфінген,Хепфинген,Хёпфинген,ヘプフィンゲン,赫普芬根', 49.6025000, 9.4286100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35990, 'Hopfgarten', 'Hopfgarten', '', 50.9863100, 11.2231100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35991, 'Hopferau', 'Hopferau', '', 47.6166700, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35992, 'Hoogstede', 'Hoogstede', 'Khogshtede,Khogstede,huo ge si te de,Хогстеде,Хогштеде,霍格斯特德', 52.5833300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35993, 'Hontheim', 'Hontheim', '', 50.0666700, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35994, 'Hönningen', 'Honningen', '', 50.4666700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35995, 'Honigsee', 'Honigsee', 'Honigsee', 54.2333300, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35996, 'Honerath', 'Honerath', '', 50.3833300, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35997, 'Hommerdingen', 'Hommerdingen', 'Homerdingen,Hommerdingen', 49.9166700, 6.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35998, 'Homburg', 'Homburg', 'Homburg', 49.3263700, 7.3386700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(35999, 'Homberg', 'Homberg', '', 51.0299400, 9.4026100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36000, 'Homberg', 'Homberg', 'Gomberg,Hoemberg,Homberg,Homberg an der Ohm,Hömberg,Khomberg,homuberuku,hwmbrg,hwmbrgh,Гомберг,Хомберг,هومبرغ,هومبرگ,ホムベルク', 50.7310800, 8.9964400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36001, 'Homberg', 'Homberg', '', 50.6422200, 8.1063900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36002, 'Hömberg', 'Homberg', '', 50.3333300, 7.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36003, 'Homberg', 'Homberg', 'Khomberg,Хомберг', 49.6500000, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36004, 'Holzwickede', 'Holzwickede', 'Gol''cvikkede,Khol''cvikkede,Kholcvikede,huo er ci wei ke de,Гольцвіккеде,Холцвикеде,Хольцвиккеде,霍尔茨维克德', 51.5000000, 7.6333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36005, 'Holzweißig', 'Holzweissig', 'Holzweiddig,Holzweissig,Holzweisslig,Holzweißig,Holzweißlig', 51.5981900, 12.3084200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36006, 'Holzsußra', 'Holzsussra', 'Holzsussra,Holzsußra', 51.2833300, 10.6833300, 'DE', '2017-06-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36007, 'Holzminden', 'Holzminden', 'Holtisminni,Holtsminne,Khol''cminden,Kholcminden,horutsuminden,huo er ci ming deng,hwltsmyndn,Холцминден,Хольцминден,هولتسميندن,هولتسمیندن,ホルツミンデン,霍尔茨明登', 51.8279800, 9.4455000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36008, 'Holzmaden', 'Holzmaden', 'Gol''cmaden,Holzmaden,Khol''cmaden,Kholcmaden,huo er ci ma deng,Гольцмаден,Холцмаден,Хольцмаден,Հոլցմադեն,霍尔茨马登', 48.6333300, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36009, 'Holzkirchen', 'Holzkirchen', 'Gol''ckirkhen,Khol''ckirkhen,Kholckirkhen,horutsukiruhyen,Гольцкірхен,Холцкирхен,Хольцкирхен,Հոլցկիրխեն,ホルツキルヒェン', 49.7813900, 9.6802800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36010, 'Holzkirchen', 'Holzkirchen', 'Gol''ckirkhen,Hoizkiacha,Khol''ckirkhen,Kholckirkhen,huo er ci ji xing,hwlts kyrshn,Гольцкірхен,Холцкирхен,Хольцкирхен,هولتس کیرشن,霍尔茨基兴', 47.8766300, 11.7018100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36011, 'Holzkirch', 'Holzkirch', '', 48.5312400, 9.9952000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36012, 'Holzheim', 'Holzheim', '', 50.3544800, 8.0483000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36013, 'Holzheim', 'Holzheim', '', 48.6111600, 10.9483700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36014, 'Holzheim', 'Holzheim', '', 48.5142200, 10.5305700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36015, 'Holzheim', 'Holzheim', '', 48.3833300, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36016, 'Holzhausen an der Haide', 'Holzhausen an der Haide', 'Holzhausen,Holzhausen an der Haide,Khol''ckhauzen-an-der-Khajde,Kholckhauzen na Khajdi,hai de de qu huo er ci hao sen,hwltshawzn an dr haydh,Холцхаузен на Хајди,Хольцхаузен-ан-дер-Хайде,هولتسهاوزن آن در هایده,海德地区霍尔茨豪森', 50.2185500, 7.9097300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36017, 'Bad Holzhausen', 'Bad Holzhausen', '', 52.2897100, 8.5395400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36018, 'Holzgünz', 'Holzguenz', 'Gol''cgjunc,Holzguenz,Holzgünz,Khol''cgjunc,Kholcginc,huo er ci jin ci,Гольцгюнц,Холцгинц,Хольцгюнц,Հոլցգյունց,霍尔茨金茨', 48.0250300, 10.2590100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36019, 'Holzgerlingen', 'Holzgerlingen', 'Gol''cgerlingen,Khol''cgerlingen,Kholcgerlingen,holtsgerlingeni,huo er ci ge er lin gen,hwltsghyrlynghn,hwlzgrlyngn,Гольцгерлінген,Холцгерлинген,Хольцгерлинген,Հոլցգերլինգեն,هولتسغيرلينغن,هولزگرلینگن,ჰოლცგერლინგენი,霍尔茨格尔林根', 48.6396900, 9.0114900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36020, 'Holzen', 'Holzen', '', 51.9333300, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36021, 'Holzdorf', 'Holzdorf', '', 54.5500000, 9.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36022, 'Holzdorf', 'Holzdorf', 'Holzdorf', 51.7787300, 13.1275600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36023, 'Holzbunge', 'Holzbunge', 'Holzbunge', 54.3833300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36024, 'Holzbach', 'Holzbach', '', 49.9500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36025, 'Holzappel', 'Holzappel', 'Holzappel,Khol''cappel'',Kholcapel,huo er cha pei er,Холцапел,Хольцаппель,霍尔察佩尔', 50.3500000, 7.9000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36026, 'Holtsee', 'Holtsee', 'Holtsee', 54.4000000, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36027, 'Holtland', 'Holtland', 'Khol''tland,Kholtland,huo er te lan,Холтланд,Хольтланд,霍尔特兰', 53.2833300, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36028, 'Holtgast', 'Holtgast', 'Khol''tgast,Kholtgast,huo er te jia si te,Холтгаст,Хольтгаст,霍尔特加斯特', 53.6299400, 7.5752000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36029, 'Holt', 'Holt', '', 54.8166700, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36030, 'Holsthum', 'Holsthum', 'Khol''stum,Kholstum,huo er si tu mu,Холстум,Хольстум,霍尔斯图姆', 49.8935300, 6.4127500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36031, 'Holstenniendorf', 'Holstenniendorf', 'Holstenniendorf', 54.0416100, 9.3480800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36032, 'Holm', 'Holm', '', 54.8333300, 8.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36033, 'Holm', 'Holm', 'Khol''m,Kholm,Холм,Хольм', 53.6166700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36034, 'Hollstadt', 'Hollstadt', 'Gol''shtadt,Kholl''shtadt,Kholshtat,huo er si ta te,Гольштадт,Холльштадт,Холштат,Հոլշթաթ,霍尔斯塔特', 50.3500000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36035, 'Hollnseth', 'Hollnseth', '', 53.5833300, 9.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36036, 'Hollnich', 'Hollnich', '', 50.0666700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36037, 'Hollingstedt', 'Hollingstedt', '', 54.4593400, 9.3369500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36038, 'Hollingstedt', 'Hollingstedt', '', 54.2903100, 9.2252100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36039, 'Hollfeld', 'Hollfeld', 'Gol''fel''d,Holfeld,Hollfeld,Kholfeld,Kholl''fel''d,horuferuto,huo er fei er de,hwlfld,Гольфельд,Холльфельд,Холфелд,Հոլֆելդ,هولفلد,ホルフェルト,霍尔费尔德', 49.9379300, 11.2915300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36040, 'Holler', 'Holler', '', 50.4166700, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36041, 'Hollenstedt', 'Hollenstedt', 'Gemeen Hullnst,Hollenstedt,Kholenshtet,Khollenshtedt,huo lun si te,Холенштет,Холленштедт,霍伦斯特', 53.3666700, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36042, 'Hollenbek', 'Hollenbek', '', 53.5911900, 10.8203200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36043, 'Hollenbach', 'Hollenbach', '', 48.4833300, 11.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36044, 'Holleben', 'Holleben', '', 51.4404700, 11.8991500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36045, 'Holle', 'Holle', 'Khole,Kholle,huo lai,Холе,Холле,霍莱', 52.0872100, 10.1601200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36046, 'Holenberg', 'Holenberg', '', 51.9166700, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36047, 'Holdorf', 'Holdorf', 'Holdorf', 52.5833300, 8.1166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36048, 'Hoisdorf', 'Hoisdorf', 'Hoisdorf', 53.6500000, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36049, 'Höingen', 'Hoeingen', '', 50.7191000, 8.9196100, 'DE', '2012-01-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36050, 'Höhr-Grenzhausen', 'Hoehr-Grenzhausen', 'Grenzhausen,Hoehr-Grenzhausen,Hohr-Grenzhausen,Höhr-Grenzhausen,Kher-Grenckhauzen,Khjor-Grenckhauzen,he he er-ge lun ci hao sen,heru=gurentsuhauzen,hwhr-grnzhawzn,hwr-ghrntshawzn,Хер-Гренцхаузен,Хёр-Гренцхаузен,هور-غرنتسهاوزن,هوهر-گرنزهاوزن,ヘール＝グレンツハウゼン,赫赫尔-格伦茨豪森', 50.4347400, 7.6690300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36051, 'Hohnstein', 'Hohnstein', '', 50.9799100, 14.1140800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36052, 'Höhnstedt', 'Hoehnstedt', 'Hoehnstedt,Hohnstedt,Höhnstedt', 51.5026800, 11.7384400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36053, 'Hohnhorst', 'Hohnhorst', 'Khonkhorst,honhorusuto,huo en huo er si te,Хонхорст,ホーンホルスト,霍恩霍尔斯特', 52.3694200, 9.3716800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36054, 'Hohne', 'Hohne', 'Khone,huo nei,Хоне,霍内', 52.5872300, 10.3760100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36055, 'Höhndorf', 'Hohndorf', '', 54.3666700, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36056, 'Hohndorf', 'Hohndorf', 'Hoehndorf,Höhndorf', 50.7404400, 12.6805800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36057, 'Hohn', 'Hohn', '', 54.3000000, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36058, 'Höhfröschen', 'Hohfroschen', '', 49.2500000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36059, 'Hohenwestedt', 'Hohenwestedt', 'Hohenwestedt,Khoehnveshtedt,Khoenveshtet,huo heng wei si te,Хоенвештет,Хоэнвештедт,霍亨韦斯特', 54.0888600, 9.6535900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36060, 'Hohenwarthe', 'Hohenwarthe', 'Hohenwarthe', 52.2296800, 11.7152800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36061, 'Hohenwarth', 'Hohenwarth', '', 49.2000000, 12.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36062, 'Hohenwarte', 'Hohenwarte', 'Hohenwarte', 50.6000000, 11.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36063, 'Hohenwarsleben', 'Hohenwarsleben', '', 52.1789800, 11.4999400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36064, 'Hohenthurm', 'Hohenthurm', 'Hohenthurm,Hohenturn', 51.5180700, 12.0974900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36065, 'Hohenthann', 'Hohenthann', 'Goentann,Hohentan,Hohenthann,Khoehntann,Khoentan,huo heng tan,hwhntan,Гоентанн,Хоентан,Хоэнтанн,Հոհենթան,هوهنتان,霍亨坦', 48.6611500, 12.0925100, 'DE', '2013-02-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36066, 'Hohentengen', 'Hohentengen', '', 48.0294600, 9.3773900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36067, 'Hohentengen am Hochrhein', 'Hohentengen am Hochrhein', 'Goentengen-am-Gokhrajn,Hohentengen,Hohentengen am Hochrhein,Khoehntengen,Khoentengen am Khokhrajn,huo heng teng gen a mu huo he lai yin,Гоентенген-ам-Гохрайн,Хоентенген ам Хохрајн,Хоэнтенген,霍亨滕根阿姆霍赫赖因', 47.5700500, 8.4325000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36068, 'Hohen-Sülzen', 'Hohen-Sulzen', 'Hohen-Suelzen,Hohen-Sülzen', 49.6191700, 8.2255600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36069, 'Hohenstein-Ernstthal', 'Hohenstein-Ernstthal', 'Goenshtajn-Ernsttal'',Hoensteina-Ernstale,Hoenšteina-Ernstāle,Hohenstein-Ernstthal,Khoehnshtajn-Ehrnsttal'',Khoenshtajn-Ernstal,huo heng si tai yin-ai er en si ta er,hwynshtayn-arnstal,Гоенштайн-Ернстталь,Хоенштајн-Ернстал,Хоэнштайн-Эрнстталь,هوهن‌اشتاین-ارنشتال,هوينشتاين-إرنستال,霍亨斯泰因-埃尔恩斯塔尔', 50.8006400, 12.7128700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36070, 'Hohenstadt', 'Hohenstadt', 'Goenshtadt,Hohenstadt an der Alb,Khoehnshtadt,Khoenshtat,huo heng si ta te,Гоенштадт,Хоенштат,Хоэнштадт,霍亨斯塔特', 48.5444000, 9.6639300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36071, 'Hohenroth', 'Hohenroth', 'Goenrot,Hohenroth,Khoehnrot,Khoenrot,huo heng luo te,Гоенрот,Хоенрот,Хоэнрот,Հոենրոթ,霍亨罗特', 50.3166700, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36072, 'Hohenpolding', 'Hohenpolding', 'Goenpol''ding,Khoehnpol''ding,Khoenpolding,huo heng bo er ding,hwhn pwldyng,Гоенпольдінг,Хоенполдинг,Хоэнпольдинг,هوهن پولدینگ,霍亨波尔丁', 48.3833300, 12.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36073, 'Hohenpeißenberg', 'Hohenpeissenberg', 'Goenpajsenberg,Hoachapeissaberg,Hoachapeißaberg,Hoenpaysenberg,Hohenpeissenberg,Hohenpeißenberg,Khoehnpajsenberg,Khoehnpajssenberg,Khoenpajsenberg,hoenpaisenberuku,huo en pai sen bei ge,hwhn paysnbrg,Гоенпайсенберг,Хоенпајсенберг,Хоэнпайсенберг,Хоэнпайссенберг,Հոենպայսենբերգ,هوهن پایسنبرگ,ホーエンパイセンベルク,霍恩派森贝格', 47.8000000, 11.0000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36074, 'Hohenölsen', 'Hohenoelsen', 'Hohenolsen,Hohenölsen', 50.7415300, 12.0858300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36075, 'Hohenöllen', 'Hohenollen', 'Khoehnjollen,Khoenelen,huo hei nei lun,Хоенелен,Хоэнёллен,霍黑内伦', 49.6166700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36076, 'Hohen Neuendorf', 'Hohen Neuendorf', 'Goen-Noendorf,Hohen Neuendorf,Hohen Noyendorf,Khoehn-Nojendorf,Khoen Nojendorf,huo heng nuo yi en duo fu,hwhn nwyndwrf,hwyn nwyndwrf,Гоен-Ноєндорф,Хоен Нојендорф,Хоэн-Нойендорф,Հոհեն Նոյենդորֆ,هوهن نویندورف,هوين نويندورف,霍亨诺伊恩多夫', 52.6763100, 13.2777500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36077, 'Hohenmölsen', 'Hohenmoelsen', 'Hohenmoelsen,Hohenmolsen,Hohenmölsen,Khoehnmjol''zen,Khoenmelzen,huo heng mo er sen,hwhnmwlzn,Хоенмелзен,Хоэнмёльзен,هوهنمولزن,霍亨默尔森', 51.1576900, 12.1000000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36078, 'Hohenlockstedt', 'Hohenlockstedt', 'Hohenlockstedt,Khoehnlokshtedt,Khoenlokshtet,Lockstedter Lager,huo heng luo ke si te,Хоенлокштет,Хоэнлокштедт,霍亨洛克斯特', 53.9666700, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36079, 'Hohenlinden', 'Hohenlinden', 'Goenlinden,Khoehnlinden,Khoenlinden,huo heng lin deng,hwhn lyndn,Гоенлінден,Хоенлинден,Хоэнлинден,هوهن لیندن,霍亨林登', 48.1561200, 11.9945800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36080, 'Hohenleuben', 'Hohenleuben', 'Hohenleuben,Khoehnlojben,Khoenlojben,huo heng luo yi ben,hwhnlwybn,hwynlwybn,Хоенлојбен,Хоэнлойбен,هوهنلویبن,هوينلويبن,霍亨洛伊本', 50.7112800, 12.0542700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36081, 'Hohenleipisch', 'Hohenleipisch', 'Hoenlaypis,Hohenleipisch,Khoehnlajpish,Khoenlajpish,huo heng lai pi shi,Хоенлајпиш,Хоэнлайпиш,Հոենլայպիշ,霍亨莱皮施', 51.5000000, 13.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36082, 'Hohenleimbach', 'Hohenleimbach', 'Hohenleimbach,Leimbach', 50.4166700, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36083, 'Hohenkirchen', 'Hohenkirchen', '', 50.8500000, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36084, 'Hohenkammer', 'Hohenkammer', 'Goenkammer,Hohen Cammer,Hohenkamer,Hohenkammer,Khoehnkammer,Khoenkamer,huo heng ka mei er,hwhn kamr,Гоенкаммер,Хоенкамер,Хоэнкаммер,Հոհենկամեր,هوهن کامر,霍亨卡梅尔', 48.4240600, 11.5252200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36085, 'Hohenhorn', 'Hohenhorn', '', 53.4764700, 10.3646000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36086, 'Hohenhameln', 'Hohenhameln', 'Khoehnkhamel''n,Khoenkhameln,huo en ha mo er en,Хоенхамелн,Хоэнхамельн,霍恩哈默尔恩', 52.2575500, 10.0641600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36087, 'Hohengandern', 'Hohengandern', 'Hohengandern,Khoehngandern,Khoengandern,huo heng gan de er en,Хоенгандерн,Хоэнгандерн,霍亨甘德尔恩', 51.3733600, 9.9477600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36088, 'Hohenfurch', 'Hohenfurch', 'Hohenfurch,Hohenfurth', 47.8500000, 10.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36089, 'Hohenfinow', 'Hohenfinow', 'Hohenfinov,Khoehnfinov,Khoenfinov,huo heng fei nuo,Хоенфинов,Хоэнфинов,Հոհենֆինով,霍亨菲诺', 52.8134000, 13.9249100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36090, 'Hohenfels', 'Hohenfels', 'Goenfel''s,Hohenfels,Khoehnfel''s,Khoenfels,Гоенфельс,Хоенфелс,Хоэнфельс,Հոհենֆելս', 49.2039700, 11.8484100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36091, 'Hohenfelden', 'Hohenfelden', 'Khoehnfel''den,Khoenfelden,huo heng fei er deng,Хоенфелден,Хоэнфельден,霍亨费尔登', 50.8785300, 11.1605600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36092, 'Hohenfelde', 'Hohenfelde', '', 54.3666700, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36093, 'Hohenfelde', 'Hohenfelde', '', 53.8432400, 9.6225800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36094, 'Hohenfelde', 'Hohenfelde', '', 53.6333300, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36095, 'Hohendodeleben', 'Hohendodeleben', 'Dodoleiba [a. 937],Dolae,Dolä,Ho''endo''lae,Hohendodeleben,Ho’endo’lä,Khoehndodeleben,Tudolon australis,Хоэндоделебен', 52.1041200, 11.5047300, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36096, 'Hohenburg', 'Hohenburg', 'Goenburg,Hohenburg,Khoehnburg,Khoenburg,huo heng bao,Гоенбург,Хоенбург,Хоэнбург,Հոհենբուրգ,霍亨堡', 49.2950700, 11.7990600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36097, 'Hohenbucko', 'Hohenbucko', '', 51.7666700, 13.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36098, 'Hohenbrunn', 'Hohenbrunn', 'Goenbrunn,Hohenbrun,Khoehnbrunn,Khoenbrun,huo heng bu lun,hwhn brwn,Гоенбрунн,Хоенбрун,Хоэнбрунн,Հոհենբրուն,هوهن برون,霍亨布伦', 48.0478500, 11.7022400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36099, 'Hohenbocka', 'Hohenbocka', 'Bukow,Hohenboka,Khoehnboka,Khoenboka,huo heng bo ka,Хоенбока,Хоэнбока,Հոհենբոկա,霍亨博卡', 51.4309900, 14.0098200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36100, 'Hohenberg-Krusemark', 'Hohenberg-Krusemark', 'Hohenberg,Hohenberg-Krusemark,Khoehnberg-Kruzemark,Khoenberg-Krusemark,Khoenberg-Kruzemark,huo en bei ge-ke lu se ma ke,Хоенберг-Круземарк,Хоенберг-Крусемарк,Хоэнберг-Круземарк,霍恩贝格-克鲁瑟马克', 52.7249100, 11.9471200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36101, 'Hohenberg an der Eger', 'Hohenberg an der Eger', 'Egeri Hoenberg,Goenberg-an-der-Eger,Hohenberg,Hohenberg an der Eger,Khoehnberg--na-Ehgere,Khoehnberg-na-Ehgere,Khoenberg an der Eger,ai ge er he pan huo heng bei ge,hwhnbrg an dr agr,hwynbrgh an dr ayghr,Гоенберг-ан-дер-Егер,Хоенберг ан дер Егер,Хоэнберг--на-Эгере,Хоэнберг-на-Эгере,Էգերի Հոենբերգ,هوهنبرگ ان در اگر,هوينبرغ أن در إيغر,ホーエンベルク・アン・デア・エーゲル,埃格尔河畔霍亨贝格', 50.0950100, 12.2200800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36102, 'Höhenberg', 'Hoehenberg', '', 50.9332300, 7.0413800, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36103, 'Hohenaspe', 'Hohenaspe', 'Hohenasbe,Hohenaspe', 53.9889800, 9.5277400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36104, 'Hohenaltheim', 'Hohenaltheim', 'Goenal''tgajm,Khoehnal''tajm,Khoehnal''tkhajm,Khoenaltkhajm,hoen''arutohaimu,huo hei na er tai mu,Гоенальтгайм,Хоеналтхајм,Хоэнальтайм,Хоэнальтхайм,Հոենալթհայմ,ホーエンアルトハイム,霍黑纳尔泰姆', 48.7840200, 10.5348600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36105, 'Höheischweiler', 'Hoheischweiler', '', 49.2333300, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36106, 'Höheinöd', 'Hoeheinoed', 'Hoeheinoed,Höheinöd', 49.2896600, 7.6067300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36107, 'Hohburg', 'Hohburg', '', 51.4116800, 12.8050800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36108, 'Hohberg', 'Hohberg', '', 48.3227000, 7.8997200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36109, 'Högsdorf', 'Hogsdorf', 'Hogsdorf,Högsdorf', 54.2500000, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36110, 'Högersdorf', 'Hogersdorf', 'Hogersdorf,Högersdorf', 53.9166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36111, 'Högel', 'Hogel', 'Hogel,Högel', 54.6500000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36112, 'Hofstetten', 'Hofstetten', '', 48.2584600, 8.0659500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36113, 'Hofstetten', 'Hofstetten', '', 48.0084700, 10.9711400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36114, 'Hofkirchen', 'Hofkirchen', 'Danubi Hofkirxen,Gofkirkhen,Hofkirchen,Khofkirkhen,hwf kyrshn,Гофкірхен,Хофкирхен,Դանուբի Հոֆկիրխեն,هوف کیرشن', 48.6780500, 13.1191700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36115, 'Hofheim in Unterfranken', 'Hofheim in Unterfranken', 'Hofheim,Hofheim in Mainfranken,Hofheim in Unterfranken', 50.1367500, 10.5232100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36116, 'Hofheim am Taunus', 'Hofheim am Taunus', 'Gofgajm,Hofheim,Hofheim am Taunus,Hofheim in Taunus,Khofkhajm am Taunus,Khofkhajm-am-Taunus,hwfhaym am tanws,hwfhaym am tawnws,tao nu si shan lu huo fu hai mu,Гофгайм,Хофхайм-ам-Таунус,Хофхајм ам Таунус,هوفهايم آم تاونوس,هوفهایم ام تانوس,ホーフハイム・アム・タウヌス,陶努斯山麓霍夫海姆', 50.0901900, 8.4493000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36117, 'Hofgeismar', 'Hofgeismar', 'Chofnkaismar,Gofgajsmar,Hofgeismar,Khofgajsmar,hofugaisuma,huo fu gai si ma er,hwfgayzmar,hwfghayzmar,Χοφγκάισμαρ,Гофгайсмар,Хофгайсмар,Хофгајсмар,هوفغايزمار,هوفگایزمار,ホーフガイスマー,霍夫盖斯马尔', 51.4960700, 9.3850000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36118, 'Hoffeld', 'Hoffeld', '', 54.2000000, 10.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36119, 'Hoffeld', 'Hoffeld', '', 50.3666700, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36120, 'Höfer', 'Hoefer', 'Hoefer,Höfer', 52.6833300, 10.2500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36121, 'Höfen an der Enz', 'Hofen an der Enz', 'Hofen,Hofen an der Enz,Höfen,Höfen an der Enz', 48.8000000, 8.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36122, 'Hofbieber', 'Hofbieber', 'Gofbiber,Khofbiber,huo fu bi bei er,Гофбібер,Хофбибер,霍夫比贝尔', 50.5862900, 9.8353400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36123, 'Hof', 'Hof', '', 50.6666700, 8.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36124, 'Hof', 'Hof', 'Curia Variscorum,Dworc,Dwórc,Gof,HOQ,Hof,Hof an der Saale,Hofas,Khof,hofu,hopeu,huo fu,hwf,hwf  alman,Гоф,Хоф,Հոֆ,هوف,هوف، آلمان,ホーフ,霍夫,호프', 50.3129700, 11.9126100, 'DE', '2014-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36125, 'Hodorf', 'Hodorf', 'Hodorf', 53.9005700, 9.4299200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36126, 'Hodenhagen', 'Hodenhagen', 'Khodenkhagen,huo deng ha gen,Ходенхаген,霍登哈根', 52.7650600, 9.5949500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36127, 'Hockweiler', 'Hockweiler', '', 49.7031100, 6.6921300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36128, 'Hockenheim', 'Hockenheim', 'Gokkengajm,Hockenheim,Hoggene,Hokenhaimas,Khokenkhajm,Khokkenkhajm,hokkenhaimu,huo ken hai mu,hwknhaym,Гоккенгайм,Хокенхајм,Хоккенхайм,هوكنهايم,هوکنهایم,ホッケンハイム,霍肯海姆', 49.3233400, 8.5519400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36129, 'Höckendorf', 'Hoeckendorf', '', 51.2242300, 13.9093500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36130, 'Höchst im Odenwald', 'Hoechst im Odenwald', 'Gekst-im-Odenval''d,Hochst,Hochst im Odenwald,Hoechst im Odenwald,Höchst,Höchst im Odenwald,Khekhst im Odenvald,Khjokhst,Khjokst,he xi si te,hehisuto・imu・oden''vu~aruto,Гекст-ім-Оденвальд,Хехст им Оденвалд,Хёкст,Хёхст,ヘーヒスト・イム・オーデンヴァルト,赫希斯特', 49.7997200, 8.9994400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36131, 'Höchstenbach', 'Hochstenbach', 'Hoechstenbach,Höchstenbach,Khekhstenbakh,Khjokhstenbakh,Khjokstenbakh,he xi si teng ba he,Хехстенбах,Хёкстенбах,Хёхстенбах,赫希斯滕巴赫', 50.6336100, 7.7447200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36132, 'Höchstberg', 'Hoechstberg', '', 50.2500000, 7.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36133, 'Hochstätten', 'Hochstatten', 'Hochstaetten,Hochstätten,Khokhshteten,Khokhshtetten,Khokstetten,huo si te teng,Хокстеттен,Хохштетен,Хохштеттен,霍斯特滕', 49.7666700, 7.8333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36134, 'Höchstädt bei Thiersheim', 'Hochstadt bei Thiersheim', 'Hochstadt,Hochstadt bei Thiersheim,Hoechstaedt im Fichtelgebirge,Höchstädt,Höchstädt bei Thiersheim,Höchstädt im Fichtelgebirge', 50.1015700, 12.0871100, 'DE', '2017-07-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36135, 'Höchstädt an der Donau', 'Hochstadt an der Donau', 'Danubi Hyoxstadt,Gekstedt-an-der-Donau,Hochstadt,Hochstatt,Hoechstaedt an der Donau,Höchstädt,Höchstädt an der Donau,Khekhshtet na Dunavu,Khjokhshtedt-an-der-Donau,Khjokhshtedt-na-Dunae,hwashtat an dr danwb,hwshtat an dr dwnaw,Гекстедт-ан-дер-Донау,Дунайдагы Хөхштедт,Хехштет на Дунаву,Хёхштедт-ан-дер-Донау,Хёхштедт-на-Дунае,Դանուբի Հյոխշտադտ,هواشتات ان در دانوب,هوشتات أن در دوناو', 48.6112400, 10.5681600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36136, 'Hochstadt am Main', 'Hochstadt am Main', 'Gokhshtadt-am-Majn,Hochstadt,Khokhshtadt-na-Majne,Khokhshtat na Majni,hwkhshtat am myn,mei yin he pan huo si ta te,Гохштадт-ам-Майн,Хохштадт-на-Майне,Хохштат на Мајни,Մայնի Հոխշթաթ,هوخشتات ام مین,ホーホシュタット・アム・マイン,美因河畔霍斯塔特', 50.1500900, 11.1711600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36137, 'Höchstadt an der Aisch', 'Hochstadt an der Aisch', 'Gekhshtadt,Hochstadt,Hoechstadt,Höchstadt,Khekhshtat an der Ajsh,Khjokhshtadt-na-Ajshe,ai shi he pan he xi shi ta te,hwashtat an dr aysh,hwshtat an dr aysh,Айштагы Хөхштадт,Гехштадт,Хехштат ан дер Ајш,Хёхштадт-на-Айше,هواشتات ان در آیش,هوشتات أن در آيش,ヘーヒシュタット・アン・デア・アイシュ,艾施河畔赫希施塔特', 49.7061700, 10.8132900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36138, 'Hochspeyer', 'Hochspeyer', 'Hochschbaija,Khokhshpajer,Khokhspajer,Khokspejer,gao shi pai er,hohhoshupaiya,Хокспейер,Хохспајер,Хохшпайер,ホッホシュパイヤー,高施派尔', 49.4420700, 7.8950400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36139, 'Hochscheid', 'Hochscheid', 'Khokhshajd,Khokskhajd,huo sha yi de,Хоксхайд,Хохшайд,Хохшајд,霍沙伊德', 49.8833300, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36140, 'Hochkirch', 'Hochkirch', 'Bukecy,Gokhkirkh,Hochkirch/Bukecy,Hochkirchi vald,Khokhkirkh,huo ji er xi,Гохкірх,Хохкирх,霍基尔希', 51.1489800, 14.5706300, 'DE', '2017-02-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36141, 'Hochheim am Main', 'Hochheim am Main', 'Gokhgajm-am-Majn,Hochheim,Hochheim am Main,Khokhajm na Majni,Khokhkhajm-am-Majn,hkhhaym am mayn,mei yin he pan huo hai mu,Гохгайм-ам-Майн,Хохајм на Мајни,Хоххайм-ам-Майн,هخهایم ام ماین,ホーホハイム・アム・マイン,美因河畔霍海姆', 50.0143600, 8.3521800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36142, 'Hochheim', 'Hochheim', '', 51.0166700, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36143, 'Höchheim', 'Hochheim', 'Gekhgajm,Hyoxhaym,Khekhkhajm,Khjokhkhajm,he xia yi mu,Гехгайм,Хеххајм,Хёххайм,Հյոխհայմ,赫夏伊姆', 50.3666700, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36144, 'Hochfeld', 'Hochfeld', '', 51.4194300, 6.7546200, 'DE', '2013-03-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36145, 'Höchenschwand', 'Hochenschwand', 'Gekhenshvand,Hoechenschwand,Höchenschwand,Khekhenshvand,Khjokhenshvand,he xing shi wan de,Гехеншванд,Хехеншванд,Хёхеншванд,赫兴施万德', 47.7333300, 8.1666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36146, 'Hochdorf', 'Hochdorf', '', 48.6928300, 9.4649400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36147, 'Hochdorf', 'Hochdorf', 'Gokhdorf,Hoxdorf,Khokhdorf,hokhdorpi,Гохдорф,Хохдорф,Հոխդորֆ,ჰოხდორფი', 48.0256000, 9.7877800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36148, 'Hochdonn', 'Hochdonn', 'Hochdorn', 54.0266300, 9.2762400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36149, 'Höchberg', 'Hochberg', 'Gekhberg,Hochberg,Hoechberg,Hyoxberg,Höchberg,Khekhberg,Khjokhberg,he xi bei ge,hehiberuku,Гехберг,Хехберг,Хёхберг,Հյոխբերգ,ヘーヒベルク,赫希贝格', 49.7844600, 9.8822300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36150, 'Hitzhusen', 'Hitzhusen', 'Hitzhusen', 53.9239700, 9.8526200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36151, 'Hitzhofen', 'Hitzhofen', 'Gicgofen,Khickhofen,hytshwfn,xi ci huo fen,Гіцгофен,Хицхофен,Հիցհոֆեն,هیتسهوفن,希茨霍芬', 48.8500000, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36152, 'Hitzacker', 'Hitzacker', 'Khicaker,Khitcakker,hytsakr,xi cha ke er,Хитцаккер,Хицакер,هيتسآكر,هیتس‌آکر,希察克尔', 53.1525400, 11.0441800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36153, 'Hittbergen', 'Hittbergen', '', 53.3445000, 10.5891400, 'DE', '2011-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36154, 'Hisel', 'Hisel', '', 49.9630900, 6.3740400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36155, 'Hirz-Maulsbach', 'Hirz-Maulsbach', '', 50.6833300, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36156, 'Hirzenhain', 'Hirzenhain', 'Gircengajn,Hirzenhain,Khircenkhajn,hirutsu~enhain,xi er cen hai en,Гірценгайн,Хирценхайн,Хирценхајн,ヒルツェンハイン,希尔岑海恩', 50.4000000, 9.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36157, 'Hirten', 'Hirten', '', 50.3333300, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36158, 'Hirschhorn', 'Hirschhorn', '', 49.4456600, 8.8959400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36159, 'Hirschfelde', 'Hirschfelde', '', 50.9443700, 14.8851000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36160, 'Hirschfeld', 'Hirschfeld', '', 51.3833300, 13.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36161, 'Hirschfeld', 'Hirschfeld', '', 50.9500000, 12.1833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36162, 'Hirschfeld', 'Hirschfeld', '', 50.6245300, 12.4572200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36163, 'Hirschberg', 'Hirschberg', '', 50.3787700, 7.9248500, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36164, 'Hirschbach', 'Hirschbach', '', 49.5500000, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36165, 'Hirschau', 'Hirschau', 'Girshau,Hirsau,Hirschau,Khirshau,hyrshaw,xi er shao,Гіршау,Хиршау,Հիրշաու,هيرشاو,هیرشاو,希尔绍', 49.5439600, 11.9461700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36166, 'Hirschaid', 'Hirschaid', 'Girshajd,Hirsayd,Hirschaid,Khirshajd,hirushaito,Гіршайд,Хиршайд,Хиршајд,Հիրշայդ,ヒルシャイト', 49.8178900, 10.9891800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36167, 'Hirrlingen', 'Hirrlingen', 'Girrlingen,Khirlingen,xi er lin gen,Гіррлінген,Хирлинген,希尔林根', 48.4124500, 8.8874200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36168, 'Hipstedt', 'Hipstedt', '', 53.4833300, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36169, 'Hinzweiler', 'Hinzweiler', 'Khincvajler,xin ci wei lei,Хинцвайлер,Хинцвајлер,欣茨韦勒', 49.5833300, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36170, 'Hinzenburg', 'Hinzenburg', '', 49.6666700, 6.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36171, 'Hinterzarten', 'Hinterzarten', 'Gintercarten,Khintercarten,xin te cha er teng,Гінтерцартен,Хинтерцартен,Հինտերցարտեն,欣特察尔滕', 47.9027600, 8.1070100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36172, 'Hinterweiler', 'Hinterweiler', '', 50.2364500, 6.7558200, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36173, 'Hinterweidenthal', 'Hinterweidenthal', 'Khintervajdental,Khintervajdental'',xin te er wei deng ta er,Хинтервайденталь,Хинтервајдентал,欣特尔魏登塔尔', 49.2000000, 7.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36174, 'Hintertiefenbach', 'Hintertiefenbach', '', 49.7333300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36175, 'Hinterschmiding', 'Hinterschmiding', 'Gintershmiding,Khintershmiding,hyntrshmydyng,xin te er shi mi ding,Гінтершмідінг,Хинтершмидинг,Հինթերշմիդինգ,هینترشمیدینگ,欣特尔施米丁', 48.8233700, 13.6036900, 'DE', '2014-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36176, 'Hinte', 'Hinte', 'Khinte,xin te,Хинте,欣特', 53.4166700, 7.1833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36177, 'Hingstheide', 'Hingstheide', 'Hingstheide', 53.9000000, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36178, 'Himmighofen', 'Himmighofen', '', 50.2120100, 7.7655300, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36179, 'Himmelstadt', 'Himmelstadt', '', 49.9238900, 9.8016700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36180, 'Himmelpforten', 'Himmelpforten', 'Himmelpforten,Himmelpoorten,Khimelpforten,Khimmel''pforten,hinmerupuforuten,xi mei er pu fu er teng,Химелпфортен,Химмельпфортен,ヒンメルプフォルテン,希梅尔普福尔滕', 53.6141300, 9.3051600, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36181, 'Himmelkron', 'Himmelkron', 'Gimmel''kron,Khimelkron,Khimmel''kron,hinmerukuron,hymlkwrn,xi mei er ke long,Гіммелькрон,Химелкрон,Химмелькрон,Հիմելքրոն,هیملکورن,ヒンメルクロン,希梅尔克龙', 50.0666700, 11.6000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36182, 'Himbergen', 'Himbergen', 'Khimbergen,xin bei er gen,Химберген,欣贝尔根', 53.0941800, 10.7290900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36183, 'Hilzingen', 'Hilzingen', 'Gil''cingen,Hilzingen,Khil''cingen,Khilcingen,xi er qin gen,Гільцинген,Хилцинген,Хильцинген,希尔钦根', 47.7666700, 8.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36184, 'Hiltpoltstein', 'Hiltpoltstein', 'Gil''tpol''tshtajn,Hiltpoltstein,Khil''tpol''tshtajn,Khiltpoltshtajn,hirutoporutoshutain,xi er te bo er ci tai yin,Гільтпольтштайн,Хилтполтштајн,Хильтпольтштайн,Հիլթփոլթշթայն,ヒルトポルトシュタイン,希尔特波尔茨泰因', 49.6607500, 11.3227200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36185, 'Hilter', 'Hilter', 'Hilter', 52.1357300, 8.1471500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36186, 'Hiltenfingen', 'Hiltenfingen', '', 48.1608500, 10.7175000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36187, 'Hilst', 'Hilst', '', 49.1333300, 7.5333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36188, 'Hilscheid', 'Hilscheid', '', 49.7333300, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36189, 'Hilpoltstein', 'Hilpoltstein', 'Gil''pol''tshtajn,Hilpoltstein,Khil''pol''tshtajn,Khilpoltshhajn,Khilpoltshtajn,hiruporutoshutain,hylbwltshtayn,xi er bo er ci tai yin,Гільпольтштайн,Хилполтштајн,Хилполтщайн,Хильпольтштайн,Հիլփոլտշթայն,هيلبولتشتاين,هیلپولت‌اشتاین,ヒルポルトシュタイン,希尔波尔茨泰因', 49.1904700, 11.1906000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36190, 'Hillscheid', 'Hillscheid', '', 50.4063900, 7.6986100, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36191, 'Hillgroven', 'Hillgroven', 'Hillgroven', 54.2166700, 8.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36192, 'Hillesheim', 'Hillesheim', 'Hillesheim', 50.2917700, 6.6696300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36193, 'Hillesheim', 'Hillesheim', '', 49.7763900, 8.2561100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36194, 'Hillerse', 'Hillerse', '', 52.4166700, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36195, 'Hillerse', 'Hillerse', '', 51.6855800, 9.9497300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36196, 'Hille', 'Hille', 'Hille', 52.3333300, 8.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36197, 'Hilkenbrook', 'Hilkenbrook', '', 52.9833300, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36198, 'Hilgertshausen-Tandern', 'Hilgertshausen-Tandern', 'Gil''gertsgauzen-Tandern,Hilgertshausen,Hilgertshauzen Tandern,Khil''gertskhauzen-Tandern,Khilgertskhauzen-Tandern,Kilkershausen,hylgrtshawzn,xi er ge er ci hao sen-tan de er en,Гільгертсгаузен-Тандерн,Хилгертсхаузен-Тандерн,Хильгертсхаузен-Тандерн,Հիլգերտսհաուզեն Տանդերն,هیلگرتسهاوزن,希尔格尔茨豪森-坦德尔恩', 48.4296000, 11.3542800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36199, 'Hilgert', 'Hilgert', '', 50.4563400, 7.6873500, 'DE', '2013-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36200, 'Hilgermissen', 'Hilgermissen', 'Khil''germissen,Khilgermisen,hirugamissen,xi er ge er mi sen,Хилгермисен,Хильгермиссен,ヒルガーミッセン,希尔格尔米森', 52.8500000, 9.1666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36201, 'Hilgenroth', 'Hilgenroth', 'Hilgenroth,Khil''genrot,Khilgenrot,hylgnrat,xi er gen luo te,Хилгенрот,Хильгенрот,هیلگنرات,希尔根罗特', 50.7333300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36202, 'Hildrizhausen', 'Hildrizhausen', 'Gil''dricgauzen,Khil''drickhauzen,Khildrickhauzen,hildritshauzeni,xi er de li ci hao sen,Гільдріцгаузен,Хилдрицхаузен,Хильдрицхаузен,Հիլդրիցհաուզեն,ჰილდრიცჰაუზენი,希尔德里茨豪森', 48.6242300, 8.9660500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36203, 'Hildesheim', 'Hildesheim', 'Chilnteschaim,Gil''desgajm,Gorad Gil''dehsgajm,Hildesheim,Hildesheima,Hildesheimas,Hildesia,Hilmessen,Khil''deskhajm,Khildeskhajm,ZNO,hildeseuhaim,hirudesuhaimu,hyldshaym,hyldshyym,hylds‌haym,xi er de si hai mu,Χίλντεσχαϊμ,Горад Гільдэсгайм,Гільдесгайм,Хилдесхайм,Хилдесхајм,Хильдесхайм,הילדסהיים,هيلدسهايم,هیلدس‌هایم,ہیلڈشیم,ヒルデスハイム,希尔德斯海姆,힐데스하임', 52.1507700, 9.9511200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36204, 'Hilders', 'Hilders', 'Gil''ders,Hiltrica,Khil''ders,Khilders,xi er de er si,Гільдерс,Хилдерс,Хильдерс,希尔德尔斯', 50.5719000, 10.0029700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36205, 'Hilden', 'Hilden', 'Gil''den,Hilde,Hilden,Khil''den,Khilden,ZNN,hyldn,xi er deng,Гільден,Хилден,Хильден,هيلدن,هیلدن,希爾登', 51.1681800, 6.9309300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36206, 'Hildburghausen', 'Hildburghausen', 'Khil''dburgkhauzen,Khildburgkhauzen,hyldbwrghhawzn,xi er de bu ge hao sen,Хилдбургхаузен,Хильдбургхаузен,هيلدبورغهاوزن,هیلدبورگ‌هاوزن,希尔德布格豪森', 50.4255300, 10.7318400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36207, 'Hilchenbach', 'Hilchenbach', 'Gil''khenbakh,Hilchenbach,Khil''khenbakh,Khilkhenbakh,hylshnbakh,xi er xing ba he,Гільхенбах,Хилхенбах,Хильхенбах,هيلشنباخ,هیلشنباخ,希尔兴巴赫', 50.9968700, 8.1106200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36208, 'Hilbersdorf', 'Hilbersdorf', '', 50.8540000, 12.9477600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36209, 'Hilbersdorf', 'Hilbersdorf', '', 50.8166700, 12.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36210, 'Hiddenhausen', 'Hiddenhausen', 'Giddengauzen,Hiddenhausen,Khiddenkhauzen,Khidenkhauzen,hidenhauzen,xi deng hao sen,Гідденгаузен,Хидденхаузен,Хиденхаузен,ヒデンハウゼン,希登豪森', 52.1666700, 8.6166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36211, 'Heygendorf', 'Heygendorf', 'Hachendorpf [a. 899],Heygendorf,Heygendorp', 51.3514400, 11.3615400, 'DE', '2014-12-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36212, 'Heyersum', 'Heyersum', '', 52.1567800, 9.8126500, 'DE', '2010-11-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36213, 'Heyersdorf', 'Heyersdorf', '', 50.8500000, 12.3500000, 'DE', '2015-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36214, 'Heyerode', 'Heyerode', 'Heyerode,Khajerode,Хайероде,Хајероде', 51.1643900, 10.3200900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36215, 'Heyen', 'Heyen', '', 52.0095100, 9.5036900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36216, 'Heuzert', 'Heuzert', '', 50.6991200, 7.7597800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36217, 'Heuweiler', 'Heuweiler', 'Gojvajler,Hoyvayler,Khojvajler,huo yi wei lei,Гойвайлер,Хойвайлер,Хојвајлер,Հոյվայլեր,霍伊韦勒', 48.0500000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36218, 'Heuthen', 'Heuthen', 'Heuthen', 51.3318800, 10.2224400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36219, 'Heusweiler', 'Heusweiler', 'Gojsvajler,Heusweiler,Khojsvajler,huo yi si wei lei,Гойсвайлер,Хойсвайлер,Хојсвајлер,霍伊斯韦勒', 49.3363200, 6.9303600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36220, 'Heustreu', 'Heustreu', '', 50.3548500, 10.2606900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36221, 'Heusenstamm', 'Heusenstamm', 'Gojzenshtamm,Heusenstamm,Khojsenstam,Khojzenshtamm,hoizenshutamu,huo yi sen si ta mu,hwyznshtam,Гойзенштамм,Хойзенштамм,Хојсенстам,هويزنشتام,هویزن‌اشتام,ホイゼンシュタム,霍伊森斯塔姆', 50.0555300, 8.8007600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36222, 'Heupelzen', 'Heupelzen', '', 50.7166700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36223, 'Heukewalde', 'Heukewalde', '', 50.8333300, 12.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36224, 'Heuerßen', 'Heuerssen', 'Heuerssen,Heuerßen,Khojersen,hoierusen,huo yi ai er sen,Хойерсен,Хојерсен,ホイエルセン,霍伊埃尔森', 52.3294600, 9.2771800, 'DE', '2016-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36225, 'Heudeber', 'Heudeber', 'Heudeber', 51.9024500, 10.8432100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36226, 'Heuchlingen', 'Heuchlingen', 'Gojkhlingen,Khojkhlingen,Khojlingen,hoikhlingeni,huo yi he lin gen,Гойхлінген,Хойхлинген,Хојлинген,ჰოიხლინგენი,霍伊赫林根', 48.8521500, 9.9439100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36227, 'Heuchelheim bei Frankenthal', 'Heuchelheim bei Frankenthal', 'Heuchelheim,Heuchelheim bei Frankenthal,Heuchelheim uber Frankenthal,Heuchelheim über Frankenthal,Khojkhel''khajm-Frankental'',Khojkhelkhajm baj Frankental,fu lan ken ta er fu jin huo yi hei er hai mu,Хойхельхайм-Франкенталь,Хојхелхајм бај Франкентал,弗兰肯塔尔附近霍伊黑尔海姆', 49.5630600, 8.2908300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36228, 'Heuchelheim', 'Heuchelheim', 'Heuchelheim', 50.5833300, 8.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36229, 'Heubach', 'Heubach', 'Gojbakh,Khojbakh,hoibakhi,huo yi ba he,hwybakh,Гойбах,Хойбах,Хојбах,هويباخ,هویباخ,ჰოიბახი,霍伊巴赫', 48.7926700, 9.9337000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36230, 'Hetzles', 'Hetzles', 'Gecles,Khecles,hei ci lai si,hettsuresu,Гецлес,Хецлес,ヘッツレス,黑茨莱斯', 49.6333300, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36231, 'Hetzerath', 'Hetzerath', '', 49.8833300, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36232, 'Hettstedt', 'Hettstedt', 'Heiczstete [a. 1046],Heiksteten,Hekstede,Hettstedt,Hezstede,Khetshtedt,Khetshtet,hei ci te,hytshtyt,Хетштедт,Хетштет,هت‌اشتت,هيتشتيت,黑茨特', 51.6503000, 11.5114600, 'DE', '2015-01-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36233, 'Hettstadt', 'Hettstadt', 'Gettshtadt,Hetstad,Khetshtadt,Khetshtat,hei ci ta te,hettoshutatto,Геттштадт,Хетштадт,Хетштат,Հետշտադ,ヘットシュタット,黑茨塔特', 49.7994400, 9.8150000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36234, 'Hettingen', 'Hettingen', 'Gettingen,Khetingen,Khettingen,hei ting gen,htynghn,htyngn,Геттінген,Хетинген,Хеттинген,هتينغن,هتینگن,黑廷根', 48.2160100, 9.2316900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36235, 'Hettenshausen', 'Hettenshausen', 'Gettensgauzen,Khetenskhauzen,Khettenskhauzen,hei teng si hao sen,htnshawzn,Геттенсгаузен,Хетенсхаузен,Хеттенсхаузен,Հեթենսհաուզեն,هتنسهاوزن,黑滕斯豪森', 48.5000000, 11.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36236, 'Hettenrodt', 'Hettenrodt', '', 49.7400900, 7.2535100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36237, 'Hettenleidelheim', 'Hettenleidelheim', 'Khetenlajdelkhajm,Khettenlajdel''khajm,hei teng lai de er hai mu,hettenraideruhaimu,Хетенлајделхајм,Хеттенлайдельхайм,ヘッテンライデルハイム,黑滕莱德尔海姆', 49.5355600, 8.0736100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36238, 'Hettenhausen', 'Hettenhausen', '', 49.3333300, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36239, 'Hetschburg', 'Hetschburg', '', 50.9128800, 11.3001300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36240, 'Hetlingen', 'Hetlingen', 'Khetlingen,hei te lin gen,Хетлинген,黑特林根', 53.6071200, 9.6371800, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36241, 'Hesweiler', 'Hesweiler', '', 50.0500000, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36242, 'Hessisch Oldendorf', 'Hessisch Oldendorf', 'Hessisch Oldendorf,Hessisch-Oldendorf,Khesish Oldendorf,Khessish-Ol''dendorf,Vicus Vetus Hassicus,hei xi shi ao er deng duo fu,hsysh aldndwrf,hsysh awldndwrf,Хесиш Олдендорф,Хессиш-Ольдендорф,هسيش أولدندورف,هسیش الدندورف,ヘッシシュ・オルデンドルフ,黑西施奥尔登多夫', 52.1726900, 9.2491300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36243, 'Hessisch Lichtenau', 'Hessisch Lichtenau', 'Gessish-Likhtenau,Hessisch Lichtenau,Khesish Likhtenau,Khessish-Likhtenau,Lichtenau,hei xi shi li xi te nao,hsysh lyshtnaw,Гессіш-Ліхтенау,Хесиш Лихтенау,Хессиш-Лихтенау,هسيش ليشتناو,هسیش لیشتناو,ヘッシシュ・リヒテナウ,黑西施利希特瑙', 51.1995400, 9.7185700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36244, 'Hessigheim', 'Hessigheim', 'Gessigajm,Khesigkhajm,Khessigkhajm,hei xi ge hai mu,hsyghaym,Гессігайм,Хесигхајм,Хессигхайм,هسیگهایم,黑西格海姆', 48.9940700, 9.1862900, 'DE', '2014-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36245, 'Heßheim', 'Hessheim', 'Kheskhajm,hei si hai mu,hesuhaimu,Хесхайм,Хесхајм,ヘースハイム,黑斯海姆', 49.5458300, 8.3077800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36246, 'Heßdorf', 'Hessdorf', 'Gesdorf,Hessdorf,Heßdorf,Khesdorf,hei si duo fu,hesudorufu,Гесдорф,Хесдорф,ヘスドルフ,黑斯多夫', 49.6272800, 10.9100200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36247, 'Hespe', 'Hespe', '', 52.3299900, 9.1081800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36248, 'Hesel', 'Hesel', 'Khesel,Khezel'',hei sai er,Хезель,Хесел,黑塞尔', 53.3000000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36249, 'Herzogenrath', 'Herzogenrath', 'Chertsonkenrat,Gercogenrat,Khercogenrat,Roa,hei er cuo gen la te,hrtswghnrat,hrzwgnras,Χέρτσογκενρατ,Герцогенрат,Херцогенрат,هرتسوغنرات,هرزوگنراس,黑尔措根拉特', 50.8687400, 6.0931700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36250, 'Herzogenaurach', 'Herzogenaurach', 'Gercogenaurakh,Herzogenaurach,Khercogenaurakh,XHI,hei cuo gen ao la he,herutsu~ogen''auraha,hrtswghn awrakh,Герцогенаурах,Херцогенаурах,هرتسوغن آوراخ,هرتسوگن‌آوراخ,ヘルツォーゲンアウラハ,黑措根奥拉赫', 49.5679800, 10.8856500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36251, 'Herzlake', 'Herzlake', 'Herzlake,Kherclake,hei er ci la ke,Херцлаке,黑尔茨拉克', 52.6853000, 7.5994600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36252, 'Herzhorn', 'Herzhorn', 'Herzhorn', 53.7833300, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36253, 'Herzberg am Harz', 'Herzberg am Harz', 'Gorad Gercberg,Hertzberga ad Harthicos montes,Herzberg,Herzberg am Harz,Khercberg,Khercberg am Kharc,Khercberg-am-Kharc,ha ci shan qu hei er ci bei ge,heleucheubeleukeu am haleucheu,hrtsbrg am harts,hrtsbrgh am harts,Горад Герцберг,Херцберг,Херцберг ам Харц,Херцберг-ам-Харц,هرتسبرغ آم هارتس,هرتسبرگ آم هارتس,ヘルツベルク・アム・ハルツ,哈茨山区黑尔茨贝格,헤르츠베르크 암 하르츠', 51.6554600, 10.3393800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36254, 'Herzberg', 'Herzberg', 'Khercberg,hei er ci bei ge,heleucheubeleukeu,hrtsbrg,hrtsbrgh,Херцберг,Հերցբերգ,هرتسبرغ,هرتسبرگ,黑尔茨贝格,헤르츠베르크', 51.6869200, 13.2201600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36255, 'Herxheimweyher', 'Herxheimweyher', '', 49.1525000, 8.2550000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36256, 'Herxheim am Berg', 'Herxheim am Berg', 'Herxheim,Herxheim am Berg', 49.5091700, 8.1791700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36257, 'Herten', 'Herten', 'Gerten,Heritono,Herten,Hiaetten,Hiätten,Hėritono,Kherten,hei er teng,hrtn,hyrtn,Гертен,Хертен,هرتن,هيرتن,黑尔滕', 51.5963800, 7.1438700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36258, 'Herschweiler-Pettersheim', 'Herschweiler-Pettersheim', 'Khershvajler-Peterskhajm,Khershvajler-Petterskhajm,hei er shi wei lei-pei te si hai mu,Хершвайлер-Петтерсхайм,Хершвајлер-Петерсхајм,黑尔施韦勒-佩特斯海姆', 49.4833300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36259, 'Herscheid', 'Herscheid', 'Gershajd,Khershajd,hei er sha yi de,Гершайд,Хершайд,Хершајд,黑尔沙伊德', 51.1790100, 7.7435500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36260, 'Herschdorf', 'Herschdorf', '', 50.7116800, 11.5373600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36261, 'Herschdorf', 'Herschdorf', 'Khershdorf,hei er shi duo fu,Хершдорф,黑尔施多夫', 50.6294300, 11.0489800, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36262, 'Herschbroich', 'Herschbroich', '', 50.3666700, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36263, 'Herschberg', 'Herschberg', '', 49.3050500, 7.5482000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36264, 'Herschbach', 'Herschbach', '', 50.5833300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36265, 'Hersbruck', 'Hersbruck', 'Gersbruk,Hersbruck,Khersbruk,hei er si bu lu ke,hrzbrwk,hyrsbrwk,Герсбрук,Херсбрук,Հերսբրուք,هرزبروک,هيرسبروك,黑尔斯布鲁克', 49.5108300, 11.4315100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36266, 'Herrstein', 'Herrstein', 'Khershtajn,hei er si tai yin,herushutain,Херштайн,Херштајн,ヘルシュタイン,黑尔斯泰因', 49.7833300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36267, 'Herrnschwende', 'Herrnschwende', 'Herrnschwende,Herrschwende', 51.2166700, 11.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36268, 'Herrsching am Ammersee', 'Herrsching am Ammersee', 'Gerrshing,Herrschin,Herrsching,Khershing am Amerze,Khershing-am-Ammerze,a mo hu pan hei er xing,hrshyng,Герршинг,Хершинг ам Амерзе,Хершинг-ам-Аммерзе,هرشینگ,阿默湖畔黑尔兴', 47.9988800, 11.1767900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36269, 'Herrnhut', 'Herrnhut', 'Hernhute,Hernhūte,Herrnhut,Khernkhut,Ochranow,hei er en hu te,hrnhwt,hyrnhwt,Хернхут,هرنهوت,هيرنهوت,黑尔恩胡特', 51.0162400, 14.7438100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36270, 'Herrngiersdorf', 'Herrngiersdorf', 'Gerrngirsdorf,Herngirsdorf,Kherngirsdorf,hei en ji er si duo fu,hrngyrsdwrf,Геррнгірсдорф,Хернгирсдорф,Հերնգիրսդորֆ,هرنگیرسدورف,黑恩吉尔斯多夫', 48.7886300, 12.0720000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36271, 'Herrmannsacker', 'Herrmannsacker', 'Khermansaker,Khermanzakker,hei er man sa ke er,Херманзаккер,Хермансакер,黑尔曼萨克尔', 51.5500000, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36272, 'Herrischried', 'Herrischried', 'Gerrishrid,Herrischried,Kherishrid,Kherrishrid,hei li shi li de,Геррішрід,Херишрид,Херришрид,黑里施里德', 47.6666700, 8.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36273, 'Herrieden', 'Herrieden', 'Gerriden,Heriden,Herrieden,Kheriden,Kherriden,hei li deng,heriden,hrydn,hyr rydn,Герріден,Хериден,Херриден,Հերիդեն,هریدن,هير ريدن,ヘリーデン,黑里登', 49.2377900, 10.5035000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36274, 'Herresbach', 'Herresbach', '', 50.3666700, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36275, 'Herren-Sulzbach', 'Herren-Sulzbach', 'Kheren-Zulcbakh,Kherren-Zul''cbakh,hei lun-su er ci ba he,Херен-Зулцбах,Херрен-Зульцбах,黑伦-苏尔茨巴赫', 49.6500000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36276, 'Herrenhof', 'Herrenhof', 'Kherenkhof,Kherrenkhof,hei lun huo fu,Херенхоф,Херренхоф,黑伦霍夫', 50.8418400, 10.6869300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36277, 'Herrenberg', 'Herrenberg', 'Gerrenberg,Herenberg,Herrenberq,Kherenberg,Kherrenberg,hei lun bei ge,herenbergi,hrnbrg,hyrnbrgh,Герренберг,Херенберг,Херренберг,Հերենբերգ,هرنبرگ,هيرنبرغ,ჰერენბერგი,黑伦贝格', 48.5952300, 8.8664800, 'DE', '2012-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36278, 'Heroldsberg', 'Heroldsberg', 'Gerol''dsberg,Heroldsberg,Kherol''dsberg,Kheroldsberg,hei luo er ci bei ge,herorutsuberuku,Герольдсберг,Херолдсберг,Херольдсберг,ヘロルツベルク,黑罗尔茨贝格', 49.5324700, 11.1555100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36279, 'Heroldsbach', 'Heroldsbach', 'Gerol''dsbakh,Kherol''dsbakh,Kheroldsbakh,hei luo er ci ba he,herorutsubahha,Герольдсбах,Херолдсбах,Херольдсбах,ヘーロルツバッハ,黑罗尔茨巴赫', 49.6934200, 10.9988200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36280, 'Heroldishausen', 'Heroldishausen', '', 51.1333300, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36281, 'Herold', 'Herold', '', 50.2774400, 7.9317900, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36282, 'Herne', 'Herne', 'Gerne,Gorad Kherneh,Herne,Hernė,Kherne,hei er ne,heleune,herne,herune,hrnh,hyrnh,Герне,Горад Хернэ,Херне,هرنه,هيرنه,ہرنے,ჰერნე,ヘルネ,黑尔讷,헤르네', 51.5388000, 7.2257200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36283, 'Hermsdorf', 'Hermsdorf', 'Berlin-Hermsdorf', 52.6113100, 13.3178300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36284, 'Hermsdorf', 'Hermsdorf', '', 52.1874000, 11.4755600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36285, 'Hermsdorf', 'Hermsdorf', '', 51.4054700, 13.8936700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36286, 'Hermsdorf', 'Hermsdorf', '', 50.9233800, 13.7348000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36287, 'Hermsdorf', 'Hermsdorf', 'Hermesdorp [a. 1256],Hermsdorf,Khermsdorf,hrmzdwrf,Хермсдорф,هرمزدورف', 50.8969400, 11.8554900, 'DE', '2014-12-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36288, 'Hermeskeil', 'Hermeskeil', 'Hermeskeil,Khermeskajl,Khermeskajl'',hei er mei si kai er,herumesukairu,hrmzkayl,hyrmskayl,Хермескайль,Хермескајл,هرمزکایل,هيرمسكايل,ჰერმესკაილი,ヘルメスカイル,黑尔梅斯凯尔', 49.6552800, 6.9440700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36289, 'Hermersberg', 'Hermersberg', 'Hermerschberch,Khermersberg,hei mo si bei ge,Хермерсберг,黑默斯贝格', 49.3166700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36290, 'Hermaringen', 'Hermaringen', 'Germaringen,Khermaringen,hei er ma lin gen,Гермарінген,Хермаринген,黑尔马林根', 48.5954400, 10.2606500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36291, 'Hermannsburg', 'Hermannsburg', 'Hermannsburg,Khermansburg,hei er man si bao,Хермансбург,黑尔曼斯堡', 52.8325400, 10.0895700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36292, 'Herleshausen', 'Herleshausen', 'Gerlesgauzen,Herleshausen,Kherleskhauzen,hei er lai si hao sen,heruresuhauzen,Герлесгаузен,Херлесхаузен,ヘルレスハウゼン,黑尔莱斯豪森', 51.0062900, 10.1673100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36293, 'Herl', 'Herl', '', 49.7333300, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36294, 'Heringsdorf', 'Heringsdorf', '', 54.3010000, 11.0065800, 'DE', '2012-07-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36295, 'Heringen', 'Heringen', 'Heringen/Helme', 51.4470500, 10.8761200, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36296, 'Heringen', 'Heringen', 'Geringen,Kheringen,hei lin gen,hrynghn,hryngn,Герінген,Херинген,هرينغن,هرینگن,黑林根', 50.8879800, 10.0071700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36297, 'Hergisdorf', 'Hergisdorf', 'Hergisdorf', 51.5333300, 11.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36298, 'Hergersweiler', 'Hergersweiler', '', 49.0963900, 8.0916700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36299, 'Hergensweiler', 'Hergensweiler', 'Gergensvajler,Hergensvayler,Khergensvajler,hei gen si wei lei,Гергенсвайлер,Хергенсвайлер,Хергенсвајлер,Հերգենսվայլեր,黑根斯韦勒', 47.6166700, 9.7833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36300, 'Hergenroth', 'Hergenroth', '', 50.5827800, 7.9747200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36301, 'Hergenfeld', 'Hergenfeld', 'Khergenfel''d,Khergenfeld,hei er gen fei er de,Хергенфелд,Хергенфельд,黑尔根费尔德', 49.9000000, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36302, 'Hergatz', 'Hergatz', 'Gergac,Khergac,hei er jia ci,Гергац,Хергац,Հերգաց,黑尔加茨', 47.6500000, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36303, 'Herforst', 'Herforst', '', 49.9500000, 6.7000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36304, 'Herford', 'Herford', 'Herford,Hiarwede,Kherford,ZNK,hei er fu de,heruforuto,hrfwrd,Херфорд,هرفورد,ヘルフォルト,黑爾福德', 52.1145700, 8.6734300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36305, 'Heretsried', 'Heretsried', '', 48.4597200, 10.7360100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36306, 'Herdorf', 'Herdorf', 'Herdorf,Kherdorf,hei er duo fu,herudorufu,hrdwrf,Хердорф,هردورف,ヘルドルフ,黑尔多夫', 50.7770400, 7.9536600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36307, 'Herdecke', 'Herdecke', 'Herdecke,Kherdeke,Kherdekke,hei er de ke,hrdkh,hyrdkh,Хердеке,Хердекке,هردکه,هيردكه,黑尔德克', 51.3999900, 7.4358400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36308, 'Herchweiler', 'Herchweiler', 'Herchwei,Kherkhvajler,hei xi wei lei,Херхвайлер,Херхвајлер,黑希韦勒', 49.5140100, 7.2934600, 'DE', '2011-09-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36309, 'Herbstmühle', 'Herbstmuhle', '', 50.0000000, 6.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36310, 'Herbstein', 'Herbstein', 'Gerbshtajn,Herbstein,Kherbshtajn,hei er bu si tai yin,herupushutain,hyrbshtayn,Гербштайн,Хербштайн,Хербштајн,هرب‌اشتاین,هيربشتاين,ヘルプシュタイン,黑尔布斯泰因', 50.5610500, 9.3459200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36311, 'Herbstadt', 'Herbstadt', 'Gerbshtadt,Kherbshtadt,Kherbshtat,hei er bu si ta te,Гербштадт,Хербштадт,Хербштат,Հերբշթաթ,黑尔布斯塔特', 50.3333300, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36312, 'Herbsleben', 'Herbsleben', 'Kherbsleben,hei er bu si lai ben,Хербслебен,黑尔布斯莱本', 51.1166700, 10.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36313, 'Herbrechtingen', 'Herbrechtingen', 'Gerbrekhtingen,Kherbrekhtingen,hei er bu lei xi ting gen,hrbrshtynghn,hrbrshtyngn,Гербрехтінген,Хербрехтинген,هربرشتينغن,هربرشتینگن,黑尔布雷希廷根', 48.6217300, 10.1760000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36314, 'Herborn', 'Herborn', 'Herborn,Kherborn,Херборн', 50.6813500, 8.3036900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36315, 'Herborn', 'Herborn', '', 49.7666700, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36316, 'Herbolzheim', 'Herbolzheim', 'Gerbol''cgajm,Herbolshaym,Herbolzheim,Kherbol''ckhajm,Kherbolckhajm,hei er bo er ci hai mu,hrbwlzhaym,hyrbwltshaym,Гербольцгайм,Херболцхајм,Хербольцхайм,Հերբոլցհայմ,هربولزهایم,هيربولتسهايم,黑尔博尔茨海姆', 48.2188400, 7.7774600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36317, 'Herbertingen', 'Herbertingen', 'Gerbertingen,Kherbertingen,he bo ting gen,Гербертінген,Хербертинген,赫伯廷根', 48.0666700, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36318, 'Hepstedt', 'Hepstedt', '', 53.2587400, 9.0820900, 'DE', '2011-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36319, 'Heppenheim an der Bergstrasse', 'Heppenheim an der Bergstrasse', 'Heppenheim,Heppenheim an der Bergstrasse', 49.6414500, 8.6320600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36320, 'Hepberg', 'Hepberg', '', 48.8224900, 11.4617200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36321, 'Hentern', 'Hentern', '', 49.6166700, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36322, 'Henschleben', 'Henschleben', '', 51.1333300, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36323, 'Hennweiler', 'Hennweiler', 'Khenvajler,heng wei lei,Хенвайлер,Хенвајлер,亨韦勒', 49.8166700, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36324, 'Hennstedt', 'Hennstedt', 'Hennstedt', 54.2833300, 9.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36325, 'Hennstedt', 'Hennstedt', '', 54.0333300, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36326, 'Hennigsdorf', 'Hennigsdorf', 'Henigsdorf,Khenigsdorf,Khennigsdorf,Stadt Hennigsdorf,hei ni ge si duo fu,hnynghsdwrf,hnyngzdwrf,Хенигсдорф,Хеннигсдорф,Хеннігсдорф,Հենիգսդորֆ,هنينغسدورف,هنینگزدورف,黑尼格斯多夫', 52.6359800, 13.2041900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36327, 'Hennef', 'Hennef', 'Gennef,Hennef,Khenef,Khennef,heng nei fu,hnf,hynnf,Геннеф,Хенеф,Хеннеф,هنف,هيننف,亨内夫', 50.7755500, 7.2830800, 'DE', '2011-10-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36328, 'Henneberg', 'Henneberg', '', 50.4924300, 10.3549200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36329, 'Hengersberg', 'Hengersberg', 'Gengersberg,Hengersberg,Khengersberg,heng ge er si bei ge,hngrsbrg,Генгерсберг,Хенгерсберг,Հենգերսբերգ,هنگرسبرگ,亨格尔斯贝格', 48.7725500, 13.0548500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36330, 'Henfstädt', 'Henfstadt', 'Henfstadt,Henfstädt,Khenfshtedt,Khenfshtet,heng fu si te,Хенфштедт,Хенфштет,亨夫斯特', 50.5163200, 10.5873900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36331, 'Henfenfeld', 'Henfenfeld', '', 49.4984600, 11.3905900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36332, 'Hendungen', 'Hendungen', 'Gendungen,Hendungen,Khendungen,heng dui gen,Гендунген,Хендунген,Հենդունգեն,亨敦根', 50.3946200, 10.3520400, 'DE', '2012-08-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36333, 'Henau', 'Henau', '', 49.8666700, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36334, 'Hemsloh', 'Hemsloh', '', 52.6004400, 8.5089100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36335, 'Hemslingen', 'Hemslingen', '', 53.0833300, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36336, 'Hemsbünde', 'Hemsbuende', 'Hemsbuende,Hemsbünde', 53.0899800, 9.4726100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36337, 'Hemsbach', 'Hemsbach', 'Gemsbakh,Hemsbach,Khemsbakh,hei mu si ba he,hemusubahha,hmsbakh,hmzbakh,Гемсбах,Хемсбах,همزباخ,همسباخ,ヘムスバッハ,黑姆斯巴赫', 49.5907500, 8.6477900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36338, 'Hemmoor', 'Hemmoor', 'Gemeen Hemmoor,Hemmoor,Khemmor,Khemor,hei mo er,hmwwr,Хеммор,Хемор,هموور,黑莫尔', 53.6870200, 9.1549200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36339, 'Hemmingstedt', 'Hemmingstedt', 'Hemmingstedt,Khemingshtet,Khemmingshtedt,hei ming ge si te,Хемингштет,Хеммингштедт,黑明格斯特', 54.1500000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36340, 'Hemmingen', 'Hemmingen', '', 52.3142500, 9.7235900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36341, 'Hemmingen', 'Hemmingen', 'Hemmigen,Hemmingen', 48.8666700, 9.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36342, 'Hemmersheim', 'Hemmersheim', '', 49.5628600, 10.0964400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36343, 'Hemmelzen', 'Hemmelzen', '', 50.6934100, 7.5815100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36344, 'Hemme', 'Hemme', 'Hemme', 54.2833300, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36345, 'Hemleben', 'Hemleben', 'Hemleben', 51.2500000, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36346, 'Hemhofen', 'Hemhofen', 'Gemgofen,Khemkhofen,hei mu huo fen,hemuhofen,Гемгофен,Хемхофен,ヘムホーフェン,黑姆霍芬', 49.6833300, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36347, 'Hemer', 'Hemer', 'Gemer,Hadamare,Hemer,Khemer,he me xr,hei mo,hemeo,hmr,Гемер,Хемер,همر,เฮเมอร์,黑默,헤머', 51.3870700, 7.7701900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36348, 'Hemdingen', 'Hemdingen', 'Grosshemdingen,Großhemdingen,Hemdingen', 53.7666700, 9.8333300, 'DE', '2017-07-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36349, 'Hemau', 'Hemau', 'Gemau,Hemau,Hemman,Khemau,hei mao,hmaw,Гемау,Хемау,Հեմաու,هماو,黑毛', 49.0539900, 11.7819500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36350, 'Helvesiek', 'Helvesiek', '', 53.2160600, 9.4915000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36351, 'Heltersberg', 'Heltersberg', '', 49.3166700, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36352, 'Helse', 'Helse', 'Helse', 53.9746300, 9.0104400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36353, 'Helsa', 'Helsa', 'Gel''za,Helsa,Khel''za,Khelsa,hei er sa,heruza,Гельза,Хелса,Хельза,ヘルザ,黑尔萨', 51.2598100, 9.6887200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36354, 'Helpsen', 'Helpsen', 'Khel''pzen,Khelpsen,hei er pu sen,herupuzen,Хелпсен,Хельпзен,ヘルプゼン,黑尔普森', 52.3113100, 9.1167600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36355, 'Helmstorf', 'Helmstorf', '', 54.2833300, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36356, 'Helmstedt', 'Helmstedt', 'Gorad Khel''mshteht,Helmestee,Helmestidde,Helmonstede [a. 952],Helmstadium,Helmstedt,Helmstidde,Khel''mshtedt,Khelmshhet,Khelmshtet,Stadt Helmstedt,hei er mu si te,herumushutetto,hlmshtyt,hlmstdt,ˈhɛlmˌʃtɛt,Горад Хельмштэт,Хелмштет,Хелмщет,Хельмштедт,הלמשטדט,هلمشتيت,هلم‌اشتات,ヘルムシュテット,黑尔姆斯特', 52.2279000, 11.0098500, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36357, 'Helmstadt', 'Helmstadt', 'Gel''mshtadt,Helmstadt,Khel''mshtadt,Khelmshtat,hei er mu si ta te,herumushutatto,Гельмштадт,Хелмштат,Хельмштадт,Հելմշտադտ,ヘルムシュタット,黑尔姆斯塔特', 49.7618000, 9.7080300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36358, 'Helmsdorf', 'Helmsdorf', '', 51.3000000, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36359, 'Helmeroth', 'Helmeroth', '', 50.7333300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36360, 'Helmenzen', 'Helmenzen', '', 50.6938800, 7.6198900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36361, 'Helmbrechts', 'Helmbrechts', 'Gel''mbrekhts,Khel''mbrekhts,Khelmbrekhts,hei er en bu lei xi ci,herumuburehitsu,hlmbrkts,hlmbrshts,hlmbrshtz,Гельмбрехтс,Хелмбрехтс,Хельмбрехтс,הלמברכטס,هلمبرشتز,هلمبرشتس,ヘルムブレヒツ,黑尔恩布雷希茨', 50.2355700, 11.7158900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36362, 'Hellwege', 'Hellwege', '', 53.0734600, 9.2356600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36363, 'Hellschen-Heringsand-Unterschaar', 'Hellschen-Heringsand-Unterschaar', 'Hellschen-Heringsand-Unterschaar', 54.2000000, 8.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36364, 'Hellingen', 'Hellingen', 'Khelingen,Khellingen,Хелинген,Хеллинген', 50.2500000, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36365, 'Hellertshausen', 'Hellertshausen', '', 49.8166700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36366, 'Hellersdorf', 'Hellersdorf', 'Berlin-Hellersdorf,hlrsdwrp,הלרסדורף', 52.5331900, 13.6088000, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36367, 'Hellenthal', 'Hellenthal', 'Gellental'',Hellenthal,Khelental,Khellental'',hei lun ta er,Гелленталь,Хелентал,Хелленталь,黑伦塔尔', 50.4833300, 6.4333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36368, 'Hellenhahn-Schellenberg', 'Hellenhahn-Schellenberg', '', 50.6127800, 8.0263900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36369, 'Helferskirchen', 'Helferskirchen', '', 50.5102800, 7.8118400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36370, 'Heldrungen', 'Heldrungen', 'Heldrungen,Khel''drungen,Kheldrungen,hei er de lun gen,hldrwnghn,hldrwngn,Хелдрунген,Хельдрунген,هلدرونغن,هلدرونگن,黑尔德伦根', 51.3020800, 11.2181600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36371, 'Helbra', 'Helbra', 'Helbra,Khel''bra,Khelbra,hei er bu la,Хелбра,Хельбра,黑尔布拉', 51.5500000, 11.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36372, 'Heitersheim', 'Heitersheim', 'Chaiterschaim,Gajtersgajm,Haytershaym,Khajterskhajm,hai te si hai mu,haytrshaym,haytrzhaym,Χάιτερσχαϊμ,Гайтерсгайм,Хайтерсхайм,Хајтерсхајм,Հայտերսհայմ,هايترسهايم,هایترزهایم,海特斯海姆', 47.8746800, 7.6572100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36373, 'Heistenbach', 'Heistenbach', '', 50.3793300, 7.9862900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36374, 'Heist', 'Heist', 'Heist', 53.6500000, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36375, 'Heisdorf', 'Heisdorf', '', 50.1333300, 6.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36376, 'Heinzenhausen', 'Heinzenhausen', 'Khajncenkhauzen,hai en cen hao sen,Хайнценхаузен,Хајнценхаузен,海恩岑豪森', 49.6333300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36377, 'Heinzenberg', 'Heinzenberg', 'Khajncenberg,hai yin cen bei ge,Хайнценберг,Хајнценберг,海因岑贝格', 49.8166700, 7.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36378, 'Heinzenbach', 'Heinzenbach', 'Heinzenbach,Heinzenberg', 49.9666700, 7.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36379, 'Heinsen', 'Heinsen', '', 52.0625700, 9.6631600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36380, 'Heinsen', 'Heinsen', 'Khajnsen,Khajnzen,hai en sen,hainzen,Хайнзен,Хајнсен,ハインゼン,海恩森', 51.8833300, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36381, 'Heinsberg', 'Heinsberg', 'Heinsberg,Heinsburg,Khajnsberg,hai yin si bei ge,haynzbrg,Хайнсберг,Хајнсберг,هاینزبرگ,海因斯贝格', 51.0635800, 6.0998000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36382, 'Heinrichsthal', 'Heinrichsthal', '', 50.0710800, 9.3429800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36383, 'Heinkenborstel', 'Heinkenborstel', 'Heinkenborstel', 54.1333300, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36384, 'Heiningen', 'Heiningen', '', 52.0693800, 10.5552900, 'DE', '2016-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36385, 'Heiningen', 'Heiningen', '', 48.6617700, 9.6497700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36386, 'Heinersreuth', 'Heinersreuth', 'Gajnersrojt,Haynersroyt,Khajnersrojt,hai nei er si luo yi te,hainasuroito,Гайнерсройт,Хайнерсройт,Хајнерсројт,Հայներսրոյտ,ハイナースロイト,海内尔斯罗伊特', 49.9666700, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36387, 'Heinersdorf', 'Heinersdorf', 'Berlin-Heinersdorf,Khajnersdorf,Хайнерсдорф', 52.5717300, 13.4375700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36388, 'Heinersbrück', 'Heinersbruck', 'Heinersbruck,Heinersbrück,Most,Móst', 51.8198600, 14.5074000, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36389, 'Heinböckel', 'Heinboeckel', 'Heinbockel,Heinböckel', 53.5745700, 9.3264400, 'DE', '2017-07-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36390, 'Heinade', 'Heinade', 'Khajnade,hai na de,hainade,Хайнаде,Хајнаде,ハイナーデ,海纳德', 51.8333300, 9.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36391, 'Heimsheim', 'Heimsheim', 'Gajmsgajm,Haymshaym,Heimsheim,Khajmskhajm,hai mu si hai mu,haymshaym,haymzhaym,Гаймсгайм,Хаймсхайм,Хајмсхајм,Հայմսհայմ,هايمسهايم,هایمزهایم,海姆斯海姆', 48.8065600, 8.8674400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36392, 'Heimertingen', 'Heimertingen', 'Gajmertingen,Khajmertingen,hai mei er ting gen,Гаймертінген,Хаймертинген,Хајмертинген,Հայմերթինգեն,海梅尔廷根', 48.0333300, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36393, 'Heimenkirch', 'Heimenkirch', 'Heimenkirch', 47.6295900, 9.9030400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36394, 'Heimbuchenthal', 'Heimbuchenthal', 'Gajmbukhental'',Haymbuxental,Khajmbukhental,Khajmbukhental'',hai en bu heng ta er,haimubuhyentaru,Гаймбухенталь,Хаймбухенталь,Хајмбухентал,Հայմբուխենտալ,ハイムブーヒェンタール,海恩布亨塔尔', 49.8891700, 9.2955600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36395, 'Heimbach', 'Heimbach', 'Heimbach,Heimisch,Khajmbakh,hai en ba,haymbakh,Хаймбах,Хајмбах,هایمباخ,海恩巴', 50.6369300, 6.4689600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36396, 'Heimbach', 'Heimbach', '', 50.4500000, 7.5333300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36397, 'Heimbach', 'Heimbach', 'Khajmbakh,Хаймбах,Хајмбах', 49.6166700, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36398, 'Heilshoop', 'Heilshoop', 'Heilshoop', 53.8833300, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36399, 'Heilsbronn', 'Heilsbronn', 'Gajl''sbronn,Haylsbron,Heilsbronn,Khajl''sbronn,Khajlsbron,hai er si bu long,hairusuburon,haylsbrwn,haylzbrwn,Гайльсбронн,Хайлсброн,Хайльсбронн,Хајлсброн,Հայլսբրոն,هايلسبرون,هایلزبرون,ハイルスブロン,海尔斯布龙', 49.3357200, 10.7874100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36400, 'Heiligkreuzsteinach', 'Heiligkreuzsteinach', 'Gajligrojcshtajnakh,Heiligkreuzsteinach,Khajligkrojcshtajnakh,Khajlikrojcshtajnakh,hai li ge ke luo yi ci si tai na,hairihikuroitsushutainaha,Гайлігройцштайнах,Хайлигкройцштайнах,Хајликројцштајнах,ハイリヒクロイツシュタイナハ,海利格克罗伊茨斯泰纳', 49.4833300, 8.7950000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36401, 'Heiligenstedtenerkamp', 'Heiligenstedtenerkamp', 'Heiligenstedtenerkamp', 53.8995900, 9.4681400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36402, 'Heiligenstedten', 'Heiligenstedten', 'Heiligenstedten', 53.9326400, 9.4746200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36403, 'Heilbad Heiligenstadt', 'Heilbad Heiligenstadt', 'Hagiopolis in Eichsfeldia,Heilbad Heiligenstadt,Heiligenstadt,Khajl''bad-Khajligenshtadt,Khajlbad Khajligenshtat,hai er ba de hai li gen si ta te,haylbad haylyghnshtat,Хайльбад-Хайлигенштадт,Хајлбад Хајлигенштат,هايلباد هايليغنشتات,هایلباد هایلیگن‌اشتات,海尔巴德海利根斯塔特', 51.3781900, 10.1374400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36404, 'Heiligenstadt', 'Heiligenstadt', 'Heiligenstadt', 49.8630300, 11.1718500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36405, 'Heiligensee', 'Heiligensee', 'Berlin-Heiligensee,Kolonie Neu-Heiligensee', 52.6144900, 13.2450100, 'DE', '2013-02-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36406, 'Heiligenroth', 'Heiligenroth', '', 50.4500000, 7.8666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36407, 'Heiligenmoschel', 'Heiligenmoschel', '', 49.5500000, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36408, 'Heiligenhaus', 'Heiligenhaus', 'Gajligengaus,Hayligenhaus,Heiligenhaus,Hillijehoes,Khajligenkhaus,Stadt Heiligenhaus,hai li gen hao si,haylyghnhaws,Гайлігенгаус,Хайлигенхаус,Хајлигенхаус,هايليغنهاوس,هایلیگن‌هاوس,海利根豪斯', 51.3266200, 6.9710600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36409, 'Heiligenhafen', 'Heiligenhafen', 'Heiligenhafen,Khajligenkhafen,hai li gen ha fen,haylyghnhafn,Хайлигенхафен,Хајлигенхафен,هايليغنهافن,هایلیگن‌هافن,海利根哈芬', 54.3696400, 10.9802200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36410, 'Heiligengrabe', 'Heiligengrabe', 'Hayligengrabe,Khajligengrabe,hai li gen la bei,Хайлигенграбе,Хајлигенграбе,Հայլիգենգրաբե,海利根拉贝', 53.1446100, 12.3625400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36411, 'Heiligenberg', 'Heiligenberg', '', 47.8209400, 9.3128000, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36412, 'Heilenbach', 'Heilenbach', '', 50.0666700, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36413, 'Heilbronn', 'Heilbronn', 'Chailmpron,Gajl''bronn,Hailprunna,Hajlbrono,Heilbronas,Heilbronn,Heilbronn Neckar,Khajl''bronn,Khajlbron,hai er bu long,hailbeulon,hailbroni,hairuburon,haylbrwn,hyylbrwn,Χαϊλμπρόν,Гайльбронн,Хайлброн,Хайльбронн,Хајлброн,היילברון,هايلبرون,هایلبرون,ہیلبرون,ჰაილბრონი,ハイルブロン,海尔布隆,하일브론', 49.1399500, 9.2205400, 'DE', '2014-01-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36414, 'Heilberscheid', 'Heilberscheid', '', 50.4166700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36415, 'Heilbach', 'Heilbach', '', 50.0500000, 6.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36416, 'Heikendorf', 'Heikendorf', 'Khajkendorf,hai ken duo fu,Хайкендорф,Хајкендорф,海肯多夫', 54.3666700, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36417, 'Heigenbrücken', 'Heigenbruecken', 'Gajgenbrjukken,Heigenbruecken,Heigenbrücken,Khajgenbriken,Khajgenbrjukken,hai gen bu lu ken,haigenburyukken,Гайгенбрюккен,Хайгенбрюккен,Хајгенбрикен,Հայգենբրյուքեն,ハイゲンブリュッケン,海根布吕肯', 50.0282000, 9.3711600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36418, 'Heidweiler', 'Heidweiler', '', 49.9166700, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36419, 'Heidmühlen', 'Heidmuhlen', '', 53.9666700, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36420, 'Heidgraben', 'Heidgraben', 'Heidgraben,Khajdgraben,hai de ge la ben,Хайдграбен,Хајдграбен,海德格拉本', 53.7078700, 9.6809900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36421, 'Heidesheim', 'Heidesheim', '', 49.5824700, 8.1953700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36422, 'Heidersdorf', 'Heidersdorf', 'Khajdersdorf,hai de er si duo fu,Хайдерсдорф,Хајдерсдорф,海德尔斯多夫', 50.6833300, 13.4000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36423, 'Heidenheim an der Brenz', 'Heidenheim an der Brenz', 'Chainten''chaim,Gajdengajm-na-Brenci,Haidenhaim Brencal,Heidenheim,Heidenheim an der Brenz,Heidenheim in Wurttemberg,Heidenheim in Württemberg,Hoana,Khajdenkhajm an der Brenc,Khajdenkhajm na Brencu,Khajdenkhajm-an-der-Brenc,Khajdenkhajm-na-Brence,hai deng hai mu,haydnhaym,haydnhaym an dr brnts,Χάιντενχαϊμ,Гайденгайм-на-Бренці,Хайденхайм ан дер Бренц,Хайденхайм-ан-дер-Бренц,Хайденхайм-на-Бренце,Хајденхајм на Бренцу,هايدنهايم,هایدنهایم آن در برنتس,海登海姆', 48.6779800, 10.1516200, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36424, 'Heidenheim', 'Heidenheim', 'Gajdengajm,Haydenhaym,Heidenheim,Khajdenkhajm,ZNI,Гайденгайм,Хайденхайм,Хајденхајм,Հայդենհայմ', 49.0171900, 10.7434700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36425, 'Heidenburg', 'Heidenburg', '', 49.8000000, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36426, 'Heidenau', 'Heidenau', '', 53.3166700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36427, 'Heidenau', 'Heidenau', 'Khajdenau,hai de nao,haydhnaw,Хайденау,Хајденау,هایدهناو,海德瑙', 50.9722100, 13.8674100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36428, 'Heiden', 'Heiden', '', 51.8333300, 6.9333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36429, 'Heidelberg', 'Heidelberg', 'Chaidelvergi,Gajdel''berg,Gejdel''berg,Gorad Gejdehl''berg,HDB,Haidelbergu,Haidlbaersch,Haidlbärsch,Heidelbarg,Heidelberch,Heidelberg,Heidelberga,Heidelbergas,Heidelburg,Heidlberg,Hejdelbergo,Heydelberg,Heydelberq,Héydélbérg,Khajdel''berg,Khajdelberg,hai de bao,haidelbeleukeu,haidelbergi,haideruberuku,hayadelabarga,haydlbrg,haydlbrgh,hyydlbrg,Χαϊδελβέργη,Гайдельберг,Гейдельберг,Горад Гейдэльберг,Хайделберг,Хайдельберг,Хајделберг,היידלבערג,היידלברג,هايدلبرغ,هایدلبرگ,ہائیڈلبرگ,हायडेलबर्ग,ჰაიდელბერგი,ハイデルベルク,海德堡,하이델베르크', 49.4076800, 8.6907900, 'DE', '2013-05-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36430, 'Heidekamp', 'Heidekamp', '', 53.8500000, 10.5000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36431, 'Heideck', 'Heideck', 'Gajdek,Heideck,Heydeck,Khajdek,hai de ke,haidekku,haydk,Гайдек,Хайдек,Хајдек,Հայդեք,هايدك,هایدک,ハイデック,海德克', 49.1336500, 11.1272600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36432, 'Heide', 'Heide', 'HEI,Heid,Heide,Khajde,haide,haydh,Хайде,Хајде,هایده,ハイデ', 54.1957900, 9.0988000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36433, 'Heichelheim', 'Heichelheim', '', 51.0500000, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36434, 'Hehlen', 'Hehlen', 'Khelen,hei lun,heren,Хелен,ヘーレン,黑伦', 51.9885800, 9.4700400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36435, 'Hefersweiler', 'Hefersweiler', 'Khefersvajler,hei fu er si wei lei,Хеферсвайлер,Хеферсвајлер,黑弗尔斯韦勒', 49.6000000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36436, 'Heeßen', 'Heessen', '', 52.2321100, 9.0964200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36437, 'Heeslingen', 'Heeslingen', 'Heessel,Heeßel,Kheslingen,hei si lin gen,hesuringen,Хеслинген,ヘースリンゲン,黑斯林根', 53.3166700, 9.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36438, 'Heemsen', 'Heemsen', 'Heemsen,Khemsen,Khemzen,hei mu sen,hemuzen,Хемзен,Хемсен,ヘームゼン,黑姆森', 52.7000000, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36439, 'Heek', 'Heek', 'Hek,Hêk', 52.1166700, 7.1000000, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36440, 'Heede', 'Heede', '', 53.7833300, 9.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36441, 'Heede', 'Heede', '', 52.9920500, 7.2983000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36442, 'Hedwigenkoog', 'Hedwigenkoog', '', 54.1833300, 8.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36443, 'Hedersleben', 'Hedersleben', '', 51.8594300, 11.2500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36444, 'Hedersleben', 'Hedersleben', 'Hedersleben,Hedersleben (Eisleben),Hedersleben (Mansfelder Land),Khedersleben (Mansfel''d),Khedersleben (Mansfeld-Zidkharc),Хедерслебен (Мансфелд-Зидхарц),Хедерслебен (Мансфельд)', 51.5489100, 11.6498300, 'DE', '2014-12-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36445, 'Hedeper', 'Hedeper', '', 52.0666700, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36446, 'Heddesheim', 'Heddesheim', 'Geddesgajm,Heddesheim,Kheddeskhajm,Khedeskhajm,heddesuhaimu,hei de si hai mu,Геддесгайм,Хеддесхайм,Хедесхајм,ヘッデスハイム,黑德斯海姆', 49.5055600, 8.6036100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36447, 'Heddesbach', 'Heddesbach', 'Geddesbakh,Kheddesbakh,Khedesbakh,heddesubahha,hei de si ba he,Геддесбах,Хеддесбах,Хедесбах,ヘッデスバッハ,黑德斯巴赫', 49.4802800, 8.8280600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36448, 'Heddert', 'Heddert', '', 49.6500000, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36449, 'Hecklingen', 'Hecklingen', 'Hecklingen,Kheklingen,hei ke lin gen,hklynghn,hklyngn,Хеклинген,هكلينغن,هکلینگن,黑克林根', 51.8470500, 11.5341600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36450, 'Heckhuscheid', 'Heckhuscheid', '', 50.1787700, 6.2226400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36451, 'Heckenmünster', 'Heckenmunster', '', 49.9000000, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36452, 'Hecken', 'Hecken', '', 49.9166700, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36453, 'Hechthausen', 'Hechthausen', 'Gemeen Heckthusen,Hechthausen,Khekhtauzen,Khekhtkhauzen,hei xi tao sen,Хехтаузен,Хехтхаузен,黑希陶森', 53.6404100, 9.2394200, 'DE', '2011-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36454, 'Hechingen', 'Hechingen', 'Gekhingen,Khekhingen,hei xin gen,hkyngn,hshynghn,hshyngn,Гехінген,Хехинген,הכינגן,هشينغن,هشینگن,黑欣根', 48.3514900, 8.9631700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36455, 'Hebertshausen', 'Hebertshausen', 'Gebertsgauzen,Hebazausn,Hebertshauzen,Khebertskhauzen,hei bei er ci hao sen,hrbrtshawzn,Гебертсгаузен,Хебертсхаузен,Հեբերտսհաուզեն,هربرتسهاوزن,黑贝尔茨豪森', 48.2895900, 11.4652600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36456, 'Hebertsfelden', 'Hebertsfelden', 'Gebertsfel''den,Khebertsfel''den,Khebertsfelden,hbrtsfldn,hei bei er ci fei er deng,Гебертсфельден,Хебертсфелден,Хебертсфельден,Հեբերթսֆելդեն,هبرتسفلدن,黑贝尔茨费尔登', 48.4059600, 12.8225900, 'DE', '2012-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36457, 'Haynrode', 'Haynrode', 'Khajnrode,hai en luo de,Хайнроде,Хајнроде,海恩罗德', 51.4454200, 10.4454400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36458, 'Hayingen', 'Hayingen', 'Gaingen,Havingen,Khajingen,hai yin gen,haynghn,haynygn,Гаїнген,Хайинген,Хајинген,هاينغن,هاینیگن,海因根', 48.2753100, 9.4776000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36459, 'Hawangen', 'Hawangen', 'Gavangen,Havangen,Khavangen,ha wan gen,Гаванген,Хаванген,Հավանգեն,哈万根', 47.9666700, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36460, 'Havixbeck', 'Havixbeck', 'Gafiksbek,Khafiksbek,Khaviksbek,ha fei ke si bei ke,Гафіксбек,Хавиксбек,Хафиксбек,哈菲克斯贝克', 51.9833300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36461, 'Havetoft', 'Havetoft', 'Havetoft,Khafetoft,Khavetoft,ha fei tuo fu te,Хаветофт,Хафетофт,哈费托夫特', 54.6500000, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36462, 'Haverlah', 'Haverlah', '', 52.0666700, 10.1666700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36463, 'Havelberg', 'Havelberg', 'Khafel''berg,Khafelberg,ha fu er bei ge,haflbrgh,hawlbrg,Хафелберг,Хафельберг,هافلبرغ,هاولبرگ,哈弗尔贝格', 52.8308800, 12.0755200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36464, 'Havekost', 'Havekost', '', 53.5500000, 10.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36465, 'Hauzenberg', 'Hauzenberg', 'Gaucenberg,Hauzenberg,Khaucenberg,hao cen bei ge,hawtsbrg,hawtsnbrgh,Гауценберг,Хауценберг,Հաուցենբերգ,هاوتسبرگ,هاوتسنبرغ,豪岑贝格', 48.6495700, 13.6264500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36466, 'Hauteroda', 'Hauteroda', 'Hauteroda', 51.2666700, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36467, 'Hausweiler', 'Hausweiler', 'Khausvajler,hao si wei lei,Хаусвайлер,Хаусвајлер,豪斯韦勒', 49.6500000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36468, 'Hauswalde', 'Hauswalde', 'Bretnig-Hauswalde,Hauswalde', 51.1521200, 14.0863000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36469, 'Hausten', 'Hausten', '', 50.4000000, 7.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36470, 'Haussömmern', 'Haussommern', 'Haussoemmern,Haussömmern', 51.1833300, 10.8166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36471, 'Hausham', 'Hausham', '', 47.7466000, 11.8406900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36472, 'Häusern', 'Hausern', 'Gojzern,Haeusern,Häusern,Khojsern,Khojzern,huo yi sai er en,Гойзерн,Хойзерн,Хојсерн,霍伊塞尔恩', 47.7500000, 8.1666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36473, 'Hausen ob Verena', 'Hausen ob Verena', 'Hausen,Hausen ob Verena,Khauzen ob Ferena,Khauzen-ob-Ferena,hao sen ao bu fei lei na,Хаузен об Ферена,Хаузен-об-Ферена,豪森奥布费雷纳', 48.0536700, 8.7246600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36474, 'Hausen am Tann', 'Hausen am Tann', 'Gauzen-am-Tann,Khauzen am Tan,Khauzen-am-Tan,hao sen a mu tan,Гаузен-ам-Танн,Хаузен ам Тан,Хаузен-ам-Тан,豪森阿姆坦', 48.1983300, 8.8363100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36475, 'Hausen am Bussen', 'Hausen am Bussen', 'Hausen', 48.2119200, 9.6251400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36476, 'Hausen', 'Hausen', '', 51.3833300, 10.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36477, 'Hausen', 'Hausen', '', 50.5424200, 7.4070300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36478, 'Hausen', 'Hausen', 'Hausen,Hausen Roth', 50.5064000, 10.1266100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36479, 'Hausen', 'Hausen', '', 49.8697200, 9.2102800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36480, 'Hausen', 'Hausen', '', 49.8666700, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36481, 'Hausen', 'Hausen', '', 49.6894500, 11.0321600, 'DE', '2012-11-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36482, 'Hausen', 'Hausen', '', 48.8595300, 12.0063000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36483, 'Hausen', 'Hausen', '', 47.6812800, 7.8398600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36484, 'Hausbay', 'Hausbay', '', 50.1068500, 7.5592800, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36485, 'Hausach', 'Hausach', 'Gauzakh,Hausach,Khauzakh,hao sa,hawzakh,Гаузах,Хаузах,هاوزاخ,豪萨', 48.2842600, 8.1760200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36486, 'Hauroth', 'Hauroth', '', 50.2500000, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36487, 'Hauptstuhl', 'Hauptstuhl', '', 49.4000000, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36488, 'Haunsheim', 'Haunsheim', 'Gaunsgajm,Haunshaym,Khaunskhajm,hao en si hai mu,hawnshaym,Гаунсгайм,Хаунсхайм,Хаунсхајм,Հաունսհայմ,هاونسهایم,豪恩斯海姆', 48.5997700, 10.3740100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36489, 'Haundorf', 'Haundorf', 'Gaundorf,Haundorf,Khaundorf,hao en duo fu,Гаундорф,Хаундорф,Հաունդորֆ,豪恩多夫', 49.1759800, 10.7712400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36490, 'Hauenstein', 'Hauenstein', 'Hauenstein,Hauenstein Kreis Pirmasens', 49.1921100, 7.8549200, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36491, 'Hatzfeld', 'Hatzfeld', 'Gacfel''d,Hatzfeld,Khacfel''d,Khacfeld,ha ci fei er de,hatsfld,hattsuferuto,Гацфельд,Хацфелд,Хацфельд,هاتسفلد,ハッツフェルト,哈茨费尔德', 50.9933400, 8.5457000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36492, 'Hatzenport', 'Hatzenport', '', 50.2333300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36493, 'Hatzenbühl', 'Hatzenbuhl', 'Hatzenbuehl,Hatzenbühl', 49.1111100, 8.2452800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36494, 'Hattstedtermarsch', 'Hattstedtermarsch', 'Haatstinger Maeaersch,Haatstinger Määrsch,Hatsted Marsk,Hattstedtermarsch,Khatshtedtermarsh,Khatshtetermarsh,ha ci te er ma er shi,Хатштедтермарш,Хатштетермарш,哈茨特尔马尔施', 54.5500000, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36495, 'Hattstedt', 'Hattstedt', 'Haatst,Hatsted,Hattstedt,Khatshtedt,Khatshtet,ha ci te,Хатштедт,Хатштет,哈茨特', 54.5333300, 9.0333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36496, 'Hattorf', 'Hattorf', 'Hattoerp,Hattorp,Hattorpp [a. 952],Hattörp', 51.6503500, 10.2368100, 'DE', '2011-03-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36497, 'Hattingen', 'Hattingen', 'Chatin''nken,Hattingen,Khatingen,Khattingen,ha ting gen,hatyngn,Χάτινγκεν,Хатинген,Хаттинген,هاتینگن,ہیٹنگن,哈廷根', 51.3989400, 7.1855700, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36498, 'Hattgenstein', 'Hattgenstein', '', 49.7000000, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36499, 'Hattersheim', 'Hattersheim', 'Hattersheim', 50.0785400, 8.4755200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36500, 'Hattenhofen', 'Hattenhofen', '', 48.6664800, 9.5745600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36501, 'Hattenhofen', 'Hattenhofen', '', 48.2223100, 11.1155100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36502, 'Hatten', 'Hatten', '', 53.0500000, 8.3833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36503, 'Haste', 'Haste', '', 52.3810500, 9.3928000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36504, 'Haßmoor', 'Hassmoor', '', 54.3000000, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36505, 'Haßmersheim', 'Hassmersheim', 'Gasmersgajm,Hassmersheim,Hassnerheim,Haßmersheim,Haßnerheim,Khasmerskhajm,ha si mei er si hai mu,hasumasuhaimu,Гасмерсгайм,Хасмерсхайм,Хасмерсхајм,ハスマースハイム,哈斯梅尔斯海姆', 49.3000000, 9.1500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36506, 'Haßloch', 'Hassloch', 'Hafsloch,Hassloch,Haßloch,Khaslokh,hasurohho,Хаслох,ハースロッホ', 49.3627800, 8.2580600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36507, 'Haßleben', 'Hassleben', 'Hassleben,Haßleben,Khasleben,ha si lai ben,Хаслебен,哈斯莱本', 51.1087800, 10.9963700, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36508, 'Haßfurt', 'Hassfurt', 'Gasfurt,Hassfurt,Haszfurt,Haszfurth,Haßfurt,Khasfurt,ha si fu er te,hasfwrt,Гасфурт,Хасфурт,Հասֆուրթ,هاسفورت,哈斯富尔特', 50.0352100, 10.5156000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36509, 'Hassendorf', 'Hassendorf', '', 53.1085900, 9.2648200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36510, 'Hasselfelde', 'Hasselfelde', 'Hasselfelde,Khaselfelde,Khassel''fel''de,Хаселфелде,Хассельфельде', 51.6905100, 10.8537300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36511, 'Hasselberg', 'Hasselberg', '', 54.7166700, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36512, 'Hasselbach', 'Hasselbach', '', 50.7166700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36513, 'Hasselbach', 'Hasselbach', '', 50.0333300, 7.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36514, 'Hassel', 'Hassel', '', 52.6968800, 8.8319800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36515, 'Hassel', 'Hassel', '', 52.6395200, 11.9263500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36516, 'Haßbergen', 'Hassbergen', '', 52.7333300, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36517, 'Hasloh', 'Hasloh', 'Hasloh,Khaslo,ha si luo,Хасло,哈斯洛', 53.6947100, 9.9168200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36518, 'Hasloch', 'Hasloch', 'Gaslokh,Haslox,Khaslokh,Гаслох,Хаслох,Հասլոխ', 49.7919400, 9.4936100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36519, 'Haslach', 'Haslach', '', 48.5653100, 8.0565800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36520, 'Haserich', 'Haserich', '', 50.0333300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36521, 'Hasenmoor', 'Hasenmoor', 'Hasenmoor', 53.9000000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36522, 'Hasenkrug', 'Hasenkrug', '', 53.9833300, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36523, 'Haselünne', 'Haseluenne', 'Haseluenne,Haselunne,Haselünne,Khazeline,Khazeljunne,ha sai lu nei,hazlwnh,Хазелине,Хазелюнне,هازلونه,哈塞吕内', 52.6741200, 7.4846000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36524, 'Haselund', 'Haselund', 'Haselund', 54.6000000, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36525, 'Haselhorst', 'Haselhorst', 'Berlin-Haselhorst,Haselhorst', 52.5440900, 13.2374300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36526, 'Haseldorf', 'Haseldorf', 'Haseldorf', 53.6378000, 9.5915100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36527, 'Haselbach', 'Haselbach', '', 51.0666700, 12.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36528, 'Haselbach', 'Haselbach', '', 49.0035300, 12.6918300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36529, 'Haselbach', 'Haselbach', '', 48.6456400, 13.3895600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36530, 'Haselau', 'Haselau', 'Haselau,Khazelau,ha sai lao,Хазелау,哈塞劳', 53.6618100, 9.6201000, 'DE', '2011-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36531, 'Hasel', 'Hasel', '', 47.6534200, 7.8972000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36532, 'Haschbach am Remigiusberg', 'Haschbach am Remigiusberg', 'Haschbach,Haschbach am Remigiusberg,Khashbakh na Remigijuzbergu,Khashbakh-am-Remigiusberg,lei mi ji wu si bei ge shan lu ha shi ba he,Хашбах на Ремигијузбергу,Хашбах-ам-Ремигиусберг,雷米吉乌斯贝格山麓哈施巴赫', 49.5333300, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36533, 'Hasborn', 'Hasborn', 'Khasborn,ha si bo er en,Хасборн,哈斯博尔恩', 50.0500000, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36534, 'Hasbergen', 'Hasbergen', 'Khasbergen,Хасберген', 52.2375400, 7.9611400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36535, 'Harzungen', 'Harzungen', '', 51.5500000, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36536, 'Harzgerode', 'Harzgerode', 'Garcgerode,Harzgerode,Kharcgerode,ha er ci ge luo de,hartsghrwdh,hartsgrwdh,Гарцгероде,Харцгероде,هارتسغروده,هارتسگروده,哈尔茨格罗德', 51.6418900, 11.1433000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36537, 'Harxheim', 'Harxheim', '', 49.9052800, 8.2641700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36538, 'Hartmannsdorf', 'Hartmannsdorf', '', 50.9608300, 11.9756600, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36539, 'Hartmannsdorf', 'Hartmannsdorf', '', 50.9000000, 12.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36540, 'Hartmannsdorf', 'Hartmannsdorf', '', 50.9000000, 12.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36541, 'Hartmannsdorf', 'Hartmannsdorf', '', 50.7580400, 12.4268700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36542, 'Härtlingen', 'Haertlingen', '', 50.5241700, 7.9163900, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36543, 'Hartheim', 'Hartheim', '', 47.9333300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36544, 'Harthausen', 'Harthausen', 'Khartauzen,Khartkhauzen,ha er tao sen,Хартаузен,Хартхаузен,哈尔陶森', 49.2941700, 8.3450000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36545, 'Hartha', 'Hartha', 'Harta,Hartha,Kharta,ha er ta,harta,hrata,Харта,هارتا,هراتا,哈尔塔', 51.0986300, 12.9739100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36546, 'Hartenstein', 'Hartenstein', 'Hartenstein', 50.6623600, 12.6696600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36547, 'Hartenstein', 'Hartenstein', '', 49.6000000, 11.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36548, 'Hartenholm', 'Hartenholm', 'Hartenholm,Khartenkhol''m,Khartenkholm,ha er teng huo er mu,Хартенхолм,Хартенхольм,哈尔滕霍尔姆', 53.8985600, 10.0595300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36549, 'Hartenfels', 'Hartenfels', '', 50.5738900, 7.7872200, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36550, 'Harsum', 'Harsum', 'Hardessem,Hassen,Kharsum,Kharzum,ha er su mu,Харзум,Харсум,哈尔苏姆', 52.2104500, 9.9648600, 'DE', '2014-07-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36551, 'Harspelt', 'Harspelt', '', 50.1333300, 6.1666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36552, 'Harsleben', 'Harsleben', 'Harsleben', 51.8666700, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36553, 'Harsewinkel', 'Harsewinkel', 'Garzevinkel'',Harsewinkel,Haswinkil,Hoswinkil,Kharsevinkel,Kharzevinkel'',ha er sai wen ke er,harzhfynkl,Гарзевінкель,Харзевинкель,Харсевинкел,هارزهفينكل,هارزه‌وینکل,哈尔塞温克尔', 51.9622400, 8.2276600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36554, 'Harsefeld', 'Harsefeld', 'Harsefeld,Harsfeld,Kharsefeld,Kharzefel''d,ha er sai fei er de,haruzeferuto,Харзефельд,Харсефелд,ハルゼフェルト,哈尔塞费尔德', 53.4539900, 9.5029700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36555, 'Harsdorf', 'Harsdorf', '', 50.0333300, 11.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36556, 'Harscheid', 'Harscheid', '', 50.4598000, 6.8920300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36557, 'Harschbach', 'Harschbach', '', 50.5833300, 7.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36558, 'Harrislee', 'Harrislee', 'Harreslev,Harrislee,Kharisle,Kharrisle,ha li si lai,Харисле,Харрисле,哈里斯莱', 54.8000000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36559, 'Harra', 'Harra', 'Harra,Khara,Kharra,ha la,Хара,Харра,哈拉', 50.4166700, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36560, 'Harpstedt', 'Harpstedt', 'Harpstedt,Kharpshtedt,Kharpshtet,ha er pu si te,Харпштедт,Харпштет,哈尔普斯特', 52.9094200, 8.5896200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36561, 'Harmstorf', 'Harmstorf', '', 53.3500000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36562, 'Harmsdorf', 'Harmsdorf', '', 54.2398600, 10.8330100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36563, 'Harmsdorf', 'Harmsdorf', '', 53.7000000, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36564, 'Hargesheim', 'Hargesheim', 'Khargeskhajm,ha er ge si hai mu,Харгесхайм,Харгесхајм,哈尔格斯海姆', 49.8666700, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36565, 'Hargarten', 'Hargarten', '', 50.1000000, 6.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36566, 'Haren', 'Haren', 'Haren', 52.7926200, 7.2414200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36567, 'Hardt', 'Hardt', '', 50.6333300, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36568, 'Hardt', 'Hardt', 'Hardt', 48.1833300, 8.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36569, 'Hardisleben', 'Hardisleben', '', 51.1535600, 11.4241500, 'DE', '2014-05-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36570, 'Hardheim', 'Hardheim', 'Gardgajm,Khardkhajm,ha de hai mu,harutohaimu,Гардгайм,Хардхайм,Хардхајм,ハルトハイム,哈德海姆', 49.6119400, 9.4719400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36571, 'Hardert', 'Hardert', '', 50.5166700, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36572, 'Hardegsen', 'Hardegsen', 'Hardegsen,Khardegsen,Khardegzen,ha er de ge sen,hardghsn,hardgsn,harudekuzen,Хардегзен,Хардегсен,هاردغسن,هاردگسن,ハルデクゼン,哈尔德格森', 51.6522700, 9.8305000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36573, 'Hardebek', 'Hardebek', 'Hardebek', 53.9885000, 9.8681300, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36574, 'Harburg', 'Harburg', 'Arrondissement de Harburg,Bezirk Harburg,Bezirk Horborg,Distretto di Harburg,Districte dHarburg,Hamburg-Harburg,Hamburgo-Harburgo,Harburg,Harburg an Elbe,Horborg,Kharburg,han bao qu,Харбург,汉堡区', 53.4605700, 9.9838800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36575, 'Harburg', 'Harburg', 'Garburg,Harburgo,Kharburg,habwrg  bayrn,harbwrgh,haruburuku,Гарбург,Харбург,هابورگ، بایرن,هاربورغ,ハールブルク', 48.7867400, 10.6892700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36576, 'Harbke', 'Harbke', 'Harbke,Hertbiki,Kharbke,ha er bu ke,Харбке,哈尔布克', 52.1887700, 11.0462400, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36577, 'Harbarnsen', 'Harbarnsen', '', 51.9833300, 9.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36578, 'Harbach', 'Harbach', '', 50.8500000, 7.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36579, 'Happurg', 'Happurg', 'Gappurg,Khappurg,Khapurg,ha pu er ge,Гаппург,Хаппург,Хапург,Հափուրգ,哈普尔格', 49.4937200, 11.4711900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36580, 'Hanstedt Eins', 'Hanstedt Eins', 'Hanstedt', 53.0464200, 10.3744400, 'DE', '2015-03-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36581, 'Hanstedt', 'Hanstedt', '', 53.2666700, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36582, 'Hanroth', 'Hanroth', '', 50.5833300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36583, 'Hannover', 'Hannover', 'Annobero,Gannovehr,Gannover,Gorad Ganover,HAJ,Hannauver,Hannober,Hannova,Hannover,Hannovera,Hannovere,Hannower,Hannóver,Hanobhar,Hanofer,Hanofér,Hanover,Hanoveri,Hanoveris,Hanovra,Hanovre,Hanovro,Hanower,Hanowery,Hanóver,Hanôver,Honovere,Hànobhar,IHanoveri,Khannover,Khanover,han no wexr,han nuo wei,hanobeo,hanofa,hanophara,hanoveri,hanwfr,hnwbr,Αννόβερο,Ганновер,Ганновэр,Горад Гановер,Ханновер,Хановер,Հաննովեր,האנאווער,הנובר,هانوفر,ھانۆفەر,ہینوور,हानोफर,হানোফার,ฮันโนเวอร์,ჰანოვერი,ハノーファー,汉诺威,漢諾威,하노버', 52.3705200, 9.7332200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36584, 'Hankensbüttel', 'Hankensbuttel', 'Hankensbuettel,Hankensbuttel,Hankensbüttel,Khankensbitel,Khankensbjuttel'',han ken si bi te er,Ханкенсбител,Ханкенсбюттель,汉肯斯比特尔', 52.7333300, 10.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36585, 'Hänigsen', 'Haenigsen', '''Kasperland'',Haehnsen,Haenigsen,Hanigsen,Henighusen [a. 1226],Hähnsen,Hänigsen,Uetze-Haenigsen,Uetze-Hänigsen', 52.4842500, 10.0912900, 'DE', '2014-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36586, 'Hanhofen', 'Hanhofen', '', 49.3166700, 8.3408300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36587, 'Hangen-Weisheim', 'Hangen-Weisheim', '', 49.7102800, 8.1836100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36588, 'Hangard', 'Hangard', '', 49.3826000, 7.2104600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36589, 'Hanerau-Hademarschen', 'Hanerau-Hademarschen', 'Hanerau-Hademarschen,Khanerau-Khademarshen,ha nei lao-ha de ma er shen,Ханерау-Хадемаршен,哈内劳-哈德马尔申', 54.1333300, 9.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36590, 'Handrup', 'Handrup', 'Handrup,Khandrup,han de lu pu,Хандруп,汉德鲁普', 52.5645600, 7.5767900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36591, 'Handorf', 'Handorf', '', 53.3408400, 10.3465200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36592, 'Handewitt', 'Handewitt', 'Handewitt,Hanved,Khandevit,han de wei te,Хандевит,汉德维特', 54.7666700, 9.3333300, 'DE', '2014-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36593, 'Handeloh', 'Handeloh', 'Handoerp,Handörp,Khandelo,Khandelokh,han de luo,Хандело,Ханделох,汉德洛', 53.2456300, 9.8392300, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36594, 'Hanau am Main', 'Hanau am Main', 'Chanaou,Hanau,Hanau am Main,Khanau,hanau,Χάναου,Ханау,ハーナウ', 50.1342300, 8.9141800, 'DE', '2015-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36595, 'Hamweddel', 'Hamweddel', 'Hamweddel', 54.1833300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36596, 'Hamwarde', 'Hamwarde', 'Hamwarde', 53.4500000, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36597, 'Hammoor', 'Hammoor', 'Hammoor', 53.7137800, 10.3220000, 'DE', '2011-08-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36598, 'Hamminkeln', 'Hamminkeln', 'Gamminkel''n,Hamminkeln,Khaminkeln,Khamminkel''n,ha ming ke er en,hamynkln,Гаммінкельн,Хаминкелн,Хамминкельн,هامينكلن,هامینکلن,哈明克尔恩', 51.7326200, 6.5903100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36599, 'Hammerstein', 'Hammerstein', 'Hammerstein', 50.4833300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36600, 'Hammerstedt', 'Hammerstedt', '', 50.9542100, 11.4542800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36601, 'Hammersbach', 'Hammersbach', 'Hammersbach', 50.2166700, 8.9833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36602, 'Hammerbrücke', 'Hammerbruecke', 'Hammerbrucke,Hammerbrücke,Hammerburg', 50.4350400, 12.4150000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36603, 'Hammelburg', 'Hammelburg', 'Gammel''burg,Hamelburg,Hammelburg,Khamelburg,Khammel''burg,ha mo er bao,hamlbwrg,hamlbwrgh,Гаммельбург,Хамелбург,Хаммельбург,Համելբուրգ,هاملبورغ,هاملبورگ,哈默尔堡', 50.1163300, 9.8914300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36604, 'Hammah', 'Hammah', 'Hammoh,Khamakh,Khamma,ha ma,hanma,Хамах,Хамма,ハンマー,哈马', 53.6166700, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36605, 'Hamm', 'Hamm', 'Gamm,Gorad Kham,Hamas,Hamm,Hammona,Kham,Khamm,ha mu,ham,hami,hamu,Гамм,Горад Хам,Хам,Хамм,هام,ہام,ჰამი,ハム,哈姆,함', 51.6803300, 7.8208900, 'DE', '2011-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36606, 'Hamm', 'Hamm', 'Hamm', 50.7653100, 7.6776100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36607, 'Hamm', 'Hamm', '', 50.0166700, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36608, 'Hamersen', 'Hamersen', '', 53.2559200, 9.4803400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36609, 'Hameln', 'Hameln', 'Gamel''n,Gorad Khamel''n,Hamala,Hamelen,Hamelin,Hameln,Hamelín,Khamel''n,Khameln,ZEZ,ha mo er en,hamelleun,hamerun,hamln,hmlyn,Гамельн,Горад Хамельн,Хамелн,Хамельн,המלין,هاملن,ハーメルン,哈默爾恩,하멜른', 52.1039700, 9.3562300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36610, 'Hämelhausen', 'Hamelhausen', '', 52.7808600, 9.2829300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36611, 'Hamdorf', 'Hamdorf', '', 54.2252200, 9.5186600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36612, 'Wandsbek', 'Wandsbek', 'Hamburg-Wandsbek,Vandsbek,Wandsbek,Вандсбек', 53.5833400, 10.0830500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36613, 'Marienthal', 'Marienthal', 'Hamburg-Marienthal', 53.5666700, 10.0833300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36614, 'Hamburg-Mitte', 'Hamburg-Mitte', 'Arrondissement de Hambourg-Mitte,Bezirk Hamburg-Mitte,Distretto di Hamburg-Mitte,Hamborg-Mitt,Hamburg-Centru,Hamburg-Mitte,Hamburgo-Centro,Hamburgum Media Urbs,Khamburg-Mite,han bao zhong qu,Хамбург-Мите,汉堡中区', 53.5500000, 10.0166700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36615, 'Eimsbüttel', 'Eimsbuettel', 'Ajmsbitel,Ajmsbjuttel'',Arrondissement dEimsbuettel,Arrondissement dEimsbüttel,Bezirk Eimsbuettel,Bezirk Eimsbüttel,Distretto di Eimsbuettel,Distretto di Eimsbüttel,Eimbueddel,Eimbüddel,Eimsbuettel,Eimsbüttel,Hamburg-Eimsbuettel,Hamburg-Eimsbüttel,ai mu si bi te er qu,Аймсбюттель,Ајмсбител,艾姆斯比特尔区', 53.5666700, 9.9833300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36616, 'Altona', 'Altona', 'Al''tona,Altno,Altona,Arrondissement dAltona,Bezirk Altona,Distretto di Altona,Districte dAltona,Hamburg-Altona,Hamburgo-Altona,a er tuo na qu,altwna  hambwrg,hanburuku=arutona,Алтона,Альтона,אלטונה,التونا، هامبورگ,ハンブルク＝アルトナ,阿尔托纳区', 53.5500000, 9.9333300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36617, 'Hamburg', 'Hamburg', 'Amborg,Ambourgo,Amburgo,Amburgu,Augusta Gambriviorum,Ciutat d''Hamburg,Estat d''Hamburg,Gamburg,Gorad Gamburg,HAM,HH,Hamboarch,Hamboerg,Hamboerj,Hamborg,Hambourg,Hamburch,Hamburg,Hamburga,Hamburgas,Hamburgo,Hamburgu,Hamburgum,Hamburk,Hambuurich,Hambörg,Hambörj,Hambùrk,Hambûrg,Hamepuka,Hammaburg [a. 832],Hampuri,Hanburgo,Khamburg,ham bur k,hambuleukeu,hamburgi,hambwrg,hambwrgh,han bao,han bao shi,hanburuku,hemburga,hmbwrg,hyambarg,hʼambwrg,Ħamburg,Αμβούργο,Гамбург,Гамбурґ,Горад Гамбург,Хамбург,Համբուրգ,האַמבורג,המבורג,هامبورغ,هامبورگ,ہymbrg,ہیمبرگ,ܗܡܒܘܪܓ,हॅम्बुर्ग,ಹ್ಯಾಂಬರ್ಗ್,ฮัมบูร์ก,ჰამბურგი,ハンブルク,汉堡,汉堡市,함부르크', 53.5753200, 10.0153400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36618, 'Hambühren', 'Hambuhren', 'Hambuehren,Hambühren,Khambiren,Khambjuren,han bi he lun,Хамбирен,Хамбюрен,汉比赫伦', 52.6333300, 9.9833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36619, 'Hambuch', 'Hambuch', 'Khambukh,han bu,Хамбух,汉布', 50.2248000, 7.1823400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36620, 'Hambrücken', 'Hambrucken', 'Gambrjukken,Hambruecken,Hambrücken,Khambriken,Khambrjuken,han bu lu ken,Гамбрюккен,Хамбрикен,Хамбрюкен,汉布吕肯', 49.1900000, 8.5405600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36621, 'Hambergen', 'Hambergen', 'Gemeen Hambargen,Khambergen,han bei er gen,Хамберген,汉贝尔根', 53.3082600, 8.8252000, 'DE', '2013-05-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36622, 'Hamberge', 'Hamberge', '', 53.8333300, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36623, 'Hambach', 'Hambach', '', 50.4000000, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36624, 'Halvesbostel', 'Halvesbostel', '', 53.3552700, 9.5984800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36625, 'Halver', 'Halver', 'Gal''fer,Halvara,Halver,Khal''fer,Khalver,ha er fei er,halfr,Гальфер,Халвер,Хальфер,هالفر,哈尔费尔', 51.1861200, 7.4981700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36626, 'Haltern', 'Haltern', 'Halahtron,Halostrun,Haltern,Haltern in Westfalen,Khal''terne,Хальтерне', 51.7429700, 7.1816300, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36627, 'Halstenbek', 'Halstenbek', 'Khal''stenbek,Khalstenbek,ha er si teng bei ke,Халстенбек,Хальстенбек,哈尔斯滕贝克', 53.6333300, 9.8500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36628, 'Halsenbach', 'Halsenbach', '', 50.1717400, 7.5567300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36629, 'Halsdorf', 'Halsdorf', '', 49.9333300, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36630, 'Halsbrücke', 'Halsbrucke', 'Halsbrucke,Halsbruecke,Halsbruecke vald,Halsbrücke,Halsbrücke vald,Khal''sbrjuke,Khalsbrike,ha er si bu lu ke,Халсбрике,Хальсбрюке,哈尔斯布吕克', 50.9500000, 13.3500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36631, 'Halsbach', 'Halsbach', 'Gal''sbakh,Halsbax,Khal''sbakh,Khalsbakh,ha er si ba he,halsbakh,Гальсбах,Халсбах,Хальсбах,Հալսբախ,هالسباخ,哈尔斯巴赫', 48.1333300, 12.6833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36632, 'Hallungen', 'Hallungen', 'Khallungen,Khalungen,ha lun gen,Халлунген,Халунген,哈伦根', 51.1333300, 10.3333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36633, 'Hallstadt', 'Hallstadt', 'Gal''shtadt,Hallstadt,Hallştadt,Halstadt,Khall''shtadt,Khalshtat,ha er si ta te,halshtat,halsyutateu,harushutatto,Гальштадт,Халльштадт,Халштат,Հալշտադտ,هالشتات,هال‌اشتات,ハルシュタット,哈尔斯塔特,할슈타트', 49.9290100, 10.8753900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36634, 'Hallschlag', 'Hallschlag', '', 50.3544500, 6.4382400, 'DE', '2016-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36635, 'Hallgarten', 'Hallgarten', 'Khal''garten,Khalgarten,ha er jia er teng,Халгартен,Хальгартен,哈尔加尔滕', 49.7592500, 7.7888300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36636, 'Hallerndorf', 'Hallerndorf', 'Gallerndorf,Khalerndorf,Khallerndorf,ha lun duo fu,harerundorufu,Галлерндорф,Халерндорф,Халлерндорф,ハレルンドルフ,哈伦多夫', 49.7590900, 10.9794600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36637, 'Hallenberg', 'Hallenberg', 'Gallenberg,Hallenberg,Hallenburg,Khalenberg,Khallenberg,ha lun bei ge,halnbrg,halnbrgh,Галленберг,Халенберг,Халленберг,هالنبرغ,هالنبرگ,哈伦贝格', 51.1111500, 8.6200800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36638, 'Halle', 'Halle', 'Galle,Halle,Halle (Westf.),Halle (Westfalen),Khalle,halh,hare,Галле,Халле,هاله,ハレ', 52.0600700, 8.3608300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36639, 'Halle', 'Halle', '', 51.9912200, 9.5653200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36640, 'Halle (Saale)', 'Halle (Saale)', 'Galle,Halle,Halle (Saale),Halle an der Saale,Halle sul Saale,Halle-on-the-Saale,Khale,hale,hare,Галле,Хале,ჰალე,ハレ', 51.4815800, 11.9794700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36641, 'Hallbergmoos', 'Hallbergmoos', 'Gal''bergmos,Halbergmos,Hallbergmoos,Khalbergmos,Khall''bergmos,ha er bei ge mo si,halbrg mws,Гальбергмос,Халбергмос,Халльбергмос,Հալբերգմոս,هالبرگ موس,哈尔贝格莫斯', 48.3274700, 11.7514200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36642, 'Halfing', 'Halfing', 'Halfing bei Endorff', 47.9519700, 12.2752500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36643, 'Halensee', 'Halensee', '', 52.4900500, 13.2960200, 'DE', '2012-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36644, 'Haldenwang', 'Haldenwang', '', 48.4376300, 10.4481700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36645, 'Haldenwang', 'Haldenwang', 'Gal''denvang,Haldenvang,Khal''denvang,Khaldenvang,Гальденванг,Халденванг,Хальденванг,Հալդենվանգ', 47.8000000, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36646, 'Haldensleben I', 'Haldensleben I', 'Hahaldesleve,Halslae,Halslä,Khal''densleben,Khaldensleben,Neuhaldensleben,ha er deng si lai ben,haldnslbn,Халденслебен,Хальденслебен,هالدنسلبن,哈尔登斯莱本', 52.2890600, 11.4098200, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36647, 'Halbs', 'Halbs', '', 50.5908300, 7.9647200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36648, 'Halblech', 'Halblech', 'Gal''blekh,Halblex,Khal''blekh,Khalble,ha er bu lai xi,harupurehi,Гальблех,Халбле,Хальблех,Հալբլեխ,ハルプレヒ,哈尔布莱希', 47.6315500, 10.8202400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36649, 'Halberstadt', 'Halberstadt', 'Gorad Gal''bershtat,Halberstadium,Halberstadt,Halberstatas,Halberštatas,Halverstidde,Khal''bershtadt,Khalbershhat,Khalbershtat,ha bo si ta te,halbrashtat,hlbrshtat,Горад Гальберштат,Халберштат,Халберщат,Хальберштадт,הלברשטאט,هالبراشتات,هلبرشتات,哈伯斯塔特', 51.8956200, 11.0562200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36650, 'Halbemond', 'Halbemond', '', 53.5671000, 7.2903800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36651, 'Halbe', 'Halbe', 'Halbe,Khal''be,Khalbe,ha er bei,harube,Халбе,Хальбе,Հալբե,ハルベ,哈尔贝', 52.1166700, 13.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36652, 'Hakenfelde', 'Hakenfelde', 'Berlin-Hakenfelde', 52.5587700, 13.2083100, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36653, 'Haiterbach', 'Haiterbach', 'Gajterbakh,Haiterbach,Hayterbax,Khajterbakh,hai te er ba he,haytrbakh,haytrzbakh,Гайтербах,Хайтербах,Хајтербах,Հայտերբախ,هايترباخ,هایترزباخ,海特尔巴赫', 48.5206600, 8.6443500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36654, 'Hainspitz', 'Hainspitz', 'Hainspitz', 50.9610600, 11.8380400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36655, 'Hainsfarth', 'Hainsfarth', '', 48.9583900, 10.6249100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36656, 'Hainichen', 'Hainichen', '', 51.0000000, 11.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36657, 'Hainichen', 'Hainichen', 'Hainichen,Hainkschen', 50.9704400, 13.1228700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36658, 'Hain-Gründau', 'Hain-Gruendau', 'Hain-Grundau,Hain-Gründau', 50.2428400, 9.1428700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36659, 'Hainfeld', 'Hainfeld', '', 49.2575000, 8.1011100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36660, 'Hainewalde', 'Hainewalde', 'Hainewalde,Khajneval''de,Khajnevalde,hai nei wa er de,Хайневальде,Хајневалде,海内瓦尔德', 50.9101400, 14.7038700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36661, 'Haina', 'Haina', 'Gajna,Haina,Khajna,hai na,haina,Гайна,Хайна,Хајна,ハイナ,海纳', 51.0277400, 8.9744100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36662, 'Haina', 'Haina', '', 50.9897100, 10.5177400, 'DE', '2014-04-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36663, 'Hain', 'Hain', '', 50.7074900, 12.0833300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36664, 'Haiming', 'Haiming', '', 48.2166700, 12.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36665, 'Haimhausen', 'Haimhausen', 'Gajmgauzen,Haymhauzen,Khajmkhauzen,hai mu hao sen,haym hawzn,Гаймгаузен,Хаймхаузен,Хајмхаузен,Հայմհաուզեն,هایم هاوزن,海姆豪森', 48.3154500, 11.5545300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36666, 'Haigerloch', 'Haigerloch', 'Gajgerlokh,Khajgerlokh,hai ge er luo,hayghrlwkh,haygrlkh,Гайгерлох,Хайгерлох,Хајгерлох,هايغرلوخ,هایگرلخ,海格尔洛', 48.3661400, 8.8035700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36667, 'Haiger', 'Haiger', 'Gajger,Gorad Khajger,Haiger,Khajger,hai ge er,hayghr,haygr,Гайгер,Горад Хайгер,Хайгер,Хајгер,هايغر,هایگر,海格尔', 50.7416200, 8.2077800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36668, 'Haidmühle', 'Haidmuhle', 'Gajdmjule,Haydmyule,Khajdmile,Khajdmjule,hai de mi he lai,haydmwlh,Гайдмюле,Хайдмюле,Хајдмиле,Հայդմյուլե,هایدموله,海德米赫莱', 48.8256500, 13.7764900, 'DE', '2014-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36669, 'Haibach', 'Haibach', '', 48.5364600, 12.9868500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36670, 'Haibach', 'Haibach', '', 49.9644400, 9.2072200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36671, 'Haibach', 'Haibach', '', 49.0240500, 12.7155200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36672, 'Hahnweiler', 'Hahnweiler', '', 49.5666700, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36673, 'Hahnstätten', 'Hahnstatten', 'Hahnstaetten,Hahnstätten,Khanshteten,Khanshtetten,ha en si te teng,hansutetten,Ханштетен,Ханштеттен,ハンステッテン,哈恩斯特滕', 50.3000000, 8.0666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36674, 'Hähnichen', 'Hahnichen', 'Genikhen,Haehnicheni vald,Hähnicheni vald,Khenikhen,Woseck,Wosečk,hei ni xing,Геніхен,Хенихен,黑尼兴', 51.3654000, 14.8609800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36675, 'Hahnheim', 'Hahnheim', '', 49.8608300, 8.2369400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36676, 'Hahnenbach', 'Hahnenbach', 'Khanenbakh,ha nen ba he,Ханенбах,哈嫩巴赫', 49.8096200, 7.4198500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36677, 'Hahn bei Marienberg', 'Hahn bei Marienberg', 'Hahn,Hahn bei Marienberg', 50.6327800, 7.9411100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36678, 'Hahnbach', 'Hahnbach', 'Ganbakh,Hanbax,Khanbakh,ha en ba he,Ганбах,Ханбах,Հանբախ,哈恩巴赫', 49.5338900, 11.8030200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36679, 'Hahn', 'Hahn', '', 49.9666700, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36680, 'Hahausen', 'Hahausen', 'Khakhauzen,ha hao sen,Хахаузен,哈豪森', 51.9500000, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36681, 'Hagnau', 'Hagnau', '', 47.6766600, 9.3178700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36682, 'Hagermarsch', 'Hagermarsch', 'Khagermarsh,ha ge er ma er shi,Хагермарш,哈格尔马尔施', 53.6500000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36683, 'Hagenow', 'Hagenow', 'Hagenova,Hagenow,Hāgenova,Khagenov,ha ge nuo,hagnw,Хагенов,هاگنو,哈格诺', 53.4313400, 11.1915900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36684, 'Hagen im Bremischen', 'Hagen im Bremischen', 'Gemeen Hagen,Hagen,Hagen im Bremischen,Khagen im Bremishen,Khagen-im-Bremishen,bu lai mei de qu ha gen,Хаген им Бремишен,Хаген-им-Бремишен,不来梅地区哈根', 53.3570700, 8.6434100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36685, 'Hagenburg', 'Hagenburg', 'Hagenborch [a. 1378],Hagenburg,Khagenburg,ha gen bao,hagenburuku,Хагенбург,ハーゲンブルク,哈根堡', 52.4336700, 9.3247300, 'DE', '2011-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36686, 'Hagenbüchach', 'Hagenbuchach', 'Gagenbjukhakh,Hagenbuechach,Hagenbyuxax,Hagenbüchach,Khagenbikhakh,Khagenbjukhakh,ha gen bi xia,Гагенбюхах,Хагенбихах,Хагенбюхах,Հագենբյուխախ,哈根比夏', 49.5333300, 10.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36687, 'Hagenbach', 'Hagenbach', 'Khagenbakh,a rang ba ke,haghnbakh,hagnbakh,Хагенбах,هاغنباخ,هاگنباخ,阿让巴克', 49.0173400, 8.2502400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36688, 'Hagen', 'Hagen', '', 53.9465200, 9.8265900, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36689, 'Hagen', 'Hagen', 'Biekero''e,Bikirothon [a. 1088],Hagen,Hagen a.T.W.,Hagen am Teutoburger Wald,Hagen-Beckerode,Khagen am Teutoburger Vald,Khagen-am-Tojtoburger-Val''d,Хаген ам Теутобургер Валд,Хаген-ам-Тойтобургер-Вальд', 52.1962900, 7.9804100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36690, 'Hagen', 'Hagen', 'Hagen,Khagen,ZEY,hagen,hageni,Хаген,ჰაგენი,ハーゲン', 51.3608100, 7.4716800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36691, 'Hagelstadt', 'Hagelstadt', 'Gagel''shtadt,Khagel''shtadt,Khagelshtat,ha ge er si ta te,haglshtat,Гагельштадт,Хагелштат,Хагельштадт,Հագելշթաթ,هاگلشتات,哈格尔斯塔特', 48.9000000, 12.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36692, 'Hage', 'Hage', 'Hage,Khage,ha ge,Хаге,哈格', 53.6027400, 7.2852700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36693, 'Hafenlohr', 'Hafenlohr', 'Gafenlor,Hafenlor,Khafenlor,ha fen luo er,Гафенлор,Хафенлор,Հաֆենլոր,哈芬洛尔', 49.8694400, 9.6022200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36694, 'Hadmersleben', 'Hadmersleben', 'Hadmersleben,Hatmersleve,Hoimerslae,Hoimerslä,Khadmersleben,Хадмерслебен', 51.9927500, 11.3028300, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36695, 'Hadenfeld', 'Hadenfeld', 'Hadenfeld', 54.0341000, 9.4557500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36696, 'Hademstorf', 'Hademstorf', '', 52.7137300, 9.6314000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36697, 'Hadamar', 'Hadamar', 'Gadamar,Hadamar,Khadamar,ha da ma er,hadamar,Гадамар,Хадамар,هادامار,哈达马尔', 50.4459300, 8.0425300, 'DE', '2016-01-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36698, 'Hackenheim', 'Hackenheim', 'Khakenkhajm,Khakkenkhajm,ha ken hai mu,Хакенхајм,Хаккенхайм,哈肯海姆', 49.8252400, 7.8990700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36699, 'Hachenburg', 'Hachenburg', 'Hachenburg,Khakhenburg,ha heng bao,hahenburuku,hakhnbwrgh,hashnbwrg,Хахенбург,هاخنبورغ,هاشنبورگ,ハーヘンブルク,哈亨堡', 50.6599800, 7.8227600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36700, 'Haby', 'Haby', 'Haby', 54.4000000, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36701, 'Habscheid', 'Habscheid', '', 50.1833300, 6.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36702, 'Habighorst', 'Habighorst', '', 52.7086400, 10.2274100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36703, 'Habach', 'Habach', 'Gabakh,Habax,Khabakh,habahha,habakh,Габах,Хабах,Հաբախ,هاباخ,ハーバッハ', 47.7333300, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36704, 'Haarbach', 'Haarbach', 'Gaarbakh,Harbax,Hoaba,Kharbakh,harbakh,Гаарбах,Харбах,Հարբախ,هارباخ', 48.5000000, 13.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36705, 'Haar', 'Haar', 'Khar,Хар', 48.1088100, 11.7265300, 'DE', '2011-02-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36706, 'Haan', 'Haan', 'Gan,Haan,Khaan,Khan,Stadt Haan,Ган,Хаан,Хан', 51.1938200, 7.0133000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36707, 'Haale', 'Haale', 'Haale', 54.1833300, 9.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36708, 'Haag in Oberbayern', 'Haag in Oberbayern', 'Fraunberg,Haag,Haag in Oberbayern,Khag,Хаг', 48.1619600, 12.1794200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36709, 'Haag an der Amper', 'Haag an der Amper', 'Amperi Haag,Gaag-an-der-Amper,Haag,Haag an der Amper,Khag an der Amper,Khag-na-Ampere,an po he pan ha ge,hag an dr ampr,Гааг-ан-дер-Ампер,Хаг ан дер Ампер,Хаг-на-Ампере,Ամպերի Հաագ,هاگ ان در آمپر,安珀河畔哈格', 48.4584000, 11.8279600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36710, 'Haag', 'Haag', '', 49.8699700, 11.5607100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36711, 'Gyhum', 'Gyhum', 'Gikhum,Jeem,gifumu,ji hu mu,Гихум,ギフム,吉胡姆', 53.2166700, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36712, 'Guxhagen', 'Guxhagen', 'Guksgagen,Gukskhagen,Guxhagen,gu ke si ha gen,gukkusuhagen,Гуксгаген,Гуксхаген,グックスハーゲン,古克斯哈根', 51.2000000, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36713, 'Gützkow', 'Guetzkow', '', 53.7243200, 13.1066400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36714, 'Gutweiler', 'Gutweiler', '', 49.7166700, 6.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36715, 'Guttau', 'Guttau', 'Gutau,Guttau,Guttau/Hucina,Guttau/Hućina,Hucina,Hućina,gu tao,Гутау,Гуттау,古陶', 51.2590400, 14.5613200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36716, 'Guthmannshausen', 'Guthmannshausen', '', 51.1333300, 11.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36717, 'Gütersloh', 'Guetersloh', 'GUT,Giterslokh,Giuterslas,Gjuterslo,Guetersloh,Gutersloh,Gütersloh,gwiteoseullo,gwtrzlwh,ju te si luo,kux the xrslo,kwtrslwh,Гитерслох,Гютерсло,كوترسلوه,گوترزلوه,กือเทอร์สโล,居特斯洛,귀터슬로', 51.9069300, 8.3785300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36718, 'Gutenstetten', 'Gutenstetten', 'Gutenshteten,Gutenshtetten,gu teng si te teng,Гутенштетен,Гутенштеттен,Գութենշթեթեն,古滕斯特滕', 49.6166700, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36719, 'Guteneck', 'Guteneck', 'Gutenek,gu te nei ke,gwtnk,Гутенек,گوتنک,古特内克', 49.4500000, 12.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36720, 'Gutenberg', 'Gutenberg', '', 51.5471000, 11.9718100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36721, 'Gutenberg', 'Gutenberg', 'Gutenberg,gu teng bei ge,Гутенберг,古滕贝格', 49.8833300, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36722, 'Gütenbach', 'Guetenbach', 'Gitenbakh,Gjutenbakh,Gutenbach,Gütenbach,ju teng ba he,Гитенбах,Гютенбах,居滕巴赫', 48.0500000, 8.1500000, 'DE', '2016-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36723, 'Gutenacker', 'Gutenacker', '', 50.3197100, 7.9220900, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36724, 'Guteborn', 'Guteborn', '', 51.4166700, 13.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36725, 'Gutach im Breisgau', 'Gutach im Breisgau', 'Gutakh im Brajsgau,Gutakh-im-Brajsgau,Gutax im Braysgau,bu lai shi gao de qu gu ta he,Гутах им Брајсгау,Гутах-им-Брайсгау,Гутах-ім-Брайсгау,Գուտախ իմ Բրայսգաու,布赖施高地区古塔赫', 48.1166700, 7.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36726, 'Gutach (Schwarzwaldbahn)', 'Gutach (Schwarzwaldbahn)', 'Gutach,Gutach (Schwarzwaldbahn)', 48.2484400, 8.2129300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36727, 'Güstrow', 'Guestrow', 'Gistrov,Gistrova,Gjustrov,Guestrow,Gustrovium,Güstrow,ghwstrw,gwtzrw,gystrw,ju si te luo,kus thor w,Гистров,Гюстров,גיסטרו,غوسترو,گوتزرو,กึสโทรว์,居斯特罗', 53.7972000, 12.1733700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36728, 'Gusterath', 'Gusterath', '', 49.7000000, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36729, 'Güster', 'Guester', 'Guester,Guster,Güster', 53.5385100, 10.6760700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36730, 'Güsten', 'Guesten', 'Gisten,Gjusten,Gusten,Güsten,ghwstn,gwshtn,ju si teng,Гистен,Гюстен,غوستن,گوشتن,居斯滕', 51.7963700, 11.6124600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36731, 'Gusenburg', 'Gusenburg', '', 49.6333300, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36732, 'Gunzenhausen', 'Gunzenhausen', 'Guncengauzen,Guncenkhauzen,Gunzenhausen,Gunzenhausn,ghwntsnhawzn,gong cen hao sen,Гунценхаузен,Ґунценгаузен,Գունցենհաուզեն,غونتسنهاوزن,گونتسن‌هاوزن,贡岑豪森', 49.1166300, 10.7597100, 'DE', '2014-01-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36733, 'Günzburg', 'Guenzburg', 'Gincburg,Gjuncburg,Gorad Gjuncburg,Guenzburg,Guntia,Guntzbourg,Gunzburg,Gunzburgo,Günzburg,ghwntsbwrgh,gwntsbwrg,gyuntsuburuku,jin ci bao,Гинцбург,Горад Гюнцбург,Гюнцбург,غونتسبورغ,گونتسبورگ,ギュンツブルク,金茨堡', 48.4559900, 10.2769500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36734, 'Günzach', 'Guenzach', 'Guenzach,Günzach', 47.8249100, 10.4354700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36735, 'Günthersdorf', 'Guenthersdorf', 'Gunthersdorf,Günthersdorf', 51.3457000, 12.1717500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36736, 'Güntersleben', 'Guntersleben', 'Gintersleben,Gjuntersleben,Guentersleben,Gyuntersleben,Güntersleben,gyuntasureben,jin te er si lai ben,Гинтерслебен,Гюнтерслебен,Գյունտերսլեբեն,ギュンタースレーベン,金特尔斯莱本', 49.8697200, 9.9050000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36737, 'Guntersblum', 'Guntersblum', 'Guntersblum,gong te er si bu lu mu,guntasuburumu,Гунтерсблум,グンタースブルム,贡特尔斯布卢姆', 49.7975000, 8.3455600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36738, 'Günstedt', 'Guenstedt', '', 51.2219100, 11.0804100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36739, 'Gunningen', 'Gunningen', '', 48.0500000, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36740, 'Gundremmingen', 'Gundremmingen', 'Gundremingen,Gundremmingen,gong de lei ming gen,Гундреминген,Гундремминген,Гундреммінген,Գունդրեմինգեն,贡德雷明根', 48.5000000, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36741, 'Gundheim', 'Gundheim', '', 49.6758300, 8.2377800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36742, 'Gundersweiler', 'Gundersweiler', '', 49.6000000, 7.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36743, 'Gundersheim', 'Gundersheim', '', 49.6961100, 8.2025000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36744, 'Gunderath', 'Gunderath', '', 50.2551100, 6.9783800, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36745, 'Gundelsheim', 'Gundelsheim', '', 49.9370800, 10.9199000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36746, 'Gundelsheim', 'Gundelsheim', 'Gundel''skhajm,Gundelsheim,Gundelskhajm,gunderusuhaimu,gwndlzhaym  badn-wwrtmbrg,Гунделсхајм,Гундельсхайм,گوندلزهایم، بادن-وورتمبرگ,グンデルスハイム', 49.2833000, 9.1603700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36747, 'Gundelfingen', 'Gundelfingen', '', 48.5534700, 10.3722300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36748, 'Gundelfingen', 'Gundelfingen', 'Gundel''fingen,Gundelfingen,Gundelfingen im Breisgau,gong de er fen gen,Гунделфинген,Гундельфинген,Гундельфінген,Գունդելֆինգեն,贡德尔芬根', 48.0424600, 7.8657000, 'DE', '2013-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36749, 'Gumtow', 'Gumtow', 'Gumtov,gu mu tuo,Гумтов,古姆托', 52.9833300, 12.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36750, 'Gumperda', 'Gumperda', 'Gumperda', 50.8095700, 11.5238000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36751, 'Gummersbach', 'Gummersbach', 'Gumersbakh,Gummersbach,Gummersbakh,ZEW,ghwmrsbakh,gu mei er si ba he,gwmrzbakh,Гумерсбах,Гуммерсбах,غومرسباخ,گومرزباخ,古梅尔斯巴赫', 51.0260800, 7.5647300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36752, 'Gumbsheim', 'Gumbsheim', '', 49.8166700, 7.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36753, 'Gülzow', 'Gulzow', 'Gulzow,Gülzow', 53.4500000, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36754, 'Güllesheim', 'Gullesheim', 'Guellesheim,Güllesheim', 50.5978400, 7.5285500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36755, 'Guhrow', 'Guhrow', 'Gory,Guhrow,Góry', 51.8120400, 14.2293500, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36756, 'Güglingen', 'Guglingen', 'Giglingen,Gjuglingen,Gueglingen,Guglingen,Güglingen,ghwghlynghn,gwglyngn,gyukuringen,ju ge lin gen,Гиглинген,Гюглинген,Гюглінген,غوغلينغن,گوگلینگن,ギュクリンゲン,居格林根', 49.0664200, 9.0017500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36757, 'Guggenhausen', 'Guggenhausen', 'Gugenkhauzen,Guggengauzen,Guggenkhauzen,gu gen hao sen,Гуггенгаузен,Гуггенхаузен,Гугенхаузен,古根豪森', 47.9000000, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36758, 'Gudow', 'Gudow', 'Gudov,gu duo fu,Гудов,古多夫', 53.5555600, 10.7702100, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36759, 'Guderhandviertel', 'Guderhandviertel', '', 53.5491900, 9.6096000, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36760, 'Gudensberg', 'Gudensberg', 'Gorad Gudehnsberg,Gudensberg,ghwdnsbrgh,gu deng si bei ge,gudensuberuku,gwdnzbrg,Горад Гудэнсберг,Гуденсберг,غودنسبرغ,گودنزبرگ,グーデンスベルク,古登斯贝格', 51.1770600, 9.3674800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36761, 'Gudendorf', 'Gudendorf', '', 54.0241800, 9.1079500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36762, 'Gückingen', 'Guckingen', '', 50.3909100, 8.0072600, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36763, 'Guckheim', 'Guckheim', 'Gukkhajm,gu ke hai mu,Гукхайм,Гукхајм,古克海姆', 50.5333300, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36764, 'Güby', 'Guby', 'Guby,Güby', 54.4833300, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36765, 'Guben', 'Guben', 'Guben,Gubenas,Gubin,ghwbn,gu ben,gwbn,Губен,Գուբեն,غوبن,گوبن,古本', 51.9498700, 14.7144700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36766, 'Gstadt am Chiemsee', 'Gstadt am Chiemsee', 'Gstadt,Gstadt am Chiemsee', 47.8845300, 12.4181300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36767, 'Gschwend', 'Gschwend', 'Gshvend,ge shi wen de,gshvendi,Гшвенд,გშვენდი,格施文德', 48.9333300, 9.7443600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36768, 'Grünwald', 'Grunwald', 'Grienewald,Gruenwald,Grünwald', 48.0394700, 11.5232000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36769, 'Grünstadt', 'Gruenstadt', 'Grinnschdadt,Grinshtat,Grjunshtadt,Gruenspadt,Gruenstadt,Grunstadt,Grünstadt,ge lin si ta te,ghrwnshtat,guryunshutatto,Гринштат,Грюнштадт,غرونشتات,گرون‌اشتات,グリューンシュタット,格林斯塔特', 49.5630200, 8.1627900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36770, 'Grünsfeld', 'Grunsfeld', 'Grinsfeld,Grjunsfel''d,Gruensfeld,Grunsfeld,Grünsfeld,ge lin si fei er de,ghrwnsfld,grwnzfld,guryunsuferuto,Гринсфелд,Грюнсфельд,غرونسفلد,گرونزفلد,グリュンスフェルト,格林斯费尔德', 49.6094900, 9.7472500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36771, 'Grünow', 'Grunow', '', 53.3166700, 13.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36772, 'Grünkraut', 'Gruenkraut', 'Grinkraut,Grjunkraut,Gruenkraut,Grunkraut,Grünkraut,ge lin ke lao te,Гринкраут,Грюнкраут,格林克劳特', 47.7441700, 9.6558800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36773, 'Grünheide', 'Gruenheide', 'Grinkhajde,Grjunkhajde,Gruenheide,Gruenheide in der Mark,Grunheide,Gryuhayde,Grünheide,Grünheide in der Mark,ge lin hai de,Гринхајде,Грюнхайде,Գրյուհայդե,格林海德', 52.4234300, 13.8132400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36774, 'Grünhainichen', 'Gruenhainichen', 'Grinkhajnikhen,Grjunkhajnikhen,Gruenhainichen,Grunhainichen,Grünhainichen,ge lin hai ni xing,Гринхајнихен,Грюнхайнихен,格林海尼兴', 50.7672000, 13.1536600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36775, 'Grünhain', 'Gruenhain', 'Gruenhain,Grunhain,Grünhain', 50.5801900, 12.8069500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36776, 'Grunewald', 'Grunewald', 'Berlin-Grunewald,Gruneval''d,grwnwwld,Груневальд,גרונוולד', 52.4833800, 13.2658600, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36777, 'Grünewald', 'Grunewald', '', 51.4000000, 14.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36778, 'Grünendeich', 'Grunendeich', 'Gruenendeich,Grünendeich', 53.5695200, 9.6121800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36779, 'Grünenbach', 'Gruenenbach', 'Grinenbakh,Grjunenbakh,Gryunenbax,ge lu nen ba he,Гриненбах,Грюненбах,Գրյունենբախ,格吕嫩巴赫', 47.6286400, 10.0084300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36780, 'Grünebach', 'Gruenebach', 'Grinebakh,Grjunebakh,ge lu nei ba he,grwnbakh,Гринебах,Грюнебах,گرونباخ,格吕内巴赫', 50.7833300, 7.9000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36781, 'Grundsheim', 'Grundsheim', '', 48.1666700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36782, 'Grundhof', 'Grundhof', 'Grumtoft,Grundkhof,ge lun de huo fu,Грундхоф,格伦德霍夫', 54.7709400, 9.6530600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36783, 'Grünberg', 'Gruenberg', 'Grinberg,Grjunberg,Gruenberg,Grunberg,Grunberg in Hessen,Grünberg,Grünberg in Hessen,ge lin bei ge,grwnbrg  hsn,Гринберг,Грюнберг,گرونبرگ، هسن,格林贝格', 50.5940300, 8.9586600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36784, 'Grünbach', 'Gruenbach', 'Grinbakh,Grjunbakh,Grunbach,Grünbach,ge lin ba he,Гринбах,Грюнбах,格林巴赫', 50.4499500, 12.3618600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36785, 'Grünau', 'Grunau', 'Berlin-Grunau,Berlin-Grünau', 52.4164200, 13.5803900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36786, 'Grumbach', 'Grumbach', 'Grumbakh,ge lun ba he,Грумбах,格伦巴赫', 49.6500000, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36787, 'Gruibingen', 'Gruibingen', 'Grjubingen,Gruibingen,Grujbingen,ge lu yi bin gen,Груибинген,Груйбінген,Грюбинген,格鲁伊宾根', 48.5948300, 9.6438900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36788, 'Grube', 'Grube', 'Grube', 54.2333300, 11.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36789, 'Grub', 'Grub', '', 50.5500000, 10.6333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36790, 'Grub', 'Grub', '', 50.1028500, 11.9290400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36791, 'Groven', 'Groven', 'Groven', 54.3000000, 8.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36792, 'Grove', 'Grove', '', 53.5333300, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36793, 'Grothusenkoog', 'Grothusenkoog', 'Grothusenkoog', 54.3012800, 8.7589100, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36794, 'Groß-Zimmern', 'Gross-Zimmern', 'Gros-Cimern,Gros-Cimmern,Gross-Zimmern,Groß-Zimmern,da qi men,gurosu=tsu~inmerun,Грос-Цимерн,Грос-Циммерн,グロース＝ツィンメルン,大齐门', 49.8758300, 8.8344400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36795, 'Großwoltersdorf', 'Grosswoltersdorf', '', 53.0666700, 13.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36796, 'Groß Wokern', 'Gross Wokern', '', 53.7513500, 12.4924900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36797, 'Groß Wittensee', 'Gross Wittensee', 'Gross Wittensee,Groß Wittensee', 54.4000000, 9.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36798, 'Großweitzschen', 'Grossweitzschen', '', 51.1584500, 13.0451700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36799, 'Großweil', 'Grossweil', 'Grosvajl,Grosvajl'',Grosvayl,da wei er,grwswayl,Гросвайль,Гросвајл,Գրոսվայլ,گروسوایل,大魏尔', 47.6759800, 11.3010800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36800, 'Großwallstadt', 'Grosswallstadt', 'Grosswallstadt,Grosval''shtadt,Grosvall''shtadt,Grosvalshtat,Großwallstadt,da wa er si ta te,gurosuvu~arushutatto,Гросвалльштадт,Гросвалштат,Гросвальштадт,Գրոսվալշթաթ,グロースヴァルシュタット,大瓦尔斯塔特', 49.8793600, 9.1533800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36801, 'Groß Vollstedt', 'Gross Vollstedt', 'Gross Vollstedt,Groß Vollstedt', 54.2333300, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36802, 'Großvargula', 'Grossvargula', '', 51.1166700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36803, 'Groß-Umstadt', 'Gross-Umstadt', 'Gros-Umshtadt,Gros-Umshtat,Gross-Umstadt,Groß-Umstadt,da wu mu si ta te,ghrws-awmshtat,gurosu=umushutatto,Грос-Умштадт,Грос-Умштат,غروس-أومشتات,گرس-اوم‌اشتات,グロース＝ウムシュタット,大乌姆斯塔特', 49.8689900, 8.9321000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36804, 'Groß Twülpstedt', 'Gross Twulpstedt', 'Gross Twuelpstedt,Groß Twülpstedt', 52.3736100, 10.9192900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36805, 'Trebel', 'Trebel', 'Gross Trebel,Groß Trebel,Trebel', 53.0000000, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36806, 'Großthiemig', 'Grossthiemig', 'Grostimig,da di mi xi,Гростимиг,Գրոսթիմիգ,大蒂米希', 51.3833300, 13.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36807, 'Großsteinhausen', 'Grosssteinhausen', '', 49.1833300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36808, 'Großsolt', 'Grosssolt', 'Grosssolt,Groszol''t,Groszolt,Großsolt,Store Solt,ge luo suo er te,Гросзолт,Гросзольт,格罗索尔特', 54.7000000, 9.5166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36809, 'Großseifen', 'Grossseifen', '', 50.6333300, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36810, 'Großschweidnitz', 'Grossschweidnitz', 'Grosshvajdnic,Swonca,Swóńca,da shi wei de ni ci,Гросшвайдниц,Гросшвајдниц,大施韦德尼茨', 51.0693900, 14.6429700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36811, 'Großschwabhausen', 'Grossschwabhausen', 'Grosshvabkhauzen,da shi wa bu hao sen,Гросшвабхаузен,大施瓦布豪森', 50.9333300, 11.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36812, 'Großschönau', 'Grossschonau', 'Grossschoenau,Grossschonau,Grossschönau,Großschönau', 50.9000000, 14.6833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36813, 'Großschirma', 'Grossschirma', 'Grosshirma,Grossirma,Grossschirma,Grosširma,Großschirma,ge luo xi er ma,ghrwsshyrma,grsshyrma,Гросширма,غروسشيرما,گرسشیرما,格罗席尔马', 50.9660200, 13.2859000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36814, 'Groß Schenkenberg', 'Gross Schenkenberg', 'Gross Schenkenberg,Groß Schenkenberg', 53.8000000, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36815, 'Groß Sarau', 'Gross Sarau', 'Gros Zarau,Gros-Zarau,Gross Sarau,Groß Sarau,da sa lao,Грос Зарау,Грос-Зарау,大萨劳', 53.7666700, 10.7333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36816, 'Groß Santersleben', 'Gross Santersleben', 'Gross Santersleben,Groß Santersleben', 52.1914300, 11.4548600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36817, 'Großrudestedt', 'Grossrudestedt', 'Grosrudeshtedt,Grosrudeshtet,da lu de si te,Гросрудештедт,Гросрудештет,大鲁德斯特', 51.0930500, 11.0997700, 'DE', '2015-01-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36818, 'Großrückerswalde', 'Grossruckerswalde', 'Grosrikersvalde,Grosrjukersval''de,Grossruckerswalde,Grossrueckerswalde,Großrückerswalde,Luckenwalden,da lu ke si wa er de,Гросрикерсвалде,Гросрюкерсвальде,大吕克斯瓦尔德', 50.6333300, 13.1166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36819, 'Großrosseln', 'Grossrosseln', 'Grosroseln,Grosrossel''n,Grossrosseln,Großrosseln,da luo se er en,Гросроселн,Гросроссельн,大罗瑟尔恩', 49.2029600, 6.8414800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36820, 'Groß Rosenburg', 'Gross Rosenburg', '', 51.9169600, 11.8918400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36821, 'Groß Rönnau', 'Gross Roennau', 'Gross Ronnau,Groß Rönnau', 53.9666700, 10.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36822, 'Großröhrsdorf', 'Grossroehrsdorf', 'Grosr''orsdorf,Grosrersdorf,Grosrersdorfa,Grosrjorsdorf,Grosrērsdorfa,Grossroehrsdorf,Grossrohrsdorf,Großröhrsdorf,Wulke Redorjecy,Wulke Rědorjecy,da lei er si duo fu,ghrws rwrsdwrf,grsrwrdwrf,Гросрерсдорф,Гросрьорсдорф,Гросрёрсдорф,Гросрөрсдорф,غروس رورسدورف,گرسروردورف,大勒尔斯多夫', 51.1452800, 14.0191700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36823, 'Groß-Rohrheim', 'Gross-Rohrheim', 'Gros-Rorgajm,Gros-Rorkhajm,Gross-Rohrheim,Groß-Rohrheim,da luo lai mu,gurosu=roruhaimu,Грос-Роргайм,Грос-Рорхайм,Грос-Рорхајм,グロース＝ロールハイム,大罗赖姆', 49.7211100, 8.4827800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36824, 'Groß Rodensleben', 'Gross Rodensleben', 'Gross Rodensleben,Groß Rodensleben', 52.1213900, 11.3836700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36825, 'Großrinderfeld', 'Grossrinderfeld', 'Grosrinderfel''d,Grosrinderfeld,Grossrinderfeld,Großrinderfeld,da lin de fei er de,gurosurindaferuto,Гросриндерфелд,Гросриндерфельд,Гросріндерфельд,グロースリンダーフェルト,大林德费尔德', 49.6653600, 9.7335600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36826, 'Groß Rheide', 'Gross Rheide', 'Gross Rheide,Groß Rheide', 54.4415400, 9.4350800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36827, 'Großreuth bei Schweinau', 'Grossreuth bei Schweinau', 'Grossreuth,Grossreuth bei Schweinau,Großreuth,Großreuth bei Schweinau', 49.4344900, 11.0227300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36828, 'Großräschen', 'Grossraeschen', 'Grosresen,Grosreshen,Grosseraeschen,Grossraeschen,Grossraschen,Grossräschen,Großeraeschen,Großräschen,Mukran,Mukrań,Ran,Rań,da lei shen,ghrwsryshn,grsrshn,Гросрешен,Գրոսրեշեն,غروسريشن,گرسرشن,大雷申', 51.5876000, 14.0109300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36829, 'Groß Quenstedt', 'Gross Quenstedt', 'Gross Quenstedt,Groß Quenstedt', 51.9333300, 11.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36830, 'Großpürschütz', 'Grosspurschutz', 'Grosspurschutz,Großpürschütz', 50.8166700, 11.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36831, 'Großpostwitz', 'Grosspostwitz', 'Budestecy,Grospostvic,Grosspostwitz,Grosspostwitz/Budestecy,Grosspostwitz/Oberlausitz,Grosspostwitzi vald,Großpostwitz,Großpostwitz/Budestecy,Großpostwitz/Oberlausitz,Großpostwitzi vald,da bo si te wei ci,Гроспоствиц,Гроспоствіц,大波斯特维茨', 51.1208300, 14.4406500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36832, 'Großpösna', 'Grossposna', 'Grospesna,Grospjosna,Grosspoesna,Grosspoesna vald,Grosspoessnitz,Grossposna,Großpoeßnitz,Großpösna,Großpösna vald,da po si na,Гроспесна,Гроспёсна,Гроспөсна,大珀斯纳', 51.2666700, 12.5000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36833, 'Groß Pankow', 'Gross Pankow', 'Gross Pankow,Groß Pankow', 53.1195200, 12.0497500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36834, 'Groß Pampau', 'Gross Pampau', '', 53.5222500, 10.5619800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36835, 'Großostheim', 'Grossostheim', 'Grosostgajm,Grosostkhajm,Grossostajm,Grossostheim,Großostheim,ge luo suo si tai mu,gurosuosutohaimu,Гросостгайм,Гросостхайм,Гросостхајм,Гроссостайм,Գրոսոսթհայմ,グロースオストハイム,格罗索斯泰姆', 49.9198500, 9.0759600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36836, 'Großörner', 'Grossoerner', '', 51.6152700, 11.4898000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36837, 'Großolbersdorf', 'Grossolbersdorf', 'Grosol''bersdorf,Grosolbersdorf,Grossolbersdorf,Großolbersdorf,ge luo suo er bei er si duo fu,Гросолберсдорф,Гросольберсдорф,格罗索尔贝尔斯多夫', 50.7000000, 13.0833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36838, 'Groß Oesingen', 'Gross Oesingen', 'Gros Osingen,Gros-Ehzingen,Gross Oesingen,Gross Osingen,Groß Oesingen,Groß Ösingen,da ao ai xin gen,Грос Осинген,Грос-Эзинген,大奥埃辛根', 52.6476100, 10.4636600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36839, 'Großobringen', 'Grossobringen', '', 51.0333300, 11.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36840, 'Groß Nordende', 'Gross Nordende', 'Gross Nordende,Groß Nordende', 53.7000000, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36841, 'Groß Niendorf', 'Gross Niendorf', '', 53.8463200, 10.2430700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36842, 'Großniedesheim', 'Grossniedesheim', 'Grosnideskhajm,da ni de si hai mu,Гроснидесхайм,Гроснидесхајм,大尼德斯海姆', 49.5752800, 8.3122200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36843, 'Großneuhausen', 'Grossneuhausen', 'Grosnojkhauzen,da nuo yi hao sen,Гроснойхаузен,Гроснојхаузен,大诺伊豪森', 51.1608000, 11.2856400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36844, 'Groß Nemerow', 'Gross Nemerow', 'Gross Nemerow,Groß Nemerow', 53.4734200, 13.2248200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36845, 'Großnaundorf', 'Grossnaundorf', '', 51.2000000, 13.9333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36846, 'Groß Munzel', 'Gross Munzel', 'Munuslo [a. 965]', 52.3655400, 9.4782800, 'DE', '2011-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36847, 'Großmonra', 'Grossmonra', 'Grossmonra,Großmonra', 51.2129900, 11.2957800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36848, 'Großmölsen', 'Grossmoelsen', '', 51.0333300, 11.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36849, 'Großmehring', 'Grossmehring', 'Grosmering,Grossmehring,Großmehring,Mehring,da mei lin,grwsmryng,Гросмеринг,Гросмерінг,Գրոսմերինգ,گروسمرینگ,大梅林', 48.7666700, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36850, 'Groß Meckelsen', 'Gross Meckelsen', '', 53.2833300, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36851, 'Großmaischeid', 'Grossmaischeid', 'Grossmaischeid,Großmaischeid', 50.5000000, 7.6333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36852, 'Großlöbichau', 'Grossloebichau', 'Grosslobichau,Großlöbichau', 50.9280200, 11.6801400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36853, 'Großlittgen', 'Grosslittgen', '', 50.0278700, 6.7986500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36854, 'Groß Lindow', 'Gross Lindow', 'Gross Lindow,Groß Lindow,Lindow', 52.2333300, 14.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36855, 'Großlehna', 'Grosslehna', '', 51.3068700, 12.1719000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36856, 'Großlangheim', 'Grosslangheim', 'Groslangajm,Groslanghaym,Groslangkhajm,Grosslangheim,Großlangheim,da lang hai mu,Грослангайм,Грослангхайм,Грослангхајм,Գրոսլանգհայմ,大朗海姆', 49.7562000, 10.2406500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36857, 'Großlangenfeld', 'Grosslangenfeld', '', 50.2166700, 6.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36858, 'Groß Laasch', 'Gross Laasch', '', 53.3464600, 11.5491900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36859, 'Groß Kummerfeld', 'Gross Kummerfeld', 'Gross Kummerfeld,Groß Kummerfeld', 54.0500000, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36860, 'Großkugel', 'Grosskugel', 'Grosskugel,Großkugel', 51.4172800, 12.1464100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36861, 'Großkrotzenburg', 'Grosskrotzenburg', 'Groskrocenburg,Groskrotcenburg,Grosskrotzenburg,Großkrotzenburg,da ke luo cen bao,gurosukurottsu~enburuku,Гроскротценбург,Гроскроценбург,グロースクロッツェンブルク,大克罗岑堡', 50.0833300, 8.9833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36862, 'Groß Kreutz', 'Gross Kreutz', 'Gros Krojc,Gros-Krojc,Gross Kreutz,Gross Kreuz,Groß Kreutz,Groß Kreuz,da ke luo yi ci,Грос Кројц,Грос-Кройц,Գրոս Կրոյց,大克罗伊茨', 52.4028100, 12.7794000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36863, 'Groß Köris', 'Gross Koeris', 'Gros Keris,Gros Kyoris,Gros-Kjoris,da ke li si,Грос Керис,Грос-Кёрис,Գրոս Կյորիս,大克里斯', 52.1658700, 13.6593500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36864, 'Großkorbetha', 'Grosskorbetha', 'Groskorbeta,Gross Corbetha,Grosskorbetha,Groß Corbetha,Großkorbetha,Гроскорбета', 51.2600200, 12.0301200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36865, 'Großkmehlen', 'Grosskmehlen', 'Groskmelen,Grosskmehlen,da ke mei lun,Гроскмелен,Գրոսկմելեն,大克梅伦', 51.3790100, 13.7250100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36866, 'Groß Kiesow', 'Gross Kiesow', 'Gros Kizov,Gros-Kizov,Kiesow,da ji suo,Грос Кизов,Грос-Кизов,大基索', 54.0126100, 13.4785100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36867, 'Großkayna', 'Grosskayna', '', 51.2906800, 11.9326900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36868, 'Großkarolinenfeld', 'Grosskarolinenfeld', 'Groskarolinenfel''d,Groskarolinenfeld,da ka luo li nen fei er de,grws karwlynnfld,Гроскаролиненфелд,Гроскаролиненфельд,Гроскароліненфельд,Գրոսկարոլինենֆելդ,گروس کارولیننفلد,大卡罗利嫩费尔德', 47.8910200, 12.0810100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36869, 'Großkarlbach', 'Grosskarlbach', 'Grooskarlbach,Groosskalbach,Grooßkalbach,Groskarlbakh,da ka er ba he,Гроскарлбах,大卡尔巴赫', 49.5383300, 8.2247200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36870, 'Großkampenberg', 'Grosskampenberg', '', 50.1500000, 6.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36871, 'Groß Ippener', 'Gross Ippener', '', 52.9666700, 8.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36872, 'Großholbach', 'Grossholbach', '', 50.4500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36873, 'Großheubach', 'Grossheubach', 'Grosgojbakh,Groshoybax,Groskhojbakh,Grossheubach,Großheubach,da huo yi ba he,gurosuhoibahha,Гросгойбах,Гросхойбах,Гросхојбах,Գրոսհոյբախ,グロースホイバッハ,大霍伊巴赫', 49.7283400, 9.2228000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36874, 'Großheringen', 'Grossheringen', 'Groskheringen,da hei lin gen,Гросхеринген,大黑林根', 51.1031300, 11.6686600, 'DE', '2014-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36875, 'Großhennersdorf', 'Grosshennersdorf', 'Groskhenersdorf,Groskhennersdorf,Grosshennersdorf,Großhennersdorf,Гросхенерсдорф,Гросхеннерсдорф', 50.9859700, 14.7877600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36876, 'Großheirath', 'Grossheirath', 'Grosgajrat,Groskhajrat,Grossheirath,Großheirath,da hai la te,gurosuhairato,Гросгайрат,Гросхайрат,Гросхајрат,Գրոսհայրաթ,グロースハイラート,大海拉特', 50.1760300, 10.9505000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36877, 'Großhartmannsdorf', 'Grosshartmannsdorf', 'Groskhartmansdorf,Grosshartmannsdorfi vald,Großhartmannsdorfi vald,da ha te man si duo fu,Гросхартмансдорф,大哈特曼斯多夫', 50.8000000, 13.3333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36878, 'Großharthau', 'Grossharthau', 'Grosgartau,Groskhartau,Grossharthau vald,Großharthau vald,da ha er tao,Гросгартау,Гросхартау,大哈尔陶', 51.1069400, 14.0991100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36879, 'Großharrie', 'Grossharrie', 'Grossharrie,Großharrie', 54.1166700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36880, 'Großhansdorf', 'Grosshansdorf', 'Groothansdoerp,Groothansdörp,Groskhansdorf,Grosshansdorf,Großhansdorf,da han si duo fu,Гросхансдорф,大汉斯多夫', 53.6666700, 10.2833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36881, 'Großhabersdorf', 'Grosshabersdorf', 'Grosgabersdorf,Groshabersdorf,Groskhabersdorf,Grosshabersdorf,Großhabersdorf,da ha bo si duo fu,Гросгаберсдорф,Гросхаберсдорф,Գրոսհաբերսդորֆ,大哈伯斯多夫', 49.4000000, 10.7833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36882, 'Groß Grönau', 'Gross Gronau', 'Gross Groenau,Gross Gronau,Groß Grönau', 53.8000000, 10.7500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36883, 'Großgoltern', 'Grossgoltern', 'Golturne [a. 1181],Groten-Goltern', 52.3326100, 9.5011100, 'DE', '2011-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36884, 'Groß-Gerau', 'Gross-Gerau', 'Gorad Gros-Gerau,Gros-Gerau,Gross-Gerau,Groß-Gerau,da gai lao,ghrws-ghyraw,grs-graw,gurosu=gerau,Горад Грос-Герау,Грос-Герау,غروس-غيراو,گرس-گراو,グロース＝ゲーラウ,大盖劳', 49.9213900, 8.4825500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36885, 'Großfischlingen', 'Grossfischlingen', '', 49.2688900, 8.1763900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36886, 'Großfahner', 'Grossfahner', 'Grosfaner,Grossfahner,Großfahner,da fa nei er,Гросфанер,大法内尔', 51.0562300, 10.8276300, 'DE', '2016-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36887, 'Großeutersdorf', 'Grosseutersdorf', 'Grosseutersdorf,Großeutersdorf', 50.7833300, 11.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36888, 'Großerlach', 'Grosserlach', 'Groserlakh,Grosserlach,Grosserlakh,Großerlach,ge luo sai er la,Гросерлах,Гроссерлах,格罗塞尔拉', 49.0536800, 9.5135600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36889, 'Großenwörden', 'Grossenworden', '', 53.6833300, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36890, 'Großenwiehe', 'Grossenwiehe', 'Grosenvie,Grosenvieh,Grosenvikhe,Grossenwiehe,Großenwiehe,Store Vi,ge luo sen wei hei,Гросенвие,Гросенвихе,Гросенвиэ,格罗森维黑', 54.7000000, 9.2500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36891, 'Großenstein', 'Grossenstein', 'Grosenshtajn,Grossenshtajn,Grossenstein,Großenstein,ge luo sen si tai yin,Гросенштайн,Гросенштајн,Гроссенштайн,格罗森斯泰因', 50.9000000, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36892, 'Großenseebach', 'Grossenseebach', 'Grosenseebach,Grossenseebach,Großenseebach', 49.6325100, 10.8748300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36893, 'Großensee', 'Grossensee', 'Grossensee,Großensee', 53.6126300, 10.3396100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36894, 'Großensee', 'Grossensee', '', 50.9333300, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36895, 'Großenrade', 'Grossenrade', 'Grossenrade,Großenrade', 54.0211400, 9.2224200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36896, 'Großenlüder', 'Grossenluder', 'Grosenlider,Grosenljuder,Grossenlueder,Grossenlüder,Großenlüder,ge luo sen lu de,Гросенлидер,Гросенлюдер,格罗森吕德', 50.5925000, 9.5423100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36897, 'Großenkneten', 'Grossenkneten', 'Ahlhorn,Grosenkneten,Grossenkneten,Großenkneten,ge luo sen ke nei teng,Гросенкнетен,格罗森克内滕', 52.9437700, 8.2532300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36898, 'Großenhain', 'Grossenhain', 'Grosengajn,Grosenhaina,Grosenkhajn,Grossenhain,Großenhain,Haganoa,Wulki Hojn,ge luo sen hai en,ghrwsnhayn,grshnhayn,Гросенгайн,Гросенхайн,Гросенхајн,غروسنهاين,گرشنهاین,格罗森海恩', 51.2895100, 13.5335000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36899, 'Großengottern', 'Grossengottern', 'Grosengotern,Grosengottern,Grossengottern,ge luo sen ge te er en,Гросенготерн,Гросенготтерн,Гроссенготтерн,格罗森戈特尔恩', 51.1482100, 10.5623200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36900, 'Großenehrich', 'Grossenehrich', 'Grosenerikh,Grossenehrich,Grossenerikh,Großenehrich,Herika [a. 877],ge luo sai nei li xi,ghrwsn arysh,grsn‌arysh,Гросенерих,Гроссенерих,غروسن إريش,گرسن‌اریش,格罗塞内里希', 51.2483800, 10.8345800, 'DE', '2014-12-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36901, 'Großen Buseck', 'Grossen Buseck', 'Buseck,Grossen Buseck,Großen Buseck', 50.6053100, 8.7856600, 'DE', '2014-05-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36902, 'Grossenbrode', 'Grossenbrode', 'Grossenbrode,Großenbrode', 54.3833300, 11.0833300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36903, 'Großenaspe', 'Grossenaspe', 'Grossenaspe,Großenaspe', 53.9833300, 9.9666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36904, 'Grosselfingen', 'Grosselfingen', 'Grosel''fingen,Groselfingen,Grossel''fingen,ge luo sai er fen gen,Гроселфинген,Гросельфинген,Гроссельфинген,Гроссельфінген,格罗塞尔芬根', 48.3322900, 8.8870400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36905, 'Großeibstadt', 'Grosseibstadt', 'Grosajbshtadt,Grosajbshtat,ge luo sai bu si ta te,Гросайбштадт,Гросајбштат,Գրոսայբշթաթ,格罗赛布斯塔特', 50.3010200, 10.4098000, 'DE', '2012-08-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36906, 'Großdubrau', 'Grossdubrau', 'Grosdubrau,Grossdubrau,Grossdubrau vald,Grossdubrau/Wulka Dubrawa,Großdubrau,Großdubrau vald,Großdubrau/Wulka Dubrawa,Wulka Dubrawa,da du bu lao,Гросдубрау,大杜布劳', 51.2542200, 14.4589700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36907, 'Groß Düben', 'Gross Duben', 'Dzewin,Dźěwin,Džěwin,Gros Diben,Gros-Djuben,Gross Duben,Gross Dueben/Dzewin,Gross Duebeni vald,Groß Düben,Groß Düben/Dźěwin,Groß Dübeni vald,da di ben,Грос Дибен,Грос-Дюбен,大迪本', 51.5666700, 14.5666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36908, 'Groß Disnack', 'Gross Disnack', 'Gross Disnack,Groß Disnack', 53.7500000, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36909, 'Großderschau', 'Grossderschau', '', 52.7905700, 12.3682000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36910, 'Großbundenbach', 'Grossbundenbach', '', 49.3000000, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36911, 'Groß Buchwald', 'Gross Buchwald', 'Gross Buchwald,Groß Buchwald', 54.1666700, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36912, 'Großbrembach', 'Grossbrembach', '', 51.1166700, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36913, 'Großbreitenbach', 'Grossbreitenbach', 'Grosbrajtenbakh,Grossbreitenbach,Großbreitenbach,da bu lai teng ba he,ghrwsbraytnbakh,grsbraytnbakh,Гросбрайтенбах,Гросбрајтенбах,غروسبرايتنباخ,گرسبرایتنباخ,大布赖滕巴赫', 50.5833500, 11.0095500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36914, 'Großbottwar', 'Grossbottwar', 'Grosbottvar,Grosbotvar,Grossbottwar,Großbottwar,da bo te wa er,ghrwsbwtfar,grsbwtwar,Гросботвар,Гросботтвар,غروسبوتفار,گرسبوتوار,大博特瓦尔', 49.0014700, 9.2934800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36915, 'Großbothen', 'Grossbothen', '', 51.1878400, 12.7510100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36916, 'Groß Börnecke', 'Gross Boernecke', '', 51.8846800, 11.4703200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36917, 'Großbodungen', 'Grossbodungen', 'Grossbodungen (Am Ohmberg),Großbodungen (Am Ohmberg)', 51.4757200, 10.4810400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36918, 'Groß Boden', 'Gross Boden', 'Gross Boden,Groß Boden', 53.7500000, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36919, 'Großbockedra', 'Grossbockedra', 'Grossbockedra,Großbockedra', 50.8500000, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36920, 'Groß-Bieberau', 'Gross-Bieberau', 'Gros-Biberau,Gross-Bieberau,Groß-Bieberau,da bi bei lao,ghrws-bybraw,grs-bybraw,gurosu=biberau,Грос-Биберау,Грос-Біберау,غروس-بيبراو,گرس-بیبراو,グロース＝ビーベラウ,大比贝劳', 49.8006400, 8.8243000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36921, 'Großbettlingen', 'Grossbettlingen', 'Grosbetlingen,Grosbettlingen,Grossbettlingen,Großbettlingen,da bei te lin gen,Гросбетлинген,Гросбеттлінген,Գրոսբետլինգեն,大贝特林根', 48.5905200, 9.3078200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36922, 'Groß Berßen', 'Gross Berssen', 'Gros Bersen,Gros-Bersen,Gross Berssen,Gross Bersssen,Groß Berßen,Groß Berßsen,da bei er sen,Грос Берсен,Грос-Берсен,大贝尔森', 52.7717300, 7.4938500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36923, 'Großbeeren', 'Grossbeeren', 'Grosberen,Grossbeeren,Großbeeren,da bei lun,Гросберен,Գրոսբերեն,大贝伦', 52.3586200, 13.3099400, 'DE', '2015-09-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36924, 'Großbartloff', 'Grossbartloff', 'Grossbartloff,Großbartloff', 51.2500000, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36925, 'Großbarkau', 'Grossbarkau', 'Grossbarkau,Großbarkau', 54.2333300, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36926, 'Großbardorf', 'Grossbardorf', 'Grosbardorf,Grossbardorf,Großbardorf,da ba duo fu,Гросбардорф,Գրոսբարդորֆ,大巴多夫', 50.2666700, 10.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36927, 'Großbardau', 'Grossbardau', '', 51.2041900, 12.6984800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36928, 'Groß Ammensleben', 'Gross Ammensleben', 'Ammenesleve,Gross Ammensleben,Groß Ammensleben', 52.2327900, 11.5219500, 'DE', '2016-01-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36929, 'Großalmerode', 'Grossalmerode', 'Grosal''merode,Grosalmerode,Grossalmerode,Großalmerode,Magna Almeroda,da a er mei luo de,ghrwsalmyrwdh,gurosuarumerode,Гросалмероде,Гросальмероде,غروسالميروده,گرس‌المروده,グロースアルメローデ,大阿尔梅罗德', 51.2585800, 9.7845000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36930, 'Großaitingen', 'Grossaitingen', 'Grossaitingen,Großaitingen', 48.2275300, 10.7794800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36931, 'Grönwohld', 'Groenwohld', 'Groenwohld,Gronwohld,Grönwohld', 53.6416200, 10.4078400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36932, 'Gröningen', 'Groeningen', 'Greningen,Grjoningen,Groeningen,Groinich,Groningen,Gröningen,ge lei ning gen,ghrwnynghn,grnyngn,Гренинген,Грёнинген,غرونينغن,گرنینگن,格勒宁根', 51.9374400, 11.2160100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36933, 'Gronau', 'Gronau', 'Gronau,ge luo nao,ghrwnaw,grwnaw  nwrdrayn-wstfaln,Гронау,غروناو,گروناو، نوردراین-وستفالن,格羅瑙', 52.2109900, 7.0223800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36934, 'Gronau', 'Gronau', 'Gronau,ghrwnaw,grwnaw  nydrzaksn,Гронау,غروناو,گروناو، نیدرزاکسن', 52.0846000, 9.7767800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36935, 'Grömitz', 'Gromitz', 'Gremic,Grjomic,Groemitz,Gromitz,Grömitz,ge lei mi ci,Гремиц,Грёмиц,格勒米茨', 54.1500000, 10.9666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36936, 'Grömbach', 'Groembach', 'Groembach,Grömbach', 48.5728900, 8.5454000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36937, 'Grolsheim', 'Grolsheim', '', 49.9083400, 7.9159900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36938, 'Groitzsch', 'Groitzsch', 'Groica,Groicsh,Groitzsch,Groiča,Grojch,Grojcsh,ge luo yi ci xi,ghrwytsh,grwych,Гроицш,Гройч,Гројцш,غرويتش,گرویچ,格罗伊茨希', 51.1553600, 12.2827900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36939, 'Grödersby', 'Grodersby', 'Grodersby,Grödersby', 54.6333300, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36940, 'Gröden', 'Groden', 'Groden,Groeden,Gröden', 51.4000000, 13.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36941, 'Gröde', 'Grode', 'A Groeoed,A Grööd,Grede,Grjode,Grode,Groue,Gröde,Grøde,ge lei de,Греде,Грёде,格勒德', 54.6333300, 8.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36942, 'Gröbzig', 'Groebzig', 'Grebcig,Grjobcig,Grobzig,Gröbzig,Гребциг,Грёбциг,Грөбциг', 51.6822600, 11.8745300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36943, 'Gröbers', 'Groebers', '', 51.4305000, 12.1162300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36944, 'Gröbenzell', 'Grobenzell', 'Groebenzell,Gröbenzell', 48.2000000, 11.3666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36945, 'Grobengereuth', 'Grobengereuth', '', 50.6691600, 11.6693700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36946, 'Grinau', 'Grinau', 'Grinau', 53.7833300, 10.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36947, 'Grimmen', 'Grimmen', 'Grimen,Grimmen,Grimmene,Grzemie,Grzëmié,ge li men,ghrymn,grymn,Гримен,Гриммен,غريمن,گریمن,格里门', 54.1121500, 13.0405100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36948, 'Grimmelshausen', 'Grimmelshausen', '', 50.4833300, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36949, 'Grimma', 'Grimma', 'Grima,Grimma,ge li ma,geulima,ghryma,gryma,Грима,Гримма,Грімма,غريما,گریما,格里马,그리마', 51.2336700, 12.7195900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36950, 'Grimburg', 'Grimburg', '', 49.6166700, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36951, 'Griesstätt', 'Griesstatt', 'Griesstaett,Griesstätt,Grisshtet,Grisshtett,ge li si te,grys ashtat,Грисштет,Грисштетт,Грісштетт,Գրիսշթեթ,گریس اشتات,格里斯特', 47.9940300, 12.1772700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36952, 'Griesingen', 'Griesingen', 'Grisingen,Grizingen,ge li xin gen,grizingeni,Гризинген,Грисинген,Грізінген,Գրիզինգեն,გრიზინგენი,格里辛根', 48.2666700, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36953, 'Griesheim', 'Griesheim', 'Griesheim', 49.8608500, 8.5725000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36954, 'Bad Griesbach', 'Bad Griesbach', 'Bad Griesbach im Rottal,Griesbach im Rott', 48.4518100, 13.1932900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36955, 'Gries', 'Gries', 'Gris,Грис', 49.4166700, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36956, 'Griefstedt', 'Griefstedt', '', 51.2295700, 11.1293200, 'DE', '2012-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36957, 'Griefstedt', 'Griefstedt', '', 51.2333300, 11.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36958, 'Griebelschied', 'Griebelschied', '', 49.8000000, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36959, 'Gribbohm', 'Gribbohm', 'Gribbohm', 54.0282100, 9.3473900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36960, 'Grevesmühlen', 'Grevesmuehlen', 'Grevesmilen,Grevesmilene,Grevesmjulen,Grevesmuehlen,Grevesmuhlen,Grevesmühlen,Grēvesmīlene,ge rui wei si mi lei en,ghrfsmwln,grfsmwln,Гревесмилен,Гревесмюлен,غرفسمولن,گرفسمولن,格芮维斯米勒恩', 53.8633700, 11.1916000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36961, 'Grevenkrug', 'Grevenkrug', 'Grevenkrug', 54.2166700, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36962, 'Grevenkop', 'Grevenkop', 'Grevenkop,Grevenkopp', 53.8426200, 9.5334700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36963, 'Grevenbroich', 'Grevenbroich', 'Grefenbrojkh,Grevenbroich,Grevenbroichas,Grevenbroikh,Grevenbrokh,ZEV,ge lei wen bu luo yi xi,ghrfnbrwysh,grfnbrwysh,gurevu~enburoho,Гревенброих,Гревенброх,Грефенбройх,غرفنبرويش,گرفنبرویش,グレーヴェンブローホ,格雷文布羅伊希', 51.0910200, 6.5827000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36964, 'Greven', 'Greven', 'Grefen,Grevaon,Greven,Grēvaon,ge lei fen,ghryfyn,grfn,Гревен,Грефен,غريفين,گرفن,格雷芬', 52.0936400, 7.5939600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36965, 'Greußenheim', 'Greussenheim', '', 49.8166700, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36966, 'Greußen', 'Greussen', 'Greussen,Greußen,Grojsen,ge luo yi sen,ghrwysn,grwysn,Гройсен,Гројсен,غرويسن,گرویسن,格罗伊森', 51.2296400, 10.9442200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36967, 'Grettstadt', 'Grettstadt', 'Gretshtadt,Gretshtat,Grettshtadt,ge lei ci ta te,grtshtat,Греттштадт,Гретштадт,Гретштат,گرتشتات,格雷茨塔特', 49.9833300, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36968, 'Grethem', 'Grethem', '', 52.7271400, 9.5725300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36969, 'Greppin', 'Greppin', 'Greppin', 51.6468200, 12.3006600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36970, 'Grenzach-Wyhlen', 'Grenzach-Wyhlen', 'Grencakh-Vilen,Grenzach,Grenzach-Wyhlen,ge lun cha-wei lun,Гренцах-Вилен,Гренцах-Вілен,格伦察-维伦', 47.5500000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36971, 'Grenderich', 'Grenderich', '', 50.0666700, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36972, 'Gremsdorf', 'Gremsdorf', 'Gremsdorf,ge lei mu si duo fu,guremusudorufu,Гремсдорф,グレムスドルフ,格雷姆斯多夫', 49.6950600, 10.8321800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36973, 'Gremersdorf', 'Gremersdorf', '', 54.3333300, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36974, 'Gremberghoven', 'Gremberghoven', 'Grembergkhofen,Kjol''n/Porc-Grembergkhofen,Грембергхофен,Кёльн/Порц-Грембергхофен', 50.9015200, 7.0612900, 'DE', '2013-03-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36975, 'Greiz', 'Greiz', 'Grajc,Greiz,Грайц', 50.6577800, 12.1991800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36976, 'Greimersburg', 'Greimersburg', '', 50.1833300, 7.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36977, 'Greimerath', 'Greimerath', '', 50.0333300, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36978, 'Greimerath', 'Greimerath', '', 49.5615500, 6.6837400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36979, 'Greiling', 'Greiling', '', 47.7666700, 11.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36980, 'Greifswald', 'Greifswald', 'Gorad Grajfsval''d,Grajfsval''d,Grajfsvald,Greifsvaldas,Greifsvalde,Greifswald,Griefswald,Griepswohld,Gripiew Las,ZGW,ge lai fu si wa er de,geulaipeuseubalteu,ghrayfsfalt,graipsvaldi,grayfswald,guraifusuvu~aruto,Горад Грайфсвальд,Грайфсвалд,Грайфсвальд,Грајфсвалд,גרייפסוואלד,غرايفسفالت,گرایفسوالد,گریفزوالڈ,გრაიფსვალდი,グライフスヴァルト,格赖夫斯瓦尔德,그라이프스발트', 54.0931100, 13.3878600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36981, 'Greifenstein', 'Greifenstein', 'Greifenstein', 50.6166700, 8.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36982, 'Greifenberg', 'Greifenberg', 'Grajfenberg,Grayfenberg,ge lai fen bei ge,grayfnbrg,guraifenberuku,Грайфенберг,Грајфенберг,Գրայֆենբերգ,گرایفنبرگ,グライフェンベルク,格赖芬贝格', 48.0706200, 11.0834900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36983, 'Grefrath', 'Grefrath', 'Grefrat,ge lei fu la te,Грефрат,格雷夫拉特', 51.3363000, 6.3407200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36984, 'Greffern', 'Greffern', '', 48.7520500, 8.0051500, 'DE', '2013-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36985, 'Greding', 'Greding', 'Greding,ge lei ding,ghrydyngh,grdyng,guredingu,Грединг,Гредінг,Գրեդինգ,غريدينغ,گردینگ,グレーディング,格雷丁', 49.0469900, 11.3570300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36986, 'Grebin', 'Grebin', 'Greben,Grebin,ge lei bin,Гребин,格雷宾', 54.2000000, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36987, 'Grebenstein', 'Grebenstein', 'Grebenshtajn,Grebensteen,Grebenstein,ge lei ben si tai yin,ghrybnshtayn,gurebenshutain,Гребенштайн,Гребенштајн,غريبنشتاين,گربن‌اشتاین,グレーベンシュタイン,格雷本斯泰因', 51.4464800, 9.4125000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36988, 'Grebenhain', 'Grebenhain', 'Grebengajn,Grebenkhajn,ge lei ben hai en,gurebenhain,Гребенгайн,Гребенхайн,Гребенхајн,グレーベンハイン,格雷本海恩', 50.4892400, 9.3385500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36989, 'Grebenau', 'Grebenau', 'Grebenau,ge lei bei nao,ghrybnaw,grbnaw,gurebenau,Гребенау,غريبناو,گربناو,グレーベナウ,格雷贝瑙', 50.7424200, 9.4730700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36990, 'Grävenwiesbach', 'Gravenwiesbach', 'Graevenwiesbach,Grefenvisbakh,Grevenvisbakh,Grävenwiesbach,ge lei fen wei si ba he,Гревенвисбах,Грефенвісбах,格雷芬维斯巴赫', 50.3902400, 8.4569000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36991, 'Grauel', 'Grauel', 'Grauel', 54.0666700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36992, 'Grattersdorf', 'Grattersdorf', 'Gratersdorf,Grattersdorf,ge la te si duo fu,gratrsdwrf,Гратерсдорф,Граттерсдорф,Գրաթերսդորֆ,گراترسدورف,格拉特斯多夫', 48.8036400, 13.1537200, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36993, 'Grassau', 'Grassau', 'Grasau,Grassau,grasaw,Грасау,Грассау,Գրասաու,گراساو', 47.7809900, 12.4535900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36994, 'Grasleben', 'Grasleben', 'Grasleben,Graslehen,Groslehen,ge la si lai ben,Граслебен,格拉斯莱本', 52.3063800, 11.0146500, 'DE', '2011-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36995, 'Grasbrunn', 'Grasbrunn', 'Grasbrun,Grasbrunn,Grosbrunn,ge la si bu lun,grasbrwn,Грасбрун,Грасбрунн,Գրասբրուն,گراسبرون,格拉斯布伦', 48.0790500, 11.7436100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36996, 'Grasberg', 'Grasberg', 'Gemeen Grasbarg,Grasberg,ge la si bei ge,Грасберг,格拉斯贝格', 53.1833300, 8.9833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36997, 'Gransee', 'Gransee', 'Granze,ge lan sai,ghranzyh,granzy,Гранзе,Գրանզե,غرانزيه,گرانزی,格兰塞', 53.0070400, 13.1575000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36998, 'Gransdorf', 'Gransdorf', '', 50.0166700, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(36999, 'Granschütz', 'Granschuetz', 'Granschuetz,Granschutz,Granschütz', 51.1843100, 12.0514900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37000, 'Grande', 'Grande', '', 53.5833300, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37001, 'Gramzow', 'Gramzow', 'Gramcov,ge la mu cuo,Грамцов,Գրամցով,格拉姆措', 53.2124600, 14.0074800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37002, 'Gramkow', 'Gramkow', '', 53.9209200, 11.3174000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37003, 'Grambek', 'Grambek', 'Grambek', 53.5738700, 10.6808100, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37004, 'Grainet', 'Grainet', 'Grainet,Grajnet,ge lai nei te,graynt,Грайнет,Грајнет,Ґрайнет,Գրայնեթ,گراینت,格赖内特', 48.8000000, 13.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37005, 'Grainau', 'Grainau', 'Grajnau,Graynau,Groana,ge lai nao,graynaw,Грайнау,Грајнау,Ґрайнау,Գրայնաու,گرایناو,格赖瑙', 47.4761400, 11.0240500, 'DE', '2012-01-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37006, 'Grafrath', 'Grafrath', 'Grafrat,ge la fu la te,grafrat,Графрат,Գրաֆրաթ,گرافرات,格拉夫拉特', 48.1166700, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37007, 'Grafling', 'Grafling', 'Grafling,ge la fu ling,graflyng,Графлинг,Графлінг,Գրաֆլինգ,گرافلینگ,格拉夫灵', 48.8949100, 12.9751100, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37008, 'Grafing bei München', 'Grafing bei Munchen', 'Grafing,Grafing apud Munkeno,Grafing ba Minga,Grafing bij Muenchen,Grafing bij München,Grafing kod Minkhena,Grafing-Mjunkhen,Markt Grafing,ghrafyngh,grafyng bay mwnykh,mu ni hei fu jin ge la fen,Графинг код Минхена,Графинг-Мюнхен,Графінг,غرافينغ,گرافینگ بای مونیخ,慕尼黑附近格拉芬', 48.0459600, 11.9679700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37009, 'Grafhorst', 'Grafhorst', '', 52.4448200, 10.9451300, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37010, 'Grafenwöhr', 'Grafenwohr', 'Grafenver,Grafenvjor,Grafenvyor,Grafenwoehr,Grafenwohr,Grafenwöhr,Gravenwerth,ge la fen wei he er,ghrafnfwr,grafnwr,Графенвер,Графенвёр,Գրաֆենվյոր,غرافنفور,گرافنور,格拉芬韦赫尔', 49.7172800, 11.9064500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37011, 'Grafenwiesen', 'Grafenwiesen', '', 49.2000000, 12.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37012, 'Gräfenthal', 'Graefenthal', 'Grafenthal,Grefental,Grevental'',Gräfenthal,ge lei fen ta er,ghryfntal,grfntal,Гревенталь,Грефентал,غريفنتال,گرفنتال,格雷芬塔尔', 50.5246300, 11.3067800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37013, 'Gräfenroda', 'Grafenroda', 'Graefenroda,Grafenroda,Grefenroda,Grevenroda,Gräfenroda,ge lei fen luo da,Гревенрода,Грефенрода,格雷芬罗达', 50.7500000, 10.8000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37014, 'Grafenrheinfeld', 'Grafenrheinfeld', 'Grafenrajnfel''d,Grafenrajnfeld,Grafenrkhajnfel''d,ge la fen lai yin fei er de,grafn raynfld,Графенрайнфельд,Графенрајнфелд,Графенрхайнфельд,گرافن راینفلد,格拉芬赖因费尔德', 50.0000000, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37015, 'Grafenhausen', 'Grafenhausen', 'Grafenhausen,Grafenhaussen', 48.2842700, 7.7667800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37016, 'Grafenhausen', 'Grafenhausen', 'Grafengauzen,Grafenhausen,Grafenkhauzen,ge la fen hao sen,Графенгаузен,Графенхаузен,格拉芬豪森', 47.7749500, 8.2573100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37017, 'Gräfenhainichen', 'Graefenhainichen', 'Graefenhainichen,Grafenhainchen,Grafenhainichen,Grefenkhajnikhen,Gräfenhainchen,Gräfenhainichen,ge lei fen hai ni xing,ghryfnhaynyshn,grfnhaynyshn,Грефенхайнихен,Грефенхајнихен,غريفنهاينيشن,گرفنهاینیشن,格雷芬海尼兴', 51.7289200, 12.4565100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37018, 'Gräfenhain', 'Grafenhain', '', 50.8166700, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37019, 'Grafengehaig', 'Grafengehaig', 'Grafengegajg,Grafengehaig,Grafengehayg,Grafengekhajg,Grafengelhaig,ge la fen ge hai xi,grafnghayg,gurafengehaiku,Графенгегайг,Графенгехайг,Графенгехајг,Գրաֆենգեհայգ,گرافنگهایگ,グラーフェンゲハイク,格拉芬格海希', 50.2031000, 11.5935800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37020, 'Gräfendorf', 'Grafendorf', 'Grefendorf,ge lei fen duo fu,Грефендорф,Գրեֆենդորֆ,格雷芬多夫', 50.1226700, 9.7405000, 'DE', '2013-02-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37021, 'Gräfendhron', 'Graefendhron', '', 49.8000000, 7.0000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37022, 'Gräfenberg', 'Grafenberg', 'Graefenberg,Gräfenberg', 49.6442600, 11.2497100, 'DE', '2017-06-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37023, 'Grafenau', 'Grafenau', 'Grafenau,Gravenau,grfnaw  bayrn,Графенау,گرفناو، بایرن', 48.8576800, 13.3974000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37024, 'Gräfelfing', 'Grafelfing', 'Graefelfing,Grefefing,Grefel''fing,Grefelfing,Gräfelfing,ge lei fei er fen ge,grflfyng,Грефелфинг,Грефельфинг,Грефельфінг,Գրեֆելֆինգ,گرفلفینگ,格雷费尔芬格', 48.1187800, 11.4293900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37025, 'Grabsleben', 'Grabsleben', 'Grabsleben', 50.9363300, 10.8350800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37026, 'Grabowhöfe', 'Grabowhoefe', '', 53.5686500, 12.5948200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37027, 'Grabow', 'Grabow', 'Grabow', 53.2796600, 11.5650200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37028, 'Grabenstetten', 'Grabenstetten', 'Grabenshteten,Grabenshtetten,ge la ben si te teng,Грабенштетен,Грабенштеттен,格拉本斯特滕', 48.5239700, 9.4615500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37029, 'Grabenstätt', 'Grabenstatt', 'Grabenshtet,Grabenshtett,Grabenstaett,Grabenstätt,Gramstaett,Gråmstätt,ge la ben si te,grabnshtt,Грабенштет,Грабенштетт,Գրաբենշթեթ,گرابنشتت,格拉本斯特', 47.8453100, 12.5433000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37030, 'Gräben', 'Graben', 'Greben,ge lei ben,Гребен,Գրեբեն,格雷本', 52.2333300, 12.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37031, 'Graben', 'Graben', '', 48.1873200, 10.8222200, 'DE', '2012-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37032, 'Grabau', 'Grabau', '', 53.8000000, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37033, 'Grabau', 'Grabau', '', 53.5135700, 10.5200100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37034, 'Gottmadingen', 'Gottmadingen', 'Gotmadingen,Gottmadingen,ge te ma ding gen,Готмадинген,Готтмадинген,Готтмадінген,戈特马丁根', 47.7351100, 8.7768700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37035, 'Göttingen', 'Goettingen', 'Choettingen,Chöttingen,G''otingen,Getingen,Getingenas,Getingene,Getynga,Gjottingen,Goettingen,Gorad Gjotyngen,Gotinga,Gottinga,Gottingen,Göttingen,Nketin''nken,ZEU,gatingen,ge ting gen,gettingen,ghwtynghn,goeting-gen,gtyngn,gwtyngn,gyotingana,keiththing ngein,Γκέτινγκεν,Гетинген,Горад Гётынген,Гьотинген,Гёттинген,Ґетінґен,Գյոթինգեն,גטינגן,غوتينغن,گوتینگن,گوٹنگن,ग्यॉटिंगन,ಗಾಟಿಂಗೆನ್,เกิททิงเงิน,გეტინგენი,ゲッティンゲン,哥廷根,괴팅겐', 51.5344300, 9.9322800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37036, 'Göttin', 'Gottin', '', 53.5333300, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37037, 'Gottfrieding', 'Gottfrieding', 'Gotfriding,Gottfriding,Gottfrieding,Gottfriedinger Schwaig,ge te fu li ding,gwtfrydyng,Готтфридинг,Готтфрідінг,Готфридинг,Գոթֆրիդինգ,گوتفریدینگ,戈特弗里丁', 48.6373700, 12.5356100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37038, 'Gotteszell', 'Gotteszell', 'Gotescel,Gottescel'',Gottescell'',ge te si ce er,gwts tsl,Готесцел,Готтесцелль,Готтесцель,Գոթեսցել,گوتس تسل,戈特斯策尔', 48.9666700, 12.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37039, 'Gottenheim', 'Gottenheim', 'Gotenkhajm,Gottengajm,Gottenkhajm,ge teng hai mu,Готенхајм,Готтенгайм,Готтенхайм,Գոթենհայմ,戈滕海姆', 48.0500000, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37040, 'Gotha', 'Gotha', 'Gorad Gota,Gota,Gotha,ge da,ghwta,gota,gwta,gwth,Горад Гота,Гота,Գոթա,גותה,غوتا,گوتا,ゴータ,哥達,고타', 50.9482300, 10.7019300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37041, 'Goßwitz', 'Gosswitz', '', 50.6353600, 11.4773700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37042, 'Gößweinstein', 'Goessweinstein', 'Gesvajnshtajn,Gjosvajnshtajn,Goessweinstein,Gossweinstein,Gößweinstein,ge si wei yin si tai yin,gesuvu~ainshutain,Гесвайнштайн,Гесвајнштајн,Гёсвайнштайн,ゲスヴァインシュタイン,格斯韦因斯泰因', 49.7689800, 11.3384100, 'DE', '2017-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37043, 'Gößnitz', 'Goessnitz', 'Gesnic,Gjosnic,Goessnitz,Gossnitz,Gößnitz,ge si ni ci,gwshnytz,Гесниц,Гёсниц,گوشنیتز,格斯尼茨', 50.8890200, 12.4329200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37044, 'Gössitz', 'Gossitz', 'Goessitz,Gössitz', 50.6220200, 11.5864800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37045, 'Gössenheim', 'Gossenheim', 'Gesenkhajm,Gessengajm,Gjossenkhajm,Goessenheim,Gyosenhaym,Gössenheim,ge sen hai mu,Гесенхајм,Гессенгайм,Гёссенхайм,Գյոսենհայմ,格森海姆', 50.0166700, 9.7833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37046, 'Gossel', 'Gossel', 'Gossel', 50.8000000, 10.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37047, 'Goslar', 'Goslar', 'Goslaer,Goslar,Goslaria,Goslär,ZET,ge si la er,ghwslar,goslari,gosura,gslar,gwslʼr,Гослар,גוסלאר,غوسلار,گسلار,گوسلار قلعہ,გოსლარი,ゴスラー,戈斯拉尔', 51.9042500, 10.4276600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37048, 'Gosheim', 'Gosheim', 'Goskhajm,ge si hai mu,Госхайм,Госхајм,戈斯海姆', 48.1343000, 8.7542600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37049, 'Gösenroth', 'Gosenroth', '', 49.8833300, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37050, 'Gösen', 'Goesen', '', 51.0000000, 11.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37051, 'Goseck', 'Goseck', 'Gosek,Gozek,Гозек,Госек', 51.2000000, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37052, 'Göschitz', 'Goschitz', 'Goschitz,Göschitz', 50.6333300, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37053, 'Görzke', 'Goerzke', 'Gercke,Gjorcke,Goerzke,Görzke,ge er ci ke,Герцке,Гёрцке,Գյորցկե,格尔茨克', 52.1717900, 12.3750600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37054, 'Görzig', 'Goerzig', 'Gercig,Gjorcig,Gorzig,Görzig,Герциг,Гёрциг,Гөрциг', 51.6638100, 11.9975900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37055, 'Görwihl', 'Goerwihl', 'Gervil,Gervil'',Gjorvil'',Goerwihl,Gohrwil,Gorwihl,Göhrwil,Görwihl,ge er wei er,Гервил,Гервіль,Гёрвиль,格尔维尔', 47.6427500, 8.0748200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37056, 'Gorsleben', 'Gorsleben', 'Gersleben,Gorsleben', 51.2753100, 11.1843800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37057, 'Görsbach', 'Gorsbach', 'Gersbeke[a. 1239],Goersbach,Görsbach', 51.4622400, 10.9370600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37058, 'Gornsdorf', 'Gornsdorf', 'Gornsdorf,ge er en si duo fu,Горнсдорф,戈尔恩斯多夫', 50.7000000, 12.8833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37059, 'Gornhausen', 'Gornhausen', '', 49.8666700, 7.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37060, 'Gornau', 'Gornau', 'Gornau,Gornau vald,Gornau/Erzgebirge,ge er nao,Горнау,戈尔瑙', 50.7590100, 13.0373100, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37061, 'Görmin', 'Goermin', 'Germin,Gjormin,ge er ming,Гермин,Гёрмин,格尔明', 53.9909200, 13.2705400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37062, 'Görlitz', 'Goerlitz', 'G''orlic,Gerlic,Gerlica,Giorlicas,Gjorlic,Goerlitz,Gorad Gjorlic,Gorlicium Germaniae,Gorlitz,Görlitz,Nkerlits,Zgorjelc,Zgórjelc,Zhorelec,Zhorjelc,Zhořelec,ge er li ci,gerlitsi,gerurittsu,ghwrlyts,goeleullicheu,grlytz,grlyz,Γκέρλιτς,Герлиц,Герліц,Горад Гёрліц,Гьорлиц,Гёрлиц,Гөрлиц,גרליץ,غورليتس,گرلیتز,گورلٹز,გერლიცი,ゲルリッツ,格尔利茨,괴를리츠', 51.1551800, 14.9885300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37063, 'Gorleben', 'Gorleben', 'Gorleben,ge er lai ben,gwrlbn,Горлебен,گورلبن,戈尔莱本', 53.0484400, 11.3572900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37064, 'Görkwitz', 'Gorkwitz', 'Gorkwitz,Görkwitz', 50.5833300, 11.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37065, 'Göritz', 'Goritz', 'Geric,Gjoric,ge li ci,Гериц,Гёриц,Գյորից,格里茨', 53.4062600, 13.9155600, 'DE', '2016-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37066, 'Görisried', 'Goerisried', 'Gerisrid,Gjorisrid,Gyorisrid,ge li si li de,gerisurito,Герисрид,Герісрід,Гёрисрид,Գյորիսրիդ,ゲリスリート,格里斯里德', 47.7066800, 10.5101500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37067, 'Görgeshausen', 'Goergeshausen', 'Goergeshausen,Görgeshausen', 50.4166700, 7.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37068, 'Göppingen', 'Goeppingen', 'G''opingen,Gepingen,Geppingen,Gjoppingen,Goeppingen,Göppingen,ZES,ge ping gen,geppingen,ghwbynghn,gwpyngn,Гепинген,Геппінген,Гьопинген,Гёппинген,غوبينغن,گوپینگن,ゲッピンゲン,格平根', 48.7035400, 9.6520900, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37069, 'Göpfersdorf', 'Gopfersdorf', 'Gopfersdorf,Göpfersdorf', 50.9130200, 12.5965100, 'DE', '2016-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37070, 'Goosefeld', 'Goosefeld', 'Goosefeld,Gosefeld,Gozefel''d,Gozefeld,ge sai fei er de,Гозефелд,Гозефельд,戈塞费尔德', 54.4333300, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37071, 'Gönnheim', 'Gonnheim', 'Goennheim,Gönnheim', 49.4480600, 8.2386100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37072, 'Gönnersdorf', 'Gonnersdorf', '', 50.4833300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37073, 'Gönnersdorf', 'Gonnersdorf', 'Goennersdorf,Gönnersdorf', 50.3333300, 6.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37074, 'Gönnebek', 'Goennebek', 'Gonnebek,Gönnebek', 54.0489500, 10.1969000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37075, 'Gondorf', 'Gondorf', '', 49.9666700, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37076, 'Gondenbrett', 'Gondenbrett', '', 50.2333300, 6.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37077, 'Gondelsheim', 'Gondelsheim', 'Gondel''sgajm,Gondel''skhajm,Gondelskhajm,Гонделсхајм,Гондельсгайм,Гондельсхайм', 49.0591700, 8.6583300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37078, 'Gonbach', 'Gonbach', '', 49.5500000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37079, 'Gompertshausen', 'Gompertshausen', 'Gompertshausen', 50.2985000, 10.6249800, 'DE', '2016-08-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37080, 'Gommersheim', 'Gommersheim', '', 49.2911100, 8.2658300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37081, 'Gommern', 'Gommern', 'Gomern,Gommern,ge mei er en,ghwmrn,gmrn,Гомерн,Гоммерн,غومرن,گمرن,戈梅尔恩', 52.0739100, 11.8229700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37082, 'Gomaringen', 'Gomaringen', 'Gomaringen,ge ma lin gen,Гомаринген,Гомарінген,戈马林根', 48.4534900, 9.0958200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37083, 'Gomadingen', 'Gomadingen', 'Gomadingen,ge ma ding gen,Гомадинген,Гомадінген,戈马丁根', 48.3998000, 9.3906500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37084, 'Golzow', 'Golzow', '', 52.5740000, 14.4930300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37085, 'Golzow', 'Golzow', '', 52.2761700, 12.6005200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37086, 'Goltoft', 'Goltoft', 'Goltoft', 54.5500000, 9.7166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37087, 'Golßen', 'Golssen', 'Gol''sen,Golisyn,Golsen,Golsene,Golssen,Golßen,Gólišyn,ge er sen,ghwlsn,glsn,Голсен,Гольсен,Գոլսեն,غولسن,گلسن,戈尔森', 51.9720400, 13.6011500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37088, 'Golmsdorf', 'Golmsdorf', 'Gol''msdorf,Golmsdorf,ge er mu si duo fu,Голмсдорф,Гольмсдорф,戈尔姆斯多夫', 50.9666700, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37089, 'Golmbach', 'Golmbach', 'Gol''mbakh,Golmbakh,ge er en ba he,gorumubahha,Голмбах,Гольмбах,ゴルムバッハ,戈尔恩巴赫', 51.9000000, 9.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37090, 'Göllnitz', 'Gollnitz', '', 50.9500000, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37091, 'Gollhofen', 'Gollhofen', 'Gol''gofen,Golhofen,Golkhofen,Goll''khofen,ge er huo fen,Голльхофен,Голхофен,Гольгофен,Գոլհոֆեն,戈尔霍芬', 49.5688100, 10.1918800, 'DE', '2013-02-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37092, 'Göllheim', 'Gollheim', 'Gelkhajm,Gjol''khajm,Goellheim,Gollheim,Göllheim,ge er hai mu,geruhaimu,Гелхајм,Гёльхайм,ゲルハイム,格尔海姆', 49.5950000, 8.0508300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37093, 'Gollenberg', 'Gollenberg', '', 49.6666700, 7.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37094, 'Gölenkamp', 'Golenkamp', '', 52.5166700, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37095, 'Goldkronach', 'Goldkronach', 'Gol''dkronakh,Goldkronach,Goldkronakh,Goldkronax,ge er de ke luo na,ghwldkrwnakh,gldkrwnakh,gorutokuronaha,Голдкронах,Гольдкронах,Գոլդկրոնախ,غولدكروناخ,گلدکروناخ,ゴルトクローナハ,戈尔德克罗纳', 50.0108600, 11.6875000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37096, 'Goldisthal', 'Goldisthal', 'Gol''distal'',Goldistal,ge er di si ta er,Голдистал,Гольдисталь,戈尔迪斯塔尔', 50.5166700, 11.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37097, 'Goldenstedt', 'Goldenstedt', 'Gol''denshtedt,Goldenshtet,ge er deng si te,Голденштет,Гольденштедт,戈尔登斯特', 52.7883300, 8.4320100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37098, 'Göldenitz', 'Goldenitz', '', 53.7166700, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37099, 'Goldelund', 'Goldelund', 'Goldelund', 54.6833300, 9.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37100, 'Goldebek', 'Goldebek', 'Goldebeck,Goldebek', 54.6833300, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37101, 'Goldberg', 'Goldberg', 'Gol''dberg,Goldberg,Goldberga,gldbrg,Голдберг,Гольдберг,گلدبرگ', 53.5887800, 12.0885500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37102, 'Goldbeck', 'Goldbeck', '', 52.7169500, 11.8606000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37103, 'Goldbach', 'Goldbach', '', 51.0456600, 11.4328900, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37104, 'Goldbach', 'Goldbach', '', 50.9924200, 10.6575100, 'DE', '2016-08-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37105, 'Goldbach', 'Goldbach', 'Gol''dbakh,Goldbach,Goldbakh,Goldbax,ge er de ba he,gorutobahha,Голдбах,Гольдбах,Գոլդբախ,ゴルトバッハ,戈尔德巴赫', 49.9995100, 9.1844000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37106, 'Gokels', 'Gokels', 'Gokels', 54.1166700, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37107, 'Göhren', 'Gohren', '', 50.9666700, 12.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37108, 'Göhrde', 'Gohrde', 'Gerde,Gjorde,Gohrde,Göhrde,ge he er de,gwrdh,Герде,Гёрде,گورده,格赫尔德', 53.1500000, 10.8833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37109, 'Goel', 'Goel', 'Goel,Gohl,Göhl', 54.2835000, 10.9403600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37110, 'Göggingen', 'Goggingen', 'Goeggingen,Göggingen', 48.8612300, 9.8839800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37111, 'Gödenstorf', 'Godenstorf', '', 53.2285500, 10.1234900, 'DE', '2011-09-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37112, 'Gödenroth', 'Godenroth', 'Goedenroth,Gödenroth', 50.0833300, 7.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37113, 'Goddert', 'Goddert', '', 50.5491700, 7.7469400, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37114, 'Göda', 'Goeda', 'Geda,Gjoda,Goeda,Goeda vald,Goeda/Hodzij,Göda,Göda vald,Göda/Hodźij,Hodzij,Hodźij,ge da,Геда,Гёда,格达', 51.1780000, 14.3195100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37115, 'Göcklingen', 'Gocklingen', 'Goecklingen,Göcklingen', 49.1619400, 8.0413900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37116, 'Gochsheim', 'Gochsheim', 'Gochsheim,Gokhskhajm,Goksgajm,Gokskhajm,gwkshaym,Гоксгайм,Гоксхайм,Гохсхајм,گوکسهایم', 50.0166700, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37117, 'Goch', 'Goch', 'Goch,Gokh,ge he,ghwkh,gkh,Гох,غوخ,گخ,戈赫', 51.6787300, 6.1589500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37118, 'Gnutz', 'Gnutz', 'Gnutz', 54.1333300, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37119, 'Gnoien', 'Gnoien', 'Gnoen,Gnoiene,Gnojen,ge nuo yi en,ghnwyn,gnwyn,Гнойен,Гноєн,Гнојен,غنوين,گنوین,格诺伊恩', 53.9687000, 12.7109900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37120, 'Gnarrenburg', 'Gnarrenburg', 'Gemeen Gnarrenborg,Gnarenburg,Gnarrenburg,ge na lun bao,gunarenburuku,Гнаренбург,Гнарренбург,グナレンブルク,格纳伦堡', 53.3833300, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37121, 'Gmund am Tegernsee', 'Gmund am Tegernsee', 'Gmund,Gmund am Tegernsee,Gmund am Tegernze,Gmund-am-Tegernze,Tegerenzei Gmund,gmwnd am tgrnzy,te ge er en hu pan ge meng de,Гмунд ам Тегернзе,Гмунд-ам-Тегернзе,Տեգերենզեի Գմունդ,گموند ام تگرنزی,特格尔恩湖畔格蒙德', 47.7511900, 11.7381000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37122, 'Glüsing', 'Gluesing', '', 54.2833300, 9.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37123, 'Glückstadt', 'Glueckstadt', 'Glikshtat,Gljukshtadt,Gluckstadt,Glueckstadt,Glückstadt,Lukkstadur,Lukkstaður,ge lu ke si ta te,ghlwkshtat,Гликштат,Глюкштадт,غلوكشتات,گلوک‌اشتات,格吕克斯塔特', 53.7889300, 9.4257600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37124, 'Glücksburg', 'Gluecksburg', 'Gliksburg,Gljuksburg,Glucksburg,Gluecksburg,Glücksburg,Lukkuborg,Lyksborg,Nklyxmpournk,ge lu ke si bao,ghlwksbwrgh,glwksbwrg,Γκλύξμπουργκ,Гликсбург,Глюксбург,غلوكسبورغ,گلوکسبورگ,გლიუკსბურგი,格吕克斯堡', 54.8352200, 9.5485300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37125, 'Glowe', 'Glowe', 'Glove,Glowe,ge luo wei,Глове,格洛韦', 54.5691100, 13.4655000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37126, 'Glött', 'Glott', 'Gloett,Glött', 48.5000000, 10.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37127, 'Glöthe', 'Gloethe', '', 51.9100000, 11.6747100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37128, 'Glonn', 'Glonn', 'Glon,Glonn,ge long,glwn,Глон,Глонн,گلون,格隆', 47.9875100, 11.8672100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37129, 'Glindenberg', 'Glindenberg', 'Glindenberg', 52.2385700, 11.6836100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37130, 'Glinde', 'Glinde', 'Glinde,Glinn', 53.5441000, 10.2004800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37131, 'Glienicke', 'Glienicke', '', 52.6335300, 13.3256400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37132, 'Gleiszellen-Gleishorbach', 'Gleiszellen-Gleishorbach', '', 49.1261100, 8.0058300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37133, 'Gleisweiler', 'Gleisweiler', 'Glajsvajler,ge lai si wei lei,Глайсвайлер,Глајсвајлер,格莱斯韦勒', 49.2422200, 8.0694400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37134, 'Gleißenberg', 'Gleissenberg', '', 49.3166700, 12.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37135, 'Gleiritsch', 'Gleiritsch', 'Glajrich,Gljajrich,ge lai li ci xi,glayrych,Глайрич,Глајрич,Гляйріч,گلایریچ,格莱里茨希', 49.4973100, 12.3151800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37136, 'Gleina', 'Gleina', 'Glajna,ge lai na,Глайна,Глајна,格莱纳', 51.2580100, 11.7202800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37137, 'Gleichamberg', 'Gleichamberg', 'Glajkhamberg,Gleichamberg,ge lai xian bei ge,Глайхамберг,Глајхамберг,格莱先贝格', 50.3706800, 10.5982200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37138, 'Glees', 'Glees', '', 50.4333300, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37139, 'Glauchau', 'Glauchau', 'Glaucha,Glauchau,Glauhava,Glaukhau,Hluchow,Hłuchow,Stadt Glauchau,ge lao hao,ghlawkhaw,glaukhau,glawkhaw,Глаухау,غلاوخاو,گلاوخاو,გლაუხაუ,格劳豪', 50.8198700, 12.5449300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37140, 'Glauburg', 'Glauburg', 'Glauberg,Glauburg,ge lao bao,gurauburuku,Глаубург,グラウブルク,格劳堡', 50.3166700, 9.0000000, 'DE', '2017-07-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37141, 'Glaubitz', 'Glaubitz', 'Glaubic,Glaubitzi vald,ge lao bi ci,Глаубиц,Глаубіц,格劳比茨', 51.3249800, 13.3781700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37142, 'Glatten', 'Glatten', 'Glaten,Glatten,ge la teng,Глатен,Глаттен,Գլաթեն,格拉滕', 48.4424600, 8.5111600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37143, 'Glattbach', 'Glattbach', 'Glatbakh,Glatbax,Glattbach,Glattbakh,ge la te ba he,gurattobahha,Глатбах,Глаттбах,Գլատբախ,グラットバッハ,格拉特巴赫', 50.0000000, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37144, 'Glashütten', 'Glashutten', 'Glasgjutten,Glashuetten,Glashutten,Glashütten,Glaskhiten,Glaskhjutten,ge la si xu teng,Гласгюттен,Гласхитен,Гласхюттен,格拉斯许滕', 50.2166700, 8.4000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37145, 'Glashütten', 'Glashutten', 'Glashuetten,Glashütten', 49.8873900, 11.4487000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37146, 'Glashütte', 'Glashuette', 'Glashuette,Glashütte,Glaskhite,Glaskhjute,Glaskhjutte,Gljaskhjutte,ge la si xu te,glshwth,Гласхите,Гласхюте,Гласхютте,Глясхютте,گلسهوته,格拉斯许特', 50.8519600, 13.7797700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37147, 'Glasehausen', 'Glasehausen', '', 51.4422400, 10.1520500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37148, 'Glasau', 'Glasau', 'Glasau', 54.0500000, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37149, 'Glan-Münchweiler', 'Glan-Munchweiler', 'Glan-Minkhvajler,Glan-Mjunkhvajler,Glan-Muenchweiler,Glan-Munchweiler,Glan-Münchweiler,Munchweiler,Münchweiler,ge lan-ming xi wei lei,guran=myunhivu~aira,Глан-Минхвајлер,Глан-Мюнхвайлер,グラン＝ミュンヒヴァイラー,格兰-明希韦勒', 49.4722200, 7.4420400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37150, 'Glandorf', 'Glandorf', 'Glandorf', 52.0847400, 7.9994400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37151, 'Gladenbach', 'Gladenbach', 'Gladenbach,Gladenbakh,ge la deng ba he,ghladnbakh,gldnbakh,guradenbahha,Гладенбах,غلادنباخ,گلدنباخ,グラーデンバッハ,格拉登巴赫', 50.7684700, 8.5808500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37152, 'Gladbeck', 'Gladbeck', 'Gladbeck,Gladbek,Gladbeki,Gladbėki,Gorad Gladbek,ZEK,ge la de bei ke,geullateubekeu,ghladbyk,gladbk,Гладбек,Горад Гладбек,غلادبيك,گلادبک,格拉德貝克,글라트베크', 51.5707700, 6.9859300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37153, 'Gladbach', 'Gladbach', '', 49.9333300, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37154, 'Gittelde', 'Gittelde', 'Gitelde,Gittel''de,ji te er de,Гителде,Гиттельде,吉特尔德', 51.7984000, 10.1878000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37155, 'Girod', 'Girod', '', 50.4500000, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37156, 'Girkenroth', 'Girkenroth', '', 50.5208300, 7.9719400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37157, 'Gipperath', 'Gipperath', '', 50.0333300, 6.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37158, 'Ginsweiler', 'Ginsweiler', 'Ginsvajler,jin si wei lei,Гинсвайлер,Гинсвајлер,金斯韦勒', 49.6500000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37159, 'Ginsheim-Gustavsburg', 'Ginsheim-Gustavsburg', 'Ginskhajm-Gustavsburg,jin si hai mu-gu si ta fu si bao,Гинсхайм-Густавсбург,Гинсхајм-Густавсбург,金斯海姆-古斯塔夫斯堡', 49.9711000, 8.3453200, 'DE', '2013-08-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37160, 'Gingst', 'Gingst', 'Gingst,jin ge si te,Гингст,金格斯特', 54.4565400, 13.2573700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37161, 'Gingen an der Fils', 'Gingen an der Fils', 'Gingen,Gingen an der Fils,Gingen-an-der-Fil''s,Gingen-na-Fil''se,fei er si he pan jin gen,Гинген ан дер Филс,Гинген-на-Фильсе,Гінген-ан-дер-Фільс,菲尔斯河畔金根', 48.6597900, 9.7809200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37162, 'Gindorf', 'Gindorf', '', 50.0166700, 6.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37163, 'Gimbweiler', 'Gimbweiler', '', 49.5833300, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37164, 'Gimbsheim', 'Gimbsheim', 'Gimbskhajm,jin bu si hai mu,Гимбсхайм,Гимбсхајм,金布斯海姆', 49.7777800, 8.3750000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37165, 'Gilzem', 'Gilzem', '', 49.8666700, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37166, 'Gilten', 'Gilten', '', 52.7000000, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37167, 'Gilserberg', 'Gilserberg', 'Gil''zerberg,Gilserberg,Gilzerberg,giruzaberuku,ji er ze bei ge,Гилзерберг,Гильзерберг,Гільзерберг,ギルザーベルク,吉尔泽贝格', 50.9500000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37168, 'Gillersdorf', 'Gillersdorf', 'Gillersdorf', 50.6166700, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37169, 'Gillenfeld', 'Gillenfeld', 'Gilenfeld,Gillenfel''d,ji lun fei er de,Гиленфелд,Гилленфельд,吉伦费尔德', 50.1279000, 6.9038300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37170, 'Gillenbeuren', 'Gillenbeuren', '', 50.1551500, 7.0186000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37171, 'Gilching', 'Gilching', 'Gil''khing,Gilching,Gilkhing,gylshyng,ji er xing,Гилхинг,Гильхинг,Гільхінг,گیلشینگ,吉尔兴', 48.1075500, 11.2936000, 'DE', '2012-09-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37172, 'Gifhorn', 'Gifhorn', 'Gifhorn,Gifkhorn,ghyfhwrn,gyfhwrn,ji fu huo en,jyfhwrn,Гифхорн,جيفهورن,غيفهورن,گیفهورن,吉夫霍恩', 52.4777400, 10.5511000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37173, 'Gießen', 'Giessen', 'Gieseni,Giessa,Giessen,Gießen,Gisen,Gissen,Gorad Gisen,Gysenas,Nkisen,ghysn,gisen,giseni,gysn,ji sen,kis sein,Γκίσεν,Гисен,Гиссен,Горад Гісен,Гіссен,גיסן,غيسن,گیسن,กีสเซิน,გისენი,ギーセン,吉森,기센', 50.5872700, 8.6755400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37174, 'Giesensdorf', 'Giesensdorf', '', 53.6833300, 10.7000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37175, 'Giesenhausen', 'Giesenhausen', '', 50.7000000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37176, 'Giesdorf', 'Giesdorf', '', 50.1833300, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37177, 'Gierstädt', 'Gierstadt', 'Gierstadt,Gierstaedt,Gierstädt,Girshtedt,Girshtet,ji er si te,Гирштедт,Гирштет,吉尔斯特', 51.0423600, 10.8262100, 'DE', '2016-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37178, 'Giersleben', 'Giersleben', 'Giersleben', 51.7666700, 11.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37179, 'Giershausen', 'Giershausen', '', 50.6811100, 7.5461100, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37180, 'Gierschnach', 'Gierschnach', '', 50.2666700, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37181, 'Giengen an der Brenz', 'Giengen an der Brenz', 'Giengen,Gingen,Gingen an der Brenc,Gingen-an-der-Brenc,Gingen-na-Brence,bu lun ci he pan jin gen,ghynghn an dr brnts,gyngn an dr brnts,Гинген ан дер Бренц,Гинген-ан-дер-Бренц,Гинген-на-Бренце,Гінген,غينغن آن در برنتس,گینگن آن در برنتس,布伦茨河畔金根', 48.6221900, 10.2431200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37182, 'Gielow', 'Gielow', 'Gielow', 53.6975600, 12.7452100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37183, 'Gielert', 'Gielert', '', 49.7746100, 7.0033600, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37184, 'Gieleroth', 'Gieleroth', '', 50.6666700, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37185, 'Gielde', 'Gielde', '', 52.0362300, 10.4936600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37186, 'Giekau', 'Giekau', 'Giekau', 54.3166700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37187, 'Gieboldehausen', 'Gieboldehausen', 'Gibol''dekhauzen,Giboldekhauzen,Gieboldehausen,giborudehauzen,ji bo er de hao sen,Гиболдехаузен,Гибольдехаузен,ギーボルデハウゼン,吉博尔德豪森', 51.6096200, 10.2161900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37188, 'Giebelstadt', 'Giebelstadt', 'GHF,Geibelstadte,Gibel''shtadt,Gibelshtat,Gibelstadt,Giebelstadt,giberushutatto,ji bo er shi ta te,Гибелштат,Гибельштадт,Гібельштадт,Գիբելշտադտ,ギーベルシュタット,吉伯尔施塔特', 49.6530800, 9.9444100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37189, 'Geyer', 'Geyer', 'Gajer,Geiere,Geyer,gai ai er,ghayr,gyr,Гайер,Гајер,غاير,گیر,盖埃尔', 50.6263200, 12.9207400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37190, 'Geversdorf', 'Geversdorf', 'Gefersdorf,Gemeen Geversdoerp,Gemeen Geversdörp,Geversdorf,ge fei er si duo fu,Геверсдорф,Геферсдорф,格费尔斯多夫', 53.8000000, 9.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37191, 'Gevensleben', 'Gevensleben', 'Gevenleben,Gevensleben', 52.0765500, 10.8222200, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37192, 'Gevenich', 'Gevenich', '', 50.1500000, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37193, 'Gevelsberg', 'Gevelsberg', 'Gefel''sberg,Gevel''sberg,Gevelsberg,Gevelsbergum,Gievelsbiaerg,Gievelsbiärg,gai wo er si bei ge,gflsbrg,ghyflsbrgh,Гевелсберг,Гевельсберг,Гефельсберг,غيفلسبرغ,گفلسبرگ,盖沃尔斯贝格', 51.3197100, 7.3392000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37194, 'Geusa', 'Geusa', 'Geusa,Gojza,Гойза,Гојза', 51.3391400, 11.9438200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37195, 'Gettorf', 'Gettorf', 'Getorf,Gettorf,Gettorp,ge tuo er fu,Геторф,Гетторф,格托尔夫', 54.4000000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37196, 'Getelo', 'Getelo', '', 52.4666700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37197, 'Gesundbrunnen', 'Gesundbrunnen', 'Berlin-Gesundbrunnen,Gezundbrunnen,Гезундбруннен', 52.5503500, 13.3913900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37198, 'Gestratz', 'Gestratz', '', 47.6500000, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37199, 'Gessertshausen', 'Gessertshausen', 'Gesertshauzen,Gesertskhauzen,Gessertsgauzen,Gessertskhauzen,ge sai er ci hao sen,Гесертсхаузен,Гессертсгаузен,Гессертсхаузен,Գեսերտսհաուզեն,格塞尔茨豪森', 48.3290400, 10.7327800, 'DE', '2012-10-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37200, 'Geslau', 'Geslau', 'Geslau,ge si lao,gesurau,Геслау,Գեսլաու,ゲスラウ,格斯劳', 49.3664300, 10.3152800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37201, 'Geseke', 'Geseke', 'Gaiseke,Gesecke,Geseke,Gesiki,Gezeke,Gisiki,Gêsiki,Gīsiki,ge sai ke,ghysykh,gskh,Гезеке,غيسيكه,گسکه,格塞克', 51.6409100, 8.5109000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37202, 'Gesees', 'Gesees', '', 50.0320700, 11.6662300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37203, 'Gesees', 'Gesees', 'Gezes,ge sai si,gezesu,Гезес,Գեզես,ゲゼース,格塞斯', 49.9000000, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37204, 'Geschwenda', 'Geschwenda', 'Geschwenda,Geshvenda,ge shi wen da,Гешвенда,格施文达', 50.7317800, 10.8254000, 'DE', '2012-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37205, 'Gescher', 'Gescher', 'Gascheri,Gasgeri,Gescher,Gesher,Gāscheri,Gāsgeri,ge she er,ghyshr,gshr,Гешер,غيشر,گشر,格舍尔', 51.9540000, 7.0048100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37206, 'Geschendorf', 'Geschendorf', 'Geschendorf', 53.9212600, 10.4420400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37207, 'Gerzen', 'Gerzen', 'Gercen,ge er cen,grtsn,Герцен,Գերցեն,گرتسن,格尔岑', 48.5070600, 12.4268600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37208, 'Gerwisch', 'Gerwisch', 'Gerwisch', 52.1766200, 11.7397200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37209, 'Gertewitz', 'Gertewitz', 'Gertewitz', 50.6833300, 11.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37210, 'Gerterode', 'Gerterode', 'Gerterode', 51.3833300, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37211, 'Gerswalde', 'Gerswalde', 'Gersval''de,Gersvalde,ge er si wa er de,Герсвалде,Герсвальде,Գերսվալդե,格尔斯瓦尔德', 53.1698800, 13.7485300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37212, 'Gerstungen', 'Gerstungen', 'Gerstungen,ge er si tong gen,Герстунген,格尔斯通根', 50.9666700, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37213, 'Gersthofen', 'Gersthofen', 'Gerstgofen,Gersthofen,Gerstkhofen,ge er si tuo fen,ghyrsthwfn,grshthwfn,Герстгофен,Герстхофен,Գերստհոֆեն,غيرستهوفن,گرشتهوفن,格尔斯托芬', 48.4243200, 10.8727300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37214, 'Gerstetten', 'Gerstetten', 'Gershteten,Gershtetten,ge er si te teng,Герштетен,Герштеттен,格尔斯特滕', 48.6225400, 10.0198400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37215, 'Gerstenberg', 'Gerstenberg', 'Gerstenberg', 51.0307800, 12.4374600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37216, 'Gersten', 'Gersten', '', 52.5833300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37217, 'Gersheim', 'Gersheim', 'Gersgajm,Gersheim,Gerskhajm,ge er si hai mu,grshaym,Герсгайм,Герсхайм,Герсхајм,گرسهایم,格尔斯海姆', 49.1500000, 7.2000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37218, 'Gersfeld', 'Gersfeld', 'Gersfel''d,Gersfeld,ge er si fei er de,ghyrsfld,grsfld,Герсфелд,Герсфельд,غيرسفلد,گرسفلد,格尔斯费尔德', 50.4513800, 9.9142200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37219, 'Gersdorf', 'Gersdorf', '', 51.1122000, 12.9388900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37220, 'Gersdorf', 'Gersdorf', '', 50.7500000, 12.7166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37221, 'Gerolzhofen', 'Gerolzhofen', 'Gerol''cgofen,Gerol''ckhofen,Gerolckhofen,Gerolzhofen,ge luo er ci huo fen,ghyrwltshwfn,grwlzhwfn,Геролцхофен,Герольцгофен,Герольцхофен,غيرولتسهوفن,گرولزهوفن,格罗尔茨霍芬', 49.9002500, 10.3483200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37222, 'Gerolstein', 'Gerolstein', 'Gerol''shtajn,Gerolshtajn,ge luo er si tai yin,gerorushutain,ghyrwlshtayn,Геролштајн,Герольштайн,غيرولشتاين,گرول‌اشتاین,გეროლშტაინი,ゲロルシュタイン,格罗尔斯泰因', 50.2222400, 6.6598400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37223, 'Gerolsheim', 'Gerolsheim', '', 49.5477800, 8.2638900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37224, 'Gerolsbach', 'Gerolsbach', '', 48.4928300, 11.3614900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37225, 'Gerolfingen', 'Gerolfingen', 'Gerol''fingen,Gerolfingen,ge luo er fen gen,gerorufingen,Геролфинген,Герольфинген,Герольфінген,Գերոլֆինգեն,ゲーロルフィンゲン,格罗尔芬根', 49.0534000, 10.5115100, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37226, 'Geroldshausen', 'Geroldshausen', 'Gerol''dsgauzen,Gerol''dskhauzen,Geroldshauzen,Geroldskhauzen,ge luo er ci hao sen,gerorutsuhauzen,Геролдсхаузен,Герольдсгаузен,Герольдсхаузен,Գերոլդսհաուզեն,ゲーロルツハウゼン,格罗尔茨豪森', 49.6836100, 9.9022200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37227, 'Geroldsgrün', 'Geroldsgrun', 'Gerol''dsgrjun,Geroldsgrin,Geroldsgruen,Geroldsgrün,ge luo er ci ge lin,gerorutsuguryun,grwldsgrwn,Геролдсгрин,Герольдсгрюн,گرولدسگرون,ゲロルツグリュン,格罗尔茨格林', 50.3333300, 11.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37228, 'Geroda', 'Geroda', '', 50.7666700, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37229, 'Gernsheim', 'Gernsheim', 'Gernsgajm,Gernsheim,Gernskhajm,gai en si hai mu,gerunsuhaimu,ghyrnshaym,grnzhaym,Гернсгайм,Гернсхайм,Гернсхајм,غيرنسهايم,گرنزهایم,ゲルンスハイム,盖恩斯海姆', 49.7530500, 8.4885900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37230, 'Gernsbach', 'Gernsbach', 'Gernsbach,Gernsbakh,ge en si ba he,ghyrnsbakh,grnzbakh,Гернсбах,غيرنسباخ,گرنزباخ,格恩斯巴赫', 48.7703400, 8.3430600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37231, 'Gernrode', 'Gernrode', 'Bad Gernrode,Gernrode,Gernrode am Harz,ge er en luo de,Гернроде,格尔恩罗德', 51.7257500, 11.1387600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37232, 'Gernrode', 'Gernrode', '', 51.4000000, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37233, 'Germersheim', 'Germersheim', 'Gemersheim,Germersche,Germersheim,Germerskhajm,ge er mei si hai mu,gerumasuhaimu,ghyrmrshaym,grmrzhaym,Гермерсхайм,Гермерсхајм,غيرمرسهايم,گرمرزهایم,ゲルマースハイム,格尔梅斯海姆', 49.2230600, 8.3638900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37234, 'Germering', 'Germering', 'Geamaring,Germering,Germeringas,ge er mei lin ge,grmryng,Гермеринг,گرمرینگ,格尔梅林格', 48.1339200, 11.3765000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37235, 'Gerlingen', 'Gerlingen', 'Gerlingen,ge er lin gen,ghyrlynghn,grlyngn,kerlinken,Герлинген,Герлінген,غيرلينغن,گرلینگن,கெர்லிங்கென்,格尔林根', 48.7995400, 9.0631600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37236, 'Geringswalde', 'Geringswalde', 'Geringsval''de,Geringsvalde,Geringswalde,Gēringsvalde,gai ling si wa er de,ghyrynghsfaldh,gryngswaldh,Герингсвалде,Герингсвальде,غيرينغسفالده,گرینگسوالده,盖灵斯瓦尔德', 51.0767700, 12.9072500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37237, 'Gering', 'Gering', '', 50.2833300, 7.2666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37238, 'Gerhardshofen', 'Gerhardshofen', 'Gergardsgofen,Gerhardshofen,Gerkhardskhofen,ge la er ci huo fen,Гергардсгофен,Герхардсхофен,Գերհարդսհոֆեն,格拉尔茨霍芬', 49.6312300, 10.6913300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37239, 'Gerhardsbrunn', 'Gerhardsbrunn', '', 49.3500000, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37240, 'Geretsried', 'Geretsried', 'Geretsrid,ge lei ci li de,ghyrytsryd,grtzryd,Геретсрид,Геретсрід,Գերետսրիդ,غيريتسريد,گرتزرید,格雷茨里德', 47.8577500, 11.4805400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37241, 'Gerdshagen', 'Gerdshagen', '', 53.2445700, 12.1981100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37242, 'Gerdau', 'Gerdau', '', 52.9666700, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37243, 'Gerbstedt', 'Gerbstedt', 'Gerbshtedt,Gerbshtet,Gerbstedt,ge er bu si te,ghyrbshtyt,Гербштедт,Гербштет,غيربشتيت,گرب‌اشتت,格尔布斯特', 51.6328100, 11.6266900, 'DE', '2014-12-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37244, 'Gerbrunn', 'Gerbrunn', 'Gerbrun,Gerbrunn,ge er bu lun,geruburun,Гербрун,Гербрунн,Գերբրուն,ゲルブルン,格尔布伦', 49.7752800, 9.9936100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37245, 'Gerbershausen', 'Gerbershausen', 'Gerbershausen', 51.3333300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37246, 'Gerbach', 'Gerbach', '', 49.6666700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37247, 'Geratskirchen', 'Geratskirchen', '', 48.3386000, 12.6623100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37248, 'Gerach', 'Gerach', '', 50.0333300, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37249, 'Gerach', 'Gerach', '', 49.7500000, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37250, 'Gerabronn', 'Gerabronn', '', 48.9707100, 9.9198600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37251, 'Geraberg', 'Geraberg', 'Geraberg,ge la bei ge,Гераберг,格拉贝格', 50.7159400, 10.8373700, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37252, 'Gera', 'Gera', 'Gera,Gerapolis,Gorad Gera,Gėra,ZGA,ge la,gela,gera,gra,gyra,Гера,Горад Гера,گرا,گیرا,ゲーラ,格拉,게라', 50.8802900, 12.0818700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37253, 'Georgsmarienhütte', 'Georgsmarienhuette', 'Georgsmarienhuette,Georgsmarienhutte,Georgsmarienhütte,Georgsmarienkhjutte,Georgsmarinkhite,ge ao er ge si ma lin xu te,ghywrghsmarynhwth,gywrgsmarynhwth,Георгсмариенхютте,Георгсмаринхите,גיאורגסמריינהוטה,غيورغسمارينهوته,گئورگسمارینهوته,格奥尔格斯马林许特', 52.2029600, 8.0448000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37254, 'Georgsdorf', 'Georgsdorf', '', 52.5666700, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37255, 'Georgenthal', 'Georgenthal', 'Georgental,Georgental'',Georgenthal,Georgenthal/Thueringer Wald,Georgenthal/Thüringer Wald,ge ao er gen ta er,Георгентал,Георгенталь,格奥尔根塔尔', 50.8320500, 10.6626600, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37256, 'Georgensgmünd', 'Georgensgmund', 'Georgensgmind,Georgensgmjund,Georgensgmuend,Georgensgmund,Georgensgmünd,ge ao er gen si ge ming de,georugensugumyunto,Георгенсгминд,Георгенсгмюнд,ゲオルゲンスグミュント,格奥尔根斯格明德', 49.1897200, 11.0166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37257, 'Georgenberg', 'Georgenberg', '', 49.7029700, 12.4208200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37258, 'Gentingen', 'Gentingen', '', 49.9000000, 6.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37259, 'Genthin', 'Genthin', 'Genthin,Gentin,gen ting,gentin,ghyntyn,gntyn,Гентин,Гентін,غينتين,گنتین,ゲンティン,根廷', 52.4066800, 12.1592000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37260, 'Gensingen', 'Gensingen', '', 49.9000000, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37261, 'Gengenbach', 'Gengenbach', 'Gengenbach,Gengenbakh,gen gen ba he,ghynghnbakh,gngnbakh,Генгенбах,غينغنباخ,گنگنباخ,根根巴赫', 48.4047600, 8.0143300, 'DE', '2016-07-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37262, 'Genderkingen', 'Genderkingen', '', 48.7000000, 10.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37263, 'Gemünden an der Wohra', 'Gemuenden an der Wohra', 'Gemuenden (Wohra),Gemunden,Gemunden an der Wohra,Gemünden,Gemünden (Wohra),Gemünden an der Wohra', 50.9740100, 8.9694600, 'DE', '2017-07-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37264, 'Gemünden', 'Gemuenden', '', 50.5587700, 8.0164900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37265, 'Gemünden am Main', 'Gemuenden am Main', 'Geminden na Majni,Gemjunden-am-Majn,Gemjunden-na-Majne,Gemuenden am Main,Gemünden am Main,Mayni Gemyunden,ghymwndn am mayn,gmwndn am mayn,mei yin he pan ge ming deng,Геминден на Мајни,Гемюнден-ам-Майн,Гемюнден-на-Майне,Մայնի Գեմյունդեն,غيموندن آم ماين,گموندن آم ماین,美因河畔格明登', 50.0494600, 9.7059300, 'DE', '2015-10-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37266, 'Gemünden', 'Gemunden', 'Geminden,Gemjunden,Геминден,Гемюнден', 49.8944400, 7.4775000, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37267, 'Gemünd', 'Gemund', '', 49.9833300, 6.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37268, 'Gemmrigheim', 'Gemmrigheim', 'Gemmrigajm,Gemmrigkhajm,Gemrigkhajm,ge mu li ge hai mu,gmryghaym,Геммригхайм,Геммрігайм,Гемригхајм,گمریگهایم,格姆里格海姆', 49.0283300, 9.1555600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37269, 'Gemmingen', 'Gemmingen', 'Gemingen,Gemmingen,ge ming gen,genmingen,Геминген,Гемминген,Геммінген,ゲンミンゲン,格明根', 49.1563900, 8.9819400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37270, 'Gemmerich', 'Gemmerich', '', 50.2278800, 7.7585800, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37271, 'Geltorf', 'Geltorf', 'Geltorf', 54.4666700, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37272, 'Gelting', 'Gelting', 'Gel''ting,Gelting,ge er ting ge,Гелтинг,Гельтинг,格尔廷格', 54.7500000, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37273, 'Geltendorf', 'Geltendorf', 'Gel''tendorf,Geltendorf,ge er teng duo fu,gerutendorufu,gltndwrf,Гелтендорф,Гельтендорф,Գելթենդորֆ,گلتندورف,ゲルテンドルフ,格尔滕多夫', 48.1173700, 11.0321600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37274, 'Gelsenkirchen', 'Gelsenkirchen', 'Gel''zenkirkhen,Gelsenkiaerken,Gelsenkirchen,Gelsenkiärken,Gelzenkirchenas,Gelzenkirhene,Gelzenkirheni,Gelzenkirkhen,Gorad Gel''zenkirkhen,Helzenkirxen,Nkelzen''kirchen,ZEJ,gai er sen ji xing,geljenkileuhen,gelsanakarsana,geruzenkiruhyen,ghylsnkyrshn,glsnkrchn,glznkyrshn,glznqyrkn,kel sen kheiyr khein,Γκελζενκίρχεν,Гелзенкирхен,Гельзенкирхен,Гельзенкірхен,Горад Гельзенкірхен,גלזנקירכן,غيلسنكيرشن,گلزنکیرشن,گلسنکرچن,गेल्सनकर्शन,เกลเซนเคียร์เคิน,გელზენკირხენი,ゲルゼンキルヒェン,盖尔森基兴,겔젠키르헨', 51.5050800, 7.0965400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37275, 'Gelnhausen', 'Gelnhausen', 'Gel''ngauzen,Gel''nkhauzen,Gelnhausen,Gelnhauzenas,Gelnhauzene,Gelnkhauzen,Gorad Gel''nkhauzen,ge er en hao sen,gerunhauzen,ghylnhawzn,Гелнхаузен,Гельнгаузен,Гельнхаузен,Горад Гельнхаўзен,غيلنهاوزن,گلن‌هاوزن,ゲルンハウゼン,格尔恩豪森', 50.2016400, 9.1874200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37276, 'Gelenberg', 'Gelenberg', '', 50.3000000, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37277, 'Gelenau', 'Gelenau', 'Gelenau,Gelenau/Erzgebirge', 50.7115100, 12.9666600, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37278, 'Geldersheim', 'Geldersheim', 'Gel''dersgajm,Gel''derskhajm,Geldersheim,Gelderskhajm,Geltersheim,ge er de er si hai mu,gldrshaym,Гелдерсхајм,Гельдерсгайм,Гельдерсхайм,گلدرسهایم,格尔德尔斯海姆', 50.0428600, 10.1560900, 'DE', '2012-09-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37279, 'Geldern', 'Geldern', 'Gel''dern,Geldere,Geldern,Gheldria,Gorad Gel''dehrn,ge er de er en,ghyldrn,gldrn,Гелдерн,Гельдерн,Горад Гельдэрн,غيلدرن,گلدرن,格尔德尔恩', 51.5190800, 6.3236300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37280, 'Gelbensande', 'Gelbensande', 'Gel''benzande,Gelbenzande,ge er ben sang de,Гелбензанде,Гельбензанде,格尔本桑德', 54.2027200, 12.3016800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37281, 'Geithain', 'Geithain', 'Chitan,Chitań,Gajtkhajn,Geithain,Geithaina,gai tai yin,gaythayn,ghaythayn,Гайтхайн,Гајтхајн,غايتهاين,گایتهاین,盖泰因', 51.0552800, 12.6967400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37282, 'Geismar', 'Geismar', 'Gajsmar,gai si ma er,Гайсмар,Гајсмар,盖斯马尔', 51.2316900, 10.1654800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37283, 'Geislingen an der Steige', 'Geislingen an der Steige', 'Gajslingen an der Shtajge,Gajslingen-an-der-Shtajge,Geislingen,Stadt Geislingen an der Steige,gayzlyngn an dr ashtaygh,ghayzlynghn an dr ashtayghh,po dao pang gai si lin gen,Гайслинген-ан-дер-Штайге,Гайслінген-ан-дер-Штайге,Гајслинген ан дер Штајге,غايزلينغن آن در اشتايغه,گایزلینگن آن در اشتایگه,坡道旁盖斯林根', 48.6242300, 9.8273600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37284, 'Geislingen', 'Geislingen', '', 48.2876800, 8.8124100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37285, 'Geisleden', 'Geisleden', 'Geisleden,Geissleden,Geißleden', 51.3500000, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37286, 'Geisingen', 'Geisingen', 'Gajzingen,Geisingen,gai xin gen,gazyngn,ghayzynghn,Гайзинген,Гајзинген,غايزينغن,گازینگن,盖辛根', 47.9250400, 8.6500200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37287, 'Geising', 'Geising', 'Gajzing,Гайзинг,Гајзинг', 50.7574200, 13.7927800, 'DE', '2015-08-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37288, 'Geisig', 'Geisig', '', 50.2536800, 7.7906400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37289, 'Geisfeld', 'Geisfeld', '', 49.7166700, 6.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37290, 'Geisenheim', 'Geisenheim', 'Gajzengajm,Gajzenkhajm,Geisenheim,Gorad Gajzenkhajm,gai sen hai mu,gayznhaym,Гайзенгайм,Гайзенхайм,Гајзенхајм,Горад Гайзенхайм,گایزنهایم,盖森海姆', 49.9847000, 7.9683500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37291, 'Geisenhausen', 'Geisenhausen', 'Gajzengauzen,Gajzenkhauzen,Gayzenhauzen,Geisenhausen,Geisenhausn,gai sen hao sen,gayznhawzn,Гайзенгаузен,Гайзенхаузен,Гајзенхаузен,Գայզենհաուզեն,گایزنهاوزن,盖森豪森', 48.4760900, 12.2581700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37292, 'Geisenhain', 'Geisenhain', 'Geisenhain', 50.8333300, 11.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37293, 'Geisenfeld', 'Geisenfeld', 'Gajzenfel''d,Gajzenfeld,Gayzenfeld,Geisenfeld,gai sen fei er de,gayznfld,ghayznfld,Гайзенфельд,Гајзенфелд,Գայզենֆելդ,غايزنفلد,گایزنفلد,盖森费尔德', 48.6842600, 11.6123300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37294, 'Geiselwind', 'Geiselwind', 'Gajzel''vind,Gajzelvind,Gayzelvind,Geiselwind,gai sai er wen de,Гайзельвинд,Гајзелвинд,Ґайзельвінд,Գայզելվինդ,盖塞尔温德', 49.7735600, 10.4706300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37295, 'Geiselhöring', 'Geiselhoring', 'Gajzel''gering,Gajzel''khjoring,Gajzelkhering,Geiselhoering,Geiselhoring,Geiselhöring,Geisselhoving,gai se er he ling,gayzlhwryng,ghayzlhwryngh,Гайзельгерінг,Гайзельхёринг,Гајзелхеринг,غايزلهورينغ,گایزلهورینگ,盖瑟尔赫灵', 48.8250500, 12.3964900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37296, 'Geiselberg', 'Geiselberg', '', 49.3260700, 7.6970800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37297, 'Geiselbach', 'Geiselbach', 'Gajzel''bakh,Gajzelbakh,Gayzelbax,gai sai er ba,gaizerubahha,Гайзельбах,Гајзелбах,Գայզելբախ,ガイゼルバッハ,盖塞尔巴', 50.1232900, 9.1966400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37298, 'Geisa', 'Geisa', 'Gajza,Geisa,gai sa,gayza,ghayza,Гайза,Гајза,غايزا,گایزا,蓋薩', 50.7146500, 9.9507500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37299, 'Geilnau', 'Geilnau', '', 50.3500000, 7.9333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37300, 'Geilenkirchen', 'Geilenkirchen', 'GKE,Gajlenkirkhen,Geilenkirchen,Gejlenkirkhen,Jellekerke,gai lun ji xing,ghaylnkyrshn,Гайленкирхен,Гайленкірхен,Гајленкирхен,Гейленкирхен,غايلنكيرشن,گایلن‌کیرشن,盖伦基兴', 50.9674500, 6.1176300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37301, 'Geiersthal', 'Geiersthal', 'Gaerstal'',Gajerstal,Gajerstal'',gai ai er si ta er,gayrstal,Гайерсталь,Гаєрсталь,Гајерстал,Գայերսթալ,گایرستال,盖埃尔斯塔尔', 49.0456900, 12.9817100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37302, 'Geichlingen', 'Geichlingen', '', 49.9500000, 6.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37303, 'Gehrweiler', 'Gehrweiler', '', 49.5833300, 7.7666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37304, 'Gehren', 'Gehren', 'Gehren,Geren,ge lun,ghyrn,grn,Герен,غيرن,گرن,格伦', 50.6485200, 11.0047100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37305, 'Gehrden', 'Gehrden', 'Gehrden bei Hannover,Gerden,ge er deng,ghyrdn,grdn,Герден,غيردن,گردن,格尔登', 52.3136200, 9.6003300, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37306, 'Gehrde', 'Gehrde', 'Gerde,ge er de,Герде,格尔德', 52.5768400, 8.0034200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37307, 'Gehofen', 'Gehofen', 'Gehofen', 51.3226900, 11.3200200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37308, 'Gehlweiler', 'Gehlweiler', '', 49.8833300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37309, 'Gehlert', 'Gehlert', '', 50.6416700, 7.8294400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37310, 'Gehlberg', 'Gehlberg', 'Gehlberg,Gel''berg,Gelberg,ge er bei ge,Гелберг,Гельберг,格尔贝格', 50.6781500, 10.7909200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37311, 'Gefrees', 'Gefrees', 'Gefrees,Gefres,ge fu lei si,gefuresu,gfrs,gfrys,ghyfrys,Гефрес,Գեֆրես,غيفريس,گفرس,گفریس,ゲフレース,格夫雷斯', 50.0953800, 11.7377200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37312, 'Gefell', 'Gefell', '', 50.2333300, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37313, 'Geesthacht', 'Geesthacht', 'Geesthacht,Gestakht,Gestkhakht,Stadt Geesthacht,ge si ta te,ghyztakht,gyztakht,Гестахт,Гестхахт,غيزتاخت,گیزتاخت,格斯塔特,', 53.4357500, 10.3779000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37314, 'Geeste', 'Geeste', '', 52.6000000, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37315, 'Gedern', 'Gedern', 'Gedern,gdrn,ge deng,gederun,ghydrn,Гедерн,غيدرن,گدرن,ゲーデルン,格登', 50.4248200, 9.1984000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37316, 'Gechingen', 'Gechingen', '', 48.6952700, 8.8291500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37317, 'Gebsattel', 'Gebsattel', 'Gebzatel,Gebzattel'',ge bu sa te er,gepuzatteru,Гебзател,Гебзаттель,Գեբզատել,ゲープザッテル,格布萨特尔', 49.3500000, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37318, 'Gebroth', 'Gebroth', '', 49.8833300, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37319, 'Gebhardshain', 'Gebhardshain', 'Gebkhardskhajn,gbhardshayn,ge bu ha er ci hai en,gebuharutsuhain,Гебхардсхайн,Гебхардсхајн,گبهاردسهاین,ゲブハルツハイン,格布哈尔茨海恩', 50.7500000, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37320, 'Gebesee', 'Gebesee', 'Gebesee,Gebeze,Gebezee,gbzy,ge bei sai,ghybhzyh,Гебезе,Гебезее,غيبهزيه,گبزی,格贝塞', 51.1148800, 10.9345500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37321, 'Gebenbach', 'Gebenbach', 'Gebenbakh,Gebenbax,ge ben ba he,Гебенбах,Գեբենբախ,格本巴赫', 49.5376200, 11.8720400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37322, 'Gau-Weinheim', 'Gau-Weinheim', '', 49.8463900, 8.0477800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37323, 'Gauting', 'Gauting', '', 48.0691900, 11.3770300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37324, 'Gaushorn', 'Gaushorn', 'Gaushorn', 54.2000000, 9.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37325, 'Gau-Odernheim', 'Gau-Odernheim', 'Gau-Odernheim,Gau-Odernkhajm,gao-ao de en hai mu,Гау-Одернхайм,Гау-Одернхајм,高-奥德恩海姆', 49.7847200, 8.1941700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37326, 'Gaukönigshofen', 'Gaukonigshofen', 'Gaukenigsgofen,Gaukenigskhofen,Gaukjonigskhofen,Gaukoenigshofen,Gaukönigshofen,gao ke ni ge si huo fen,gaukenihisuhofen,Гаукенигсхофен,Гаукенігсгофен,Гаукёнигсхофен,Գաուքյոնիգսհոֆեն,ガウケーニヒスホーフェン,高克尼格斯霍芬', 49.6333300, 10.0000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37327, 'Gau-Heppenheim', 'Gau-Heppenheim', '', 49.7422200, 8.1733300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37328, 'Gaugrehweiler', 'Gaugrehweiler', '', 49.7000000, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37329, 'Gauersheim', 'Gauersheim', '', 49.6597200, 8.0719400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37330, 'Gauern', 'Gauern', 'Gauern', 50.7833300, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37331, 'Gau-Bischofsheim', 'Gau-Bischofsheim', '', 49.9158300, 8.2727800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37332, 'Gau-Bickelheim', 'Gau-Bickelheim', '', 49.8352800, 8.0205600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37333, 'Gau-Algesheim', 'Gau-Algesheim', 'Gau-Al''geskhajm,Gau-Algeskhajm,gao-a er ge si hai mu,gau=arugesuhaimu,gaw-algshaym,ghaw-alghshaym,Гау-Алгесхајм,Гау-Альгесхайм,غاو-آلغسهايم,گاو-آلگسهایم,ガウ＝アルゲスハイム,高-阿尔格斯海姆', 49.9566900, 8.0156900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37334, 'Gatow', 'Gatow', 'Berlin-Gatow', 52.4832400, 13.1828500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37335, 'Gatersleben', 'Gatersleben', 'Gatersleben,Гатерслебен', 51.8221500, 11.2866100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37336, 'Garz', 'Garz', 'Garz,Garz/Ruegen,Garz/Rügen', 54.3184300, 13.3512500, 'DE', '2017-07-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37337, 'Gartz', 'Gartz', 'Garc,Gardziec,Gartz an der Oder,garts,gharts,jia er ci,Гарц,Գարց,غارتس,گارتس,加尔茨', 53.2082900, 14.3922600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37338, 'Gärtringen', 'Gartringen', 'Gaertringen,Gertringen,Gärtringen,ge er te lin gen,Гертринген,Гертрінген,Գերտրինգեն,გერტრინგენი,格尔特林根', 48.6417600, 8.9007300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37339, 'Gartow', 'Gartow', 'Gartov,gartw,jia er tuo,Гартов,گارتو,加尔托', 53.0247000, 11.4620000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37340, 'Garstedt', 'Garstedt', '', 53.2846700, 10.1613700, 'DE', '2011-09-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37341, 'Gars', 'Gars', 'Gars', 48.1538600, 12.2776700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37342, 'Garrel', 'Garrel', 'Garel,Garrel'',jia lei er,Гарел,Гаррель,加雷尔', 52.9500000, 8.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37343, 'Garmisch-Partenkirchen', 'Garmisch-Partenkirchen', 'Garmasch-Partakurch,Garmisa-Partenkirhene,Garmisas-Partenkirchenas,Garmisch-Partenkirchen,Garmish-Partehnkirkhen,Garmish-Partenkirkhen,Garmiša-Partenkirhene,Garmišas-Partenkirchenas,Markt Garmisch-Partenkirchen,Nkarmis-Parten''kirchen,Qarmis-Partenkirhen,Qarmiş-Partenkirhen,ZEI,galeumisyupaleutenkileuhen,garmysh-partnkyrshn,garumisshu=parutenkiruhyen,gharmysh-bartnkyrshn,grmys-prtnqyrkn,jia er mi shi-pa teng ji xing,Γκάρμις-Παρτενκίρχεν,Гармиш-Партенкирхен,Гарміш-Партенкірхен,Гарміш-Партэнкірхен,גרמיש-פרטנקירכן,غارميش-بارتنكيرشن,گارمیش-پارتنکیرشن,ガルミッシュ＝パルテンキルヒェン,加爾米施-帕滕基興,가르미슈파르텐키르헨', 47.4920900, 11.0957600, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37344, 'Garlstorf', 'Garlstorf', '', 53.2372800, 10.1013700, 'DE', '2011-09-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37345, 'Garding', 'Garding', 'Garding,gardyng,ghardyngh,jia er ding,Гардинг,غاردينغ,گاردینگ,加尔丁', 54.3305600, 8.7805600, 'DE', '2011-08-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37346, 'Gardelegen', 'Gardelegen', 'Gardelegen,Gardelengen,Garlae,Garlä,ghardhlyghn,jia er de lai gen,Гарделеген,غاردهليغن,گراده‌لگن,加尔德莱根', 52.5252000, 11.3952300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37347, 'Garching bei München', 'Garching bei Munchen', 'Arching,Garching,Garching bei Minga,Garching bei Munchen,Garching bei München,Garkhing,Garkhing kod Minkhena,Garkhing-baj-Mjunkhen,Garxing,garshyng bay mwnykh,gharshyngh bay mwnshn,jia xing,Гархинг,Гархинг код Минхена,Гархінг-бай-Мюнхен,Գարխինգ,غارشينغ باي مونشن,گارشینگ بای مونیخ,ガーヒンク・バイ・ミュンヘン,加兴', 48.2489600, 11.6510100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37348, 'Garching an der Alz', 'Garching an der Alz', 'Garching,Garching an da Alz,Garching an der Alz,Garkhing an der Alc,Garkhing-an-der-Al''c,Garkhing-na-Al''ce,garshyng an dr alts,Гархинг ан дер Алц,Гархинг-на-Альце,Гархінг-ан-дер-Альц,Ալցի Գարխինգ,گارشینگ ان در آلتس', 48.1345100, 12.5815200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37349, 'Garbsen', 'Garbsen', 'Altgarbsen,Garbsen,Garbzen,Gerbernessen [a. 1286],Olengarbsen,ZEH,garbzn,jia bu sen,Гарбзен,Гарбсен,گاربزن,加布森', 52.4137100, 9.5899000, 'DE', '2014-07-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37350, 'Gappenach', 'Gappenach', '', 50.2729900, 7.3450500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37351, 'Gangloffsömmern', 'Gangloffsoemmern', '', 51.1894000, 10.9433200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37352, 'Gangkofen', 'Gangkofen', 'Ganghofen,Gangkofen,Gangofen,Gankfoken,Gankofen,gang ke fen,gangkwfn,Гангофен,Ганкофен,Գանգոֆեն,گانگکوفن,冈科芬', 48.4370100, 12.5641900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37353, 'Gangelt', 'Gangelt', 'Gangel''t,Gangelt,gan ge er te,janjlt,Гангелт,Гангельт,جانجلت,甘格尔特', 50.9924700, 5.9980200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37354, 'Gandesbergen', 'Gandesbergen', '', 52.7600100, 9.2256400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37355, 'Ganderkesee', 'Ganderkesee', 'Ganderkesee,Ganderkeze,gan de er ke sai,Гандеркезе,甘德尔克塞', 53.0333300, 8.5333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37356, 'Gammertingen', 'Gammertingen', 'Gamertingen,Gammertingen,gamrtyngn,ghamrtynghn,jia mei er ting gen,Гамертинген,Гаммертинген,Гаммертінген,غامرتينغن,گامرتینگن,加梅尔廷根', 48.2524000, 9.2234900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37357, 'Gammelshausen', 'Gammelshausen', 'Gamelskhauzen,Gammel''sgauzen,Gammel''skhauzen,jia mei er si hao sen,Гамелсхаузен,Гаммельсгаузен,Гаммельсхаузен,加梅尔斯豪森', 48.6402300, 9.6507200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37358, 'Gammelsdorf', 'Gammelsdorf', 'Gamelsdorf,Gammel''sdorf,Gammelsdorf,gamlsdwrf,jia mei er si duo fu,Гамелсдорф,Гаммельсдорф,Գամելսդորֆ,گاملسدورف,加梅尔斯多夫', 48.5500000, 11.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37359, 'Gammelby', 'Gammelby', '', 54.5000000, 9.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37360, 'Gamlen', 'Gamlen', '', 50.2333300, 7.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37361, 'Gallmersgarten', 'Gallmersgarten', 'Gal''mersgarten,Gall''mersgarten,Galmersgarten,jia er mei er si jia er teng,Галльмерсгартен,Галмерсгартен,Гальмерсгартен,Գալմերսգարթեն,加尔梅尔斯加尔滕', 49.4500000, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37362, 'Galenberg', 'Galenberg', '', 50.4333300, 7.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37363, 'Gaißach', 'Gaissach', 'Gaissach,Gaißach,Gajsakh,Gaysax,gai sa,gaysakh,Гайсах,Гајсах,Գայսախ,گایساخ,盖萨', 47.7500000, 11.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37364, 'Gaimersheim', 'Gaimersheim', 'Gajmersgajm,Gajmerskhajm,Gaymershaym,Goamascham,gai mei er si hai mu,gaymrshaym,Гаймерсгайм,Гаймерсхайм,Гајмерсхајм,Գայմերսհայմ,گایمرسهایم,盖梅尔斯海姆', 48.8070500, 11.3680100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37365, 'Gailingen', 'Gailingen', '', 47.6971100, 8.7556700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37366, 'Gaildorf', 'Gaildorf', 'Gajl''dorf,Gajldorf,gai er duo fu,gairudorufu,gayldwrf,ghayldwrf,Гайльдорф,Гајлдорф,غايلدورف,گایلدورف,ガイルドルフ,盖尔多夫', 49.0002700, 9.7695300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37367, 'Gaienhofen', 'Gaienhofen', 'Gaingofen,Gajenkhofen,Gajnkhofen,gai en huo fen,Гайенхофен,Гайнхофен,Гаїнгофен,Гајнхофен,盖恩霍芬', 47.6833300, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37368, 'Gaiberg', 'Gaiberg', 'Gajberg,gai bei ge,gaiberuku,Гайберг,Гајберг,ガイベルク,盖贝格', 49.3663900, 8.7497200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37369, 'Gaggenau', 'Gaggenau', 'Gagenau,Gaggenau,gagnaw,ghaghnaw,jia ge nao,Гаггенау,Гагенау,غاغناو,گاگناو,加格瑙', 48.8000000, 8.3333300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37370, 'Gägelow', 'Gaegelow', '', 53.6855800, 11.8963900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37371, 'Gädheim', 'Gadheim', 'Gaedheim,Gedgajm,Gedhaym,Gedkhajm,Gädheim,ge de hai mu,Гедгайм,Гедхайм,Гедхајм,Գեդհայմ,格德海姆', 50.0333300, 10.3500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37372, 'Gadheim', 'Gadheim', '', 49.8458400, 9.9056600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37373, 'Gadebusch', 'Gadebusch', 'Gadebusa,Gadebusch,Gadebush,Gādebuša,gadbwsh,ghadhbwsh,jia de bu shi,Гадебуш,غادهبوش,گادبوش,加德布施', 53.7013700, 11.1167600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37374, 'Gackenbach', 'Gackenbach', '', 50.3666700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37375, 'Gachenbach', 'Gachenbach', 'Gakhenbakh,Gaxenbax,gakhnbakh,jia heng ba he,Гахенбах,Գախենբախ,گاخنباخ,加亨巴赫', 48.5000000, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37376, 'Gabsheim', 'Gabsheim', 'Gabskhajm,jia bu si hai mu,Габсхайм,Габсхајм,加布斯海姆', 49.8277800, 8.1761100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37377, 'Gablingen', 'Gablingen', 'Gablingen,jia bu lin gen,Габлинген,Габлінген,Գաբլինգեն,加布林根', 48.4500000, 10.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37378, 'Gablenz', 'Gablenz', 'Gablenz,Jabtonc,Jabtońc', 51.5333300, 14.6666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37379, 'Bad Füssing', 'Bad Fussing', 'Bad Fising,Bad Fuessing,Bad Fussing,Bad Fyusing,Bad Füssing,Bad-Fjussing,Fussing,Füssing,ba te fei xing,bad fwsyng,Бад Фисинг,Бад-Фюссинг,Бад-Фюссінг,Բադ Ֆյուսինգ,باد فوسینگ,巴特菲兴', 48.3510000, 13.3120000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37380, 'Fußgönheim', 'Fussgonheim', 'Fusgenkhajm,Fusgjonkhajm,Fussgennem,Fussgoenheim,Fußgennem,Fußgönheim,fu si gen hai mu,Фусгенхајм,Фусгёнхайм,Фусгөнхайм,富斯根海姆', 49.4611100, 8.2922200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37381, 'Füssen', 'Fuessen', 'Abdiacum,Fiassa,Fisen,Fiusenas,Fjusen,Fjussen,Fuessen,Fysen,Fyusen,Füssen,fei sen,fsn,fus sein,fu~yussen,fwsn,Φύσεν,Фисен,Фюсен,Фюссен,Ֆյուսեն,فسن,فوسن,ฟึสเซิน,フュッセン,菲森', 47.5714300, 10.7017100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37382, 'Furtwangen im Schwarzwald', 'Furtwangen im Schwarzwald', 'Furtvangen,Furtvangen im Shvarcvald,Furtvangen-im-Shvarcval''d,Furtwangen,Furtwangen im Schwarzwald,fu te wang gen,furutovu~angen,Фуртванген,Фуртванген им Шварцвалд,Фуртванген-ім-Шварцвальд,فورت‌وانغن,فورت‌وانگن,フルトヴァンゲン,富特旺根', 48.0515600, 8.2071500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37383, 'Furth im Wald', 'Furth im Wald', 'Brod nad Lesy,Furt,Furt im Vald,Furt-im-Val''d,Furth,Furth im Wald,fwrt am fald,fwrt aym wald,lin qu fu er te,Фурт им Валд,Фурт-им-Вальд,Фурт-ім-Вальд,Վալդի Ֆուրթ,فورت إم فالد,فورت ایم والد,林区富尔特', 49.3095500, 12.8415600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37384, 'Fürthen', 'Furthen', 'Fuerthen,Fürthen', 50.7833300, 7.6666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37385, 'Fürth', 'Furth', 'Fuerth,Fürth', 49.6508300, 8.7847200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37386, 'Fürth', 'Furth', 'Firt,Fiurtas,Fjurt,Fuerth,Fürth,Gorad Fjurt,fei er te,fu~yuruto,fwrt,pwileuteu,Горад Фюрт,Фирт,Фюрт,פיורדא,فرتھ,فورت,ფიურტი,フュルト,菲尔特,퓌르트', 49.4759300, 10.9885600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37387, 'Furth', 'Furth', '', 48.5909500, 12.0205700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37388, 'Furth', 'Furth', '', 48.4061600, 12.3812100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37389, 'Fürstenzell', 'Furstenzell', 'Fiaschtnzei,Firstencel,Fjurstencel'',Fjurstencell'',Fuerstenzell,Furstenzell,Fürstenzell,fei er si teng ce er,fwrstnzl,Фирстенцел,Фюрстенцелль,Фюрстенцель,Ֆյուրսթենցել,فورستنزل,菲尔斯滕策尔', 48.5216300, 13.3174900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37390, 'Fürstenwalde', 'Fuerstenwalde', 'Firstenvalde,Fjurstenval''de,Fuerstenwalde,Fuerstenwalde/Spree,Furstenwalde,Fürstenwalde,Fürstenwalde/Spree,fei er si teng wa er de,fwrstnwaldh,Фирстенвалде,Фюрстенвальде,فورستنوالده,菲尔斯滕瓦尔德', 52.3606700, 14.0618500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37391, 'Fürstenstein', 'Furstenstein', 'Firstenshtajn,Fjurstenshtajn,Fuerstenstein,Fürstenstein,fei er si teng si tai yin,fwrstnshtayn,Фирстенштајн,Фюрстенштайн,Ֆյուրսթենշթայն,فورستنشتاین,菲尔斯滕斯泰因', 48.7166700, 13.3333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37392, 'Fürstenhausen', 'Fuerstenhausen', '', 49.2407500, 6.8681700, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37393, 'Fürstenfeldbruck', 'Fuerstenfeldbruck', 'Bruck,FEL,Firstenfeldbruk,Fiurstenfeldbrukas,Fjurstenfel''dbruk,Fjurstenfeldbruk,Fuerstenfeldbruck,Fuerstenfeldburg,Furstenfeld,Fürstenfeldbruck,Gorad Fjul''stehnfel''dbruk,fei er si teng fei er de bu lu ke,fjurstenfel''dbruk,fwrstnfldbrwk,Горад Фюльстэнфельдбрук,Фирстенфелдбрук,Фюрстенфелдбрук,Фюрстенфельдбрук,Ֆյուրսթենֆելդբրուք,فرسٹنفلڈبرک,فورستنفلدبروك,فورستنفلدبروک,菲尔斯滕费尔德布鲁克', 48.1790400, 11.2547000, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37394, 'Fürsteneck', 'Fursteneck', 'Firstenek,Fjurstenek,Fuersteneck,Fürsteneck,fei er si te nei ke,fwrstnk,Фирстенек,Фюрстенек,Ֆյուրսթենեկ,فورستنک,菲尔斯特内克', 48.7166700, 13.4666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37395, 'Fürstenberg', 'Fuerstenberg', 'Fuerstenberg/Havel,Furstenberg,Fürstenberg,Fürstenberg/Havel', 53.1842700, 13.1444200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37396, 'Fürstenberg', 'Furstenberg', '', 51.7333300, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37397, 'Fürstenau', 'Fuerstenau', 'Firstenau,Fjurstenau,Foersnau,Fuerstenau,Furstenau,Försnau,Fürstenau,fwrstnaw,fwrstnaw  alman,Фирстенау,Фюрстенау,فورستناو,فورستناو، آلمان', 52.5166700, 7.6767000, 'DE', '2016-03-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37398, 'Fürfeld', 'Fuerfeld', 'Firfeld,Fjurfel''d,Fuerfeld,Fürfeld,fei er fei er de,Фирфелд,Фюрфельд,菲尔费尔德', 49.7773700, 7.8926400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37399, 'Fünfstetten', 'Fuenfstetten', '', 48.8321500, 10.7654000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37400, 'Fuldatal', 'Fuldatal', 'Ful''datal'',Fuldatal,fu er da ta er,furudataru,Фулдатал,Фульдаталь,フルダタール,富尔达塔尔', 51.3833300, 9.5666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37401, 'Fuldabrück', 'Fuldabruck', 'Ful''dabrjuk,Fuldabrik,Fuldabrueck,Fuldabrück,fu er da bu lu ke,furudaburyukku,Фулдабрик,Фульдабрюк,フルダブリュック,富尔达布吕克', 51.2666700, 9.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37402, 'Fulda', 'Fulda', 'Foulnta,Ful''da,Fulda,Gorad Ful''da,ZEE,fu er da,furuda,fwlda,pulda,pwldh,Φούλντα,Горад Фульда,Фулда,Фульда,פולדה,فولدا,フルダ,富尔达,풀다', 50.5516200, 9.6751800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37403, 'Fuhlsbüttel', 'Fuhlsbuettel', 'Fuhlsbuettel,Fuhlsbüttel,Fulsbitel,Hamburg-Fuhlsbuettel,Hamburg-Fuhlsbüttel,Фулсбител', 53.6345900, 10.0160800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37404, 'Fuhlenhagen', 'Fuhlenhagen', 'Fuhlenhagen', 53.5729900, 10.5284100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37405, 'Fuhlendorf', 'Fuhlendorf', '', 53.9436600, 9.8868400, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37406, 'Fuchsstadt', 'Fuchsstadt', 'Fukhsshtat,Fuksshtadt,fu si ta te,Фуксштадт,Фухсштат,Ֆուքսշտադտ,富斯塔特', 50.1082500, 9.9337000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37407, 'Fuchsmühl', 'Fuchsmuhl', 'Fuchsmuehl,Fuchsmuhl,Fuchsmühl,Fukhsmil,Fuksmjul'',fu si mi he er,Фуксмюль,Фухсмил,Ֆուքսմյուլ,富斯米赫尔', 49.9226500, 12.1458200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37408, 'Fuchshofen', 'Fuchshofen', '', 50.4283200, 6.8510100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37409, 'Frücht', 'Frucht', 'Fruecht,Frücht', 50.3166700, 7.6833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37410, 'Frose', 'Frose', 'Frose', 51.7958100, 11.3791400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37411, 'Frontenhausen', 'Frontenhausen', 'Frontengauzen,Frontenhausen,Frontenkhauzen,frwntnhawzn,fu long teng hao sen,Фронтенгаузен,Фронтенхаузен,Ֆրոնթենհաուզեն,فرونتنهاوزن,弗龙滕豪森', 48.5462800, 12.5311800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37412, 'Fronhofen', 'Fronhofen', '', 49.9833300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37413, 'Fronhausen', 'Fronhausen', 'Frongauzen,Fronkhauzen,fu long hao sen,furonhauzen,Фронгаузен,Фронхаузен,フロンハウゼン,弗龙豪森', 50.7000000, 8.7000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37414, 'Fröndenberg', 'Froendenberg', 'Fr''ondenberg na Rur,Frendenberg,Frjondenberg-na-Rure,Froendenberg,Froendenberg/Ruhr,Frondenberg,Fröndenberg,Fröndenberg/Ruhr,frwndnbrg,frwndnbrgh,fu lun deng bei ge,Френденберг,Фрьонденберг на Рур,Фрёнденберг-на-Руре,فروندنبرغ,فروندنبرگ,弗伦登贝格', 51.4756300, 7.7694600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37415, 'Frömmstedt', 'Froemmstedt', '', 51.2611400, 11.0401000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37416, 'Frohnsdorf', 'Frohnsdorf', '', 50.9424800, 12.5786800, 'DE', '2016-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37417, 'Frohnhofen', 'Frohnhofen', 'Fronkhofen,fu luo en huo fen,Фронхофен,弗罗恩霍芬', 49.4538400, 7.2993900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37418, 'Frohnau', 'Frohnau', 'Berlin-Frohnau', 52.6333600, 13.2902400, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37419, 'Frohburg', 'Frohburg', 'Froburg,Froburga,Frohburg,Frokhburg,frhbwrg,frwhbwrgh,fu luo bao,Фробург,Фрохбург,فرهبورگ,فروهبورغ,弗罗堡', 51.0571900, 12.5574600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37420, 'Fritzlar', 'Fritzlar', 'FRZ,Fricdislaria,Friclar,Fritclar,Fritslar,Fritzlar,Gorad Fryclar,frytslar,frytzlar,fu li ci la er,furittsura,Φρίτσλαρ,Горад Фрыцлар,Фритцлар,Фрицлар,Фріцлар,فريتسلار,فریتزلار,フリッツラー,弗里茨拉尔', 51.1318100, 9.2755700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37421, 'Frittlingen', 'Frittlingen', '', 48.1270900, 8.7077400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37422, 'Friolzheim', 'Friolzheim', 'Friol''cgajm,Friol''ckhajm,Friolckhajm,fu li ao er ci hai mu,Фриолцхајм,Фриольцхайм,Фріольцгайм,Ֆրիոլցհայմ,弗里奥尔茨海姆', 48.8333300, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37423, 'Friesoythe', 'Friesoythe', 'Ait,Aithe,Friesoythe,Frizojte,fryzwyth,fu li suo yi te,Фризойте,Фризојте,فريزويته,فریزویته,弗里索伊特', 53.0226000, 7.8576400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37424, 'Friesenried', 'Friesenried', '', 47.8747700, 10.5346400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37425, 'Friesenheim', 'Friesenheim', '', 49.8363900, 8.2569400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37426, 'Friesenheim', 'Friesenheim', 'Frizengajm,Frizenkhajm,Фризенхайм,Фризенхајм,Фрізенгайм', 48.3666700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37427, 'Friesenhagen', 'Friesenhagen', 'Frizenkhagen,fraysnhagn,fu li sen ha gen,Фризенхаген,فرایسنهاگن,弗里森哈根', 50.9037700, 7.8096100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37428, 'Friesack', 'Friesack', 'Frizak,fryzak,fu li sa ke,Фризак,Ֆրիզակ,فريزاك,فریزاک,弗里萨克', 52.7376400, 12.5796900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37429, 'Friemar', 'Friemar', 'Friemar', 50.9770200, 10.7885100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37430, 'Frielendorf', 'Frielendorf', 'Freilendorf,Frielendorf,Frilendorf,fu li lun duo fu,furirendorufu,Фрилендорф,Фрілендорф,フリーレンドルフ,弗里伦多夫', 50.9707300, 9.3226900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37431, 'Friedrich-Wilhelm-Lübke-Koog', 'Friedrich-Wilhelm-Lubke-Koog', 'Fridrikh-Vil''gel''m-Ljubke-Kog,Fridrikh-Vilkhelm-Libke-Kog,Friedrich-Wilhelm-Lubke-Koog,Friedrich-Wilhelm-Luebke-Kuuch,Friedrich-Wilhelm-Lübke-Koog,Friedrich-Wilhelm-Lübke-Kuuch,fu li de li xi-wei er hei er mu-lu bu ke-ke ge,Фридрих-Вилхелм-Либке-Ког,Фридрих-Вильгельм-Любке-Ког,弗里德里希-维尔黑尔姆-吕布克-科格', 54.8666700, 8.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37432, 'Friedrichswerth', 'Friedrichswerth', 'Friedrichswerth', 50.9940900, 10.5446900, 'DE', '2014-04-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37433, 'Friedrichswalde', 'Friedrichswalde', 'Fridrikhsval''de,Fridrikhsvalde,Fridriksvalde,Fridrixsvalde,fu li de li xi si wa er de,Фридриксвалде,Фридрихсвалде,Фридрихсвальде,Ֆրիդրիխսվալդե,弗里德里希斯瓦尔德', 53.0291900, 13.7068200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37434, 'Friedrichsthal', 'Friedrichsthal', 'Friedrichsthal', 49.3278600, 7.0962200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37435, 'Friedrichsthal', 'Friedrichsthal', '', 51.4833300, 10.5833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37436, 'Friedrichstadt', 'Friedrichstadt', 'Fraeaerstaeae,Frederiksstad,Fridrikhshtadt,Fridrikhshtat,Fräärstää,fei te lie shi ta te,frydryshtat,Фридрихштадт,Фридрихштат,فريدريشتات,فریدریش‌اشتات,腓特烈施塔特', 54.3756600, 9.0867200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37437, 'Friedrichskoog', 'Friedrichskoog', 'Fridrikhskog,Fridrikskog,Friedrichskoog,Konig Friedfricks VII Koog,fu li de li xi si ke ge,Фридрикског,Фридрихског,弗里德里希斯科格', 54.0166700, 8.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37438, 'Friedrichsholm', 'Friedrichsholm', 'Friedrichsholm', 54.3017200, 9.4273200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37439, 'Friedrichshain', 'Friedrichshain Bezirk', 'Berlin-Friedrichshain,Fridrikhskhajn,Verwaltungsbezirk Friedrichshain,fei te lie si hai yin,prydrykshyyn,Фридрихсхайн,פרידריכסהיין,فریڈرشہائین-کریوزبرگ,腓特烈斯海因', 52.5155900, 13.4548200, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37440, 'Friedrichshagen', 'Friedrichshagen', 'Berlin-Friedrichshagen', 52.4505200, 13.6246300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37441, 'Friedrichshafen', 'Friedrichshafen', 'FDH,Fridrikhsgafen,Fridrikhskhafen,Fridrixshafen,Friedrichshafen,Gorad Frydrykhsgafen,fei te lie gang,frydryshshafn,furidorihisuhafen,peulideulihiseuhapen,phridariksahaphena,pridrikhshapeni,Горад Фрыдрыхсгафен,Фридрихсхафен,Фрідріхсгафен,Ֆրիդրիխսհաֆեն,פרידריכסהאפן,فريدريشسهافن,فریدریشسهافن,फ्रीडरिक्सहाफेन,ფრიდრიხსჰაფენი,フリードリヒスハーフェン,腓特烈港,프리드리히스하펜', 47.6568900, 9.4755400, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37442, 'Friedrichsgraben', 'Friedrichsgraben', 'Friedrichsgraben', 54.2666700, 9.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37443, 'Friedrichsgabekoog', 'Friedrichsgabekoog', 'Fridrikhsgabekog,Fridriksgabekog,Friedrichsgabekoog,fu li de li xi si jia bei ke ge,Фридриксгабеког,Фридрихсгабеког,弗里德里希斯加贝科格', 54.1500000, 8.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37444, 'Friedrichsfelde', 'Friedrichsfelde', 'Berlin-Friedrichsfelde', 52.5057500, 13.5081200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37445, 'Friedrichsdorf', 'Friedrichsdorf', 'Fridrikhsdorf,frydryshsdwrf,frydryshzdwrf,fu li de li xi si duo fu,Фридрихсдорф,Фрідріхсдорф,فريدريشسدورف,فریدریشزدورف,弗里德里希斯多夫', 50.2496200, 8.6428100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37446, 'Friedrichsbrunn', 'Friedrichsbrunn', 'Fridrikhsbrun,Fridriksbrun,Friedrichsbrunn,Фридриксбрун,Фридрихсбрун', 51.6902800, 11.0373700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37447, 'Friedrichroda', 'Friedrichroda', 'Fridrikhroda,frydryshrwda,fu li de li xi luo da,Фридрихрода,فريدريشرودا,فریدریشرودا,弗里德里希罗达', 50.8575400, 10.5650700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37448, 'Friedland', 'Friedland', 'Friedland', 53.6702800, 13.5540000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37449, 'Friedland', 'Friedland', 'Bryland,Fridland,Friedland,frydlnd,Фридланд,فریدلند', 52.1049300, 14.2639900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37450, 'Gemeinde Friedland', 'Gemeinde Friedland', '', 51.4166700, 9.9333300, 'DE', '2015-01-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37451, 'Friedewald', 'Friedewald', 'Freidewald,Frideval''d,Fridevald,Friedewald,Фридевалд,Фридевальд,Фрідевальд', 50.8833300, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37452, 'Friedewald', 'Friedewald', '', 50.7110600, 7.9604000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37453, 'Friedersdorf', 'Friedersdorf', 'Friedersdorf', 51.6480900, 12.3655500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37454, 'Friedersdorf', 'Friedersdorf', 'Friedersdorf', 51.0241600, 14.5624600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37455, 'Friedersdorf', 'Friedersdorf', '', 50.6049200, 11.0357700, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37456, 'Friedenweiler', 'Friedenweiler', 'Fridenvajler,Fridenvayler,fu li deng wei lei,Фриденвайлер,Фриденвајлер,Фріденвайлер,Ֆրիդենվայլեր,弗里登韦勒', 47.9177800, 8.2562700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37457, 'Friedenfels', 'Friedenfels', '', 49.8826000, 12.1012400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37458, 'Friedenau', 'Friedenau', 'Berlin-Friedenau,Fridenau,Фриденау', 52.4713300, 13.3281300, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37459, 'Friedelsheim', 'Friedelsheim', '', 49.4469400, 8.2230600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37460, 'Friedelshausen', 'Friedelshausen', 'Friedelshausen', 50.6578100, 10.2366800, 'DE', '2013-06-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37461, 'Friedeburg', 'Friedeburg', 'Freborg,Frideburg,Friedeburg,fu li de bao,Фридебург,弗里德堡', 53.4500000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37462, 'Friedberg', 'Friedberg', 'Fridberg,Friedberch,Friedberg,Friedberg in Hessen,Friedburg,Gorad Frydberg,frydbrg  hsn,frydbrgh,fu li de bei ge,furitoberuku,Горад Фрыдберг,Фридберг,Фрідберг,فريدبرغ,فریدبرگ، هسن,フリートベルク,弗里德贝格', 50.3373900, 8.7559100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37463, 'Friedberg', 'Friedberg', 'Fribe,Fridberg,Friedberch,Friedberg bei Augsburg,frydbrg  bayrn,frydbrgh,furitoberuku,Фридберг,Фрідберг,Ֆրիդբերգ,فريدبرغ,فریدبرگ، بایرن,フリートベルク', 48.3569300, 10.9846100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37464, 'Fridolfing', 'Fridolfing', 'Fridol''fing,Fridolfing,Friedolfing,frydwlfyng,fu li duo er fen ge,Фридолфинг,Фридольфинг,Фрідольфінг,Ֆրիդոլֆինգ,فریدولفینگ,弗里多尔芬格', 47.9977300, 12.8262800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37465, 'Fridingen an der Donau', 'Fridingen an der Donau', 'Fridingen,Fridingen na Dunavu,Fridingen-an-der-Donau,Fridingen-na-Dunae,duo nao he pan fu li ding gen,frydynghn an dr danwb,frydyngn an dr danwb,Фридинген на Дунаву,Фридинген-ан-дер-Донау,Фридинген-на-Дунае,فريدينغن آن در دانوب,فریدینگن آن در دانوب,多瑙河畔弗里丁根', 48.0195500, 8.9232200, 'DE', '2013-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37466, 'Frickingen', 'Frickingen', 'Frickengen,Frickingen,Frikingen,Frikkingen,Frkikingen,fu li jin gen,Фрикинген,Фріккінген,Ֆրկիկինգեն,ფრიკინგენი,弗里金根', 47.8143800, 9.2734900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37467, 'Frickenhausen', 'Frickenhausen', '', 49.6708900, 10.0926800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37468, 'Frickenhausen', 'Frickenhausen', '', 48.5935300, 9.3600500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37469, 'Freyung', 'Freyung', 'Frajung,Frejung,Freyung,frywng  bayrn,fu lai weng,Фрајунг,Фрейунг,فریونگ، بایرن,弗赖翁', 48.8095200, 13.5476800, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37470, 'Freystadt', 'Freystadt', 'Feyenstadt,Frajshtadt,Frajshtat,Freystadt,frayshtat,Фрайштадт,Фрајштат,فرايشتات,فریسٹیڈ,فری‌اشتات', 49.2000700, 11.3303200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37471, 'Freyburg', 'Freyburg', 'Frajburg,Frejburg,Freyburg,Freyburg (Unstrut),fraybwrgh,frybwrg,Фрайбург,Фрајбург,Фрейбург,فرايبورغ,فریبورگ', 51.2136200, 11.7680400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37472, 'Freudental', 'Freudental', 'Freudental,Frojdental,Frojdental'',frwdntal,fu luo yi deng ta er,Фройденталь,Фројдентал,فرودنتال,弗罗伊登塔尔', 49.0097200, 9.0591700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37473, 'Freudenstadt', 'Freudenstadt', 'Freudenstadt,Frojdenshtadt,Frojdenshtat,fu luo yi deng shi ta te,Фройденштадт,Фројденштат,فرویدن‌اشتات,弗罗伊登施塔特', 48.4669500, 8.4137100, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37474, 'Freudenburg', 'Freudenburg', 'Frojdenburg,fu luo yi deng bao,Фройденбург,Фројденбург,弗罗伊登堡', 49.5434800, 6.5329200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37475, 'Freudenberg', 'Freudenberg', 'Freudenberg', 50.8974100, 7.8741500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37476, 'Freudenberg', 'Freudenberg', 'Freudenberg,Freudenberg am Main,Frojdenberg,frwydnbrg,frwydnbrgh,furoidenberuku,Фройденберг,Фројденберг,فرويدنبرغ,فرویدنبرگ,フロイデンベルク', 49.7534900, 9.3274800, 'DE', '2013-04-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37477, 'Freudenberg', 'Freudenberg', 'Freudenberg', 49.4833300, 11.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37478, 'Fretterode', 'Fretterode', 'Fretterode', 51.3166700, 10.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37479, 'Frettenheim', 'Frettenheim', '', 49.7597200, 8.2447200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37480, 'Frestedt', 'Frestedt', 'Frestedt', 54.0333300, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37481, 'Fresendelf', 'Fresendelf', 'Fresendelf', 54.3937500, 9.2468800, 'DE', '2012-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37482, 'Fresenburg', 'Fresenburg', '', 52.8833300, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37483, 'Freren', 'Freren', 'Freren,frrn,fryrn,fu lei lun,Фререн,فررن,فريرن,弗雷伦', 52.4870000, 7.5431300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37484, 'Frensdorf', 'Frensdorf', 'Frensdorf,fu lun si duo fu,furensudorufu,Френсдорф,Ֆրենսդորֆ,フレンスドルフ,弗伦斯多夫', 49.8166700, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37485, 'Fremdingen', 'Fremdingen', 'Fremdingen,fu lei mu ding gen,furemudingen,Фремдинген,Фремдінген,Ֆրեմդինգեն,フレムディンゲン,弗雷姆丁根', 48.9724100, 10.4575400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37486, 'Frellstedt', 'Frellstedt', '', 52.2057100, 10.9154300, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37487, 'Freital', 'Freital', 'Frajtal,Frajtal'',Freital,Freitale,Freithal,Freitāle,fraytal,fu lai ta er,Фрайтал,Фрайталь,Фрајтал,פרייטאל,فرايتال,فرایتال,弗赖塔尔', 51.0016600, 13.6488000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37488, 'Freistatt', 'Freistatt', 'Frajshtatt,Frejstatt,frystat,fu lai si ta te,Фрайштатт,Фрейстатт,فريستات,弗赖斯塔特', 52.6229600, 8.6522500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37489, 'Freising', 'Freising', 'Fraizin''nk,Frajzing,Frayzing,Freising,Freizingas,Freysing,Frisinga,Fryzynga,frayzng,frayzngh,fryzng,fu lai xin,furaijingu,peulaijing,Φράιζινγκ,Фрайзинг,Фрайзінг,Фрајзинг,Ֆրայզինգ,فرايزنغ,فرایزنگ,فریزنگ,フライジング,弗赖辛,프라이징', 48.4035100, 11.7487600, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37490, 'Freisen', 'Freisen', 'Frajzen,fu lai sen,Фрайзен,Фрајзен,弗赖森', 49.5500000, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37491, 'Freisbach', 'Freisbach', '', 49.2716700, 8.2719400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37492, 'Freirachdorf', 'Freirachdorf', '', 50.5833300, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37493, 'Freinsheim', 'Freinsheim', 'Frajnskhajm,Freinsheim,fraynshaym,fraynzhaym,fu lai yin si hai mu,furainsuhaimu,Фрайнсхайм,Фрајнсхајм,فراينسهايم,فراینزهایم,フラインスハイム,弗赖因斯海姆', 49.5064900, 8.2118600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37494, 'Freimersheim', 'Freimersheim', '', 49.7083300, 8.0891700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37495, 'Freilingen', 'Freilingen', '', 50.5593000, 7.8345800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37496, 'Frei-Laubersheim', 'Frei-Laubersheim', 'Fraj-Lauberskhajm,fu lai-lao bei er si hai mu,Фрай-Лауберсхайм,Фрај-Лауберсхајм,弗赖-劳贝尔斯海姆', 49.8000000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37497, 'Freilassing', 'Freilassing', 'Frajlasing,Frajlassing,Fraylasing,Freilassing,QFL,fraylasngh,fraylaysng,frylysng,fu lai la xin,Фрайлассинг,Фрайлассінг,Фрајласинг,Ֆրայլասինգ,فرايلاسنغ,فرایلایسنگ,فریلیسنگ,弗赖拉辛', 47.8408500, 12.9811400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37498, 'Freihung', 'Freihung', 'Frajgung,Frajkhung,Frajung,Frayung,Freihung,fu lai hong,Фрайгунг,Фрайунг,Фрајхунг,Ֆրայունգ,弗赖洪', 49.6213400, 11.9081700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37499, 'Freienwill', 'Freienwill', 'Freienwill', 54.7275200, 9.4941400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37500, 'Freiensteinau', 'Freiensteinau', 'Fraenshtajnau,Frajenshtajnau,Frajnshtajnau,fu lai en si tai nao,furaienshutainau,Фрайенштайнау,Фраєнштайнау,Фрајнштајнау,フライエンシュタイナウ,弗赖恩斯泰瑙', 50.4250900, 9.4026700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37501, 'Freienorla', 'Freienorla', 'Freienorla', 50.7666700, 11.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37502, 'Freienhagen', 'Freienhagen', '', 51.4166700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37503, 'Freienbessingen', 'Freienbessingen', 'Freienbessingen', 51.2333300, 10.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37504, 'Freiburg', 'Freiburg', 'Frajburg,Freiburg,Freiburg im Breisgau,Fribourg-en-Brisgau,Friburg de Brisgovia,Friburg de Brisgòvia,Friburgo de Brisgovia,Friburgo in Brisgovia,Fryburg Bryzgowijski,Phraimpournk,fraybwrg,fraybwrgh,fu lai bao,furaiburuku,Φράιμπουργκ,Фрайбург,Фрајбург,فرايبورغ,فرایبورگ,フライブルク,弗莱堡', 47.9959000, 7.8522200, 'DE', '2016-02-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37505, 'Freiburg', 'Freiburg', 'Frajburg,Freiborg,Freiburg,Freiburg an der Elbe,Freiburg/Elbe,Fryburg nad Laba,Fryburg nad Łabą,fu lai bu er ge,furaiburuku/erube,Фрайбург,Фрајбург,フライブルク/エルベ,弗赖布尔格', 53.8252900, 9.2880300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37506, 'Freiberg am Neckar', 'Freiberg am Neckar', 'Frajberg am Nekar,Frajberg-am-Nekkar,Frajberg-na-Nekkare,Freiberg,fraybrg am nkar,fraybrgh am nykar,nei ka he pan fu lai bei ge,Фрайберг-ам-Неккар,Фрайберг-на-Неккаре,Фрајберг ам Некар,فرايبرغ آم نيكار,فرایبرگ آم نکار,内卡河畔弗赖贝格', 48.9319600, 9.2024000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37507, 'Freiberg', 'Freiberg', 'Frajberg,Frayberq,Freiberg,Freiberga,Freiburg,Friberga,fraybrg,fraybrgh,fu lai bei ge,furaiberuku,peulaibeleukeu,pryybrg,Фрайберг,Фрајберг,פרייברג,فرايبرغ,فرایبرگ,フライベルク,弗莱贝格,프라이베르크', 50.9108900, 13.3388100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37508, 'Fredesdorf', 'Fredesdorf', 'Fredesdorf', 53.8758400, 10.1969300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37509, 'Freden', 'Freden', 'Freden,fu lei deng,Фреден,弗雷登', 51.9277100, 9.8935000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37510, 'Fredeburg', 'Fredeburg', '', 53.6666700, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37511, 'Bad Fredeburg', 'Bad Fredeburg', 'Fredeburg', 51.1893000, 8.3097800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37512, 'Freckenfeld', 'Freckenfeld', 'Frekenfeld,Frekkenfel''d,fu lei ken fei er de,Фрекенфелд,Фреккенфельд,弗雷肯费尔德', 49.0650000, 8.1138900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37513, 'Frechen', 'Frechen', 'Frechem,Frechen,Frekhen,frshn,fryshn,fu lei xing,Фрехен,فرشن,فريشن,弗雷兴', 50.9148500, 6.8118000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37514, 'Fraureuth', 'Fraureuth', 'Frauenreuth,Fraureuth', 50.7000000, 12.3500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37515, 'Fraunberg', 'Fraunberg', '', 48.3666700, 12.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37516, 'Frauenwald', 'Frauenwald', 'Frauenwald', 50.5843000, 10.8584100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37517, 'Frauenstein', 'Frauenstein', 'Frauehnshtajn,Frauenshtajn,fu lao en si tai yin,Фрауенштајн,Фрауэнштайн,فراون‌اشتاین,弗劳恩斯泰因', 50.8027900, 13.5379000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37518, 'Frauensee', 'Frauensee', 'Frauehnzee,Frauenze,fu lao en sai,Фрауензе,Фрауэнзее,弗劳恩塞', 50.8778600, 10.1417500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37519, 'Frauenprießnitz', 'Frauenpriessnitz', 'Frauehnprisnic,Frauenpriessnitz,Frauenprießnitz,Frauenprisnic,fu lao en pu li si ni ci,Фрауенприсниц,Фрауэнприсниц,弗劳恩普里斯尼茨', 51.0166700, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37520, 'Fraueneuharting', 'Fraueneuharting', '', 48.0387300, 12.0478000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37521, 'Frauenberg', 'Frauenberg', 'Frauehnberg,Frauenberg,fu lao en bei ge,Фрауенберг,Фрауэнберг,弗劳恩贝格', 49.6666700, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37522, 'Frauenau', 'Frauenau', 'Frauehnau,Frauenau,fraynaw,fu lao ai nao,Фрауенау,Фрауэнау,Ֆրաուենաու,فرائناو,弗劳埃瑙', 48.9889500, 13.3006700, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37523, 'Frasdorf', 'Frasdorf', 'Frasdorf,frasdwrf,fu la si duo fu,Фрасдорф,Ֆրասդորֆ,فراسدورف,弗拉斯多夫', 47.8037600, 12.2851200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37524, 'Franzenheim', 'Franzenheim', '', 49.6833300, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37525, 'Franzburg', 'Franzburg', 'Francburg,Francburga,Franzburg,Nowopole,Nowòpòle,frantsbwrg,frantsbwrgh,fu lan ci bao,Францбург,فرانتسبورغ,فرانتسبورگ,弗兰茨堡', 54.1850100, 12.8821000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37526, 'Frankweiler', 'Frankweiler', '', 49.2277800, 8.0580600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37527, 'Frankleben', 'Frankleben', '', 51.3114400, 11.9293200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37528, 'Fränkisch-Crumbach', 'Frankisch-Crumbach', 'Fraenkisch-Crumbach,Frenkish-Krumbakh,Fränkisch-Crumbach,fu lun ji shi-ke lun ba he,furenkishu=kurumubahha,Френкиш-Крумбах,Френкіш-Крумбах,フレンキシュ＝クルムバッハ,弗伦基施-克伦巴赫', 49.7461100, 8.8586100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37529, 'Frankfurt am Main', 'Frankfurt am Main', 'FRA,Francfort,Francfort - Frankfurt am Main,Francfort d''o Meno,Francfort del Meno,Francfort sul Main,Francfort-sur-le-Main,Francfòrt sul Main,Francoforte,Francoforte sul Meno,Francofurtum ad Moenum,Francuforti supro Menu,Francuforti suprô Menu,Frankford-on-Main,Frankfort,Frankfort an''n Main,Frankfort an’n Main,Frankfort on the Main,Frankfurt,Frankfurt am Main,Frankfurt del Main,Frankfurt na Majn,Frankfurt na Majni,Frankfurt nad Menem,Frankfurt nad Mohanem,Frankfurt nad Mohanom,Frankfurt-na-Majne,Frankfurt/Main,Frankfurtas prie Maino,Frankfurte pie Mainas,Frankfurto ce Majno,Frankfurto ĉe Majno,Fráncfort,Fráncfort - Frankfurt am Main,Fráncfort d''o Meno,Fráncfort del Meno,Phran''kphourte,fa lan ke fu,frankfwrt,peulangkeupuleuteu,prnqpwrt,Φρανκφούρτη,Франкфурт на Майн,Франкфурт на Мајни,Франкфурт-на-Майне,פרנקפורט,فرانكفورت,فرانکفورت,แฟรงค์เฟิร์ต,ფრანკფურტ-ამ-მაინი,フランクフルト・アム・マイン,法兰克福,프랑크푸르트', 50.1155200, 8.6841700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37530, 'Frankfurt (Oder)', 'Frankfurt (Oder)', 'Francfort,Francfort del Oder,Francfort del Odra,Francfort-sur-l''Oder,Francoforte sull''Oder,Frankfort an de Oder,Frankfort on the Oder,Frankfurt,Frankfurt (Oder),Frankfurt Oderi aeaeres,Frankfurt Oderi ääres,Frankfurt an der Oder,Frankfurt de l''Oder,Frankfurt len Oder,Frankfurt na Oder,Frankfurt na Odri,Frankfurt nad Odra,Frankfurt nad Odrą,Frankfurt pe Oder,Frankfurt-na-Odere,Frankfurt/Oder,Frankfurtas prie Oderio,Frankfurto ce Odro,Frankfurto ĉe Odro,Fráncfort,Fráncfort del Odra,Fráncfort del Óder,ZFR,furankufuruto,oderis prankʼpurtʼi,Франкфурт на Одер,Франкфурт-на-Одере,פרנקפורט על האודר,ოდერის ფრანკფურტი,フランクフルト', 52.3471400, 14.5506200, 'DE', '2016-09-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37531, 'Frankenwinheim', 'Frankenwinheim', '', 49.8873300, 10.3143200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37532, 'Frankenthal', 'Frankenthal', '', 51.1312900, 14.1089300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37533, 'Frankenthal', 'Frankenthal', 'Frankental,Frankental'',Frankenthal,Frongedahl,frakntal,fu lan ken ta er,Франкентал,Франкенталь,فراکنتال,弗兰肯塔尔', 49.5341400, 8.3535700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37534, 'Frankenstein', 'Frankenstein', '', 50.9006400, 13.2093300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37535, 'Frankenstein', 'Frankenstein', 'Frankenstein', 49.4401500, 7.9774400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37536, 'Frankenroda', 'Frankenroda', 'Frankenroda,fu lan ken luo da,Франкенрода,弗兰肯罗达', 51.1000000, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37537, 'Frankenheim', 'Frankenheim', 'Frankenheim,Frankenheim/Rhoen,Frankenheim/Rhön', 50.5445200, 10.0682800, 'DE', '2017-06-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37538, 'Frankenhain', 'Frankenhain', '', 50.7566000, 10.7876900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37539, 'Frankenfeld', 'Frankenfeld', '', 52.7684000, 9.4298700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37540, 'Frankeneck', 'Frankeneck', '', 49.3763900, 8.0486100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37541, 'Frankendorf', 'Frankendorf', '', 50.9666700, 11.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37542, 'Frankenberg', 'Frankenberg', 'Frankenberg,franknbrg,franknbrgh,fu lan ken bei ge,furankenberuku,Франкенберг,فرانكنبرغ,فرانکنبرگ,フランケンベルク,弗兰肯贝格', 51.0589000, 8.8007700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37543, 'Frankenberg', 'Frankenberg', 'Frankenberg,Frankenberg/Sa.,Frankenberga/Sa.,Frankenburg,franknbrg  zaksn,fu lan ken bei ge,Франкенберг,Франкенбург,فرانکنبرگ، زاکسن,弗蘭肯貝格', 50.9129700, 13.0401100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37544, 'Frankenau', 'Frankenau', 'Frakanava,Frankenau,franknaw,fu lan ke nao,furankenau,Франкенау,فرانكناو,فرانکناو,フランケナウ,弗兰克瑙', 51.0926900, 8.9344700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37545, 'Frankelbach', 'Frankelbach', '', 49.5333300, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37546, 'Frammersbach', 'Frammersbach', 'Framersbakh,Framersbax,Frammasboch,Frammersbach,Frammersbakh,fu la mei er si ba he,Фрамерсбах,Фраммерсбах,Ֆրամերսբախ,弗拉梅尔斯巴赫', 50.0646800, 9.4688800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37547, 'Framersheim', 'Framersheim', 'Framerskhajm,fu la mei er si hai mu,Фрамерсхайм,Фрамерсхајм,弗拉梅尔斯海姆', 49.7580600, 8.1741700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37548, 'Forstmehren', 'Forstmehren', '', 50.7000000, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37549, 'Forstinning', 'Forstinning', 'Forstining,Forstinning,fu er si di ning ge,fwrstynyng,Форстининг,Форстиннинг,Форстіннінг,فورستینینگ,福尔斯蒂宁格', 48.1686600, 11.9124400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37550, 'Forstern', 'Forstern', '', 48.1834300, 11.9771600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37551, 'Forst', 'Forst', 'Barsac,Barsc,Baršć,Forst,Forst (Lausitz),Forst/Lausitz,Stadt Forst (Lausitz),frst,fwrst,poleuseuteu,pwrst,Форст,Ֆորսթ,פורסט,فرست,فورست,포르스트', 51.7354400, 14.6397100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37552, 'Forst', 'Forst', '', 50.8000000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37553, 'Forst', 'Forst', 'Forst,Форст', 49.1586100, 8.5808300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37554, 'Föritz', 'Foeritz', 'Feric,Fjoric,fu li ci,Фериц,Фёриц,弗里茨', 50.3417400, 11.2318000, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37555, 'Forheim', 'Forheim', 'Forgajm,Forhaym,Forkhajm,foruhaimu,fu lai mu,Форгайм,Форхайм,Форхајм,Ֆորհայմ,フォルハイム,福赖姆', 48.7666700, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37556, 'Förderstedt', 'Foerderstedt', 'Foerderstedt,Forderstedt,Förderstedt', 51.8971700, 11.6334900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37557, 'Forchtenberg', 'Forchtenberg', 'Forchtenberg,Forkhtenberg,foruhitenberuku,fu xi teng bei ge,fwrshtnbrgh,fwrshtnbwrg,Форхтенберг,فورشتنبرغ,فورشتنبورگ,フォルヒテンベルク,福希滕贝格', 49.2886700, 9.5602600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37558, 'Forchheim', 'Forchheim', 'Forchheim,Forchheimas,Forkhgajm,Forkhkhajm,Forxhaym,foruhihaimu,fu xi hai mu,fwrshhaym,pwrshyym,Форхгайм,Форххайм,Форххајм,Ֆորխհայմ,פורשהיים,فورشهايم,فورشهایم,فورچہایم,フォルヒハイム,福希海姆', 49.7175400, 11.0587700, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37559, 'Forchheim', 'Forchheim', '', 48.1666700, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37560, 'Forbach', 'Forbach', 'Forbakh,fu er ba he,Форбах,福尔巴赫', 48.6833300, 8.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37561, 'Fohren-Linden', 'Fohren-Linden', '', 49.5833300, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37562, 'Föhren', 'Foehren', 'Feren,Fjoren,Foehren,Föhren,fu he lun,Ферен,Фёрен,弗赫伦', 49.8592900, 6.7648000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37563, 'Föhrden-Barl', 'Fohrden-Barl', 'Fohrden-Barl,Forden-Barl,Föhrden-Barl,Förden-Barl', 53.9280300, 9.7870200, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37564, 'Fockendorf', 'Fockendorf', 'Fokendorf,fu ken duo fu,Фокендорф,福肯多夫', 51.0500000, 12.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37565, 'Föckelberg', 'Fockelberg', 'Fekelberg,Fjokkel''berg,Foeckelberg,Föckelberg,fu ke er bei ge,Фекелберг,Фёккельберг,弗克尔贝格', 49.5333300, 7.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37566, 'Fockbek', 'Fockbek', 'Fockbek', 54.3000000, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37567, 'Fluterschen', 'Fluterschen', '', 50.6665000, 7.6271100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37568, 'Flußbach', 'Flussbach', '', 50.0166700, 6.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37569, 'Flossenbürg', 'Flossenburg', 'Flosenbirg,Flosenbyurg,Flossenbjurg,Flossenbuerg,Flossenburg,Flossenbürg,Stratopedo synkentroses Phlosenmpernk,plwsnbwrg,Στρατόπεδο συγκέντρωσης Φλόσενμπεργκ,Флосенбирг,Флоссенбюрг,Ֆլոսենբյուրգ,פלוסנבורג', 49.7333300, 12.3500000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37570, 'Floß', 'Floss', 'Flos,Floss,Flosz,fu luo si,Флос,弗洛斯', 49.7239500, 12.2759300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37571, 'Flörsheim', 'Floersheim', 'Floersheim am Main,Florsheim,Florsheim am Main,Flörsheim,Flörsheim am Main', 50.0131100, 8.4277900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37572, 'Flonheim', 'Flonheim', 'Flonkhajm,fu long hai mu,Флонхайм,Флонхајм,弗隆海姆', 49.7850000, 8.0400000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37573, 'Flomborn', 'Flomborn', '', 49.6905600, 8.1491700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37574, 'Flöha', 'Floeha', 'Flea,Flekha,Fljoa,Floeha,Flöha,Flēa,flwha,fu lei ha,Флеа,Флеха,Флёа,Флөа,فلوها,弗勒哈', 50.8561300, 13.0740700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37575, 'Flögeln', 'Floegeln', 'Flegeln,Fljogel''n,fu lei ge er en,Флегелн,Флёгельн,弗勒格尔恩', 53.6616300, 8.8048600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37576, 'Flintsbach', 'Flintsbach', '', 47.7257600, 12.1241900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37577, 'Flintbek', 'Flintbek', 'Flintbek,Gross Flintbek,Groß Flintbek,fu lin te bei ke,Флинтбек,弗林特贝克', 54.2500000, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37578, 'Fließem', 'Fliessem', 'Fliessem,Fliessen,Fließem,Fließen', 50.0234900, 6.5415100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37579, 'Flieden', 'Flieden', 'Fliden,fu li deng,Флиден,Фліден,弗利登', 50.4238900, 9.5666000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37580, 'Flessau', 'Flessau', 'Flessau', 52.7599600, 11.6709300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37581, 'Fleringen', 'Fleringen', '', 50.2166700, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37582, 'Flensburg', 'Flensburg', 'FLF,Flensboarch,Flensborag,Flensborg,Flensbourg,Flensburg,Flensburga,Flensburgas,Flensburgh,Flensburgo,Flensbuurich,Flensmpournk,Flenzburg,Gorad Flensburg,flnsbwrg,flnsbwrgh,flnzbrg,fu lun si bao,furensuburuku,peullenseubuleukeu,phlensaburga,plnsbwrg,Φλένσμπουργκ,Горад Фленсбург,Флензбург,Фленсбург,פלנסבורג,فلنزبرگ,فلنسبورغ,فلنسبورگ,ফ্লেন্সবুর্গ,フレンスブルク,弗伦斯堡,플렌스부르크', 54.7843100, 9.4396100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37583, 'Flemlingen', 'Flemlingen', '', 49.2427800, 8.0950000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37584, 'Fleischwangen', 'Fleischwangen', 'Flajshvangen,Fljajshvangen,fu lai shi wan gen,Флайшванген,Флајшванген,Фляйшванген,弗莱施万根', 47.8833300, 9.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37585, 'Flein', 'Flein', 'Flajn,Flein,Fljajn,fu lai yin,furain,Флайн,Флајн,Фляйн,フライン,弗莱因', 49.1030600, 9.2108300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37586, 'Fleckeby', 'Fleckeby', 'Fleckeby', 54.4833300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37587, 'Flechtingen', 'Flechtingen', 'Flahtungun,Flekhtingen,fu lai xi ting gen,Флехтинген,弗莱希廷根', 52.3308300, 11.2417600, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37588, 'Flarchheim', 'Flarchheim', '', 51.1333300, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37589, 'Flammersfeld', 'Flammersfeld', 'Flamersfeld,Flammersfel''d,flamrsfld,fu la mei er si fei er de,furanmasuferuto,Фламерсфелд,Фламмерсфельд,فلامرسفلد,フランマースフェルト,弗拉梅尔斯费尔德', 50.6471100, 7.5271300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37590, 'Fladungen', 'Fladungen', 'Fladungen,fladwng,fladwnghn,fu la dui gen,Фладунген,Ֆլադունգեն,فلادونغن,فلادونگ,فلیڈنجن,弗拉敦根', 50.5205400, 10.1458100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37591, 'Flacht', 'Flacht', '', 50.3452800, 8.0502800, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37592, 'Flachslanden', 'Flachslanden', 'Flachslanden,Flakhslanden,Flakslanden,fu la si lan deng,furahasuranden,Флаксланден,Флахсланден,Ֆլակսլանդեն,フラハスランデン,弗拉斯兰登', 49.3984500, 10.5132300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37593, 'Fitzen', 'Fitzen', '', 53.4948900, 10.6466100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37594, 'Fitzbek', 'Fitzbek', 'Fitzbek', 54.0000000, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37595, 'Fischingen', 'Fischingen', 'Fischingen', 47.6500000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37596, 'Fischerbach', 'Fischerbach', 'Fisherbakh,fei she er ba he,Фишербах,Фішербах,菲舍尔巴赫', 48.2868700, 8.1095900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37597, 'Fischbachau', 'Fischbachau', 'Fisbaxau,Fishbakhau,fyshbashaw,Фишбахау,Фішбахау,Ֆիշբախաու,فیشباشاو', 47.7195200, 11.9508100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37598, 'Fischbach', 'Fischbach', 'Fishbakh,fei shi ba he,Фишбах,菲施巴赫', 49.7333300, 7.4000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37599, 'Fischbach', 'Fischbach', '', 49.4500000, 7.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37600, 'Fischbach', 'Fischbach', 'Fischbach,Fischbach bei Dahn', 49.0877100, 7.7116000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37601, 'Fischach', 'Fischach', 'Fisax,Fishakh,fei sha,Фишах,Фішах,Ֆիշախ,菲沙', 48.2904700, 10.6559200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37602, 'Fisch', 'Fisch', '', 49.6166700, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37603, 'Firrel', 'Firrel', 'Firel,Firrel'',fei lei er,Фирел,Фиррель,菲雷尔', 53.3333300, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37604, 'Fintel', 'Fintel', 'Fintel,Fintel'',fen te er,finteru,Финтел,Финтель,フィンテル,芬特尔', 53.1718800, 9.6696900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37605, 'Finsterwalde', 'Finsterwalde', 'Finsterval''de,Finstervalde,Finsterwalde,Grabin,fen si te er wa er de,fynstrfaldh,fynstrwaldh,Финстервалде,Финстервальде,Ֆինսթերվալդե,فينسترفالده,فینستروالده,芬斯特尔瓦尔德', 51.6338800, 13.7066200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37606, 'Finsterbergen', 'Finsterbergen', 'Finsterbergen', 50.8346400, 10.5891600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37607, 'Finsing', 'Finsing', 'Finzing,fen xin ge,fynzyng,Финзинг,Фінзінг,فینزینگ,芬辛格', 48.2161500, 11.8241200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37608, 'Finnentrop', 'Finnentrop', 'Finentrop,Finnentrop,Neubrucke,Neubrücke,fei nen te luo pu,Финентроп,Финнентроп,Фіннентроп,菲嫩特罗普', 51.1680000, 7.9730000, 'DE', '2015-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37609, 'Finkenbach-Gersweiler', 'Finkenbach-Gersweiler', '', 49.6833300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37610, 'Filz', 'Filz', 'Fils,Filz', 50.1666700, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37611, 'Filsum', 'Filsum', '', 53.2421300, 7.6278500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37612, 'Filsen', 'Filsen', '', 50.2401800, 7.5848600, 'DE', '2013-04-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37613, 'Fiersbach', 'Fiersbach', '', 50.7000000, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37614, 'Fiefbergen', 'Fiefbergen', 'Fiefbergen', 54.3833300, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37615, 'Fichtenwalde', 'Fichtenwalde', 'Beelitz (Mark) OT Fichtenwalde,Beelitz Ortsteil Fichtenwalde,Fichtenvalde,Fichtenwalde,Fiwa,Klaistower Heide,Kolonie Fichtenwalde,Wohnplatz Fichtenwalde,Фичтенвалде,Фічтенвалде', 52.2803800, 12.8834900, 'DE', '2015-10-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37616, 'Fichtenberg', 'Fichtenberg', '', 48.9860100, 9.7119900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37617, 'Fichtelberg', 'Fichtelberg', 'Fichtelberg', 50.0028800, 11.8542500, 'DE', '2012-04-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37618, 'Feusdorf', 'Feusdorf', '', 50.3500000, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37619, 'Feuerscheid', 'Feuerscheid', '', 50.1000000, 6.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37620, 'Stuttgart Feuerbach', 'Stuttgart Feuerbach', 'Feuerbach', 48.8086700, 9.1571900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37621, 'Feuchtwangen', 'Feuchtwangen', 'Feuchtwangen,Feuchtwanger,Fojkhtvangen,Foyxtvangen,foihitovu~angen,fu yi he te wan gen,fwyshtfanghn,fwyshtwangn,Фойхтванген,Фојхтванген,Ֆոյխտվանգեն,فويشتفانغن,فویشتوانگن,フォイヒトヴァンゲン,福伊赫特万根', 49.1628700, 10.3385000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37622, 'Feucht', 'Feucht', 'Feucht,Fojkht,fu yi he te,Фойхт,Фојхт,Ֆոյխթ,福伊赫特', 49.3759700, 11.2143300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37623, 'Ferschweiler', 'Ferschweiler', '', 49.8666700, 6.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37624, 'Ferna', 'Ferna', 'Ferna', 51.4500000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37625, 'Ferdinandshof', 'Ferdinandshof', 'Ferdinandshof,Ferdinandskhof,fei er di nan ci huo fu,Фердинандсхоф,费尔迪南茨霍夫', 53.6612400, 13.8872400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37626, 'Fensdorf', 'Fensdorf', '', 50.7333300, 7.7666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37627, 'Fenne', 'Fenne', '', 49.2470200, 6.8849900, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37628, 'Felsberg', 'Felsberg', 'Fel''sberg,Felsberg,ferusuberuku,flsbrg,Фелсберг,Фельсберг,فلسبرگ,フェルスベルク', 51.1376300, 9.4213900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37629, 'Felm', 'Felm', 'Felm', 54.4166700, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37630, 'Fellheim', 'Fellheim', 'Fel''gajm,Felhaym,Felkhajm,Fell''khajm,fei er hai mu,Фелльхайм,Фелхајм,Фельгайм,Ֆելհայմ,费尔海姆', 48.0728000, 10.1522400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37631, 'Fellen', 'Fellen', 'Felen,Fellen,Фелен,Феллен,Ֆելեն', 50.1500000, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37632, 'Fellbach', 'Fellbach', 'Felbakh,Fell''bakh,Foeuebach,Föübåch,fei er ba he,flbakh,Фелбах,Фелльбах,فلباخ,费尔巴赫', 48.8091200, 9.2769700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37633, 'Fell', 'Fell', '', 49.7666700, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37634, 'Feldkirchen-Westerham', 'Feldkirchen-Westerham', 'Fel''dkirkhen-Vestergam,Fel''dkirkhen-Vesterkham,Feldkirkhen-Vesterkham,fei er de ji er xing-wei si te la mu,fldkyrshn-wstrham,Фелдкирхен-Вестерхам,Фельдкирхен-Вестерхам,Фельдкірхен-Вестергам,Ֆելդկիրխեն Վեսթերհամ,فلدکیرشن-وسترهام,费尔德基尔兴-韦斯特拉姆', 47.9074800, 11.8426600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37635, 'Feldkirchen', 'Feldkirchen', '', 48.8382800, 12.5278500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37636, 'Feldkirchen', 'Feldkirchen', '', 48.1481100, 11.7310000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37637, 'Felde', 'Felde', 'Fel''de,Felde,Фелде,Фельде', 54.3000000, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37638, 'Feldberg', 'Feldberg', '', 47.7743500, 7.6414200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37639, 'Feldafing', 'Feldafing', 'Fel''dafing,Feldafing,fei er da fen ge,fldafyng,Фелдафинг,Фельдафинг,Фельдафінг,فلدافینگ,费尔达芬格', 47.9460200, 11.2932600, 'DE', '2012-09-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37640, 'Feilsdorf', 'Feilsdorf', '', 49.9833300, 6.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37641, 'Feilitzsch', 'Feilitzsch', 'Fajlich,Fajlicsh,fa yi li ci xi,fairitchu,Файлич,Файліч,Фајлицш,ファイリッチュ,法伊利茨希', 50.3666700, 11.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37642, 'Feilbingert', 'Feilbingert', 'Fajl''bingert,Fajlbingert,fa yi er bin ge er te,Файльбингерт,Фајлбингерт,法伊尔宾格尔特', 49.7666700, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37643, 'Fehrbellin', 'Fehrbellin', 'Ferbelin,Ferbellin,Ferberlin,fei er bei lin,Фербелин,Фербеллин,Ֆերբեռլին,费尔贝林', 52.8135000, 12.7644000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37644, 'Fehl-Ritzhausen', 'Fehl-Ritzhausen', '', 50.6450000, 8.0030600, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37645, 'Fedderwarden', 'Fedderwarden', '*Fathrwurth-,*Faþrwurþ-,Fatruwerde [a. 1155],Fedderwarn,Ffedderwurden in Frisia [a. 1420]', 53.5614200, 8.0437100, 'DE', '2011-03-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37646, 'Fedderingen', 'Fedderingen', 'Fedderingen', 54.2833300, 9.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37647, 'Faulbach', 'Faulbach', 'Faul''bakh,Faulbakh,Faulbax,faurubahha,Фаулбах,Фаульбах,Ֆաուլբախ,ファウルバッハ', 49.7852800, 9.4441700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37648, 'Faßberg', 'Fassberg', 'Fasberg,Fassberg,Faßberg,fa si bei ge,Фасберг,法斯贝格', 52.9000000, 10.1666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37649, 'Farven', 'Farven', '', 53.4333300, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37650, 'Farschweiler', 'Farschweiler', '', 49.7166700, 6.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37651, 'Farnstädt', 'Farnstadt', 'Farnshtedt,Farnshtet,Farnstadt,Farnstaedt,Farnstädt,fa er en si te,Фарнштедт,Фарнштет,法尔恩斯特', 51.4333300, 11.5666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37652, 'Farchant', 'Farchant', 'Farchat,Farkhant,Farxant,fa er xian te,farshant,Фархант,Ֆարխանտ,فارشانت,法尔先特', 47.5303600, 11.1115100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37653, 'Fambach', 'Fambach', 'Fambach,Fambakh,fan ba he,Фамбах,凡巴赫', 50.7333300, 10.3666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37654, 'Bad Fallingbostel', 'Bad Fallingbostel', 'Bad Falingbostel,Bad Fallingbostel,Bad Fambossel,Bad-Fallingbostel'',Fallingbostel,ba te fa ling bo si te er,bad falyng bwstl,bad falynghbwstl,Бад Фалингбостел,Бад-Фаллингбостель,باد فالينغبوستل,باد فالینگ بوستل,巴特法灵博斯特尔', 52.8664100, 9.6955800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37655, 'Falkenstein', 'Falkenstein', 'Fal''kenshtajn,Falkenshtajn,Falkensteina,Falkenšteina,Фалкенштајн,Фалькенштайн,فالکن‌اشتاین، زاکسن', 50.4778800, 12.3712900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37656, 'Falkenstein', 'Falkenstein', '', 49.6000000, 7.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37657, 'Falkenstein', 'Falkenstein', 'Fal''kenshtajn,Falkenshtajn,Falkenstein,Фалкенштајн,Фалькенштайн,Ֆալքենշթայն,فالکینسٹین، بواریا', 49.0975000, 12.4880200, 'DE', '2012-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37658, 'Falkensee', 'Falkensee', 'Fal''kenze,Falkensee,Falkenze,fa er ken sai,falknzy,falknzyh,falkynsy,Фалкензе,Фалькензе,Ֆալկենզե,פאלקנזה,فالكنزيه,فالکنزی,فالکینسی,法尔肯塞', 52.5601400, 13.0927000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37659, 'Falkenhain', 'Falkenhain', '', 51.3988800, 12.8708300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37660, 'Falkenhagen', 'Falkenhagen', '', 52.4333300, 14.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37661, 'Falkenfels', 'Falkenfels', 'Fal''kenfel''s,Falkenfels,fa er ken fei er si,falknfls,falkynfyls,Фалкенфелс,Фалькенфельс,فالکنفلس,فالکینفیلس,法尔肯费尔斯', 49.0041500, 12.5948000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37662, 'Falkenberg', 'Falkenberg', 'Berlin-Falkenberg,falkynbyrg,فالکینبیرگ', 52.5680000, 13.5459700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37663, 'Falkenberg', 'Falkenberg', 'Fal''kenberg,Falkenberg,Falkenberg/Mark,Фалкенберг,Фалькенберг,Ֆալկենբերգ,فالکینبیرگ، مارکیسچ-وڈیرلینڈ', 52.8051000, 13.9580400, 'DE', '2017-07-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37664, 'Falkenberg', 'Falkenberg', 'Falkenberg,Falkenburg', 51.5855700, 13.2434700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37665, 'Falkenberg', 'Falkenberg', '', 48.4615400, 12.7304900, 'DE', '2011-07-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37666, 'Falkenau', 'Falkenau', '', 50.8555900, 13.1171800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37667, 'Faid', 'Faid', '', 50.1445400, 7.1195100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37668, 'Fahrenzhausen', 'Fahrenzhausen', 'Fahrenzhausn,Farencgauzen,Farenckhauzen,fa lun ci hao sen,farnts hawzn,Фаренцгаузен,Фаренцхаузен,Ֆարենցհաուզեն,فارنتس هاوزن,فاہرینژوسین,法伦茨豪森', 48.3531700, 11.5552100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37669, 'Fahrenkrug', 'Fahrenkrug', 'Fahrenkrug', 53.9500000, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37670, 'Fahrenbach', 'Fahrenbach', 'Farenbakh,fa lun ba he,farenbahha,Фаренбах,فاہرینباچ,ファーレンバッハ,法伦巴赫', 49.4313900, 9.1505600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37671, 'Fahren', 'Fahren', '', 54.3500000, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37672, 'Fahrdorf', 'Fahrdorf', 'Fardorf,Fartorp,fa er duo fu,Фардорф,فاہرڈورف,法尔多夫', 54.5000000, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37673, 'Fachbach', 'Fachbach', '', 50.3333300, 7.6833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37674, 'Eystrup', 'Eystrup', 'Ajstrup,ai si te lu pu,aisutorupu,Айструп,Ајструп,アイストルプ,艾斯特鲁普', 52.7793500, 9.2131500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37675, 'Eyendorf', 'Eyendorf', '', 53.2000000, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37676, 'Eydelstedt', 'Eydelstedt', 'Ajdel''shtedt,Ajdelshtet,Eidelstee,ai de er si te,Айдельштедт,Ајделштет,艾德尔斯特', 52.6924100, 8.5466800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37677, 'Ewighausen', 'Ewighausen', '', 50.5350000, 7.8277800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37678, 'Evessen', 'Evessen', 'Ehfessen,Evesen,ai fei sen,Евесен,Эфессен,埃费森', 52.1888800, 10.7108100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37679, 'Everswinkel', 'Everswinkel', 'Efersvinkel'',Ehfersvinkel'',Ehversvinkel'',Eversvinkel,Everswinkel,ai fei er si wen ke er,Еверсвинкел,Еферсвінкель,Эверсвинкель,Эферсвинкель,埃费尔斯温克尔', 51.9259500, 7.8469000, 'DE', '2013-05-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37680, 'Everode', 'Everode', 'Ehferode,Everode,ai fei luo de,Евероде,Эфероде,埃费罗德', 51.9500000, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37681, 'Eutingen', 'Eutingen', 'Entingen,Eutingen,Eutingen an der Enz', 48.9124600, 8.7489800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37682, 'Eutin', 'Eutin', 'Eutin,Eutin mit Malente,Oitin,Ojtin,ao yi ting,awytyn,aywtyn,Οϊτίν,Ойтин,Ојтин,أويتين,ائوتین,奥伊廷', 54.1405400, 10.6075100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37683, 'Eußerthal', 'Eusserthal', 'Ojsertal,Ojsertal'',Ojssertal'',ao yi sai er ta er,Ойсерталь,Ойссерталь,Ојсертал,奥伊塞尔塔尔', 49.2500000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37684, 'Eußenheim', 'Eussenheim', 'Eussenheim,Eußenheim,Ojsengajm,Ojsenkhajm,Ojssenkhajm,Oysenhaym,ao yi sen hai mu,Ойсенгайм,Ойсенхайм,Ойссенхайм,Ојсенхајм,Օյսենհայմ,奥伊森海姆', 49.9858900, 9.8089900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37685, 'Euskirchen', 'Euskirchen', 'Euskirchen,OEskerche,Ojskirkhen,ZED,ao yi si ji xing,aywskyrsh,Öskerche,Ойскирхен,Ојскирхен,ائوسکیرش,奧伊斯基興', 50.6605700, 6.7872200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37686, 'Euscheid', 'Euscheid', '', 50.1333300, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37687, 'Eurasburg', 'Eurasburg', 'Eurasberg,Eurasburg', 48.3333300, 11.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37688, 'Eurasburg', 'Eurasburg', '', 47.8538900, 11.4058700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37689, 'Eulgem', 'Eulgem', '', 50.2333300, 7.1666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37690, 'Eulenbis', 'Eulenbis', '', 49.5000000, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37691, 'Eulenberg', 'Eulenberg', '', 50.6060700, 7.4757700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37692, 'Euerdorf', 'Euerdorf', 'Oerdorf,Ojerdorf,Oyerdorf,ao yi er duo fu,Ойердорф,Оєрдорф,Ојердорф,Օյերդորֆ,奥伊尔多夫', 50.1485300, 10.0233100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37693, 'Euerbach', 'Euerbach', 'Oerbakh,Ojerbakh,ao yi ai er ba he,awyrbakh,Ойербах,Оєрбах,Ојербах,اویرباخ,奥伊埃尔巴赫', 50.0619900, 10.1369500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37694, 'Etzleben', 'Etzleben', 'Etzleben', 51.2666700, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37695, 'Etzenricht', 'Etzenricht', '', 49.6333300, 12.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37696, 'Etzelwang', 'Etzelwang', 'Ecelvang,Ehtcel''vang,Etcel''vang,ai ce er wang,Етцельванг,Ецелванг,Этцельванг,Էտցելվանգ,埃策尔旺', 49.5276000, 11.5860300, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37697, 'Etzelsrode', 'Etzelsrode', 'Ecelsrode,Ehtcel''srode,ai ce er si luo de,Ецелсроде,Этцельсроде,埃策尔斯罗德', 51.5000000, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37698, 'Etzbach', 'Etzbach', '', 50.7783100, 7.6880000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37699, 'Ettringen', 'Ettringen', '', 50.3500000, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37700, 'Ettlingen', 'Ettlingen', 'Ediningum,Ehttlingen,Etlingen,Ettlingen,ai te lin gen,atlyngn,aytlynghn,Етлинген,Еттлінген,Эттлинген,إيتلينغن,اتلینگن,埃特林根', 48.9409400, 8.4076300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37701, 'Ettinghausen', 'Ettinghausen', '', 50.5156400, 7.8725200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37702, 'Ettersburg', 'Ettersburg', 'Ehttersburg,Etersburg,ai te er si bao,Етерсбург,Эттерсбург,埃特尔斯堡', 51.0339500, 11.2795000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37703, 'Ettenstatt', 'Ettenstatt', 'Ehttenshtat,Etenstat,Ettenshtatt,Ettenstadt,ai teng si ta te,Етенстат,Еттенштатт,Эттенштат,Էթենշտատ,埃滕斯塔特', 49.0775200, 11.0553800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37704, 'Ettenheim', 'Ettenheim', 'Ehttenkhajm,Etenkhajm,Ettengajm,Ettenheim,ai teng hai mu,atnhaym,aytnhaym,Етенхајм,Еттенгайм,Эттенхайм,إيتنهايم,اتنهایم,埃滕海姆', 48.2569600, 7.8124700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37705, 'Etteldorf', 'Etteldorf', '', 50.0333300, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37706, 'Ettal', 'Ettal', 'Ehttal'',Etal,Ettal,Ettal'',atal,Етал,Етталь,Этталь,Էթալ,اتال', 47.5666700, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37707, 'Etschberg', 'Etschberg', 'Echberg,Ehchberg,ai qi bei ge,Ечберг,Эчберг,埃奇贝格', 49.5166700, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37708, 'Etgert', 'Etgert', '', 49.7788300, 7.0212100, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37709, 'Estorf', 'Estorf', '', 53.5760100, 9.2027100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37710, 'Estorf', 'Estorf', '', 52.5885000, 9.1414700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37711, 'Esthal', 'Esthal', 'Ehstal'',Estal,ai si ta er,Естал,Эсталь,埃斯塔尔', 49.3833300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37712, 'Esterwegen', 'Esterwegen', 'AEaesterweede,Ehstervegen,Estervegen,ai si te er wei gen,Äästerweede,Естервеген,Эстервеген,埃斯特尔韦根', 52.9928800, 7.6332700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37713, 'Estenfeld', 'Estenfeld', 'Ehstenfel''d,Estenfel''d,Estenfeld,ai si teng fei er de,esutenferuto,Естенфелд,Естенфельд,Эстенфельд,Էսթենֆելդ,エステンフェルト,埃斯滕费尔德', 49.8289600, 10.0058800, 'DE', '2012-10-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37714, 'Eßweiler', 'Essweiler', 'Ehsvajler,Essweiler,Esvajler,Eßweiler,ai si wei lei,Есвајлер,Эсвайлер,埃斯韦勒', 49.5582200, 7.5641900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37715, 'Esslingen', 'Esslingen', 'Ehslingen-am-Nekkar,Eslinga,Eslingen,Esslingen,Esslingen am Neckar,Eszlingen,Eszlingen am Neckar,ZEB,Еслинген,Эслинген-ам-Неккар', 48.7396100, 9.3047300, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37716, 'Essingen', 'Essingen', '', 49.2358300, 8.1747200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37717, 'Essingen', 'Essingen', 'Ehssingen,Esingen,Essingen,ai xin gen,esingeni,Есинген,Ессінген,Эссинген,ესინგენი,埃辛根', 48.8085900, 10.0277300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37718, 'Essing', 'Essing', 'Ehssing,Esing,Essing,ai xing,Есинг,Ессінг,Эссинг,Էսինգ,埃兴', 48.9346700, 11.7897200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37719, 'Essenheim', 'Essenheim', 'Ehssenkhajm,Esenkhajm,ai sen hai mu,Есенхајм,Эссенхайм,埃森海姆', 49.9305600, 8.1555600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37720, 'Essenbach', 'Essenbach', 'Ehssenbakh,Esenbakh,Esenbax,Essenbach,Essenbakh,Essenboch,ai sen ba he,asnbakh,Есенбах,Ессенбах,Эссенбах,Էսենբախ,اسنباخ,埃森巴赫', 48.6133200, 12.2183300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37721, 'Essen', 'Essen', 'Ehssen,Esen,Essen,Есен,Эссен', 52.7225800, 7.9371000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37722, 'Essen', 'Essen', 'Asnithi,Assindia,ESS,Ehssen,Esen,Esenas,Esene,Esse,Essen,Gorad Ehsehn,ai sen,aisana,asn,aysn,aysyn,ecan,esen,esena,eseni,essen,xes sein,Ésén,Έσσεν,Горад Эсэн,Есен,Ессен,Эссен,Էսսեն,אסן,إسن,اسن,ایسن,ایسین,एसेन,এসেন,ਐੱਸਨ,எசன்,เอสเซิน,ესენი,エッセン,埃森,에센', 51.4565700, 7.0122800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37723, 'Esselborn', 'Esselborn', '', 49.7152800, 8.1186100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37724, 'Esselbach', 'Esselbach', 'Ehssel''bakh,Eselbakh,Eselbax,Essel''bakh,ai sai er ba he,Еселбах,Ессельбах,Эссельбах,Էսելբախ,埃塞尔巴赫', 49.8552800, 9.5258300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37725, 'Essel', 'Essel', '', 52.6913100, 9.6414100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37726, 'Eßbach', 'Essbach', 'Essbach,Eßbach', 50.5833300, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37727, 'Espenhain', 'Espenhain', 'Ehspenkhajn,Espenhain,Espenhaini vald,Espenkhajn,ai si peng hai en,Еспенхајн,Эспенхайн,埃斯彭海恩', 51.1892600, 12.4788500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37728, 'Espenau', 'Espenau', 'Ehspenau,Espenau,ai si pei nao,esupenau,Еспенау,Эспенау,エスペナウ,埃斯佩瑙', 51.3966400, 9.4702100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37729, 'Espelkamp', 'Espelkamp', 'Ehspel''kamp,Espel''kamp,Espelkaempe,Espelkamp,Espelkämpe,ai si pei er kan pu,asblkamb,asplkampf,esuperukanpu,Еспелкамп,Еспелькамп,Эспелькамп,إسبلكامب,اسپلکامپف,エスペルカンプ,埃斯佩尔坎普', 52.3825100, 8.6212700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37730, 'Eslohe', 'Eslohe', 'Ehsloeh,Esloe,Eslohe,Eslokhe,ai si luo hei,Еслое,Еслохе,Эслоэ,埃斯洛黑', 51.2536900, 8.1694900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37731, 'Eslarn', 'Eslarn', 'Ehslarn,Eslarn,Eszlarn,ai si la en,Есларн,Эсларн,Էսլարն,埃斯拉恩', 49.5834500, 12.5215600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37732, 'Esgrus', 'Esgrus', 'Ehsgrus,Esgrus,Eskeris,ai si ge lu si,Есгрус,Эсгрус,埃斯格鲁斯', 54.7166700, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37733, 'Esens', 'Esens', 'Ehzens,Ezens,ai sen si,asnz  nydrzaksn,Езенс,Эзенс,اسنز، نیدرزاکسن,埃森斯', 53.6486600, 7.6126700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37734, 'Eschweiler', 'Eschweiler', 'Aischwiele,Ascvilare,Ehshvajler,Eschweiler,Eshvajler,Esvayler,Esveilere,Esveileris,Esveilers,Eşvayler,Ešveilere,Ešveileris,Ešveilers,ZEA,ai shi wei lei,ashwaylr,ayshfaylr,eshuvu~aira,eshvaileri,esyubailleo,Ешвайлер,Ешвајлер,Эшвайлер,אשוויילר,إيشفايلر,اشوایلر,ეშვაილერი,エシュヴァイラー,埃施韦勒,에슈바일러', 50.8185400, 6.2718400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37735, 'Eschwege', 'Eschwege', 'Ehshvege,Escevegia,Eschwege,Eshvege,ai shi wei ge,ashfyghh,ashwgh,eshuvu~ege,Ешвеге,Эшвеге,إشفيغه,اشوگه,エシュヴェーゲ,埃施韦格', 51.1838600, 10.0532900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37736, 'Eschlkam', 'Eschlkam', 'Ehshl''kam,Eschlkam,Eshl''kam,Eshlkam,Eslkam,ai shi er ka mu,Ешлкам,Ешлькам,Эшлькам,Էշլկամ,埃施尔卡姆', 49.2988300, 12.9157300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37737, 'Eschfeld', 'Eschfeld', 'Ehshfel''d,Eshfeld,ai shi fei er de,Ешфелд,Эшфельд,埃施费尔德', 50.1166700, 6.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37738, 'Eschershausen', 'Eschershausen', 'Ehsherskhauzen,Esherskhauzen,Raabestadt Eschershausen,ai she er si hao sen,ashrshawzn,ashrzhawzn,esshasuhauzen,Ешерсхаузен,Эшерсхаузен,إشرسهاوزن,اشرزهاوزن,エッシャースハウゼン,埃舍尔斯豪森', 51.9266400, 9.6428200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37739, 'Eschenlohe', 'Eschenlohe', '', 48.0173100, 12.0301200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37740, 'Eschenlohe', 'Eschenlohe', 'Ehshenloeh,Eschenlohe,Esenloe,Eshenloe,Eshenlokhe,ai shen luo hei,ashnlwhh,Ешенлое,Ешенлохе,Эшенлоэ,Էշենլոե,اشنلوهه,埃申洛黑', 47.6000000, 11.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37741, 'Eschenbergen', 'Eschenbergen', 'Ehshenbergen,Eschenbergen,Eshenbergen,ai shen bei er gen,Ешенберген,Эшенберген,埃申贝尔根', 51.0268100, 10.7593200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37742, 'Eschenbach', 'Eschenbach', '', 48.6526400, 9.6703700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37743, 'Eschelbronn', 'Eschelbronn', 'Ehshel''bronn,Eschelbronn,Eschlbrunn,Eselmpron,Eshel''bronn,Eshelbron,ai she er bu long,essheruburon,Έσελμπρον,Ешелброн,Ешельбронн,Эшельбронн,エッシェルブロン,埃舍尔布龙', 49.3194400, 8.8652800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37744, 'Eschede', 'Eschede', 'Askithi,Ehshede,Eshede,ai she de,Ешеде,Эшеде,埃舍德', 52.7349400, 10.2354000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37745, 'Escheburg', 'Escheburg', 'Ehsheburg,Escheburg,Esheburg,ai she bao,Ешебург,Эшебург,埃舍堡', 53.4666700, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37746, 'Esche', 'Esche', '', 52.5333300, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37747, 'Eschborn', 'Eschborn', 'Ehshborn,Eschborn,Eshborn,ai shi bo en,ashbwrn,eshuborun,Ешборн,Эшборн,إشبورن,اشبورن,エシュボルン,埃施博恩', 50.1432800, 8.5711100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37748, 'Eschbach', 'Eschbach', '', 50.2139300, 7.7271700, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37749, 'Eschbach', 'Eschbach', '', 49.1744400, 8.0191700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37750, 'Eschbach', 'Eschbach', '', 47.8910200, 7.6554100, 'DE', '2017-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37751, 'Eschau', 'Eschau', 'Ehshau,Esau,Eschau,Eshau,ai shao,esshau,Ешау,Эшау,Էշաու,エッシャウ,埃绍', 49.8188900, 9.2592000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37752, 'Eschach', 'Eschach', '', 48.8883200, 9.8699900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37753, 'Esch', 'Esch', '', 50.3666700, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37754, 'Esch', 'Esch', '', 49.9000000, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37755, 'Erzhausen', 'Erzhausen', 'Ehrckhauzen,Ercgauzen,Erckhauzen,ai er ci hao sen,erutsuhauzen,Ерцгаузен,Ерцхаузен,Эрцхаузен,エルツハウゼン,埃尔茨豪森', 49.9552800, 8.6475000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37756, 'Erzenhausen', 'Erzenhausen', '', 49.5000000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37757, 'Erxleben', 'Erxleben', '', 52.2181200, 11.2424500, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37758, 'Erwitte', 'Erwitte', 'Arwitti,Ehrvitte,Eritonon,Ervite,Ervitte,Erwitte,ai er wei te,arfyth,arwyth,Ėritonon,Ервите,Ервітте,Эрвитте,إرفيته,ارویته,埃尔维特', 51.6127000, 8.3384000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37759, 'Ertingen', 'Ertingen', 'Ehrtingen,Ertingen,ai er ting gen,Ертинген,Ертінген,Эртинген,Էրտինգեն,ერტინგენი,埃尔廷根', 48.1000000, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37760, 'Ersingen', 'Ersingen', '', 48.2926000, 9.8551000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37761, 'Ershausen', 'Ershausen', 'Erhausen,Erschuesen,Erschüsen', 51.2570800, 10.1613200, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37762, 'Ersfeld', 'Ersfeld', 'Ehrsfel''d,Ersfeld,Ersfelt,Ersfield,ai er si fei er de,arsfld,Ерсфелд,Эрсфельд,ارسفلد,埃尔斯费尔德', 50.7000000, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37763, 'Erpolzheim', 'Erpolzheim', 'AEaebelsm,Ehrpol''ckhajm,Erpolckhajm,ai er bo er ci hai mu,Ääbelsm,Ерполцхајм,Эрпольцхайм,埃尔波尔茨海姆', 49.4891700, 8.2247200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37764, 'Erpel', 'Erpel', 'Ehrpel'',Erpel,ai er pei er,Ерпел,Эрпель,埃尔佩尔', 50.5833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37765, 'Erolzheim', 'Erolzheim', 'Ehrol''ckhajm,Erol''cgajm,Erolckhajm,Erolzheim,ai luo er ci hai mu,eroltshaimi,Еролцхајм,Ерольцгайм,Эрольцхайм,Էրոլցհայմ,ეროლცჰაიმი,埃罗尔茨海姆', 48.0900100, 10.0730000, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37766, 'Ernzen', 'Ernzen', '', 49.8427000, 6.4244200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37767, 'Ernstroda', 'Ernstroda', 'Ernstroda', 50.8648400, 10.6205600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37768, 'Ernst', 'Ernst', '', 50.1500000, 7.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37769, 'Ernsgaden', 'Ernsgaden', 'Ehrnsgaden,Ernsgaden,Ernsgodn,ai er en si jia deng,arnsgadn,Ернсгаден,Эрнсгаден,Էրնսգադեն,ارنسگادن,埃尔恩斯加登', 48.7333300, 11.5833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37770, 'Erndtebrück', 'Erndtebrueck', 'Ehrndtebrjuk,Ernatebruck,Erndtebrik,Erndtebrjuk,Erndtebruck,Erndtebrueck,Erndtebrück,ai er en te bu lu ke,Ерндтебрик,Ерндтебрюк,Эрндтебрюк,埃尔恩特布吕克', 50.9892700, 8.2528800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37771, 'Ermlitz', 'Ermlitz', '', 51.3918200, 12.1594600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37772, 'Ermershausen', 'Ermershausen', 'Ehrmerskhauzen,Ermersgauzen,Ermershauzen,Ermerskhauzen,ai er mei er si hao sen,Ермерсгаузен,Ермерсхаузен,Эрмерсхаузен,Էրմերսհաուզեն,埃尔梅尔斯豪森', 50.2084600, 10.6257600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37773, 'Erligheim', 'Erligheim', 'Ehrligkhajm,Erligajm,Erligkhajm,ai er li ge hai mu,arlyghaym,Ерлигхајм,Ерлігайм,Эрлигхайм,ارلیگهایم,埃尔利格海姆', 49.0225000, 9.0972200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37774, 'Erlensee', 'Erlensee', 'AEaelaensee,Ehrlenze,Erlenze,ai er lun sai,erurenze,Äälänsee,Ерлензе,Эрлензе,エルレンゼー,埃尔伦塞', 50.1630400, 8.9782300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37775, 'Erlenmoos', 'Erlenmoos', '', 48.0653000, 9.9756700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37776, 'Erlenbach am Main', 'Erlenbach am Main', 'Ehrlenbakh-na-Majne,Erlenbach,Erlenbach am Main,Erlenbach uber Klingenberg,Erlenbach über Klingenberg,Erlenbakh na Majni,Erlenbakh-am-Majn,Mayni Erlenbax,arlnbakh am mayn,mei yin he pan ai er lun ba he,Ерленбах на Мајни,Ерленбах-ам-Майн,Эрленбах-на-Майне,Մայնի Էրլենբախ,إرلنباخ آم ماين,ارلنباخ آم ماین,エアレンバッハ・アム・マイン,美因河畔埃尔伦巴赫', 49.8034100, 9.1631100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37777, 'Erlenbach', 'Erlenbach', '', 49.9785700, 9.6445900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37778, 'Erlenbach', 'Erlenbach', 'Erlenbach', 49.1725000, 9.2683300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37779, 'Erlbach', 'Erlbach', 'Erlbach,Markt Erlbach', 50.3166700, 12.3666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37780, 'Erlbach', 'Erlbach', '', 48.3000000, 12.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37781, 'Erlau', 'Erlau', '', 51.0093800, 12.9454900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37782, 'Erlangen', 'Erlangen', 'Ehrlangen,Erlanga,Erlangen,Erlangenas,Erlangene,Erlanken,Gorad Ehrlangen,ZCZ,ai er lan gen,ai er lang gen,arlangn,arlnjn,arlynjn,earangen,eleullang-gen,Έρλαγκεν,Горад Эрланген,Ерланген,Эрланген,ארלנגן,ارلانگن,ارلنجن,ارلینجن,エアランゲン,埃尔朗根,埃爾蘭根,에를랑겐', 49.5909900, 11.0078300, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37783, 'Erlabrunn', 'Erlabrunn', 'Ehrlabrunn,Erlabrun,Erlabrunn,ai er la bu lun,earaburun,Ерлабрун,Ерлабрунн,Эрлабрунн,Էրլաբրուն,エアラブルン,埃尔拉布伦', 49.8597200, 9.8441700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37784, 'Erkrath', 'Erkrath', 'Ehrkrat,Erkrat,Erkrath,ai er ke la te,arkrat,Еркрат,Эркрат,إركرات,ارکرات,埃尔克拉特', 51.2223500, 6.9083100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37785, 'Erkner', 'Erkner', 'Ehrkner,Erkner,ai er ke na,arknr,Еркнер,Эркнер,Էրկներ,إركنر,ارکنر,埃尔克纳', 52.4200000, 13.7543700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37786, 'Erkheim', 'Erkheim', 'Ehrkkhajm,Erkgajm,Erkhaym,Erkheim,Erkkhajm,ai er ke hai mu,Еркгайм,Еркхајм,Эркхайм,Էրկհայմ,埃尔克海姆', 48.0373000, 10.3357000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37787, 'Erkerode', 'Erkerode', 'Ehrkerode,Erkerode,ai er ke luo de,Еркероде,Эркероде,埃尔克罗德', 52.2048500, 10.7098200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37788, 'Erkenbrechtsweiler', 'Erkenbrechtsweiler', 'Ehrkenbrekhtsvajler,Erkenbrekhtsvajler,Erkenbrextsvayler,ai ken bu lei xi ci wei lei,Еркенбрехтсвайлер,Еркенбрехтсвајлер,Эркенбрехтсвайлер,Էրկենբրեխտսվայլեր,埃肯布雷希茨韦勒', 48.5565600, 9.4321100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37789, 'Erkelenz', 'Erkelenz', 'Ehrkelenc,Erkelenc,Erkelens,Erkelenz,ai er ke lun ci,arklnts,arklnz,Еркеленц,Эркеленц,إركلنتس,ارکلنز,埃尔克伦茨', 51.0794700, 6.3153100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37790, 'Eriskirch', 'Eriskirch', 'Ehriskirkh,Eriskirkh,Eriskirx,ai li si ji er xi,Ерискирх,Еріскірх,Эрискирх,Էրիսկիրխ,ერისკირხი,埃里斯基尔希', 47.6247900, 9.5419700, 'DE', '2012-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37791, 'Ering', 'Ering', 'Ehring,Ering,Fring,ai ling,aryng,Еринг,Ерінг,Эринг,Էրինգ,ارینگ,埃灵', 48.2992100, 13.1502900, 'DE', '2011-06-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37792, 'Erharting', 'Erharting', 'Ehrkharting,Erarting,Erkharting,ai la er ting,arhartyng,Ерартінг,Ерхартинг,Эрхартинг,Էրհարթինգ,ارهارتینگ,埃拉尔廷', 48.2833300, 12.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37793, 'Ergoldsbach', 'Ergoldsbach', 'Ehrgol''dsbakh,Erblsbach,Ergol''dsbakh,Ergoldsbach,Ergoldsbakh,Ergoldsbax,Erweschbo,ai er ge er ci ba he,argwldsbakh,Ерголдсбах,Ергольдсбах,Эргольдсбах,Էրգոլդսբախ,ارگولدسباخ,埃尔戈尔茨巴赫', 48.6926300, 12.2044200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37794, 'Ergolding', 'Ergolding', 'Ehrgol''ding,Ergol''ding,Ergolding,ai ge er ding,argwldyng,Ерголдинг,Ергольдінг,Эргольдинг,Էրգոլդինգ,ارگولدینگ,埃戈尔丁', 48.5765400, 12.1710200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37795, 'Ergeshausen', 'Ergeshausen', '', 50.2721200, 7.9425100, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37796, 'Ergersheim', 'Ergersheim', '', 49.5166700, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37797, 'Erfweiler', 'Erfweiler', '', 49.1571200, 7.8123100, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37798, 'Erfurt', 'Erfurt', 'ERF,Ehrfurt,Erfesfurt [a. 1144],Erfordia,Erfurt,Erfurtas,Erfurte,Erfurti,Erfurto,Erpesforth [a. 1133],Erphesfurt [a. 742],Erphord [a. 1210],Erphourte,Erpisfurt,Erpsfordia [a. 1222],Erpsfurd [a. 1196],Gorad Ehrfurt,Jarobrod,ai er fu te,arfwrt,eafuruto,eleupuleuteu,eraphurta,Érfurt,Ερφούρτη,Горад Эрфурт,Ерфурт,Эрфурт,ארפורט,ערפורט,إرفورت,ارفرٹ,ارفورت,एरफुर्ट,แอร์ฟูร์ท,ერფურტი,エアフルト,埃尔福特,에르푸르트', 50.9787000, 11.0328300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37799, 'Erftstadt', 'Erftstadt', 'Ehrftshtadt,Erftshtadt,Erftshtat,Erftstadt,ai er fu te shi ta te,arftshtat,Ерфтштадт,Ерфтштат,Эрфтштадт,إرفتشتات,ارفت‌اشتات,埃尔夫特施塔特', 50.8148100, 6.7938700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37800, 'Erfde', 'Erfde', 'Erfde', 54.3000000, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37801, 'Eresing', 'Eresing', 'Ehrezing,Erezing,ai lei xing,arzyng,erejingu,Ерезинг,Ерезінг,Эрезинг,Էրեզինգ,ارزینگ,エレージング,埃雷兴', 48.0870000, 11.0238800, 'DE', '2012-03-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37802, 'Erdweg', 'Erdweg', 'Ehrdveg,Erdveg,ai er de wei ge,ardwg,Ердвег,Эрдвег,Էրդվեգ,اردوگ,埃尔德韦格', 48.3318000, 11.3033900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37803, 'Erdmannhausen', 'Erdmannhausen', 'Ehrdmannkhauzen,Erdmankhauzen,Erdmanngauzen,ai er de man hao sen,ardmanhawzn,Ердманнгаузен,Ердманхаузен,Эрдманнхаузен,اردمانهاوزن,埃尔德曼豪森', 48.9425600, 9.2961500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37804, 'Erding', 'Erding', 'Aerding,Arrdeng,Ehrding,Erding,Erding As,Erdingas,ai er ding,ardyng,Ėrdingas,Ердинг,Эрдинг,اردینگ,ارڈنگ,埃尔丁', 48.3060300, 11.9068600, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37805, 'Erdesbach', 'Erdesbach', 'Ehrdesbakh,Erdesbakh,ai er de si ba he,Ердесбах,Эрдесбах,埃尔德斯巴赫', 49.5742800, 7.4421500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37806, 'Erden', 'Erden', 'Ehrden,Erden,ai er deng,Ерден,Эрден,埃尔登', 49.9833300, 7.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37807, 'Erbes-Büdesheim', 'Erbes-Budesheim', 'Erbes-Budesheim,Erbes-Buedesheim,Erbes-Büdesheim', 49.7544400, 8.0313900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37808, 'Erbenhausen', 'Erbenhausen', '', 50.5666700, 10.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37809, 'Erbendorf', 'Erbendorf', 'Ehrbendorf,Erbendorf,Ermdoaf,ai er ben duo fu,arbndwrf,Ербендорф,Эрбендорф,Էրբենդորֆ,إربندورف,اربندورف,ایربنڈورف,埃尔本多夫', 49.8398300, 12.0459300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37810, 'Erbach', 'Erbach', '', 50.0333300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37811, 'Erbach', 'Erbach', 'Ehrbakh,Erbach,Erbach im Odenwald,Erbakh,Erbakh-im-Odenval''d,Gorad Ehrbakh,arbakh am awdnfald,arbakh dr awdnwald,eabahha,Горад Эрбах,Ербах,Ербах-ім-Оденвальд,Эрбах,إرباخ إم أودنفالد,ارباخ در اودنوالد,エアバッハ', 49.6614800, 8.9940200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37812, 'Erbach', 'Erbach', '', 48.3284100, 9.8875200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37813, 'Eppstein', 'Eppstein', 'Ehpshtajn,Eppshtajn,Eppstein,Epshhajn,Epshtajn,abshtayn,ai pu si tai yin,eppushutain,Еппштайн,Епштајн,Епщайн,Эпштайн,إبشتاين,اپ‌اشتاین,エップシュタイン,埃普斯泰因', 50.1427700, 8.3923100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37814, 'Eppishausen', 'Eppishausen', 'Ehppiskhauzen,Episkhauzen,Eppisgauzen,ai pi si hao sen,Еписхаузен,Еппісгаузен,Эпписхаузен,Էփիսհաուզեն,埃皮斯豪森', 48.1666700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37815, 'Eppingen', 'Eppingen', 'Ehppingen,Epingen,Epingenas,Eppingen,abynghn,ai ping gen,apyngn,eppingen,Епинген,Еппінген,Эппинген,إبينغن,اپینگن,ეპინგენი,エッピンゲン,埃平根', 49.1364500, 8.9122900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37816, 'Eppertshausen', 'Eppertshausen', 'Ehppertskhauzen,Epertskhauzen,Eppertsgauzen,Eppertshausen,ai pei er ci hao sen,eppatsuhauzen,Епертсхаузен,Еппертсгаузен,Эппертсхаузен,エッパーツハウゼン,埃佩尔茨豪森', 49.9505600, 8.8538900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37817, 'Eppenschlag', 'Eppenschlag', 'Ehppenshlag,Epenshlag,Eppenshlag,ai peng shi la ge,apnshlag,Епеншлаг,Еппеншлаг,Эппеншлаг,Էփենշլագ,اپنشلاگ,埃彭施拉格', 48.8893800, 13.2998900, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37818, 'Eppenrod', 'Eppenrod', '', 50.4047200, 7.9297200, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37819, 'Eppendorf', 'Eppendorf', '', 50.8000000, 13.2333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37820, 'Eppenbrunn', 'Eppenbrunn', 'Ehppenbrun,Epenbrun,ai peng bu lun,Епенбрун,Эппенбрун,埃彭布伦', 49.1166700, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37821, 'Eppenberg', 'Eppenberg', '', 50.2500000, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37822, 'Eppelsheim', 'Eppelsheim', '', 49.7055600, 8.1652800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37823, 'Eppelheim', 'Eppelheim', 'Ehppel''khajm,Epelkhajm,Eppel''gajm,Eppelheim,ablhaym,ai pei er hai mu,aplhaym,epperuhaimu,Епелхајм,Еппельгайм,Эппельхайм,إبلهايم,اپلهایم,エッペルハイム,埃佩尔海姆', 49.4019000, 8.6364400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37824, 'Eppelborn', 'Eppelborn', 'Ehppel''born,Epelborn,Eppel''born,Eppelborn,ai po er bo en,Епелборн,Еппельборн,Эппельборн,埃珀尔博恩', 49.4000000, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37825, 'Epfendorf', 'Epfendorf', 'Ehpfendorf,Epfendorf,ai pu fen duo fu,Епфендорф,Эпфендорф,埃普芬多夫', 48.2500000, 8.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37826, 'Epfenbach', 'Epfenbach', 'Ehpfenbakh,Epfenbach,Epfenbakh,ai pu fen ba he,epufenbahha,Епфенбах,Эпфенбах,エプフェンバッハ,埃普芬巴赫', 49.3391700, 8.9077800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37827, 'Epenwöhrden', 'Epenwoehrden', 'Epenwohrden,Epenwöhrden', 54.1102500, 9.0530400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37828, 'Enzklösterle', 'Enzkloesterle', 'Ehnckljosterle,Encklesterle,Enzklostelte,Enzklosterle,Enzklösterle,en ci ke lei si te er lai,Енцклестерле,Энцклёстерле,Էնցկլյոսթերլե,恩茨克勒斯特尔莱', 48.6663800, 8.4708300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37829, 'Enzen', 'Enzen', '', 49.9166700, 6.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37830, 'Enspel', 'Enspel', '', 50.6166700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37831, 'Ensheim', 'Ensheim', 'Ensheim', 49.8063900, 8.1155600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37832, 'Ensdorf', 'Ensdorf', '', 49.3406200, 11.9358700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37833, 'Ensdorf', 'Ensdorf', '', 49.3000000, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37834, 'Ensch', 'Ensch', '', 49.8333300, 6.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37835, 'Ennigerloh', 'Ennigerloh', 'Aningeroloh,Aningerolôh,Ehnnigerlo,Enigerlokh,Ennigerlo,Ennigerloh,ai ni ge er luo,anyghrlwh,anygrlwh,Енигерлох,Еннігерло,Эннигерло,إنيغرلوه,انیگرلوه,埃尼格尔洛', 51.8384300, 8.0309300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37836, 'Ennetach', 'Ennetach', '', 48.0523800, 9.3201000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37837, 'Ennepetal', 'Ennepetal', 'Ehnnepetal'',Enepetal,Iaempedal,Iämpedal,ai nei pei ta er,anybhtal,anyptal,Енепетал,Эннепеталь,إنيبهتال,انیپتال,埃内佩塔尔', 51.2984800, 7.3629000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37838, 'Enkirch', 'Enkirch', 'Ehnkirkh,Enkirkh,en ji er xi,Енкирх,Энкирх,恩基尔希', 49.9843400, 7.1299700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37839, 'Enkenbach-Alsenborn', 'Enkenbach-Alsenborn', '', 49.4833300, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37840, 'Eningen unter Achalm', 'Eningen unter Achalm', 'Ehningen-unter-Akhal''m,Eningen,Eningen pod Akhalmom,a ha er mu shan xia ai ning gen,Енинген под Ахалмом,Енінген,Энинген-унтер-Ахальм,阿哈尔姆山下埃宁根', 48.4868600, 9.2594600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37841, 'Sankt Englmar', 'Sankt Englmar', 'Englmar,Sankt Englmar,Sankt-Ehngl''mar,Zankt-Engl''mar,sheng en er ma er,zankt anglmar,Занкт-Енгльмар,Санкт Енглмар,Санкт-Энгльмар,زانکت انگلمار,圣恩尔马尔', 49.0029800, 12.8265800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37842, 'Enger', 'Enger', 'Angeri,Angėri,Ehnger,Enger,Engeri,enga,Ėngėri,Енгер,Энгер,エンガー', 52.1406300, 8.5577200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37843, 'Engen', 'Engen', 'Ehngen,Engen,angn  badn-wwrtmbrg,en gen,Енген,Энген,انگن، بادن-وورتمبرگ,恩根', 47.8553400, 8.7734200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37844, 'Engelthal', 'Engelthal', 'Ehngel''tal'',Engel''tal'',Engeltal,en ge er ta er,Енгелтал,Енгельталь,Энгельталь,Էնգելթալ,恩格尔塔尔', 49.4718100, 11.3994300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37845, 'Engelstadt', 'Engelstadt', '', 49.9041700, 8.0652800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37846, 'Engelskirchen', 'Engelskirchen', 'Ehngel''skirkhen,Engel''skirkhen,Engelskirchen,Engelskirkhen,en ge er si ji xing,Енгелскирхен,Енгельскірхен,Энгельскирхен,恩格尔斯基兴', 50.9885400, 7.4139100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37847, 'Engelschoff', 'Engelschoff', '', 53.6666700, 9.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37848, 'Engelsbrand', 'Engelsbrand', 'Ehngel''sbrand,Engel''sbrand,Engelsbrand,en ge er si bu lan de,Енгелсбранд,Енгельсбранд,Энгельсбранд,Էնգելսբրանդ,恩格尔斯布兰德', 48.8333300, 8.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37849, 'Engelsberg', 'Engelsberg', '', 48.1163100, 12.5426700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37850, 'Engeln', 'Engeln', '', 52.7936300, 8.9181500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37851, 'Engden', 'Engden', 'Ehngden,Engden,en deng,Енгден,Энгден,恩登', 52.4000000, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37852, 'Endschütz', 'Endschutz', '', 50.7869500, 12.1363100, 'DE', '2015-01-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37853, 'Bad Endorf', 'Bad Endorf', 'Bad Endorf,Bad Endorf in Oberbayern,Bad-Ehndorf,Bad-Endorf,Endorf,Endorf in Oberbayern,ba te en duo fu,bad andwrf,Бад Ендорф,Бад-Ендорф,Бад-Эндорф,Բադ Էնդորֆ,باد اندورف,巴特恩多夫', 47.9090100, 12.2979500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37854, 'Endlichhofen', 'Endlichhofen', '', 50.2018500, 7.8181500, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37855, 'Endingen', 'Endingen', 'Endingen', 48.1422100, 7.7004900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37856, 'Bad Endbach', 'Bad Endbach', 'Bad Endbach,Bad Endbakh,Bad-Ehndbakh,Bad-Endbakh,Endbach,ba te en de ba he,Бад Ендбах,Бад-Ендбах,Бад-Эндбах,バート・エントバッハ,巴特恩德巴赫', 50.7500000, 8.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37857, 'Emtmannsberg', 'Emtmannsberg', 'Ehmtmansberg,Emtmannsberg,Emtmansberg,ai mu te man si bei ge,emutomansuberuku,Емтманнсберг,Емтмансберг,Эмтмансберг,Էմտմանսբերգ,エムトマンスベルク,埃姆特曼斯贝格', 49.8923100, 11.6446600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37858, 'Emtinghausen', 'Emtinghausen', 'Ehmtingkhauzen,Emhusen,Emtingkhauzen,ai mu ting hao sen,emutinguhauzen,Емтингхаузен,Эмтингхаузен,エムティングハウゼン,埃姆廷豪森', 52.9333300, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37859, 'Emstek', 'Emstek', 'Ehmstek,Emstek,ai mu si te ke,Емстек,Эмстек,埃姆斯特克', 52.8333300, 8.1500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37860, 'Emskirchen', 'Emskirchen', 'Ehmskirkhen,Emskirchen,Emskirkhen,Emskirxen,ai mu si ji xing,Емскирхен,Емскірхен,Эмскирхен,Էմսկիրխեն,埃姆斯基兴', 49.5528200, 10.7127800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37861, 'Emsdetten', 'Emsdetten', 'Ehmsdetten,Emsdeten,Emsdetten,ai mu si dai teng,amstdn,amzdtn,Емсдетен,Емсдеттен,Эмсдеттен,إمستدن,امزدتن,埃姆斯代滕', 52.1734000, 7.5278100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37862, 'Emsbüren', 'Emsburen', 'Ehmsbjuren,Emsbiren,Emsbueren,Emsburen,Emsbüren,ai mu si bi lun,Емсбирен,Эмсбюрен,埃姆斯比伦', 52.4000000, 7.3000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37863, 'Empfingen', 'Empfingen', 'Ehmpfingen,Empfingen,en pu fen gen,Емпфинген,Емпфінген,Эмпфинген,Էմպֆինգեն,恩普芬根', 48.3925800, 8.7103600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37864, 'Empfertshausen', 'Empfertshausen', 'Ehmpfertskhauzen,Empfertshausen,Empfertskhauzen,en pu fei er ci hao sen,Емпфертсхаузен,Эмпфертсхаузен,恩普费尔茨豪森', 50.6666700, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37865, 'Emmerzhausen', 'Emmerzhausen', 'Ehmmerckhauzen,Emerckhauzen,ai mei er ci hao sen,amrzhawsn,Емерцхаузен,Эммерцхаузен,امرزهاوسن,埃梅尔茨豪森', 50.6997200, 8.0345100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37866, 'Emmering', 'Emmering', '', 48.1833300, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37867, 'Emmering', 'Emmering', '', 47.9976200, 12.0564200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37868, 'Emmerich', 'Emmerich', 'Ehmmerikh,Emmerich,QEX,Stadt Emmerich,Эммерих', 51.8393300, 6.2479200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37869, 'Emmendorf', 'Emmendorf', 'Ehmmendorf,Emendorf,ai men duo fu,Емендорф,Эммендорф,埃门多夫', 53.0202200, 10.5646000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37870, 'Emmendingen', 'Emmendingen', '', 48.1209600, 7.8535900, 'DE', '2017-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37871, 'Emmelshausen', 'Emmelshausen', 'Ehmmel''skhauzen,Emelskhauzen,ai mei er si hao sen,amlshawzn,amlzhawzn,enmerusuhauzen,Емелсхаузен,Эммельсхаузен,إملسهاوزن,املزهاوزن,エンメルスハウゼン,埃梅尔斯豪森', 50.1548400, 7.5518500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37872, 'Emmelbaum', 'Emmelbaum', '', 50.0500000, 6.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37873, 'Emlichheim', 'Emlichheim', 'Ehmlikhgajm,Ehmlikhkhajm,Emlikhkhajm,Emmelkamp,ai mu li xia yi mu,Емлиххајм,Эмлихгайм,Эмлиххайм,埃姆利夏伊姆', 52.6166700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37874, 'Emleben', 'Emleben', 'Ehmleben,Emleben,ai mu lai ben,Емлебен,Эмлебен,埃姆莱本', 50.8941100, 10.7030000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37875, 'Emkendorf', 'Emkendorf', 'Ehmkendorf,Emkendorf,ai mu ken duo fu,Емкендорф,Эмкендорф,埃姆肯多夫', 54.2666700, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37876, 'Emersacker', 'Emersacker', 'Ehmerzakker,Emerzaker,Emerzakker,ai mei er sa ke er,Емерзакер,Емерзаккер,Эмерзаккер,Էմերզաքեր,埃梅尔萨克尔', 48.4896500, 10.6738000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37877, 'Emerkingen', 'Emerkingen', 'Ehmerkingen,Emerkingen,ai mei er jin gen,Емеркинген,Емеркінген,Эмеркинген,Էմերկինգեն,ემერკინგენი,埃梅尔金根', 48.2119200, 9.6564700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37878, 'Emeringen', 'Emeringen', '', 48.2338800, 9.5178100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37879, 'Emden', 'Emden', 'Amuthon,EME,Ehmden,Emda,Emden,Gorad Ehmdehn,Oamde,ai mu deng,amdn,emden,emtan,emuden,Āmūthon,Горад Эмдэн,Емден,Эмден,אמדן,إمدن,امدن,எம்டன்,エムデン,埃姆登,엠덴', 53.3674500, 7.2077800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37880, 'Embühren', 'Embuhren', 'Embuhren,Embühren', 54.1666700, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37881, 'Embsen', 'Embsen', 'Ehmbzen,Embden,Embsen,Embzen,en bu sen,Ембзен,Эмбзен,恩布森', 53.1760600, 10.3462500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37882, 'Elzweiler', 'Elzweiler', 'Ehl''cvajler,Elcvajler,ai er ci wei lei,Елцвајлер,Эльцвайлер,埃尔茨韦勒', 49.5833300, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37883, 'Elze', 'Elze', 'Elze,Elze (Wedemark),Wedemark-Elze', 52.5815700, 9.7349200, 'DE', '2012-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37884, 'Elze', 'Elze', 'Ehl''ce,Elce,ai er ce,altsh,Елце,Эльце,إلتسه,التسه,埃尔策', 52.1226300, 9.7359500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37885, 'Elzach', 'Elzach', 'Ehl''cakh,El''cakh,Elcakh,Elsax,Elzach,ai er cha he,altsakh,Елцах,Ельцах,Эльцах,Էլցախ,إلتساخ,التساخ,埃尔察赫', 48.1724700, 8.0699200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37886, 'Elz', 'Elz', 'Ehl''c,El''c,Elc,Elz,ai er ci,Елц,Ельц,Эльц,埃尔茨', 50.4166700, 8.0333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37887, 'Elxleben', 'Elxleben', '', 51.0500000, 10.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37888, 'Elxleben', 'Elxleben', '', 50.8666700, 11.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37889, 'Eltville', 'Eltville', 'Eltville', 50.0285800, 8.1175400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37890, 'Eltmann', 'Eltmann', 'Ehl''tman,El''tmann,Eltman,Eltmann,ai er te man,altman,altmn,Елтман,Ельтманн,Эльтман,Էլթման,إلتمان,التمن,ایلٹمان,埃尔特曼', 49.9714800, 10.6671200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37891, 'Elterlein', 'Elterlein', 'Ehl''terlajn,Elterlajn,Elterlein,Elterleine,ai er te er lai yin,altrlayn,Елтерлајн,Эльтерлайн,إلترلاين,الترلاین,埃尔特尔莱因', 50.5766300, 12.8683600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37892, 'Elstra', 'Elstra', 'Ehl''stra,Elstra,Elstra/Halstrow,Elstra/Halštrow,Halstrov,Halstrow,Halštrov,Halštrow,ai er si te la,alshtra,Елстра,Эльстра,إلشترا,الشترا,埃尔斯特拉', 51.2217200, 14.1320100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37893, 'Elsterwerda', 'Elsterwerda', 'Ehl''sterverda,Elsterverda,Elsterwerda,Esterwerda,Wikow,ai er si te wei da,alshtrwrda,alstrfyrda,Елстерверда,Эльстерверда,Էլսթերվերդա,إلسترفيردا,الشتروردا,埃尔斯特韦达', 51.4604300, 13.5200100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37894, 'Elstertrebnitz', 'Elstertrebnitz', 'Ehl''stertrebnic,Elstertrebnic,Elstertrebnitz,Elstertrebnitzi vald,ai er si te er te lei bu ni ci,Елстертребниц,Эльстертребниц,埃尔斯特尔特雷布尼茨', 51.1500000, 12.2333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37895, 'Elsterberg', 'Elsterberg', 'Ehl''sterberg,Elsterberg,Elsterberga,ai er si te bei ge,alshtrbrg,alstrbrgh,Елстерберг,Эльстерберг,إلستربرغ,الشتربرگ,埃尔斯特贝格', 50.6084100, 12.1678700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37896, 'Elster', 'Elster', '', 51.8301100, 12.8242400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37897, 'Elsnig', 'Elsnig', 'Ehl''snig,El''snig,Elsnig,ai er si ni xi,Елсниг,Ельсніг,Эльсниг,埃尔斯尼希', 51.6102400, 12.9283300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37898, 'Elskop', 'Elskop', 'Elskop', 53.8166700, 9.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37899, 'Elsfleth', 'Elsfleth', 'Ehl''sflet,Elsflet,ai er si fu lai te,alzfls,Елсфлет,Эльсфлет,الزفلس,埃尔斯夫莱特', 53.2374800, 8.4566400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37900, 'Elsenfeld', 'Elsenfeld', 'Ehl''zenfel''d,El''zenfel''d,Elsenfeld,Elzenfeld,ai er sen fei er de,eruzenferuto,Елзенфелд,Ельзенфельд,Эльзенфельд,Էլզենֆելդ,エルゼンフェルト,埃尔森费尔德', 49.8428900, 9.1635500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37901, 'Elsendorf', 'Elsendorf', '', 48.7075700, 11.8098200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37902, 'Elsdorf-Westermühlen', 'Elsdorf-Westermuhlen', 'Elsdorf-Westermuehlen,Elsdorf-Westermuhlen,Elsdorf-Westermühlen', 54.2666700, 9.5166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37903, 'Elsdorf', 'Elsdorf', '', 53.2412000, 9.3505600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37904, 'Elsdorf', 'Elsdorf', '', 50.9373900, 6.5682800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37905, 'Elpersbüttel', 'Elpersbuttel', 'Ehl''persbjuttel'',Elpersbitel,Elpersbuttel,Elpersbüttel,ai er pei er si bi te er,Елперсбител,Эльперсбюттель,埃尔佩尔斯比特尔', 54.0724800, 9.0467300, 'DE', '2011-09-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37906, 'Elmstein', 'Elmstein', 'Ehl''mshtajn,Elmshtajn,Elmstein,ai er mu si tai yin,Елмштајн,Эльмштайн,埃尔姆斯泰因', 49.3666700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37907, 'Elmshorn', 'Elmshorn', 'Ehl''mskhorn,Elmshorn,Elmshornas,Elmskhorn,ai er mu si huo en,almshwrn,almzhwrn,Елмсхорн,Эльмсхорн,אלמסהורן,إلمسهورن,المزهورن,埃尔姆斯霍恩', 53.7539600, 9.6533900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37908, 'Elmlohe', 'Elmlohe', '', 53.5867000, 8.7425400, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37909, 'Elmenhorst', 'Elmenhorst', '', 54.1558300, 12.0108400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37910, 'Elmenhorst', 'Elmenhorst', 'Ehl''menkhorst,Elmenkhorst,Елменхорст,Эльменхорст', 53.7666700, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37911, 'Elmenhorst', 'Elmenhorst', '', 53.5456100, 10.5352000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37912, 'Ellzee', 'Ellzee', 'Ehll''ce,Elce,Ell''ce,Елльце,Елце,Элльце,Էլցե', 48.3397100, 10.3189100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37913, 'Ellweiler', 'Ellweiler', '', 49.6166700, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37914, 'Ellwangen', 'Ellwangen', 'Ehl''vangen,Ell''vangen,Ellwanga,Elvangen,ai er wan gen,alfanghn,alwangan,elvangeni,Елванген,Елльванген,Эльванген,إلفانغن,الوانگان,ელვანგენი,埃尔万根', 48.9616400, 10.1317300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37915, 'Ellscheid', 'Ellscheid', '', 50.1500000, 6.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37916, 'Ellrich', 'Ellrich', 'Alarici [a. 876],Ehl''rikh,Ellrich / Thueringen,Ellrich / Thüringen,Elrike [a. 1229],Elrikh,ai er li xi,alrysh,Елрих,Эльрих,الریش,埃尔里希', 51.5865600, 10.6632600, 'DE', '2016-12-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37917, 'Ellingstedt', 'Ellingstedt', 'Ellingstedt', 54.4749000, 9.4113700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37918, 'Ellingshausen', 'Ellingshausen', '', 50.5500000, 10.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37919, 'Ellingen', 'Ellingen', 'Ehllingen,Elingen,Ellingen,ai lin gen,alynghn,alyngn,aylnjn,Елинген,Еллінген,Эллинген,Էլինգեն,إلينغن,الینگن,ایلنجن,埃林根', 49.0607600, 10.9678300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37920, 'Ellhöft', 'Ellhoft', 'Ellhoft,Ellhöft', 54.8833300, 8.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37921, 'Ellhofen', 'Ellhofen', 'Ehl''khofen,Elkhofen,Ell''gofen,Ellhofen,ai er huo fen,eruhofen,Елльгофен,Елхофен,Эльхофен,エルホーフェン,埃尔霍芬', 49.1466700, 9.3219400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37922, 'Ellgau', 'Ellgau', '', 48.6000000, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37923, 'Ellerstadt', 'Ellerstadt', 'Ehllershtadt,Elershtat,ai lai er si ta te,Елерштат,Эллерштадт,埃莱尔斯塔特', 49.4616700, 8.2594400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37924, 'Ellersleben', 'Ellersleben', 'Elrickesleuben', 51.1500000, 11.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37925, 'Ellerhoop', 'Ellerhoop', 'Ellerhoop', 53.7260300, 9.7693300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37926, 'Ellerdorf', 'Ellerdorf', 'Ellerdorf', 54.1937800, 9.8393300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37927, 'Ellerbek', 'Ellerbek', 'Ehllerbek,Elerbek,Ellerbek,ai lai er bei ke,Елербек,Эллербек,埃莱尔贝克', 53.6581700, 9.8699100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37928, 'Ellerau', 'Ellerau', 'Ellerau', 53.7500000, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37929, 'Ellenhausen', 'Ellenhausen', '', 50.5163900, 7.7252800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37930, 'Ellenberg', 'Ellenberg', '', 49.6500000, 7.1500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37931, 'Ellenberg', 'Ellenberg', '', 49.0166700, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37932, 'Ellefeld', 'Ellefeld', '', 50.4836700, 12.3888000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37933, 'Elleben', 'Elleben', 'Ehlleben,Eleben,Elleben,ai lai ben,Елебен,Эллебен,埃莱本', 50.8666700, 11.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37934, 'Elkenroth', 'Elkenroth', '', 50.7333300, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37935, 'Elisabeth-Sophien-Koog', 'Elisabeth-Sophien-Koog', 'Ehlizabet-Sofien-Kog,Elisabeth-Sophie Kog,Elisabeth-Sophien-Koog,Elisabeth-Sophien-Kuuch,Elizabet-Sofien-Kog,Elizabet-Zofin-Kog,ai li sa bei te-suo fen-ke ge,Елизабет-Зофин-Ког,Елизабет-Софиен-Ког,Элизабет-Софиен-Ког,埃利萨贝特-索芬-科格', 54.5166700, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37936, 'Elgersburg', 'Elgersburg', 'Ehl''gersburg,Elgersburg,ai er ge er si bao,Елгерсбург,Эльгерсбург,埃尔格尔斯堡', 50.7060300, 10.8531000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37937, 'Elfershausen', 'Elfershausen', 'Ehl''ferskhauzen,El''fersgauzen,Elfershauzen,Elferskhauzen,ai er fei er si hao sen,Елферсхаузен,Ельферсгаузен,Эльферсхаузен,Էլֆերսհաուզեն,埃尔费尔斯豪森', 50.1474300, 9.9615100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37938, 'Eldingen', 'Eldingen', 'Ehl''dingen,Eldingen,ai er ding gen,Елдинген,Эльдинген,埃尔丁根', 52.6833300, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37939, 'Eldena', 'Eldena', 'Ehl''dena,Eldena,ai er de na,Елдена,Эльдена,埃尔德纳', 53.2319100, 11.4180400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37940, 'Elchweiler', 'Elchweiler', '', 49.6666700, 7.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37941, 'Elbingerode', 'Elbingerode', 'Ehl''bingerode,Elbingerode,Elljeroe,Елбингероде,Эльбингероде', 51.7703900, 10.8055700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37942, 'Elbingerode', 'Elbingerode', '', 51.6592500, 10.2777100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37943, 'Elben', 'Elben', '', 50.7500000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37944, 'Eitting', 'Eitting', 'Ajting,Ajtting,Eitting,Euting,ai ting ge,aytyng,Айттинг,Айттінг,Ајтинг,ایتینگ,艾廷格', 48.3595700, 11.8911000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37945, 'Eitorf', 'Eitorf', 'Aitorf,Ajtorf,Eitdorf,Eitorf,ai tuo fu,Άιτορφ,Айторф,Ајторф,艾托夫', 50.7666700, 7.4500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37946, 'Eiterfeld', 'Eiterfeld', 'Eiterfeld', 50.7666700, 9.8000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37947, 'Eitensheim', 'Eitensheim', 'Ajtensgajm,Ajtenskhajm,Aytenshaym,Eitensham,ai teng si hai mu,aytnshaym,Айтенсгайм,Айтенсхайм,Ајтенсхајм,Այտենսհայմ,آیتنسهایم,აიტენსჰაიმი,艾滕斯海姆', 48.8166700, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37948, 'Eitelborn', 'Eitelborn', '', 50.3780600, 7.7233300, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37949, 'Eislingen', 'Eislingen', 'Ajslingen,Ajzlingen,Eislingen-Fils,Eislingen/Fils,ai si lin gen,ayslyngn,Айзлинген,Ајслинген,آیسلینگن,艾斯林根', 48.6951500, 9.7067600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37950, 'Eisingen', 'Eisingen', '', 49.7597200, 9.8311100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37951, 'Eisingen', 'Eisingen', '', 48.9500000, 8.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37952, 'Eisighofen', 'Eisighofen', '', 50.2333300, 8.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37953, 'Eisfeld', 'Eisfeld', 'Ajsfel''d,Ajsfeld,Eisfeld,ai si fei er de,aysfld,Айсфельд,Ајсфелд,آيسفلد,ایسفلد,艾斯费尔德', 50.4264800, 10.9069500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37954, 'Eisenschmitt', 'Eisenschmitt', '', 50.0441600, 6.7230000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37955, 'Eisenhüttenstadt', 'Eisenhuettenstadt', 'Ajzenkhitenshtat,Ajzenkhjutenshhat,Ajzenkhjuttenshtadt,Eisenhuettenstadt,Eisenhüttenstadt,Eizenhiutenstatas,Eizenhiutenštatas,Eyzenhyutenstadt,Fuerstenberg,Iesenhuettenstadt,Iesenhüttenstadt,ai sen xu teng si ta te,ayznhwtnshtat,Айзенхютенщат,Айзенхюттенштадт,Ајзенхитенштат,Էյզենհյուտենշտադտ,آيزنهوتنشتات,آیزنهوتن‌اشتات,艾森许滕斯塔特', 52.1500000, 14.6500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37956, 'Eisendorf', 'Eisendorf', '', 54.2000000, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37957, 'Eisenburg', 'Eisenburg', '', 48.0140400, 10.2087000, 'DE', '2015-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37958, 'Eisenberg', 'Eisenberg', 'Ajzenberg,Eisenberg,ayznbrg,Айзенберг,Ајзенберг,آیزنبرگ', 50.9686000, 11.9020700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37959, 'Eisenberg', 'Eisenberg', 'Eisenberg', 49.5585900, 8.0719900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37960, 'Eisenberg', 'Eisenberg', 'Ajzenberg,Ayzenberg,aizenbergi,aizenberuku,Айзенберг,Ајзенберг,Այզենբերգ,აიზენბერგი,アイゼンベルク', 47.6136500, 10.6072300, 'DE', '2013-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37961, 'Eisenbach', 'Eisenbach', 'Ajzenbakh,Ayzenbax,Eisenbach,ai sen ba he,aizenbakhi,Айзенбах,Ајзенбах,Այզենբախ,აიზენბახი,艾森巴赫', 47.9611700, 8.2680200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37962, 'Eisenach', 'Eisenach', 'Aizenach,Ajzenakh,EIB,ESA,Eisenach,Gorad Ajzenakh,Iesenack,Wartburgstadt,Ysenacum,ai sen na he,aijenaheu,aizenaha,ayznakh,Άιζεναχ,Айзенах,Ајзенах,Горад Айзенах,آیزناخ,アイゼナハ,艾森纳赫,아이제나흐', 50.9807000, 10.3152200, 'DE', '2016-03-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37963, 'Eisenach', 'Eisenach', '', 49.8500000, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37964, 'Eisdorf am Harz', 'Eisdorf am Harz', 'Eisdorf,Eisdorf uber Herzberg,Eisdorf über Herzberg,Eisdorp', 51.7615200, 10.1759100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37965, 'Einselthum', 'Einselthum', 'Ajnzel''tum,Ajnzeltum,ai yin sai er tu mu,Айнзельтум,Ајнзелтум,埃因塞尔图姆', 49.6516700, 8.1247200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37966, 'Einöllen', 'Einoellen', 'Ajnelen,Ajnjollen,Einoellen,Einöllen,ai nei lun,Айнёллен,Ајнелен,艾内伦', 49.6166700, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37967, 'Einig', 'Einig', '', 50.2833300, 7.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37968, 'Einhausen', 'Einhausen', '', 50.5283400, 10.4618800, 'DE', '2013-10-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37969, 'Einhausen', 'Einhausen', '', 49.6766700, 8.5483300, 'DE', '2014-09-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37970, 'Einhaus', 'Einhaus', '', 53.7166700, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37971, 'Markt Einersheim', 'Markt Einersheim', 'Einersheim,Markt Ajnerskhajm,Markt Einersheim,Markt-Ajnersgajm,Markt-Ajnerskhajm,ma er ke te ai nei er si hai mu,Маркт Ајнерсхајм,Маркт-Айнерсгайм,Маркт-Айнерсхайм,Մարքթ Այներսհայմ,马尔克特艾内尔斯海姆', 49.6866300, 10.2915500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37972, 'Eineborn', 'Eineborn', 'Eineborn', 50.8333300, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37973, 'Einbeck', 'Einbeck', 'Aimbeck,Ainmpek,Ajnbek,Einbeck,Stadt Einbeck,ai yin bei ke,ainbekku,aynbk,Άινμπεκ,Айнбек,Ајнбек,آينبك,آینبک,アインベック,埃因贝克', 51.8201800, 9.8696100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37974, 'Eimsheim', 'Eimsheim', '', 49.7958300, 8.2894400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37975, 'Eimke', 'Eimke', '', 52.9660100, 10.3132400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37976, 'Eimen', 'Eimen', '', 51.8833300, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37977, 'Eimeldingen', 'Eimeldingen', 'Ajmel''dingen,Ajmeldingen,ai mei er ding gen,Аймельдинген,Аймельдінген,Ајмелдинген,艾梅尔丁根', 47.6333300, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37978, 'Eime', 'Eime', 'Ajme,ai mei,Айме,Ајме,艾梅', 52.0744900, 9.7211800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37979, 'Eilsleben', 'Eilsleben', 'Ajl''sleben,Ajlsleben,Eilsleben,Eisleben,ai er si lai ben,Айльслебен,Ајлслебен,艾尔斯莱本', 52.1470800, 11.2103500, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37980, 'Eilscheid', 'Eilscheid', '', 50.1333300, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37981, 'Eilenburg', 'Eilenburg', 'Ajlenburg,Eilenburg,Eilenburga,Eilenburgum,Jilow,Jiłow,ai lun bao,aylnbwrg,aylnbwrgh,Айленбург,Ајленбург,آيلنبورغ,آیلنبورگ,艾伦堡', 51.4598400, 12.6333800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37982, 'Eil', 'Eil', '', 50.8936200, 7.0796700, 'DE', '2013-03-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37983, 'Eigeltingen', 'Eigeltingen', 'Ajgel''tingen,Ajgeltingen,Eigeltingen,ai ge er ting gen,Айгельтинген,Айгельтінген,Ајгелтинген,艾格尔廷根', 47.8580200, 8.8978400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37984, 'Eicklingen', 'Eicklingen', 'Ajklingen,Eicklingen,Eikeln,ai ke lin gen,Айклинген,Ајклинген,艾克林根', 52.5503700, 10.1843900, 'DE', '2014-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37985, 'Eickendorf', 'Eickendorf', 'Eickendorf,Eickendorf (Boerdeland),Eickendorf (Bördeland),Eickendorf (Landkreis Schoenebeck),Eickendorf (Landkreis Schönebeck),Eikendorf', 51.9476500, 11.6753800, 'DE', '2012-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37986, 'Eickeloh', 'Eickeloh', '', 52.7292200, 9.6068600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37987, 'Eichwalde', 'Eichwalde', 'Ajkhval''de,Ajkhvalde,aihivu~arude,Айхвальде,Ајхвалде,Էյչվալդե,アイヒヴァルデ', 52.3666700, 13.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37988, 'Eichstruth', 'Eichstruth', 'Eichstruth', 51.3000000, 10.0833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37989, 'Eichstetten', 'Eichstetten', '', 48.0942700, 7.7424400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37990, 'Eichstegen', 'Eichstegen', 'Ajkhshtegen,Ajkhstegen,ai xi si te gen,Айхштеген,Ајхстеген,艾希斯特根', 47.9333300, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37991, 'Eichstätt', 'Eichstaett', 'Ajkhshhet,Ajkhshtet,Ayxstet,Ayxştet,Eichstaett,Eichstatt,Eichstätt,Gorad Ajkhshteht,ai xi si te,ayshtyt,aysh‌shtt,Айхштет,Айхщет,Ајхштет,Горад Айхштэт,Այխշտետ,آيشتيت,آیش‌شتت,艾希斯特', 48.8885400, 11.1967500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37992, 'Eichigt', 'Eichigt', 'Ajkhigt,Eichigt,ai xi ge te,Айхигт,Ајхигт,艾希格特', 50.3500000, 12.1666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37993, 'Eichenzell', 'Eichenzell', 'Ajkhencel,Ajkhencell'',ai xing ce er,Айхенцелль,Ајхенцел,艾兴策尔', 50.4953600, 9.6967200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37994, 'Eichenried', 'Eichenried', 'Eichenried bei Erding', 48.2774800, 11.7820600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37995, 'Eichendorf', 'Eichendorf', 'Ajkhendorf,Ayxendorf,Eichendorf,Euchendorf,ai xing duo fu,ayshndwrf,Айхендорф,Ајхендорф,Այխենդորֆ,ایشندورف,艾兴多夫', 48.6326600, 12.8558600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37996, 'Eichenbühl', 'Eichenbuhl', 'Ajkhenbil,Ajkhenbjul'',Eyxenbyul,ai xing bi he er,aihyenbyuru,Айхенбюль,Ајхенбил,Էյխենբյուլ,アイヒェンビュール,艾兴比赫尔', 49.7055600, 9.3291700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37997, 'Eichenberg', 'Eichenberg', '', 50.8000000, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37998, 'Eichenberg', 'Eichenberg', '', 50.5500000, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(37999, 'Eichenbarleben', 'Eichenbarleben', 'Ajkhenbarleben,Eichenbarleben,Айхенбарлебен,Ајхенбарлебен', 52.1668800, 11.4012500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38000, 'Eichenbach', 'Eichenbach', '', 50.4333300, 6.8166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38001, 'Eichenau', 'Eichenau', 'Ajkhenau,Eichenau,ai xie nao,Айхенау,Ајхенау,艾歇瑙', 48.1666700, 11.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38002, 'Eichen', 'Eichen', '', 50.6333300, 7.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38003, 'Eichelhardt', 'Eichelhardt', 'Ajkhel''khardt,Ajkhelkhardt,ai xie er ha er te,aykhlhart,Айхельхардт,Ајхелхардт,ایخلهارت,艾歇尔哈尔特', 50.7166700, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38004, 'Eich', 'Eich', '', 49.7500000, 8.3988900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38005, 'Eibenstock', 'Eibenstock', 'Aimpenstok,Ajbenshtok,Eibenstock,Eibenstoka,Eibenštoka,ai ben si tuo ke,aybnshtwk,Άιμπενστοκ,Айбеншток,Ајбеншток,آيبنشتوك,آیبن‌اشتوک,艾本斯托克', 50.4943100, 12.5997800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38006, 'Eibelstadt', 'Eibelstadt', 'Ajbel''shtadt,Ajbelshtat,Aybelstadt,Aybelştadt,ai bei er si ta te,aiberushutatto,ayblshtat,Айбельштадт,Ајбелштат,Այբելշտադտ,آيبلشتات,آیبل‌اشتات,აიბელშტადტი,アイベルシュタット,艾贝尔斯塔特', 49.7239200, 9.9996200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38007, 'Eibau', 'Eibau', 'Ajbau,Eibau,Jiwow,ai bao,Айбау,Ајбау,艾鲍', 50.9827200, 14.6621400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38008, 'Ehweiler', 'Ehweiler', 'Ehvajler,Ekhvajler,ai wei lei,Ехвајлер,Эвайлер,埃韦勒', 49.5166700, 7.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38009, 'Ehringshausen', 'Ehringshausen', 'Ehringskhauzen,Eringskhauzen,ai lin ge si hao sen,Ерингсхаузен,Эрингсхаузен,埃林格斯豪森', 50.6000000, 8.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38010, 'Ehrenfriedersdorf', 'Ehrenfriedersdorf', 'Ehrenfridersdorf,Ehrenfriedersdorf,Erenfridersdorf,Erenfridersdorfa,ai lun fu li de er si duo fu,arnfrdynzdwrf,ayrn frydrsdwrf,Ērenfrīdersdorfa,Еренфридерсдорф,Эренфридерсдорф,إيرن فريدرسدورف,ارنفردینزدورف,埃伦夫里德尔斯多夫', 50.6493400, 12.9700900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38011, 'Ehrenburg', 'Ehrenburg', '', 52.7500000, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38012, 'Ehrenberg', 'Ehrenberg', '', 50.4833300, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38013, 'Ehr', 'Ehr', '', 50.2378700, 7.7846700, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38014, 'Ehningen', 'Ehningen', 'Eningen,ai ning gen,eningeni,Енинген,Енінген,ენინგენი,埃宁根', 48.6588200, 8.9412400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38015, 'Ehndorf', 'Ehndorf', 'Ehndorf', 54.0500000, 9.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38016, 'Ehlscheid', 'Ehlscheid', '', 50.5144800, 7.4665500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38017, 'Ehlenz', 'Ehlenz', '', 50.0404400, 6.4712000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38018, 'Ehingen', 'Ehingen', '', 49.0868000, 10.5407000, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38019, 'Ehingen', 'Ehingen', '', 48.6000000, 10.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38020, 'Ehingen', 'Ehingen', 'Egingen,Ehingen,Ehingen Donau,Ehingen an der Donau,Ehkhingen,Ekhingen,ai xin gen,anyngn,ayhnghn,ehingeni,Егінген,Ехинген,Эинген,Эхинген,Էհինգեն,إيهنغن,انینگن,ეჰინგენი,埃欣根', 48.2825900, 9.7274900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38021, 'Ehekirchen', 'Ehekirchen', 'Eekirkhen,Ehehkirkhen,Ehekirxen,Ekhekirkhen,ahh kyrshn,ai hei ji xing,Еекірхен,Ехекирхен,Ээкирхен,Էհեկիրխեն,اهه کیرشن,埃黑基兴', 48.6333300, 11.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38022, 'Egweil', 'Egweil', 'Egvajl,Egvajl'',Egvayl,Ehgvajl'',agwayl,ai ge wei er,Егвайл,Егвайль,Егвајл,Эгвайль,Էգվայլ,اگوایل,埃格魏尔', 48.7833300, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38023, 'Egmating', 'Egmating', '', 48.0040500, 11.7952800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38024, 'Egloffstein', 'Egloffstein', 'Egloffshtajn,Egloffstein,Eglofshtajn,Ehglofshtajn,ai ge luo fu si tai yin,egurofushutain,Еглоффштайн,Еглофштајн,Эглофштайн,エグロフシュタイン,埃格洛夫斯泰因', 49.7018200, 11.2574900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38025, 'Egling', 'Egling', '', 48.1862600, 10.9766900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38026, 'Egling', 'Egling', 'Egling,Ehgling,aglyng,ai ge ling,Еглинг,Еглінг,Эглинг,Էգլինգ,اگلینگ,埃格灵', 47.9231600, 11.5051700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38027, 'Eging', 'Eging', '', 48.4632800, 12.1895700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38028, 'Eggstedt', 'Eggstedt', 'Eggstedt', 54.0500000, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38029, 'Eggstätt', 'Eggstatt', 'Eggshtett,Eggstaett,Eggstätt,Egshtet,Ehgshtett,agshtt,Еггштетт,Егштет,Эгштетт,Էգշթեթ,اگشتت', 47.9269800, 12.3791900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38030, 'Eggolsheim', 'Eggolsheim', 'Eggol''sgajm,Eggolsheim,Egolshaym,Egolskhajm,Ehggol''skhajm,ai ge er si hai mu,egorusuhaimu,Еггольсгайм,Еголсхајм,Эггольсхайм,Էգոլսհայմ,エゴルスハイム,埃戈尔斯海姆', 49.7696100, 11.0570100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38031, 'Egglkofen', 'Egglkofen', 'Eggl''kofen,Eglkofen,Ehgl''kofen,aglkwfn,ai ge er ke fen,Егглькофен,Еглкофен,Эглькофен,Էգլքոֆեն,اگلکوفن,埃格尔科芬', 48.4000000, 12.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38032, 'Egglham', 'Egglham', 'Eggl''gam,Eglham,Eglkham,Ehgl''kham,aglham,ai ge er ha mu,Еггльгам,Еглхам,Эгльхам,Էգլհամ,اگلهام,埃格尔哈姆', 48.5290200, 13.0540200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38033, 'Eggesin', 'Eggesin', 'Checzeno,Chëczëno,Egesin,Egezin,Egezine,Egezīne,Eggesin,Ehggezin,aghhzyn,agzyn,ai ge xin,Егезин,Егесин,Эггезин,إغهزين,اگزین,埃格辛', 53.6797300, 14.0799200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38034, 'Eggersdorf', 'Eggersdorf', '', 51.9762100, 11.7097100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38035, 'Eggenthal', 'Eggenthal', 'Egental,Eggental'',Ehggental'',ai gen ta er,eggentaru,Еггенталь,Егентал,Эггенталь,Էգենթալ,エッゲンタール,埃根塔尔', 47.9166700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38036, 'Eggenstein-Leopoldshafen', 'Eggenstein-Leopoldshafen', 'Egenshtajn-Leopoldskhafen,Eggenshtajn-Leopol''dsgafen,Eggenstein-Leopoldshafen,Ehggenshtajn-Leopol''dskhafen,Leopoldshafen,ai gen si tai yin-lie ao bo de gang,Еггенштайн-Леопольдсгафен,Егенштајн-Леополдсхафен,Эггенштайн-Леопольдсхафен,埃根斯泰因-列奥波德港', 49.0900600, 8.3987900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38037, 'Eggenfelden', 'Eggenfelden', 'Egenfelden,Eggenfejdn,Eggenfel''den,Ehggenfel''den,aghnfldn,agnfldn,ai gen fei er deng,Еггенфельден,Егенфелден,Эггенфельден,Էգենֆելդեն,إغنفلدن,اگنفلدن,ایگنفیلڈن,埃根费尔登', 48.4050900, 12.7575200, 'DE', '2013-11-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38038, 'Eggebek', 'Eggebek', 'Eggebek', 54.6166700, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38039, 'Egg an der Günz', 'Egg an der Gunz', 'Eg an der Ginc,Egg,Egg an der Gunz,Egg an der Günz,Egg-an-der-Gjunc,Ehgg-an-der-Gjunc,jin ci he pan ai ge,Ег ан дер Гинц,Егг-ан-дер-Гюнц,Эгг-ан-дер-Гюнц,Գյունցի Էգ,金茨河畔埃格', 48.0871400, 10.2849500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38040, 'Egestorf', 'Egestorf', 'Egestorf,Egestorf am Suentel,Egestorf am Suntel,Egestorf am Süntel,Ehgestorf,ai ge si tuo fu,Егесторф,Эгесторф,埃格斯托夫', 53.1930000, 10.0630000, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38041, 'Egestorf', 'Egestorf', 'Egestoerp,Egestorf,Egestorf (Deister),Egestörp,Esedesthorp [a. 1231],Estoerp,Estoerpe,Estörp,Estörpe', 52.2856800, 9.5167600, 'DE', '2012-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38042, 'Egesheim', 'Egesheim', 'Egeskhajm,Ehgeskhajm,ai ge si hai mu,Егесхајм,Эгесхайм,埃格斯海姆', 48.1171700, 8.8564400, 'DE', '2013-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38043, 'Egenhofen', 'Egenhofen', 'Egengofen,Egenhofa,Egenhofen,Egenkhofen,Ehgenkhofen,agnhwfn,ai gen huo fen,Егенгофен,Егенхофен,Эгенхофен,Էգենհոֆեն,اگنهوفن,埃根霍芬', 48.2833300, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38044, 'Egenhausen', 'Egenhausen', '', 48.5666700, 8.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38045, 'Egelsbach', 'Egelsbach', 'Egel''sbakh,Egelsbach,Egelsbakh,Ehgel''sbakh,QEF,ai ge er si ba he,egerusubahha,Егелсбах,Егельсбах,Эгельсбах,エーゲルスバッハ,埃格尔斯巴赫', 49.9679200, 8.6634100, 'DE', '2016-12-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38046, 'Egeln', 'Egeln', 'AEjeln,Egelen,Egeln,Ehgel''n,aghln,agln,ai ge er en,Äjeln,Егелн,Эгельн,إغلن,اگلن,埃格尔恩', 51.9438400, 11.4326500, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38047, 'Efringen-Kirchen', 'Efringen-Kirchen', 'Efringen-Kirchen,Efringen-Kirkhen,Ehfringen-Kirkhen,ai fu lin gen-ji xing,Ефринген-Кирхен,Ефрінген-Кірхен,Эфринген-Кирхен,埃夫林根-基兴', 47.6500000, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38048, 'Effeltrich', 'Effeltrich', 'Efeltrikh,Effel''trikh,Ehffel''trikh,ai fei er te li xi,efferutorihi,Ефелтрих,Еффельтріх,Эффельтрих,エッフェルトリヒ,埃费尔特里希', 49.6592900, 11.0931900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38049, 'Effelder', 'Effelder', '', 51.2394800, 10.2477800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38050, 'Edling', 'Edling', '', 48.0561100, 12.1647000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38051, 'Edingen-Neckarhausen', 'Edingen-Neckarhausen', 'Edingen-Nekarkhauzen,Edingen-Nekkargauzen,Ehdingen-Nekkarkhauzen,ai ding gen-nei ka lao sen,edingen=nekkahauzen,Единген-Некархаузен,Едінген-Неккаргаузен,Эдинген-Неккархаузен,エーディンゲン＝ネッカーハウゼン,埃丁根-内卡劳森', 49.4572200, 8.6063900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38052, 'Edewecht', 'Edewecht', 'Edevekht,Edewecht,Ehdevekht,Erwech,ai de wei xi te,Едевехт,Эдевехт,埃德韦希特', 53.1269900, 7.9840600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38053, 'Edesheim', 'Edesheim', 'Edeskhajm,Edsm,Ehdeskhajm,ai de si hai mu,Едесхајм,Эдесхайм,埃德斯海姆', 49.2633300, 8.1350000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38054, 'Edersleben', 'Edersleben', '', 51.4166700, 11.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38055, 'Ederheim', 'Ederheim', 'Edergajm,Ederhaym,Ederkhajm,Ehderkhajm,ai de lai mu,edahaimu,Едергайм,Едерхајм,Эдерхайм,Էդերհայմ,エーダーハイム,埃德赖姆', 48.8082700, 10.4660900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38056, 'Edenkoben', 'Edenkoben', 'Edenkoben,Ehdenkoben,adnkwbn,ai deng ke ben,idenkoben,Еденкобен,Эденкобен,إدنكوبن,ادنکوبن,イデンコーベン,埃登科本', 49.2839300, 8.1271400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38057, 'Edemissen', 'Edemissen', 'Edemisen,Ehdemissen,Emisse,ai de mi sen,Едемисен,Эдемиссен,埃德米森', 52.3870200, 10.2614000, 'DE', '2011-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38058, 'Edelsfeld', 'Edelsfeld', '', 49.5764400, 11.6958900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38059, 'Edderitz', 'Edderitz', 'Edderitz', 51.6993300, 11.9371200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38060, 'Eddelak', 'Eddelak', 'Eddelak,Edelak,Ehddelak,ai de la ke,Еделак,Эдделак,埃德拉克', 53.9500000, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38061, 'Eckstedt', 'Eckstedt', 'Ekenstete [a. 1231]', 51.0711200, 11.1460600, 'DE', '2014-12-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38062, 'Ecklingerode', 'Ecklingerode', 'Ecklingerode', 51.5000000, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38063, 'Ecklak', 'Ecklak', 'Ecklak', 53.9500000, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38064, 'Eckfeld', 'Eckfeld', '', 50.1166700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38065, 'Eckersweiler', 'Eckersweiler', '', 49.5666700, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38066, 'Eckersdorf', 'Eckersdorf', '', 50.0287400, 11.3961100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38067, 'Eckersdorf', 'Eckersdorf', 'Ehkkersdorf,Ekersdorf,Ekkersdorf,ai ke er si duo fu,ekkasudorufu,Екерсдорф,Еккерсдорф,Эккерсдорф,Էքերսդորֆ,エッカースドルフ,埃克尔斯多夫', 49.9348000, 11.4962100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38068, 'Eckernförde', 'Eckernfoerde', 'Eckernfoeoer,Eckernfoerde,Eckernforde,Eckernförde,Eckernföör,Egernforde,Egernførde,Ehkkernfjorde,Ekerenforda,Ekernferde,Ekernfernte,ai ke er en fu er de,akrnfwrdh,Εκερνφέρντε,Екернферде,Эккернфёрде,إكرنفورده,اکرنفورده,埃克尔恩弗尔德', 54.4685400, 9.8382400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38069, 'Eckenroth', 'Eckenroth', '', 49.9166700, 7.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38070, 'Eckelsheim', 'Eckelsheim', '', 49.8000000, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38071, 'Eckartsberga', 'Eckartsberga', 'Eckartsberga,Ehkkartsberga,Ekartsberga,ai ka er ci bei er jia,akartsbrg,akartsbrgha,Екартсберга,Эккартсберга,إكارتسبرغا,اکارتسبرگ,埃卡尔茨贝尔加', 51.1238000, 11.5604500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38072, 'Echzell', 'Echzell', 'Echzell,Ehkhcell'',Ekhcel,Ekhcell'',ai xi ce er,ehitsu~eru,Ехцел,Ехцелль,Эхцелль,エヒツェル,埃希策尔', 50.3888800, 8.8860500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38073, 'Echtershausen', 'Echtershausen', '', 50.0166700, 6.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38074, 'Echternacherbrück', 'Echternacherbruck', '', 49.8166700, 6.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38075, 'Eching', 'Eching', '', 48.5000000, 12.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38076, 'Eching', 'Eching', 'Ehkhing,Ekhing,ai xing,ashyng,Ехинг,Ехінг,Эхинг,اشینگ,埃兴', 48.3000000, 11.6166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38077, 'Eching', 'Eching', '', 48.0799100, 11.1133600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38078, 'Echem', 'Echem', '', 53.3333300, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38079, 'Ebstorf', 'Ebstorf', 'Ebsdorf,Ebstorf,Ehbstorf,ai bu si tuo fu,Ебсторф,Эбсторф,埃布斯托夫', 53.0278500, 10.4183900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38080, 'Ebringen', 'Ebringen', 'Ebringen,Ehbringen,ai bu lin gen,Ебринген,Ебрінген,Эбринген,Էբրինգեն,埃布林根', 47.9578000, 7.7765200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38081, 'Ebnath', 'Ebnath', 'Ebnath,Ebriat', 49.9500000, 11.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38082, 'Ebhausen', 'Ebhausen', 'Ebgauzen,Ebhausen,Ebhausen uber Wollhausen,Ebhausen über Wollhausen,Ebhauzen,Ebkhauzen,Ehbkhauzen,ai bu hao sen,Ебгаузен,Ебхаузен,Эбхаузен,Էբհաուզեն,埃布豪森', 48.5833300, 8.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38083, 'Ebertsheim', 'Ebertsheim', 'Ebertskhajm,Ehbertskhajm,Ewwerdsm,ai bei er ci hai mu,Ебертсхајм,Эбертсхайм,埃贝尔茨海姆', 49.5683300, 8.1086100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38084, 'Ebertshausen', 'Ebertshausen', '', 50.2833300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38085, 'Eberswalde', 'Eberswalde', 'Ebersval''de,Ebersvalde,Ebersvaldė,Eberswalde,Eberswalde-Finow,Ehbersval''de,Gorad Ehbersval''deh,Neustadium Eberswaldum,abrs waldh,ai bei er si wa er de,ebeleuseubalde,eberusuvu~arude,Ēbersvalde,Горад Эберсвальдэ,Еберсвалде,Еберсвальде,Эберсвальде,Էբերսվալդե,אברסוולדה,ابرس والده,エーベルスヴァルデ,埃贝尔斯瓦尔德,에베르스발데', 52.8349200, 13.8195100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38086, 'Eberstedt', 'Eberstedt', '', 51.0738200, 11.5787700, 'DE', '2017-07-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38087, 'Eberstadt', 'Eberstadt', '', 49.1802800, 9.3211100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38088, 'Ebershausen', 'Ebershausen', 'Ebersgauzen,Ebershauzen,Eberskhauzen,Ehberskhauzen,ai bei er si hao sen,Еберсгаузен,Еберсхаузен,Эберсхаузен,Էբերսհաուզեն,ኤበርስሃውዘን,埃贝尔斯豪森', 48.2054600, 10.3156500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38089, 'Ebersdorf', 'Ebersdorf', '', 53.5251400, 9.0489700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38090, 'Ebersdorf', 'Ebersdorf', '', 50.3289800, 11.1526600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38091, 'Ebersberg', 'Ebersberg', 'Ebasbeag,Ebersberg,Ehbersberg,abrsbrg,abrsbrgh,ai bo si bei ge,Еберсберг,Эберсберг,إبرسبرغ,ابرسبرگ,ኤበርስበርግ,埃伯斯贝格', 48.0771000, 11.9706300, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38092, 'Ebersbach an der Fils', 'Ebersbach an der Fils', 'Ebersbach,Ebersbachander Fils,Ebersbakh an der Fils,Ebersbakh-an-der-Fil''s,Ehbersbakh-na-Fil''se,abrsbakh an dr fylz,abrzbakh an dr fylz,fei er si he pan ai bei er si ba he,Еберсбах ан дер Филс,Еберсбах-ан-дер-Фільс,Эберсбах-на-Фильсе,إبرسباخ آن در فيلز,ابرزباخ آن در فیلز,菲尔斯河畔埃贝尔斯巴赫', 48.7160000, 9.5236000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38093, 'Ebersbach', 'Ebersbach', '', 51.0990000, 13.1135000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38094, 'Ebersbach', 'Ebersbach', 'Ebersbach,Habrachcicy,Habrachćicy', 51.0076200, 14.5862100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38095, 'Ebernhahn', 'Ebernhahn', '', 50.4727800, 7.7700000, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38096, 'Ebermannstadt', 'Ebermannstadt', 'Ebermannshtadt,Ebermannstadt,Ebermanshtat,Ehbermanshtadt,URD,abrmanshtat,ai bei er man si ta te,ebamanshutatto,Еберманнштадт,Еберманштат,Эберманштадт,Էբերմանշթաթ,إبرمانشتات,ابرمانسٹیڈ,ابرمان‌اشتات,エーバーマンシュタット,埃贝尔曼斯塔特', 49.7815400, 11.1816800, 'DE', '2013-11-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38097, 'Ebermannsdorf', 'Ebermannsdorf', 'Ebermannsdorf,Ebermansdorf,Ehbermansdorf,ai bo man si duo fu,Еберманнсдорф,Ебермансдорф,Эбермансдорф,Էբերմանսդորֆ,埃伯曼斯多夫', 49.3937500, 11.9358200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38098, 'Eberholzen', 'Eberholzen', '', 52.0500000, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38099, 'Eberhardzell', 'Eberhardzell', 'Eberardcell'',Eberkhardcel,Ehberkhardcell'',ai bei la er de ce er,eberhardtseli,Еберардцелль,Еберхардцел,Эберхардцелль,Էբերհարդցել,ებერჰარდცელი,埃贝拉尔德策尔', 48.0000000, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38100, 'Ebergötzen', 'Ebergoetzen', 'Ebergecen,Ehbergjotcen,ai bo ge cen,ebagettsu~en,Ебергецен,Эбергётцен,エーバーゲッツェン,埃伯格岑', 51.5709600, 10.1063200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38101, 'Eberdingen', 'Eberdingen', 'Eberdenge,Eberdingen,Ehberdingen,abrdyngn,ai bei er ding gen,Ебердинген,Ебердінген,Эбердинген,ابردینگن,埃贝尔丁根', 48.8794200, 8.9650200, 'DE', '2015-10-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38102, 'Eberbach', 'Eberbach', 'Eberbach,Eberbakh,Ehberbakh,Ewwerbach,abrbakh,ai bei er ba he,ebabahha,Ебербах,Эбербах,ابرباخ,エーバーバッハ,埃贝尔巴赫', 49.4668000, 8.9901600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38103, 'Ebenweiler', 'Ebenweiler', 'Ebenvajler,Ehbenvajler,ai ben wei lei,Ебенвайлер,Ебенвајлер,Эбенвайлер,埃本韦勒', 47.9000000, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38104, 'Ebenshausen', 'Ebenshausen', '', 51.0833300, 10.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38105, 'Ebensfeld', 'Ebensfeld', 'Ebensfel''d,Ebensfeld,Ehbensfel''d,abnsfld,ai ben si fei er de,ebensuferuto,Ебенсфелд,Ебенсфельд,Эбенсфельд,Էբենսֆելդ,ابنسفلد,エーベンスフェルト,埃本斯费尔德', 50.0664000, 10.9583500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38106, 'Ebendorf', 'Ebendorf', '', 52.1855100, 11.5747800, 'DE', '2014-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38107, 'Ebelsbach', 'Ebelsbach', 'Ebel''sbakh,Ebelsbach,Ebelsbakh,Ebelsbax,Ehbel''sbakh,ai bei er si ba he,Ебелсбах,Ебельсбах,Эбельсбах,Էբելսբախ,埃贝尔斯巴赫', 49.9857200, 10.6744200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38108, 'Ebeleben', 'Ebeleben', 'Ebeleben,Ehbeleben,Elsleben,abhlybn,ablbn,ai bei lai ben,Ебелебен,Эбелебен,إبهليبن,ابلبن,埃贝莱本', 51.2828300, 10.7299900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38109, 'Duvenstedt', 'Duvenstedt', '', 53.7080600, 10.1044400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38110, 'Duvensee', 'Duvensee', 'Duvensee', 53.7000000, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38111, 'Dußlingen', 'Dusslingen', 'Duslingen,Dusslingen,Dußlingen,du si lin gen,Дуслинген,Дуслінген,杜斯林根', 48.4535700, 9.0555200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38112, 'Düsseldorf', 'Duesseldorf', 'DUS,Diseldorf,Diseldorfa,Disseldorf,Diuseldorfas,Djuseldorf,Djussel''dorf,Duesseldoerp,Duesseldorf,Duessldorf,Duseldorfo,Dusseldoerp,Dusseldorf,Dusseldorpium,Dusseldörp,Dyuseldorf,Dyzeldorfi,Dzjusel''dorf,Düsseldorf,Düsseldörp,Düssldorf,Ntiselntorph,Ntysselntorf,daseladorfa,de~yusserudorufu,diao su duo er fu,diuseldorpi,du sai er duo fu,dus se ld xrf,dwiseldoleupeu,dwsldwrf,dysldwrp,dyuseladorpha,tiyucaltorhpu,Ντίσελντορφ,Ντύσσελντορφ,Дзюсельдорф,Диселдорф,Дюселдорф,Дюссельдорф,Дүсселдорф,Դյուսելդորֆ,דיסלדורף,دوسلدورف,دوسلدۆرف,ڈسلڈورف,डसेलडॉर्फ़,ड्युसेलडॉर्फ,தியூசல்டோர்ஃபு,ഡൂസൽഡോർഫ്,ดึสเซลดอร์ฟ,ဒပ်ဆဲလ်ဒေါ့ဖ်မြို့,დიუსელდორფი,ዲውስልዶርፍ,デュッセルドルフ,杜塞尔多夫,調素多爾夫,뒤셀도르프', 51.2217200, 6.7761600, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38113, 'Dürrwangen', 'Durrwangen', 'Dirvangen,Djurrvangen,Djurvangen,Duerrwangen,Durrwangen,Dyurvangen,Dürrwangen,de~yuruvu~angen,di er wan gen,Дирванген,Дюрванген,Дюррванген,Դյուրվանգեն,デュルヴァンゲン,迪尔万根', 49.1077800, 10.3850000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38114, 'Dürrröhrsdorf', 'Duerrroehrsdorf', 'Durrohrsdorf,Durrrohrsdorf-Dittersbach,Dürrröhrsdorf-Dittersbach,Dürröhrsdorf', 51.0339500, 13.9971800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38115, 'Dürrlauingen', 'Durrlauingen', 'Dirlauingen,Djurlauingen,Djurlaujngen,Djurrlauingen,Dyurlauyngen,di er lao yin gen,Дирлауинген,Дюрлауинген,Дюрлауйнген,Дюррлауїнген,Դյուրլաույնգեն,迪尔劳因根', 48.4666600, 10.4286000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38116, 'Dürrhennersdorf', 'Duerrhennersdorf', 'Dirkhenersdorf,Djurkhennersdorf,Duerrhennersdorf,Duerrhennersdorfi vald,Dürrhennersdorf,Dürrhennersdorfi vald,Suche Hendrichecy,di lei nei er si duo fu,Дирхенерсдорф,Дюрхеннерсдорф,迪雷内尔斯多夫', 51.0486300, 14.6038300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38117, 'Dürnau', 'Durnau', 'Duernau,Dürnau', 48.6407900, 9.6354400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38118, 'Dürnau', 'Duernau', '', 48.0602800, 9.5552600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38119, 'Durmersheim', 'Durmersheim', 'Durmersgajm,Durmersheim,Durmerskhajm,Ntourmerschaim,du er mei er si hai mu,Ντούρμερσχαϊμ,Дурмерсгайм,Дурмерсхайм,Дурмерсхајм,杜尔梅尔斯海姆', 48.9333300, 8.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38120, 'Dürmentingen', 'Durmentingen', 'Duermentingen,Dürmentingen', 48.1166700, 9.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38121, 'Durlangen', 'Durlangen', 'Durlangen,du er lan gen,durlangeni,Дурланген,დურლანგენი,杜尔兰根', 48.8563200, 9.7965400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38122, 'Düren', 'Dueren', 'Diren,Djuren,Dueren,Duren,Düren,di lun,dwilen,Дирен,Дюрен,ዲውረን,迪伦,뒤렌', 50.8043400, 6.4929900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38123, 'Durchhausen', 'Durchhausen', 'Durchhausen,Durkhauzen,Durkhgauzen,Durkhkhauzen,du er xiao sen,Дурхаузен,Дурхгаузен,Дурххаузен,杜尔肖森', 48.0397300, 8.6749200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38124, 'Dürbheim', 'Durbheim', 'Dirbkhajm,Djurbkhajm,Duerbheim,Dürbheim,di er bu hai mu,Дирбхајм,Дюрбхайм,迪尔布海姆', 48.0562300, 8.7934400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38125, 'Durbach', 'Durbach', 'Durbakh,Дурбах', 48.4935200, 8.0173600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38126, 'Durach', 'Durach', 'Durakh,Durax,Дурах,Դուրախ', 47.6944000, 10.3444900, 'DE', '2013-02-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38127, 'Duppach', 'Duppach', '', 50.2666700, 6.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38128, 'Dunzweiler', 'Dunzweiler', 'Duncvajler,dui ci wei lei,Дунцвайлер,Дунцвајлер,敦茨韦勒', 49.4158600, 7.3054800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38129, 'Dunum', 'Dunum', '', 53.6000000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38130, 'Dunsum', 'Dunsum', '', 54.7312600, 8.4248800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38131, 'Dünsen', 'Duensen', 'Dinzen,Djunzen,ding sen,Динзен,Дюнзен,丁森', 52.9274900, 8.6419100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38132, 'Dunningen', 'Dunningen', 'Duningen,Dunningen,du ning gen,Дунинген,Дуннинген,Дуннінген,杜宁根', 48.2124200, 8.5061900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38133, 'Düngenheim', 'Duengenheim', 'Duengenheim,Düngenheim', 50.2606200, 7.1652300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38134, 'Dünfus', 'Dunfus', '', 50.2166700, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38135, 'Dümpelfeld', 'Dumpelfeld', 'Dimpelfeld,Djumpel''fel''d,ding pei er fei er de,Димпелфелд,Дюмпельфельд,丁佩尔费尔德', 50.4333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38136, 'Dummerstorf', 'Dummerstorf', 'Dumerstorf,Dummerstorf,du mei er si tuo er fu,Думерсторф,Думмерсторф,杜梅尔斯托尔夫', 54.0148400, 12.2282100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38137, 'Dümmer', 'Duemmer', 'Duemmer,Dummer,Dümmer', 53.5762900, 11.2049700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38138, 'Dülmen', 'Duelmen', 'Dilmen,Djul''men,Duelmen,Dulmen,Dulmenni,Dulmėnni,Dyulmen,Dülmen,di er men,dwlmn,Дилмен,Дюльмен,Դյուլմեն,دولمن,迪爾門', 51.8314900, 7.2807500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38139, 'Duisburg', 'Duisburg', 'DUI,Disburga,Duisboerj,Duisborg,Duisbourg,Duisburch,Duisburg,Duisburg and Hamborn,Duisburg-Hamborn,Duisburgas,Duisburgo,Duisbörj,Duizburg,Dujsburg,Duusboerg,Duusbörg,Duysburg,Dīsburga,Gorad Dujsburg,Ntouismpournk,Thuiscoburgum,de~yusuburuku,du sburk,du yi si bao,du''isaburga,duisburgi,dwiseubuleukeu,dwysbwrg,dwysbwrgh,dysbwrg,Ντούισμπουργκ,Горад Дуйсбург,Дуизбург,Дуйсбург,Дујсбург,Դույսբուրգ,דיסבורג,دويسبورغ,دویسبورگ,ڈوئسبرگ,ڈیسبورگ,डुइसबुर्ग,ดืสบูร์ก,დუისბურგი,ዱይስቡርግ፣ ጀርመን,デュースブルク,杜伊斯堡,뒤스부르크', 51.4324700, 6.7651600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38140, 'Duingen', 'Duingen', 'Duingen,Dujngen,du yin gen,Дуинген,Дуйнген,杜因根', 52.0044900, 9.6957800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38141, 'Duggendorf', 'Duggendorf', '', 49.1166700, 11.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38142, 'Duderstadt', 'Duderstadt', 'Dudershtadt,Dudershtat,Duderstadium,Dustadt,do~udashutatto,du de er si ta te,dwdrashtat,dwdrshtat,Дудерштадт,Дудерштат,دودراشتات,دودرشتات,ドゥーダーシュタット,杜德尔斯塔特', 51.5131200, 10.2595100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38143, 'Dudenhofen', 'Dudenhofen', 'Dudenkhofen,do~udenhofen,du deng huo fen,Дуденхофен,ドゥーデンホーフェン,杜登霍芬', 49.3186100, 8.3886100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38144, 'Düdenbüttel', 'Duedenbuettel', '', 53.5904000, 9.3500400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38145, 'Dudeldorf', 'Dudeldorf', 'Dudel''dorf,Dudeldorf,du de er duo fu,Дуделдорф,Дудельдорф,杜德尔多夫', 49.9749400, 6.6372400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38146, 'Duchroth', 'Duchroth', 'Dukhrot,Durot,du luo te,Дурот,Духрот,杜罗特', 49.7833300, 7.7333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38147, 'Ducherow', 'Ducherow', 'Ducherow,Dukherov,du hei luo,Духеров,杜黑罗', 53.7643600, 13.7821600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38148, 'Düchelsdorf', 'Duchelsdorf', 'Duchelsdorf,Düchelsdorf', 53.7333300, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38149, 'Drübeck', 'Druebeck', 'Drubeck,Druebeck,Drübeck', 51.8582000, 10.7183900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38150, 'Droyßig', 'Droyssig', 'Drojsig,de luo yi xi xi,Дройсиг,Дројсиг,德罗伊西希', 51.0424700, 12.0259000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38151, 'Drolshagen', 'Drolshagen', 'Draulsen,Drol''sgagen,Drol''skhagen,Drolshagen,Drolskhagen,de luo er si ha gen,drwlshaghn,drwlzhagn,Дролсхаген,Дрольсгаген,Дрольсхаген,درولزهاگن,درولسهاغن,德罗尔斯哈根', 51.0235800, 7.7735500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38152, 'Drognitz', 'Drognitz', '', 50.5879200, 11.5722900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38153, 'Drogen', 'Drogen', '', 50.9166700, 12.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38154, 'Drochtersen', 'Drochtersen', 'Drochters,Drochtersen,Drokhtersen,Drokhterzen,de luo te er sen,dorohotazen,Дрохтерзен,Дрохтерсен,ドロホターゼン,德罗特尔森', 53.7101500, 9.3846300, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38155, 'Dröbischau', 'Drobischau', 'Drobischau,Dröbischau', 50.6297600, 11.0730200, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38156, 'Driftsethe', 'Driftsethe', '', 53.3833300, 8.6166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38157, 'Driedorf', 'Driedorf', 'Dridorf,Driedorf,Drydorf,de li duo fu,Дридорф,Дрыдорф,Дрідорф,德里多夫', 50.6333300, 8.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38158, 'Drestedt', 'Drestedt', '', 53.3304700, 9.7573600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38159, 'Dresden', 'Dresden', 'DRS,Drazdany,Drazgany,Dresda,Dresde,Dresden,Dresdenas,Dresdeno,Dresdn,Drezda,Drezden,Drezdene,Drezno,Drjezdzany,Drježdźany,Drážďany,Drèsda,Drézdén,Drēzdene,Gorad Drehzdehn,de lei si dun,de rs dein,deuleseuden,doresuden,dresdena,drezdeni,drsdn,drysdn,drzdn,Δρέσδη,Горад Дрэздэн,Дрезден,Դրեզդեն,דרזדן,דרעזדן,درسدن,دريسدن,ڈریسڈن,ड्रेस्डेन,เดรสเดิน,დრეზდენი,ドレスデン,德累斯顿,드레스덴', 51.0508900, 13.7383200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38160, 'Drentwede', 'Drentwede', 'Drentvede,de lun te wei de,Дрентведе,德伦特韦德', 52.7438800, 8.5650400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38161, 'Drensteinfurt', 'Drensteinfurt', 'Drenshtajnfurt,Drenstaynfurt,Drenştaynfurt,de lun si tai yin fu er te,drnshtaynfwrt,Дренштайнфурт,Дренштајнфурт,درنشتاينفورت,درن‌اشتاینفورت,德伦斯泰因富尔特', 51.7953500, 7.7381500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38162, 'Drelsdorf', 'Drelsdorf', 'Drel''sdorf,Drelsdorf,Trelstorp,Troelstrup,Trölstrup,de lei er si duo fu,Дрелсдорф,Дрельсдорф,德雷尔斯多夫', 54.6054800, 9.0444900, 'DE', '2013-05-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38163, 'Dreitzsch', 'Dreitzsch', 'Dreitzsch', 50.7333300, 11.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38164, 'Dreisen', 'Dreisen', '', 49.6033300, 8.0105600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38165, 'Dreisbach', 'Dreisbach', '', 50.6166700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38166, 'Dreis', 'Dreis', 'Drajs,de lai si,Драйс,Драјс,德赖斯', 49.9409000, 6.8184500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38167, 'Dreifelden', 'Dreifelden', '', 50.5913900, 7.8361100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38168, 'Dreierwalde', 'Dreierwalde', '', 52.3319400, 7.5033300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38169, 'Dreieich', 'Dreieich', 'Drajajkh,Dreieich,de lai ai xi,doraiaihi,Драйайх,Драјајх,درای‌آیش,ドライアイヒ,德赖艾希', 50.0199700, 8.6961100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38170, 'Drehnow', 'Drehnow', 'Drehnow,Drjenow', 51.8666700, 14.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38171, 'Dreggers', 'Dreggers', 'Dreggers', 53.8833300, 10.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38172, 'Dreetz', 'Dreetz', '', 52.8029700, 12.4596100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38173, 'Drees', 'Drees', '', 50.3500000, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38174, 'Drebkau', 'Drebkau', 'Drebkau,Drebkau/Drjowk,Drjowk,de lei bu kao,drbkaw,drbkayw,Дребкау,Դրեբկաու,دربكاو,دربکائو,德雷布考', 51.6541200, 14.2231600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38175, 'Drebach', 'Drebach', 'Drebach,Drebakh,Ntrempach,Ντρέμπαχ,Дребах', 50.6758300, 13.0162000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38176, 'Dreba', 'Dreba', 'Dreba', 50.6666700, 11.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38177, 'Dranske', 'Dranske', 'Dranske,de lan si ke,Дранске,德兰斯克', 54.6311800, 13.2283100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38178, 'Dransfeld', 'Dransfeld', 'Dransfel''d,Dransfeld,de lan si fei er de,doransuferuto,dransfld,dranzfld,Дрансфелд,Дрансфельд,درانزفلد,درانسفلد,ドランスフェルト,德兰斯费尔德', 51.4991000, 9.7617900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38179, 'Drangstedt', 'Drangstedt', 'Drangshtedt,Drangshtet,Drangst,de lang si te,Дрангштедт,Дрангштет,德朗斯特', 53.6135900, 8.7557600, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38180, 'Drakenburg', 'Drakenburg', 'Drakenburg,de la ken bao,dorakenburuku,Дракенбург,ドラーケンブルク,德拉肯堡', 52.6868900, 9.2108300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38181, 'Drahnsdorf', 'Drahnsdorf', '', 51.9166700, 13.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38182, 'Drage', 'Drage', '', 54.3555900, 9.1577700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38183, 'Drage', 'Drage', '', 54.0040400, 9.5192700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38184, 'Drage', 'Drage', '', 53.4166700, 10.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38185, 'Drachselsried', 'Drachselsried', 'Drakhselsrid,Draksel''srid,de la sai er si li de,drakhzlsryd,Драксельсрид,Драксельсрід,Драхселсрид,Դրաքսելսրիդ,دراخزلسرید,德拉塞尔斯里德', 49.1075900, 13.0118500, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38186, 'Drachhausen', 'Drachhausen', '', 51.8902600, 14.3164200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38187, 'Döttesfeld', 'Dottesfeld', 'Doettesfeld,Döttesfeld', 50.6231700, 7.5488100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38188, 'Dotternhausen', 'Dotternhausen', 'Doternkhauzen,Dotterngauzen,Dotternkhauzen,duo te er en hao sen,Дотернхаузен,Доттернгаузен,Доттернхаузен,多特尔恩豪森', 48.2284800, 8.7922800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38189, 'Dötlingen', 'Dotlingen', 'Detlingen,Djotlingen,Doetlingen,Dotlingen,Dötlingen,de te lin gen,Детлинген,Дётлинген,德特林根', 52.9333300, 8.3833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38190, 'Dossenheim', 'Dossenheim', 'Dosenkhajm,Dossengajm,Dossenheim,Dossenkhajm,dossenhaimu,duo sen hai mu,Досенхајм,Доссенгайм,Доссенхайм,ドッセンハイム,多森海姆', 49.4502800, 8.6747200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38191, 'Döschnitz', 'Doschnitz', 'Doschnitz,Döschnitz', 50.6166700, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38192, 'Dörzbach', 'Dorzbach', 'Dercbakh,Djorcbakh,Doerzbach,Dorzbach Ober Franken,Dörzbach,Dörzbach Ober Franken,de er ci ba he,derutsubahha,Дерцбах,Дёрцбах,デルツバッハ,德尔茨巴赫', 49.3835500, 9.7073200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38193, 'Dörverden', 'Dorverden', 'Derverden,Djorferden,Doerbern,Doerverden,Dorferdenas,Dorverden,Dörbern,Dörverden,de er fei er deng,deruferuden,Дерверден,Дёрферден,デルフェルデン,德尔费尔登', 52.8500000, 9.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38194, 'Dorum', 'Dorum', 'Dorum,duo lu mu,Дорум,多鲁姆', 53.6833300, 8.5666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38195, 'Dortmund', 'Dortmund', 'DTM,Dortmund,Dortmundas,Dortmunde,Dortmundi,Dueoerpm,Düörpm,Gorad Dortmund,Ntortmount,Throtmenni,Tremonia,d xr thmund,doleuteumunteu,dortamunda,dorutomunto,duo te meng de,dwrtmwnd,Ντόρτμουντ,Горад Дортмунд,Дортмунд,דורטמונד,دورتموند,دۆرتمۆند,ڈارٹمنڈ,डॉर्टमुंड,ดอร์ทมุนด์,დორტმუნდი,ドルトムント,多特蒙德,도르트문트', 51.5149400, 7.4660000, 'DE', '2016-03-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38196, 'Dörth', 'Dorth', 'Doerth,Dörth', 50.1500000, 7.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38197, 'Dorsten', 'Dorsten', 'Doessen,Dorsten,Dössen,ZCX,duo si teng,dwrstn,Дорстен,دورستن,多斯滕', 51.6616600, 6.9651400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38198, 'Dorstadt', 'Dorstadt', 'Dorshtadt,Dorshtat,duo er si ta te,Дорштадт,Дорштат,多尔斯塔特', 52.1000000, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38199, 'Dorsheim', 'Dorsheim', '', 49.9166700, 7.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38200, 'Dorsel', 'Dorsel', '', 50.3833300, 6.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38201, 'Dörsdorf', 'Dorsdorf', '', 50.2461600, 8.0096300, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38202, 'Dörscheid', 'Doerscheid', 'Dershajd,Djorshajd,Doerscheid,Dörscheid,de er sha yi de,Дершајд,Дёршайд,德尔沙伊德', 50.1000000, 7.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38203, 'Dörrmoschel', 'Dorrmoschel', 'Doerrmoschel,Dörrmoschel', 49.6166700, 7.7500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38204, 'Dörrenbach', 'Dorrenbach', 'Derenbakh,Derrebach,Djorrenbakh,de lun ba he,Деренбах,Дёрренбах,德伦巴赫', 49.0897200, 7.9614000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38205, 'Dörrebach', 'Doerrebach', 'Derebakh,Djorrebakh,de lei ba he,Деребах,Дёрребах,德雷巴赫', 49.9453800, 7.7201900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38206, 'Dörpstedt', 'Dorpstedt', '', 54.4333300, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38207, 'Dörpling', 'Doerpling', 'Doerpling,Dorpling,Dörpling', 54.2592200, 9.3050300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38208, 'Dörphof', 'Dorphof', 'Dorphof,Dörphof', 54.6166700, 9.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38209, 'Dörpen', 'Dorpen', 'Derpen,Djorpen,Dorpen,Dörpen,de er peng,Дерпен,Дёрпен,德尔彭', 52.9646900, 7.3227300, 'DE', '2011-09-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38210, 'Dornum', 'Dornum', 'Dornum,duo er nu mu,Дорнум,多尔努姆', 53.6464800, 7.4295700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38211, 'Dornstetten', 'Dornstetten', 'Dornshteten,Dornshtetten,Dornstetten,duo er en si te teng,dwrnshtytn,Дорнштетен,Дорнштеттен,Դորնշտեթեն,دورنشتيتن,دورن‌اشتتن,多尔恩斯特滕', 48.4719800, 8.4981700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38212, 'Dornstadt', 'Dornstadt', 'Dornshtadt,Dornshtat,Dornstadt,duo er en si ta te,Дорнштадт,Дорнштат,Դորնշտադտ,დორნშტადტი,多尔恩斯塔特', 48.4669700, 9.9443400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38213, 'Dörnick', 'Doernick', 'Doernick,Dornick,Dörnick', 54.1666700, 10.3666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38214, 'Dornholzhausen', 'Dornholzhausen', '', 50.2703100, 7.7898200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38215, 'Dornheim', 'Dornheim', '', 50.8350900, 10.9938000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38216, 'Dornhan', 'Dornhan', 'Dorhan,Dorngan,Dornhan,Dornkhan,duo er en han,dwrnhan,Дорнган,Дорнхан,Դորհան,دورنهان,多尔恩汉', 48.3500800, 8.5090100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38217, 'Dorn-Dürkheim', 'Dorn-Durkheim', 'Dorn-Duerkheim,Dorn-Dürkheim', 49.7686100, 8.2697200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38218, 'Dorndorf', 'Dorndorf', '', 50.8347200, 10.0892100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38219, 'Dörnberg', 'Dornberg', '', 50.3256700, 7.8835000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38220, 'Dormitz', 'Dormitz', '', 49.5978600, 11.1176500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38221, 'Dormettingen', 'Dormettingen', 'Dormetingen,Dormettingen,duo er mei ting gen,Дорметинген,Дорметтинген,Дорметтінген,多尔梅廷根', 48.2368800, 8.7732700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38222, 'Dormagen', 'Dormagen', 'Dormagen,Dormaje,ZCW,duo er ma gen,dwrmaghn,dwrmagn,Дормаген,دورماغن,دورماگن,ዶርማገን,多爾馬根', 51.0968300, 6.8316700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38223, 'Dorfprozelten', 'Dorfprozelten', 'Dorfprocel''ten,Dorfprocelten,dorufupurotsu~eruten,duo fu pu luo cai er teng,Дорфпроцелтен,Дорфпроцельтен,Դորֆպրոցելտեն,ドルフプロツェルテン,多夫普罗采尔滕', 49.7805600, 9.3802800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38224, 'Dorfhain', 'Dorfhain', 'Dorfkhajn,duo fu hai en,Дорфхайн,Дорфхајн,多夫海恩', 50.9333300, 13.5666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38225, 'Dorfen', 'Dorfen', 'Dorfen,duo er fen,dwrfn,Дорфен,دورفن,ڈورفن,多尔芬', 48.2703700, 12.1605600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38226, 'Dorfchemnitz', 'Dorfchemnitz', 'Dorfchemnitzi vald,Dorfkemnic,Dorfkhemnic,duo fu xie mu ni ci,Дорфкемниц,Дорфхемниц,多夫歇姆尼茨', 50.7666700, 13.4500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38227, 'Dorfchemnitz', 'Dorfchemnitz', '', 50.6636300, 12.8365100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38228, 'Dörentrup', 'Dorentrup', 'Derentrup,Djorentrup,Doerentrup,Dörentrup,de lun te lu pu,derentorupu,Дерентруп,Дёрентруп,デーレントルプ,德伦特鲁普', 52.0410900, 9.0027800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38229, 'Donzdorf', 'Donzdorf', 'Doncdorf,dong ci duo fu,dwntsdwrf,dwnzdwrf,Донцдорф,دونتسدورف,دونزدورف,栋茨多夫', 48.6854400, 9.8105300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38230, 'Donsieders', 'Donsieders', 'Donsiders,Donziders,dong xi de er si,Донзидерс,Донсидерс,栋西德尔斯', 49.2652600, 7.6419200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38231, 'Donnersdorf', 'Donnersdorf', 'Donersdorf,Donnersdorf,duo nei er si duo fu,dwnrsdwrf,Донерсдорф,Доннерсдорф,دونرسدورف,多内尔斯多夫', 49.9666700, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38232, 'Donndorf', 'Donndorf', 'Dondorf,Donndorf,dong duo fu,Дондорф,Донндорф,栋多夫', 51.2940200, 11.3728300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38233, 'Donauwörth', 'Donauwoerth', 'Doanaweat,Donauv''ort,Donauvert,Donauvjort,Donauwerth,Donauwoerth,Donauworth,Donauwörth,Ntonaouvert,donauverti,donauvu~eruto,duo nao wo te,dwnawfwrt,dwnawwrth,Ντόναουβερτ,Донауверт,Донаувьорт,Донаувёрт,Դոնաուվյորթ,دوناوفورت,دوناوورث,ڈوناؤورتھ,დონაუვერთი,ドナウヴェルト,多瑙沃特', 48.7180400, 10.7793000, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38234, 'Donaustauf', 'Donaustauf', 'Donaushtauf,Donaustauf,duo nao si tao fu,dwnawshtawf,Донаустауф,Донауштауф,Донаўштаўф,Դոնաուշտաուֆ,دوناوشتاوف,多瑙斯陶夫', 49.0325800, 12.2045900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38235, 'Donaueschingen', 'Donaueschingen', 'Donauehshingen,Donaueschingen,Donaueshingen,Doneschinga,donauesshingen,duo nao ai xin gen,dwnashyngn,dwnawshynghn,Донауешинген,Донауэшинген,دوناشینگن,دوناوشينغن,ドナウエッシンゲン,多瑙艾辛根', 47.9551400, 8.4970700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38236, 'Domsühl', 'Domsuehl', 'Domsuehl,Domsühl,Domzil,Domzjul'',duo mu xu he er,Домзил,Домзюль,多姆叙赫尔', 53.4872300, 11.7709900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38237, 'Dommitzsch', 'Dommitzsch', 'Domich,Domicsh,Dommica,Dommich,Dommitzsch,Dommiča,duo mi ci xi,dwmytssh,dwmytzsh,Домицш,Домич,Доммич,Домміч,دوميتسش,دومیتزش,多米茨希', 51.6407100, 12.8794000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38238, 'Dommershausen', 'Dommershausen', 'Domerskhauzen,Dommerskhauzen,duo mei er si hao sen,Домерсхаузен,Доммерсхаузен,多梅尔斯豪森', 50.1500000, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38239, 'Dömitz', 'Doemitz', 'Demic,Demica,Djomic,Doemitz,Dēmica,de mi ci,dwmsytz,dwmyts,Демиц,Дёмиц,دومسیتز,دوميتس,德米茨', 53.1408000, 11.2501700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38240, 'Domersleben', 'Domersleben', 'Daumerschlaeh,Daumerschläh,Domersleben,Домерслебен', 52.0919900, 11.4375700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38241, 'Dombühl', 'Dombuhl', 'Dombil,Dombjul'',Dombuehl,Dombuhl,Dombyul,Dombühl,domubyuru,dong bi he er,Домбил,Домбюль,Դոմբյուլ,ドムビュール,栋比赫尔', 49.2534900, 10.2854200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38242, 'Döllstädt', 'Dollstadt', 'Delshtet,Djol''shtedt,Doellstaedt,Dollstadt,Döllstädt,Делштет,Дёльштедт', 51.0833300, 10.8166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38243, 'Dollrottfeld', 'Dollrottfeld', 'Dollrottfeld', 54.6333300, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38244, 'Döllnitz', 'Doellnitz', '', 51.4077700, 12.0283100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38245, 'Dollerup', 'Dollerup', 'Dolerup,Dollerup,duo lai lu pu,Долеруп,Доллеруп,多莱鲁普', 54.7779800, 9.6798100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38246, 'Dollern', 'Dollern', '', 53.5333300, 9.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38247, 'Dollbergen', 'Dollbergen', 'Dolberge [a. 1226],Dollbarge,Dollbargen,Dolle', 52.4067100, 10.1809800, 'DE', '2014-05-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38248, 'Dolgesheim', 'Dolgesheim', '', 49.7944400, 8.2569400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38249, 'Dölbau', 'Doelbau', '', 51.4670100, 12.0573500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38250, 'Dohren', 'Dohren', '', 53.3000000, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38251, 'Dohr', 'Dohr', '', 50.1293300, 7.1215100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38252, 'Dohna', 'Dohna', 'Dona,Donin,Donín,dona,duo na,dwna,Дона,دونا,多纳,도나', 50.9562100, 13.8583900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38253, 'Dohm-Lammersdorf', 'Dohm-Lammersdorf', '', 50.2666700, 6.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38254, 'Dohma', 'Dohma', 'Doma,Дома', 50.9166700, 13.9333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38255, 'Döhlau', 'Dohlau', 'Doehlau,Döhlau', 50.2833300, 11.9500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38256, 'Dogern', 'Dogern', 'Dogern,duo ge er en,Догерн,多格尔恩', 47.6095200, 8.1671300, 'DE', '2013-04-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38257, 'Dodenburg', 'Dodenburg', '', 49.9166700, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38258, 'Dockweiler', 'Dockweiler', 'Dokvajler,duo ke wei lei,Доквайлер,Доквајлер,多克韦勒', 50.2500000, 6.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38259, 'Dockendorf', 'Dockendorf', '', 49.9166700, 6.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38260, 'Döbritz', 'Doebritz', '', 50.7000000, 11.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38261, 'Döbritschen', 'Dobritschen', '', 50.9192100, 11.4759900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38262, 'Dobitschen', 'Dobitschen', 'Dobichen,duo bi ci xing,Добичен,多比茨兴', 50.9500000, 12.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38263, 'Dobersdorf', 'Dobersdorf', '', 54.3189300, 10.2801100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38264, 'Doberschütz', 'Doberschutz', 'Dobershic,Dobershjuc,duo bei er xu ci,Добершиц,Добершюц,多贝尔许茨', 51.4987000, 12.7479200, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38265, 'Döbernitz', 'Doebernitz', '', 51.5124100, 12.3475300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38266, 'Doberlug-Kirchhain', 'Doberlug-Kirchhain', 'Doberlug Kirxhayn,Doberlug-Kirchhain,Doberlug-Kirkhajn,Doberlug-Kirkhkhajn,Doberluga-Kirhaina,Dobrilugk-Kirchhain,Dobrjolug-Gostkow,Dobrjoług-Góstkow,duo bei er lu ge-ji er xia yin,dwbrlwg-kyrshhayn,dwbrlwgh-kyrshhayn,Доберлуг-Кирхајн,Доберлуг-Кирххайн,Доберлуг-Кирххајн,Դոբերլուգ Կիրխհայն,دوبرلوغ-كيرشهاين,دوبرلوگ-کیرشهاین,多贝尔卢格-基尔夏因', 51.6257800, 13.5623200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38267, 'Döbeln', 'Doebeln', 'Debel''n,Debeln,Debelne,Djobel''n,Dobeln,Doblin,Doebeln,Doeberln,Döbeln,Dēbelne,Stadt Dobeln,Stadt Döbeln,de bo er en,dwbln,Дебелн,Дебельн,Дёбельн,Дөбельн,دوبلن,德伯爾恩', 51.1221000, 13.1102700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38268, 'Dobel', 'Dobel', 'Dobel,Dobel'',duo bei er,Добел,Добель,Դոբել,多贝尔', 48.8000000, 8.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38269, 'Dobbertin', 'Dobbertin', 'Dobbertin,Dobertin,duo bei er ting,Доббертин,Добертин,多贝尔廷', 53.6230600, 12.0746600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38270, 'Ditzingen', 'Ditzingen', 'Dicingen,Ditcingen,di qin gen,dytzyngn,dytzynjyn,Дитцинген,Дицинген,Дітцинген,ديتزينجين,دیتزینگن,迪钦根', 48.8267200, 9.0670300, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38271, 'Dittweiler', 'Dittweiler', 'Ditvajler,di te wei lei,Дитвайлер,Дитвајлер,迪特韦勒', 49.4302900, 7.3356100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38272, 'Dittersdorf', 'Dittersdorf', '', 50.6500000, 11.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38273, 'Dittenheim', 'Dittenheim', 'Ditenkhajm,Dittengajm,Dittenkhajm,Дитенхајм,Диттенхайм,Діттенгайм,Դիթենհայմ', 49.0553600, 10.7920100, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38274, 'Dittelbrunn', 'Dittelbrunn', 'Ditelbrun,Dittel''brunn,Dittelbrunn,di te er bu lun,dytlbrwn,Дителбрун,Диттельбрунн,Діттельбрунн,دیتلبرون,迪特尔布伦', 50.0721200, 10.2197400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38275, 'Ditscheid', 'Ditscheid', '', 50.3000000, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38276, 'Ditfurt', 'Ditfurt', 'Ditfurt,di te fu er te,Дитфурт,迪特富尔特', 51.8333300, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38277, 'Dissen', 'Dissen', 'Dissen', 52.1159100, 8.1995600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38278, 'Dischingen', 'Dischingen', 'Dischingen,Dishingen,di xin gen,Дишинген,Дішинген,迪欣根', 48.7000000, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38279, 'Dirmstein', 'Dirmstein', 'Dermschdae,Dermschdä,Dirmshtajn,Dirmstein,di er mu si tai yin,Дирмштайн,Дирмштајн,迪尔姆斯泰因', 49.5633300, 8.2447200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38280, 'Dirlewang', 'Dirlewang', 'Dirlevang,Dirlewang,di er lai wang,Дирлеванг,Дірлеванг,Դիրլևանգ,迪尔莱旺', 48.0019500, 10.5030600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38281, 'Dippoldiswalde', 'Dippoldiswalde', 'Dipoldisvalde,Dippol''disval''de,di bo er di si wa er de,dybwldysfaldh,dypldyzwaldh,Диполдисвалде,Диппольдисвальде,ديبولديسفالده,دیپلدیزوالده,迪波尔迪斯瓦尔德', 50.8962100, 13.6690500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38282, 'Dipperz', 'Dipperz', 'Diperc,Dipperc,di pei er ci,Диперц,Дипперц,Діпперц,迪佩尔茨', 50.5433300, 9.7958600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38283, 'Dippach', 'Dippach', '', 50.9195900, 10.0423600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38284, 'Dintesheim', 'Dintesheim', '', 49.7075000, 8.1433300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38285, 'Dinslaken', 'Dinslaken', 'Dinslaken,Dinslakena,Ntinslaken,ZCV,ding si la ken,dynslakn,dynzlakn,Ντίνσλακεν,Динслакен,Динслакена,Дінслакен,دينسلاكن,دینزلاکن,丁斯拉肯', 51.5622700, 6.7434000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38286, 'Dinklage', 'Dinklage', 'Dinklage,ding ke la ge,dynklagh,dynklaghh,Динклаге,دينكلاغه,دینکلاگه,丁克拉格', 52.6622300, 8.1244000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38287, 'Dinkelscherben', 'Dinkelscherben', 'Dinkel''sherben,Dinkelserben,Dinkelsherben,ding ke er she er ben,dynklshrbn,Динкелшербен,Динкельшербен,Дінкельшербен,Դինկելշերբեն,دینکلشربن,丁克尔舍尔本', 48.3482600, 10.5889300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38288, 'Dinkelsbühl', 'Dinkelsbuhl', 'Dinkel''sbjul'',Dinkelsbil,Dinkelsbiulis,Dinkelsbuehl,Dinkelsbyul,Dinkelsbühl,ding ke er si bi er,dinkerusubyuru,dynklsbwl,dynklzbwl,Динкелсбил,Динкельсбюль,Дінкельсбюль,Դինկելսբյուլ,دينكلسبول,دینکلزبول,ディンケルスビュール,丁克尔斯比尔', 49.0694200, 10.3198500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38289, 'Dingsleben', 'Dingsleben', 'Dingsleben', 50.4333300, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38290, 'Dingolshausen', 'Dingolshausen', 'Dingol''sgauzen,Dingol''skhauzen,Dingolshausen,Dingolskhauzen,ding ge er si hao sen,dyngwlshawzn,Динголсхаузен,Дингольсхаузен,Дінгольсгаузен,دینگولسهاوزن,丁戈尔斯豪森', 49.9071000, 10.3903200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38291, 'Dingolfing', 'Dingolfing', 'Dingelfing,Dinglfing,Dingol''fing,Dingolfing,ding ge er fen,dynghwlfyngh,dyngwlfyng,Динголфинг,Дингольфинг,Дінгольфінг,Դինգոլֆինգ,دينغولفينغ,دینگولفینگ,ڈینگولفنگ,丁戈尔芬', 48.6424400, 12.4928300, 'DE', '2017-04-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38292, 'Dingen', 'Dingen', '', 53.9666700, 9.1166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38293, 'Dingelstädt', 'Dingelstaedt', 'Dingel''shtedt,Dingelshtet,Dingelstadt,Dingelstaedt,Dingelstädt,ding ge er shi tai te,dynghlshtyt,Дингелштет,Дингельштедт,دينغلشتيت,دینگل‌اشتت,丁格尔施泰特', 51.3152900, 10.3174000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38294, 'Dingdorf', 'Dingdorf', '', 50.1500000, 6.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38295, 'Dimbach', 'Dimbach', '', 49.1666700, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38296, 'Dillstädt', 'Dillstadt', 'Dillstaedt,Dillstädt', 50.5833300, 10.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38297, 'Dillingen an der Donau', 'Dillingen an der Donau', 'Danubi Dilingen,Dilinga,Dilingen na Dunavu,Dillingen,Dillingen an der Donau,Dillingen-an-der-Donau,Dillingen-na-Dunae,dylynghn an dr dwnaw,dylyngn an dr danwb,Дилинген на Дунаву,Диллинген-ан-дер-Донау,Диллинген-на-Дунае,Діллінген-ан-дер-Донау,Դանուբի Դիլինգեն,ديلينغن أن در دوناو,دیلینگن آن در دانوب,ڈیلینجن', 48.5815300, 10.4952700, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38298, 'Dillingen', 'Dillingen', 'Dillengen,Dillingen', 49.3555700, 6.7278100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38299, 'Dillendorf', 'Dillendorf', '', 49.9166700, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38300, 'Dillenburg', 'Dillenburg', 'Dilenburg,Dillenberg,Dillenboarch,Dillenburg,Gorad Dylenburg,di lun bao,dylnbwrg,dylnbwrgh,Горад Дыленбург,Диленбург,Дилленбург,Ділленбург,ديلنبورغ,دیلنبورگ,迪伦堡', 50.7411400, 8.2869900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38301, 'Dill', 'Dill', '', 49.9166700, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38302, 'Diez', 'Diez', 'Dic,Dietz,Diez,Diez an der Lahn,di ci,dyz  alman,Диц,دیز، آلمان,迪茨', 50.3741900, 8.0073500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38303, 'Dietzenbach', 'Dietzenbach', 'Dicenbakh,Dietzenbach,Ditcenbakh,Stadt Dietzenbach,di cen ba he,ditsu~enbahha,dytsnbakh,dyznbakh,Дитценбах,Диценбах,Дітценбах,ديتسنباخ,دیزنباخ,ディーツェンバッハ,迪岑巴赫', 50.0097600, 8.7778300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38304, 'Dietrichingen', 'Dietrichingen', '', 49.1833300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38305, 'Dietramszell', 'Dietramszell', 'Ditramscel,Ditramscel'',Ditramscell'',di te la mu si ce er,dytramstsl,Дитрамсцел,Дитрамсцелль,Дітрамсцель,Դիտրամսցել,دیترامستسل,迪特拉姆斯策尔', 47.8487100, 11.5953000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38306, 'Dietmannsried', 'Dietmannsried', 'Dietmannsried,Ditmannsrid,Ditmansrid,di te man si li de,Дитмансрид,Дітманнсрід,Դիտմանսրիդ,迪特曼斯里德', 47.8078700, 10.2894800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38307, 'Dietingen', 'Dietingen', 'Ditingen,di ting gen,Дитинген,Дітінген,迪廷根', 48.2048000, 8.6486400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38308, 'Diethardt', 'Diethardt', '', 50.1666700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38309, 'Dietfurt', 'Dietfurt', 'Diefurt,Dietfurt', 49.0357800, 11.5862400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38310, 'Dieterskirchen', 'Dieterskirchen', 'Diterskirkhen,di te er si ji er xing,dytrskyrshn,Дитерскирхен,Дітерскірхен,دیترسکیرشن,迪特尔斯基尔兴', 49.4166700, 12.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38311, 'Dietersheim', 'Dietersheim', 'Ditersgajm,Diterskhajm,di te er si hai mu,Дитерсхайм,Дитерсхајм,Дітерсгайм,Դիթերսհայմ,迪特尔斯海姆', 49.5563100, 10.5407400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38312, 'Dietersburg', 'Dietersburg', 'Diederschburg,Ditersburg,di te er si bao,dytrsbwrg,Дитерсбург,Дітерсбург,Դիթերսբուրգ,دیترسبورگ,迪特尔斯堡', 48.4924900, 12.9249900, 'DE', '2012-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38313, 'Dieterode', 'Dieterode', 'Dieterode', 51.3000000, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38314, 'Dietenhofen', 'Dietenhofen', 'Dietenhofen,Ditengofen,Ditenhofen,Ditenkhofen,di teng huo fen,ditenhofen,Дитенхофен,Дітенгофен,Դիտենհոֆեն,ディーテンホーフェン,迪滕霍芬', 49.3999700, 10.6897500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38315, 'Dietenheim', 'Dietenheim', 'Dietenheim,Ditengajm,Ditenhaym,Ditenkhajm,di teng hai mu,dytnhaym,Дитенхайм,Дитенхајм,Дітенгайм,Դիտենհայմ,ديتنهايم,دیتنهایم,დიტენჰაიმი,迪滕海姆', 48.2107200, 10.0716300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38316, 'Dießen am Ammersee', 'Diessen am Ammersee', 'Diessen,Diessen am Ammersee,Dießen,Dießen am Ammersee,Markt Diessen am Ammersee,Markt Dießen am Ammersee', 47.9508500, 11.1030600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38317, 'Diespeck', 'Diespeck', 'Dispek,di si pei ke,Диспек,Діспек,Դիսպեք,迪斯佩克', 49.6000000, 10.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38318, 'Dieskau', 'Dieskau', '', 51.4355300, 12.0403500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38319, 'Diesdorf', 'Diesdorf', 'Diesdorf,Magdeburg-Diesdorf,Thieterisdorf', 52.1307500, 11.5648300, 'DE', '2015-12-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38320, 'Dierscheid', 'Dierscheid', '', 49.9000000, 6.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38321, 'Dierfeld', 'Dierfeld', '', 50.0833300, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38322, 'Dierdorf', 'Dierdorf', 'Dierdorf,Dirdorf,di er duo fu,diadorufu,dyrdwrf,Дирдорф,ديردورف,دیردورف,ディーアドルフ,迪尔多夫', 50.5464700, 7.6527100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38323, 'Dierbach', 'Dierbach', '', 49.0808300, 8.0672200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38324, 'Diepholz', 'Diepholz', 'Deefholt,Diepholz,Diepholzi vald,Dipkhol''c,Dipkholc,di pu huo er ci,dybhwlts,dyphwlz,Дипхолц,Дипхольц,ديبهولتس,دیپهولز,迪普霍尔茨', 52.6078300, 8.3700500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38325, 'Dienstweiler', 'Dienstweiler', '', 49.6333300, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38326, 'Diensdorf-Radlow', 'Diensdorf-Radlow', '', 52.2500000, 14.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38327, 'Dienheim', 'Dienheim', 'Dinkhajm,ding hai mu,Динхайм,Динхајм,丁海姆', 49.8372200, 8.3497200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38328, 'Dienethal', 'Dienethal', '', 50.3041400, 7.7774600, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38329, 'Dielmissen', 'Dielmissen', 'Dil''missen,Dilmisen,di er mi sen,dirumissen,Дилмисен,Дильмиссен,ディールミッセン,迪尔米森', 51.9706100, 9.6066900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38330, 'Dielkirchen', 'Dielkirchen', 'Dil''kirkhen,Dilkirkhen,di er ji er xing,Дилкирхен,Дилькирхен,迪尔基尔兴', 49.6666700, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38331, 'Dielheim', 'Dielheim', 'Dielheim,Dil''gajm,Dil''khajm,Dilkhajm,diruhaimu,Дилхајм,Дильхайм,Дільгайм,ディールハイム', 49.2841700, 8.7380600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38332, 'Diekholzen', 'Diekholzen', 'Dikkhol''cen,Dikkholcen,di ke huo er cen,Дикхолцен,Дикхольцен,迪克霍尔岑', 52.0961700, 9.9194500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38333, 'Diefenbach', 'Diefenbach', '', 50.0333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38334, 'Diedorf', 'Diedorf', 'Didorf,Diedorf,di duo fu,dydwrf,Дидорф,Дідорф,Դիդորֆ,دیدورف,迪多夫', 48.3532000, 10.7820600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38335, 'Dieburg', 'Dieburg', 'Diburg,Dieburg,Gorad Dyburg,di bao,diburuku,dybwrg,dybwrgh,Горад Дыбург,Дибург,Дібург,ديبورغ,دیبورگ,ディーブルク,迪堡', 49.8973800, 8.8461300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38336, 'Dieblich', 'Dieblich', 'Diblikh,di bu li xi,Диблих,迪布利希', 50.3139600, 7.4718500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38337, 'Diebach', 'Diebach', 'Dibakh,Dibax,di ba he,dibahha,Дибах,Дібах,Դիբախ,ディーバッハ,迪巴赫', 49.3091200, 10.1918800, 'DE', '2012-10-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38338, 'Didderse', 'Didderse', 'De''esse,Didderze,Diderse,Ditenhusen [a. 924],Thidersen [a. 1272],di de er sai,Диддерзе,Дидерсе,迪德尔塞', 52.3804200, 10.4029400, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38339, 'Dickesbach', 'Dickesbach', 'Dikesbakh,Dikkesbakh,di ke si ba he,Дикесбах,Диккесбах,迪克斯巴赫', 49.7166700, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38340, 'Dickenschied', 'Dickenschied', 'Dikenshid,Dikkenshid,di ken xi de,Дикеншид,Диккеншид,迪肯席德', 49.9000000, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38341, 'Dickendorf', 'Dickendorf', '', 50.7333300, 7.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38342, 'Dickel', 'Dickel', '', 52.6449400, 8.4716600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38343, 'Dichtelbach', 'Dichtelbach', '', 50.0086000, 7.6957100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38344, 'Dhronecken', 'Dhronecken', '', 49.7166700, 6.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38345, 'Dexheim', 'Dexheim', '', 49.8472200, 8.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38346, 'Deutzen', 'Deutzen', 'Deutzeni vald,Dojcen,duo yi cen,Дойцен,Дојцен,多伊岑', 51.1121700, 12.4254100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38347, 'Deutz', 'Deutz', 'Divitia,Duex,Düx,Koeln-Deutz,Köln-Deutz,dao yi ci,道依茨', 50.9346300, 6.9749500, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38348, 'Deutschneudorf', 'Deutschneudorf', 'Deutschneudorf,Deutschneudorfi vald,Dojchnojdorf,duo yi ci xi nuo yi duo fu,Дойчнойдорф,Дојчнојдорф,多伊茨希诺伊多夫', 50.6166700, 13.4666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38349, 'Deutsch Evern', 'Deutsch Evern', 'Dojch Evern,Dojch-Ehfern,duo yi ci xi ai fei er en,Дойч-Эферн,Дојч Еверн,多伊茨希埃费尔恩', 53.2000000, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38350, 'Deuselbach', 'Deuselbach', '', 49.7500000, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38351, 'Deuna', 'Deuna', 'Deuna,Dojna,duo yi na,Дойна,Дојна,多伊纳', 51.3545000, 10.4743900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38352, 'Deuerling', 'Deuerling', '', 49.0372000, 11.9104500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38353, 'Deudesfeld', 'Deudesfeld', '', 50.1025800, 6.7307600, 'DE', '2016-10-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38354, 'Deuben', 'Deuben', 'Deuben', 51.1096800, 12.0725900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38355, 'Detzem', 'Detzem', '', 49.8166700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38356, 'Dettum', 'Dettum', 'Dettum,Detum,de tu mu,Деттум,Детум,德图姆', 52.1724600, 10.6680700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38357, 'Dettingen unter Teck', 'Dettingen unter Teck', 'Detingen pod Tekom,Dettingen,Dettingen unter Teck,Dettingen-unter-Tek,de ting gen weng te er te ke,Детинген под Теком,Деттинген-унтер-Тек,Деттінген-унтер-Тек,Դեթինգեն ունտեր Տեկ,德廷根翁特尔特克', 48.6166700, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38358, 'Dettingen an der Iller', 'Dettingen an der Iller', 'Detingen an der Iler,Dettingen,Dettingen an der Iller,Dettingen-an-der-Iller,Dettingen-na-Illere,Illerdegi Dettingen,yi lai er he pan de ting gen,Детинген ан дер Илер,Деттинген-на-Иллере,Деттінген-ан-дер-Іллер,Иллердеги Деттинген,Իլերի Դեթինգեն,დეტინგენ-ან-დერ-ილერი,伊莱尔河畔德廷根', 48.1000000, 10.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38359, 'Dettingen an der Erms', 'Dettingen an der Erms', 'Detingen an der Erms,Dettingen,Dettingen-an-der-Erms,Dettingen-na-Ehrmse,de ting gen an de er ai er mu si,Детинген ан дер Ермс,Деттинген-на-Эрмсе,Деттінген-ан-дер-Ермс,德廷根安德尔埃尔姆斯', 48.5307700, 9.3445800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38360, 'Dettingen', 'Dettingen', '', 48.2624600, 9.7216100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38361, 'Dettighofen', 'Dettighofen', '', 47.6233300, 8.4851200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38362, 'Dettenhausen', 'Dettenhausen', 'Detenkhauzen,Dettengauzen,Dettenkhauzen,de teng hao sen,Детенхаузен,Деттенгаузен,Деттенхаузен,德滕豪森', 48.6075800, 9.1004100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38363, 'Dettelbach', 'Dettelbach', 'Detelbakh,Dettel''bakh,Dettelbach,de te er ba he,dtlbakh,Детелбах,Деттельбах,Դեթելբախ,دتلباخ,ڈیٹلباخ,德特尔巴赫', 49.8029500, 10.1651900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38364, 'Detmold', 'Detmold', 'Detmol''d,Detmold,Detmolda,Detmoldas,dai te mo er de,deteumolteu,deth mx ld,detomoruto,dtmwld,Детмолд,Детмольд,دتمولد,เดทมอลด์,デトモルト,代特莫尔德,데트몰트', 51.9385500, 8.8731800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38365, 'Detmerode', 'Detmerode', '', 52.3901600, 10.7448000, 'DE', '2016-03-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38366, 'Detern', 'Detern', 'Detern,Lehe Kol,Tjootern,de te er en,Детерн,德特尔恩', 53.2092700, 7.6739500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38367, 'Dessighofen', 'Dessighofen', 'Dessighoven', 50.2580200, 7.7719700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38368, 'Dessau', 'Dessau', 'Desau,Desava,Dessau,Dessau-Rosslau,Dessau-Roßlau,Dessavia,Ntesaou,de shao,desau,dessau,dsayw,dysaw,Ντεσάου,Десау,Дессау,דסאו,دسائو,ديساو,დესაუ,デッサウ,德绍,데사우', 51.8386400, 12.2455500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38369, 'Desloch', 'Desloch', 'Deslokh,de si luo,Деслох,德斯洛', 49.7166700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38370, 'Dersum', 'Dersum', '', 52.9611200, 7.2739400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38371, 'Dersekow', 'Dersekow', 'Derzekov,de er sai ke,Дерзеков,德尔塞科', 54.0458300, 13.2924300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38372, 'Derschen', 'Derschen', '', 50.7166700, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38373, 'Dersau', 'Dersau', 'Dersau', 54.1180500, 10.3336800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38374, 'Dernbach', 'Dernbach', '', 50.5500000, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38375, 'Dernbach', 'Dernbach', '', 50.4555100, 7.7900300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38376, 'Dernbach', 'Dernbach', '', 49.2472200, 8.0052800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38377, 'Dernau', 'Dernau', 'Dernau,de er nao,Дернау,德尔瑙', 50.5333300, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38378, 'Dermbach', 'Dermbach', 'Dermbakh,de er en ba he,Дермбах,德尔恩巴赫', 50.7138300, 10.1183900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38379, 'Derental', 'Derental', 'Derental,Derental'',de lun ta er,derentaru,Дерентал,Деренталь,デーレンタール,德伦塔尔', 51.6947500, 9.4320200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38380, 'Derenburg', 'Derenburg', 'Derenburg,Деренбург', 51.8708600, 10.9102900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38381, 'Denzlingen', 'Denzlingen', 'Denclingen,Denzlingen,deng ci lin gen,Денцлинген,Денцлінген,Դենցլինգեն,登茨林根', 48.0666700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38382, 'Dentlein am Forst', 'Dentlein am Forst', 'Dentlajn am Forst,Dentlajn-am-Forst,Dentlaym am Forst,Dentlein,Dentlein a. Forst,Dentlein am Forst,Dentljajn,deng te lai yin a mu fu er si te,Дентлайн-ам-Форст,Дентлајн ам Форст,Дентляйн,Դենտլայմ ամ Ֆորստ,デントライン・アム・フォルスト,登特莱因阿姆福尔斯特', 49.1477200, 10.4230900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38383, 'Densborn', 'Densborn', 'Densborn,deng si bo er en,Денсборн,登斯博尔恩', 50.1221300, 6.6006800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38384, 'Dennweiler-Frohnbach', 'Dennweiler-Frohnbach', 'Denvajler-Fronbakh,deng wei lei-fu luo en ba he,Денвайлер-Фронбах,Денвајлер-Фронбах,登韦勒-弗罗恩巴赫', 49.5833300, 7.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38385, 'Dennheritz', 'Dennheritz', '', 50.8141200, 12.4651900, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38386, 'Denklingen', 'Denklingen', 'Denklingen,deng ke lin gen,denkuringen,dnklyngn,Денклинген,Денклінген,Դենքլինգեն,دنکلینگن,デンクリンゲン,登克林根', 47.9166700, 10.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38387, 'Denkingen', 'Denkingen', 'Denkingen,deng jin gen,Денкинген,登金根', 48.1111000, 8.7382000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38388, 'Denkendorf', 'Denkendorf', 'Denkendorf', 48.9283900, 11.4569500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38389, 'Denkendorf', 'Denkendorf', 'Denkendorf Kr.Esslingen', 48.6955500, 9.3167500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38390, 'Demmin', 'Demmin', 'Demin,Demino,Demmin,Demmine,Demmīne,Dymin,Dëmino,dmyn,Демин,Деммин,دمين,دمین', 53.9076200, 13.0314200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38391, 'Demitz-Thumitz', 'Demitz-Thumitz', 'Demic-Tumic,Demitz-Thumitz,Zemicy-Tumicy,de mi ci-tu mi ci,Демиц-Тумиц,Деміц-Туміц,德米茨-图米茨', 51.1414900, 14.2471900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38392, 'Demerath', 'Demerath', '', 50.1833300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38393, 'Demen', 'Demen', 'Demen,de men,Демен,德门', 53.6296700, 11.7663900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38394, 'Delve', 'Delve', 'Del''fe,Delfe,Delve,Delvunda,dai er wo,Делве,Делфе,Дельфе,代尔沃', 54.3000000, 9.2500000, 'DE', '2011-11-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38395, 'Delmenhorst', 'Delmenhorst', 'Del''menkhorst,Delmenhorst,Delmenkhorst,Demost,Gorad Dehl''menkhorst,ZCT,dai er men huo si te,derumenhorusuto,dlmnhwrst,Горад Дэльменхорст,Делменхорст,Дельменхорст,دلمنهورست,デルメンホルスト,代尔门霍斯特', 53.0511000, 8.6309100, 'DE', '2017-02-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38396, 'Dellstedt', 'Dellstedt', 'Dellstedt', 54.2333300, 9.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38397, 'Delligsen', 'Delligsen', 'Deligsen,Delligzen,de li ge sen,derihizen,Делигсен,Деллигзен,デリヒゼン,德利格森', 51.9412000, 9.8027200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38398, 'Dellfeld', 'Dellfeld', '', 49.2339700, 7.4739900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38399, 'Delitzsch', 'Delitzsch', 'Delic,Delica,Delich,Delitium,Delitzsch,Delič,Dēliča,Stadt Delitzsch,de li ci xi,dellichi,deritchu,dlytssh,dlytzsh,Делич,Деліч,دليتسش,دلیتزش,デーリッチュ,德利茨希,델리치', 51.5254600, 12.3428400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38400, 'Delingsdorf', 'Delingsdorf', 'Delingsdorf', 53.7000000, 10.2500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38401, 'Delbrück', 'Delbrueck', 'Del''brjuk,Delbrik,Delbruck,Delbrueck,Delbrück,Gorad Dehl''bruk,de er bu lu ke,dlbrwk,Горад Дэльбрук,Делбрик,Дельбрюк,دلبروك,دلبروک,德尔布吕克', 51.7650300, 8.5622300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38402, 'Deizisau', 'Deizisau', 'Dajcisau,Dajcizau,dai qi shao,Дайцизау,Дајцисау,Դայցիզաու,戴齐绍', 48.7122000, 9.3861000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38403, 'Deißlingen', 'Deisslingen', 'Dajslingen,Dajssingen,dai si lin gen,Дайслинген,Дайслінген,Дайссинген,Дајслинген,戴斯林根', 48.1123000, 8.6073600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38404, 'Deisenhausen', 'Deisenhausen', '', 48.2555400, 10.3269800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38405, 'Deinstedt', 'Deinstedt', 'Dajnshtedt,Dajnshtet,Deins,dai yin si te,dainshutetto,Дайнштедт,Дајнштет,ダインシュテット,戴因斯特', 53.4166700, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38406, 'Deinste', 'Deinste', 'Dajnste,Deinst,dainsute,Дайнсте,Дајнсте,ダインステ', 53.5290300, 9.4437600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38407, 'Deiningen', 'Deiningen', '', 48.8666700, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38408, 'Deining', 'Deining', 'Dajning,Dayning,dai ning,Дайнинг,Дайнінг,Дајнинг,Դայնինգ,戴宁', 49.2255600, 11.5396800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38409, 'Deimberg', 'Deimberg', 'Dajmberg,dai yin bei ge,Даймберг,Дајмберг,戴因贝格', 49.6333300, 7.5166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38410, 'Deilingen', 'Deilingen', '', 48.1741000, 8.7853300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38411, 'Deidesheim', 'Deidesheim', 'Daisem,Dajdeskhajm,Deidesheim,dai de si hai mu,daidesuhaimu,daydshaym,daydzhaym,Дайдесхайм,Дајдесхајм,دايدسهايم,دایدزهایم,ダイデスハイム,戴德斯海姆', 49.4078200, 8.1844500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38412, 'Dehrn', 'Dehrn', 'Dehrn', 50.4204900, 8.0984600, 'DE', '2013-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38413, 'Deggingen', 'Deggingen', 'Deggingen,Degingen,de jin gen,Деггинген,Деггінген,Дегинген,德金根', 48.5971000, 9.7189100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38414, 'Deggendorf', 'Deggendorf', 'Deckendorf,Degendorf,Degendorfas,Deggendorf,Degndorf,Gorad Dehgendorf,dai gen duo fu,degenadarpha,dghndwrf,dgndwrf,Горад Дэгендорф,Деггендорф,Дегендорф,Դեգենդորֆ,دغندورف,دگندورف,ڈیگنڈورف,ডেগেনডর্ফ,代根多夫', 48.8408500, 12.9606800, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38415, 'Deesen', 'Deesen', '', 50.5108300, 7.7000000, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38416, 'Deesbach', 'Deesbach', 'Deesbach', 50.5666700, 11.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38417, 'Deensen', 'Deensen', '', 51.8605300, 9.5932200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38418, 'Dedenbach', 'Dedenbach', '', 50.4833300, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38419, 'Dedelstorf', 'Dedelstorf', 'Dedel''storf,Dedelstorf,de de er si tuo fu,Деделсторф,Дедельсторф,德德尔斯托夫', 52.7000000, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38420, 'Deckenpfronn', 'Deckenpfronn', '', 48.6512800, 8.8241700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38421, 'Daxweiler', 'Daxweiler', 'Daksvajler,da ke si wei lei,Даксвайлер,Даксвајлер,达克斯韦勒', 49.9666700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38422, 'Dauwelshausen', 'Dauwelshausen', 'Dauvelshausen,Dauwelshausen', 50.0000000, 6.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38423, 'Dautmergen', 'Dautmergen', 'Dautmergen,dao te mei er gen,Даутмерген,道特梅尔根', 48.2420000, 8.7414300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38424, 'Dausenau', 'Dausenau', 'Dauzenau,dao sai nao,Даузенау,道塞瑙', 50.3333300, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38425, 'Daun', 'Daun', 'Daun,duo yin,dyywn  alman,Даун,דאון,دیئون، آلمان,多因', 50.1971600, 6.8294200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38426, 'Dauchingen', 'Dauchingen', 'Daukhingen,dao xin gen,Даухинген,Даухінген,道欣根', 48.0899300, 8.5501100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38427, 'Daubach', 'Daubach', '', 50.4000000, 7.8500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38428, 'Daubach', 'Daubach', '', 49.8500000, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38429, 'Datzeroth', 'Datzeroth', '', 50.5166700, 7.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38430, 'Dattenberg', 'Dattenberg', 'Datenberg,Dattenberg,da teng bei ge,Датенберг,Даттенберг,达滕贝格', 50.5536200, 7.2939300, 'DE', '2012-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38431, 'Datteln', 'Datteln', 'Dateln,Dattel''n,Datteln,da te er en,datln,Дателн,Даттельн,داتلن,达特尔恩', 51.6559800, 7.3453000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38432, 'Dätgen', 'Datgen', 'Daetgen,Datgen,Dätgen', 54.1833300, 9.9333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38433, 'Dassow', 'Dassow', 'Dasov,Dasova,Dassov,da suo fu,Дасов,Дассов,达索夫', 53.9109600, 10.9755100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38434, 'Dassendorf', 'Dassendorf', 'Dassendorf', 53.4953200, 10.3598700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38435, 'Dassel', 'Dassel', 'Dasel,Dassel'',da sai er,dasl,dasseru,dazl,Дасел,Дассель,دازل,داسل,ダッセル,达塞尔', 51.8017900, 9.6890400, 'DE', '2015-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38436, 'Dasing', 'Dasing', '', 48.3848200, 11.0466700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38437, 'Dasburg', 'Dasburg', 'Dasburg,Doosber,da si bao,Дасбург,达斯堡', 50.0500000, 6.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38438, 'Darstein', 'Darstein', '', 49.1500000, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38439, 'Darscheid', 'Darscheid', '', 50.2166700, 6.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38440, 'Darmstadt', 'Darmstadt', 'Darmshhat,Darmshtadi,Darmshtadt,Darmshtat,Darmstadium,Darmstadt,Darmstat,Darmstatas,Darmstate,Darmundestadt,Darmştat,Darmštatas,Darmštate,Gorad Darmshtat,Ntarmstat,ZCS,da mu shi ta te,daleumsyutateu,darmastata,darmshtat,darumushutatto,drmstdt,Ντάρμστατ,Горад Дармштат,Дармштадт,Дармштат,Дармщат,דרמשטדט,دارمشتات,ڈریمسٹڈ,डार्मश्टाट,დარმშტადტი,ダルムシュタット,达姆施塔特,다름슈타트', 49.8716700, 8.6502700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38441, 'Darlingerode', 'Darlingerode', 'Dalliero,Darlingerode,Дарлингероде', 51.8471200, 10.7309700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38442, 'Dargun', 'Dargun', 'Dargun,Darguna,da er gong,darghwn,dargwn,Даргун,دارغون,دارگون,达尔贡', 53.9009000, 12.8501400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38443, 'Dannewerk', 'Dannewerk', 'Dannewerk', 54.4833300, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38444, 'Dannenfels', 'Dannenfels', 'Danenfels,Dannenfel''s,da nen fei er si,Даненфелс,Данненфельс,达嫩费尔斯', 49.6286800, 7.9435500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38445, 'Dannenberg', 'Dannenberg', 'Danenberg,Dannenbarg,Dannenberg,da nen bei ge,dannbrg,dannbrgh,Даненберг,Данненберг,داننبرغ,داننبرگ,达嫩贝格', 53.0967000, 11.0900100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38446, 'Danndorf', 'Danndorf', '', 52.4247200, 10.9128600, 'DE', '2011-04-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38447, 'Dannau', 'Dannau', '', 54.2406500, 10.5423300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38448, 'Dankmarshausen', 'Dankmarshausen', 'Dankmarskhauzen,dan ke ma er si hao sen,Данкмарсхаузен,丹克马尔斯豪森', 50.9252700, 10.0160100, 'DE', '2016-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38449, 'Dankerath', 'Dankerath', '', 50.3333300, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38450, 'Dänischenhagen', 'Daenischenhagen', 'Daenischenhagen,Danischenhagen,Denishenkhagen,Dänischenhagen,de ni shen ha gen,Денишенхаген,德尼申哈根', 54.4277500, 10.1259600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38451, 'Damsdorf', 'Damsdorf', '', 54.0666700, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38452, 'Damscheid', 'Damscheid', '', 50.1000000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38453, 'Damp', 'Damp', 'Damp', 54.5833300, 9.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38454, 'Damnatz', 'Damnatz', '', 53.1364700, 11.1768700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38455, 'Dammfleth', 'Dammfleth', 'Dammfleth', 53.9088100, 9.3731200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38456, 'Damme', 'Damme', 'Dame,Damme,damh,damt,Даме,Дамме,دامة,دامه', 52.5215700, 8.1979300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38457, 'Damlos', 'Damlos', 'Damlos', 54.2500000, 10.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38458, 'Damflos', 'Damflos', '', 49.6666700, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38459, 'Damendorf', 'Damendorf', 'Damendorf', 54.4166700, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38460, 'Dambach', 'Dambach', '', 49.6333300, 7.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38461, 'Dalldorf', 'Dalldorf', '', 53.4350000, 10.6118500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38462, 'Dalheim', 'Dalheim', '', 49.8266700, 8.2952800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38463, 'Daleiden', 'Daleiden', 'Dalajden,Doleeden,da lai deng,Далайден,Далајден,达莱登', 50.0700000, 6.1836100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38464, 'Daldorf', 'Daldorf', 'Daldorf', 54.0166700, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38465, 'Dalberg', 'Dalberg', '', 49.9000000, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38466, 'Daiting', 'Daiting', '', 48.7917700, 10.9046300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38467, 'Daisendorf', 'Daisendorf', 'Dajzendorf,Dayzendorf,dai sen duo fu,daizendorpi,Дайзендорф,Дајзендорф,Դայզենդորֆ,დაიზენდორფი,戴森多夫', 47.7126500, 9.2678300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38468, 'Dähre', 'Daehre', 'Dere,de lei,Дере,德雷', 52.7980400, 10.9067200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38469, 'Dahnen', 'Dahnen', '', 50.0666700, 6.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38470, 'Dahn', 'Dahn', 'Dahn,Dan,da en,dan,Дан,دان,ダーン,达恩', 49.1509800, 7.7784300, 'DE', '2015-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38471, 'Dahmker', 'Dahmker', 'Dahmker', 53.5833300, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38472, 'Dahme', 'Dahme', '', 54.2166700, 11.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38473, 'Dahme', 'Dahme', 'Dahme,Dahme/Mark', 51.8700800, 13.4274300, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38474, 'Dahlheim', 'Dahlheim', 'Dahlheim,Dal''khajm,Dalheim,Dalkhajm,Далхајм,Дальхайм', 50.2101800, 7.6958300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38475, 'Dahlenwarsleben', 'Dahlenwarsleben', '', 52.1951900, 11.5373600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38476, 'Dahlenburg', 'Dahlenburg', 'Dahlenburg,Dalenburg,da lun bao,Даленбург,达伦堡', 53.1876700, 10.7365000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38477, 'Dahlen', 'Dahlen', 'Dahlen', 51.3649500, 12.9988100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38478, 'Dahlem', 'Dahlem', 'Berlin-Dahlem,Dalem,Далем,דאהלם', 52.4581000, 13.2870200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38479, 'Dahlem', 'Dahlem', '', 53.2000000, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38480, 'Dahlem', 'Dahlem', '', 50.3860700, 6.5476800, 'DE', '2016-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38481, 'Dahlem', 'Dahlem', '', 49.9166700, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38482, 'Dägeling', 'Dageling', 'Daegeling,Dageling,Dägeling', 53.8833300, 9.5333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38483, 'Dagebüll', 'Dagebull', 'Dagebil,Dagebjull'',Dagebol,Dagebøl,Doogebel,da ge bi er,Дагебил,Дагебюлль,达格比尔', 54.7292800, 8.7008300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38484, 'Dackscheid', 'Dackscheid', '', 50.1166700, 6.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38485, 'Dackenheim', 'Dackenheim', '', 49.5211100, 8.1872200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38486, 'Dachwig', 'Dachwig', 'Dachwig', 51.0777000, 10.8547900, 'DE', '2016-11-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38487, 'Dachsenhausen', 'Dachsenhausen', '', 50.2541500, 7.7272500, 'DE', '2012-06-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38488, 'Dachau', 'Dachau', 'Dachanum,Dachau,Dakhau,Daxau,Dochau,KZ Dachau,Ntachaou,ZCR,da hao,dahau,dahhau,dakhaw,teccu,Νταχάου,Дахау,Դախաու,דאכוי,דכאו,داخاو,ڈاکسو,டேச்சு,ダッハウ,达豪,다하우', 48.2600000, 11.4340200, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38489, 'Dabergotz', 'Dabergotz', '', 52.9031000, 12.7246600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38490, 'Dabel', 'Dabel', '', 53.6611200, 11.9002500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38491, 'Daaden', 'Daaden', 'Daden,da deng,daaden,dadyn,Даден,دادین,ダアーデン,达登', 50.7333300, 7.9666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38492, 'Cuxhaven', 'Cuxhaven', 'Cux,Cuxhaven,Cuxhoben,Cuxhuuwen,FCN,Kuksgafen,Kukskhafen,Kukskhaven,ku ke si gang,kugseuhapen,kukkusuhafen,kwkshafn,kwkshawn,Куксгафен,Куксхавен,Куксхафен,Կուքսհաֆեն,كوكسهافن,کوکسهاون,ککسہیون,クックスハーフェン,库克斯港,쿡스하펜', 53.8717600, 8.6908700, 'DE', '2016-11-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38493, 'Cursdorf', 'Cursdorf', 'Kursdorf,ku er si duo fu,Курсдорф,库尔斯多夫', 50.5666700, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38494, 'Cunewalde', 'Cunewalde', 'Cunewalde,Kumwald,Kumwałd,Kuneval''de,Kunevalde,ku nei wa er de,Куневалде,Куневальде,库内瓦尔德', 51.1000000, 14.5166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38495, 'Cumlosen', 'Cumlosen', 'Cumlosen,Kumlosen', 53.0333300, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38496, 'Crottendorf', 'Crottendorf', 'Crottendorf,Krotendorf,Krottendorf,ke luo teng duo fu,Кротендорф,Кроттендорф,克罗滕多夫', 50.5166700, 12.9500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38497, 'Crostwitz', 'Crostwitz', 'Chroscicy,Chrósćicy,Crostwitz,Crostwitz/Chroscicy,Crostwitz/Chrósćicy,Crostwitzi vald,Krostvic,ke luo si te wei ci,Кроствиц,克罗斯特维茨', 51.2383200, 14.2433800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38498, 'Crostau', 'Crostau', 'Chrostawa,Chróstawa,Crostau,Crostau vald,Krostau,Кростау', 51.0846200, 14.4558900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38499, 'Cronenberg', 'Cronenberg', 'Kronenberg,ke luo nen bei ge,Кроненберг,克罗嫩贝格', 49.6500000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38500, 'Crivitz', 'Crivitz', 'Crivitz,Krivic,Krivica,Krīvica,ke li fei ci,kryfyts,srywytz,Кривиц,سریویتز,كريفيتس,克里菲茨', 53.5731600, 11.6519400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38501, 'Crispendorf', 'Crispendorf', 'Crispendorf,Krispendorf,ke li si peng duo fu,Криспендорф,克里斯彭多夫', 50.5914900, 11.7336600, 'DE', '2016-12-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38502, 'Crinitz', 'Crinitz', 'Krinic,Krynica,ke li ni ci,Криниц,Կրինից,克里尼茨', 51.7333300, 13.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38503, 'Crimmitschau', 'Crimmitschau', 'Crimmitschau,Crimmitshau,Krimichau,Krimmicava,Krimmichau,Krimmičava,Stadt Crimmitschau,ke li mi ci xiao,krymytshaw,krymytshwa,Кримичау,Криммичау,كريميتشاو,کریمیتشوا,克里米茨肖', 50.8164400, 12.3904500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38504, 'Crimla', 'Crimla', 'Crimla', 50.8000000, 12.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38505, 'Creuzburg', 'Creuzburg', 'Creuzburg,Krojcburg,ke luo yi ci bao,krwytsbwrgh,krwyzbrg,Кройцбург,Кројцбург,كرويتسبورغ,کرویزبرگ,克罗伊茨堡', 51.0528800, 10.2475000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38506, 'Creußen', 'Creussen', 'Creussen,Creuszen,Creußen,Krojsen,Krojssen,Kroysen,ke luo yi sen,krwysn,kuroisen,Кройсен,Кройссен,Кројсен,Կրոյսեն,كرويسن,کرویسن,クロイセン,克罗伊森', 49.8449500, 11.6268300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38507, 'Cremlingen', 'Cremlingen', 'Cremlingen,Kremlingen,ke lei mu lin gen,Кремлинген,克雷姆林根', 52.2500000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38508, 'Creglingen', 'Creglingen', 'Creglingen,Kreglingen,ke lei ge lin gen,krghlynghn,krglyngn,kurekuringen,Креглинген,Креглінген,كرغلينغن,کرگلینگن,クレクリンゲン,克雷格林根', 49.4693700, 10.0311900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38509, 'Crawinkel', 'Crawinkel', 'Crawinkel', 50.7833300, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38510, 'Cramme', 'Cramme', '', 52.1133100, 10.4467100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38511, 'Cramberg', 'Cramberg', 'Kramberg', 50.3416800, 7.9426900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38512, 'Crailsheim', 'Crailsheim', 'Crailsheimum,ICrailsheim,Krailsheimas,Krajl''sgajm,Krajl''skhajm,Krajlskhajm,QEI,Stadt Crailsheim,ke lai er si hai mu,kraylshaym,krylzhaym,kurairusuhaimu,Крайльсгайм,Крайльсхайм,Крајлсхајм,كرايلسهايم,کریلزهایم,クライルスハイム,克赖尔斯海姆', 49.1344400, 10.0719300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38513, 'Cottbus', 'Cottbus', 'CBU,Chocebuz,Chociebuz,Chociebuż,Chosebuz,Chotebuz,Chotěbuz,Choćebuz,Chośebuz,Chóśebuz,Cotbusium,Cottbus,Kotbus,Kotbusa,Kotbusas,Kottbus,ke te bu si,khxthth bus,kosbuseu,kotobusu,ktbws,kwtbws,qwtbws,Котбус,קוטבוס,كوتبوس,کتبوس,کوٹبس,คอทท์บุส,კოტბუსი,コトブス,科特布斯,콧부스', 51.7576900, 14.3288800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38514, 'Coswig', 'Coswig', 'Coswig,Kosvig,kswyg,Косвиг,کسویگ', 51.8861800, 12.4500900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38515, 'Coswig', 'Coswig', 'Coswig,Kosvig,kswyg,Косвиг,کسویگ', 51.1320400, 13.5831200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38516, 'Cornberg', 'Cornberg', 'Cornberg,Dorf Kornberg,Kornberg,ke en bei ge,Корнберг,科恩贝格', 51.0416000, 9.8605100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38517, 'Coppengrave', 'Coppengrave', 'Kopengrave,Koppengrafe,ke peng la fei,Копенграве,Коппенграфе,科彭拉费', 51.9833300, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38518, 'Coppenbrügge', 'Coppenbruegge', 'Coppenbruegge,Coppenbrugge,Coppenbrügge,Kopenbrige,Koppenbrjugge,Koppenbrugge,Koppenbrügge,ke peng bu lu ge,koppenburyugge,Копенбриге,Коппенбрюгге,コッペンブリュッゲ,科彭布吕格', 52.1185200, 9.5487000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38519, 'Contwig', 'Contwig', 'Kontvig,kong te wei xi,Контвиг,孔特维希', 49.2500000, 7.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38520, 'Colnrade', 'Colnrade', 'Kol''nrade,Kolnrade,ke er en la de,Колнраде,Кольнраде,科尔恩拉德', 52.8333300, 8.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38521, 'Colmberg', 'Colmberg', 'Colmberg,Kol''mberg,Kolmberg,korumuberuku,Колмберг,Кольмберг,Կոլմբերգ,コルムベルク', 49.3548000, 10.4115700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38522, 'Colditz', 'Colditz', 'Colditz,Kol''dic,Koldic,Koldica,Kolntits,ke er di ci,kldytz,kwldyts,Κόλντιτς,Колдиц,Кольдиц,كولديتس,کلدیتز,科尔迪茨', 51.1282100, 12.8029500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38523, 'Colbitz', 'Colbitz', 'Kol''bic,Kolbic,Kolbitz,ke er bi ci,Колбиц,Кольбиц,科尔比茨', 52.3170800, 11.6053400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38524, 'Cölbe', 'Coelbe', 'Coelbe,Colbe,Cölbe,Kel''be,Kelbe,Kjol''be,ke er bo,kerube,Келбе,Кельбе,Кёльбе,ケルベ,克尔伯', 50.8509800, 8.7809200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38525, 'Coesfeld', 'Coesfeld', 'Coesfeld,Cosfeldia,Kesfel''d,Koesfeld,Koosfeld,Kosfel''d,Kosfeld,ke ai si fei er de,ksfld,kwsfld,Кесфельд,Коесфелд,Косфелд,Косфельд,كوسفلد,کسفلد,科埃斯费尔德', 51.9434900, 7.1680900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38526, 'Cochstedt', 'Cochstedt', 'CSO,Cochstedt,Cocstede,Kochstedt', 51.8824700, 11.4108500, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38527, 'Cochem', 'Cochem', 'Cochem,Kochem,Kokhem,ke he mu,kohhemu,kwshm,qwkm,Кохем,קוכם,كوشم,کوشم,コッヘム,科赫姆', 50.1451100, 7.1637900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38528, 'Coburg', 'Coburg', 'Cobourg,Coburg,Coburgo,Coburgum,Cuburgh,Koburg,Koburq,Kreisfreie Stadt Coburg,ke bao,kho bur k,kobuleukeu,koburuku,kwbrg,kwbwrg,kwbwrgh,Кобург,Կոբուրգ,كوبورغ,کوبرگ,کوبورگ,โคบูร์ก,コーブルク,科堡,코부르크', 50.2593700, 10.9638400, 'DE', '2016-06-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38529, 'Cloppenburg', 'Cloppenburg', 'Cloppenborg,Cloppenburg,Klopenburg,Kloppenboarch,Kloppenburg,Kloppenbuurich,ke luo peng bao,klwbnbwrgh,klwpnbwrg,Клопенбург,Клоппенбург,كلوبنبورغ,کلوپنبورگ,克洛彭堡', 52.8475400, 8.0450000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38530, 'Clingen', 'Clingen', 'Clingen,Klingen,ke lin gen,klynghn,klyngn,Клинген,كلينغن,کلینگن,克林根', 51.2320600, 10.9328100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38531, 'Clenze', 'Clenze', 'Clenze,Klence,Klenze,ke lun ce,klntsh,Кленце,کلنتسه,克伦策', 52.9372900, 10.9575000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38532, 'Cleebronn', 'Cleebronn', 'Klebron,Klebronn,ke lai bu long,kureburon,Клеброн,Клебронн,クレーブロン,克莱布龙', 49.0450000, 9.0369400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38533, 'Clausthal-Zellerfeld', 'Clausthal-Zellerfeld', 'Bergstadt-Clausthal-Zellerfeld,Clausthal-Zellerfeld,Klaustal''-Cellerfel''d,Klaustal-Celerfeld,Klaustal-Zellerfeld,ke lao si ta er,klawstal tsyllrfyld,klawstal-tslrfld,Клаустал-Целерфелд,Клаусталь-Целлерфельд,كلاوستال تسيللرفيلد,کلازتھال زیلرفیلڈ,کلاوستال-تسلرفلد,克劳斯塔尔', 51.8094900, 10.3382100, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38534, 'Claußnitz', 'Claussnitz', 'Claussnitzi vald,Claußnitzi vald,Klausnic,ke lao si ni ci,Клаусниц,克劳斯尼茨', 50.9333300, 12.8833300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38535, 'Clausen', 'Clausen', '', 49.2607500, 7.6773000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38536, 'Chursdorf', 'Chursdorf', '', 50.6666700, 11.8500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38537, 'Christinenthal', 'Christinenthal', 'Christinental,Christinenthal', 54.0500000, 9.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38538, 'Christiansholm', 'Christiansholm', 'Christiansholm', 54.3166700, 9.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38539, 'Christes', 'Christes', 'Christes', 50.6666700, 10.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38540, 'Chorin', 'Chorin', 'Khorin,Korin,xiao lin,Корин,Хорин,Կորին,肖林', 52.9019700, 13.8715300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38541, 'Chiemsee', 'Chiemsee', '', 47.8666700, 12.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38542, 'Chieming', 'Chieming', 'Cheaming,Khiming,Kiming,Ximing,shymyng,xi ming ge,Киминг,Кімінг,Химинг,Խիմինգ,شیمینگ,希明格', 47.8925800, 12.5401200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38543, 'Chemnitz', 'Chemnitz', 'Chemnicas,Chemnicium,Chemnitz,Gorad Khemnic,Hemnica,Kamenica,Kamjenica,Karl-Marx-Stadt,Kemnic,Kemnits,Khemnic,Saska Kamenice,Saská Kamenice,chymntz,kai mu ni ci,kemnicheu,kemunittsu,khe mniths,kmnytz,kymnts,qmnyz,Κέμνιτς,Горад Хемніц,Кемниц,Хемниц,Хемніц,קמניץ,קעמניץ,كيمنتس,چیمنتز,کمنیتز,เคมนิทซ์,კემნიცი,ケムニッツ,开姆尼茨,켐니츠', 50.8357000, 12.9292200, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38544, 'Charlottenburg', 'Charlottenburg Bezirk', 'Berlin-Charlottenburg,Sharlottenburg,sharlٹnbrg-wlmrzڈwrf,xia luo teng bao,Шарлоттенбург,شارلٹنبرگ-ولمرزڈورف,夏洛滕堡', 52.5166700, 13.2833300, 'DE', '2014-04-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38545, 'Charlottenberg', 'Charlottenberg', '', 50.3437000, 7.8808100, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38546, 'Chamerau', 'Chamerau', 'Kamerau,Khamerau,Xamerau,xia mei lao,Камерау,Хамерау,Խամերաու,夏梅劳', 49.2000000, 12.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38547, 'Cham', 'Cham', 'Cham,Cham Regen,QHQ', 49.2256500, 12.6550100, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38548, 'Celle', 'Celle', 'Cele,Cella,Celle,Celle i Tyskland,Celė,Gorad Cehle,ZCN,ce lei,chelle,sel lex,slh,syly,tsu~ere,Горад Цэле,Целе,Целле,سله,سيلي,เซลเลอ,ツェレ,策勒,첼레', 52.6226400, 10.0804700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38549, 'Cavertitz', 'Cavertitz', 'Kafertic,ka fei er di ci,Кафертиц,Кафертіц,卡费尔蒂茨', 51.3833300, 13.1333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38550, 'Castrop-Rauxel', 'Castrop-Rauxel', 'Castrop-Rauxel,Kastrop-Rauksel,Kastrop-Rauksel'',Stadt Castrop-Rauxel,ZCM,ka si te luo pu-lao ke sai er,kastrwb rawksl,kastrwp-rawksl,khas thrx ph-rea seil,Кастроп-Рауксел,Кастроп-Рауксель,كاستروب راوكسل,کاستروپ-راوکسل,คัสทรอพ-เราเซิล,卡斯特罗普-劳克塞尔', 51.5565700, 7.3115500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38551, 'Castell', 'Castell', 'Castell', 49.7417300, 10.3497800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38552, 'Casekow', 'Casekow', 'Kasekow,Kazekov,ka sai ke,Казеков,Կազեկով,卡塞科', 53.2111700, 14.2082400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38553, 'Carpin', 'Carpin', 'Carpin,Karpin,ka er ping,Карпин,卡尔平', 53.3569100, 13.2432800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38554, 'Carlsberg', 'Carlsberg', '', 49.5038900, 8.0416700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38555, 'Carlow', 'Carlow', '', 53.7586100, 10.9378900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38556, 'Cappeln', 'Cappeln', 'Cappeln,Kapeln,Kappel''n,Капелн,Каппельн', 52.8108500, 8.1147400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38557, 'Cappel', 'Cappel', 'Cappel,Kappel', 53.7264800, 8.5703000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38558, 'Camburg', 'Camburg', 'Camburg,Kamburg,Камбург', 51.0552400, 11.7096700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38559, 'Bad Camberg', 'Bad Camberg', 'Bad Camberg,Bad Kamberg,Bad-Kamberg,Camberg,Gorad Bad-Kamberg,Kamberg,ba te kan bei ge,bad kambrg,bad kambrgh,Бад Камберг,Бад-Камберг,Горад Бад-Камберг,باد كامبرغ,باد کامبرگ,巴特坎贝格', 50.2969500, 8.2689600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38560, 'Calw', 'Calw', 'Calewa,Calw,Kal''v,Kalv,ka er fu,kalf,karufu,klaw,Калв,Кальв,Կալվ,كالف,کلاو,カルフ,卡尔夫', 48.7141900, 8.7403100, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38561, 'Calvörde', 'Calvorde', 'Calvoerde vald,Calvorde,Calvörde,Calvörde vald,Kal''ferde,Kal''fjorde,Kalferde,ka er fu er de,Калферде,Кальферде,Кальфёрде,卡尔弗尔德', 52.3955100, 11.2946300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38562, 'Callenberg', 'Callenberg', 'Kalenberg,Kallenberg,ka lun bei ge,Каленберг,Калленберг,卡伦贝格', 50.8500000, 12.6333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38563, 'Callbach', 'Callbach', '', 49.7000000, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38564, 'Calden', 'Calden', 'Kal''den,Kalden,ka er deng,karuden,Калден,Кальден,カルデン,卡尔登', 51.4094300, 9.4018900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38565, 'Calberlah', 'Calberlah', 'Kal''berla,Kalberlah,Kalberlakh,Kalberloa,Kaluerlege [a. 1318],Kalŭerlege [a. 1318],ka er bei er la,Калберлах,Кальберла,卡尔贝尔拉', 52.4207400, 10.6232600, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38566, 'Calbe', 'Calbe', 'Calbe,Calbe an der Saale,Calva,Kal''be,Kalbe,kalbh,kalbt,Калбе,Кальбе,كالبة,کالبه', 51.9066800, 11.7747800, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38567, 'Calau', 'Calau', 'Calau,Kalau,Kalawa,ka lao,kalaw,kalwa,Калау,Կալաու,كالاو,کالوا,卡劳', 51.7440200, 13.9532900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38568, 'Cadolzburg', 'Cadolzburg', 'Kadol''cburg,Kadolcburg,ka duo er ci bao,Кадолцбург,Кадольцбург,Կադոլցբուրգ,卡多尔茨堡', 49.4573000, 10.8532900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38569, 'Cadenberge', 'Cadenberge', 'Kadenberge,Kumbarg,ka deng bei ge,Каденберге,卡登贝格', 53.7692600, 9.0626900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38570, 'Caaschwitz', 'Caaschwitz', 'Caaschwitz,Gaaschwitz', 50.9500000, 12.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38571, 'Buxtehude', 'Buxtehude', 'Bukstekhude,Buxtehude,Gemeen Buxthu,bukusutefude,bwksthwdh,Букстехуде,بوكستهوده,بوکستهوده,ブクステフーデ', 53.4671600, 9.6863600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38572, 'Buxheim', 'Buxheim', '', 48.8068600, 11.2921000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38573, 'Buxheim', 'Buxheim', '', 48.0000000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38574, 'Bützow', 'Buetzow', 'Bicov,Bicova,Bjutcov,Buetzow,Butzow,Bützow,bi cuo,bwtsw,bwtzw,Бицов,Бютцов,بوتزو,بوتسو,比措', 53.8483200, 11.9825600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38575, 'Butzbach', 'Butzbach', 'Bucbakh,bu ci ba he,buttsubahha,bwtsbakh,bwtzbakh,Буцбах,بوتزباخ,بوتسباخ,ブッツバッハ,布茨巴赫', 50.4339500, 8.6712200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38576, 'Büttstedt', 'Buettstedt', 'Buttstedt,Büttstedt', 51.2597200, 10.3063600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38577, 'Buttstädt', 'Buttstaedt', 'Buttstadt,Buttstaedt,Buttstädt', 51.1222700, 11.4172100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38578, 'Buttlar', 'Buttlar', 'Butlar,bu te la er,Бутлар,布特拉尔', 50.7577000, 9.9527700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38579, 'Bütthard', 'Butthard', 'Bitard,Bjuttard,Bjuttkhard,Butthar,Butthard,Butthart,Bütthar,Bütthard,Bütthart,bi ta er de,byuttoharuto,Битард,Бюттард,Бюттхард,Բյութարդ,ビュットハルト,比塔尔德', 49.5991300, 9.8798700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38580, 'Buttenwiesen', 'Buttenwiesen', 'Butenvisen,Buttenvizen,bu teng wei sen,bwtnwyzn,Бутенвисен,Буттенвизен,Буттенвізен,Բութենվիզեն,بوتنویزن,布滕维森', 48.6000000, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38581, 'Buttenheim', 'Buttenheim', 'Butenkhajm,Buttengajm,Buttenkhajm,bu teng hai mu,buttenhaimu,Бутенхајм,Буттенгайм,Буттенхайм,Բութենհայմ,ブッテンハイム,布滕海姆', 49.8036500, 11.0300200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38582, 'Buttelstedt', 'Buttelstedt', 'Butelshtet,Buttel''shtedt,Buttelstedt,bu te er si te,bwtlshtyt,Бутелштет,Буттельштедт,بوتلشتيت,بوتل‌اشتت,布特尔斯特', 51.0765000, 11.3435300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38583, 'Büttelborn', 'Buttelborn', 'Bitelborn,Bjuttel''born,Buettelborn,Büttelborn,bi te er bo en,byutteruborun,Бителборн,Бюттельборн,ビュッテルボルン,比特尔博恩', 49.9033300, 8.5233300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38584, 'Büttel', 'Buttel', '', 53.9000000, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38585, 'Büsumer Deichhausen', 'Buesumer Deichhausen', '', 54.1333300, 8.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38586, 'Büsum', 'Busum', 'Bizum,Bjuzum,Buesen,Büsen,HEI,bi su mu,Бизум,Бюзум,比苏姆', 54.1339800, 8.8575600, 'DE', '2013-05-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38587, 'Büsingen', 'Busingen', 'Buesingen,Buesingen am Hochrhein,Büsingen,Büsingen am Hochrhein', 47.6963800, 8.6875900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38588, 'Busenwurth', 'Busenwurth', 'Busenwurth', 54.0412400, 9.0377400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38589, 'Busenhausen', 'Busenhausen', 'Buzenkhauzen,bu sen hao sen,bwznhasn,Бузенхаузен,بوزنهاسن,布森豪森', 50.7166700, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38590, 'Busenberg', 'Busenberg', 'Buzenberg,bu sen bei ge,Бузенберг,布森贝格', 49.1302400, 7.8293000, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38591, 'Busdorf', 'Busdorf', 'Busdorf,Bustrup,bu si duo fu,Бусдорф,布斯多夫', 54.4911100, 9.5499700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38592, 'Busdorf', 'Busdorf', '', 54.1034500, 10.0824200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38593, 'Burweg', 'Burweg', 'Burveg,Gemeen Burweg,bu er wei ge,buruvu~eku,Бурвег,ブルヴェク,布尔韦格', 53.6247500, 9.2663500, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38594, 'Burtscheid', 'Burtscheid', '', 49.7333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38595, 'Burtenbach', 'Burtenbach', 'Burtenbakh,Burtenbax,bu er teng ba he,Буртенбах,Բուրտենբախ,布尔滕巴赫', 48.3405100, 10.4528000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38596, 'Bürstadt', 'Buerstadt', 'Birshtat,Bjurshtadt,Buerstadt,Burstadt,Bürstadt,Gorad Bjurshtat,bi er si ta te,bwrashtt,byurushutatto,bywrshtat,Бирштат,Бюрштадт,Горад Бюрштат,بوراشتت,بيورشتات,ビュルシュタット,比尔斯塔特', 49.6426600, 8.4593600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38597, 'Burscheid', 'Burscheid', 'Burscheid,Burshajd,bu er sha yi de,bwrshayd,Буршайд,Буршајд,بورشايد,بورشاید,布尔沙伊德', 51.0846800, 7.1139300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38598, 'Burrweiler', 'Burrweiler', 'Burvajler,bu er wei lei,Бурвайлер,Бурвајлер,布尔韦勒', 49.2477800, 8.0783300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38599, 'Burow', 'Burow', '', 53.7737200, 13.2731800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38600, 'Burladingen', 'Burladingen', 'Burladingen,bu er la ding gen,bwrladynghn,bwrladyngn,Бурладинген,Бурладінген,بورلادينغن,بورلادینگن,布尔拉丁根', 48.2911100, 9.1128600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38601, 'Burkhardtsdorf', 'Burkhardtsdorf', 'Burkkhardtsdorf,Burkkhartsdorf,bu er ke ha er ci duo fu,Буркхардтсдорф,Буркхартсдорф,布尔克哈尔茨多夫', 50.7333300, 12.9166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38602, 'Burkau', 'Burkau', 'Burkau,Burkau/Porchow,Porchow,bu er kao,Буркау,布尔考', 51.1757900, 14.1732900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38603, 'Burkardroth', 'Burkardroth', 'Burkardrot,Burkardroth,bu er ka er de luo te,Буркардрот,Բուրկարդրոտ,布尔卡尔德罗特', 50.2712500, 9.9916200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38604, 'Burk', 'Burk', '', 49.1331800, 10.4789100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38605, 'Burgwindheim', 'Burgwindheim', 'Burgvindgajm,Burgvindhaym,Burgvindkhajm,Burgwindheim,bu er ge wen de hai mu,burukuvu~intohaimu,Бургвиндхайм,Бургвиндхајм,Бургвіндгайм,Բուրգվինդհայմ,ブルクヴィントハイム,布尔格温德海姆', 49.8273300, 10.5963100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38606, 'Burgwerben', 'Burgwerben', 'Burgwerben', 51.2227000, 11.9839600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38607, 'Burgwalde', 'Burgwalde', 'Burgwalde', 51.3833300, 10.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38608, 'Burgthann', 'Burgthann', 'Burgtan,Burgtann,bu er ge tan,Бургтан,Бургтанн,Բուրգթան,布尔格坦', 49.3520200, 11.3115400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38609, 'Burg Stargard', 'Burg Stargard', 'Burg Shtargard,Burg Stargard,Burg-Shtargard,Burgstargarde,Burgštargarde,bu er ge si ta er jia er de,bwrg ashtargard,bwrgh shtarghard,Бург Штаргард,Бург-Штаргард,بورغ شتارغارد,بورگ اشتارگارد,布尔格斯塔尔加尔德', 53.4958200, 13.3112200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38610, 'Burgstall', 'Burgstall', '', 52.4084900, 11.6966600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38611, 'Burgstädt', 'Burgstaedt', 'Burgshtedt,Burgshtet,Burgstadt,Burgstaedt,Burgstete,Burgstädt,Burgštete,bu er ge si te,bwrghshtyt,Бургштедт,Бургштет,بورغشتيت,بورگ‌اشتت,布尔格斯特', 50.9133300, 12.8060000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38612, 'Bürgstadt', 'Burgstadt', 'Birgshtat,Bjurgshtadt,Burgstadt,Burgstaedt,Burgstädt,Bürgstadt,bi er ge si ta te,byurukushutatto,Биргштат,Бюргштадт,Բյուրգշթաթ,ビュルクシュタット,比尔格斯塔特', 49.7147600, 9.2691600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38613, 'Burgsponheim', 'Burgsponheim', 'Burgsponkhajm,bu er ge si peng hai mu,Бургспонхайм,Бургспонхајм,布尔格斯蓬海姆', 49.8333300, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38614, 'Burgsolms', 'Burgsolms', '', 50.5419100, 8.4041100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38615, 'Burgsinn', 'Burgsinn', 'Burgsin,Burgsinn,Burgzin,Burgzinn,bu er ge xin,Бургзинн,Бургзінн,Бургсин,Բուրգզին,布尔格辛', 50.1496800, 9.6511900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38616, 'Burgschwalbach', 'Burgschwalbach', '', 50.2833300, 8.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38617, 'Burgsalach', 'Burgsalach', 'Burgsalack,Burgsalakh,Burgzalakh,Burgzalax,bu er ge sa la,Бургзалах,Бургсалах,Բուրգզալախ,布尔格萨拉', 49.0331600, 11.0976600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38618, 'Burgrieden', 'Burgrieden', 'Burgriden,bu er ge li deng,burgrideni,Бургриден,Бургріден,Բուրգրիդեն,ბურგრიდენი,布尔格里登', 48.2333300, 9.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38619, 'Burgpreppach', 'Burgpreppach', 'Burgprepakh,Burgpreppach,Burgpreppakh,bu er ge pu lei pa,Бургпрепах,Бургпреппах,Բուրգփրեփախ,布尔格普雷帕', 50.1414900, 10.6497700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38620, 'Burgoberbach', 'Burgoberbach', 'Burgoberbakh,Burgoberbax,bu er ge bei er ba he,burukuobabahha,Бургобербах,Բուրգոբերբախ,ブルクオーバーバッハ,布尔戈贝尔巴赫', 49.2333300, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38621, 'Burglengenfeld', 'Burglengenfeld', 'Burglegenfeld,Burglengenfel''d,Burglengenfeld,bu er ge lun gen fei er de,bwglngnfld,bwrghlnghnfld,Бургленгенфелд,Бургленгенфельд,بورغلنغنفلد,بوگلنگنفلد,布尔格伦根费尔德', 49.2037900, 12.0445200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38622, 'Burglauer', 'Burglauer', '', 50.2764500, 10.1793900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38623, 'Burglahr', 'Burglahr', '', 50.6177800, 7.4968800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38624, 'Burgkunstadt', 'Burgkunstadt', 'Burgkundstadt,Burgkunshtat,Burgunshtadt,bu er ge kun si ta te,burukukunshutatto,bwrgh kwnshtat,Бургкунштат,Бургунштадт,Բուրգունշթաթ,בורגקונשטאדט,بورغ كونشتات,بورگکون‌اشتات,ブルククンシュタット,布尔格昆斯塔特', 50.1409300, 11.2520500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38625, 'Burgkirchen an der Alz', 'Burgkirchen an der Alz', 'Buagkiacha a da Oiz,Burgirkhen-an-der-Al''c,Burgirkhen-na-Al''ce,Burgkirchen,Burgkirchen an der Alz,Burgkirkhen an der Alc,Burgkirkhen-an-der-Al''c,a er ci he pan bu ge ji xing,bwrg kyrshn an dr alts,Бургирхен-на-Альце,Бургкирхен ан дер Алц,Бургкирхен-ан-дер-Альц,Бургірхен-ан-дер-Альц,Ալցի Բուրգիրհեն,بورگ کیرشن ان در آلتس,阿尔茨河畔布格基兴', 48.1675300, 12.7325000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38626, 'Burgk', 'Burgk', 'Burgk,bu er ge ke,Бургк,布尔格克', 50.5560300, 11.7180300, 'DE', '2016-01-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38627, 'Burgheim', 'Burgheim', 'Burggajm,Burghaym,Burgheim,Burgkhajm,Burkheim,bu er ge hai mu,Бурггайм,Бургхайм,Бургхајм,Բուրգհայմ,布尔格海姆', 48.7003500, 11.0159900, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38628, 'Burghausen', 'Burghausen', 'Burghausen,Burgkhauzen,Burkhausen,Бургхаузен', 48.1692500, 12.8313900, 'DE', '2015-11-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38629, 'Burghaun', 'Burghaun', 'Burgaun,Burgkhaun,bu er ge hao en,Бургаун,Бургхаун,布尔格豪恩', 50.6968400, 9.7245300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38630, 'Burghaslach', 'Burghaslach', 'Burgaslakh,Burghaslach,Burghaslax,Burgkhaslakh,bu er ge ha si la,Бургаслах,Бургхаслах,Բուրգհասլախ,布尔格哈斯拉', 49.7331300, 10.6007000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38631, 'Burggen', 'Burggen', '', 47.7768900, 10.8172400, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38632, 'Burgen', 'Burgen', '', 50.2112700, 7.3895900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38633, 'Burgen', 'Burgen', '', 49.8833300, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38634, 'Bürgel', 'Buergel', 'Birgel,Bjurgel'',Buergel,Burgel,Bürgel,bwrgl,Биргел,Бюргель,بورگل', 50.9421700, 11.7563500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38635, 'Burgebrach', 'Burgebrach', 'Burgebrach,Burgebrakh,Burgebrax,bu er ge bu la,burukueburaha,Бургебрах,Բուրգեբրախ,ブルクエーブラハ,布尔格布拉', 49.8283200, 10.7433800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38636, 'Burgdorf', 'Burgdorf', 'Borchdoerp,Borchdörp,Borgtorff [a. 1654],Bortaerpe,Bortoerp,Bortärpe,Bortörp,Burgdorf,Burgdorf (Gannover),Burgdorf (Hanovro),Burgdorf (Khanover),Burgdorf (Region Hannover),Burgdorf  Hanover,Burgdorfas,Burgtorff [a. 1654],bwrgdwrf,Бургдорф (Ганновер),Бургдорф (Хановер),بورگدورف', 52.4462800, 10.0064000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38637, 'Burgdorf', 'Burgdorf', '', 52.1443400, 10.2176300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38638, 'Burgbrohl', 'Burgbrohl', 'Burgbrol,Burgbrol'',bu er ge bu luo er,Бургброл,Бургброль,布尔格布罗尔', 50.4546300, 7.2772000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38639, 'Burgbernheim', 'Burgbernheim', 'Burgberngajm,Burgbernhaym,Burgbernheim,Burgbernkhajm,bu er ge bei er en hai mu,bwrgbrnhaym,bwrghbrnhaym,Бургбернгайм,Бургбернхайм,Бургбернхајм,Բուրգբերնհայմ,بورغبرنهايم,بورگبرنهایم,布尔格贝尔恩海姆', 49.4510300, 10.3238500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38640, 'Burgberg', 'Burgberg', 'Burgberg,Burgberg im Allgaeu,Burgberg im Allgäu', 47.5365700, 10.2888300, 'DE', '2015-03-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38641, 'Burgau', 'Burgau', 'Burgau,Burgau Kreis Gunzburg,Burgau Kreis Günzburg,bu er gao,bwrghaw,bwrgwa,Бургау,Բուրգաու,بورغاو,بورگوا,布尔高', 48.4315900, 10.4098900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38642, 'Burg auf Fehmarn', 'Burg auf Fehmarn', 'Burg,Burg am Fehmarn,Burg auf Fehmarn,Бург', 54.4333300, 11.2000000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38643, 'Burg', 'Burg', 'Burg', 53.9970800, 9.2589100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38644, 'Burg bei Magdeburg', 'Burg bei Magdeburg', 'Burg,Stadt Burg bei Magdeburg', 52.2715200, 11.8549300, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38645, 'Burg', 'Burg', 'Borkowy,Burg,Burg (Spreewald),Burg-Dorf,Bórkowy', 51.8344800, 14.1485600, 'DE', '2017-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38646, 'Burg', 'Burg', '', 49.9666700, 6.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38647, 'Büren', 'Bueren', 'Biren,Bjuren,Bueren,Buren,Burion,Büren,Būrion,bwrn,Бирен,Бюрен,بورن', 51.5510900, 8.5595600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38648, 'Bürdenbach', 'Burdenbach', '', 50.6043800, 7.5163700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38649, 'Burbach', 'Burbach', 'Burbach', 50.7510500, 8.0793900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38650, 'Burbach', 'Burbach', '', 50.1075400, 6.5181800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38651, 'Bunsoh', 'Bunsoh', 'Bunsoh', 54.1648100, 9.3199200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38652, 'Bünsdorf', 'Bunsdorf', 'Bunsdorf,Bünsdorf', 54.3666700, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38653, 'Bundorf', 'Bundorf', 'Bundorf,Бундорф,Բունդորֆ', 50.2166700, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38654, 'Bundenthal', 'Bundenthal', '', 49.0954900, 7.8083900, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38655, 'Bundenbach', 'Bundenbach', 'Bundenbakh,ben deng ba he,Бунденбах,本登巴赫', 49.8428000, 7.3782600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38656, 'Bunde', 'Bunde', 'Bunde', 53.1833300, 7.2666700, 'DE', '2016-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38657, 'Bünde', 'Buende', 'Binde,Bjunde,Buende,Buginithi,Bunde,Bünde,byunde,Бинде,Бюнде,ビュンデ', 52.1983700, 8.5864400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38658, 'Bülstringen', 'Bulstringen', 'Bilstringen,Bjul''shtringen,Bjul''stringen,Bulstringen,Bülstringen,bi er si te lin gen,Билстринген,Бюльстринген,Бюльштринген,比尔斯特林根', 52.3166700, 11.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38659, 'Bullenkuhlen', 'Bullenkuhlen', 'Bullenkuhlen', 53.7666700, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38660, 'Bullay', 'Bullay', 'Bulaj,Bullaj,bu lai,Булај,Буллай,布莱', 50.0544800, 7.1373000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38661, 'Bülkau', 'Buelkau', 'Bilkau,Bjul''kau,Bulkau,Bülkau,Gemeen Buelkau,Gemeen Bülkau,bi er kao,Билкау,Бюлькау,比尔考', 53.7461300, 8.9781300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38662, 'Bühren', 'Buehren', '', 52.8062900, 8.2188000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38663, 'Bühren', 'Buhren', 'Biren,Bjuren,bi he lun,byuren,Бирен,Бюрен,ビューレン,比赫伦', 51.4833300, 9.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38664, 'Bühnsdorf', 'Buehnsdorf', 'Buhnsdorf,Bühnsdorf', 53.8833300, 10.3833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38665, 'Bühlerzell', 'Buhlerzell', 'Bilercel,Bjulercell'',bi he lai er ce er,byuratsu~eru,Билерцел,Бюлерцелль,ビューラーツェル,比赫莱尔策尔', 49.0033300, 9.9205600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38666, 'Bühlertann', 'Buhlertann', 'Bilertan,Bjulertan,Bjulertann,Buehlertann,Buhlertann,Bühlertann,bi he lai er tan,byuratan,Билертан,Бюлертан,Бюлертанн,ビューラータン,比赫莱尔坦', 49.0416700, 9.9086100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38667, 'Bühlertal', 'Buhlertal', 'Bilertal,Bjulertal'',Buehlertal,Buhlertal,Bühlertal,bi he lai er ta er,Билертал,Бюлерталь,比赫莱尔塔尔', 48.6856900, 8.1887600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38668, 'Buhlenberg', 'Buhlenberg', '', 49.6549900, 7.1199500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38669, 'Buhla', 'Buhla', 'Buhla', 51.4333300, 10.4333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38670, 'Bühl', 'Buhl', 'Bil,Bjul'',Buehl,Buhl,Bühl,bwl,bywl,Бил,Бюль,بول,بيول', 48.6967600, 8.1352300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38671, 'Buggingen', 'Buggingen', 'Buggingen,Bugingen,bu jin gen,Буггинген,Буггінген,Бугинген,Բուգինգեն,布金根', 47.8475000, 7.6379900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38672, 'Bufleben', 'Bufleben', 'Bufleben,bu fu lai ben,Буфлебен,布夫莱本', 51.0000000, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38673, 'Büdlich', 'Budlich', '', 49.7833300, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38674, 'Büdingen', 'Buedingen', 'Bidingen,Bjudingehn,Bjudingen,Buedingen,Büdingen,bi ding gen,bwdynghn,bwdyngn,byudingen,Бидинген,Бюдинген,Бюдингэн,Бюдінген,بودينغن,بودینگن,ビューディンゲン,比丁根', 50.2901300, 9.1114000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38675, 'Büdesheim', 'Budesheim', '', 50.2166700, 6.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38676, 'Budenheim', 'Budenheim', 'Budenheim,Budenkhajm,bu deng hai mu,budenhaimu,Буденхайм,Буденхајм,ブーデンハイム,布登海姆', 50.0166700, 8.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38677, 'Budenbach', 'Budenbach', '', 50.0333300, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38678, 'Büdelsdorf', 'Buedelsdorf', 'Budelsdorf,Buedelsdorf,Büdelsdorf', 54.3184400, 9.6729500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38679, 'Buckow', 'Buckow', 'Berlin-Buckow', 52.4320000, 13.4601800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38680, 'Buckow', 'Buckow', 'Buckow,Bukkov,Bukov,bu ke,bwkw,Букков,Буков,بوکو,布科', 52.5661000, 14.0742900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38681, 'Buckenhof', 'Buckenhof', '', 49.5932400, 11.0504400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38682, 'Bücken', 'Buecken', 'Biken,Bjuken,Bjukken,Bucken,Bücken,bi ken,byukken,Бикен,Бюкен,Бюккен,ビュッケン,比肯', 52.7787600, 9.1337100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38683, 'Bückeburg', 'Buckeburg', 'Bikeburg,Bjukkeburg,Buckeborch [a. 1348],Buckeburg,Buckeburgo,Bueckeborch,Bueckeburg,Bückeborch,Bückeburg,bi ke bao,bwikebuleukeu,bwkh‌bwrg,byukkeburuku,bywkhbwrgh,Бикебург,Бюккебург,بوکه‌بورگ,بيوكهبورغ,ビュッケブルク,比克堡,뷔케부르크', 52.2606500, 9.0493900, 'DE', '2016-04-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38684, 'Buchloe', 'Buchloe', 'Buchloe,Bukhle,Bukhlo,Bukhloeh,Buxloe,bu luo ai,bufuroe,bwshlw,Бухле,Бухло,Бухлоэ,Բուխլոե,بوشلو,ブーフローエ,布洛埃', 48.0371900, 10.7254800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38685, 'Büchlberg', 'Buechlberg', 'Bilberg,Bjukhl''berg,Buechlberg,Byuxlberg,Büchlberg,bi xi er bei ge,bwshlbrg,Билберг,Бюхльберг,Բյուխլբերգ,بوشلبرگ,比希尔贝格', 48.6711200, 13.5210000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38686, 'Buchhorst', 'Buchhorst', '', 53.3859600, 10.5655000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38687, 'Buchholz in der Nordheide', 'Buchholz in der Nordheide', 'Buchholz,Buchholz in der Nordheide,Bukhgol''c-in-der-Nordkhajde,Bukhkhol''c-in-der-Nordkhajde,Bukholc in der Nordkhajde,Gemeen Bookholt,bwkhhlts dr nwrdhaydh,bwkhhwlts an dr nwrdhaydh,nuo er deng di an bu he huo er ci,Бухгольц-ин-дер-Нордхайде,Бухолц ин дер Нордхајде,Буххольц-ин-дер-Нордхайде,بوخهلتس در نوردهایده,بوخهولتس إن در نوردهايده,诺尔登堤岸布赫霍尔茨', 53.3264100, 9.8681200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38688, 'Französisch Buchholz', 'Buchholz', 'Berlin-Buchholz,Berlin-Franzoesisch Buchholz,Berlin-Französisch Buchholz,Buchholz,Francjozish-Bukhkhol''c,Францёзиш-Буххольц', 52.6024200, 13.4301900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38689, 'Buchholz', 'Buchholz', '', 53.9882900, 9.2236200, 'DE', '2011-07-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38690, 'Buchholz', 'Buchholz', '', 53.7333300, 10.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38691, 'Buchholz', 'Buchholz', '', 53.0088400, 9.5628700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38692, 'Buchholz', 'Buchholz', '', 52.2265400, 9.1277500, 'DE', '2016-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38693, 'Buchholz', 'Buchholz', '', 51.5333300, 10.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38694, 'Buchhofen', 'Buchhofen', 'Bukhgofen,Bukhkhofen,Buxhofen,bu huo fen,bwkhhwfn,Бухгофен,Буххофен,Բուխհոֆեն,بوخهوفن,布霍芬', 48.6969700, 12.9245600, 'DE', '2012-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38695, 'Buchheim', 'Buchheim', '', 50.9515200, 7.0209300, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38696, 'Buchheim', 'Buchheim', '', 48.0103700, 8.9859600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38697, 'Buchfart', 'Buchfart', '', 50.9210300, 11.3324800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38698, 'Buchet', 'Buchet', '', 50.2333300, 6.3166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38699, 'Büchenbeuren', 'Buechenbeuren', 'Bikhenbojren,Bjukhenbojren,Buechenbeuren,Büchenbeuren,bi xing bo yi lun,Бихенбојрен,Бюхенбойрен,比兴博伊伦', 49.9209700, 7.2799900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38700, 'Buchenberg', 'Buchenberg', 'Buchenberg,Bukhenberg,Buxenberg,bu heng bei ge,Бухенберг,Բուխենբերգ,布亨贝格', 47.6959300, 10.2392700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38701, 'Büchenbach', 'Buchenbach', 'Bikhenbakh,Bjukhenbakh,Buechenbach,Byuxenbax,Büchenbach,bi xing ba he,byuhyenbahha,Бихенбах,Бюхенбах,Բյուխենբախ,ビューヒェンバッハ,比兴巴赫', 49.2677800, 11.0588900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38702, 'Buchenbach', 'Buchenbach', 'Buchenbach,Bukhenbakh,Buxenbax,bu heng ba he,Бухенбах,Բուխենբախ,布亨巴赫', 47.9613800, 8.0090900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38703, 'Büchen', 'Buchen', 'Bikhen,Bjukhen,bi xing,Бихен,Бюхен,比兴', 53.4800800, 10.6176000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38704, 'Buchen', 'Buchen', 'Buchen,Buchen in Odenwald,Bukhen,bu heng,buhyen,bwkhn,Бухен,بوخن,ブーヒェン,布亨', 49.5241600, 9.3229300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38705, 'Büchel', 'Buchel', '', 51.2500000, 11.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38706, 'Büchel', 'Buechel', 'Bikhel,Bjukhel'',bi xie er,Бихел,Бюхель,比歇尔', 50.1728900, 7.0831800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38707, 'Buchdorf', 'Buchdorf', '', 48.7833300, 10.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38708, 'Buchbrunn', 'Buchbrunn', 'Buchbrunn,Bukhbrun,Bukhbrunn,Buxbrun,bu bu lun,Бухбрун,Бухбрунн,Բուխբրուն,布布伦', 49.7598100, 10.1368600, 'DE', '2013-02-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38709, 'Buchbach', 'Buchbach', 'Buchbach,Bukhbakh,Buxbax,bwkhbakh,Бухбах,Բուխբախ,بوخباخ', 48.3123100, 12.2734300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38710, 'Buch am Buchrain', 'Buch am Buchrain', 'Buch,Buch am Buchrain,Bukh am Bukhrajn,Bukh-am-Bukhrajn,bu he lai yin pan bu he,bwkh am bwkhrayn,Бух ам Бухрајн,Бух-ам-Бухрайн,بوخ ام بوخراین,布赫赖因畔布赫', 48.2151000, 11.9950900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38711, 'Buch am Ahorn', 'Buch am Ahorn', 'Buch,Buch am Ahorn', 49.5390900, 9.5556000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38712, 'Bucha', 'Bucha', '', 50.8833300, 11.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38713, 'Bucha', 'Bucha', '', 50.6333300, 11.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38714, 'Buch', 'Buch', 'Berlin-Buch,Bukh,Бух', 52.6347000, 13.4967900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38715, 'Buch', 'Buch', '', 50.2000000, 7.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38716, 'Buch', 'Buch', '', 50.0760900, 7.3892300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38717, 'Buch', 'Buch', '', 48.6523400, 12.1631100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38718, 'Buch', 'Buch', 'Bukh,Bux,Бух,Բուխ', 48.2247900, 10.1805500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38719, 'Bubsheim', 'Bubsheim', 'Bubskhajm,bu bu si hai mu,Бубсхайм,Бубсхајм,布布斯海姆', 48.1166700, 8.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38720, 'Buborn', 'Buborn', 'Buborn,bu bo er en,Буборн,布博尔恩', 49.6333300, 7.5500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38721, 'Bubesheim', 'Bubesheim', 'Bubesgajm,Bubeshaym,Bubeskhajm,bu bei si hai mu,Бубесгайм,Бубесхайм,Бубесхајм,Բուբեսհայմ,布贝斯海姆', 48.4333300, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38722, 'Bubenreuth', 'Bubenreuth', 'Bubenrojt,bu ben luo yi te,bubenroito,Бубенройт,Бубенројт,ブーベンロイト,布本罗伊特', 49.6274500, 11.0172300, 'DE', '2012-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38723, 'Bubenheim', 'Bubenheim', '', 49.9216700, 8.0797200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38724, 'Bubenheim', 'Bubenheim', '', 49.6280600, 8.1177800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38725, 'Bubach', 'Bubach', '', 50.0666700, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38726, 'Brüssow', 'Bruessow', 'Brisov,Brjussov,Bryusov,bu lu suo,bwrsw,Брисов,Брюссов,Բրյուսով,بورسو,布吕索', 53.3997100, 14.1253300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38727, 'Brüsewitz', 'Bruesewitz', 'Brizevic,Brjuzevic,Brusewitz,Brüsewitz,bu lu sai wei ci,Бризевиц,Брюзевиц,布吕塞维茨', 53.6758800, 11.2437900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38728, 'Bruschied', 'Bruschied', 'Brushid,bu lu xi de,Брушид,布鲁席德', 49.8333300, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38729, 'Brunstorf', 'Brunstorf', '', 53.4933100, 10.4251800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38730, 'Brunsmark', 'Brunsmark', 'Brunsmark', 53.6166700, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38731, 'Brunsbüttel', 'Brunsbuettel', 'Brunsbitel,Brunsbjuttel'',Brunsbuettel,Brunsbuttel,Brunsbüttel,brwnsbwtl,brwnzbwtl,bu lun si bi te er,Брунсбител,Брунсбюттель,برونزبوتل,برونسبوتل,布伦斯比特尔', 53.8950400, 9.1048400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38732, 'Brunnthal', 'Brunnthal', 'Brunntal'',Brunntoi,Bruntal,Bruntal'',brwntal,bu lun ta er,Бруннталь,Брунтал,Брунталь,Բրունթհալ,برونتال,布伦塔尔', 48.0065200, 11.6840500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38733, 'Brunnen', 'Brunnen', '', 48.6289900, 11.3092200, 'DE', '2012-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38734, 'Brunnen', 'Brunnen', '', 48.2295600, 10.9733200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38735, 'Brunn', 'Brunn', '', 53.6707600, 13.3703200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38736, 'Brunn', 'Brunn', '', 49.2363200, 12.1915600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38737, 'Brunn', 'Brunn', '', 49.1000000, 11.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38738, 'Brumby', 'Brumby', '', 51.8963500, 11.7175100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38739, 'Brühl', 'Bruehl', 'Bril,Brjul'',Bruehl,Brühl,brwl,Брил,Брюль,برول', 50.8292800, 6.9049900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38740, 'Brühl', 'Bruhl', 'Brihl,Bril,Brjul'',Bruehl,Bruhl,Brühl,bu lu er,buryuru,Брил,Брюль,ブリュール,布呂爾', 49.3972200, 8.5336100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38741, 'Brüheim', 'Bruheim', 'Bruheim,Brüheim', 51.0000000, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38742, 'Brüggen', 'Bruggen', 'Brueggen,Brüggen', 52.0425000, 9.7745000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38743, 'Brüggen', 'Bruggen', 'Brueggen,Brüggen', 51.2405300, 6.1837600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38744, 'Brügge', 'Bruegge', '', 54.1757800, 10.0691300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38745, 'Brüel', 'Brueel', 'Briele,Bril,Brjuehl'',Brueel,Bruel,Brüel,Brīele,brwyl,bu lu ai er,Брил,Брюэль,بروئل,برويل,布吕埃尔', 53.7371900, 11.7147100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38746, 'Bruckmühl', 'Bruckmuhl', 'Bruckmuehl,Bruckmuhl,Bruckmühl,Brukmil,Brukmjul'',Brukmyuhl,brwkmwl,bu lu ke mi he er,Брукмил,Брукмюль,Բրուկմյուհլ,بروکمول,布鲁克米赫尔', 47.8785900, 11.9109800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38747, 'Bruck in der Oberpfalz', 'Bruck in der Oberpfalz', 'Bruck,Bruck bei Nittenau,Bruck i.d. OPf.,Bruck in der Oberpfalz,Bruck in der Oberptalz,Bruk,Bruk u Oberpfalcu,Bruk-in-der-Oberpfal''c,brwk ayn dr awbrfalts,Брук,Брук у Оберпфалцу,Брук-ін-дер-Оберпфальц,بروک این در اوبرفالتس', 49.2492700, 12.3071000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38748, 'Brücken', 'Brucken', 'Briken,Brjukken,bu lu ken,Брикен,Брюккен,布吕肯', 49.6333300, 7.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38749, 'Brücken', 'Bruecken', 'Briken,Brjukken,Bruecken,Brücken,Брикен,Брюккен', 49.4317400, 7.3599800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38750, 'Bruckberg', 'Bruckberg', '', 49.3599100, 10.6992400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38751, 'Bruckberg', 'Bruckberg', '', 48.5224400, 11.9944800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38752, 'Brück', 'Brueck', 'Bruck,Brueck,Brück', 52.1976600, 12.7686800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38753, 'Brücktal', 'Brucktal', 'Bruck,Brucktal,Brück,Brücktal', 50.3166700, 6.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38754, 'Bruck', 'Bruck', '', 48.0211600, 11.9078100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38755, 'Bruchweiler-Bärenbach', 'Bruchweiler-Barenbach', '', 49.1166700, 7.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38756, 'Bruchweiler', 'Bruchweiler', 'Brukhvajler,bu lu he wei lei,Брухвайлер,Брухвајлер,布鲁赫韦勒', 49.7983300, 7.2255700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38757, 'Bruchstedt', 'Bruchstedt', '', 51.1833300, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38758, 'Bruchsal', 'Bruchsal', 'Bruchsal,Bruchsalia,Brukhzal,Brukhzal'',Brusel,brwkhzal,bu lu sa er,buruffuzaru,Брухзал,Брухзаль,بروخزال,ブルッフザール,布鲁萨尔', 49.1242600, 8.5980400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38759, 'Bruchköbel', 'Bruchkoebel', 'Bruchkobel,Bruchkoebel,Bruchköbel,Brukhkebel,Brukhkebel'',Brukhkjobel'',Gorad Brukhkjobel'',brwkhkwbl,bu lu ke bei er,burufukeberu,Брухкебел,Брухкебель,Брухкёбель,Горад Брухкёбель,بروخكوبل,بروخکوبل,ブルーフケーベル,布鲁克贝尔', 50.1785300, 8.9231500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38760, 'Bruchhausen-Vilsen', 'Bruchhausen-Vilsen', 'Brooksen-Vilsen,Bruchhausen,Bruchhausen-Vilsen,Brukhauzen-Vilsen,Brukhgauzen-Fil''zen,Brukhkhauzen-Fil''zen,Vilsen,bu lu hao sen-fei er sen,Брухаузен-Вилсен,Брухгаузен-Фильзен,Бруххаузен-Фильзен,布鲁豪森-菲尔森', 52.8293100, 8.9906600, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38761, 'Bruchertseifen', 'Bruchertseifen', '', 50.7500000, 7.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38762, 'Bruch', 'Bruch', '', 49.9569500, 6.7817400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38763, 'Brotterode', 'Brotterode', 'Broterode,Brotterode,brwtrwdh,Бротероде,Броттероде,بروتروده', 50.8241200, 10.4444600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38764, 'Bröthen', 'Brothen', '', 53.4794700, 10.6675500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38765, 'Bronkow', 'Bronkow', 'Bronkov,Bronkow,bu long ke,Бронков,Բրոնկով,布龙科', 51.6666700, 13.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38766, 'Bromskirchen', 'Bromskirchen', 'Bromskirchen,Bromskirkhen,bu luo mu si ji xing,buromusukiruhyen,Бромскирхен,Бромскірхен,ブロムスキルヒェン,布罗姆斯基兴', 51.0936300, 8.6264000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38767, 'Brome', 'Brome', 'Brome,bu luo mei,Броме,布罗梅', 52.6001900, 10.9375400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38768, 'Brokstedt', 'Brokstedt', 'Brokstedt', 53.9833300, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38769, 'Brokdorf', 'Brokdorf', 'Brokdorf', 53.8638000, 9.3231400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38770, 'Brohl', 'Brohl', '', 50.2190900, 7.2794700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38771, 'Broderstorf', 'Broderstorf', 'Broderstorf,bu luo de er si tuo er fu,Бродерсторф,布罗德尔斯托尔夫', 54.0811400, 12.2635000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38772, 'Brodersdorf', 'Brodersdorf', 'Brodersdorf', 54.3833300, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38773, 'Brodersby', 'Brodersby', '', 54.6333300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38774, 'Brodersby', 'Brodersby', '', 54.5333300, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38775, 'Brodenbach', 'Brodenbach', 'Brodenbakh,bu luo deng ba he,Броденбах,布罗登巴赫', 50.2333300, 7.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38776, 'Brockum', 'Brockum', '', 52.4666700, 8.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38777, 'Brockscheid', 'Brockscheid', 'Brockscheid,Brockscheidt,Brokshajd,bu luo ke sha yi de,Брокшайд,Брокшајд,布罗克沙伊德', 50.1333300, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38778, 'Brockel', 'Brockel', 'Brokel,Brokkel'',Brookel,bu luo ke er,burokkeru,Брокел,Броккель,ブロッケル,布罗克尔', 53.1000000, 9.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38779, 'Bröckel', 'Broeckel', 'Braeukel,Breukel,Brockelde [a. 1215],Broeckel,Bräukel,Bröckel', 52.5162700, 10.2150500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38780, 'Britz', 'Britz', 'Berlin-Britz,beulicheu,bu li ci,布里茨,브리츠', 52.4429300, 13.4338800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38781, 'Britz', 'Britz', '', 52.8872600, 13.8111900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38782, 'Britten', 'Britten', '', 49.5206100, 6.6765100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38783, 'Brinkum', 'Brinkum', '', 53.2666700, 7.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38784, 'Brinjahe', 'Brinjahe', 'Brinjahe', 54.1666700, 9.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38785, 'Brimingen', 'Brimingen', '', 49.9697200, 6.3636600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38786, 'Brilon', 'Brilon', 'Brailen,Brilon,bryln,brylwn,bu li long,Брилон,Брілон,بريلون,بریلن,布里隆', 51.3946200, 8.5714600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38787, 'Brietlingen', 'Brietlingen', 'Britlingen,bu li te lin gen,Бритлинген,布里特林根', 53.3333300, 10.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38788, 'Brieskow-Finkenheerd', 'Brieskow-Finkenheerd', 'Brieskow,Briskov Finkenherd,Briskov-Finkenkherd,Finkenheerd,bu li si ke fu-fen ken hei er de,Брисков-Финкенхерд,Բրիսկով Ֆինկենհերդ,布里斯科夫-芬肯黑尔德', 52.2538700, 14.5728500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38789, 'Briesen', 'Briesen', '', 52.3438300, 14.2780400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38790, 'Briesen', 'Briesen', 'Briesen,Briesen/Brjazyna,Brizen,Brjazyna,bu li sen,Бризен,Բրիզեն,布里森', 51.8155400, 14.2442000, 'DE', '2011-07-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38791, 'Brieselang', 'Brieselang', 'Briselang,Brizelang,bu li sai lang,Бризеланг,Бриселанг,Բրիզելանգ,布里塞朗', 52.5833300, 13.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38792, 'Briedern', 'Briedern', '', 50.1000000, 7.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38793, 'Brieden', 'Brieden', '', 50.1833300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38794, 'Briedel', 'Briedel', 'Bridel,Bridel'',bu li de er,Бридел,Бридель,布里德尔', 50.0166700, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38795, 'Brickeln', 'Brickeln', 'Brickeln', 54.0166700, 9.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38796, 'Brey', 'Brey', '', 50.2725300, 7.6264500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38797, 'Brevörde', 'Brevorde', 'Brefjorde,Breverde,bu lei fu er de,bureferude,Бреверде,Брефёрде,ブレフェルデ,布雷弗尔德', 51.9166700, 9.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38798, 'Breunigweiler', 'Breunigweiler', '', 49.5666700, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38799, 'Breuna', 'Breuna', 'Brojna,Bruene,Brüne,bu luo yi na,buroina,Бройна,Бројна,ブロイナ,布罗伊纳', 51.4157500, 9.1850000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38800, 'Bretzfeld', 'Bretzfeld', 'Brecfel''d,Brecfeld,Bretcfel''d,Bretzfeld,bu lei ci fei er de,burettsuferuto,Бретцфельд,Брецфелд,Брецфельд,ブレッツフェルト,布雷茨费尔德', 49.1794400, 9.4383300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38801, 'Bretzenheim', 'Bretzenheim', 'Brecenkhajm,Bretcenkhajm,bu lei cen hai mu,Бретценхайм,Бреценхајм,布雷岑海姆', 49.8779600, 7.8965300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38802, 'Bretthausen', 'Bretthausen', '', 50.6666700, 8.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38803, 'Bretten', 'Bretten', 'Breten,Bretten,brtn,brytn,bu lei teng,Бретен,Бреттен,برتن,بريتن,布雷滕', 49.0368500, 8.7074500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38804, 'Bretleben', 'Bretleben', 'Bretleben', 51.3333300, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38805, 'Brest', 'Brest', '', 53.4500000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38806, 'Brensbach', 'Brensbach', 'Brensbakh,bu lun si ba he,burensubahha,Бренсбах,ブレンスバッハ,布伦斯巴赫', 49.7738900, 8.8844400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38807, 'Brennberg', 'Brennberg', 'Brenberg,Brennberg,brnbrg,Бренберг,Бреннберг,Բրենբերգ,برنبرگ', 49.0666700, 12.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38808, 'Brenk', 'Brenk', '', 50.4333300, 7.1833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38809, 'Bremsnitz', 'Bremsnitz', 'Bremsnitz', 50.7992400, 11.7715500, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38810, 'Bremm', 'Bremm', '', 50.1000000, 7.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38811, 'Bremervörde', 'Bremervoerde', 'Bremerf''orde,Bremerfjorde,Bremerverde,Bremervoerde,Bremervorde,Bremervörde,Gemeen Bremervoeoer,Gemeen Bremervöör,brmrfwrdh,brymrfwrdh,bu lei mei er fu er de,buremaferude,Бремерверде,Бремерфьорде,Бремерфёрде,برمرفورده,بريمرفورده,ブレーマーフェルデ,布雷梅尔弗尔德', 53.4845800, 9.1430600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38812, 'Bremerhaven', 'Bremerhaven', 'BRV,Bremergafen,Bremerhafenas,Bremerhafene,Bremerhaven,Bremerhoawen,Bremerhoben,Bremerhuuwen,Bremerkhafen,Brēmerhāfene,Brėmerhafenas,Wesermuende,Wesermünde,beulemeohapen,bremerhaveni,brmrhafn,bu lai mei ha fen,buremahafen,Бремергафен,Бремерхафен,Брэмэрһаффен,برمرهافن,بریمرہیون,ბრემერჰავენი,ブレーマーハーフェン,不来梅哈芬,브레머하펜', 53.5502100, 8.5767300, 'DE', '2016-10-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38813, 'Bremen', 'Bremen', 'BRE,Brehmehn,Brema,Breme,Bremen,Bremen hiria,Bremenas,Bremene,Bremeni,Bremeno,Bremy,Brèma,Bréma,Brémy,Brémén,Brême,Brēmene,Brėmenas,Byen Bremen,Gorad Brehmen,ber mein,beulemen,bremena,bremeni,brmn,brymn,bu lai mei,buremen,mdynt brymn,Βρέμη,Бремен,Брэмэн,Горад Брэмен,Բրեմեն,ברמן,برمن,بريمن,مدينة بريمن,ब्रेमेन,เบรเมิน,ဘရီမန်မြို့,ბრემენი,ブレーメン,不来梅,브레멘,', 53.0751600, 8.8077700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38814, 'Bremberg', 'Bremberg', '', 50.3063900, 7.9201100, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38815, 'Breklum', 'Breklum', 'Braeaeklem,Breklum,Brääklem,bu lei ke lu mu,Бреклум,布雷克卢姆', 54.6000000, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38816, 'Brekendorf', 'Brekendorf', 'Brekendorf', 54.4212000, 9.6335000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38817, 'Breitungen', 'Breitungen', 'Altenbreitungen,Brajtungen,Breitungen,Breitungen/Werra,bu lai tong gen,Брайтунген,Брајтунген,布赖通根', 50.7635500, 10.3272400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38818, 'Breitscheidt', 'Breitscheidt', 'Breitscheid,Breitscheidt', 50.7500000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38819, 'Breitscheid', 'Breitscheid', 'Brajtshajd,Breitscheid,Брайтшайд,Брајтшајд', 50.6850700, 8.1912000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38820, 'Breitscheid', 'Breitscheid', '', 50.5815400, 7.4438200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38821, 'Breitscheid', 'Breitscheid', '', 50.0500000, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38822, 'Breitnau', 'Breitnau', 'Brajtnau,Braytnau,Breitnau,Брайтнау,Брајтнау,Բրայտնաու', 47.9333300, 8.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38823, 'Breitingen', 'Breitingen', '', 48.5172600, 9.9922800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38824, 'Breitenworbis', 'Breitenworbis', 'Breitenworbis', 51.4126700, 10.4282000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38825, 'Breitenthal', 'Breitenthal', 'Brajtental,Brajtental'',Breitenthal,Брайтенталь,Брајтентал', 49.8000000, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38826, 'Breitenthal', 'Breitenthal', '', 48.2378200, 10.2995100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38827, 'Breitenheim', 'Breitenheim', '', 49.7000000, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38828, 'Breitengüßbach', 'Breitengussbach', 'Brajtengisbakh,Brajtengjusbakh,Braytengyusbax,bu lai teng ju si ba he,buraitengyusubahha,Брайтенгюсбах,Брајтенгисбах,Բրայտենգյուսբախ,ブライテンギュスバッハ,布赖滕居斯巴赫', 49.9720900, 10.8859100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38829, 'Breitenfelde', 'Breitenfelde', 'Brajtenfel''de,Brajtenfelde,Breitenfelde,bu lai teng fei er de,Брайтенфельде,Брајтенфелде,布赖滕费尔德', 53.6059200, 10.6333900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38830, 'Breitenburg', 'Breitenburg', 'Brajtenburg,Breitenburg,bu lai teng bao,Брайтенбург,Брајтенбург,布赖滕堡', 53.9057200, 9.5704100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38831, 'Breitenbrunn', 'Breitenbrunn', 'Brajtenbrun,Brajtenbrunn,Breitenbrunn,Breitenbrunn/Erzgebirge,Breitenbrunni vald,Брайтенбрунн,Брајтенбрун', 50.4755300, 12.7664900, 'DE', '2017-07-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38832, 'Breitenbrunn', 'Breitenbrunn', '', 49.3638800, 12.0201300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38833, 'Breitenbrunn', 'Breitenbrunn', '', 48.1333300, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38834, 'Breitenberg', 'Breitenberg', '', 53.9241300, 9.6351400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38835, 'Breitenberg', 'Breitenberg', 'Breitenberg,Breitenburg', 48.7043900, 13.7933300, 'DE', '2011-07-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38836, 'Breitenbach', 'Breitenbach', '', 50.9565500, 9.7828500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38837, 'Breitenbach', 'Breitenbach', '', 50.6889500, 10.4914800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38838, 'Breitenbach', 'Breitenbach', 'Brajtenbakh,Брайтенбах,Брајтенбах', 49.4333300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38839, 'Breitenau', 'Breitenau', '', 50.4980600, 7.6905600, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38840, 'Breitbrunn', 'Breitbrunn', '', 50.0166700, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38841, 'Breitbrunn', 'Breitbrunn', '', 48.0432000, 12.1543100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38842, 'Breit', 'Breit', '', 49.7756100, 6.9055900, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38843, 'Breisach am Rhein', 'Breisach am Rhein', 'Alt-Breisach,Brajsakh na Rajni,Brajzakh,Brajzakh am Rejn,Brajzakh-am-Rajn,Brajzakh-na-Rejne,Breisach,Breisach am Rhein,Vieux-Brisach,brayzakh,lai yin he pan bu lai sa he,rainis braizakhi,Брайзах,Брайзах ам Рейн,Брайзах-ам-Райн,Брайзах-на-Рейне,Брајзах,Брајсах на Рајни,ברייזאך,برايزاخ,برایزاخ,რაინის ბრაიზახი,莱茵河畔布莱萨赫', 48.0327900, 7.5829400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38844, 'Breiholz', 'Breiholz', 'Breiholz', 54.2055400, 9.5237100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38845, 'Breidenbach', 'Breidenbach', 'Brajdenbakh,bu lai deng ba he,buraidenbahha,Брайденбах,Брајденбах,ブライデンバッハ,布赖登巴赫', 50.8873400, 8.4574800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38846, 'Brehna', 'Brehna', 'Brehna', 51.5579000, 12.2127600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38847, 'Brehme', 'Brehme', '', 51.4942100, 10.3590800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38848, 'Breese', 'Breese', '', 53.0000000, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38849, 'Bredstedt', 'Bredstedt', 'Braeist,Bredshtedt,Bredshtet,Bredsted,Bredstedt,Bräist,brdashtt,brydshtyt,bu lei ci te,Бредштедт,Бредштет,برداشتت,بريدشتيت,布雷茨特', 54.6186800, 8.9644100, 'DE', '2015-05-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38850, 'Bredenbek', 'Bredenbek', '', 54.3224700, 9.8729300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38851, 'Breddorf', 'Breddorf', '', 53.2926200, 9.0808900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38852, 'Breddin', 'Breddin', '', 52.8856000, 12.2236600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38853, 'Breddenberg', 'Breddenberg', '', 52.9546400, 7.6112900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38854, 'Breckerfeld', 'Breckerfeld', 'Braeckfelle,Breckerfeld,Brekerfeld,Brekkerfel''d,Bräckfelle,brkrfld,brykrfld,bu lei ke er fei er de,Брекерфелд,Бреккерфельд,بريكرفلد,برکرفلد,布雷克尔费尔德', 51.2592600, 7.4680700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38855, 'Brecht', 'Brecht', '', 49.9833300, 6.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38856, 'Brebel', 'Brebel', 'Brebel', 54.6333300, 9.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38857, 'Brauweiler', 'Brauweiler', '', 49.8166700, 7.5000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38858, 'Braunweiler', 'Braunweiler', '', 49.8666700, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38859, 'Braunshorn', 'Braunshorn', '', 50.0833300, 7.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38860, 'Braunschweig', 'Braunschweig', 'BWE,Braounsvaich,Braunschweig,Braunshvajg,Braunshvejg,Braunshweyg,Braunshwéyg,Braunsveiga,Braunsveigas,Braunšveiga,Braunšveigas,Bronswiek,Brunsvicum,Brunsvik,Brunswick,Brunswik,Brunswyck,Brunswyk,Brunszwik,Brunšwik,Brúnsvík,Gorad Braunshvejg,beulaunsyubaikeu,bra''unasva''iga,branjavika,branshwyg,braunshvaigi,brawnshfaygh,brawnshwayg,bu lun rui ke,buraunshuvu~aiku,Μπράουνσβαϊχ,Брауншвайг,Брауншвајг,Брауншвейг,Горад Браўншвейг,בראונשווייג,برانشویگ,براونشفايغ,براونشوایگ,ब्रंजविक,ब्राउनश्वाइग,ბრაუნშვაიგი,ブラウンシュヴァイク,不伦瑞克,브라운슈바이크', 52.2659400, 10.5267300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38861, 'Braunsbedra', 'Braunsbedra', 'Braunsbedra,Braunsdorf,brwansbdra,bu luo yin si bei de la,Браунсбедра,بروانسبدرا,布罗因斯贝德拉', 51.2860200, 11.8898700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38862, 'Braunsbach', 'Braunsbach', 'Braunsbach,Braunsbakh,bu luo yin si ba he,buraunsubahha,Браунсбах,ブラウンスバッハ,布罗因斯巴赫', 49.1991700, 9.7905600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38863, 'Bräunlingen', 'Braunlingen', 'Braeunlingen,Braunlingen,Brojnlingen,Bräunlingen,brwanayngn,brwynlynghn,bu luo yi en lin gen,Бройнлинген,Бройнлінген,Бројнлинген,برواناینگن,بروينلينغن,布罗伊恩林根', 47.9295700, 8.4480600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38864, 'Braunlage', 'Braunlage', 'Braunlage,brawnlaghh,brwanlagh,bu luo yin la ge,Браунлаге,براونلاغه,بروانلاگه,布罗因拉格', 51.7265100, 10.6109000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38865, 'Braunichswalde', 'Braunichswalde', 'Braunichswalde', 50.8000000, 12.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38866, 'Braunfels', 'Braunfels', 'Braunfel''s,Braunfels,Gorad Braunfel''s,brawnflz,brwanflz,bu luo yin fei er si,Браунфелс,Браунфельс,Горад Браўнфельс,براونفلز,بروانفلز,布罗因费尔斯', 50.5154500, 8.3891800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38867, 'Brauneberg', 'Brauneberg', 'Brauneberg,bu lao ne bei ge,Браунеберг,布劳讷贝格', 49.9058300, 6.9812700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38868, 'Braubach', 'Braubach', 'Braubach,Braubakh,brawbakh,brwabakh,bu lao ba he,buraubahha,Браубах,براوباخ,برواباخ,ブラウバッハ,布劳巴赫', 50.2736000, 7.6450800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38869, 'Braschwitz', 'Braschwitz', 'Braschwitz', 51.5228400, 12.0586700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38870, 'Brannenburg', 'Brannenburg', 'Branenburg,Brannaburg,Brannenburg,brannbwrg,bu la nen bao,Браненбург,Бранненбург,Բրանենբուրգ,براننبورگ,布拉嫩堡', 47.7399600, 12.0916600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38871, 'Brandshagen', 'Brandshagen', '', 54.2394500, 13.1691700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38872, 'Brandscheid', 'Brandscheid', '', 50.5608300, 7.9202800, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38873, 'Brandscheid', 'Brandscheid', '', 50.2201500, 6.3084800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38874, 'Brandis', 'Brandis', '', 51.3359700, 12.6102400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38875, 'Brand-Erbisdorf', 'Brand-Erbisdorf', 'Brand-Ehrbisdorf,Brand-Erbisdorf,Branda-Erbisdorfa,Erbisdorf,brand-arbysdwrf,brnd-arbysdwrf,bu lan de-ai er bi si duo fu,Бранд-Ербисдорф,Бранд-Эрбисдорф,براند-إربيسدورف,برند-اربیسدورف,布兰德-埃尔比斯多夫', 50.8664300, 13.3228500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38876, 'Brandenburg an der Havel', 'Brandenburg an der Havel', 'Brandebourg-sur-la-Havel,Brandeburgas,Brandeburgo sulla Havel,Brandenburg,Brandenburg na Khafelu,Brandenburg un der Havel,Brandenburg-na-Khafele,Brandenburg-na-Khafeli,Brandenburgas,Brandenburgum,Brannenborg an de Havel,Ciudad de Brandeburgo,beulandenbuleukeuandeeohapel,brandenburgi,brndnbwrg,brndnbwrg an dr hawl,ha fu er he pan bo lan deng bao,Бранденбург,Бранденбург на Хафелу,Бранденбург-на-Хафеле,Бранденбург-на-Хафелі,ברנדנבורג,برانڈنبرگ آن ڈیر ہاول,برندنبورگ آن در هاول,ბრანდენბურგი,ブランデンブルク・アン・デア・ハーフェル,哈弗尔河畔勃兰登堡,브란덴부르크안데어하펠', 52.4166700, 12.5500000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38877, 'Brande-Hörnerkirchen', 'Brande-Hornerkirchen', 'Brande-Hoernerkirchen,Brande-Hornerkirchen,Brande-Hörnerkirchen', 53.8500000, 9.7166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38878, 'Brand', 'Brand', '', 49.9597200, 11.9107200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38879, 'Bramstedtlund', 'Bramstedtlund', 'Bramstedtlund', 54.8500000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38880, 'Bramstedt', 'Bramstedt', '', 53.3660300, 8.6900500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38881, 'Bramsche', 'Bramsche', 'Bramsche,Bramshe,bramshh,bu la mu she,Брамше,برامشه,布拉姆舍', 52.4088100, 7.9728800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38882, 'Brammer', 'Brammer', '', 54.2000000, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38883, 'Brakel', 'Brakel', 'Brakal,Brakel,Brakel'',brakl  alman,Бракел,Бракель,براکل، آلمان', 51.7175000, 9.1859600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38884, 'Brake (Unterweser)', 'Brake (Unterweser)', 'Brake', 53.3333300, 8.4833300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38885, 'Brahmenau', 'Brahmenau', 'Brahmenau,Bramenau,bu la mei nao,Браменау,布拉梅瑙', 50.9235900, 12.1588600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38886, 'Braderup', 'Braderup', 'Braderup,Braeaederep,Braeaegerep,Brääderep,Brääđerep', 54.8354000, 8.8904300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38887, 'Brackenheim', 'Brackenheim', 'Brackenheim,Brakenkhajm,Brakkengajm,braknhaym,bu la ken hai mu,burakkenhaimu,Бракенхайм,Бракенхајм,Браккенгайм,براكنهايم,براکنهایم,ブラッケンハイム,布拉肯海姆', 49.0778700, 9.0660100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38888, 'Brackel', 'Brackel', '', 53.2997400, 10.0486000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38889, 'Brachtendorf', 'Brachtendorf', '', 50.2333300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38890, 'Brachbach', 'Brachbach', 'Brachbach,Brachback,Brakhbakh,brakhbakh,bu la ba he,Брахбах,براخباخ,布拉巴赫', 50.8166700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38891, 'Braak', 'Braak', '', 53.6099100, 10.2453200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38892, 'Böxlund', 'Boxlund', 'Boxlund,Böxlund', 54.8500000, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38893, 'Boxberg', 'Boxberg', 'Boksberg,Boxberg,Boxberg/Hamor,Boxberg/O.L.,Boxberg/Oberlausitz,Boxbergi vald,Hamor,Боксберг', 51.4037300, 14.5759800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38894, 'Boxberg', 'Boxberg', '', 50.2666700, 6.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38895, 'Boxberg', 'Boxberg', 'Boxberg,Boxberg Stadt', 49.4796500, 9.6400600, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38896, 'Bovenden', 'Bovenden', 'Bovenden,Bovendeni vald,bo fen deng,bovu~enden,Бовенден,ボーヴェンデン,博芬登', 51.5883600, 9.9222000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38897, 'Bovenau', 'Bovenau', '', 54.3333300, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38898, 'Bous', 'Bous', 'Bous,Buss,Buß', 49.2773200, 6.8013100, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38899, 'Bötzingen', 'Botzingen', 'Becingen,Betcingen,Bjotcingen,Boetzingen,Bötzingen,bo qin gen,Бетцинген,Бецинген,Бётцинген,Բյոտցինգեն,伯钦根', 48.0764200, 7.7248500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38900, 'Bottrop', 'Bottrop', 'Botrop,Botropas,Bottrop,ZCJ,bo te luo pu,boteulopeu,botoroppu,bttrwp,Ботроп,Боттроп,بتتروپ,بوٹروپ,ბოტროპი,ボトロップ,博特罗普,보트로프', 51.5239200, 6.9285000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38901, 'Böttingen', 'Bottingen', 'Betingen,Bjottingen,bo ting gen,Бетинген,Бёттинген,伯廷根', 48.1000000, 8.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38902, 'Bottenbach', 'Bottenbach', '', 49.1833300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38903, 'Bothkamp', 'Bothkamp', 'Bothkamp', 54.2000000, 10.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38904, 'Bothenheilingen', 'Bothenheilingen', '', 51.1833300, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38905, 'Bothel', 'Bothel', '', 53.0666700, 9.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38906, 'Bötersen', 'Botersen', '', 53.1333300, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38907, 'Bösleben-Wüllersleben', 'Bosleben-Wullersleben', 'Boesleben-Wuellersleben,Bosleben-Wullersleben,Bösleben-Wüllersleben', 50.8333300, 11.0666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38908, 'Bösingen', 'Bosingen', 'Boesingen,Bösingen', 48.2333300, 8.5500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38909, 'Bösenbrunn', 'Bosenbrunn', 'Bezenbrun,Bjozenbrunn,bo sen bu lun,Безенбрун,Бёзенбрунн,Бөзенбрунн,伯森布伦', 50.3970300, 12.0999800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38910, 'Bosenbach', 'Bosenbach', 'Bosenbakh,Bozenbakh,bo sen ba he,Бозенбах,Босенбах,博森巴赫', 49.5402200, 7.5302900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38911, 'Bösel', 'Bosel', 'Bezel,Bjozel'',Boeaesel,Boesel,Bosel,Bösel,Böäsel,bo sai er,Безел,Бёзель,伯塞尔', 53.0000000, 7.9500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38912, 'Bösdorf', 'Boesdorf', '', 54.1500000, 10.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38913, 'Bosbüll', 'Bosbull', 'Bosbull,Bosbüll', 54.8166700, 8.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38914, 'Bosau', 'Bosau', 'Bosau,Bozau,bo shao,Бозау,Босау,博绍', 54.0978700, 10.4357000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38915, 'Borxleben', 'Borxleben', 'Borxleben', 51.4000000, 11.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38916, 'Börtlingen', 'Bortlingen', 'Boertlingen,Börtlingen', 48.7537600, 9.6318100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38917, 'Borstorf', 'Borstorf', 'Borstorf', 53.6166700, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38918, 'Borstendorf', 'Borstendorf', 'Borstendorf,bo er si teng duo fu,Борстендорф,博尔斯滕多夫', 50.7732300, 13.1791800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38919, 'Borstel-Hohenraden', 'Borstel-Hohenraden', 'Borstel,Borstel''-Khoehnraden,Borstel-Hohenraden,Borstel-Khoenraden,bo er si te er-huo heng la deng,Борстел-Хоенраден,Борстель-Хоэнраден,博尔斯特尔-霍亨拉登', 53.6833300, 9.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38920, 'Borstel', 'Borstel', '', 53.9675000, 9.7996300, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38921, 'Borstel', 'Borstel', '', 52.6703400, 8.9689600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38922, 'Börßum', 'Boerssum', 'Bersum,Bjorsum,Borssum,Börßum,bo er su mu,Берсум,Бёрсум,伯尔苏姆', 52.0692100, 10.5843100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38923, 'Börslingen', 'Borslingen', 'Berslingen,Bjorzlingen,Byorzlingen,berslingeni,bo er si lin gen,Берслинген,Берслінген,Бёрзлинген,Բյորզլինգեն,ბერსლინგენი,伯尔斯林根', 48.5389100, 10.0631300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38924, 'Borsfleth', 'Borsfleth', 'Borsfleth', 53.8333300, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38925, 'Borsdorf', 'Borsdorf', 'Borsdorf,Borsdorfi vald,bo er si duo fu,Борсдорф,博尔斯多夫', 51.3500000, 12.5333300, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38926, 'Börsborn', 'Borsborn', 'Bersborn,Berschborre,Bjorsborn,Boersborn,Börsborn,bo er si bo er en,Берсборн,Бёрсборн,伯尔斯博尔恩', 49.4333300, 7.4000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38927, 'Börrstadt', 'Boerrstadt', '', 49.5777200, 7.9424500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38928, 'Borrentin', 'Borrentin', 'Borrentin', 53.8096800, 12.9671800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38929, 'Borod', 'Borod', '', 50.6675000, 7.7097200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38930, 'Bornstedt', 'Bornstedt', '', 51.4833300, 11.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38931, 'Börnsen', 'Boernsen', '', 53.4762000, 10.2816000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38932, 'Börnichen', 'Boernichen', 'Boernichen,Boernichen/Erzgebirge,Bornichen,Börnichen,Börnichen/Erzgebirge', 50.7501000, 13.1407500, 'DE', '2017-07-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38933, 'Bornich', 'Bornich', 'Bornikh,bo er ni xi,Борних,博尔尼希', 50.1268700, 7.7658000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38934, 'Bornhöved', 'Bornhoved', 'Bornhoeved,Bornhoved,Bornhöved', 54.0666700, 10.2333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38935, 'Bornheim', 'Bornheim', 'Borngajm,Bornheim,Bornkhajm,brnhaym,bwrnhaym,Борнгайм,Борнхайм,Борнхајм,برنهایم,بورنهايم', 50.7631300, 6.9908900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38936, 'Bornheim', 'Bornheim', '', 49.7830600, 8.0602800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38937, 'Bornheim', 'Bornheim', '', 49.2225000, 8.1633300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38938, 'Bornhagen', 'Bornhagen', 'Bornhagen,Bornkhagen,bo er en ha gen,Борнхаген,博尔恩哈根', 51.3333300, 9.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38939, 'Borne', 'Borne', '', 51.9488100, 11.5586500, 'DE', '2011-04-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38940, 'Borna', 'Borna', 'Borna,Bornis,Borno,bo er na,brna,Борна,برنا,博尔纳', 51.1241600, 12.4963900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38941, 'Born', 'Born', 'Born am Darss,Born am Darß,Born uber Barth,Born über Barth', 54.3853600, 12.5305100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38942, 'Börm', 'Borm', 'Borm,Börm', 54.4000000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38943, 'Borler', 'Borler', '', 50.3166700, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38944, 'Borkwalde', 'Borkwalde', '', 52.2500000, 12.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38945, 'Borkum', 'Borkum', 'BMK,Boarkum,Borkum,bo er ku mu,brkwm,bwrkwm,bwrqwm,bxr khum,Боркум,בורקום,برکوم,بوركوم,บอร์คุม,ბორკუმი,博尔库姆', 53.5809400, 6.6915300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38946, 'Borkheide', 'Borkheide', 'Bork,Borkhayde,Borkheide,Borkkhajde,Kolonie Bork,bo er ke hai de,Боркхайде,Боркхајде,Բորկհայդե,博尔克海德', 52.2166700, 12.8500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38947, 'Borken', 'Borken', 'Borken,Buorken,Gorad Borken,bo er ken,brkn  nwrdrayn-wstfaln,bwrkn,Боркен,Горад Боркен,برکن، نوردراین-وستفالن,بوركن,博尔肯', 51.8438200, 6.8577400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38948, 'Borken', 'Borken', 'Borken,bo er ken,boruken,brkn,bwrkn,Боркен,برکن,بوركن,ボルケン,博爾肯', 51.0450100, 9.2844000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38949, 'Borgwedel', 'Borgwedel', 'Borgwedel', 54.5000000, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38950, 'Borgsum', 'Borgsum', '', 54.7006200, 8.4574100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38951, 'Borgstedt', 'Borgstedt', 'Borgshtedt,Borgshtet,bo er ge si te,Боргштедт,Боргштет,博尔格斯特', 54.3326800, 9.7095400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38952, 'Borgholzhausen', 'Borgholzhausen', 'Borggol''cgauzen,Borgholzhausen,Borgkhol''ckhauzen,Borgkholckhauzen,bo er ge huo er ci hao sen,brghwlzhawzn,bwrghhwltshawzn,Борггольцгаузен,Боргхолцхаузен,Боргхольцхаузен,برگهولزهاوزن,بورغهولتسهاوزن,博尔格霍尔茨豪森', 52.1034300, 8.3021100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38953, 'Borgfelde', 'Borgfelde', '', 53.5547500, 10.0344700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38954, 'Börger', 'Borger', 'Berger,Bjorger,Borger,bo er ge er,Бергер,Бёргер,伯尔格尔', 52.9121100, 7.5357600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38955, 'Borgentreich', 'Borgentreich', 'Bentreike,Borgentrajkh,Borgentreich,bo er gen te lai xi,borugentoraihi,bwrghntraysh,bwrgntraysh,Боргентрайх,Боргентрајх,بورغنترايش,بورگنترایش,ボルゲントライヒ,博尔根特赖希', 51.5691700, 9.2411300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38956, 'Borgdorf-Seedorf', 'Borgdorf-Seedorf', 'Borgdorf-Seedorf', 54.1666700, 9.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38957, 'Börfink', 'Borfink', 'Berfink,Bjorfink,bo er fen ke,Берфинк,Бёрфинк,伯尔芬克', 49.6833300, 7.0833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38958, 'Bordesholm', 'Bordesholm', 'Bordesholm,Bordeskhol''m,Bordeskholm,bo de si huo er mu,Бордесхолм,Бордесхольм,博德斯霍尔姆', 54.1761100, 10.0314600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38959, 'Boppard', 'Boppard', 'Bopard,Boppard,bo pa de,bopaleuteu,bopparuto,bwbard,bwpard,Бопард,Боппард,بوبارد,بوپارد,ボッパルト,博帕德,보파르트', 50.2308500, 7.5899200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38960, 'Bopfingen', 'Bopfingen', 'Bopfingen,bo pu fen gen,bwbfynghn,bwpfyngn,Бопфинген,Бопфінген,بوبفينغن,بوپفینگن,ბოპფინგენი,博普芬根', 48.8584700, 10.3541700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38961, 'Boostedt', 'Boostedt', 'Boostedt,Boshtedt,Boshtet,bo si te,Боштедт,Боштет,博斯特', 54.0166700, 10.0333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38962, 'Boos', 'Boos', '', 50.3166700, 7.0166700, 'DE', '2017-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38963, 'Boos', 'Boos', '', 49.8000000, 7.7166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38964, 'Boos', 'Boos', '', 48.0752100, 10.1952300, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38965, 'Bonstetten', 'Bonstetten', '', 48.4400200, 10.7053200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38966, 'Bönningstedt', 'Bonningstedt', 'Beningshtet,Bjonningshtedt,Boenningstedt,Bonningstedt,Bönningstedt,bo ning ge si te,Бенингштет,Бённингштедт,伯宁格斯特', 53.6666700, 9.9166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38967, 'Bönnigheim', 'Bonnigheim', 'Benigkhajm,Bennigajm,Bjonnigkhajm,Boennigheim,Bonnigheim,Bönnigheim,bo ni ge hai mu,bwnyghaym,bwnyghhaym,Бенигхајм,Беннігайм,Бённигхайм,بونيغهايم,بونیگهایم,伯尼格海姆', 49.0401800, 9.0938600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38968, 'Bonndorf im Schwarzwald', 'Bonndorf im Schwarzwald', 'Bondorf,Bondorf im Shvarcvald,Bonndorf,Bonndorf im Schwarzwald,bndwrf dr jngl syah,bwndwrf,hei lin shan qu bang duo fu,Бондорф,Бондорф им Шварцвалд,Бонндорф,بندورف در جنگل سیاه,بوندورف,黑林山区邦多夫', 47.8186300, 8.3413900, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38969, 'Bonn', 'Bonn', 'BNJ,Bon,Bona,Boni,Bonn,Bonna,Gorad Bon,Vonni,bn,bo en,bon,bona,boni,bwn,bxnn,Βόννη,Бон,Бонн,Горад Бон,באן,בון,بن,بون,बॉन,บอนน์,བྷོ་ཨིན།,ბონი,ボン,波恩,본', 50.7343800, 7.0954900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38970, 'Bongard', 'Bongard', '', 50.3000000, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38971, 'Bönen', 'Bonen', 'Benen,Bjonen,Boenen,Bonen,Bönen,bo nen,Бенен,Бёнен,伯嫩', 51.6000000, 7.7666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38972, 'Bonefeld', 'Bonefeld', '', 50.5238800, 7.4893200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38973, 'Bönebüttel', 'Bonebuttel', 'Bonebuttel,Bönebüttel', 54.0833300, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38974, 'Bondorf', 'Bondorf', 'Bondorf,bang duo fu,bondorpi,Бондорф,Բոնդորֆ,ბონდორფი,邦多夫', 48.5206400, 8.8370400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38975, 'Bondelum', 'Bondelum', 'Bondelum', 54.5666700, 9.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38976, 'Boms', 'Boms', '', 47.9763100, 9.5163900, 'DE', '2013-04-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38977, 'Bomlitz', 'Bomlitz', 'Bomlic,bo mu li ci,Бомлиц,博姆利茨', 52.9000000, 9.6500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38978, 'Bolsterlang', 'Bolsterlang', 'Bol''sterlang,Bolsterlang,bo er si te er lang,Болстерланг,Больстерланг,Բոլսթերլանգ,博尔斯特尔朗', 47.4666700, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38979, 'Bölsberg', 'Bolsberg', 'Boelsberg,Bölsberg', 50.6666700, 7.9166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38980, 'Bollschweil', 'Bollschweil', 'Bol''shvajl'',Bollschweil Priory,bo er shi wei er,Большвайль,博尔施魏尔', 47.9214300, 7.7898600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38981, 'Bollingstedt', 'Bollingstedt', 'Bolingsted,Bollingstedt', 54.5922900, 9.4173800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38982, 'Bollendorf', 'Bollendorf', 'Bolendorf,Bollendorf,Bollenduerf,Bottendorf,bo lun duo fu,Болендорф,Боллендорф,博伦多夫', 49.8526800, 6.3579500, 'DE', '2013-07-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38983, 'Böllenborn', 'Boellenborn', '', 49.1000000, 7.9333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38984, 'Bollenbach', 'Bollenbach', '', 49.8333300, 7.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38985, 'Böllen', 'Bollen', '', 47.8000000, 7.8413000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38986, 'Bollberg', 'Bollberg', 'Bollberg', 50.8833300, 11.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38987, 'Boll', 'Boll', '', 48.6435700, 9.6129500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38988, 'Bolheim', 'Bolheim', 'Bola', 48.6314100, 10.1499500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38989, 'Bolanden', 'Bolanden', 'Bolanden,Boulanden,bo lan deng,Боланден,Բոլանդեն,博兰登', 49.6391700, 8.0119400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38990, 'Boksee', 'Boksee', 'Boksee', 54.2333300, 10.1333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38991, 'Böklund', 'Boklund', 'Boeklund,Boklund,Böklund', 54.6000000, 9.5833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38992, 'Bokhorst', 'Bokhorst', '', 54.0666700, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38993, 'Bokholt-Hanredder', 'Bokholt-Hanredder', 'Bokholt-Hanredder', 53.7880800, 9.7358600, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38994, 'Bokensdorf', 'Bokensdorf', 'Bokensdorf,bo ken si duo fu,Бокенсдорф,博肯斯多夫', 52.5000000, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38995, 'Bokelrehm', 'Bokelrehm', 'Bokelrehm', 54.0381500, 9.3860600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38996, 'Bokel', 'Bokel', '', 54.2139900, 9.7953000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38997, 'Bokel', 'Bokel', '', 53.8666700, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38998, 'Bokel', 'Bokel', '', 53.3932600, 8.7680300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(38999, 'Boizenburg', 'Boizenburg', 'Boicenburga pie Elbas,Boizenberg,Boizenburg,Boizenburg dElba,Boizenburg/ Elbe,Boizenburg/Elbe,Bojcenburg,bo yi cen bao,bwytsnbwrgh,bwyznbwrg,Бойценбург,Бојценбург,بويتسنبورغ,بویزنبورگ,博伊岑堡', 53.3815300, 10.7237500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39000, 'Boitze', 'Boitze', 'Boice,Bojtce,bo yi ce,Боице,Бойтце,博伊策', 53.1500000, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39001, 'Bohnsdorf', 'Bohnsdorf', 'Berlin-Bohnsdorf', 52.3943400, 13.5733900, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39002, 'Böhnhusen', 'Bohnhusen', 'Bohnhusen,Böhnhusen', 54.2166700, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39003, 'Bohmte', 'Bohmte', 'Bohmte,Bomte,bo mu te,Бомте,博姆特', 52.3666700, 8.3166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39004, 'Bohmstedt', 'Bohmstedt', 'Baamst,Bohmstedt,Bomshtedt,Bomshtet,Bomsted,Bååmst,bo mu si te,Бомштедт,Бомштет,博姆斯特', 54.5833300, 9.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39005, 'Böhmfeld', 'Boehmfeld', 'Bemfel''d,Bemfeld,Bjomfel''d,Byomfeld,bo he mu fei er de,bwmfld,Бемфелд,Бемфельд,Бёмфельд,Բյոմֆելդ,بومفلد,伯赫姆费尔德', 48.8607900, 11.3679400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39006, 'Böhmenkirch', 'Bohmenkirch', 'Bemenkirkh,Bjomenkirkh,Boehmenkirch,Bohmenkirch,Böhmenkirch,bo he men ji er xi,Беменкирх,Беменкірх,Бёменкирх,伯赫门基尔希', 48.6833300, 9.9333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39007, 'Böhme', 'Bohme', 'Boehme,Böhme', 52.7833300, 9.4666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39008, 'Böhlen', 'Boehlen', 'Boehlen,Bohlen,Böhlen', 51.2006100, 12.3862200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39009, 'Böhlen', 'Boehlen', 'Bohlen,Böhlen', 50.5879800, 11.0434500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39010, 'Böhen', 'Bohen', 'Begen,Bekhen,Bjoehn,Boehen,Byohen,Böhen,bo heng,Беген,Бехен,Бёэн,Բյոհեն,伯亨', 47.8833300, 10.3000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39011, 'Bogenhausen', 'Bogenhausen', 'Bogenhausen', 48.1522100, 11.6158500, 'DE', '2016-08-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39012, 'Bogen', 'Bogen', '', 48.9112200, 12.6895500, 'DE', '2012-09-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39013, 'Bogel', 'Bogel', '', 50.1894300, 7.7997800, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39014, 'Boffzen', 'Boffzen', 'Bofcen,bo fu cen,bofutsu~en,Бофцен,ボフツェン,博夫岑', 51.7500000, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39015, 'Böel', 'Boel', 'Boeel,Boel,Böel', 54.6500000, 9.7166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39016, 'Bodolz', 'Bodolz', 'Bodol''c,Bodolc,bo duo er ci,Бодолц,Бодольц,Բոդոլց,博多尔茨', 47.5666700, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39017, 'Bodnegg', 'Bodnegg', 'Bodneg,Bodnegg,bo de nei ge,Боднег,Боднегг,博德内格', 47.7101400, 9.6884100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39018, 'Bodenwöhr', 'Bodenwoehr', 'Bodenver,Bodenvjor,Bodenwoehr,Bodenwöhr,bo deng wei he er,bwdnwwr,Боденвер,Боденвёр,بودنوور,博登韦赫尔', 49.2708200, 12.3014600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39019, 'Bodenwerder', 'Bodenwerder', 'Bodenverder,bo deng wei er de er,boden''vu~eruda,bwdnfyrdr,bwdnwrdr,Боденвердер,بودنفيردر,بودنوردر,ボーデンヴェルダー,博登韦尔德尔', 51.9715600, 9.5193100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39020, 'Bodenteich', 'Bodenteich', 'Bad Bodenteich,Bodendick,Bodendieck,Bodenteich [< a. 1998],Bonndiek', 52.8307700, 10.6818000, 'DE', '2016-10-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39021, 'Bodensee', 'Bodensee', '', 51.6061300, 10.1326300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39022, 'Bodenmais', 'Bodenmais', 'Bodenmais,Bodenmajs,Bodenmays,Bomoas,bo deng mai si,bwdnmays,Боденмайс,Боденмајс,Բոդենմայս,بودنمایس,博登迈斯', 49.0666700, 13.1000000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39023, 'Bodenkirchen', 'Bodenkirchen', 'Bodenkira,Bodenkirchen,Bodenkirkhen,Bodenkirxen,bo deng ji xing,bwdnkyrshn,Боденкирхен,Боденкірхен,Բոդենկիրխեն,بودنکیرشن,博登基兴', 48.3833300, 12.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39024, 'Bodenheim', 'Bodenheim', 'Bodenkhajm,bo deng hai mu,bodenhaimu,Боденхайм,Боденхајм,ボーデンハイム,博登海姆', 49.9352800, 8.3200000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39025, 'Bodenfelde', 'Bodenfelde', 'Bodenfel''de,Bodenfelde,bo deng fei er de,bodenferude,Боденфелде,Боденфельде,ボーデンフェルデ,博登费尔德', 51.6404400, 9.5556900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39026, 'Bodenbach', 'Bodenbach', '', 50.3166700, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39027, 'Boden', 'Boden', '', 50.4739200, 7.8569500, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39028, 'Bodelwitz', 'Bodelwitz', 'Bodelwitz', 50.6875000, 11.6222300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39029, 'Bodelshausen', 'Bodelshausen', 'Bodel''sgauzen,Bodel''skhauzen,Bodelskhauzen,bo de er si hao sen,Боделсхаузен,Бодельсгаузен,Бодельсхаузен,博德尔斯豪森', 48.3888600, 8.9770300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39030, 'Bockstadt', 'Bockstadt', 'Bockstadt', 50.4000000, 10.8833300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39031, 'Bockhorst', 'Bockhorst', '', 53.0329600, 7.5757600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39032, 'Bockhorn', 'Bockhorn', 'Bockhorn', 53.4000000, 8.0166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39033, 'Bockhorn', 'Bockhorn', '', 48.3147100, 11.9869400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39034, 'Bockenheim', 'Bockenheim', 'Bockenheim,Bockenheim an der Weinstrasse,Bockenheim an der Weinstraße', 49.6066900, 8.1848600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39035, 'Bockenem', 'Bockenem', 'Bokeln,Bokenem,Bokkenem,Bukeneim [a. 1132],bo ke nei mu,bwknm,bwkynm,Бокенем,Боккенем,بوكينم,بوکنم,博克内姆', 52.0099300, 10.1319700, 'DE', '2011-03-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39036, 'Bockenau', 'Bockenau', 'Bokenau,Bokkenau,bo ke nao,Бокенау,Боккенау,博克瑙', 49.8333300, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39037, 'Bockelwitz', 'Bockelwitz', 'Bockelwitz,Bockelwitzi vald,Bokel''vic,Bokelvic,Бокелвиц,Бокельвиц,Бокельвіц', 51.1994200, 12.9561800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39038, 'Bockau', 'Bockau', 'Bockau,Bokau,bo kao,Бокау,博考', 50.5420900, 12.6863900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39039, 'Bochum', 'Bochum', 'Baukem,Bochoum,Bochum,Bochumas,Bohuma,Bokhem,Bokhum,Bōkhêm,Gorad Bokhum,QBO,bo hong,bo khum,bofumu,bohum,bokhuma,bokhumi,bwkhm,bwkhwm,bwkwm,Μπόχουμ,Бохум,Горад Бохум,בוכום,بوخم,بوخوم,बोखुम,โบคุม,ბოხუმი,ボーフム,波鸿,보훔', 51.4816500, 7.2164800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39040, 'Bocholt', 'Bocholt', 'Bocholt,Bokelt,Bokhol''t,Bokholt,Bōkholt,ZCI,bo huo er te,bwshwlt  alman,Бохолт,Бохольт,بوشولت، آلمان,博霍爾特', 51.8387900, 6.6153100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39041, 'Böchingen', 'Bochingen', 'Bekhingen,Bjokhingen,bo xin gen,Бехинген,Бёхинген,伯欣根', 49.2369400, 8.0933300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39042, 'Böbrach', 'Boebrach', 'Bebra,Bebrakh,Bjobrakh,Boebrach,Byobrax,Böbrach,bo bu la,bwbrakh,Бебрах,Бёбрах,Բյոբրախ,بوبراخ,伯布拉', 49.0562100, 13.0346900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39043, 'Böbrach', 'Bobrach', '', 48.9332200, 12.8830400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39044, 'Böblingen', 'Boeblingen', 'B''oblingen,Beblingen,Bilbonium,Bjoblingen,Boblingen,Boeblingen,Byoblingen,Böblingen,beblingeni,beburingen,bo bu lin gen,bwblngn,bwblynghyn,bwblyngyn,Беблинген,Беблінген,Бьоблинген,Бёблинген,Բյոբլինգեն,بوبلنگن,بوبلينغين,بوبلینگین,ბებლინგენი,ベーブリンゲン,伯布林根', 48.6821200, 9.0117100, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39045, 'Bobitz', 'Bobitz', 'Bobic,Bobitz,bo bi ci,Бобиц,博比茨', 53.8045000, 11.3591400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39046, 'Böbingen', 'Bobingen', '', 49.2844400, 8.2366700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39047, 'Bobingen', 'Bobingen', 'Bobingen,bo bin gen,bwbynghn,bwbyngn,Бобинген,Бобінген,Բոբինգեն,بوبينغن,بوبینگن,博宾根', 48.2709100, 10.8339000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39048, 'Böbing', 'Boebing', 'Bebing,Bjobing,Byobing,bebingu,bo bin,bwbyng,Бебинг,Бебінг,Бёбинг,Բյոբինգ,بوبینگ,ベービング,伯宾', 47.7556200, 10.9887700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39049, 'Bobenthal', 'Bobenthal', 'Bobental,Bobental'',bo ben ta er,Бобентал,Бобенталь,博本塔尔', 49.0666700, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39050, 'Bobenheim-Roxheim', 'Bobenheim-Roxheim', 'Bobenheim,Bobenheim am Rhein,Bobenheim-Roxheim,Bobenkhajm-Rokskhajm,bo ben hai mu-luo ke si hai mu,Бобенхайм-Роксхайм,Бобенхајм-Роксхајм,博本海姆-罗克斯海姆', 49.5875000, 8.3577800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39051, 'Bobenheim am Berg', 'Bobenheim am Berg', 'Bobenheim,Bobenheim am Berg', 49.5241700, 8.1511100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39052, 'Bobeck', 'Bobeck', '', 50.9033600, 11.7929600, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39053, 'Bobbau', 'Bobbau', 'Bobbau', 51.6874700, 12.2725300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39054, 'Blunk', 'Blunk', 'Blunk', 54.0093600, 10.3138500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39055, 'Blumenthal', 'Blumenthal', '', 54.2333300, 10.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39056, 'Blumberg', 'Blumberg', 'Blumberg,blwmbrg,blwmbrgh,Блумберг,بلومبرغ,بلومبرگ', 47.8405800, 8.5332900, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39057, 'Blowatz', 'Blowatz', 'Blowatz', 53.9897200, 11.5336000, 'DE', '2016-03-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39058, 'Blomesche Wildnis', 'Blomesche Wildnis', 'Blomesche Wildnis', 53.8000000, 9.4166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39059, 'Blomberg', 'Blomberg', 'Blomberg,blmbrg,Бломберг,بلمبرگ', 51.9433100, 9.0906700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39060, 'Blomberg', 'Blomberg', '', 53.5767800, 7.5582400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39061, 'Blindheim', 'Blindheim', 'Blindgajm,Blindhaym,Blindkhajm,blyndhaym,bu lin de hai mu,Блиндхайм,Блиндхајм,Бліндгайм,Բլինդհայմ,بلیندهایم,布林德海姆', 48.6313800, 10.6199200, 'DE', '2012-11-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39062, 'Bliestorf', 'Bliestorf', 'Bliestorf', 53.7666700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39063, 'Blieskastel', 'Blieskastel', 'Bliskastel,Bliskastel'',blyzkastl,bu li si ka si te er,Блискастел,Блискастель,Бліскастель,بليزكاستل,بلیزکاستل,布利斯卡斯特尔', 49.2372400, 7.2561700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39064, 'Bliesdorf', 'Bliesdorf', 'Blisdorf,bu li si duo fu,Блисдорф,Բլիսդորֆ,布利斯多夫', 52.6929800, 14.1594900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39065, 'Bliedersdorf', 'Bliedersdorf', 'Blidersdorf,Bliersdoerp,Bliersdörp,bu li de er si duo fu,buridasudorufu,Блидерсдорф,ブリーダースドルフ,布利德尔斯多夫', 53.4833300, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39066, 'Blender', 'Blender', 'Blender,Blenner,burenda,Блендер,ブレンダー', 52.9166700, 9.1333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39067, 'Blekendorf', 'Blekendorf', '', 54.2821100, 10.6582000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39068, 'Bleicherode', 'Bleicherode', 'Blajkherode,blaysharwdh,bu lai xie luo de,Блайхероде,Блајхероде,بلايشاروده,بلایشاروده,布莱歇罗德', 51.4402600, 10.5720200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39069, 'Bleialf', 'Bleialf', 'Blajal''f,Blajalf,bu lai a er fu,Блайальф,Блајалф,布莱阿尔夫', 50.2333300, 6.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39070, 'Bleckhausen', 'Bleckhausen', '', 50.1333300, 6.7833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39071, 'Bleckede', 'Bleckede', 'Bleckede,Blekede,Blekkede,bu lai ke de,Блекеде,Блеккеде,布莱克德', 53.2897200, 10.7337200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39072, 'Blaufelden', 'Blaufelden', 'Blaufel''den,Blaufelden,bu lao fei er deng,burauferuden,Блауфелден,Блауфельден,ブラウフェルデン,布劳费尔登', 49.2977800, 9.9738900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39073, 'Blaubeuren', 'Blaubeuren', 'Blaubeuren Abbey,Blaubojren,Klasztor w Blaubeuren,bu lao bo yi lun,Блаубойрен,布劳博伊伦', 48.4121500, 9.7842700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39074, 'Blaubach', 'Blaubach', 'Blaubakh,Блаубах', 49.5666700, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39075, 'Blankenstein', 'Blankenstein', 'Blankenshtajn,bu lan ken si tai yin,Бланкенштайн,Бланкенштајн,布兰肯斯泰因', 50.4021300, 11.6989800, 'DE', '2012-04-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39076, 'Blankensee', 'Blankensee', '', 53.4039000, 13.2683600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39077, 'Blankenrath', 'Blankenrath', 'Blankenrath', 50.0389800, 7.3021400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39078, 'Blankenheim', 'Blankenheim', '', 51.5071700, 11.4287800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39079, 'Blankenheim', 'Blankenheim', 'Blankenheim', 50.4333300, 6.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39080, 'Blankenhain', 'Blankenhain', 'Blankenkhajn,blanknhayn,bu lan ken hai en,Бланкенхайн,Бланкенхајн,بلانكنهاين,بلنکن‌هاین,布兰肯海恩', 50.8599300, 11.3439000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39081, 'Blankenfelde', 'Blankenfelde', 'Berlin-Blankenfelde', 52.6186300, 13.3905700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39082, 'Blankenburg', 'Blankenburg', 'Berlin-Blankenburg,Blankenburg,Бланкенбург', 52.5929300, 13.4551600, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39083, 'Blankenburg', 'Blankenburg', 'Blankenburg,Blankenburg am Harz,blanknbwrgh,blnknbwrg,Бланкенбург,بلانكنبورغ,بلنکنبورگ', 51.7902500, 10.9550900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39084, 'Blankenburg', 'Blankenburg', '', 51.2000000, 10.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39085, 'Blankenberg', 'Blankenberg', 'Blankenberg', 50.4029900, 11.7162300, 'DE', '2012-04-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39086, 'Blaichach', 'Blaichach', 'Blajkhakh,Blayxax,bu lai xia,Блайхах,Блајхах,Բլայխախ,布莱夏', 47.5420800, 10.2584600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39087, 'Blaibach', 'Blaibach', 'Blajbakh,Blaybax,bu lai ba he,Блайбах,Блајбах,Բլայբախ,布莱巴赫', 49.1666700, 12.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39088, 'Bitzen', 'Bitzen', '', 50.8000000, 7.6833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39089, 'Bitz', 'Bitz', 'Bic,bi ci,Биц,Біц,比茨', 48.2440000, 9.0914400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39090, 'Bitterfeld-Wolfen', 'Bitterfeld-Wolfen', 'Biterfeld,Bitterfel''d,Bitterfeld,Bitterfeld-Wolfen,Bitterfelde,bi te fei er de,bitaferuto,Битерфелд,Биттерфельд,ビターフェルト,比特费尔德', 51.6235500, 12.3239500, 'DE', '2013-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39091, 'Bitburg', 'Bitburg', 'BBJ,Beibreg,Bitburg,Bitburgo,Béibreg,bi te bao,biteubuleukeu,bittoburuku,bytbwrg,bytbwrgh,Битбург,بيتبورغ,بیتبورگ,ბიტბურგი,ビットブルク,比特堡,비트부르크', 49.9679400, 6.5273400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39092, 'Bisterschied', 'Bisterschied', '', 49.6500000, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39093, 'Bisten', 'Bisten', '', 49.2543100, 6.7070200, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39094, 'Bissingen an der Teck', 'Bissingen an der Teck', 'Bisingen an der Tek,Bissingen,Bissingen-an-der-Tek,tai ke shan lu bi xin gen,Бисинген ан дер Тек,Биссинген-ан-дер-Тек,Біссінген-ан-дер-Тек,Բիսինգեն ան դեր Տեկ,泰克山麓比辛根', 48.5991500, 9.4914600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39095, 'Bissingen', 'Bissingen', 'Bisingen,Bissingen,bysyngn,Бисинген,Биссинген,Біссінген,Բիսինգեն,بیسینگن', 48.7169400, 10.6176600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39096, 'Bissersheim', 'Bissersheim', '', 49.5358300, 8.2041700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39097, 'Bissendorf', 'Bissendorf', 'Bisendorf,Bissendorf,bi sen duo fu,Бисендорф,Биссендорф,比森多夫', 52.2333300, 8.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39098, 'Bissee', 'Bissee', 'Bissee', 54.1833300, 10.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39099, 'Bispingen', 'Bispingen', 'Bispingen,Gemeen Bissen,bi si ping gen,Биспинген,比斯平根', 53.0831200, 9.9977200, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39100, 'Bismark', 'Bismark', 'Bismark', 52.6619500, 11.5563800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39101, 'Bisingen', 'Bisingen', 'Bizingen,bi sen gen shi,Бизинген,Бізінген,畢森根市', 48.3101200, 8.9173800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39102, 'Bischweier', 'Bischweier', '', 48.8376600, 8.2841200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39103, 'Bischofswiesen', 'Bischofswiesen', 'Bischofswiesen,Bischofswiesn,Bishofsvizen,Bisofsvizen,bi shao fu si wei sen,byshwfswyzn,Бишофсвизен,Бішофсвізен,Բիշոֆսվիզեն,بیشوفسویزن,比绍夫斯维森', 47.6311500, 12.9830500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39104, 'Bischofswerda', 'Bischofswerda', 'Bishofsverda,Biskopicy,Bisofsverda,Bišofsverda,bi shao fu si wei er da,byshwfsfyrda,byshwfzwrda,byswpswwrdh,Бишофсверда,Бішофсверда,בישופסוורדה,بيشوفسفيردا,بیشوفزوردا,比绍夫斯韦尔达', 51.1277100, 14.1797400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39105, 'Bischofsmais', 'Bischofsmais', 'Bishofsmajs,Bisofsmays,bi shao fu si mai si,byshwfsmays,Бишофсмайс,Бишофсмајс,Бішофсмайс,Բիշոֆսմայս,بیشوفسمایس,比绍夫斯迈斯', 48.9179600, 13.0818400, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39106, 'Bischofsheim an der Rhön', 'Bischofsheim an der Rhon', 'Bischofsheim,Bishofsgajm-an-der-Ren,Bishofskhajm an der Ren,Bishofskhajm-an-der-Rjon,Bishofskhajm-na-Rjone,Ryoni Bisofshaym,byshfzhaym an dr rwn,byshwfshaym an dr rwn,lun shan qian bi shao fu si hai mu,Бишофсхайм-ан-дер-Рён,Бишофсхайм-на-Рёне,Бишофсхајм ан дер Рен,Бішофсгайм-ан-дер-Рен,Ռյոնի Բիշոֆսհայմ,بيشوفسهايم آن در رون,بیشفزهایم آن در رون,伦山前比绍夫斯海姆', 50.4023900, 10.0075100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39107, 'Bischofsheim', 'Bischofsheim', 'Bischofsheim,Gau-Bischofsheim', 49.9938900, 8.3672200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39108, 'Bischofsgrün', 'Bischofsgruen', 'Bischofsgruen,Bischofsgrün,Bishofsgrin,Bishofsgrjun,Bisofsgryun,bi shao fu si ge lin,bishofusuguryun,Бишофсгрин,Бишофсгрюн,Бішофсгрюн,Բիշոֆսգրյուն,ビショフスグリュン,比绍夫斯格林', 50.0512200, 11.7999700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39109, 'Bischofroda', 'Bischofroda', 'Bishofroda,bi shao fu luo da,Бишофрода,比绍夫罗达', 51.0563800, 10.3639400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39110, 'Bischofrod', 'Bischofrod', 'Bischofrod', 50.5500000, 10.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39111, 'Bischofferode', 'Bischofferode', 'Bischofferode (Am Ohmberg)', 51.4965600, 10.4439600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39112, 'Bischoffen', 'Bischoffen', 'Bischoffen,Bishofen,Bishoffen,bi shao fen,Бишофен,Бишоффен,Бішоффен,比绍芬', 50.7000000, 8.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39113, 'Bischheim', 'Bischheim', '', 49.6700000, 8.0325000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39114, 'Bischbrunn', 'Bischbrunn', 'Bisbrun,Bishbrun,Bishbrunn,bi shi bu lun,Бишбрун,Бишбрунн,Бішбрунн,Բիշբրուն,比施布伦', 49.8702800, 9.4891700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39115, 'Bischberg', 'Bischberg', 'Bisberg,Bishberg,bi shi bei ge,bishuberuku,Бишберг,Бішберг,Բիշբերգ,ビシュベルク,比施贝格', 49.9108700, 10.8321200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39116, 'Birx', 'Birx', 'Birx', 50.5333300, 10.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39117, 'Birtlingen', 'Birtlingen', '', 49.9500000, 6.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39118, 'Birstein', 'Birstein', 'Birshhajn,Birshtajn,bi er si tai yin,birushutain,Бирштайн,Бирштајн,Бирщайн,Бірштайн,ビルシュタイン,比尔斯泰因', 50.3500000, 9.3000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39119, 'Birresborn', 'Birresborn', 'Biresborn,Birresborn,Birreses Born,bi lei si bo er en,Биресборн,Бирресборн,比雷斯博尔恩', 50.1833300, 6.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39120, 'Birnbach', 'Birnbach', 'Birnbakh,bi er en ba he,byrnbakh,Бирнбах,بیرنباخ,比尔恩巴赫', 50.7000000, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39121, 'Bad Birnbach', 'Bad Birnbach', 'Bad Birnbakh,Bad Birnbax,Bad-Birnbakh,ba te bi en ba he,bad byrnbakh,Бад Бирнбах,Бад-Бирнбах,Бад-Бірнбах,Բադ Բիրնբախ,باد بیرنباخ,巴特比恩巴赫', 48.4448900, 13.0910300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39122, 'Birlenbach', 'Birlenbach', '', 50.3581500, 8.0027300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39123, 'Birkweiler', 'Birkweiler', '', 49.2033300, 8.0383300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39124, 'Birkheim', 'Birkheim', '', 50.1166700, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39125, 'Birkenwerder', 'Birkenwerder', 'Birkenverder,bi er ken wei er de er,Биркенвердер,Բիրկենվերդեր,比尔肯韦尔德尔', 52.6833300, 13.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39126, 'Birkenhügel', 'Birkenhugel', 'Birkenhugel,Birkenhügel', 50.4333300, 11.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39127, 'Birkenhördt', 'Birkenhordt', '', 49.1166700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39128, 'Birkenheide', 'Birkenheide', 'Birkenkhajde,bi er ken hai de,Биркенхайде,Биркенхајде,比尔肯海德', 49.4813900, 8.2619400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39129, 'Birkenfelde', 'Birkenfelde', 'Birkenfelde', 51.3500000, 10.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39130, 'Birkenfeld', 'Birkenfeld', '', 49.8586100, 9.6955600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39131, 'Birkenfeld', 'Birkenfeld', 'Birkenfel''d,Birkenfeld,Birkenfell,bi er ken fei er de,birukenferuto,byrknfld,Биркенфелд,Биркенфельд,بيركنفلد,بیرکنفلد,ბირკენფელდი,ビルケンフェルト,比尔肯费尔德', 49.6524500, 7.1666800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39132, 'Birkenfeld', 'Birkenfeld', '', 48.8666700, 8.6333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39133, 'Birkenbeul', 'Birkenbeul', '', 50.7333300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39134, 'Birkenau', 'Birkenau', 'Birkenau,bi ke nao,birukenau,byrkynaw,Биркенау,Біркенау,بيركيناو,ビルケナウ,比克瑙', 49.5625000, 8.7069400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39135, 'Birgte', 'Birgte', 'Birgithi', 52.2479000, 7.6483300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39136, 'Birgel', 'Birgel', '', 50.3166700, 6.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39137, 'Birenbach', 'Birenbach', 'Birenbakh,bi lun ba he,Биренбах,Біренбах,比伦巴赫', 48.7473200, 9.6611500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39138, 'Bippen', 'Bippen', 'Bipen,Bippen,bi peng,Бипен,Биппен,比彭', 52.5833300, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39139, 'Binzen', 'Binzen', 'Bincen,bin cen,Бинцен,Бінцен,宾岑', 47.6333300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39140, 'Binswangen', 'Binswangen', 'Binsvangen,bin si wan gen,bynswangn,Бинсванген,Бінсванген,Բինսվանգեն,بینسوانگن,宾斯万根', 48.5579800, 10.6424900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39141, 'Binsfeld', 'Binsfeld', '', 49.9666700, 6.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39142, 'Binningen', 'Binningen', '', 50.2063900, 7.2461200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39143, 'Binnen', 'Binnen', '', 52.6166700, 9.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39144, 'Bingen am Rhein', 'Bingen am Rhein', 'Bingen,Bingen am Rejn,Bingen am Rhein,Bingen na Rajni,Bingen-Am-Rhein,Bingen-am-Rhein,Bingen-na-Rejne,Bingium,bynghn an dr rayn,byngn an dr rayn,lai yin he pan bin gen,Бинген ам Рейн,Бинген на Рајни,Бинген-на-Рейне,بينغن آن در راين,بینگن آن در راین,ビンゲン・アム・ライン,莱茵河畔宾根', 49.9667500, 7.8992000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39145, 'Bingen', 'Bingen', '', 48.1112700, 9.2723800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39146, 'Bindlach', 'Bindlach', 'Bindlach,Bindlakh,Bindlax,bin de la,bintoraha,Биндлах,Біндлах,Բինդլախ,ビントラハ,宾德拉', 49.9816700, 11.6138900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39147, 'Binau', 'Binau', 'Binau,bi nao,binau,Бинау,Бінау,ビーナウ,比瑙', 49.3683300, 9.0580600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39148, 'Bimöhlen', 'Bimohlen', 'Bimoehlen,Bimohlen,Bimöhlen', 53.9333300, 9.9500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39149, 'Bilzingsleben', 'Bilzingsleben', '', 51.2833300, 11.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39150, 'Bilshausen', 'Bilshausen', 'Bil''skhauzen,Bilskhauzen,bi er si hao sen,birusuhauzen,Билсхаузен,Бильсхаузен,ビルスハウゼン,比尔斯豪森', 51.6297400, 10.1585900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39151, 'Bilsen', 'Bilsen', 'Bilsen', 53.7666700, 9.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39152, 'Billigheim', 'Billigheim', 'Biligkhajm,Billigajm,Billigheim,Billigkhajm,bi li ge hai mu,birihihaimu,Билигхајм,Биллигхайм,Біллігайм,ビリヒハイム,比利格海姆', 49.3486100, 9.2538900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39153, 'Billerbeck', 'Billerbeck', 'Bilerbek,Billerbeck,Billerbek,Billerbiek,Billerbiëk,Billurbeki,Billurbėki,bi lai er bei ke,bylrbk,Билербек,Биллербек,Біллербек,بيلربك,بیلربک,比莱尔贝克', 51.9782900, 7.2926100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39154, 'Bilkheim', 'Bilkheim', '', 50.4980600, 7.9483300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39155, 'Bietigheim-Bissingen', 'Bietigheim-Bissingen', 'Bietigheim-Bissingen,Bitigajm-Bissingen,Bitigkhajm-Bisingen,Bitigkhajm-Bissingen,bi di ge hai mu-bi xin gen,bitihhihaimu=bisshingen,bytyghaym-bysyngn,bytyghhaym-bysynghn,Битигхайм-Биссинген,Битигхајм-Бисинген,Бітігайм-Біссінген,بيتيغهايم-بيسينغن,بیتیگهایم-بیسینگن,ビーティッヒハイム＝ビッシンゲン,比蒂格海姆-比辛根', 48.9440700, 9.1175500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39156, 'Bietigheim', 'Bietigheim', '', 48.9091900, 8.2520200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39157, 'Biessenhofen', 'Biessenhofen', 'Bisenhofen,Bisenkhofen,Bissengofen,Bissenkhofen,bi sen huo fen,bisenhofen,Бисенхофен,Биссенхофен,Біссенгофен,Բիսենհոֆեն,ビーセンホーフェン,比森霍芬', 47.8305700, 10.6402200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39158, 'Biesenthal', 'Biesenthal', 'Bisental,Bizental,Bizental'',Bizentale,Bīzentāle,bi sen ta er,byzntal,Бизентал,Бизенталь,Бисентал,Բիզենտալ,بيزنتال,بیزنتال,比森塔尔', 52.7661600, 13.6441600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39159, 'Biesdorf', 'Biesdorf', 'Berlin-Biesdorf', 52.5090600, 13.5534000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39160, 'Biesdorf', 'Biesdorf', '', 49.8833300, 6.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39161, 'Biere', 'Biere', 'Biere', 51.9743100, 11.6544300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39162, 'Bienstädt', 'Bienstadt', 'Bienstadt,Bienstaedt,Bienstädt,Binshtedt,Binshtet,bin si te,Бинштедт,Бинштет,宾斯特', 51.0166700, 10.8500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39163, 'Bienenbüttel', 'Bienenbuttel', 'Bienenbuettel,Bienenbüttel,Binenbitel,Binenbjuttel'',Gemeen Bienbueddel,Gemeen Bienbüddel,bi nen bi te er,Биненбител,Биненбюттель,比嫩比特尔', 53.1415700, 10.4867900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39164, 'Biendorf', 'Biendorf', '', 54.0752000, 11.7012700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39165, 'Bielefeld', 'Bielefeld', 'BFE,Bielefeld,Bilefel''d,Bilefeld,Bilefelde,Bilifeld,Bilivelda,Builefeld,Bylefeldas,Bīlefelde,Bīlifeld,Gorad Bilefel''d,Mpilephelnt,bi lei fei er de,bilephelda,bilepildi,billepelteu,bireferuto,bylyfyld,Μπίλεφελντ,Билефелд,Билефельд,Білефельд,Горад Білефельд,بيليفيلد,بیلفیلڈ,بیله‌فلد,बीलेफेल्ड,ბილეფილდი,ビーレフェルト,比勒费尔德,빌레펠트', 52.0333300, 8.5333300, 'DE', '2012-11-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39166, 'Biedesheim', 'Biedesheim', '', 49.6050000, 8.1072200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39167, 'Biedershausen', 'Biedershausen', '', 49.3166700, 7.4833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39168, 'Biederitz', 'Biederitz', 'Bideric,Biederitz,bi de li ci,Бидериц,比德里茨', 52.1500000, 11.7166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39169, 'Biedenkopf', 'Biedenkopf', 'Bidenkopf,Biedenkopf,bi deng ke pu fu,bidenkopufu,bydnkpf,bydnkwbf,Биденкопф,Біденкопф,بيدنكوبف,بیدنکپف,ビーデンコプフ,比登科普夫', 50.9112500, 8.5301600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39170, 'Biebrich', 'Biebrich', '', 50.3039000, 7.9500000, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39171, 'Biebesheim', 'Biebesheim', '', 49.7808800, 8.4669600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39172, 'Biebern', 'Biebern', '', 49.9833300, 7.4500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39173, 'Bieberehren', 'Bieberehren', 'Bibereren,bi bei lei lun,bibereren,Биберерен,Біберерен,Բիբերերեն,ビーベレーレン,比贝雷伦', 49.5173300, 10.0090800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39174, 'Biebelsheim', 'Biebelsheim', '', 49.8666700, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39175, 'Biebelried', 'Biebelried', 'Bibel''rid,Bibelrid,bi bei er li de,Бибелрид,Бибельрид,Бібельрід,Բիբելրիդ,比贝尔里德', 49.7666700, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39176, 'Biebelnheim', 'Biebelnheim', 'Bibel''nkhajm,Bibelnkhajm,bi bei er en hai mu,Бибелнхајм,Бибельнхайм,比贝尔恩海姆', 49.7966700, 8.1705600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39177, 'Bidingen', 'Bidingen', 'Bidingen,bidingen,Бидинген,Бідінген,Բիդինգեն,ビディンゲン', 47.8297400, 10.7262300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39178, 'Bickendorf', 'Bickendorf', '', 50.0333300, 6.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39179, 'Bickenbach', 'Bickenbach', 'Bicherbach,Bickenbach', 50.1255900, 7.5279500, 'DE', '2014-06-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39180, 'Bickenbach', 'Bickenbach', '', 49.7591700, 8.6175000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39181, 'Bichl', 'Bichl', 'Bikhl,Bikhl'',Bixl,bi xi er,byshl,Бихл,Бихль,Біхль,Բիխլ,بیشل,比希尔', 47.7201000, 11.4123100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39182, 'Biburg', 'Biburg', '', 48.7906600, 11.8572600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39183, 'Bibra', 'Bibra', '', 50.8038700, 11.5470600, 'DE', '2017-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39184, 'Biblis', 'Biblis', 'Biblis,Biwwelse,bi bu li si,biburisu,byblys,Библис,Бібліс,بيبليس,ビブリス,比布利斯', 49.6916700, 8.4586100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39185, 'Biberbach', 'Biberbach', 'Biberbach,Biberbakh,Biberbax,bi bei er ba he,bybrbakh,Бибербах,Бібербах,Բիբերբախ,بیبرباخ,比贝尔巴赫', 48.5177800, 10.8113900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39186, 'Biberach an der Riß', 'Biberach an der Riss', 'Biberach,Biberach an der Riss,Biberach an der Riß,Biberakh an der Risu,Biberakh-na-Rise,Biberakh-na-Risi,bybrakh an dr rys,li si he pan bi bo la he,Биберах ан дер Рису,Биберах-на-Рисе,Біберах-на-Рісі,بیبراخ آن در ریس,里斯河畔比伯拉赫', 48.0934500, 9.7905300, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39187, 'Biberach', 'Biberach', '', 48.6100800, 8.2770400, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39188, 'Biberach', 'Biberach', 'Biberach', 48.3333300, 8.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39189, 'Bexbach', 'Bexbach', 'Beksbakh,bei ke si ba he,bksbakh,Бексбах,بكسباخ,بکسباخ,贝克斯巴赫', 49.3461500, 7.2552700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39190, 'Beverungen', 'Beverungen', 'Beferungen,Beverungen,bei fei lun gen,bevu~erungen,bwrwngn,byfrwnghn,Беверунген,Беферунген,بورونگن,بيفرونغن,ベーヴェルンゲン,贝费伦根', 51.6680100, 9.3741700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39191, 'Beverstedt', 'Beverstedt', 'Befershtedt,Bevershtedt,Bevershtet,Gemeen Beverst,bei fei er si te,Беверштедт,Беверштет,Беферштедт,贝费尔斯特', 53.4341300, 8.8191500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39192, 'Bevern', 'Bevern', '', 53.7559200, 9.7708800, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39193, 'Bevern', 'Bevern', 'Befern,Bevarnon,Bevern,bei fei er en,bevu~erun,Беверн,Беферн,ベーヴェルン,贝费尔恩', 51.8582600, 9.4940800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39194, 'Bad Bevensen', 'Bad Bevensen', 'Bad Bevensen,Bad-Bevenzen,Bevensen,ba te bei wen sen,bad bwnsn,bad byfynsn,Бад Бевенсен,Бад-Бевензен,باد بونسن,باد بيفينسن,巴特贝文森', 53.0792300, 10.5812900, 'DE', '2015-03-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39195, 'Bevenrode', 'Bevenrode', 'Bemro''e,Bevenrode,Bevenrodhe [a. 1231],Grotin Bevenrodhe [a. 1479]', 52.3402600, 10.5774300, 'DE', '2015-10-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39196, 'Beutelsbach', 'Beutelsbach', '', 48.5500000, 13.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39197, 'Beuron', 'Beuron', 'Bojron,bo yi long,Бойрон,Бојрон,博伊龙', 48.0500000, 8.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39198, 'Beuren', 'Beuren', '', 50.1000000, 7.0833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39199, 'Beuren', 'Beuren', '', 48.5692700, 9.4040600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39200, 'Beuna', 'Beuna', 'Beuna', 51.3166700, 11.9500000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39201, 'Beulich', 'Beulich', '', 50.1833300, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39202, 'Beuern', 'Beuern', '', 50.6274500, 8.8210800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39203, 'Betzigau', 'Betzigau', 'Becigau,Betcigau,bei qi gao,Бетцигау,Бецигау,Բետցիգաու,贝齐高', 47.7333300, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39204, 'Betzenweiler', 'Betzenweiler', '', 48.1166700, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39205, 'Betzendorf', 'Betzendorf', 'Becendorf,Betcendorf,bei cen duo fu,Бетцендорф,Бецендорф,贝岑多夫', 53.1375000, 10.3127300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39206, 'Betzdorf', 'Betzdorf', 'Becdorf,Betzdorf,btzdwrf,Бецдорф,بتزدورف', 50.7909400, 7.8718900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39207, 'Bettingen', 'Bettingen', 'Nieder Bettingen', 49.9421100, 6.4016000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39208, 'Bettenfeld', 'Bettenfeld', 'Beppenfield,Bettenfeld', 50.0850300, 6.7601000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39209, 'Bettendorf', 'Bettendorf', '', 50.2330700, 7.8687900, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39210, 'Betteldorf', 'Betteldorf', '', 50.2500000, 6.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39211, 'Bethenhausen', 'Bethenhausen', 'Bethenhausen', 50.9333300, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39212, 'Betheln', 'Betheln', 'Betel''n,Beteln,bei te er en,Бетелн,Бетельн,贝特尔恩', 52.1143100, 9.7939700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39213, 'Bestwig', 'Bestwig', 'Bestvig,bei si te wei xi,Бествиг,Бествіг,贝斯特维希', 51.3608100, 8.4008200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39214, 'Bestensee', 'Bestensee', 'Bestensee,Bestenze,bei si teng sai,Бестензе,Բեստենզե,贝斯滕塞', 52.2397800, 13.6373200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39215, 'Besigheim', 'Besigheim', 'Besigheim,Bezigajm,Bezigkhajm,bei xi ge hai mu,bsyghaym,byzyghhaym,Безигхайм,Безигхајм,Безігайм,بسیگهایم,بيزيغهايم,贝西格海姆', 48.9979700, 9.1426800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39216, 'Besenthal', 'Besenthal', 'Besenthal', 53.5333300, 10.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39217, 'Besdorf', 'Besdorf', 'Besdorf', 54.0500700, 9.3600300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39218, 'Beschendorf', 'Beschendorf', 'Beschendorf', 54.1833300, 10.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39219, 'Bescheid', 'Bescheid', '', 49.7500000, 6.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39220, 'Berzhausen', 'Berzhausen', '', 50.6666700, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39221, 'Berzhahn', 'Berzhahn', '', 50.5400000, 8.0066700, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39222, 'Berus', 'Berus', 'Berus', 49.2642000, 6.6958700, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39223, 'Berumbur', 'Berumbur', 'Berumbur,bei lun bu er,Берумбур,贝伦布尔', 53.6000000, 7.3166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39224, 'Berthelsdorf', 'Berthelsdorf', '', 51.0467900, 14.2219700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39225, 'Berstadt', 'Berstadt', '', 50.4260600, 8.8662100, 'DE', '2017-03-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39226, 'Bersenbrück', 'Bersenbrueck', 'Bersenbruck,Bersenbrueck,Bersenbrück,Berzenbrik,Berzenbrjuk,bei er sen bu lu ke,brsnbrwk,brznbrwk,Берзенбрик,Берзенбрюк,برزنبروك,برسنبروک,贝尔森布吕克', 52.5516000, 7.9483600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39227, 'Berscheid', 'Berscheid', '', 49.9833300, 6.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39228, 'Berod bei Wallmerod', 'Berod bei Wallmerod', 'Berod,Berod bei Wallmerod', 50.4833300, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39229, 'Bernstadt', 'Bernstadt', '', 51.0473600, 14.8278400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39230, 'Bernstadt', 'Bernstadt', 'Bernshtadt,Bernshtat,Bernstadt,Бернштадт,Бернштат,Բերնշտադտ,ბერნშტადტი', 48.4995700, 10.0257500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39231, 'Bernsdorf', 'Bernsdorf', 'Bernsdorf,Njedzichow,Njedźichow', 51.3735000, 14.0688600, 'DE', '2017-04-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39232, 'Bernsdorf', 'Bernsdorf', '', 50.7666700, 12.6666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39233, 'Bernsbach', 'Bernsbach', 'Bernsbach', 50.5762400, 12.7675100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39234, 'Bernried', 'Bernried', '', 48.9166700, 12.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39235, 'Bernried', 'Bernried', 'Bernried am Starnberger See', 47.8660400, 11.2938600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39236, 'Bernkastel-Kues', 'Bernkastel-Kues', 'Bern Kastel,Bernkastel''-Kus,Bernkastel-Cues,Bernkastel-Kues,Tabernae Mosellanicae-Cusa,bei er en ka si te er-ku ai si,berunkasuteru=kusu,brnksl-kwyz,brnqstl-qwyz,byrnkastl-kwyz,Бернкастел-Куес,Бернкастель-Кус,ברנקסטל-קויז,برنکسل-کوئز,بيرنكاستل-كويز,ბერნკასტელ-კუუსი,ベルンカステル＝クース,贝尔恩卡斯特尔-库埃斯', 49.9160200, 7.0766400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39237, 'Bernitt', 'Bernitt', 'Bernit,Bernitt,bei er ni te,Бернит,Бернитт,贝尔尼特', 53.9040300, 11.8866900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39238, 'Bernhardswald', 'Bernhardswald', 'Berngardsval''d,Bernhardsvald,Bernkhardsval''d,Bernkhardsvald,bei er en ha er ci wa er de,brnhardswald,Бернгардсвальд,Бернхардсвалд,Бернхардсвальд,Բերնհարդսվալդ,برنهاردسوالد,贝尔恩哈尔茨瓦尔德', 49.0912300, 12.2474400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39239, 'Berngau', 'Berngau', 'Berngau,bei er en gao,Бернгау,Բերնգաու,贝尔恩高', 49.2500000, 11.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39240, 'Berndroth', 'Berndroth', '', 50.2371600, 7.9692100, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39241, 'Berndorf', 'Berndorf', '', 50.3050600, 6.6966300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39242, 'Bernburg', 'Bernburg', 'Bernbourg,Bernburg,Bernburg (Saale),bei er en bu er ge,beleunbuleukeu,brnbwrg,brnbwrgh,Бернбург,ברנבורג,برنبورغ,برنبورگ,贝尔恩布尔格,베른부르크', 51.7946400, 11.7401000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39243, 'Bernbeuren', 'Bernbeuren', 'Bernbojren,Bernboyren,bei er en bo yi lun,berunboiren,brn bwyrn,Бернбойрен,Бернбојрен,Բերնբոյրեն,برن بویرن,ベルンボイレン,贝尔恩博伊伦', 47.7369600, 10.7770700, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39244, 'Bernau am Chiemsee', 'Bernau am Chiemsee', 'Bernau,Bernau am Cheamsee,Bernau am Chiemsee,Bernau am Kimze,Bernau-am-Kimze,Bernau-am-Kimzee,Kimzeei Bernau,brnaw am shymzy,ji mu hu pan bei er nao,Бернау ам Кимзе,Бернау-ам-Кимзее,Бернау-ам-Кімзе,Կիմզեեի Բերնաու,برناو ام شیمزی,基姆湖畔贝尔瑙', 47.8116700, 12.3756600, 'DE', '2013-11-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39245, 'Bernau bei Berlin', 'Bernau bei Berlin', 'Bernau,Bernau baj Berlin,Bernau kaj Berlin,Bernava pie Berlines,Bernava pie Berlīnes,Bernoa,bai lin fu jin bei er nao,brna bay brlyn,Бернау,Бернау бај Берлин,Бернау кај Берлин,Բերնաու,ברנאו שליד ברלין,برنا بای برلین,柏林附近贝尔瑙', 52.6798200, 13.5870800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39246, 'Bernau', 'Bernau', '', 47.8001800, 8.0383000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39247, 'Bermersheim', 'Bermersheim', '', 49.6819400, 8.2236100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39248, 'Bermel', 'Bermel', '', 50.2833300, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39249, 'Bermbach', 'Bermbach', '', 50.6777500, 10.5963100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39250, 'Bermatingen', 'Bermatingen', 'Bermatingen,bei er ma ting gen,Берматинген,Берматінген,Բերմատինգեն,ბერმატინგენი,贝尔马廷根', 47.7333300, 9.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39251, 'Berlstedt', 'Berlstedt', 'Berl''shtedt,Berlshtet,Берлштет,Берльштедт', 51.0614200, 11.2428800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39252, 'Berlingerode', 'Berlingerode', 'Berlingerode', 51.4577500, 10.2384000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39253, 'Berlingen', 'Berlingen', '', 50.2389400, 6.7193400, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39254, 'Berlin', 'Berlin', 'BER,Beirlin,Beirlín,Berleno,Berlien,Berliin,Berliini,Berlijn,Berlim,Berlin,Berline,Berlini,Berlino,Berlyn,Berlynas,Berlëno,Berlín,Berlîn,Berlīne,Berolino,Berolinum,Birlinu,Bèrlîn,Estat de Berlin,Estat de Berlín,bai lin,barlina,beleullin,berlini,berurin,bexrlin,brlyn,perlin,Βερολίνο,Берлин,Берлін,Бэрлін,Բերլին,בערלין,ברלין,برلين,برلین,بېرلىن,ܒܪܠܝܢ,बर्लिन,বার্লিন,பெர்லின்,เบอร์ลิน,ბერლინი,ベルリン,柏林,베를린', 52.5243700, 13.4105300, 'DE', '2016-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39255, 'Berkoth', 'Berkoth', '', 50.0441600, 6.3399100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39256, 'Berkheim', 'Berkheim', 'Berkgajm,Berkhaym,Berkkhajm,bei er ke hai mu,Беркгайм,Беркхайм,Беркхајм,Բերկհայմ,ბერკჰაიმი,贝尔克海姆', 48.0426300, 10.0822700, 'DE', '2011-05-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39257, 'Berkenthin', 'Berkenthin', 'Berkenthin,Berkinthin', 53.7333300, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39258, 'Berkenbrück', 'Berkenbruck', '', 52.3500000, 14.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39259, 'Beringstedt', 'Beringstedt', 'Beringstedt', 54.1166700, 9.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39260, 'Bergwitz', 'Bergwitz', '', 51.7947900, 12.5895400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39261, 'Bergweiler', 'Bergweiler', '', 49.9666700, 6.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39262, 'Bergtheim', 'Bergtheim', 'Bergtajm,Bergtgajm,Bergthaym,Bergtkhajm,bei ge te hai mu,berukutohaimu,Бергтайм,Бергтгайм,Бергтхайм,Бергтхајм,Բերգտհայմ,ベルクトハイム,贝格特海姆', 49.9000000, 10.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39263, 'Bergstedt', 'Bergstedt', '', 53.6711100, 10.1269400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39264, 'Bergrheinfeld', 'Bergrheinfeld', 'Bergrajnfel''d,Bergrajnfeld,Bergrhemfeld,Bergrkhajnfel''d,bei ge lai yin fei er de,brg raynfld,Берграйнфельд,Берграјнфелд,Бергрхайнфельд,برگ راینفلد,贝格莱茵费尔德', 50.0102800, 10.1808900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39265, 'Bergneustadt', 'Bergneustadt', 'Bergneustadt,Bergnojshhat,Bergnojshtadt,Bergnojshtat,bei er ge nuo yi si ta te,brghnwyshtat,Бергнойштадт,Бергнойщат,Бергнојштат,برغنويشتات,بگنوی‌اشتات,贝尔格诺伊斯塔特', 51.0249600, 7.6559900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39266, 'Berglicht', 'Berglicht', '', 49.7873600, 6.9658500, 'DE', '2012-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39267, 'Berglern', 'Berglern', 'Berglern,bei ge lun,brglrn,Берглерн,برگلرن,贝格伦', 48.3840700, 11.9301200, 'DE', '2012-11-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39268, 'Berglangenbach', 'Berglangenbach', '', 49.6000000, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39269, 'Bergkirchen', 'Bergkirchen', '', 48.2567100, 11.3648800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39270, 'Bergkamen', 'Bergkamen', 'Bergkamen,Berkamen,Biaergkoamen,Biärgkoamen,ZCH,bei ge ka men,brghkamn,brgkamn,Бергкамен,Беркамен,برغكامن,برگکامن,贝格卡门', 51.6163300, 7.6445100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39271, 'Bergisch Gladbach', 'Bergisch Gladbach', 'Bergisch Gladbach,Bergish Gladbakh,Jlaebbisch,Jläbbisch,ZCG,Бергиш Гладбах', 50.9856000, 7.1329800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39272, 'Berg im Gau', 'Berg im Gau', 'Berg,Berg im Gau,Berg-im-Gau,Gaui Berg,bei ge yi mu gao,brg aym gaw,Берг им Гау,Берг-им-Гау,Берг-ім-Гау,Գաուի Բերգ,برگ ایم گاو,贝格伊姆高', 48.6333300, 11.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39273, 'Berghülen', 'Berghulen', 'Berggjulen,Berghuelen,Berghyulen,Berghülen,Bergkhilen,Bergkhjulen,bei ge xu lun,berghiuleni,Берггюлен,Бергхилен,Бергхюлен,Բերգհյուլեն,ბერგჰიულენი,贝格许伦', 48.4639900, 9.7611000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39274, 'Bergheim', 'Bergheim', 'Bergem,Bergheim an der Erft,Бергем', 50.9557200, 6.6398600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39275, 'Bergheim', 'Bergheim', 'Bergheim', 48.7606000, 11.2573800, 'DE', '2012-03-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39276, 'Berghausen', 'Berghausen', '', 50.2589500, 8.0071400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39277, 'Berghaupten', 'Berghaupten', 'Berggaupten,Bergkhaupten,bei ge hao pu teng,Берггауптен,Бергхауптен,贝格豪普滕', 48.4060200, 7.9867200, 'DE', '2013-04-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39278, 'Bergfeld', 'Bergfeld', 'Bergfel''d,Bergfeld,bei ge fei er de,Бергфелд,Бергфельд,贝格费尔德', 52.5440000, 10.8450500, 'DE', '2011-11-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39279, 'Bergewöhrden', 'Bergewohrden', 'Bergewohrden,Bergewöhrden', 54.3166700, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39280, 'Bergenhusen', 'Bergenhusen', 'Bergenhusen', 54.3833300, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39281, 'Bergenhausen', 'Bergenhausen', '', 50.0166700, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39282, 'Bergen auf Rügen', 'Bergen auf Ruegen', 'Bergen,Bergen Rugen,Bergen Rügen,Bergen auf Rigen,Bergen auf Ruegen,Bergen auf Rugen,Bergen auf Rügen,Bergen bei Ruegen,Bergen bei Rügen,Bergen en Ruegen,Bergen en Rügen,Bergen na Rigen,Bergen na Rjugen,Bergen-auf-Rjugen,Bergene Rigene,Bergene Rīgenē,Gora,Gorad Bergen-na-Rugene,Góra,beleugen-aupeulwigen,brghn awf rwghn,brgn an dr rwgn,lu gen dao bei er gen,Берген ауф Риген,Берген на Риген,Берген на Рюген,Берген-ауф-Рюген,Горад Берген-на-Ругене,برغن آوف روغن,برگن آن در روگن,吕根岛贝尔根,베르겐아우프뤼겐', 54.4182300, 13.4334900, 'DE', '2016-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39283, 'Bergen an der Dumme', 'Bergen an der Dumme', 'Bergen,Bergen Dumme,Bergen ad Dumme flumen,Bergen an der Dume,Bergen-an-der-Dumme,Bergen-na-Dumme,brgn an dr dwmh,du mei he pan bei er gen,Берген ан дер Думе,Берген-ан-дер-Думме,Берген-на-Думме,برگن ان در دومه,杜梅河畔贝尔根', 52.8910900, 10.9562900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39284, 'Bergen', 'Bergen', 'Berga,Bergen,bo gen,brgn,Берген,برگن,伯根', 52.8083700, 9.9637400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39285, 'Bergen', 'Bergen', '', 50.4710000, 12.2744800, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39286, 'Bergen', 'Bergen', '', 49.7833300, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39287, 'Bergen', 'Bergen', '', 49.0734700, 11.1140000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39288, 'Bergen', 'Bergen', '', 47.8083700, 12.5898200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39289, 'Berge', 'Berge', '', 53.2333300, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39290, 'Berge', 'Berge', '', 52.6232600, 7.7455000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39291, 'Bergatreute', 'Bergatreute', 'Bergatrojte,bei er jia te luo yi te,Бергатройте,Бергатројте,贝尔加特罗伊特', 47.8500000, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39292, 'Berga', 'Berga', '', 51.4556100, 11.0071000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39293, 'Berga', 'Berga', 'Berga,Berga an der Elster,Berga/Elster', 50.7518400, 12.1644500, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39294, 'Berg', 'Berg', '', 50.5552300, 6.9488600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39295, 'Berg', 'Berg', '', 50.3747300, 11.7785000, 'DE', '2012-04-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39296, 'Berg', 'Berg', '', 50.2542800, 7.8113700, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39297, 'Berg', 'Berg', '', 49.8141700, 12.1416100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39298, 'Berg', 'Berg', '', 48.9840300, 8.2023200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39299, 'Berg', 'Berg', 'Berg am See,Berg am Starnberger See', 47.9673700, 11.3544600, 'DE', '2016-01-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39300, 'Berg', 'Berg', '', 47.8666700, 11.3833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39301, 'Berg', 'Berg', 'Berg', 47.8166700, 9.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39302, 'Berenbach', 'Berenbach', '', 50.2333300, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39303, 'Bereborn', 'Bereborn', '', 50.2833300, 6.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39304, 'Berchtesgaden', 'Berchtesgaden', 'Berchtesgaden,Berchtesnkanten,Berchtolsgaden,Berchtsgoan,Berkhtesgaden,Berxtesgaden,ZCE,bei xi te si jia deng,beleuhiteseugaden,beruhitesugaden,brshts gadn,Μπέρχτεσγκαντεν,Берхтесгаден,Բերխտեսգադեն,برشتس گادن,ベルヒテスガーデン,贝希特斯加登,베르히테스가덴', 47.6323600, 13.0018700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39305, 'Berching', 'Berching', 'Berching,Berkhing,bei er xin ge,brshyng,Берхинг,برشینگ,贝尔欣格', 49.1069500, 11.4413800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39306, 'Beratzhausen', 'Beratzhausen', 'Beracgauzen,Berackhauzen,Beratzhausen,bei la ci hao sen,bratshawzn,Берацгаузен,Берацхаузен,Բերացհաուզեն,براتسهاوزن,贝拉茨豪森', 49.0951700, 11.8097000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39307, 'Benzweiler', 'Benzweiler', '', 50.0166700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39308, 'Bentzin', 'Bentzin', 'Bencin,ben qin,Бенцин,本钦', 53.9460800, 13.2732000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39309, 'Bentwisch', 'Bentwisch', 'Bentvish,Bentwisch,ben te wei shi,Бентвиш,本特维施', 54.1150300, 12.2046500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39310, 'Bensheim', 'Bensheim', 'Bensgajm,Benshaimas,Bensheim,Benskhajm,Gorad Benskhajm,ben si hai mu,bensuhaimu,bnshaym,bnzhaym,Бенсгайм,Бенсхайм,Бенсхајм,Горад Бенсхайм,بنزهایم,بنسهايم,ベンスハイム,本斯海姆', 49.6836900, 8.6183900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39311, 'Benshausen', 'Benshausen', 'Benshausen,Benskhauzen,ben si hao sen,Бенсхаузен,本斯豪森', 50.6500000, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39312, 'Bennungen', 'Bennungen', '', 51.4608500, 11.1181600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39313, 'Bennstedt', 'Bennstedt', 'Bennstedt,Benshtedt,Benshtet,Бенштедт,Бенштет', 51.4820100, 11.8262000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39314, 'Benningen am Neckar', 'Benningen am Neckar', 'Beningen am Nekar,Benningen,Benningen-am-Nekkar,Benningen-na-Nekkare,bnyngn am nkar,nei ka he pan bei ning gen,Бенинген ам Некар,Беннинген-ам-Неккар,Беннинген-на-Неккаре,Беннінген-ам-Неккар,بنینگن ام نکار,内卡河畔贝宁根', 48.9467200, 9.2421200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39315, 'Benningen', 'Benningen', 'Beningen,Benningen,bei ning gen,Бенинген,Беннинген,Беннінген,Բենինգեն,贝宁根', 47.9666700, 10.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39316, 'Bennhausen', 'Bennhausen', '', 49.6166700, 7.9833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39317, 'Bennewitz', 'Bennewitz', 'Benevic,Bennevic,Bennewitzi vald,bei nei wei ci,Беневиц,Бенневиц,贝内维茨', 51.3607400, 12.7137600, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39318, 'Benneckenstein', 'Benneckenstein', 'Benekenshtajn,Benneckenstein,Bennekenshtajn,Бенекенштајн,Беннекенштайн', 51.6682300, 10.7171600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39319, 'Benndorf', 'Benndorf', 'Bennendhorp', 51.5703500, 11.4929000, 'DE', '2014-12-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39320, 'Bengel', 'Bengel', '', 50.0166700, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39321, 'Benediktbeuern', 'Benediktbeuern', 'Benedict Beyrn,Benediktbeiern,Benediktboern,Benediktbojern,Benediktboyern,bei nei di ke te bo yi ai er en,bndykt bwyrn,Бенедиктбойерн,Бенедиктбоєрн,Бенедиктбојерн,Բենեդիկտբոյերն,بندیکت بویرن,贝内迪克特博伊埃尔恩', 47.7062400, 11.4152200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39322, 'Bendorf', 'Bendorf', '', 54.0833300, 9.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39323, 'Bendorf', 'Bendorf', 'Bendorf,bendorufu,bndwrf,bndwrf an dr rayn,Бендорф,بندورف,بندورف آن در راین,ベンドルフ', 50.4228900, 7.5792400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39324, 'Bendfeld', 'Bendfeld', 'Bendfeld', 54.3666700, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39325, 'Bendestorf', 'Bendestorf', '', 53.3358300, 9.9615400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39326, 'Bempflingen', 'Bempflingen', 'Bempflingen,ben pu fu lin gen,Бемпфлинген,Бемпфлінген,Բեմպֆլինգեն,本普夫林根', 48.5717800, 9.2683400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39327, 'Bad Belzig', 'Bad Belzig', 'Belzig', 52.1418400, 12.5927200, 'DE', '2015-11-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39328, 'Belum', 'Belum', 'Belum,Gemeen Belen,bei lu mu,Белум,贝卢姆', 53.8166700, 9.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39329, 'Beltheim', 'Beltheim', 'Bel''tajm,Bel''tkhajm,Beltheim,Beltkhajm,bei er tai mu,Белтхајм,Бельтайм,Бельтхайм,贝尔泰姆', 50.1060600, 7.4620800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39330, 'Belrieth', 'Belrieth', 'Belrieth', 50.5333300, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39331, 'Belm', 'Belm', 'Bel''m,Belm,bei er mu,Белм,Бельм,贝尔姆', 52.3000000, 8.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39332, 'Bellstedt', 'Bellstedt', 'Bellstedt', 51.2666700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39333, 'Bellingen', 'Bellingen', '', 50.6000000, 7.9000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39334, 'Bellheim', 'Bellheim', 'Bel''khajm,Belkhajm,bei er hai mu,Белхајм,Бельхайм,贝尔海姆', 49.1983300, 8.2794400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39335, 'Bellenberg', 'Bellenberg', '', 48.2572600, 10.0909400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39336, 'Belleben', 'Belleben', '', 51.6749900, 11.6342000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39337, 'Bell', 'Bell', '', 50.3833300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39338, 'Bell', 'Bell', '', 50.0613900, 7.4151500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39339, 'Belgweiler', 'Belgweiler', '', 49.9500000, 7.4833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39340, 'Belgershain', 'Belgershain', '', 51.2333300, 12.5500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39341, 'Belgern', 'Belgern', 'Bel''gern,Belgern,bei er ge er en,blghrn,blgrn,Белгерн,Бельгерн,بلغرن,بلگرن,贝尔格尔恩', 51.4826300, 13.1238200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39342, 'Belg', 'Belg', '', 49.9833300, 7.3000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39343, 'Beldorf', 'Beldorf', 'Beldorf', 54.1333300, 9.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39344, 'Belau', 'Belau', '', 54.0980000, 10.2584800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39345, 'Bekond', 'Bekond', '', 49.8500000, 6.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39346, 'Bekmünde', 'Bekmunde', 'Bekmunde,Bekmünde', 53.9250200, 9.4462600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39347, 'Bekdorf', 'Bekdorf', 'Bekdorf', 53.9393800, 9.4226800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39348, 'Beinhausen', 'Beinhausen', '', 50.2666700, 6.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39349, 'Beinerstadt', 'Beinerstadt', 'Beinerstadt', 50.4666700, 10.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39350, 'Beindersheim', 'Beindersheim', 'Bajnderskhajm,Boinderschem,bai yin de er si hai mu,Байндерсхайм,Бајндерсхајм,拜因德尔斯海姆', 49.5605600, 8.3194400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39351, 'Beimerstetten', 'Beimerstetten', '', 48.4833300, 9.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39352, 'Beilstein', 'Beilstein', 'Bajl''shtajn,Bajlshtajn,Beilstein,Байльштайн,Бајлштајн', 50.1166700, 7.2500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39353, 'Beilstein', 'Beilstein', 'Bajl''shtajn,Bajlshtajn,Beilstein,bairushutain,Байльштайн,Бајлштајн,بایل‌اشاین,バイルシュタイン', 49.0414000, 9.3137000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39354, 'Beilrode', 'Beilrode', 'Bajl''rode,Bajlrode,bai er luo de,Байльроде,Бајлроде,拜尔罗德', 51.5666700, 13.0666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39355, 'Beilingen', 'Beilingen', '', 49.9500000, 6.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39356, 'Beierstedt', 'Beierstedt', '', 52.0741300, 10.8581000, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39357, 'Beiersdorf', 'Beiersdorf', '', 51.0740500, 14.5382800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39358, 'Beierfeld', 'Beierfeld', '', 50.5652900, 12.7904900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39359, 'Bei der Höhne', 'Bei der Hoehne', '', 53.5135100, 9.1119100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39360, 'Beidenfleth', 'Beidenfleth', 'Beidenfleth', 53.8794200, 9.4131500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39361, 'Beichlingen', 'Beichlingen', '', 51.2325600, 11.2578100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39362, 'Behringen', 'Behringen', '', 50.7728300, 11.0140300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39363, 'Behrendorf', 'Behrendorf', '', 54.5666700, 9.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39364, 'Behlendorf', 'Behlendorf', '', 53.7000000, 10.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39365, 'Beetzendorf', 'Beetzendorf', 'Becendorf,Beetzendorf,Betcendorf,bei cen duo fu,Бетцендорф,Бецендорф,贝岑多夫', 52.7022600, 11.0889000, 'DE', '2016-09-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39366, 'Beesten', 'Beesten', '', 52.4333300, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39367, 'Beeskow', 'Beeskow', 'Beeskow,Beskov,Bezkov,Bezkow,bei si ke,beseukopeu,byzkw,Безков,Бесков,Բեսկով,بيزكو,بیزکو,贝斯科,베스코프', 52.1729100, 14.2459700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39368, 'Beesenstedt', 'Beesenstedt', 'Beesenstedt', 51.5682800, 11.7332300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39369, 'Beesenlaublingen', 'Beesenlaublingen', '', 51.7127400, 11.6972900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39370, 'Beerfelden', 'Beerfelden', 'Beerfelden,Berfel''den,Berfelden,beaferuden,bei er fei er deng,byrfldn,Берфелден,Берфельден,بيرفلدن,بیرفلدن,ベーアフェルデン,贝尔费尔登', 49.5685800, 8.9744400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39371, 'Beendorf', 'Beendorf', '', 52.2427300, 11.0872700, 'DE', '2011-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39372, 'Beelitz', 'Beelitz', 'Beelitz,Belic,Belizi,Spargelstadt Beelitz,bei li ci,beːlɪts (de),beːlɪt͡s (de),blytz,bylyts,Белиц,Беліц,Բելից,بلیتز,بيليتس,贝利茨', 52.2381200, 12.9714000, 'DE', '2015-10-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39373, 'Beelen', 'Beelen', 'Beilen,Belen,Белен', 51.9290600, 8.1111700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39374, 'Beedenbostel', 'Beedenbostel', '', 52.6428800, 10.2590700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39375, 'Bedesbach', 'Bedesbach', 'Bedesbakh,bei de si ba he,Бедесбах,贝德斯巴赫', 49.5684900, 7.4578500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39376, 'Bedburg', 'Bedburg', 'Bebber,Bedburg,bdbwrg,bei de bao,bydbwrgh,Бедбург,بدبورگ,بيدبورغ,贝德堡', 50.9925800, 6.5712800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39377, 'Beckum', 'Beckum', 'Beckum,Bekkum,Bekum,Biaekem,Biäkem,bei ku mu,bkwm  alman,Беккум,Бекум,بکوم، آلمان,贝库姆', 51.7557100, 8.0407500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39378, 'Beckingen', 'Beckingen', 'Bekingen,Bekkingen,bei jin gen,bekkingen,Бекинген,Беккинген,Беккінген,ベッキンゲン,贝金根', 49.4000000, 6.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39379, 'Beckeln', 'Beckeln', '', 52.8666700, 8.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39380, 'Beckedorf', 'Beckedorf', 'Bekedorf,Bekkedorf,bekkedorufu,Бекедорф,Беккедорф,ベッケドルフ', 52.3500000, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39381, 'Beckdorf', 'Beckdorf', 'Beckdorf,Beekdoerp,Beekdörp,Bekdorf,bekkudorufu,Бекдорф,ベックドルフ', 53.4166700, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39382, 'Bechtsrieth', 'Bechtsrieth', 'Bekhtsrit,Bextsrit,bei xi ci li te,Бехтсрит,Бехтсріт,Բեխտսրիտ,贝希茨里特', 49.6448700, 12.2099700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39383, 'Bechtolsheim', 'Bechtolsheim', 'Bechtolsheim,Bekhtol''skhajm,Bekhtolskhajm,bei xi tuo er si hai mu,Бехтолсхајм,Бехтольсхайм,贝希托尔斯海姆', 49.8041700, 8.1938900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39384, 'Bechtheim', 'Bechtheim', '', 49.7277800, 8.2922200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39385, 'Bechstedtstraß', 'Bechstedtstrass', '', 50.9500000, 11.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39386, 'Bechstedt', 'Bechstedt', 'Bechstedt', 50.6666700, 11.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39387, 'Bechhofen', 'Bechhofen', '', 49.3500000, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39388, 'Becherbach', 'Becherbach', 'Bekherbakh,bei xie er ba he,Бехербах,贝歇尔巴赫', 49.6500000, 7.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39389, 'Bechenheim', 'Bechenheim', '', 49.7286100, 8.0033300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39390, 'Becheln', 'Becheln', '', 50.2928500, 7.7179800, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39391, 'Bebra', 'Bebra', 'Bebra,Byvera,Gorad Bebra,bbra,bei bu la,bybra,Бебра,Горад Бебра,ببرا,بيبرا,贝布拉', 50.9744500, 9.7956200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39392, 'Bebensee', 'Bebensee', 'Bebensee', 53.8833300, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39393, 'Bayrischzell', 'Bayrischzell', 'Bajrishcel,Bajrishcel'',Bajrishcell'',Boarischzell,bai li shi ce er,bayryshtsl,Байришцел,Байришцелль,Байрішцель,Бајришцел,Բայրիշցել,بایریشتسل,拜里施策尔', 47.6744000, 12.0144900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39394, 'Bayreuth', 'Bayreuth', 'BYU,Bairoit,Bajrojt,Baruthum,Bayreith,Bayreuth,Gorad Bajrojt,bai luo yi te,bailoiteu,bairoito,bayrwyt,byyrwyt,Μπαϊρόιτ,Байройт,Бајројт,Горад Байройт,ביירוית,بايرويت,بایرویت,ضلع بیرتھ,バイロイト,拜罗伊特,바이로이트', 49.9478200, 11.5789300, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39395, 'Bayerisch Gmain', 'Bayerisch Gmain', 'Baerish-Gmajn,Bajerish Gmajn,Bajerish-Gmajn,Bayeris Gmayn,Boarisch Gmoa,bai ren li xi ge mai yin,bayrysh gmayn,Байериш-Гмайн,Баєріш-Гмайн,Бајериш Гмајн,Բայերիշ Գմայն,بایریش گماین,拜仁里希格迈因', 47.7166700, 12.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39396, 'Bayerisch Eisenstein', 'Bayerisch Eisenstein', 'Baerish-Ajzenshtajn,Bajerish Ajzenshtajn,Bajerish-Ajzenshtajn,Boarisch Eisnstoa,bai en ai sen shi tai yin,bayrysh ayznshtayn,Байериш-Айзенштайн,Баєріш-Айзенштайн,Бајериш Ајзенштајн,Բայերիշ Էյզենշթայն,بایریش ایزنشتاین,拜恩埃森施泰因', 49.1166700, 13.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39397, 'Bayerfeld-Steckweiler', 'Bayerfeld-Steckweiler', '', 49.6833300, 7.8000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39398, 'Bayerbach', 'Bayerbach', 'Bayerbach', 48.7045000, 12.2975000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39399, 'Bayerbach', 'Bayerbach', '', 48.4101700, 13.1441100, 'DE', '2011-07-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39400, 'Bayenthal', 'Bayenthal', '', 50.9121800, 6.9679900, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39401, 'Bawinkel', 'Bawinkel', 'Bavinkel,Bavinkel'',Bawinkel,ba wen ke er,Бавинкел,Бавинкель,巴温克尔', 52.6000000, 7.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39402, 'Bautzen', 'Bautzen', 'Baucen,Baucene,Bautcen,Bautzen,Budishin,Budisin,Budissa,Budišin,Budysin,Budysyn,Budyšin,Budyšyn,Budyšín,Budziszyn,bao cen,bautsu~en,bawtsn,bawtzn,bea th sein,bwatzn,Баутцен,Бауцен,Будишин,באוצן,باؤتزن,باوتسن,بواتزن,เบาท์เซิน,バウツェン,包岑', 51.1803500, 14.4349400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39403, 'Baustert', 'Baustert', '', 49.9780000, 6.3898400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39404, 'Bausendorf', 'Bausendorf', '', 50.0166700, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39405, 'Baunatal', 'Baunatal', 'Baunatal,Baunatal'',bao na ta er,baunataru,bawnatal,bwanatal,Баунатал,Баунаталь,باوناتال,بواناتال,バウナタール,鲍纳塔尔', 51.2518200, 9.4074700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39406, 'Baunach', 'Baunach', 'Baunakh,Baunax,bao na,baunaha,bawnakh,bwanakh,Баунах,Բաունախ,باوناخ,بواناخ,バウナハ,鲍纳', 49.9859200, 10.8517900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39407, 'Baumschulenweg', 'Baumschulenweg', 'Baumschulenweg,Berlin-Baumschulenweg', 52.4658300, 13.4852300, 'DE', '2012-08-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39408, 'Baumholder', 'Baumholder', 'Baumholder,Baumkhol''der,Baumkholder,bao mu huo er de er,baumuhoruda,bawmhwldr,Баумхолдер,Баумхольдер,باومهولدر,بوام‌هلدر,バウムホルダー,鲍姆霍尔德尔', 49.6173800, 7.3338100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39409, 'Bauler', 'Bauler', '', 50.3333300, 6.8833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39410, 'Bauler', 'Bauler', '', 49.9666700, 6.2000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39411, 'Baudenbach', 'Baudenbach', 'Baudenbach,Baudenbakh,Baudenbax,bao deng ba he,Бауденбах,Բաուդենբախ,鲍登巴赫', 49.6251200, 10.5359800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39412, 'Battweiler', 'Battweiler', '', 49.2784800, 7.4636600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39413, 'Battenberg', 'Battenberg', 'Battenberg', 51.0139100, 8.6460300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39414, 'Bastorf', 'Bastorf', 'Bastorf', 54.1256600, 11.6969500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39415, 'Basthorst', 'Basthorst', '', 53.5767600, 10.4737800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39416, 'Bastheim', 'Bastheim', 'Bastajm,Bastgajm,Bastkhajm,ba si tai mu,Бастайм,Бастгайм,Бастхайм,Бастхајм,Բասթհայմ,巴斯泰姆', 50.4008000, 10.2037200, 'DE', '2012-08-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39417, 'Bassum', 'Bassum', 'Bassen,Bassum,Basum,ba su mu,baswm,Бассум,Басум,باسوم,巴苏姆', 52.8505900, 8.7279100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39418, 'Bassenheim', 'Bassenheim', 'Bassenkhajm,Bazenkhajm,ba sen hai mu,Базенхајм,Бассенхайм,巴森海姆', 50.3582000, 7.4596100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39419, 'Basedow', 'Basedow', '', 53.4166700, 10.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39420, 'Basdahl', 'Basdahl', 'Basdaal,Basdal,Basdal'',ba si da er,basudaru,Басдал,Басдаль,バスダール,巴斯达尔', 53.4450200, 9.0002500, 'DE', '2011-10-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39421, 'Basberg', 'Basberg', '', 50.3000000, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39422, 'Barweiler', 'Barweiler', 'Barvajler,ba er wei lei,baruvu~aira,Барвайлер,Барвајлер,バルヴァイラー,巴尔韦勒', 50.3666700, 6.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39423, 'Bärweiler', 'Barweiler', 'Baerweiler,Bervajler,Bärweiler,bei er wei lei,Бервайлер,Бервајлер,贝尔韦勒', 49.7333300, 7.6000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39424, 'Barwedel', 'Barwedel', 'Barvedel,Barvedel'',ba er wei de er,Барведел,Барведель,巴尔韦德尔', 52.5219200, 10.7748800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39425, 'Barver', 'Barver', '', 52.6206600, 8.5925100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39426, 'Baruth', 'Baruth', 'Baruth,Baruth/Mark', 52.0446800, 13.5027000, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39427, 'Barum', 'Barum', '', 53.3500000, 10.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39428, 'Barum', 'Barum', '', 53.0500000, 10.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39429, 'Bartholomä', 'Bartholoma', 'Bartholomae,Bartholomä,Bartolome,ba er tuo luo mei,bartolome,Бартоломе,ბართოლომე,巴尔托洛梅', 48.7535000, 9.9875200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39430, 'Barth', 'Barth', 'Bart,Barta,Biardo,barth  alman,Барт,بارث، آلمان', 54.3634600, 12.7249100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39431, 'Barßel', 'Barssel', 'Baeaersel,Barsel,Barsel'',Barssel,Barßel,Bäärsel,ba er sai er,Барсел,Барсель,巴尔塞尔', 53.1698100, 7.7501200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39432, 'Barsinghausen', 'Barsinghausen', 'Barzingkhauzen,Basche,Baschehusen,Berkingehusen [a. 1193],ba er xin ge hao sen,barzynghhawzn,Барзингхаузен,Барзінгхаузен,بارزينغهاوزن,بارزینگ‌هاوزن,巴尔辛格豪森', 52.3000000, 9.4500000, 'DE', '2011-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39433, 'Barsbüttel', 'Barsbuettel', 'Barsbitel,Barsbjuttel'',Barsbuettel,Barsbuetteli vald,Barsbuttel,Barsbüttel,Barsbütteli vald,ba er si bi te er,Барсбител,Барсбюттель,巴尔斯比特尔', 53.5666700, 10.1666700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39434, 'Barsbek', 'Barsbek', 'Barsbek', 54.4000000, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39435, 'Barntrup', 'Barntrup', 'Barntrup,ba er en te lu pu,barntrwb,barntrwp,baruntorupu,Барнтруп,بارنتروب,بارنتروپ,バルントルプ,巴尔恩特鲁普', 51.9903800, 9.1164200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39436, 'Barnstorf', 'Barnstorf', 'Baarnstrup,Barnstorf,ba en si tuo fu,Барнсторф,巴恩斯托夫', 52.7100900, 8.5025600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39437, 'Barnstedt', 'Barnstedt', 'Barnshtedt,Barnshtet,Barnstedt,ba er en si te,Барнштедт,Барнштет,巴尔恩斯特', 53.1333300, 10.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39438, 'Barnstädt', 'Barnstaedt', 'Barnstadt,Barnstaedt,Barnstädt', 51.3440100, 11.6373500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39439, 'Bärnau', 'Barnau', 'Baernau,Bernau,Bärnau,bei er nao,brnwa,Бернау,برنوا,贝尔瑙', 49.8107900, 12.4331800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39440, 'Barmstedt', 'Barmstedt', 'Barmshtedt,Barmshtet,Barmstedt,ba er mu si te,barmshtyt,Бармштедт,Бармштет,بارمشتيت,بارم‌اشتت,巴尔姆斯特', 53.7920900, 9.7673900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39441, 'Barmissen', 'Barmissen', 'Barmissen', 54.2000000, 10.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39442, 'Barlt', 'Barlt', 'Barlt', 54.0166700, 9.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39443, 'Barleben', 'Barleben', 'Barlaeae,Barleben,Barlää,ba er lai ben,Барлебен,巴尔莱本', 52.2019300, 11.6177000, 'DE', '2014-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39444, 'Barkenholm', 'Barkenholm', 'Barkenholm', 54.2333300, 9.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39445, 'Barkelsby', 'Barkelsby', 'Barkel''sbi,Barkelsbi,Barkelsby,ba er ke er si bi,Баркелсби,Баркельсби,巴尔克尔斯比', 54.5000000, 9.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39446, 'Bark', 'Bark', 'Bark', 53.9114600, 10.1794900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39447, 'Bargum', 'Bargum', 'Bargum', 54.7000000, 8.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39448, 'Bargteheide', 'Bargteheide', 'Bargteheide,Bargtekhajde,ba er ge te hai de,barghtyhayd,Баргтехайде,Баргтехајде,بارغتيهايد,بارگته‌هایده,巴尔格特海德', 53.7285600, 10.2669500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39449, 'Bargstedt', 'Bargstedt', '', 54.1666700, 9.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39450, 'Bargstedt', 'Bargstedt', '', 53.4666700, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39451, 'Bargstall', 'Bargstall', 'Bargstall', 54.2666700, 9.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39452, 'Bargfeld-Stegen', 'Bargfeld-Stegen', 'Bargfel''d-Shtegen,Bargfeld-Shtegen,Bargfeld-Stegen,ba er ge fei er de-si te gen,Баргфелд-Штеген,Баргфельд-Штеген,巴尔格费尔德-斯特根', 53.7677800, 10.1875000, 'DE', '2011-08-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39453, 'Bargenstedt', 'Bargenstedt', 'Bargenstedt', 54.1000000, 9.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39454, 'Bärenthal', 'Barenthal', 'Berental,Berental'',bei lun ta er,Берентал,Беренталь,贝伦塔尔', 48.0666700, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39455, 'Bärenstein', 'Baerenstein', '', 50.8012500, 13.7977100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39456, 'Bärenstein', 'Barenstein', 'Baerenstein,Bärenstein', 50.5000000, 13.0333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39457, 'Barendorf', 'Barendorf', 'Barendorf,ba lun duo fu,Барендорф,巴伦多夫', 53.2289600, 10.5215800, 'DE', '2011-09-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39458, 'Barenburg', 'Barenburg', 'Baarnborg,Barenburg,ba lun bao,Баренбург,巴伦堡', 52.6195300, 8.7999900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39459, 'Bärenbach', 'Barenbach', '', 49.9500000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39460, 'Bärenbach', 'Barenbach', 'Baerenbach,Berenbakh,Bärenbach,Беренбах', 49.7500000, 7.4500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39461, 'Bardowick', 'Bardowick', 'Bardenuvicum,Bardovik,Bardowick,Bardowiek,Bewick,ba er duo wei ke,Бардовик,巴尔多维克', 53.2935400, 10.3881100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39462, 'Barchfeld', 'Barchfeld', '', 50.8287200, 11.1795500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39463, 'Barchfeld', 'Barchfeld', 'Barkhfel''d,Barkhfeld,ba er xi fei er de,Бархфелд,Бархфельд,巴尔希费尔德', 50.8000000, 10.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39464, 'Barbing', 'Barbing', 'Barbing,Perbing,ba er bin,barbyng,Барбинг,Барбінг,Բարբինգ,باربینگ,巴尔宾', 49.0000000, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39465, 'Barbelroth', 'Barbelroth', '', 49.0988900, 8.0691700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39466, 'Banzkow', 'Banzkow', 'Banckov,Banzkow,ban ci ke,Банцков,班茨科', 53.5249700, 11.5230600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39467, 'Banteln', 'Banteln', 'Bantel''n,Banteln,ban te er en,Бантелн,Бантельн,班特尔恩', 52.0666700, 9.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39468, 'Bannewitz', 'Bannewitz', 'Banevic,Bannevic,ba nei wei ci,Баневиц,Банневиц,巴内维茨', 50.9929100, 13.7171200, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39469, 'Bannberscheid', 'Bannberscheid', '', 50.4718300, 7.8365800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39470, 'Bann', 'Bann', '', 49.3833300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39471, 'Bammental', 'Bammental', 'Bamental,Bammemtal,Bammental,Bammental'',Bammenthal,ba men ta er,banmentaru,Баментал,Бамменталь,バンメンタール,巴门塔尔', 49.3561100, 8.7794400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39472, 'Bamberg', 'Bamberg', 'Bambarg,Bamberg,Bamberga,Bambergas,Bamberk,Bampernk,Gorad Bamberg,ZCD,ba mu bei ge,bambeleukeu,bambergi,bambrg,bambrgh,ban bao,banberuku,bmbrg,Μπάμπεργκ,Бамберг,Горад Бамберг,במברג,بامبرغ,بامبرگ,บัมแบร์ก,ბამბერგი,バンベルク,巴姆贝格,班堡,밤베르크', 49.8987300, 10.9006700, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39473, 'Balzhausen', 'Balzhausen', 'Bal''cgauzen,Bal''ckhauzen,Balckhauzen,ba er ci hao sen,Балцхаузен,Бальцгаузен,Бальцхаузен,Բալցհաուզեն,巴尔茨豪森', 48.2422800, 10.4936600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39474, 'Balzfeld', 'Balzfeld', '', 49.2689200, 8.7891900, 'DE', '2010-11-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39475, 'Balve', 'Balve', 'Bal''ve,Ballova,Balve,ba er fei,balfh,balwh,Балве,Бальве,بالفه,بالوه,巴尔费', 51.3315000, 7.8642400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39476, 'Baltrum', 'Baltrum', 'BMR,Bal''trum,Baltrum,ba er te lu mu,baltrwm,Балтрум,Бальтрум,بالتروم,ბალტრუმი,巴尔特鲁姆', 53.7283600, 7.3714300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39477, 'Baltmannsweiler', 'Baltmannsweiler', 'Bal''tmannsvajler,Baltmansvajler,Baltmansvayler,ba te man si wei lei,Балтмансвајлер,Бальтманнсвайлер,Բալտմանսվայլեր,巴特曼斯韦勒', 48.7421500, 9.4494000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39478, 'Ballstedt', 'Ballstedt', '', 51.0500000, 11.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39479, 'Ballstädt', 'Ballstadt', 'Bal''shtedt,Ballstadt,Ballstädt,Balshtet,ba er si te,Балштет,Бальштедт,巴尔斯特', 51.0333300, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39480, 'Ballenstedt', 'Ballenstedt', 'Balenshhet,Balenshtet,Ballenshtedt,Ballenstedt,ba lun si te,balnshtyt,Баленштет,Баленщет,Балленштедт,بالنشتيت,بالن‌اشتات,巴伦斯特', 51.7190000, 11.2326500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39481, 'Ballendorf', 'Ballendorf', 'Balendorf,Ballendorf,balendorpi,Балендорф,Баллендорф,Բալենդորֆ,ბალენდორფი', 48.5541700, 10.0769500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39482, 'Balje', 'Balje', 'Bal''e,Balje,ba er ye,barie,Балье,Балје,バリエ,巴尔耶', 53.8333300, 9.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39483, 'Balingen', 'Balingen', 'Balingen,ba lin gen,balynghn,balyngn,Балинген,Балінген,بالينغن,بالینگن,巴林根', 48.2752500, 8.8546400, 'DE', '2014-01-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39484, 'Balgstädt', 'Balgstaedt', 'Balgstadt,Balgstädt', 51.2053100, 11.7333400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39485, 'Balgheim', 'Balgheim', '', 48.0666700, 8.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39486, 'Balge', 'Balge', 'Bal''ge,Balge,ba er ge,baruge,Балге,Бальге,バルゲ,巴尔格', 52.7166700, 9.1666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39487, 'Balesfeld', 'Balesfeld', '', 50.1000000, 6.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39488, 'Balduinstein', 'Balduinstein', 'Bal''duinshtajn,Balduinshtajn,ba er du yin si tai yin,Балдуинштајн,Бальдуинштайн,巴尔杜因斯泰因', 50.3500000, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39489, 'Baldringen', 'Baldringen', '', 49.6166700, 6.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39490, 'Balderschwang', 'Balderschwang', 'Bal''dershvang,Baldershvang,Baldersvang,ba er de er shi wang,Балдершванг,Бальдершванг,Բալդերշվանգ,巴尔德尔施旺', 47.4666700, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39491, 'Bälau', 'Balau', 'Balau,Bälau', 53.6166700, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39492, 'Bakum', 'Bakum', 'Bakum,ba ku mu,Бакум,巴库姆', 52.7411800, 8.1954600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39493, 'Bäk', 'Bak', 'Bak,Bäk', 53.7166700, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39494, 'Baisweil', 'Baisweil', 'Bajsvajl,Bajsvajl'',Baysvayl,bai si wei er,baisuvu~airu,Байсвайль,Бајсвајл,Բայսվայլ,バイスヴァイル,拜斯魏尔', 47.9443900, 10.5400700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39495, 'Baindt', 'Baindt', 'Bajndt,bai yin te,Байндт,Бајндт,拜因特', 47.8500000, 9.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39496, 'Baiersdorf', 'Baiersdorf', 'Baersdorf,Bajersdorf,Bajrsdorf,bai ai er si duo fu,baiasudorufu,bayrsdwrf,Байерсдорф,Баєрсдорф,Бајрсдорф,بایرسدورف,بیرسڈورف,バイアースドルフ,拜埃尔斯多夫', 49.6580700, 11.0359400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39497, 'Baiersbronn', 'Baiersbronn', 'Baiersbronn,Bajersbron,Bajrsbron,bai ai er si bu long,Байрсброн,Бајерсброн,Бајрсброн,拜埃尔斯布龙', 48.5031800, 8.3769900, 'DE', '2013-04-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39498, 'Baierbrunn', 'Baierbrunn', 'Baerbrunn,Baiabrunn,Baierbrun,Bajerbrun,Bajerbrunn,Bayerbrun,bai ai er bu lun,bayrbrwn,Байербрунн,Баєрбрунн,Бајербрун,Բայերբրուն,بایربرون,ባየርብሩን,拜埃尔布伦', 48.0203000, 11.4868900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39499, 'Baierbach', 'Baierbach', 'Baierboch,Bairbakh,Bajerbakh,Bajrbakh,Bayerbax,bai ai er ba he,Байербах,Баїрбах,Бајрбах,Բայերբախ,拜埃尔巴赫', 48.4166700, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39500, 'Baienfurt', 'Baienfurt', 'Bainfurt,Bajenfurt,Bajnfurt,bai en fu er te,baynfwrt,Байнфурт,Баїнфурт,Бајенфурт,باینفورت,拜恩富尔特', 47.8285700, 9.6515700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39501, 'Bahrenhof', 'Bahrenhof', 'Bahrenhof', 53.8833300, 10.3833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39502, 'Bahrenfleth', 'Bahrenfleth', 'Bahrenfleth,Barenfleth', 53.8713300, 9.4396400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39503, 'Bahrenborstel', 'Bahrenborstel', 'Bahrenbostel', 52.5700900, 8.8086300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39504, 'Bahrdorf', 'Bahrdorf', 'Bahrdorp,Bardorp,Bardorp [a. 973],Bardorpe [~ a. 1250],Bårdorp', 52.3858700, 11.0004000, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39505, 'Bahlingen', 'Bahlingen', 'Bahlingen', 48.1206400, 7.7398200, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39506, 'Baesweiler', 'Baesweiler', 'Baaswieler,Basweilen,Basweiler,Besvajler,Bäsweiler,ba si wei lei,baysfaylr,byzwaylr,Бесвайлер,Бесвајлер,بايسفايلر,بیزوایلر,巴斯韦勒', 50.9096400, 6.1887400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39507, 'Bad Zwischenahn', 'Bad Zwischenahn', 'Bad Cvishenan,Bad Twiskenoan,Bad Zwischenahn,Bad-Cvishenan,Twueschenahn,Twüschenahn,ba te ci wei shen an,Бад Цвишенан,Бад-Цвишенан,巴特茨维申安', 53.1833300, 8.0000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39508, 'Bad Wurzach', 'Bad Wurzach', 'Bad Vurcakh,Bad Wurzach,Bad-Vurcakh,ba te wu er cha he,bad fwrtsakh,bad wwrzakh,Бад Вурцах,Бад-Вурцах,باد فورتساخ,باد وورزاخ,巴特武尔察赫', 47.9079900, 9.8968600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39509, 'Bad Wörishofen', 'Bad Worishofen', 'Bad V''oriskhofen,Bad Veriskhofen,Bad Vyorishofen,Bad Woerishofen,Bad Worishofen,Bad Wörishofen,Bad-Verisgofen,Bad-Vjoriskhofen,ba te wo li si huo fen,bad fwryshwfn,bad wryshwfn,Бад Верисхофен,Бад Вьорисхофен,Бад-Верісгофен,Бад-Вёрисхофен,Бад-Вөрисхофен,Բադ Վյորիսհոֆեն,باد فوريسهوفن,باد وریسهوفن,بیڈ وورسشوفن,巴特沃里斯霍芬', 48.0067400, 10.5966600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39510, 'Bad Windsheim', 'Bad Windsheim', 'Bad Vindshaym,Bad Vindskhajm,Bad Windsheim,Bad-Vindsgajm,Bad-Vindskhajm,ba te wen ci hai mu,bad fyndshaym,bad wyndshaym,byڈ wnڈsہaym,Бад Виндсхајм,Бад-Виндсхайм,Бад-Віндсгайм,Բադ Վինդսհայմ,باد فيندسهايم,باد ویندسهایم,بیڈ ونڈسہایم,巴特温茨海姆', 49.5027400, 10.4153900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39511, 'Bad Wimpfen', 'Bad Wimpfen', 'Bad Vimpfen,Bad Wimpfen,Bad-Vimpfen,Wimpina,ba te wen pu fen,bad fymbfn,bad wympn,Бад Вимпфен,Бад-Вимпфен,Бад-Вімпфен,باد فيمبفن,باد ویمپن,バート・ヴィンプフェン,巴特温普芬', 49.2297100, 9.1564800, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39512, 'Bad Wilsnack', 'Bad Wilsnack', 'Bad Vilsnak,Bad Wilsnack,Bad-Vil''snak,ba te wei er si na ke,bad fylsnak,bad wylznak,Бад Вилснак,Бад-Вильснак,باد فيلسناك,باد ویلزناک,巴特维尔斯纳克', 52.9560700, 11.9490300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39513, 'Bad Wildungen', 'Bad Wildungen', 'Bad Vildungen,Bad-Vil''dungen,ba te wei er dong gen,bad fyldwnghn,bad wyldwngn,Бад Вилдунген,Бад-Вильдунген,Бад-Вільдунген,باد فيلدونغن,باد ویلدونگن,バート・ヴィルドゥンゲン,巴特維爾東根', 51.1196300, 9.1247500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39514, 'Bad Wiessee', 'Bad Wiessee', 'Bad Visze,Bad-Visze,ba te wei sai,Бад Висзе,Бад-Висзе,Бад-Вісзе,Բադ Վիսզե,巴特维塞', 47.7166700, 11.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39515, 'Bad Waldsee', 'Bad Waldsee', 'Bad Valdze,Bad Waldsee,Bad-Val''dze,ba te wa er de sai,bad faldzyh,bad waldzy,Бад Валдзе,Бад-Вальдзе,باد فالدزيه,باد والدزی,巴特瓦尔德塞', 47.9202700, 9.7549000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39516, 'Bad Vilbel', 'Bad Vilbel', 'Bad Vilbel,Bad-Fil''bel'',ba de fei er bei er,bad fylbl,Бад Вилбел,Бад-Фильбель,Бад-Фільбель,باد فيلبل,باد فیلبل,バート・フィルベル,巴德菲尔贝尔', 50.1786600, 8.7375600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39517, 'Bad Überkingen', 'Bad Uberkingen', 'Bad Iberkingen,Bad UEberkingen,Bad Überkingen,Bad-Iberkingen,Bad-Juberkingen,ba te yu bo jing gen,Бад Иберкинген,Бад-Иберкинген,Бад-Юберкінген,巴特于伯京根', 48.5999100, 9.7958600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39518, 'Bad Tölz', 'Bad Toelz', 'Bad T''olc,Bad Telc,Bad Toelz,Bad Tölz,Bad-Tel''c,Bad-Tjol''c,Badtelca,Bādtelca,Daeiz,Däiz,Gorad Bad-Cjol''c,Tolz,ba te te er ci,bad twlts,bad twlz,Бад Телц,Бад Тьолц,Бад-Тельц,Бад-Тёльц,Бад-Төльц,Горад Бад-Цёльц,Բադ Տյոլց,באד טלץ,باد تولتس,باد تولز,بیڈ ٹولز,巴特特尔茨', 47.7611100, 11.5589000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39519, 'Bad Tennstedt', 'Bad Tennstedt', 'Bad Tennstedt,Bad Tenshtet,Bad-Tenshtedt,Tennisteti [a. 877],ba te teng shi tai te,bad tnshtyt,Бад Тенштет,Бад-Тенштедт,باد تنشتيت,باد تن‌اشتت,巴特滕施泰特', 51.1544700, 10.8387300, 'DE', '2014-12-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39520, 'Bad Sülze', 'Bad Suelze', 'Bad Suelze,Bad Sülze,Bad Zilce,Bad-Zjul''ce,Badzilce,Bādzilce,ba te xu er ce,bad zwltsh,bad zwlzh,Бад Зилце,Бад-Зюльце,Бад-Зүльце,باد زولتسه,باد زولزه,巴特叙尔策', 54.1108400, 12.6605400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39521, 'Bad Sulza', 'Bad Sulza', 'Bad Zulca,Bad-Zul''ca,ba te su er cha,bad zwltsa,bad zwlza,Бад Зулца,Бад-Зульца,باد زولتسا,باد زولزا,巴特苏尔察', 51.0892900, 11.6247400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39522, 'Bad Suderode', 'Bad Suderode', 'Bad Zuderode,Bad-Zuderode,Бад Зудероде,Бад-Зудероде', 51.7333300, 11.1166700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39523, 'Bad Steben', 'Bad Steben', 'Bad Shteben,Bad Steben,Bad-Shteben,Badsteban,Steben,Untersteben,ba te shi tai ben,bad ashtbn,Бад Штебен,Бад-Штебен,باد اشتبن,バート・シュテーベン,巴特施泰本', 50.3664800, 11.6443800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39524, 'Bad Sooden-Allendorf', 'Bad Sooden-Allendorf', 'Allendorf,Bad Sooden,Bad Sooden-Allendorf,Bad Zoden-Alendorf,Bad-Zoden-Allendorf,ba te suo deng-a lun duo fu,bad zwdn-alndwrf,bad zwndn-alndwrf,Бад Зоден-Алендорф,Бад-Зоден-Аллендорф,باد زودن-آلندورف,باد زوندن-الندورف,バート・ゾーデン＝アレンドルフ,巴特索登-阿伦多夫', 51.2709200, 9.9748300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39525, 'Bad Soden-Salmünster', 'Bad Soden-Salmuenster', 'Bad Soden-Salmuenster,Bad Soden-Salmünster,Bad Zoden-Zalminster,Bad-Zoden-Zal''mjunster,Salmuenster,Salmünster,ba te suo deng-sa er ming si te,bad zwndn-zalmwnstr,Бад Зоден-Залминстер,Бад-Зоден-Зальмюнстер,باد زوندن-زالمونستر,バート・ゾーデン＝ザルミュンスター,巴特索登-萨尔明斯特', 50.2757400, 9.3670500, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39526, 'Bad Soden am Taunus', 'Bad Soden am Taunus', 'Bad Soden,Bad Soden in Taunus,Bad Zoden am Taunus,Bad-Zoden,Gorad Bad-Zodehn,bad zwdn an dr tawnws,bad zwndn an dr tawnws,bateu joden,tao nu si shan lu ba de suo deng,Бад Зоден ам Таунус,Бад-Зоден,Горад Бад-Зодэн,باد زودن آن در تاونوس,باد زوندن آن در تاونوس,バート・ゾーデン・アム・タウヌス,陶努斯山麓巴德索登,바트 조덴', 50.1408000, 8.5044900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39527, 'Bad Segeberg', 'Bad Segeberg', 'Bad Segeberg,Bad Zegeberg,Bad-Zegeberg,Sebarg,ba te sai ge bei ge,bad zgbrg,bad zghhbrgh,Бад Зегеберг,Бад-Зегеберг,باد زغهبرغ,باد زگبرگ,巴特塞格贝格', 53.9431300, 10.3021500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39528, 'Bad Schwartau', 'Bad Schwartau', 'Bad Schwartau,Bad Shvartau,Bad-Shvartau,ba te shi wa tao,bad ashwratwa,bad shfartaw,Бад Швартау,Бад-Швартау,باد اشوراتوا,باد شفارتاو,巴特施瓦陶', 53.9188700, 10.6969100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39529, 'Bad Schwalbach', 'Bad Schwalbach', 'Bad Schwalbach,Bad Shvalbakh,Bad-Shval''bakh,Gorad Bad-Shval''bakh,ba te shi wa er ba he,bad ashwalbakh,bad shfalbakh,Бад Швалбах,Бад-Швальбах,Горад Бад-Швальбах,باد اشوالباخ,باد شفالباخ,巴特施瓦尔巴赫', 50.1419600, 8.0696400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39530, 'Bad Schmiedeberg', 'Bad Schmiedeberg', 'Bad Schmiedeberg,Bad Shmideberg,Bad-Shmideberg,ba te shi mi de bei ge,bad ashmydbrg,bad shmydhbrgh,Бад Шмидеберг,Бад-Шмидеберг,باد اشمیدبرگ,باد شميدهبرغ,巴特施米德贝格', 51.6851600, 12.7348300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39531, 'Bad Schandau', 'Bad Schandau', 'Bad Shandau,Bad-Shandau,Badsandava,Bādšandava,Zandow,ba te shang dao,bad shandaw,bad shwandwa,Žandow,Бад Шандау,Бад-Шандау,باد شانداو,باد شواندوا,巴特尚道', 50.9174300, 14.1549400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39532, 'Bad Sassendorf', 'Bad Sassendorf', 'Bad Sassendorf,Bad Zasendorf,Bad-Zassendorf,ba te sa sen duo fu,Бад Засендорф,Бад-Зассендорф,巴特萨森多夫', 51.5833300, 8.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39533, 'Bad Salzungen', 'Bad Salzungen', 'Bad Salzungen,Bad Zalcungen,Bad-Zal''cungen,ba te sa er cong gen,bad zaltswnghn,bad zalzwngn,Бад Залцунген,Бад-Зальцунген,باد زالتسونغن,باد زالزونگن,巴特萨尔聪根', 50.8134200, 10.2361000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39534, 'Bad Salzuflen', 'Bad Salzuflen', 'Bad Zalcuflen,Bad-Zal''cuflen,ba te sa er ci wu fu lun,bad zaltswfln,Бад Залцуфлен,Бад-Зальцуфлен,باد زالتسوفلن,バート・ザルツウフレン,巴特萨尔茨乌夫伦', 52.0862000, 8.7443400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39535, 'Bad Salzschlirf', 'Bad Salzschlirf', 'Bad Zalcshlirf,Bad-Zal''cshlirf,ba te sa er qi li fu,Бад Залцшлирф,Бад-Зальцшлирф,Бад-Зальцшлірф,巴特萨尔奇利夫', 50.6238800, 9.5081500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39536, 'Bad Salzdetfurth', 'Bad Salzdetfurth', 'Bad Salzdetfurth,Bad Salzendetkuith,Bad Zalcdetfurt,Bad-Zal''cdetfurt,ba te sa er ci dai te fu te,bad zaldtfwrth,bad zaltsdtfwrt,Бад Залцдетфурт,Бад-Зальцдетфурт,باد زالتسدتفورت,باد زالدتفورث,巴特萨尔茨代特富特', 52.0577700, 10.0058000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39537, 'Bad Säckingen', 'Bad Sackingen', 'Bad Saeckingen,Bad Säckingen,Bad Zekingen,Bad-Zekingen,Bad-Zekkingen,Sackingen,Säckingen,ba te sai jing gen,bad zkynghyn,bad zkyngyn,Бад Зекинген,Бад-Зекинген,Бад-Зеккінген,باد زكينغين,باد زکینگین,巴特塞京根', 47.5537100, 7.9461200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39538, 'Bad Sachsa', 'Bad Sachsa', 'Bad Zakhsa,Bad-Zaksa,Sathsa,ba te sa ke sa,bad zaksa,Бад Захса,Бад-Закса,باد زاكسا,باد زاکسا,巴特萨克萨', 51.5949900, 10.5554600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39539, 'Bad Saarow', 'Bad Saarow', 'Bad Saarow,Bad Zarov,Bad-Zarov,Zarow,ba te sa luo,Бад Заров,Бад-Заров,Բադ Զարով,巴特萨罗', 52.2833300, 14.0666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39540, 'Bad Rothenfelde', 'Bad Rothenfelde', 'Bad Rotenfel''de,Bad Rotenfelde,Bad Rothenfelde,Bad-Rotenfel''de,ba te luo teng fei er de,Бад Ротенфелде,Бад Ротенфельде,Бад-Ротенфельде,巴特罗滕费尔德', 52.1166700, 8.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39541, 'Bad Reichenhall', 'Bad Reichenhall', 'Bad Rajkhenkhal,Bad Rayxenhal,Bad Reichenhall,Bad-Rajkhengall'',Bad-Rajkhenkhall'',Datreiche Hall,Gorad Bad-Rajkhenkhal'',Reichahoi,Reichenhall,ba te lai xing ha er,bad rayshnhal,Бад Райхенхал,Бад Рајхенхал,Бад-Райхенгалль,Бад-Райхенхалль,Горад Бад-Райхенхаль,Բադ Ռայխենհալ,باد رايشنهال,باد رایشنهال,بیڈ ریچنہال,巴特赖兴哈尔', 47.7294700, 12.8781900, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39542, 'Bad Rappenau', 'Bad Rappenau', 'Bad Rapenau,Bad Rappenau,Bad-Rappenau,ba te la po nao,bad rabnaw,bad rapnwa,Бад Рапенау,Бад-Раппенау,باد رابناو,باد راپنوا,バート・ラッペナウ,巴特拉珀瑙', 49.2384800, 9.1018000, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39543, 'Bad Pyrmont', 'Bad Pyrmont', 'Bad Pirmont,Bad Pyrmont,Bad-Pirmont,Petrimons,ba te pi er meng te,bad byrmwnt,bad pyrmwnt,Бад Пирмонт,Бад-Пирмонт,باد بيرمونت,باد پیرمونت,バート・ピルモント,巴特皮尔蒙特', 51.9858900, 9.2524600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39544, 'Bad Orb', 'Bad Orb', 'Bad Orb,Bad-Orb,ba te ao er bu,bad awrb,Бад Орб,Бад-Орб,باد اورب,バート・オルプ,巴特奥尔布', 50.2278800, 9.3478200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39545, 'Bad Oldesloe', 'Bad Oldesloe', 'Bad Oldeslo,Bad Oldesloe,Bad-Ol''deslo,Odislo,ba te ao er de si luo,bad aldzwlh,bad awldzlwh,Бад Олдесло,Бад-Ольдесло,באד אולדסלו,باد أولدزلوه,باد الدزوله,巴特奥尔德斯洛', 53.8116700, 10.3741700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39546, 'Bad Oeynhausen', 'Bad Oeynhausen', 'Bad Oajnkhauzen,Bad Oeyhausen,Bad Oeynhausen,Bad-Ehjnkhauzen,Bad-Ejngauzen,ba te en hao sen,bad awynhawzn,bateuoeinhaujen,Бад Оајнхаузен,Бад-Ейнгаузен,Бад-Эйнхаузен,باد أوينهاوزن,باد اوین‌هاوزن,バート・エーンハウゼン,巴特恩豪森,바트외인하우젠', 52.2069900, 8.8036500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39547, 'Bad Neustadt an der Saale', 'Bad Neustadt an der Saale', 'Bad Neustadt,Bad Neustadt a.d.Saale,Bad Neustadt an der Saale,Bad Nojshtat an der Zale,Bad-Nojshtadt-an-der-Zaale,Bad-Nojshtadt-an-der-Zale,Neustadt,Neustadt an der Saale,bad nwyashtat an dr zalh,sa lei he pan ba te nuo yi shi ta te,Бад Нојштат ан дер Зале,Бад-Нойштадт-ан-дер-Заале,Бад-Нойштадт-ан-дер-Зале,Զաալեի Բադ Նոյշթաթ,باد نوياشتات آن در زاله,باد نوی‌اشتات آن در زاله,萨勒河畔巴特诺伊施塔特', 50.3217400, 10.2067300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39548, 'Bad Neuenahr-Ahrweiler', 'Bad Neuenahr-Ahrweiler', 'Bad Neuenahr-Ahrweiler,Bad Nojenar-Arvajler,Bad-Nojenar-Arvajler,Stadt Bad Neuenahr-Ahrweiler,ba te nuo yin a er-a er wei lei,bad nwynar-arfaylr,Бад Нойенар-Арвайлер,Бад Нојенар-Арвајлер,Бад-Нойенар-Арвайлер,باد نوينار-آرفايلر,باد نوین‌آر-آروایلار,バート・ノイェンアール＝アールヴァイラー,巴特诺因阿尔-阿尔韦勒', 50.5432200, 7.1113000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39549, 'Bad Nenndorf', 'Bad Nenndorf', 'Bad Nendorf,Bad Nenndorf,Bad Neundorf,Bad-Nendorf,ba te nen duo fu,bad nndwrf,Бад Нендорф,Бад-Нендорф,باد نندورف,バート・ネンドルフ,巴特嫩多夫', 52.3370300, 9.3790400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39550, 'Bad Nauheim', 'Bad Nauheim', 'Bad Naukhajm,Bad-Naukhajm,Stadt Bad Nauheim,ba de nao hai mu,bad nwahaym,Бад Наухајм,Бад-Наухайм,باد نواهایم,巴德瑙海姆', 50.3646300, 8.7385900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39551, 'Bad Muskau', 'Bad Muskau', 'Bad Muskau,Bad Muskau/Muzakow,Bad Muskau/Mužakow,Bad-Muskau,Badmuskava,Bādmuskava,Hora,Muscavia,Muskau,Muskau Bad,Muzakow,Muzaków,Mużaków,Mužakow,ba te mu si kao,bad mwskaw,Бад Мускау,Бад-Мускау,باد موسكاو,باد موسکاو,巴特穆斯考', 51.5505100, 14.7124000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39552, 'Bad Münstereifel', 'Bad Muenstereifel', 'Bad Minsterajfel,Bad Muenstereifel,Bad Munstereifel,Bad Münstereifel,Bad-Mjunsterajfel'',Munstereifel,Münstereifel,ba te ming si te ai fei er,bad mwnstr ayfl,bad mwnstrrayfl,bateumwinseuteoaipel,Бад Минстерајфел,Бад-Мюнстерайфель,باد مونستر آيفل,باد مونستررایفل,巴特明斯特艾费尔,바트뮌스터아이펠', 50.5566700, 6.7642400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39553, 'Bad Münster am Stein-Ebernburg', 'Bad Muenster am Stein-Ebernburg', 'Bad Minster am Shtajn-Ebernburg,Bad Munster,Bad Munster am Stein-Ebernburg,Bad Munster-Ebernburg,Bad Münster,Bad Münster am Stein-Ebernburg,Bad Münster-Ebernburg,Bad-Mjunster-na-Shtajn-Ehbernburge,Ebernburg,bad mwnsr an dr ashtayn-arnbwrg,bad mwnstr am shtayn-abrnbwrgh,shi tai yin-ai bo en bao de qu ba te ming si te,Бад Минстер ам Штајн-Ебернбург,Бад-Мюнстер-на-Штайн-Эбернбурге,Штайн-Эбернбургдагы Бад-Мүнстөр,باد مونستر آم شتاين-إبرنبورغ,باد مونسر آن در اشتاین-ارنبورگ,施泰因-埃伯恩堡地区巴特明斯特', 49.8115900, 7.8452300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39554, 'Bad Münder am Deister', 'Bad Muender am Deister', 'Bad Minder am Dajster,Bad Muender,Bad Munder,Bad Munder am Deister,Bad Münder,Bad Münder am Deister,Bad-Mjunder-am-Dajster,Munder am Deister,Munimeri,Münder am Deister,bad mwndr,bad mwndr an dr daystr,dai si te er shan lu ba de ming de er,mundera,Бад Миндер ам Дајстер,Бад-Мюндер-ам-Дайстер,باد موندر,باد موندر آن در دایستر,मुंडेर,バート・ミュンダー・アム・ダイスター,代斯特尔山麓巴德明德尔', 52.1955100, 9.4642100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39555, 'Bad Mergentheim', 'Bad Mergentheim', 'Bad Mergentheim,Bad Mergentheimas,Bad Mergentkhajm,Bad-Mergentgajm,Bad-Mergentkhajm,ba te mei er gen te hai mu,bad mrghnthaym,Бад Мергентхайм,Бад Мергентхајм,Бад-Мергентгайм,Бад-Мергентхайм,باد مرغنتهايم,باد مرگنت‌هایم,バート・メルゲントハイム,巴特梅尔根特海姆', 49.4925000, 9.7736100, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39556, 'Bad Meinberg', 'Bad Meinberg', 'curia Meginbergen [a. 978]', 51.8958800, 8.9831300, 'DE', '2011-11-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39557, 'Bad Marienberg', 'Bad Marienberg', 'Bad Marienberg,Bad Marinberg,Bad-Marienberg,Marienberg,ba te ma lin bei ge,bad marynbrg,bad marynbrgh,Бад Маринберг,Бад-Мариенберг,باد مارينبرغ,باد مارینبرگ,バート・マリーエンベルク,巴特马林贝格', 50.6494700, 7.9495800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39558, 'Bad Lippspringe', 'Bad Lippspringe', 'Bad Lippspringe,Bad Lipspringe,Bad-Lippshpringe,Bad-Lipshpringe,Lippspringe,ba te li pu shi pu ling ge,bad lybshbrynghh,Бад Липспринге,Бад-Липшпринге,Бад-Ліппшпрінге,باد ليبشبرينغه,باد لیپ‌اسپرینگه,巴特利普施普灵格', 51.7833300, 8.8168300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39559, 'Bad Liebenzell', 'Bad Liebenzell', 'Bad Libencel,Bad Liebenzell,Bad-Libencell'',Gorad Bad-Libencehl'',ba te li ben cai er,bad lybntsl,Бад Либенцел,Бад-Либенцелль,Бад-Лібенцелль,Горад Бад-Лібенцэль,Բադ Լիբենցել,باد ليبنتسل,باد لیبن‌زل,巴特利本采尔', 48.7742700, 8.7297100, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39560, 'Bad Liebenwerda', 'Bad Liebenwerda', 'Bad Libenverda,Bad Liebenwerda,Bad-Libenverda,Liebenwerda,Rukow,ba te li ben wei da,bad lybnfyrda,Бад Либенверда,Бад-Либенверда,Բադ Լիբենվերդա,باد ليبنفيردا,باد لیبن‌وردا,巴特利本韦达', 51.5182600, 13.3945900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39561, 'Bad Liebenstein', 'Bad Liebenstein', 'Bad Libenshtajn,Bad Liebenstein,Bad-Libenshtajn,ba de li ben si tai yin,Бад Либенштајн,Бад-Либенштайн,باد لیبن‌اشتاین,巴德利本斯泰因', 50.8156900, 10.3512300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39562, 'Bad Lauterberg im Harz', 'Bad Lauterberg im Harz', 'Aquae Lauterbergenses in Harthicis montibus,Bad Lauterberg,Bad Lauterberg im Harz,Bad Lauterberg im Kharc,Bad-Lauterberg,Lauterberg,bad lawtrbrgh,bad lwatrbrg dr harz,ha ci shan qu ba te lao te bei ge,Бад Лаутерберг,Бад Лаутерберг им Харц,Бад-Лаутерберг,باد لاوتربرغ,باد لواتربرگ در هارز,哈茨山区巴特劳特贝格', 51.6327200, 10.4703100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39563, 'Bad Lausick', 'Bad Lausick', 'Bad Lauzik,Bad-Lauzik,Badlauzika,Bādlauzika,ba te lao xi ke,bad lawzyk,bad lwasyk,Бад Лаузик,Бад-Лаузик,باد لاوزيك,باد لواسیک,巴特劳西克', 51.1449500, 12.6444900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39564, 'Bad Lauchstädt', 'Bad Lauchstaedt', 'Bad Lauchstadt,Bad Lauchstaedt,Bad Lauchstedt,Bad Lauchstädt,Bad Laukhshtet,Bad-Laukhshtedt,Bad-Laukstedt,Lauchstadt,Lauchstaedt,ba te lao he shi tai te,bad lawkhshtyt,Бад Лаухштет,Бад-Лаукстедт,Бад-Лаухштедт,باد لاوخشتيت,باد لواخ‌اشتت,巴特劳赫施泰特', 51.3865200, 11.8695600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39565, 'Bad Langensalza', 'Bad Langensalza', 'Bad Langensalza,Bad Langenzalca,Bad-Langenzal''ca,Langensalza,ba te lang gen sa er cha,bad langhnzaltsa,Бад Лангензалца,Бад-Лангензальца,باد لانغنزالتسا,باد لانگن‌زاسا,巴特朗根萨尔察', 51.1077100, 10.6460000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39566, 'Bad Krozingen', 'Bad Krozingen', 'Bad Krocingen,Bad-Krocingen,ba te ke luo qing gen,bad krwtsynghn,bad krwzyngn,Бад Кроцинген,Бад-Кроцинген,Бад-Кроцінген,Բադ Կրոցինգեն,باد كروتسينغن,باد کروزینگن,巴特克罗青根', 47.9166700, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39567, 'Bad Kreuznach', 'Bad Kreuznach', 'Bad Kreuznach,Bad Krojcnakh,Bad-Krojcnakh,Cruciniacum,Kreuznach,ba te ke luo yi ci na he,bad krwytsnakh,Бад Кройцнах,Бад Кројцнах,Бад-Кройцнах,باد كرويتسناخ,باد کرویتسناخ,バート・クロイツナハ,巴特克罗伊茨纳赫', 49.8414000, 7.8671300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39568, 'Bad Köstritz', 'Bad Koestritz', 'Bad Kestric,Bad Koestritz,Bad Kostritz,Bad Köstritz,Bad-Kjostric,Gorad Bad-Kjostryc,Kostritz,Köstritz,ba te ke si te li ci,bad kwstryts,bad kwstrytz,Бад Кестриц,Бад-Кёстриц,Бад-Көстриц,Горад Бад-Кёстрыц,باد كوستريتس,باد کوستریتز,巴特克斯特里茨', 50.9303200, 12.0100500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39569, 'Bad Kösen', 'Bad Koesen', 'Bad Kezen,Bad Kosen,Bad Kösen,Bad-Kjozen,Cusne,Kosen,Kösen,Бад Кезен,Бад-Кёзен,Бад-Көзен,バート・ケーゼン', 51.1343100, 11.7220300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39570, 'Bad König', 'Bad Koenig', 'Bad K''onig,Bad Kenig,Bad Koenig,Bad Konig,Bad König,Bad-Kenig,Bad-Kjonig,Gorad Bad-Kjonig,Konig,König,ba te ke ni xi,bad kwnygh,bad kwnysh,Бад Кениг,Бад Кьониг,Бад-Кеніг,Бад-Кёниг,Бад-Көниг,Горад Бад-Кёніг,باد كونيغ,باد کونیش,バート・ケーニヒ,巴特柯尼希', 49.7432000, 9.0075000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39571, 'Bad Kohlgrub', 'Bad Kohlgrub', 'Bad Kolgrub,Bad-Kol''grub,ba te ke er ge lu bu,bad kwlgrwb,Бад Колгруб,Бад-Кольгруб,Բադ Կոլգրուբ,باد کولگروب,巴特科尔格鲁布', 47.6666700, 11.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39572, 'Bad Klosterlausnitz', 'Bad Klosterlausnitz', 'Bad Klosterlausnic,Bad Klosterlausnitz,Bad-Klosterlausnic,Klosterlausnitz,ba de ke luo si te er lao si ni ci,Бад Клостерлаусниц,Бад-Клостерлаусниц,巴德克洛斯特尔劳斯尼茨', 50.9166700, 11.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39573, 'Bad Kleinen', 'Bad Kleinen', 'Bad Klajnen,Bad Kleinen,Bad-Klajnen,Kleinen,ba te ke lai nen,Бад Клајнен,Бад-Клайнен,巴特克莱嫩', 53.7713400, 11.4716500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39574, 'Bad Kissingen', 'Bad Kissingen', 'Bad Kisingen,Bad Kissingen,Bad-Kissingen,Gorad Bad-Kisingen,ba te ji xin gen,bad kysynghn,bad kysyngn,Бад Кисинген,Бад-Киссинген,Бад-Кіссінген,Горад Бад-Кісінген,Բադ Կիսինգեն,باد كيسينغن,باد کیسینگن,بیڈ کسنجن,巴特基辛根', 50.2022800, 10.0778400, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39575, 'Bad Iburg', 'Bad Iburg', 'Bad Iburg,Bad-Iburg,Gorad Bad-Iburg,Ibig,ba te yi bao,bad aybwrg,bad aybwrgh,Бад Ибург,Бад-Ибург,Горад Бад-Ібург,باد إيبورغ,باد ایبورگ,巴特伊堡', 52.1549000, 8.0421600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39576, 'Bad Hönningen', 'Bad Hoenningen', 'Bad Hoenningen,Bad Honningen,Bad Hönningen,Bad Kheningen,Bad-Khjonningen,Honningen,Hönningen,ba te heng ning gen,bad hwnynghn,bad hwnyngn,Бад Хенинген,Бад-Хённинген,Бад-Хөннинген,باد هونينغن,باد هونینگن,バート・ヘニンゲン,巴特亨宁根', 50.5168900, 7.3119500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39577, 'Bad Honnef', 'Bad Honnef', 'Bad Honnef,Bad Honnef am Rhein,Bad Khonef,Bad-Gonnef,Bad-Khonnef,Honnef,Hunapha,ba te hong nei fu,bad hwnf,bad hwnyf,Бад Хонеф,Бад-Гоннеф,Бад-Хоннеф,باد هونف,باد هونيف,巴特洪内夫', 50.6433600, 7.2278000, 'DE', '2016-09-27', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39578, 'Bad Homburg vor der Höhe', 'Bad Homburg vor der Hoehe', 'Bad Homburg,Bad Homburg v.d. Hoehe,Bad Homburg v.d. Höhe,Bad Homburg vor der Hoehe,Bad Homburg vor der Höhe,Bad Khomburg,Bad-Gomburg,Bad-Khomburg,Bant Chompournk,Gorad Bad-Khomburg,Homburg vor der Hohe,Homburg vor der Höhe,ba te hong bao,bad h xm bur kf xrde xr hex xex,bad hwmbwrg fwr dr hwhh,bateuhombuleukeupo-eodeeohoee,Μπαντ Χόμπουργκ,Бад Хомбург,Бад-Гомбург,Бад-Хомбург,Горад Бад-Хомбург,באד הומבורג,باد هومبورگ فور در هوهه,บัดฮอมบูร์กฟอร์เดอร์เฮอเออ,巴特洪堡,바트홈부르크포어데어회에', 50.2268300, 8.6181600, 'DE', '2014-01-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39579, 'Bad Hersfeld', 'Bad Hersfeld', 'Bad Hersfeld,Bad Khersfeld,Bad-Gersfel''d,Bad-Khersfel''d,Gorad Bad-Khersfel''d,Hersfeld,ba te hei si fei er de,bad hrsfld,Бад Херсфелд,Бад-Герсфельд,Бад-Херсфельд,Горад Бад-Херсфельд,باد هرسفلد,巴特黑斯费尔德', 50.8719700, 9.7089100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39580, 'Bad Herrenalb', 'Bad Herrenalb', 'Bad Herenalb,Bad Herrenalb,Bad Kherenalb,Bad-Gerrenal''b,Bad-Kherrenal''b,Herrenalb,ba te hei lun a er bu,bad hyrnalb,Бад Хереналб,Бад-Герренальб,Бад-Херренальб,Բադ Հերենալբ,باد هررن‌آلب,باد هيرنآلب,巴特黑伦阿尔布', 48.7978700, 8.4361700, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39581, 'Bad Heilbrunn', 'Bad Heilbrunn', 'Bad Haylbrun,Bad Khajlbrun,Bad-Gajl''brunn,Bad-Khajl''brunn,Heilbrunn,ba te hai er bu lun,Бад Хајлбрун,Бад-Гайльбрунн,Бад-Хайльбрунн,Բադ Հայլբրուն,巴特海尔布伦', 47.7467100, 11.4593400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39582, 'Bad Harzburg', 'Bad Harzburg', 'Bad Harzborch,Bad Harzburg,Bad Kharcburg,Bad-Garcburg,Bad-Kharcburge,Hartsburgum,Stadt Bad Harzburg,ba te ha er ci bao,bad haghzbwrgh,bad hartsbwrg,Бад Харцбург,Бад-Гарцбург,Бад-Харцбурге,باد هارتسبورگ,باد هاغزبورغ,巴特哈尔茨堡', 51.8826800, 10.5615700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39583, 'Bad Grund', 'Bad Grund', 'Bad Grund,Bad-Grund,ba te ge lun de,bad ghrwnd,bad grwnd,Бад Грунд,Бад-Грунд,باد غروند,باد گروند,巴特格伦德', 51.8102100, 10.2369400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39584, 'Bad Gandersheim', 'Bad Gandersheim', 'Bad Gandersheim,Bad Ganderskhajm,Bad-Ganderskhajm,Gandersheim,Gandershemium,Ganderssen,ba te gan de si hai mu,bad gandrshaym,bad ghandrshaym,Бад Гандерсхайм,Бад Гандерсхајм,Бад-Гандерсхайм,باد غاندرسهايم,باد گاندرسهایم,バート・ガンダースハイム,巴特甘德斯海姆', 51.8716700, 10.0253700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39585, 'Bad Freienwalde', 'Bad Freienwalde', 'Bad Frajenvalde,Bad Frajnvalde,Bad Frayenvalde,Bad-Frajenval''de,Freienwalde,Freienwaldum,Gorad Bad-Fraenval''deh,ba te fu lai en wa er de,bad fraynfaldh,Бад Фрајенвалде,Бад Фрајнвалде,Бад-Фрайенвальде,Горад Бад-Фраенвальдэ,Բադ Ֆրայենվալդե,باد فراينفالده,باد فراین‌والده,巴特弗赖恩瓦尔德', 52.7873000, 14.0304000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39586, 'Bad Frankenhausen', 'Bad Frankenhausen', 'Bad Frankenhausen,Bad Frankenhausen/Kyffhaeuser,Bad Frankenhausen/Kyffhäuser,Bad Frankenkhauzen,Bad-Frankenkhauzen-Kifkhojzer,Francohusium,Frankenhausen,ba te fu lan ken hao sen,bad franknhawzn,Бад Франкенхаузен,Бад-Франкенхаузен-Кифхойзер,باد فرانكنهاوزن,باد فرانکن‌هاوزن/کیفرهویزر,巴特弗兰肯豪森', 51.3560900, 11.0997700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39587, 'Bad Feilnbach', 'Bad Feilnbach', 'Bad Fajlnbakh,Bad Faylnbax,Bad Feilnboch,Bad-Fajl''nbakh,Feilnbach,ba te fa yi er en ba he,bad faylnbakh,Бад Фајлнбах,Бад-Файльнбах,Բադ Ֆայլնբախ,باد فایلنباخ,巴特法伊尔恩巴赫', 47.7733100, 12.0097300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39588, 'Bad Essen', 'Bad Essen', 'Bad Esen,Bad Essen,Bad-Ehssen,ba te ai sen,Бад Есен,Бад-Эссен,巴特埃森', 52.3166700, 8.3333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39589, 'Badenweiler', 'Badenweiler', 'Badehnvajler,Badenvajler,Badenvayler,ba deng wei lei,badenvaileri,Баденвайлер,Баденвајлер,Бадэнвайлер,Բադենվայլեր,ბადენვაილერი,巴登韦勒', 47.8022300, 7.6723600, 'DE', '2013-03-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39590, 'Badenheim', 'Badenheim', '', 49.8333300, 7.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39591, 'Badenhausen', 'Badenhausen', 'Badenkhauzen,ba deng hao sen,Баденхаузен,巴登豪森', 51.7699600, 10.2049300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39592, 'Badenhard', 'Badenhard', '', 50.1166700, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39593, 'Badendorf', 'Badendorf', '', 53.8666700, 10.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39594, 'Baden-Baden', 'Baden-Baden', 'Aquae Aureliae,Baden,Baden-Baden,Badenas-Badenas,Badenbadene,Banten-Banten,Bādenbādene,FKB,Gorad Badehn-Badehn,b+b,ba deng-ba deng,baden=baden,badenbaden,badn badn,badn-badn,Μπάντεν-Μπάντεν,Баден-Баден,Горад Бадэн-Бадэн,Բադեն-Բադեն,באדן-באדן,بادن بادن,بادن-بادن,バーデン＝バーデン,巴登-巴登,바덴바덴', 48.7606000, 8.2397500, 'DE', '2013-05-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39595, 'Bad Ems', 'Bad Ems', 'Bad Ems,Bad-Ehms,Bad-Ems,Ems,ba te ai mu si,bad ams,Бад Емс,Бад-Емс,Бад-Эмс,בד אמס,باد إمس,باد امس,バート・エムス,巴特埃姆斯', 50.3354400, 7.7136900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39596, 'Badem', 'Badem', '', 50.0000000, 6.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39597, 'Bad Elster', 'Bad Elster', 'Bad Elster,Bad-Ehl''ster,Bad-El''ster,Badelstere,Bādelstere,ba te ai er si te,bad alstr,Бад Елстер,Бад-Ельстер,Бад-Эльстер,باد إلستر,باد الستر,巴特埃尔斯特', 50.2819200, 12.2343000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39598, 'Bad Eilsen', 'Bad Eilsen', 'Bad Ajlzen,Bad Eilsen,Bad-Ajl''zen,Eilsen,ba te ai er sen,Бад Ајлзен,Бад-Айльзен,バート・アイルゼン,巴特艾尔森', 52.2421500, 9.0982200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39599, 'Bad Dürrheim', 'Bad Durrheim', 'Bad Dirkhajm,Bad Duerrheim,Bad Durrheim,Bad Dürrheim,Bad-Djurkhajm,Bad-Djurrgajm,Durrheim,Dürrheim,ba te di er hai mu,bad dwrhaym,Бад Дирхајм,Бад-Дюрргайм,Бад-Дюрхайм,باد دورهايم,باد دورهایم,巴特迪尔海姆', 48.0209300, 8.5305600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39600, 'Bad Dürrenberg', 'Bad Duerrenberg', 'Bad Direnberg,Bad Duerrenberg,Bad Durrenberg,Bad Dürrenberg,Bad-Djurrenberg,Durrenberg,Dürrenberg,ba te di lun bei ge,bad dwrnbrg,bad dwrnbrgh,Бад Диренберг,Бад-Дюрренберг,باد دورنبرغ,باد دورنبرگ,巴特迪伦贝格', 51.2954500, 12.0658300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39601, 'Bad Dürkheim', 'Bad Duerkheim', 'Bad Dirkkhajm,Bad Djurkkhajm,Bad Duerkheim,Bad Durkheim,Bad Dürkheim,Bad-Djurkkhajm,Derkem,Durkheim,Dürkheim,ba te di ke hai mu,bad dwrkhaym,Бад Диркхајм,Бад Дюркхайм,Бад-Дюркхайм,Бад-Дүркхайм,باد دوركهايم,باد دورک‌هایم,バート・デュルクハイム,巴特迪克海姆', 49.4618000, 8.1723600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39602, 'Bad Düben', 'Bad Dueben', 'Bad Diben,Bad Duben,Bad Dueben,Bad Düben,Bad-Djuben,Badibene,Bādībene,Duben,Düben,ba te di ben,bad dwbn,Бад Дибен,Бад-Дюбен,باد دوبن,巴特迪本', 51.5917400, 12.5849200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39603, 'Bad Driburg', 'Bad Driburg', 'Bad Driburg,Bad-Driburg,ba te de li bao,bad drbwrg,bad drbwrgh,Бад Дрибург,Бад-Дрибург,Бад-Дрібург,باد دربورغ,باد دربورگ,バート・ドリーブルク,巴特德里堡', 51.7329700, 9.0196900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39604, 'Bad Doberan', 'Bad Doberan', 'Bad Doberan,Bad-Doberan,Baddoberana,Bāddoberāna,Doberan,Doberanum,ba te duo bo lan,bad dwbran,Бад Доберан,Бад-Доберан,باد دوبران,巴特多伯兰', 54.1071200, 11.9005100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39605, 'Bad Ditzenbach', 'Bad Ditzenbach', 'Bad Dicenbakh,Bad-Ditcenbakh,ba te di cen ba he,Бад Диценбах,Бад-Дитценбах,Бад-Дітценбах,巴特迪岑巴赫', 48.5883000, 9.7039300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39606, 'Baddeckenstedt', 'Baddeckenstedt', 'Baddekkenshtedt,Badekenshtet,ba dai ken shi tai te,Баддеккенштедт,Бадекенштет,巴代肯施泰特', 52.0833300, 10.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39607, 'Bad Buchau', 'Bad Buchau', 'Bad Buchau,Bad Bukhau,Bad Buxau,Bad-Bukhau,Buchau,Buchau am Federsee,ba te bu hao,bad bwkhaw,bad bwsha,bad-bukhau,Бад Бухау,Бад-Бухау,Բադ Բուխաու,باد بوخاو,باد بوشا,ბად-ბუხაუ,巴特布豪', 48.0623100, 9.6124400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39608, 'Bad Brückenau', 'Bad Bruckenau', 'Bad Brikenau,Bad Brueckenau,Bad Brückenau,Bad-Brjukkenau,Bruckenau,Brückenau,ba te bu lu ke nao,bad brwknaw,bad brwknwa,Бад Брикенау,Бад-Брюккенау,Բադ Բրյուքենաու,באד בריקנאו,باد بروكناو,باد بروکنوا,بیڈ بروکیناؤ,巴特布吕克瑙', 50.3085300, 9.7898500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39609, 'Bad Breisig', 'Bad Breisig', 'Bad Brajzig,Bad Breisig,Bad Breissig,Bad-Brajzig,ba te bu lai xi xi,bad brayzyg,bad brayzygh,Бад Брајзиг,Бад-Брайзиг,باد برايزيغ,باد برایزیگ,バート・ブライジク,巴特布赖西希', 50.5052300, 7.2886100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39610, 'Bad Bramstedt', 'Bad Bramstedt', 'Bad Bramshtet,Bad Bramstedt,Bad-Bramshtedt,ba te bu la mu shi tai te,bad bramshtyt,Бад Брамштет,Бад-Брамштедт,باد برامشتيت,باد برام‌اشتت,巴特布拉姆施泰特', 53.9183000, 9.8842400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39611, 'Bad Brambach', 'Bad Brambach', 'Bad Brambach,Brambach', 50.2166700, 12.3166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39612, 'Bad Bocklet', 'Bad Bocklet', 'Bad Bocklet,Bad Boklet,Bad-Boklet,ba te bo ke lai te,Бад Боклет,Бад-Боклет,Բադ Բոկլետ,巴特博克莱特', 50.2664800, 10.0790200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39613, 'Bad Blankenburg', 'Bad Blankenburg', 'Bad Blankenburg,Bad-Blankenburg,ba te bu lan ken bao,bad blnknbwrg,bad blnknbwrgh,Бад Бланкенбург,Бад-Бланкенбург,باد بلنكنبورغ,باد بلنکنبورگ,巴特布兰肯堡', 50.6818900, 11.2736900, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39614, 'Bad Bibra', 'Bad Bibra', 'Bad Bibra,Bad-Bibra,ba te bi bu la,bad bybra,Бад Бибра,Бад-Бибра,باد بيبرا,باد بیبرا,巴特比布拉', 51.2079600, 11.5851700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39615, 'Bad Bertrich', 'Bad Bertrich', 'Bad Bertrikh,Bad-Bertrikh,ba te bei er te li xi,Бад Бертрих,Бад-Бертрих,巴特贝尔特里希', 50.0666700, 7.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39616, 'Bad Berneck im Fichtelgebirge', 'Bad Berneck im Fichtelgebirge', 'Bad Berneck,Bad Berneck im Fichtelgebirge,Bad Bernek,Bad Bernek im Fikhtelgebirge,Bad-Bernek,Bad-Bernek-im-Fikhtel''gebirge,Bad-Bernekk-im-Fikhtel''gebirge,Berneck,bad brnk aym fyshtlgbyrgh,bad brnyk am fyshtlghbryghh,fei xi te er shan qu ba te bei nei ke,Бад Бернек им Фихтелгебирге,Бад-Бернек,Бад-Бернек-ім-Фіхтельгебірге,Бад-Бернекк-им-Фихтельгебирге,Բադ Բերնեկ,باد برنيك إم فيشتلغبريغه,باد برنک ایم فیشتلگبیرگه,بیڈ برنیک,バート・ベルネック・イム・フィヒテルゲビルゲ,菲希特尔山区巴特贝内克', 50.0456400, 11.6723800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39617, 'Bad Berleburg', 'Bad Berleburg', 'Bad Berleburg,Bad-Berleburg,Berleberg,Berleburg,ba te bei lei bao,bad brlbwrg,bad brlhbwrgh,Бад Берлебург,Бад-Берлебург,باد برلبورگ,باد برلهبورغ,巴特贝勒堡', 51.0522400, 8.3922700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39618, 'Bad Berka', 'Bad Berka', 'Bad Berka,Bad-Berka,ba te bei er ka,bad brka,bad byrka,Бад Берка,Бад-Берка,باد برکا,باد بيركا,巴特贝尔卡', 50.8998200, 11.2824500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39619, 'Bad Bergzabern', 'Bad Bergzabern', 'Bad Bergcabern,Bad Bergzaben,Bad Bergzabern,Bad-Bergcabern,Bergzabern,Tabernae Montanus,ba te bei ge cha bo en,bad byrghtsabrn,Бад Бергцаберн,Бад-Бергцаберн,باد برگ‌زابرن,باد بيرغتسابرن,バート・ベルクツァバン,巴特贝格察伯恩', 49.1024500, 8.0009200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39620, 'Badbergen', 'Badbergen', 'Badbergen,ba te bei er gen,Бадберген,巴特贝尔根', 52.6333300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39621, 'Bad Bentheim', 'Bad Bentheim', 'Bad Bentheim,Bad Bentkhajm,Bad-Bentkhajm,ba te ben te hai mu,badbnthaym,Бад Бентхайм,Бад Бентхајм,Бад-Бентхайм,بادبنتهايم,بادبنتهایم,巴特本特海姆', 52.3006600, 7.1576300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39622, 'Bad Bellingen', 'Bad Bellingen', 'Bad Belingen,Bad Bellingen,Bad-Bellingen,Bellingen,ba te bei lin gen,Бад Белинген,Бад-Беллинген,Бад-Беллінген,巴特贝林根', 47.7314700, 7.5575600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39623, 'Bad Aibling', 'Bad Aibling', 'Aibling,Albling,Bad Ajbling,Bad Aybling,Bad-Ajbling,Epininga,Oabling,ba te ai bu ling,bad ayblyng,bad ayblyngh,Бад Ајблинг,Бад-Айблинг,Бад-Айблінг,Բադ Այբլինգ,باد آيبلينغ,باد آیبلینگ,بیڈ ابلنگ,巴特艾布灵', 47.8638000, 12.0105500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39624, 'Bad Abbach', 'Bad Abbach', 'Abach,Abacum,Abbach,Bad Abakh,Bad Abax,Bad Abbach,Bad-Abbakh,ba te a ba he,bad abakh,Бад Абах,Бад-Аббах,Բադ Աբախ,باد آباخ,巴特阿巴赫', 48.9375400, 12.0449400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39625, 'Backnang', 'Backnang', 'Backnang,Baknang,ba ke nan,baknang,baknangh,Бакнанг,باكنانغ,باکنانگ,巴克南', 48.9474300, 9.4371800, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39626, 'Bächingen an der Brenz', 'Bachingen an der Brenz', 'Bachingen,Baechingen,Bekhingen,Bekhingen an der Brenc,Bekhingen-an-der-Brenc,Bächingen,bshyngn,Бехинген ан дер Бренц,Бехинген-ан-дер-Бренц,Бехінген,Բրենցի Բեխինգեն,بشینگن', 48.5462700, 10.3128100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39627, 'Bachhagel', 'Bachhagel', 'Bakhgagel'',Bakhkhagel,Bakhkhagel'',Baxhagel,ba ha ge er,bakhhagl,Бахгагель,Баххагел,Баххагель,Բախհագել,باخهاگل,巴哈格尔', 48.6321700, 10.3204500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39628, 'Bachfeld', 'Bachfeld', '', 50.4166700, 10.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39629, 'Bachenberg', 'Bachenberg', '', 50.7166700, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39630, 'Bacharach', 'Bacharach', 'Bacharach,Bakharakh,ba ha la,bahharahha,bakharakh,bkrk,Бахарах,בכרך,باخاراخ,باخ‌آراخ,バッハラッハ,巴哈拉', 50.0572500, 7.7694800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39631, 'Bach', 'Bach', '', 49.4000000, 12.3833300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39632, 'Babensham', 'Babensham', 'Babensgam,Babensham,Babenskham,ba ben si ha mu,babnsham,Бабенсгам,Бабенсхам,Բաբենսհամ,بابنسهام,巴本斯哈姆', 48.0833300, 12.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39633, 'Babenhausen', 'Babenhausen', 'Babenhausen,Babenkhauzen,ba ben hao sen,babenhauzen,Бабенхаузен,بابن‌هاوزن,バーベンハウゼン,巴本豪森', 49.9651900, 8.9512900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39634, 'Babenhausen', 'Babenhausen', 'Babengauzen,Babenhausen,Babenhauzen,Babenkhauzen,ba ben hao sen,Бабенгаузен,Бабенхаузен,Բաբենհաուզեն,巴本豪森', 48.1449700, 10.2532500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39635, 'Baalberge', 'Baalberge', 'Baalberge', 51.7646900, 11.7988000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39636, 'Aystetten', 'Aystetten', 'Ajshteten,Ajshtetten,Aysteten,ai si te teng,aywshttn,Айштеттен,Ајштетен,Այշտետեն,آیوشتتن,艾斯特滕', 48.4055600, 10.7774200, 'DE', '2012-11-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39637, 'Ayl', 'Ayl', '', 49.6333300, 6.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39638, 'Aying', 'Aying', 'Aing,Ajing,Aying,ai yin ge,aiingi,ayyng,Айинг,Аїнг,Ајинг,Այինգ,آیینگ,აიინგი,艾因格', 47.9701000, 11.7775200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39639, 'Axstedt', 'Axstedt', 'Aksshtedt,Aksshtet,Ax,a ke si si te,Аксштедт,Аксштет,阿克斯斯特', 53.3546600, 8.7748500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39640, 'Averlak', 'Averlak', 'Averlak', 53.9398200, 9.1841800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39641, 'Aventoft', 'Aventoft', 'Aventoft', 54.9000000, 8.8166700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39642, 'Auufer', 'Auufer', 'Auufer', 53.9241600, 9.6830200, 'DE', '2011-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39643, 'Außernzell', 'Aussernzell', 'Auserncel,Auserncel'',Auserncell'',Ausserncell'',ao sai er en ce er,awsrnzl,Аусернцел,Аусернцелль,Аусернцель,Ауссернцелль,Աուսերնցել,اوسرنزل,奥塞尔恩策尔', 48.7240900, 13.2029100, 'DE', '2012-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39644, 'Ausleben', 'Ausleben', 'Ausleben,ao si lai ben,Ауслебен,奥斯莱本', 52.0904900, 11.1119200, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39645, 'Ausacker', 'Ausacker', 'Ausacker', 54.7333300, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39646, 'Aurich', 'Aurich', 'Auerk,Auriacum,Aurich,Aurichas,Aurikh,Aurk,Auwerk,ao li xi,awrysh,Аурих,آوريش,آوریش,奥里希', 53.4691900, 7.4823200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39647, 'Aura im Sinngrund', 'Aura im Sinngrund', 'Aura,Aura im Sinngrund,Aura im Zingrund,Aura-im-Zingrund,Aura-im-Zinngrund,Zingrundi Aura,Аура им Зингрунд,Аура-им-Зингрунд,Аура-ім-Зіннгрунд,Զինգրունդի Աուրա', 50.1781900, 9.5754700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39648, 'Aurach', 'Aurach', 'Aurach (Bayern)', 49.2500000, 10.4166700, 'DE', '2016-07-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39649, 'Aumühle', 'Aumuhle', 'Aumuehle,Aumuhle,Aumühle', 53.5333300, 10.3166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39650, 'Auma', 'Auma', 'Auma,awma,Аума,آوما', 50.7004400, 11.8995800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39651, 'Aull', 'Aull', '', 50.3855600, 8.0019400, 'DE', '2017-03-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39652, 'Aulendorf', 'Aulendorf', 'Aulendorf,ao lun duo fu,awlndwrf,Аулендорф,آولندورف,奥伦多夫', 47.9508300, 9.6374500, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39653, 'Auleben', 'Auleben', '', 51.4264000, 10.9296800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39654, 'Au in der Hallertau', 'Au in der Hallertau', 'Au,Au bei Ambs,Au in da Holledau,Au in der Hallertau,Au u Khalertauu,Au-in-der-Gallertau,Au-in-der-Khallertau,Halertaui Au,aw ayn dr halrtaw,Ау у Халертауу,Ау-ин-дер-Халлертау,Ау-ін-дер-Галлертау,Հալերտաուի Աու,آو این در هالرتاو', 48.5583800, 11.7413800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39655, 'Auhausen', 'Auhausen', 'Augauzen,Auhauzen,Aukhauzen,ao hao sen,auhauzen,Аугаузен,Аухаузен,Աուհաուզեն,アウハウゼン,奥豪森', 49.0079000, 10.6224000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39656, 'Auhagen', 'Auhagen', 'Aukhagen,ao ha gen,auhagen,Аухаген,アウハーゲン,奥哈根', 52.3982800, 9.2919400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39657, 'Augustusburg', 'Augustusburg', 'Augustusburg,Augustusburga,Augustusburgas,Avgustusburg,aghwstwsbwrgh,agwstwsbwrg,ao gu si tu si bao,Августусбург,Аугустусбург,آغوستوسبورغ,آگوستوسبورگ,奥古斯图斯堡', 50.8119200, 13.1019700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39658, 'Augustdorf', 'Augustdorf', 'Augustdorf,ao gu si duo fu,augusutodorufu,Аугустдорф,アウグストドルフ,奥古斯多夫', 51.9094400, 8.7317300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39659, 'Augsburg', 'Augsburg', 'AGY,Agsborg,Aounksmpournk,Augsberg,Augsboerj,Augsborg,Augsbourg,Augsburg,Augsburga,Augsburgas,Augsburgo,Augsbörj,Augschburg,Augusta,Augusta Vindelicorum,Augzburg,Auqsburq,Gorad Augsburg,a''ugsaburga,agzbrg,ao ge si bao,aucupurku,augsburga,augsburgi,augusuburuku,aukeuseubuleukeu,aukusuburuku,awghsbwrgh,awgsbwrg,xea k sburk,Ágsborg,Άουγκσμπουργκ,Аугзбург,Аугсбург,Горад Аўгсбург,אאוגסבורג,آوغسبورغ,آوگسبورگ,اگزبرگ,आउग्सबुर्ग,औग्स्बुर्ग,আউগ্‌সবুর্গ,ஔசுபூர்கு,เอาก์สบูร์ก,აუგსბურგი,アウクスブルク,アウグスブルク,奥格斯堡,아우크스부르크', 48.3715400, 10.8985100, 'DE', '2016-02-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39660, 'Auggen', 'Auggen', 'Augen,Auggen,ao gen,augeni,Аугген,Ауген,Աուգեն,აუგენი,奥根', 47.7833300, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39661, 'Aufseß', 'Aufsess', 'Aufses,Aufzes,ao fu sai si,aufuzesu,Ауфзес,Ауфсес,Աուֆզես,アウフゼス,奥夫塞斯', 49.8837000, 11.2269200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39662, 'Aufhausen', 'Aufhausen', 'Aufgauzen,Aufhauzen,Aufkhauzen,ao fu hao sen,awfhawzn,Ауфгаузен,Ауфхаузен,Աուֆհաուզեն,آوفهاوزن,奥夫豪森', 48.8720500, 12.2821000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39663, 'Auerbach', 'Auerbach', '', 50.6833300, 12.9166700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39664, 'Auerbach', 'Auerbach', 'Auerbach', 50.5115500, 12.4008300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39665, 'Auerbach', 'Auerbach', 'Auehrbakh,Auerbach,Auerbach in der Oberpfalz,Aurbach,Ауэрбах', 49.6920100, 11.6332700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39666, 'Auerbach', 'Auerbach', '', 48.8035300, 13.0995200, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39667, 'Auen', 'Auen', 'Auehn,Auen,ao en,Ауен,Ауэн,奥恩', 49.8333300, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39668, 'Auel', 'Auel', '', 50.1666700, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39669, 'Aue', 'Aue', 'Aue,Aue-Auerhammer,Aueh,Auje,Aujė,Stadt Aue,ao e,aue,ayw,Ауе,Ауэ,آئو,アウエ,奧厄', 50.5903400, 12.7065700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39670, 'Auderath', 'Auderath', 'Anderath,Auderath', 50.1833300, 7.0000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39671, 'Aubstadt', 'Aubstadt', 'Aubshtadt,Aubshtat,ao bu si ta te,Аубштадт,Аубштат,Աուբշթաթ,奥布斯塔特', 50.3333300, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39672, 'Aub', 'Aub', 'Aub,Aubas,Gorad Aub,ab,aupu,awb,aywb,Ауб,Горад Аўб,Աուբ,آئوب,آوب,اب,アウプ', 49.5526700, 10.0653000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39673, 'Au am Rhein', 'Au am Rhein', 'Au,Au am Rajn,Au am Rhein,Au-am-Rajn,Au-na-Rejne,lai yin he pan ao,Ау ам Рајн,Ау-ам-Райн,Ау-на-Рейне,莱茵河畔奥', 48.9500000, 8.2333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39674, 'Au', 'Au', '', 47.9500000, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39675, 'Atzendorf', 'Atzendorf', 'Atzendorf,Atzendorf (Stassfurt),Atzendorf (Staßfurt)', 51.9195400, 11.5990600, 'DE', '2012-06-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39676, 'Atzelgift', 'Atzelgift', '', 50.7000000, 7.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39677, 'Atting', 'Atting', 'Ating,Atting,a ting ge,atyng,Атинг,Аттинг,Аттінг,آتینگ,阿廷格', 48.8941200, 12.4877600, 'DE', '2012-09-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39678, 'Attenweiler', 'Attenweiler', 'Atenvajler,Attenvajler,a teng wei lei,Атенвајлер,Аттенвайлер,Աթենվայլեր,ატენვაილერი,阿滕韦勒', 48.1333300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39679, 'Attenkirchen', 'Attenkirchen', 'Atenkirkhen,Attenkirkhen,a teng ji er xing,atn kyrshn,Атенкирхен,Аттенкирхен,Аттенкірхен,Աթենկիրխեն,آتن کیرشن,阿滕基尔兴', 48.5052600, 11.7601100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39680, 'Attenhofen', 'Attenhofen', '', 48.6507200, 11.8485000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39681, 'Attenhausen', 'Attenhausen', '', 50.2919700, 7.8755700, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39682, 'Attendorn', 'Attendorn', 'Atendorn,Atendornas,Atenduorns,Attandara,Attendorn,a teng duo er en,atndwrm,atndwrn,Атендорн,Аттендорн,آتندورم,آتندورن,阿滕多尔恩', 51.1264500, 7.9033300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39683, 'Astert', 'Astert', '', 50.6950000, 7.7783300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39684, 'Aßling', 'Assling', 'Asling,Assling,Aßling,a si ling,aslyng,Аслинг,Аслінг,آسلینگ,阿斯灵', 47.9929700, 12.0064300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39685, 'Aßlar', 'Asslar', 'Asslar,Aßlar', 50.5916300, 8.4627300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39686, 'Asselfingen', 'Asselfingen', 'Aselfingen,Assel''fingen,a sai er fen gen,aselpingeni,Аселфинген,Ассельфинген,Ассельфінген,Ասելֆինգեն,ასელფინგენი,阿塞尔芬根', 48.5295900, 10.1916600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39687, 'Assamstadt', 'Assamstadt', 'Asamshtat,Assamshtadt,Assamstadt,Assumstadt,a sa mu si ta te,assamushutatto,Асамштат,Ассамштадт,アッサムシュタット,阿萨姆斯塔特', 49.4280600, 9.6861100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39688, 'Aspisheim', 'Aspisheim', '', 49.9000000, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39689, 'Asperg', 'Asperg', 'Asperg,asbyrgh,asprg,Асперг,آسبيرغ,آسپرگ', 48.9052500, 9.1350200, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39690, 'Asendorf', 'Asendorf', '', 53.2926600, 9.9790500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39691, 'Asendorf', 'Asendorf', '', 52.7721900, 9.0048900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39692, 'Aschheim', 'Aschheim', 'Ashaym,Ashgajm,Ashkhajm,Oscham,a sha yi mu,ashhaym,Ашгайм,Ашхайм,Ашхајм,Աշհայմ,آشهایم,阿沙伊姆', 48.1711200, 11.7167500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39693, 'Aschersleben', 'Aschersleben', 'Ascaria,Ascherslebbe,Aschersleben,Ashersleben,a she er si lai ben,ashrslbn,ashrslybn,Ашерслебен,آشرسلبن,آشرسليبن,阿舍尔斯莱本', 51.7574200, 11.4608400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39694, 'Aschenhausen', 'Aschenhausen', 'Aschenhausen,Ashenkhauzen,a shen hao sen,Ашенхаузен,阿申豪森', 50.6000000, 10.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39695, 'Ascheffel', 'Ascheffel', 'Ascheffel', 54.4333300, 9.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39696, 'Ascheberg', 'Ascheberg', '', 54.1502700, 10.3455200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39697, 'Ascheberg', 'Ascheberg', 'Ascheberg,Asheberg,a she bei ge,Ашеберг,阿舍贝格', 51.7833300, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39698, 'Aschbach', 'Aschbach', 'Ashbakh,a shi ba he,Ашбах,阿施巴赫', 49.6000000, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39699, 'Aschau am Inn', 'Aschau am Inn', 'Aschau,Aschau am Inn,Aschau bei Kraiburg,Ashau am In,Ashau-am-Inn,Innei Asau,ashaw am ayn,yin he pan a shao,Ашау ам Ин,Ашау-ам-Інн,Ашау-ам-Инн,Իննեի Աշաու,آشاو ام این,因河畔阿绍', 48.1984500, 12.3500300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39700, 'Aschaffenburg', 'Aschaffenburg', 'Asafenburga,Asafenmpournk,Aschaffenbourg,Aschaffenburg,Aschaffenburgum,Ashafenburg,Ashaffenburg,Auscheffenburg,Ašafenburga,Gorad Ashafenburg,ZCB,a sha fen bao,ashaffenburuku,ashafnbwrg,ashafnbwrgh,asshyfnbrg,asyapenbuleukeu,Ασάφενμπουργκ,Ашафенбург,Ашаффенбург,Горад Ашафенбург,آشافنبورگ,أشافنبورغ,اسشیفنبرگ,アシャッフェンブルク,阿沙芬堡,아샤펜부르크', 49.9770400, 9.1521400, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39701, 'Ascha', 'Ascha', 'Asha,asha,Аша,آشا', 49.0000000, 12.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39702, 'Asbach', 'Asbach', 'Asbakh,asubahha,Асбах,アスバッハ', 50.6666700, 7.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39703, 'Asbach', 'Asbach', '', 49.8166700, 7.2833300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39704, 'Arzfeld', 'Arzfeld', 'Arcfel''d,Arcfeld,a er ci fei er de,arutsuferuto,Арцфелд,Арцфельд,アルツフェルト,阿尔茨费尔德', 50.0895700, 6.2706900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39705, 'Arzberg', 'Arzberg', 'Arcberg,Арцберг', 51.5288700, 13.1256500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39706, 'Arzberg', 'Arzberg', 'Arzberg', 50.0577400, 12.1867600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39707, 'Arzbach', 'Arzbach', 'Arcbakh,a er ci ba he,Арцбах,阿尔茨巴赫', 50.3790200, 7.7494800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39708, 'Artlenburg', 'Artlenburg', 'Artlenburg,Artlenburgi vald,a er te lun bao,Артленбург,阿尔特伦堡', 53.3718200, 10.4879300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39709, 'Artern', 'Artern', 'Aratora,Artern,Artern/Unstrut,a er te er en,artrn,artrn/awnashtrwt,Артерн,آرترن,آرترن/اوناشتروت,阿尔特尔恩', 51.3643100, 11.2916700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39710, 'Arrach', 'Arrach', 'Arax,Arrakh,Аррах,Արախ', 49.1914900, 12.9938700, 'DE', '2015-02-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39711, 'Arpsdorf', 'Arpsdorf', 'Arpsdorf', 54.0333300, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39712, 'Arpke', 'Arpke', 'Arebeke [a. 1166],Orpke', 52.3859700, 10.1004700, 'DE', '2014-05-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39713, 'Bad Arolsen', 'Bad Arolsen', 'Arothia,Bad Arolsen,Bad Arolzen,Bad-Arol''zen,ba te a luo er sen,bad arwlzn,Бад Аролзен,Бад-Арользен,باد آرولزن,バート・アーロルゼン,巴特阿罗尔森', 51.3798200, 9.0144500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39714, 'Arnstorf', 'Arnstorf', 'Armstorf,Arnstorf,a er en si tuo er fu,arnstwrf,Арнсторф,Արնսթորֆ,آرنستورف,არნსტორფი,阿尔恩斯托尔夫', 48.5584000, 12.8167400, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39715, 'Arnstein', 'Arnstein', 'Arnstein', 49.9776700, 9.9698300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39716, 'Arnstadt', 'Arnstadt', 'Arnestati [a. 704],Arnshhat,Arnshtadt,Arnshtadte,Arnshtat,Arnstadium,Arnstadt,a en shi ta te,arnshtat,Арнштадт,Арнштадте,Арнштат,Арнщат,ארנשטאט,آرنشتات,آرن‌اشتات,阿恩施塔特', 50.8404800, 10.9519800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39717, 'Arnshöfen', 'Arnshofen', '', 50.5405600, 7.8700000, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39718, 'Arnsdorf', 'Arnsdorf', 'Arnsdorf,Arnsdorfi vald,Warnocicy,Warnoćicy,a er en si duo fu,Арнсдорф,阿尔恩斯多夫', 51.0942000, 13.9917600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39719, 'Arnschwang', 'Arnschwang', 'Arnshvang,Arnsvang,a er en shi wang,arnshvagi,Арншванг,Արնշվանգ,არნშვაგი,阿尔恩施旺', 49.2766300, 12.8159500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39720, 'Arnsberg', 'Arnsberg', 'Arensperg,Arnsberg,Arnsberga,Arnsbergas,Arnsberge,Gorad Arnsberg,a en si bei ge,arnsbrg,arnsbrgh,Арнсберг,Арнсберге,Горад Арнсберг,آرنسبرغ,آرنسبرگ,阿恩斯貝格', 51.3833300, 8.0833300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39721, 'Arneburg', 'Arneburg', 'Arneburg,a er nei bao,arnhbwrgh,Арнебург,آرنهبورغ,آرن‌برگ,阿尔内堡', 52.6756500, 12.0051400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39722, 'Arnbruck', 'Arnbruck', 'Arnbruk,a er en bu lu ke,arnbrwk,Арнбрук,Արնբրուք,آرنبروک,阿尔恩布鲁克', 49.1301200, 12.9982000, 'DE', '2011-08-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39723, 'Armstorf', 'Armstorf', '', 53.6000000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39724, 'Armstedt', 'Armstedt', 'Armstedt', 53.9713300, 9.8471000, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39725, 'Armsheim', 'Armsheim', 'Armskhajm,a er mu si hai mu,Армсхайм,Армсхајм,阿尔姆斯海姆', 49.8097200, 8.0566700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39726, 'Arlewatt', 'Arlewatt', 'Arlewatt', 54.5333300, 9.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39727, 'Arkebek', 'Arkebek', 'Arkebek', 54.1666700, 9.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39728, 'Arholzen', 'Arholzen', 'Arkhol''cen,Arkholcen,a luo er cen,aruhorutsu~en,Архолцен,Архольцен,アルホルツェン,阿罗尔岑', 51.8666700, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39729, 'Argenthal', 'Argenthal', 'Argental,Argental'',a er gen ta er,Аргентал,Аргенталь,阿尔根塔尔', 49.9666700, 7.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39730, 'Argenschwang', 'Argenschwang', 'Argenshvang,a er gen shi wang,Аргеншванг,阿尔根施旺', 49.8833300, 7.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39731, 'Arft', 'Arft', '', 50.3833300, 7.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39732, 'Aresing', 'Aresing', '', 48.5333300, 11.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39733, 'Aresing', 'Aresing', '', 48.2770400, 12.6053800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39734, 'Arenshausen', 'Arenshausen', 'Ahrenshausen,Arenshausen,Arenskhauzen,a lun si hao sen,Аренсхаузен,阿伦斯豪森', 51.3761300, 9.9687000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39735, 'Arenrath', 'Arenrath', '', 49.9500000, 6.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39736, 'Luftkurort Arendsee', 'Luftkurort Arendsee', 'Arendsee,Arendsee (Altmark)', 52.8807300, 11.4862100, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39737, 'Aremberg', 'Aremberg', 'Aremberg,a lun bei ge,arenberuku,Аремберг,アレンベルク,阿伦贝格', 50.4166700, 6.8000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39738, 'Arberg', 'Arberg', 'Arberg,a er bei ge,aberuku,Арберг,アーベルク,阿尔贝格', 49.1442800, 10.6172200, 'DE', '2013-04-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39739, 'Arbach', 'Arbach', '', 50.2833300, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39740, 'Appenweier', 'Appenweier', 'Apenvajer,Appenvaer,Appenvajer,Appenweier,Appenweir,a peng wei ai er,Апенвајер,Аппенвайер,Аппенваєр,阿彭魏埃尔', 48.5333300, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39741, 'Appenheim', 'Appenheim', '', 49.9300000, 8.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39742, 'Appen', 'Appen', 'Apen,Appen,a peng,Апен,Аппен,阿彭', 53.6581300, 9.7458200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39743, 'Appel', 'Appel', '', 53.3906000, 9.7456500, 'DE', '2017-07-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39744, 'Apolda', 'Apolda', 'Apol''da,Apol''de,Apolda,Stadt Apolda,a bo er da,ablda,aplda,Аполда,Апольда,Апольде,آبلدا,آپلدا,阿波尔达', 51.0262400, 11.5163800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39745, 'Apfeltrach', 'Apfeltrach', 'Apfel''trakh,Apfeltrakh,a pu fei er te la,Апфелтрах,Апфельтрах,Ապֆելթրախ,阿普费尔特拉', 48.0166700, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39746, 'Apfelstädt', 'Apfelstaedt', 'Apfel''shtedt,Apfelshtet,Apfelstaedt,Apfelstädt,Апфелштет,Апфельштедт', 50.9015700, 10.8897700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39747, 'Apensen', 'Apensen', 'Apenzen,Obbens,a peng sen,apenzen,Апензен,アペンゼン,阿彭森', 53.4333300, 9.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39748, 'Apen', 'Apen', 'Aap,Apen,Апен', 53.2166700, 7.8000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39749, 'Apelern', 'Apelern', 'Aop''larn,Apelern,a pei lai er en,apererun,Апелерн,アーペレルン,阿佩莱尔恩', 52.2897900, 9.3358000, 'DE', '2011-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39750, 'Anzing', 'Anzing', 'Ancing,an qin ge,antsyng,Анцинг,آنتسینگ,安钦格', 48.1517100, 11.8533000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39751, 'Antweiler', 'Antweiler', 'Antvajler,an te wei lei,antovu~aira,Антвайлер,Антвајлер,アントヴァイラー,安特韦勒', 50.4000000, 6.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39752, 'Antdorf', 'Antdorf', 'Antdorf,an duo fu,antdwrf,antodorufu,Антдорф,Անտդորֆ,آنتدورف,アントドルフ,安多夫', 47.7513300, 11.3084500, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39753, 'Anschau', 'Anschau', '', 50.3000000, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39754, 'Ansbach', 'Ansbach', 'Ansbach,Ansbachas,Ansbakh,Gorad Ansbakh,Onoldum,QOB,an si ba he,ansbakh,ansubahha,aynzbach,Ансбах,Горад Ансбах,آنسباخ,اینزباچ,アンスバッハ,安斯巴赫', 49.3048100, 10.5931000, 'DE', '2014-02-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39755, 'Anrode', 'Anrode', '', 51.2666700, 10.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39756, 'Anröchte', 'Anroechte', 'Anrekhte,Anrjokhte,Anroechte,Anröchte,an lei xi te,Анрехте,Анрёхте,Анрөхте,安勒希特', 51.5666700, 8.3333300, 'DE', '2015-05-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39757, 'Annweiler am Trifels', 'Annweiler am Trifels', 'Annwailer,Annweiler,Annweiler am Trifels,Anvajler kod Trifelsa,Anvajler-na-Trifel''se,anfaylar am tryflz,anwaylar an dr tryflz,te li fei er si shan lu an wei lei,Анвайлер-на-Трифельсе,Анвајлер код Трифелса,آنفايلار آم تريفلز,آنوایلار آن در تریفلز,アンヴァイラー・アム・トリフェルス,特里费尔斯山麓安韦勒', 49.2061300, 7.9752700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39758, 'Annaburg', 'Annaburg', 'Anaburg,Annaburg,a na bao,anabwrg,anabwrgh,Анабург,Аннабург,آنابورغ,آنابورگ,阿纳堡', 51.7329800, 13.0472900, 'DE', '2015-08-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39759, 'Annaberg-Buchholz', 'Annaberg-Buchholz', 'Anaberg-Bukholc,Anabergas-Buchholcas,Anabergas-Būchholcas,Annaberg-Bukhkhol''c,Annaberga-Buholca,Stadt Annaberg-Buchholz,an na bei ge-bu he huo er ci,anabrg-bwkh‌hwlts,anabrgh-bwkhhwlts,Анаберг-Бухолц,Аннаберг-Буххольц,آنابرغ-بوخهولتس,آنابرگ-بوخ‌هولتس,آنابرگ-بوخ‌هولز,安娜贝格-布赫霍尔茨', 50.5795300, 13.0062700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39760, 'Ankum', 'Ankum', 'Ankum,an ku mu,Анкум,安库姆', 52.5500000, 7.8833300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39761, 'Anklam', 'Anklam', 'Anklam,Anklama,Gorad Anklam,QKQ,Taglim,Tãglim,an ke la mu,anklam,Анклам,Горад Анклам,آنكلام,آنکلام,安克拉姆', 53.8563700, 13.6896500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39762, 'Anhausen', 'Anhausen', 'Ankhauzen,an hao sen,Анхаузен,安豪森', 50.5000000, 7.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39763, 'Angersdorf', 'Angersdorf', 'Angersdorf,Angersdorf/Saale', 51.4602500, 11.9070500, 'DE', '2016-02-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39764, 'Angern', 'Angern', 'Angern,an ge er en,Ангерн,安格尔恩', 52.3500000, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39765, 'Angermünde', 'Angermuende', 'Angerminde,Angermjunde,Angermuende,Angermyunde,Angermünde,Gorad Angermjundeh,an ge er ming de,angamyunde,anghrmwndh,angrmwndh,Ангерминде,Ангермюнде,Горад Ангермюндэ,Անգերմյունդե,آنغرمونده,آنگرمونده,アンガーミュンデ,安格尔明德', 53.0149900, 13.9992400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39766, 'Anger', 'Anger', '', 47.8018600, 12.8580800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39767, 'Angelroda', 'Angelroda', 'Angel''roda,Angelroda,an ge er luo da,Ангелрода,Ангельрода,安格尔罗达', 50.7500000, 10.8666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39768, 'Andisleben', 'Andisleben', '', 51.0828200, 10.9278600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39769, 'Andernach', 'Andernach', 'Andernach,Andernachas,Andernakh,Stadt Andernach,an de na he,andanahha,andrnakh,Андернах,آندرناخ,アンダーナッハ,安德纳赫', 50.4310900, 7.4042500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39770, 'Anderlingen', 'Anderlingen', '', 53.3743600, 9.3035700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39771, 'Andenhausen', 'Andenhausen', '', 50.6666700, 10.0666700, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39772, 'Andechs', 'Andechs', 'Abbaye d''Andechs,Andechs,Andeks,Kloster Andechs,Андекс', 47.9746400, 11.1827900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39773, 'Amtzell', 'Amtzell', 'Amcel,Amcell'',Amtcell'',Amtzell,a mu ce er,amtzl,Амтцелль,Амцел,Амцелль,امتزل,阿姆策尔', 47.7000000, 9.7500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39774, 'Amstetten', 'Amstetten', 'Amshteten,Amshtetten,amstytn,Амштетен,Амштеттен,Ամշտեթեն,امستیتن,ამშტეტენი', 48.5787600, 9.8738800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39775, 'Ampfing', 'Ampfing', 'Ampfing,ampfyng,an pu fen,Ампфинг,Ампфінг,Ամպֆինգ,امپفینگ,安普芬', 48.2540000, 12.4151500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39776, 'Amöneburg', 'Amoeneburg', 'Am''oneburg,Ameneburg,Amjoneburg,a mo nei bao,ameneburuku,amwnbrg,amwnhbwrgh,Аменебург,Амьонебург,Амёнебург,Амөнебург,آمونبرگ,آمونهبورغ,アメーネブルク,阿默内堡', 50.7959500, 8.9233000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39777, 'Ammerndorf', 'Ammerndorf', 'Ammerndorf', 49.4233500, 10.8501100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39778, 'Amerdingen', 'Amerdingen', 'Amerdingen,a mei er ding gen,amerudingen,amrdyngn,Амердинген,Амердінген,Ամերդինգեն,امردینگن,アーメルディンゲン,阿梅尔丁根', 48.7257200, 10.4856100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39779, 'Amerang', 'Amerang', 'Amerang,a mei lang,amrang,Амеранг,Ամերանգ,آمرانگ,阿梅朗', 47.9913900, 12.3079500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39780, 'Amendingen', 'Amendingen', '', 48.0030200, 10.1791800, 'DE', '2015-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39781, 'Amelinghausen', 'Amelinghausen', 'Amelingkhauzen,a mo ling hao sen,Амелингхаузен,امیلین‌گاسن,阿默灵豪森', 53.1239700, 10.2127400, 'DE', '2011-08-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39782, 'Amberg', 'Amberg', 'Amberg,Ambergas,Ampernk,Anberg,Gorad Amberg,amberg,ambrg,an bei ge,aymbrg,Άμπεργκ,Амберг,Горад Амберг,آمبرگ,ایمبرگ,安贝格', 49.4428700, 11.8626700, 'DE', '2014-01-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39783, 'Amberg', 'Amberg', '', 48.0666700, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39784, 'Alzey', 'Alzey', 'Alzey,XZY', 49.7465700, 8.1151300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39785, 'Alzenau in Unterfranken', 'Alzenau in Unterfranken', 'Alzenau,Alzenau in Unterfranken', 50.0888000, 9.0645500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39786, 'Alveslohe', 'Alveslohe', 'Al''vesloeh,Alfesloe,Alveslohe,Alveslokhe,a er fei si luo hei,alwslah,Алвеслохе,Алфеслое,Альвеслоэ,الوسلاه,阿尔费斯洛黑', 53.7833300, 9.9166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39787, 'Altweidelbach', 'Altweidelbach', '', 49.9833300, 7.5666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39788, 'Alt Wallmoden', 'Alt Wallmoden', 'Alt Wallmoden,Alt Wallmoden (Wallmoden),Walmonthem [a. 1016]', 52.0193300, 10.3029400, 'DE', '2012-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39789, 'Altusried', 'Altusried', 'Al''tusrid,Altusrid,Altusried,Comuna Altusried,a er tu si li de,altwsryd,Алтусрид,Альтусрид,Альтусрід,Ալտուսրիդ,التوسرید,阿尔图斯里德', 47.8041000, 10.2142900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39790, 'Alt Tucheband', 'Alt Tucheband', 'Al''t-Tukheband,Alt Tukheband,a er te tu hei ban de,alt twchband,Алт Тухебанд,Альт-Тухебанд,Ալթ Տուխեբանդ,آلت توچباند,阿尔特图黑班德', 52.5373200, 14.5122500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39791, 'Altstrimmig', 'Altstrimmig', '', 50.1000000, 7.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39792, 'Altstadt', 'Altstadt', '', 53.5500000, 10.0000000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39793, 'Altshausen', 'Altshausen', 'Al''tsgauzen,Al''tskhauzen,Altskhauzen,a er ci hao sen,Алтсхаузен,Альтсгаузен,Альтсгаўзен,Альтсхаузен,阿尔茨豪森', 47.9333300, 9.5333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39794, 'Altscheid', 'Altscheid', '', 50.0166700, 6.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39795, 'Altrip', 'Altrip', 'Al''trip,Aldrib,Altrip,a er te li pu,altryp,arutorippu,Алтрип,Альтрип,التریپ,アルトリップ,阿尔特里普', 49.4355600, 8.4947200, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39796, 'Altrich', 'Altrich', '', 49.9570100, 6.9121700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39797, 'Altötting', 'Altoetting', 'Al''tehtting,Al''tetting,Alt''oting,Alteting,Altoetting,Altotting,Altyoting,Altötting,Gorad Al''cjotyng,Oidaeding,Oidäding,a er te ting,altwtyg,altwtyngh,Алтетинг,Алтьотинг,Альтеттінг,Альтэттинг,Горад Альцётынг,Ալտյոտինգ,آلتوتينغ,آلتوتیگ,ایلٹوٹنگ,阿尔特廷', 48.2253300, 12.6766500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39798, 'Altomünster', 'Altomunster', 'Al''tomjunster,Altmunster,Altominster,Altomuenster,Altomünster,a er tuo ming si te,altwmwnstr,Алтоминстер,Альтомюнстер,Ալտոմյունսթեր,التومونستر,阿尔托明斯特', 48.3876700, 11.2569100, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39799, 'Alt Mölln', 'Alt Moelln', 'Alt Molln,Alt Mölln', 53.6231400, 10.6618200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39800, 'Altmittweida', 'Altmittweida', '', 50.9666700, 12.9500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39801, 'Alt Meteln', 'Alt Meteln', 'Alt Meteln', 53.7470900, 11.3405600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39802, 'Altlußheim', 'Altlussheim', 'Al''tlusgajm,Al''tluskhajm,Altlosse,Altluskhajm,Altlussheim,Altlußheim,altlwbhym,arutorusuhaimu,jiu lu si hai mu,Алтлусхајм,Альтлусгайм,Альтлусхайм,التلوبهیم,アルトルスハイム,旧卢斯海姆', 49.3016700, 8.4991700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39803, 'Altleiningen', 'Altleiningen', 'Al''tlajningen,Altlajningen,Altleiningen,altlynyngn,jiu lai ning gen,Алтлајнинген,Альтлайнинген,التلینینگن,旧莱宁根', 49.5075000, 8.0733300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39804, 'Altlay', 'Altlay', 'Al''tlaj,Altlaj,a er te lai,altlay,Алтлај,Альтлай,التلای,阿尔特莱', 49.9876900, 7.2718200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39805, 'Altlandsberg', 'Altlandsberg', 'Al''tlandsberg,Altlandsberg,a er te lan ci bei ge,altlandsbrg,altlandsbrgh,Алтландсберг,Альтландсберг,Ալտլանդսբերգ,آلتلاندسبرغ,آلتلاندسبرگ,阿尔特兰茨贝格', 52.5650300, 13.7281500, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39806, 'Altkirchen', 'Altkirchen', 'Al''tkirkhen,Aldenkirkin [a. 1140],Altkirkhen,Ztarecoztol [a. 1140],altkyrchn,jiu ji xing,Źtarecoźtol [a. 1140],Алткирхен,Альткирхен,التکیرچن,旧基兴', 50.9333300, 12.3500000, 'DE', '2014-12-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39807, 'Althüttendorf', 'Althuttendorf', 'Al''tkhjuttendorf,Altkhitendorf,Altyuntendorf,a er di teng duo fu,altwtndraf,Алтхитендорф,Альтхюттендорф,Ալտյունտենդորֆ,التوتندراف,阿尔蒂滕多夫', 52.9622900, 13.8072400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39808, 'Althütte', 'Althutte', 'Al''tjutte,Al''tkhjutte,Altkhite,a er di te,altwt,Алтхите,Альтхютте,Альтютте,التوت,阿尔蒂特', 48.9156500, 9.5698400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39809, 'Althornbach', 'Althornbach', '', 49.2000000, 7.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39810, 'Althengstett', 'Althengstett', 'Al''tengshtett,Al''tengstett,Al''tkhengshtett,Altkhengshtet,a er teng si te,altngstt,Алтхенгштет,Альтенгстетт,Альтенгштетт,Альтхенгштетт,Ալթհենգշտեթ,التنگستت,阿尔滕斯特', 48.7232500, 8.7943400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39811, 'Altheim', 'Altheim', '', 48.3280100, 9.7704100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39812, 'Altheim', 'Altheim', '', 48.1452700, 9.4473800, 'DE', '2017-05-07', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39813, 'Althegnenberg', 'Althegnenberg', 'Al''tegnenberg,Altkhegnenberg,Henaberg,a er te ge nen bei ge,altgnynbrg,Алтхегненберг,Альтегненберг,Ալթեգնենբերգ,التگنینبرگ,阿尔特格嫩贝格', 48.2333300, 11.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39814, 'Altglienicke', 'Altglienicke', 'Al''tglinike,Berlin-Altglienicke,altglynyk,Альтглинике,التگلینیک', 52.4111600, 13.5355000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39815, 'Altfraunhofen', 'Altfraunhofen', 'Al''tfraungofen,Al''tfraunkhofen,Altfraunkhofen,Oidfraunhofa,altfraywnhafn,jiu fu lao en huo fen,Алтфраунхофен,Альтфраунгофен,Альтфраунхофен,Ալթֆրաունհոֆեն,التفرائونهافن,旧弗劳恩霍芬', 48.4500000, 12.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39816, 'Altforweiler', 'Altforweiler', '', 49.2741100, 6.7059800, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39817, 'Altersbach', 'Altersbach', 'Altersbach', 50.7000000, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39818, 'Alterkülz', 'Alterkulz', 'Al''terkjul''c,Alterkilc,a er te er qu er ci,altrkwlz,Алтеркилц,Альтеркюльц,الترکولز,阿尔特尔屈尔茨', 50.0333300, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39819, 'Altentreptow', 'Altentreptow', 'Al''tentreptov,Altentreptov,Altentreptova,Altentreptow,Store Trzebiatowo,Stôré Trzébiatowò,altntrbtww,altntrptww,jiu te lei pu tuo,Алтентрептов,Альтентрептов,آلتنتربتوو,آلتنترپتوو,旧特雷普托', 53.6941600, 13.2650400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39820, 'Altenthann', 'Altenthann', 'Al''tentann,Altentan,a er teng tan,altntan,Алтентан,Альтентанн,Ալտենթան,التنتان,阿尔滕坦', 49.1000000, 12.3000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39821, 'Altensteig', 'Altensteig', 'Al''tenshtajg,Al''tenstajg,Altenshtajg,Altenstayg,Altensteig,a er teng si tai xi,altnshtayg,altnshtaygh,Алтенштајг,Альтенстайг,Альтенштайг,Ալտենշտայգ,آلتنشتايغ,آلتنشتایگ,阿尔滕斯泰希', 48.5864900, 8.6039500, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39822, 'Altenstadt', 'Altenstadt', 'Altenstadt', 50.2874700, 8.9437300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39823, 'Altenstadt', 'Altenstadt', 'Al''tenshtadt,Altenshtat,altnstad  swaby,Алтенштат,Альтенштадт,Ալտենշթաթ,التنستاد، سوابی', 48.1603000, 10.1143700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39824, 'Altenstadt', 'Altenstadt', '', 47.8235900, 10.8747500, 'DE', '2012-10-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39825, 'Altenriet', 'Altenriet', 'Al''tenrit,Altenrit,a er teng li te,altnryt,Алтенрит,Альтенрит,Альтенріт,Ալտենրիտ,التنریت,阿尔滕里特', 48.5914000, 9.2218600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39826, 'Altenpleen', 'Altenpleen', '', 54.3545600, 12.9564000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39827, 'Altenmünster', 'Altenmunster', 'Al''tenmjunster,Altenminster,Altenmuenster,Altenmyunster,Altenmünster,a er teng ming si te er,altnmanstr,Алтенминстер,Альтенмюнстер,Ալտենմյունստեր,التنمانستر,阿尔滕明斯特尔', 48.4649500, 10.5906500, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39828, 'Altenmoor', 'Altenmoor', 'Altenmoor', 53.7666700, 9.5666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39829, 'Altenmedingen', 'Altenmedingen', 'Al''tenmedingen,Altenmedingen,Ohmein,a er teng mei ding gen,altnmdyngn,Алтенмединген,Альтенмединген,التنمدینگن,阿尔滕梅丁根', 53.1305000, 10.6016300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39830, 'Altenmarkt', 'Altenmarkt', '', 47.7796000, 12.1356000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39831, 'Altenkunstadt', 'Altenkunstadt', 'Al''tenkunshtadt,Altenkunshtat,a er teng kun si ta te,altnkanstad,arutenkunshutatto,Алтенкунштат,Альтенкунштадт,Ալթենքունշթաթ,אלטנקונשטאדט,التنکانستاد,アルテンクンシュタット,阿尔滕昆斯塔特', 50.1250400, 11.2503000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39832, 'Altenkrempe', 'Altenkrempe', 'Al''tenkrempe,Altenkrempe,a er teng ke lun pei,altnkrymp,Алтенкремпе,Альтенкремпе,التنکریمپ,阿尔滕克伦佩', 54.1333300, 10.8333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39833, 'Altenkirchen', 'Altenkirchen', '', 54.6362400, 13.3433200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39834, 'Altenkirchen', 'Altenkirchen', 'Al''tenkirkhen,Altenkirchen,Altenkirkhen,Gorad Al''tehnkirkhen,a er teng ji xing,altnkyrshn,Алтенкирхен,Альтенкирхен,Альтенкірхен,Горад Альтэнкірхен,آلتنکیرشن,阿尔滕基兴', 50.6859400, 7.6417600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39835, 'Altenkirchen', 'Altenkirchen', 'Al''tenkirkhen,Altenkirkhen,altnkyrchn  kasl,Алтенкирхен,Альтенкирхен,التنکیرچن، کاسل', 49.4431300, 7.3208400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39836, 'Altenholz', 'Altenholz', 'Al''tenkhol''c,Altenholz,Altenkholc,a er teng huo er ci,altnhalz,Алтенхолц,Альтенхольц,التنهالز,阿尔滕霍尔茨', 54.4000000, 10.1333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39837, 'Altenhof', 'Altenhof', '', 54.4333300, 9.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39838, 'Altenhausen', 'Altenhausen', 'Al''tenkhauzen,Altenhusen,Altenkhauzen,Haldenhusen [a. 1330],Olenhusen,Ollnhusen,a er teng hao sen,altnhasn,Алтенхаузен,Альтенхаузен,التنهاسن,阿尔滕豪森', 52.2619600, 11.2542900, 'DE', '2015-12-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39839, 'Altengottern', 'Altengottern', '', 51.1639500, 10.5809300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39840, 'Altenglan', 'Altenglan', 'Al''tenglan,Altenglan,a er teng lan,altnglan,arutenguran,Алтенглан,Альтенглан,التنگلان,アルテングラン,阿尔滕兰', 49.5500000, 7.4666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39841, 'Altenfeld', 'Altenfeld', 'Al''tenfel''d,Altenfeld,a er teng fei er de,altnfyld,Алтенфелд,Альтенфельд,التنفیلد,阿尔滕费尔德', 50.5666700, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39842, 'Altendorf', 'Altendorf', '', 50.0842400, 11.1678600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39843, 'Altendorf', 'Altendorf', '', 49.4055000, 12.2815100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39844, 'Altendiez', 'Altendiez', '', 50.3666700, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39845, 'Alten Buseck', 'Alten Buseck', '', 50.6221800, 8.7532200, 'DE', '2014-05-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39846, 'Altenburg', 'Altenburg', 'AOC,Al''tenburg,Altemburgo,Altenbourg,Altenburg,Altenburgas,Altenburgo,Altenburgum in Misnia,Starograd,a er teng bao,altenbuleukeu,altnbrg,altnbwrg,altnbwrgh,arutenburuku,Алтенбург,Альтенбург,אלטנבורג,آلتنبورغ,آلتنبورگ,التنبرگ,الٹنبورگ,アルテンブルク,阿尔滕堡,알텐부르크', 50.9876300, 12.4368400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39847, 'Altenbeuthen', 'Altenbeuthen', '', 50.5919000, 11.6006200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39848, 'Altenberge', 'Altenberge', 'Al''tenberge,Altenberge,a er teng bei ge,Алтенберге,Альтенберге,阿尔滕贝格', 52.0500000, 7.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39849, 'Altenberga', 'Altenberga', 'Al''tenberga,Altenberga,a er teng bei er jia,altnbrga,Алтенберга,Альтенберга,التنبرگا,阿尔滕贝尔加', 50.8333300, 11.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39850, 'Altenberg', 'Altenberg', 'Al''tenberg,Altenberg,altnbrg,Алтенберг,Альтенберг,آلتنبرگ', 50.7655600, 13.7533400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39851, 'Altenbeken', 'Altenbeken', 'Al''tenbeken,Altenbeken,a er teng bei ken,altynbkn,arutenbeken,Алтенбекен,Альтенбекен,التینبکن,アルテンベーケン,阿尔滕贝肯', 51.7645500, 8.9420100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39852, 'Altenbamberg', 'Altenbamberg', 'Al''tenbamberg,Altenbamberg,a er teng ban bei ge,altynbambrg,Алтенбамберг,Альтенбамберг,التینبامبرگ,阿尔滕班贝格', 49.7833300, 7.8333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39853, 'Altenau', 'Altenau', 'Al''tenau,Altenau,a er te nao,altnaw,Алтенау,Альтенау,آلتناو,阿尔特瑙', 51.8011300, 10.4414800, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39854, 'Altenahr', 'Altenahr', 'Al''tenar,Altenar,Altenaras,a er te na er,altynahr,aruten''aru,Алтенар,Альтенар,التیناهر,アルテンアール,阿尔特纳尔', 50.5169400, 6.9920600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39855, 'Altena', 'Altena', 'Al''tena,Altena,Altenoa,Gorad Al''tehna,a er te na,altna,Алтена,Альтена,Горад Альтэна,آلتنا,阿尔特纳', 51.2947200, 7.6733700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39856, 'Alteglofsheim', 'Alteglofsheim', 'Al''teglofsgajm,Al''teglofskhajm,Alteglofshaym,Alteglofsheim,Alteglofskhajm,Eglofsheim,a er te ge luo fu si hai mu,altyglafshym,Алтеглофсхајм,Альтеглофсгайм,Альтеглофсхайм,Ալտեգլոֆսհայմ,التیگلافشیم,阿尔特格洛夫斯海姆', 48.9166700, 12.2000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39857, 'Altefähr', 'Altefaehr', 'Al''tefer,Altefer,a er te fei er,altyfahr,Алтефер,Альтефер,التیفاهر,阿尔特费尔', 54.3299400, 13.1264300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39858, 'Alt Duvenstedt', 'Alt Duvenstedt', 'Al''t-Dufenshtedt,Alt Dufenshtet,Alt Duvenshtet,Alt Duvenstedt,a er te du fen si te,alt dwfnshtt,Алт Дувенштет,Алт Дуфенштет,Альт-Дуфенштедт,آلت دوفنشتت,阿尔特杜芬斯特', 54.3666700, 9.6500000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39859, 'Altdorf', 'Altdorf', 'Altdorf', 49.3856000, 11.3573000, 'DE', '2014-04-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39860, 'Altdorf', 'Altdorf', '', 49.2872200, 8.2161100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39861, 'Altdorf', 'Altdorf', '', 48.6311200, 8.9962600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39862, 'Altdorf', 'Altdorf', '', 48.5942100, 9.2716500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39863, 'Altdorf', 'Altdorf', '', 48.1537400, 12.1841900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39864, 'Altdöbern', 'Altdobern', 'Al''tdjobern,Altdebern,Altdoebern,Altdyobern,Altdöbern,Stara Darbnja,a er de bei er en,altdwbrn,Алтдеберн,Альтдёберн,Ալտդյոբերն,التدوبرن,阿尔德贝尔恩', 51.6500000, 14.0333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39865, 'Alt Bennebek', 'Alt Bennebek', '', 54.3833300, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39866, 'Altbach', 'Altbach', 'Al''tbakh,Altbakh,Altbax,a er te ba he,altbakh,Алтбах,Альтбах,Ալտբախ,التباخ,阿尔特巴赫', 48.7226800, 9.3807800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39867, 'Ammerthal', 'Ammerthal', 'Altammerthal,Amertal,Ammertal'',a mei er ta er,amrsal,Амертал,Аммерталь,Ամերտալ,امرسال,阿梅尔塔尔', 49.4412300, 11.7618100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39868, 'Alsterdorf', 'Alsterdorf', 'Alsterdorf,Hamburg-Alsterdorf,alstrdraf,Алстердорф,الستردراف', 53.6108300, 10.0130600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39869, 'Alsleben', 'Alsleben', 'Al''sleben,Alsleben,a er si lai ben,alslbn,alslybn,Алслебен,Альслебен,آلسلبن,آلسليبن,阿尔斯莱本', 51.7016100, 11.6764800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39870, 'Alsheim', 'Alsheim', 'Al''skhajm,Alskhajm,a er si hai mu,alshaym,Алсхајм,Альсхайм,آلسهایم,阿尔斯海姆', 49.7680600, 8.3402800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39871, 'Alsfeld', 'Alsfeld', 'Al''sfel''d,Alsfeld,Alsfelt,Gorad Al''sfel''d,a er si fei er de,alsfld,arusuferuto,Άλσφελτ,Алсфелд,Альсфельд,Горад Альсфельд,آلسفلد,アルスフェルト,阿尔斯费尔德', 50.7518500, 9.2708200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39872, 'Alsenz', 'Alsenz', 'Al''zenc,Alsenc,a er sen ci,alsnz,aruzentsu,Алсенц,Альзенц,السنز,アルゼンツ,阿尔森茨', 49.7166700, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39873, 'Alsdorf', 'Alsdorf', 'Al''sdorf,Alsdorf,Elsdoerp,Elsdörp,a er si duo fu,alsdwrf,arusudorufu,Алсдорф,Альсдорф,آلسدورف,アルスドルフ,阿尔斯多夫', 50.8767300, 6.1639900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39874, 'Alsdorf', 'Alsdorf', '', 50.7773600, 7.8856200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39875, 'Alsdorf', 'Alsdorf', '', 49.8883300, 6.4682000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39876, 'Alsbach', 'Alsbach', '', 50.4641100, 7.6619800, 'DE', '2017-03-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39877, 'Alpirsbach', 'Alpirsbach', 'Al''pirsbakh,Alpirsbakh,Alpirsbax,a er pi er si ba he,albyrsbakh,alpyrsbakh,Алпирсбах,Альпирсбах,Альпірсбах,Ալպիրսբախ,آلبيرسباخ,آلپیرسباخ,阿尔皮尔斯巴赫', 48.3450700, 8.4019700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39878, 'Alperstedt', 'Alperstedt', '', 51.0924000, 11.0453000, 'DE', '2013-10-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39879, 'Alpenrod', 'Alpenrod', '', 50.6333300, 7.8666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39880, 'Alpen', 'Alpen', '', 51.5833300, 6.5166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39881, 'Almstedt', 'Almstedt', 'Al''mshtedt,Almshtet,almstd,Алмштет,Альмштедт,المستد', 52.0324300, 9.9615100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39882, 'Almersbach', 'Almersbach', 'Al''mersbakh,Almersbakh,a er mei er si ba he,Алмерсбах,Альмерсбах,阿尔梅尔斯巴赫', 50.6833300, 7.6333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39883, 'Almdorf', 'Almdorf', 'Almdorf', 54.5833300, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39884, 'Allstedt', 'Allstedt', 'Ahlsdorf,Al''shtedt,Allstedt,Alshtet,a er si te,alshtyt,Алштет,Альштедт,آلشتيت,آل‌اشتد,阿尔斯特', 51.4037900, 11.3868900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39885, 'Allmersbach im Tal', 'Allmersbach im Tal', 'Al''mersbakh-im-Tal'',All''mersbakh,Allmersbach,Almersbakh im Tal,a er mo si ba he,almrzbakh,Алльмерсбах,Алмерсбах им Тал,Альмерсбах-им-Таль,المرزباخ,阿尔默斯巴赫', 48.9065900, 9.4681500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39886, 'Allmendingen', 'Allmendingen', '', 48.3305200, 9.7241900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39887, 'Allmannsweiler', 'Allmannsweiler', '', 48.0285300, 9.5936100, 'DE', '2011-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40348, 'Tadjoura', 'Tadjoura', 'Gorad Tadzhura,TDJ,Tadjoura,Tadjourah,Tadjura,Tadzhura,Tadzura,Tadżura,Tadžura,Tagiura,Tajura,Tantzoura,ta zhu la,tajula,tajura,tajwrh,tajwrt,Ταντζουρά,Горад Таджура,Таджура,Թաջուրա,تاجورة,تاجوره,تاجورہ,ტაჯურა,タジュラ,塔朱拉,타주라', 11.7852800, 42.8844400, 'DJ', '2012-01-18', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40349, 'Obock', 'Obock', 'Gorad Abok,Hayyou,OBC,Obock,Obok,Obokas,Obuk,Ompok,ao bo ke,awbwk,obokeu,obokku,Ομπόκ,Горад Абок,Обок,أوبوك,اوبوک,ობოკი,オボック,奧博克,오보크', 11.9630600, 43.2905600, 'DJ', '2012-01-18', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40350, 'Loyada', 'Loyada', 'La-waada,Loya Ada,Loyada,Loyi Ada', 11.4611100, 43.2527800, 'DJ', '2012-01-18', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40351, 'Holhol', 'Holhol', 'Hol Holl,Holhol,Holl-Holl', 11.3102800, 42.9294400, 'DJ', '2012-01-18', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40352, 'Dorra', 'Dorra', 'Dorra', 12.1502800, 42.4762400, 'DJ', '2012-07-04', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40353, 'Djibouti', 'Djibouti', 'Byen Djibouti,Cibuti,Dinas Jibwti,Diobuiti,Diobúití,Djiboeti,Djibouti,Djibouti Chhi,Djibouti Chhī,Djibuti,Dschibuti,Dzhibuti,Dzibuti,Dzibutis,Dzjibuty,Dzjibûty,Dzsibuti,Dżibuti,Džibuti,Džibutis,Džíbútí,Gibuti,Gibuto,Gibutum,Gorad Dzhybuci,Ilu Djibouti,JIB,Jabuuti,Jiboti,Jibouti,Jibuti,Lungsod ng Djibouti,Mbanza ya Djibuti,Sita Jibouti,Syudad han Djibouti,Tzimpouti,Xibuti,Xibutí,Yibuti,Zhibuti shaary,ci buti,ciputti,dzsybwty,gybwty,jbwty,jbwty ʿlaqہ,ji bu de shi,ji bu ti cheng,jibuchi shi,jibuti,jybwty,jybwwty,Ìlú Djibouti,Ĝibuto,Τζιμπουτί,Џибути,Горад Джыбуці,Джибути,Джибуті,Жибути шаары,Ҷибути,Ջիբութի,גיבוטי,דזשיבוטי,جبوتی,جبوتی علاقہ,جيبوتي,جیبوتی,جیبووتی,जिबूती,জিবুতি,ਜਿਬੂਤੀ,சீபூத்தீ,จิบูตี,ཇི་བའོ་ཊི།,ჯიბუტი,ジブチ市,吉布地市,吉布提城,지부티', 11.5890100, 43.1450300, 'DJ', '2012-05-14', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40354, 'Dikhil', 'Dikhil', 'Dicchil,Dikhil,Dikil,Dikil'',Dikilis,Dikkil,Gorad Dykhil,Ntikil,di ji lei,dikeuhil,dikiru,dkhyl,Ντικίλ,Горад Дыхіл,Дикиль,دخيل,دخیل,დიკილი,ディキル,迪基勒,디크힐', 11.1086100, 42.3738900, 'DJ', '2012-01-18', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39888, 'Allmannshofen', 'Allmannshofen', 'All''mannsgofen,All''manskhofen,Almanshofen,Almanskhofen,a er man si huo fen,Алльманнсгофен,Алльмансхофен,Алмансхофен,Ալմանսհոֆեն,المن‌شافن,阿尔曼斯霍芬', 48.6125500, 10.8093000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39889, 'Alling', 'Alling', 'Aling,Alling,Oiing,a ling,alyng,Алинг,Аллинг,Аллінг,Ալինգ,الینگ,阿灵', 48.1403400, 11.3014400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39890, 'Alleshausen', 'Alleshausen', 'Aleshauzen,Aleskhauzen,Allesgauzen,Alleskhauzen,a lai si hao sen,aleshauzeni,alyshasn,Алесхаузен,Аллесгаузен,Аллесхаузен,Ալեսհաուզեն,الیشاسن,ალესჰაუზენი,阿莱斯豪森', 48.1035900, 9.6217900, 'DE', '2012-08-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39891, 'Allershausen', 'Allershausen', 'Alershauzen,Alerskhauzen,Allersgauzen,Allerskhauzen,a lai er si hao sen,alyrshawsn,Алерсхаузен,Аллерсгаузен,Аллерсхаузен,Ալերսհաուզեն,الیرشاوسن,阿莱尔斯豪森', 48.4333300, 11.6000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39892, 'Allersberg', 'Allersberg', 'Alersberg,Allersberg,a lei si bei ge,alyrzbrg,arasuberuku,Алерсберг,Аллерсберг,Ալերսբերգ,الیرزبرگ,アラースベルク,阿勒斯贝格', 49.2513200, 11.2365900, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39893, 'Allensbach', 'Allensbach', 'Alensbakh,Allensbach,Allensbakh,a lun si ba he,alynzbakh,Аленсбах,Алленсбах,الینزباخ,阿伦斯巴赫', 47.7153600, 9.0714500, 'DE', '2011-09-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39894, 'Allenfeld', 'Allenfeld', '', 49.8666700, 7.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39895, 'Allendorf an der Lahn', 'Allendorf an der Lahn', 'Allendorf,Allendorf an der Lahn', 50.5510900, 8.6200800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39896, 'Allendorf', 'Allendorf', 'Alendorf,Allendorf,Allendorf-Eder,alyndraf  waldk-franknbrg,arendorufu,Алендорф,Аллендорф,الیندراف، والدک-فرانکنبرگ,アレンドルフ', 51.0299500, 8.6723200, 'DE', '2016-09-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39897, 'Allendorf', 'Allendorf', '', 50.6546800, 11.1579900, 'DE', '2012-09-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39898, 'Allendorf', 'Allendorf', '', 50.2677800, 7.9988200, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39899, 'Allenbach', 'Allenbach', 'Alenbakh,Allenbakh,a lun ba he,alnbakh,Аленбах,Алленбах,النباخ,阿伦巴赫', 49.7544900, 7.1672000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39900, 'Alkersum', 'Alkersum', '', 54.7079600, 8.5092500, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39901, 'Alkersleben', 'Alkersleben', 'Al''kersleben,Alkersleben,a er ke er si lai ben,alkrslbn,Алкерслебен,Алькерслебен,الکرسلبن,阿尔克尔斯莱本', 50.8500000, 11.0333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39902, 'Alken', 'Alken', '', 50.2500000, 7.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39903, 'Alheim', 'Alheim', 'Al''gajm,Al''khajm,Alheim,Alkhajm,a er hai mu,alhym,Алхајм,Альгайм,Альхайм,الهیم,阿尔海姆', 51.0333300, 9.6666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39904, 'Algermissen', 'Algermissen', 'Al''germissen,Alegrimesheim [a. 985],Alegrimessen [a. 1204],Algermisen,Algermissen,a er ge er mi sen,algrmysn,Алгермисен,Альгермиссен,Альгерміссен,الگرمیسن,阿尔格尔米森', 52.2533200, 9.9691500, 'DE', '2014-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39905, 'Alfter', 'Alfter', 'Al''fter,Alefte,Alfter,a er fu te,alftr,Алфтер,Альфтер,الفتر,阿尔夫特', 50.7333300, 7.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39906, 'Alfstedt', 'Alfstedt', '', 53.5500000, 9.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39907, 'Alflen', 'Alflen', 'Aflen,Al''flen,Alflen,a er fu lun,alfln,Алфлен,Альфлен,الفلن,阿尔夫伦', 50.1768300, 7.0395000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39908, 'Alfhausen', 'Alfhausen', 'Al''fkhauzen,Alfhausen,Alfkhauzen,a er fu hao sen,alfaywsn,Алфхаузен,Альфхаузен,الفائوسن,阿尔夫豪森', 52.5000000, 7.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39909, 'Alfeld', 'Alfeld', 'ALF,Al''fel''d,Alfeld,Alfeld (Leine),Alfeldas,Allefelle,Alvelde,a er fei er de,alfld,Алфелд,Альфельд,آلفلد,阿尔费尔德', 51.9838200, 9.8198900, 'DE', '2014-07-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39910, 'Alfeld', 'Alfeld', '', 49.4333300, 11.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39911, 'Alfdorf', 'Alfdorf', 'Al''fdorf,Alfdorf,a er fu duo fu,alfdarf,Алфдорф,Альфдорф,الفدارف,阿尔夫多夫', 48.8438500, 9.7185700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39912, 'Alf', 'Alf', 'Al''f,Alf,a er fu,alf  rynlnd-platynt,Алф,Альф,الف، رینلند-پلاتینت,阿尔夫', 50.0545300, 7.1234200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39913, 'Bad Alexandersbad', 'Bad Alexandersbad', 'Alexandersbad,Bad Aleksandersbad,Bad Alexandersbad,Bad-Aleksandersbad,ba te ya li shan da si ba de,Бад Александерсбад,Бад-Александерсбад,Բադ Ալեքսանդերսբադ,バート・アレクサンダースバート,巴特亚历山大斯巴德', 50.0166700, 12.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39914, 'Aletshausen', 'Aletshausen', 'Aletsgauzen,Aletshauzen,Aletskhauzen,a lai ci hao sen,altshawsn,Алетсгаузен,Алетсхаузен,Ալետսհաուզեն,التشاوسن,阿莱茨豪森', 48.1985900, 10.3887700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39915, 'Alesheim', 'Alesheim', 'Alesgajm,Aleshaym,Aleskhajm,a lai si hai mu,alyshym,Алесгайм,Алесхайм,Алесхајм,Ալեսհայմ,الیشیم,阿莱斯海姆', 49.0464800, 10.8649600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39916, 'Alerheim', 'Alerheim', '', 48.8500000, 10.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39917, 'Aldingen', 'Aldingen', 'Al''dingen,Aldingen,a er ding gen,aldyngn,Алдинген,Альдинген,الدینگن,阿尔丁根', 48.1000000, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39918, 'Aldersbach', 'Aldersbach', 'Al''dersbakh,Aldersbach,Aldersbakh,Aldersbax,Allersbach,Oidaschbo,a er de er si ba he,aldrzbakh,Алдерсбах,Альдерсбах,Ալդերսբախ,الدرزباخ,阿尔德尔斯巴赫', 48.5897200, 13.0897100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39919, 'Aldenhoven', 'Aldenhoven', 'Al''dengofen,Al''denkhofen,Aldenhoffen,Aldenhoven,Aldenkhofen,a er deng huo fen,aldynhawyn,Алденхофен,Альденгофен,Альденхофен,الدینهاوین,阿尔登霍芬', 50.9000000, 6.2833300, 'DE', '2013-05-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39920, 'Albstadt', 'Albstadt', 'Al''bshtadt,Albshtat,Albstadt,Gorad Al''bshtat,a er bu si ta te,Албштат,Альбштадт,Горад Альбштат,آلب‌اشتاد,阿尔布斯塔特', 48.2164400, 9.0259600, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39921, 'Albshausen', 'Albshausen', '', 50.5443100, 8.4378400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39922, 'Albsfelde', 'Albsfelde', 'Albsfelde', 53.6833300, 10.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39923, 'Albisheim', 'Albisheim', 'Albisheim', 49.6494100, 8.0944200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39924, 'Albig', 'Albig', 'Al''big,Albig,a er bi xi,albyg,Албиг,Альбиг,البیگ,阿尔比希', 49.7736100, 8.1213900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39925, 'Albessen', 'Albessen', 'Al''bessen,Albesen,a er bei sen,albsn,Албесен,Альбессен,البسن,阿尔贝森', 49.5166700, 7.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39926, 'Albertstadt', 'Albertstadt', 'Al''bertshtadt,Albertstadt,Альбертштадт', 51.0833300, 13.7666700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39927, 'Albertshofen', 'Albertshofen', 'Al''bertsgofen,Al''bertskhofen,Albertskhofen,a er bei er ci huo fen,albrtshafn,Албертсхофен,Альбертсгофен,Альбертсхофен,Ալբերթսհոֆեն,البرتشافن,阿尔贝尔茨霍芬', 49.7666700, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39928, 'Albersweiler', 'Albersweiler', 'Al''bersvajler,Albersvajler,a er bo si wei lei,albrswylr,Алберсвајлер,Альберсвайлер,البرسویلر,阿尔伯斯韦勒', 49.2191700, 8.0300000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39929, 'Albershausen', 'Albershausen', 'Al''bersgauzen,Al''berskhauzen,Alberskhauzen,a er bo si hao sen,Алберсхаузен,Альберсгаузен,Альберсхаузен,البرت‌شاسن,阿尔伯斯豪森', 48.6913600, 9.5649300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39930, 'Albersdorf', 'Albersdorf', '', 54.1500000, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39931, 'Albersdorf', 'Albersdorf', '', 50.9033000, 11.7729700, 'DE', '2012-09-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39932, 'Albbruck', 'Albbruck', 'Al''bbruk,Al''bruk,Albbruck-Dogern,Albruk,a er bu lu ke,albrak,Албрук,Альббрук,Альбрук,البراک,阿尔布鲁克', 47.5907700, 8.1295400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39933, 'Albaching', 'Albaching', 'Al''bakhing,Albakhing,Albaxing,Oibiching,a er ba xing,albachyng,Албахинг,Альбахинг,Альбахінг,Ալբախինգ,الباچینگ,阿尔巴兴', 48.1101100, 12.1107400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39934, 'Aken', 'Aken', 'Aken,a ken,akn,Акен,آكن,آکن,阿肯', 51.8527400, 12.0446100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39935, 'Aitrang', 'Aitrang', 'Ajtrang,Aytrang,ai te lang,aitorangu,aytrang,Айтранг,Ајтранг,Այտրանգ,ایترانگ,アイトラング,艾特朗', 47.8166700, 10.5333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39936, 'Aitrach', 'Aitrach', 'Aitrach,Ajtrakh,ai te la,aytrach,Айтрах,Ајтрах,ایتراچ,艾特拉', 47.9333300, 10.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39937, 'Aitern', 'Aitern', 'Ajtern,ai te er en,aytrn,Айтерн,Ајтерн,ایترن,艾特尔恩', 47.8000000, 7.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39938, 'Alterhofen', 'Alterhofen', 'Aiterhofen', 48.8465900, 12.6201200, 'DE', '2017-07-13', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39939, 'Aislingen', 'Aislingen', 'Ajslingen,Ayslingen,aislingeni,ayslyngn,Айслинген,Айслінген,Ајслинген,Այսլինգեն,آیسلینگن,აისლინგენი', 48.5064800, 10.4577800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39940, 'Ainring', 'Ainring', 'Ainring,Ajnring,Aynring,ai yin ling,ainringi,aynryng,Айнринг,Айнрінг,Ајнринг,Այնրինգ,اینرینگ,აინრინგი,艾因灵', 47.8131100, 12.9404800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39941, 'Aindling', 'Aindling', 'Aindling,Ainling,Ajndling,Aydling,Oaing,ai en de ling,aindlingi,aintoringu,ayndlyng,Айндлинг,Айндлінг,Ајндлинг,Այդլինգ,ایندلینگ,აინდლინგი,アイントリング,艾恩德灵', 48.5136000, 10.9531500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39942, 'Ailertchen', 'Ailertchen', '', 50.5986100, 7.9419400, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39943, 'Aiglsbach', 'Aiglsbach', 'Ajgl''sbakh,Ajglsbakh,Ayglsbax,Oaglsboch,ai ge er si ba he,aiglsbakhi,ayglzbakh,Айгльсбах,Ајглсбах,Այգլսբախ,ایگلزباخ,აიგლსბახი,艾格尔斯巴赫', 48.6921100, 11.7083100, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39944, 'Aidlingen', 'Aidlingen', 'Ajdlingen,Aydlingen,ai de lin gen,aidlingeni,aydlyngn,Айдлинген,Айдлінген,Ајдлинген,Այդլինգեն,ایدلینگن,აიდლინგენი,艾德林根', 48.6784900, 8.8952400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39945, 'Aidhausen', 'Aidhausen', 'Aidhausen,Ajdgauzen,Ajdkhauzen,Aydhauzen,ai de hao sen,aidhauzeni,aydhasn,Айдгаузен,Айдхаузен,Ајдхаузен,Այդհաուզեն,ایدهاسن,აიდჰაუზენი,艾德豪森', 50.1500000, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39946, 'Aidenbach', 'Aidenbach', 'Aidenbach,Aitenbach,Ajdenbakh,Aydenbax,Oambo,ai deng ba he,aidenbakhi,aydnbakh,Айденбах,Ајденбах,Այդենբախ,ایدنباخ,აიდენბახი,艾登巴赫', 48.5702800, 13.0900000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39947, 'Aichstetten', 'Aichstetten', 'Ajkhshteten,Ajkhshtetten,ai xi si te teng,aychstn,Айхштеттен,Ајхштетен,ایچستن,艾希斯特滕', 47.8929500, 10.0783700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39948, 'Aichhalden', 'Aichhalden', 'Aichhalden,Ajkhalden,Ajkhgal''den,Ajkhkhal''den,Gemeinde Aichhalden,ai xia er deng,aychhaldn,Айхгальден,Айххальден,Ајхалден,ایچهالدن,艾夏尔登', 48.2671900, 8.4023300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39949, 'Aichen', 'Aichen', 'Ajkhen,Ayxen,aychn,Айхен,Ајхен,Այխեն,ایچن', 48.2289800, 10.5394900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39950, 'Aichelberg', 'Aichelberg', 'Aichelburg', 48.6355700, 9.5637300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39951, 'Aicha vorm Wald', 'Aicha vorm Wald', 'Aicha,Aicha vorm Wald,Aicha vorm Woid,Ajkha vorm Vald,Ajkha-form-Val''d,Ayxa form Vald,ai xia fu er mu wa er de,aycha warm wald,Айха-форм-Вальд,Ајха ворм Валд,Այխա ֆորմ Վալդ,ایچا وارم والد,艾夏福尔姆瓦尔德', 48.6760100, 13.2954200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39952, 'Aichach', 'Aichach', 'Aicha,Aichach,Ajkhakh,Ayxax,Gorad Ajkhakh,ai xia,aihyahha,aychakh,ayshakh,Άιχαχ,Айхах,Ајхах,Горад Айхах,Այխախ,آيشاخ,آیشاخ,ایچاخ,アイヒャッハ,艾夏', 48.4575500, 11.1341300, 'DE', '2017-05-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39953, 'Ahsen-Oetzen', 'Ahsen-Oetzen', 'Ahsen-Oetz,Ahsen-Oetzen,Oetzen', 52.9586800, 9.0793300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39954, 'Ahrenviöl', 'Ahrenviol', '', 54.5313100, 9.2068300, 'DE', '2011-08-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39955, 'Ahrensfelde', 'Ahrensfelde', 'Arensfel''de,Arensfelde,a lun si fei er de,ahrnsfld,Аренсфелде,Аренсфельде,Արենսֆելդե,اهرنسفلد,阿伦斯费尔德', 52.5765600, 13.5797000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39956, 'Ahrensburg', 'Ahrensburg', 'Ahrensburg,Arensburg,Arensburgas,Stadt Ahrensburg,a lun si bao,arnsbwrg,arynsbwrgh,Аренсбург,آرنسبورگ,آرينسبورغ,阿伦斯堡', 53.6751500, 10.2259300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39957, 'Ahrensbök', 'Ahrensbok', 'Ahrensbock,Ahrensboek,Ahrensbok,Ahrensbök,Arensbek,Arensbjok,a lun si bo ke,ahrnsbak,Аренсбек,Аренсбёк,Аренсбөк,اهرنسباک,阿伦斯伯克', 54.0086200, 10.5743400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39958, 'Ahorn', 'Ahorn', 'Ahorn', 50.2376200, 10.9541700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39959, 'Aholming', 'Aholming', 'Agol''ming,Aholming,Akhol''ming,Akholming,a huo er ming ge,ahalmyng,Агольмінг,Ахолминг,Ахольминг,Ահոլմինգ,اهالمینگ,阿霍尔明格', 48.7354200, 12.9099700, 'DE', '2012-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39960, 'Aholfing', 'Aholfing', '', 48.9428300, 12.4685700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39961, 'Ahnsen', 'Ahnsen', 'Aohnsen', 52.2546600, 9.1008900, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39962, 'Ahnsbeck', 'Ahnsbeck', 'Ansbek,a en si bei ke,ahnsbk,Ансбек,اهنسبک,阿恩斯贝克', 52.6107100, 10.2853400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39963, 'Ahneby', 'Ahneby', 'Ahneby,Aneby,Åneby', 54.7166700, 9.7333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39964, 'Ahlstädt', 'Ahlstadt', 'Ahlstadt,Ahlstädt', 50.5333300, 10.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39965, 'Ahlsdorf', 'Ahlsdorf', '', 51.5454300, 11.4665500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39966, 'Ahlerstedt', 'Ahlerstedt', '', 53.4000000, 9.4500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39967, 'Ahlen', 'Ahlen', 'Ahlen,Alen,Alenas,Alene,Alna,Alnon,Aulen,a lun,ahln,allen,aren,Ālene,Ālna,Ālnon,Ален,اهلن,اہلن,アーレン,阿伦,알렌', 51.7633800, 7.8887000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39968, 'Ahlden', 'Ahlden', 'Ahlden,Al''den,Alden,a er deng,ahldn,Алден,Альден,اهلدن,اہلدن,阿尔登', 52.7596800, 9.5511500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39969, 'Ahlbeck', 'Ahlbeck', 'Ahlbeck', 53.6697200, 14.1862200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39970, 'Ahausen', 'Ahausen', 'Ahausen,Ahusen,Akhauzen,a hao sen,ahasn,ahauzen,Ахаузен,اهاسن,اہاسن,アハウゼン,阿豪森', 53.0666700, 9.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39971, 'Ahaus', 'Ahaus', 'Aahusium,Agaus,Ahaus,Akhaus,a hao si,ahaws,Агаус,Ахаус,آهاوس,阿豪斯', 52.0793600, 7.0134400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39972, 'Aham', 'Aham', 'Agam,Aham,Akham,a ha mu,aham,Агам,Ахам,Ահամ,اهام,اہام,阿哈姆', 48.5265100, 12.4606400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39973, 'Aham', 'Aham', '', 48.3482100, 12.1615600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39974, 'Aglasterhausen', 'Aglasterhausen', 'Aglastergauzen,Aglasterkhauzen,a ge la si te lao sen,aglastrhasn,agurasutahauzen,Агластергаузен,Агластерхаузен,اگلاسترهاسن,اگلاسترہاسن,アグラスターハウゼン,阿格拉斯特劳森', 49.3569400, 8.9869400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39975, 'Agethorst', 'Agethorst', 'Agethorst', 54.0194700, 9.4359000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39976, 'Agathenburg', 'Agathenburg', '', 53.5606500, 9.5318000, 'DE', '2011-08-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39977, 'Affler', 'Affler', '', 50.0166700, 6.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39978, 'Affinghausen', 'Affinghausen', '', 52.7833300, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39979, 'Affing', 'Affing', 'Affing,Afing,a fen ge,afingu,afyng,Афинг,Аффинг,Аффінг,Աֆֆինգ,آفینگ,アフィング,阿芬格', 48.4666700, 10.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39980, 'Affalterbach', 'Affalterbach', 'Afalterbakh,Affal''terbakh,a fa er te er ba he,afaltrbakh,Афалтербах,Аффальтербах,آفالترباخ,阿法尔特尔巴赫', 48.9226700, 9.3236200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39981, 'Aerzen', 'Aerzen', '*Arthilis-husun,Aartlessen [a. 1317],Aercen,Arzen,Ehrcen,a ai er cen,aerutsu~en,Ärzen,Аерцен,Эрцен,アエルツェン,阿埃尔岑', 52.0495300, 9.2585600, 'DE', '2014-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39982, 'Adorf', 'Adorf', 'Adorf,Adorfa,a duo fu,adwrf,Адорф,آدورف,阿多夫', 50.3201100, 12.2598600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39983, 'Adlkofen', 'Adlkofen', 'Adl''kofen,Adlkofen,a de er ke fen,Адлкофен,Адлькофен,Ադլքոֆեն,ادل‌کافن,ადლკოფენი,阿德尔科芬', 48.5500000, 12.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39984, 'Adlershof', 'Adlershof', 'Adlerskhof,Aldershof,Berlin-Adlershof,adlrshaf,Адлерсхоф,ادلرشاف', 52.4354800, 13.5482500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39985, 'Adenstedt', 'Adenstedt', 'Adenshtedt,Adenshtet,Adenstede [a. 1282],Adenstide [a. 1282],Ahnstie,Oahnstie,a deng si te,adnstdt,Аденштедт,Аденштет,ادنستدت,阿登斯特', 51.9985200, 9.9351600, 'DE', '2014-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39986, 'Adendorf', 'Adendorf', 'Adendorf,a deng duo fu,adndarf,Адендорф,ادندارف,阿登多夫', 53.2818900, 10.4378700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39987, 'Adenbüttel', 'Adenbuettel', 'Adenbitel,Adenbjuttel'',Adenebutle [a. 1226],a deng bi te er,adnbwtl,Аденбител,Аденбюттель,ادنبوتل,阿登比特尔', 52.3798400, 10.4507900, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39988, 'Adenbach', 'Adenbach', 'Adenbakh,a deng ba he,adnbakh,Аденбах,ادنباخ,阿登巴赫', 49.6666700, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39989, 'Adenau', 'Adenau', 'Adenau,a de nao,adenau,adnaw,Аденау,آدناو,アーデナウ,阿德瑙', 50.3823800, 6.9329100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39990, 'Adelzhausen', 'Adelzhausen', 'Adel''cgauzen,Adel''ckhauzen,Adelckhauzen,a de er ci hao sen,adeltshauzeni,aderutsuhauzen,adlzhaywsn,Аделцхаузен,Адельцгаузен,Адельцхаузен,Ադելցհաուզեն,ادلژائوسن,ადელცჰაუზენი,アーデルツハウゼン,阿德尔茨豪森', 48.3567100, 11.1385100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39991, 'Adelsried', 'Adelsried', 'Adel''srid,Adelsrid,Adlsriad,a de er si li de,adelsridi,adlsrayd,Аделсрид,Адельсрид,Адельсрід,Ադելսրիդ,ادلسراید,ადელსრიდი,阿德尔斯里德', 48.4246500, 10.7182800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39992, 'Adelshofen', 'Adelshofen', '', 49.4333300, 10.1666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39993, 'Adelshofen', 'Adelshofen', '', 48.1833300, 11.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39994, 'Adelsheim', 'Adelsheim', 'Adel''sgajm,Adel''skhajm,Adelshaym,Adelsheim,Adelskhajm,a de er si hai mu,aderusuhaimu,adlshaym,Аделсхајм,Адельсгайм,Адельсхайм,آدلسهايم,آدلسهایم,アーデルスハイム,阿德尔斯海姆', 49.4015000, 9.3925000, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39995, 'Adelsdorf', 'Adelsdorf', '', 49.7121600, 10.8950000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39996, 'Adelsdorf', 'Adelsdorf', '', 49.4702200, 10.6852200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39997, 'Adelschlag', 'Adelschlag', 'Adel''shlag,Adelschlag,Adelshlag,Adelslag,a de er shi la ge,adelshlagi,adlskag,Аделшлаг,Адельшлаг,Ադելշլագ,ادلسکاگ,ადელშლაგი,阿德尔施拉格', 48.8402500, 11.2191300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39998, 'Adelmannsfelden', 'Adelmannsfelden', 'Adel''mannsfel''den,Adel''mansfel''den,Adelmansfelden,a de er man si fei er deng,adelmanspeldeni,adlmansfldn,Аделмансфелден,Адельманнсфельден,Адельмансфельден,ادلمانسفلدن,ადელმანსფელდენი,阿德尔曼斯费尔登', 48.9547600, 10.0046600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(39999, 'Adelheidsdorf', 'Adelheidsdorf', 'Aalheidsdoerp,Aalheidsdörp,Adel''khajdsdorf,Adelkhajdsdorf,a de er hai ci duo fu,adlhdzdraf,Аделхајдсдорф,Адельхайдсдорф,ادلهدزدراف,阿德尔海茨多夫', 52.5640400, 10.0603900, 'DE', '2014-08-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40000, 'Adelebsen', 'Adelebsen', 'Aalessen,Adelebsen,Adelebzen,Adelevessen [a. 1234],Alessen,Dransfeld,Ethelleveshusen [a. 990],a de lai bu sen,aderepuzen,adlbsn,Аделебзен,Аделебсен,ادلبسن,アーデレプゼン,阿德莱布森', 51.5827200, 9.7546100, 'DE', '2014-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40001, 'Adelberg', 'Adelberg', 'Adel''berg,Adelberg,Adelberg-Dorf,Dorf-Adelberg,a de er bei ge,adlbrg,Аделберг,Адельберг,ادلبرگ,阿德尔贝格', 48.7622700, 9.5999100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40002, 'Achtrup', 'Achtrup', 'Agtrup,Akhtrup,Aktoorp,a te lu pu,aktrap,Åktoorp,Ахтруп,اکتراپ,阿特鲁普', 54.7905300, 9.0284800, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40003, 'Achterwehr', 'Achterwehr', 'Akhterver,a te er wei er,aktrwr,Ахтервер,اکترور,阿特尔韦尔', 54.3131800, 9.9661000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40004, 'Achtelsbach', 'Achtelsbach', 'Akhtel''sbakh,Akhtelsbakh,a te er si ba he,Ахтелсбах,Ахтельсбах,اکتلس‌باچ,阿特尔斯巴赫', 49.6253500, 7.0899500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40005, 'Acht', 'Acht', '', 50.3666700, 7.0666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40006, 'Achstetten', 'Achstetten', 'Akhshteten,Akhshtetten,a si te teng,aksttn,Ахштетен,Ахштеттен,Ախշտեթեն,اکستتن,ახშტეტენი,阿斯特滕', 48.2588600, 9.8974800, 'DE', '2012-03-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40007, 'Achslach', 'Achslach', 'Akhslakh,Akslakh,a si la,akslach,Акслах,Ахслах,Աքսլախ,اکسلاچ,阿斯拉', 48.9717100, 12.9351100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40008, 'Achim', 'Achim', 'Achem,Akhim,Uphusen,a xi mu,ahimu,akhym,Ахим,آخيم,آخیم,アヒム,阿希姆', 53.0141600, 9.0263000, 'DE', '2011-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40009, 'Achern', 'Achern', 'Achara,Achern,Akhern,a he en,akhrn,Ахерн,آخرن,阿赫恩', 48.6311500, 8.0760700, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40010, 'Abtweiler', 'Abtweiler', 'Abtvajler,Abtweiler,Apweiler,a bu te wei lei,abtwylr,Абтвайлер,Абтвајлер,ابتویلر,阿布特韦勒', 49.7500000, 7.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40011, 'Abtsgmünd', 'Abtsgmund', 'Abtsgmind,Abtsgmjund,Abtsgmuend,Abtsgmünd,a bu ci ge ming de,abstwmand,Абтсгминд,Абтсгмюнд,ابستوماند,აბტსგმიუნდი,阿布茨格明德', 48.8950300, 10.0017200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40012, 'Abtsdorf', 'Abtsdorf', '', 51.8898400, 12.7252600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40013, 'Abtsbessingen', 'Abtsbessingen', 'Abtsbesingen,Abtsbessingen,a bu ci bei xin gen,absbsynyn,Абтсбесинген,Абтсбессинген,Абтсбессінген,ابسبسینین,阿布茨贝辛根', 51.2614100, 10.7628000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40014, 'Aebtissinwisch', 'Aebtissinwisch', 'Abtissinwisch,Aebtissinwisch,Äbtissinwisch', 53.9666700, 9.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40015, 'Abstatt', 'Abstatt', 'Abshtat,a bu si ta te,abstat,apushutatto,Абштат,ابستات,アプシュタット,阿布斯塔特', 49.0682000, 9.2907000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40016, 'Absberg', 'Absberg', 'Absberg,a bu si bei ge,absbergi,absbrg,Абсберг,Աբսբերգ,ابسبرگ,აბსბერგი,阿布斯贝格', 49.1443800, 10.8810100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40017, 'Abentheuer', 'Abentheuer', '', 49.6500000, 7.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40018, 'Abensberg', 'Abensberg', 'Abensberg,Abensberq,Abensperg,Aventinum,Gorad Abensberg,Omschberg,a ben si bei ge,abensbergi,abnsbrg,abnsbrgh,Абенсберг,Горад Абенсберг,Աբենսբերգ,آبنسبرغ,آبنسبرگ,აბენსბერგი,አበንስበርግ,阿本斯贝格', 48.8168400, 11.8498000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40019, 'Abenberg', 'Abenberg', 'Abenberg,Abenberq,a ben bei ge,abenbergi,abenberuku,Абенберг,Աբենբերգ,آبن‌برغ,آبن‌برگ,აბენბერგი,アーベンベルク,阿本贝格', 49.2428200, 10.9640100, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40020, 'Abbesbüttel', 'Abbesbuettel', 'Abesbuttel [a. 1397]', 52.3523300, 10.5564900, 'DE', '2015-09-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40021, 'Aasbüttel', 'Aasbuttel', 'Aasbuttel,Aasbüttel', 54.0666700, 9.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40022, 'Aalen', 'Aalen', 'Aalen,Ala,Alen,Alenas,Alene,a lun,aaleni,allen,aln,alyn,aren,Ālene,Άαλεν,Аален,Ален,آلن,آلین,აალენი,アーレン,阿倫,알렌', 48.8377700, 10.0933000, 'DE', '2014-05-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40023, 'Aach', 'Aach', '', 49.7833300, 6.6000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40024, 'Aach', 'Aach', 'Aach', 47.8424000, 8.8538400, 'DE', '2013-02-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40025, 'Eggermühlen', 'Eggermuhlen', 'Egermilen,Ehggermjulen,ai ge er mi he lun,Егермилен,Эггермюлен,埃格尔米赫伦', 52.5666700, 7.8166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40026, 'Thalfang', 'Thalfang', 'Tal''fang,Talfang,ta er fang,tarufangu,Талфанг,Тальфанг,タールファング,塔尔方', 49.7500000, 7.0000000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40027, 'Quendorf', 'Quendorf', '', 52.3333300, 7.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40028, 'Nienwohld', 'Nienwohld', 'Nienwohld', 53.7869400, 10.1944400, 'DE', '2011-08-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40029, 'Traventhal', 'Traventhal', 'Traventhal', 53.9000000, 10.3166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40030, 'Erdeborn', 'Erdeborn', 'Erdeborn', 51.4755400, 11.6348700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40031, 'Barby', 'Barby', 'Barby,Bareboi', 51.9671100, 11.8826100, 'DE', '2015-12-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40032, 'Hohenau', 'Hohenau', '', 48.8498300, 13.4882500, 'DE', '2011-08-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40033, 'Apfeldorf', 'Apfeldorf', '', 47.9000000, 10.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40034, 'Eglfing', 'Eglfing', '', 47.7333300, 11.1833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40035, 'Höhenkirchen-Siegertsbrunn', 'Hohenkirchen-Siegertsbrunn', 'Geenkirkhen-Zigertsbrunn,Hoehenkirchen-Siegertsbrunn,Höhenkirchen-Siegertsbrunn,Khekhenkirkhen-Zigertsbrun,Khjoehnkirkhen-Zigertsbrunn,he heng ji er xing-xi ge er ci bu lun,hwhn kyrshn-zygrtsbrwn,Геенкірхен-Зігертсбрунн,Хехенкирхен-Зигертсбрун,Хёэнкирхен-Зигертсбрунн,Հյոենկիրխեն Զիգերթսբրուն,هوهن کیرشن-زیگرتسبرون,赫亨基尔兴-西格尔茨布伦', 48.0193200, 11.7190600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40036, 'Missen-Wilhams', 'Missen-Wilhams', 'Misen Vilhams,Misen-Vilkhams,Missen-Vil''gams,Missen-Vil''khams,mi sen-wei er ha mu si,Мисен-Вилхамс,Миссен-Вильхамс,Міссен-Вільгамс,Միսեն Վիլհամս,米森-维尔哈姆斯', 47.6000000, 10.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40037, 'Oy-Mittelberg', 'Oy-Mittelberg', 'Oj-Mitelberg,Oj-Mittel''berg,ao yi-mi te er bei ge,Ой-Миттельберг,Ой-Міттельберг,Ој-Мителберг,Օյ Միթելբերգ,奥伊-米特尔贝格', 47.6333300, 10.4333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40038, 'Straßlach-Dingharting', 'Strasslach-Dingharting', 'Shtraslakh-Dingarting,Shtraslakh-Dingkharting,Strasslach,Strasslach-Dingharting,Straßlach,Straßlach-Dingharting,ashtraslakh-dyng hartyng,shi te la si la he-ding ha ting,Штраслах-Дингхартинг,Штраслах-Дінгартінг,Շթրասլախ Դինգհարթինգ,اشتراسلاخ-دینگ هارتینگ,施特拉斯拉赫-丁哈廷', 48.0049100, 11.5141000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40039, 'Sankt Leonhard am Wonneberg', 'Sankt Leonhard am Wonneberg', 'Sankt Leonhard am Wonneberg', 47.9153300, 12.7192600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40040, 'Seeon-Seebruck', 'Seeon-Seebruck', 'Seeon-Seebruck,Seon-Seebruck,Zeeon-Zeebruk,Zeon-Zebruk,sai weng-sai bu lu ke,zyywn-zybrwk,Зееон-Зеебрук,Зеон-Зебрук,Զեեոն Զեեբրուք,زیئون-زیبروک,塞翁-塞布鲁克', 47.9666700, 12.4666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40041, 'Weiler-Simmerberg', 'Weiler-Simmerberg', 'Weiler-Simmerberg', 47.5826100, 9.9135200, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40042, 'Bodman-Ludwigshafen', 'Bodman-Ludwigshafen', 'Bodman-Ljudvigskhafen,Bodman-Ludvigsgafen,Bodman-Ludvigskhafen,bo de man-lu de wei ge si ha fen,Бодман-Лудвигсхафен,Бодман-Лудвігсгафен,Бодман-Людвигсхафен,博德曼-卢德维格斯哈芬', 47.8181700, 9.0554000, 'DE', '2013-04-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40043, 'Eggingen', 'Eggingen', 'Eggingen,Egingen,Ehggingen,ai jin gen,Еггінген,Егинген,Эггинген,埃金根', 47.7000000, 8.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40044, 'Emmingen-Liptingen', 'Emmingen-Liptingen', 'Ehmmingen-Liptingen,Emingen-Liptingen,ai ming gen-li pu ting gen,Еминген-Липтинген,Эмминген-Липтинген,埃明根-利普廷根', 47.9333300, 8.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40045, 'Herdwangen-Schönach', 'Herdwangen-Schonach', 'Gerdvangen-Shenakh,Herdwangen-Schoenach,Herdwangen-Schonach,Herdwangen-Schönach,Kherdvangen-Shenakh,Kherdvangen-Shjonakh,hei er de wan gen-she na,Гердванген-Шенах,Хердванген-Шенах,Хердванген-Шёнах,黑尔德万根-舍纳', 47.8500000, 9.2000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40046, 'Lauchringen', 'Lauchringen', 'Laukhringen,Lauringen,lao he lin gen,Лауринген,Лаухринген,劳赫林根', 47.6269900, 8.3144200, 'DE', '2011-07-18', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40047, 'Mühlhausen-Ehingen', 'Muhlhausen-Ehingen', 'Milkhauzen-Ekhingen,Mjul''gauzen-Egingen,Mjul''khauzen-Ehkhingen,Muehlhausen-Ehingen,Mühlhausen-Ehingen,mi he er hao sen-ai xin gen,Милхаузен-Ехинген,Мюльгаузен-Егінген,Мюльхаузен-Эхинген,米赫尔豪森-埃欣根', 47.8110200, 8.8122400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40048, 'Uhldingen-Mühlhofen', 'Uhldingen-Muhlhofen', 'Uhldingen-Muehlhofen,Uhldingen-Muhlhofen,Uhldingen-Mühlhofen,Ul''dingen-Mjul''khofen,Uldingen-Milkhofen,Unteruhldigen,wu er ding gen-mi he er huo fen,Улдинген-Милхофен,Ульдинген-Мюльхофен,乌尔丁根-米赫尔霍芬', 47.7333300, 9.2500000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40049, 'Ühlingen-Birkendorf', 'Uhlingen-Birkendorf', 'Ilingen-Birkendorf,Julingen-Birkendorf,UEhlingen-Birkendorf,yu lin gen-bi ken duo fu,Ühlingen-Birkendorf,Илинген-Биркендорф,Юлінген-Біркендорф,于林根-比肯多夫', 47.7166700, 8.3166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40050, 'Altes Lager', 'Altes Lager', 'Al''tes Lager,Altes Lager,Альтес Лагер', 48.4175500, 9.5360600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40051, 'Aspach', 'Aspach', 'Aspach', 48.9666700, 9.4000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40052, 'Bad Peterstal-Griesbach', 'Bad Peterstal-Griesbach', 'Bad Peterstal-Grisbakh,Bad-Peterstal''-Grisbakh,ba te bi de si ta er-ge li si ba he,Бад Петерстал-Грисбах,Бад-Петерсталь-Грисбах,Бад-Петерсталь-Грісбах,巴特彼得斯塔尔-格里斯巴赫', 48.4333300, 8.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40053, 'Bad Rippoldsau-Schapbach', 'Bad Rippoldsau-Schapbach', 'Bad Ripoldsau-Shapbakh,Bad-Rippol''dzau-Shapbakh,ba te li bo er cao-sha pu ba he,Бад Риполдсау-Шапбах,Бад-Риппольдзау-Шапбах,Бад-Ріппольдзау-Шапбах,Բադ Ռիփոլդզաու Շապբախ,巴特里波尔曹-沙普巴赫', 48.4000000, 8.3333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40054, 'Bad Teinach-Zavelstein', 'Bad Teinach-Zavelstein', 'Bad Tajnakh-Cavelshtajn,Bad-Tajnakh-Cafel''shtajn,ba te tai na he-cha fei er shi tai yin,bad taynakh-tsaflshtayn,Бад Тајнах-Цавелштајн,Бад-Тайнах-Цафельштайн,Բադ Տայնախ Ցաֆելշտայն,باد تايناخ-تسافلشتاين,باد تایناخ-زوالن‌اشتاین,巴特泰纳赫-察费尔施泰因', 48.6905100, 8.6928500, 'DE', '2013-03-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40055, 'Böbingen an der Rems', 'Bobingen an der Rems', 'Bebingen an der Rems,Bebingen-an-der-Rems,Bjobingen-na-Remse,Boebingen,Boebingen an der Rems,Böbingen,Böbingen an der Rems,bebingen-an-der-remsi,lei mu si he pan bo bin gen,Бебинген ан дер Ремс,Бебінген-ан-дер-Ремс,Бёбинген-на-Ремсе,ბებინგენ-ან-დერ-რემსი,雷姆斯河畔伯宾根', 48.8195500, 9.9213000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40056, 'Burgstetten', 'Burgstetten', 'Burgshteten,Burgshtetten,bu er ge si te teng,Бургштетен,Бургштеттен,布尔格斯特滕', 48.9280500, 9.3723900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40057, 'Gutenzell-Hürbel', 'Gutenzell-Hurbel', 'Gutencel-Khirbel,Gutencell''-Gjurbel'',Gutencell''-Khjurbel'',Gutenzell-Huerbel,Gutenzell-Hurbel,Gutenzell-Hürbel,Гутенцел-Хирбел,Гутенцелль-Гюрбель,Гутенцелль-Хюрбель,Գուտենցել Հյուրբել,გუტენცელ-ჰიურბელი', 48.1166700, 9.9833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40058, 'Königsbach-Stein', 'Konigsbach-Stein', 'Kenigsbakh-Shtajn,Kjonigsbakh-Shtajn,Koenigsbach-Stein,Konigsbach-Stein,Königsbach-Stein,ke ni xi si ba he-shi tai yin,Кенигсбах-Штајн,Кенігсбах-Штайн,Кёнигсбах-Штайн,Քյոնիգսբախ Շտայն,柯尼希斯巴赫-施泰因', 48.9658500, 8.6057300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40059, 'Niefern-Öschelbronn', 'Niefern-Oschelbronn', 'Niefern-OEschelbronn,Niefern-Oschelbronn,Niefern-Öschelbronn,Nifern Eselbron,Nifern-Ehshel''bronn,Nifern-Eshel''bronn,Nifern-Eshelbron,ni fei er en-e she er bu long,Ниферн-Ешелброн,Ниферн-Эшельбронн,Ніферн-Ешельбронн,Նիֆերն Էշելբրոն,尼费尔恩-厄舍尔布龙', 48.9166700, 8.7833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40060, 'Ölbronn-Dürrn', 'OElbronn-Duerrn', 'Ehl''bron-Djurn,El''bronn-Djurrn,Elbron Dyurn,Elbron-Dirn,OElbronn-Duerrn,e er bu long-di en,Ölbronn-Dürrn,Елброн-Дирн,Ельбронн-Дюррн,Эльброн-Дюрн,Էլբրոն Դյուրն,厄尔布龙-迪恩', 48.9666700, 8.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40061, 'Rietheim-Weilheim', 'Rietheim-Weilheim', 'Ritkhajm-Vajl''khajm,Ritkhajm-Vajlkhajm,li tai mu-wei er hai mu,Ритхайм-Вайльхайм,Ритхајм-Вајлхајм,里泰姆-魏尔海姆', 48.0166700, 8.7666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40062, 'Seitingen-Oberflacht', 'Seitingen-Oberflacht', 'Zajtingen-Oberflakht,sai ting gen-ao bei er fu la te,Зайтинген-Оберфлахт,Зајтинген-Оберфлахт,赛廷根-奥贝尔夫拉特', 48.0166700, 8.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40063, 'Urbach', 'Urbach', '', 48.8168000, 9.5769000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40064, 'Giesen', 'Giesen', 'Gizen,Iesen,Joisen,Гизен', 52.1971600, 9.8989000, 'DE', '2014-07-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40065, 'Häuslingen', 'Hauslingen', 'Haeuslingen,Häuslingen', 52.8099200, 9.3922800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40066, 'Mallersdorf-Pfaffenberg', 'Mallersdorf-Pfaffenberg', 'Malersdorf-Pfafenberg,Mallersdorf,Mallersdorf-Pfaffenberg,ma lei si duo fu-pu fa fen bei ge,malrsdwrf-fafnbrg,Малерсдорф-Пфафенберг,Маллерсдорф-Пфаффенберг,مالرسدورف-فافنبرگ,马勒斯多夫-普法芬贝格', 48.7663700, 12.2309600, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40067, 'Altendorf', 'Altendorf', '', 49.8000000, 11.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40068, 'Muhr am See', 'Muhr am See', 'Muhr,Muhr am See,Mur am Ze,Mur-am-Ze,bin hu mu er,Мур ам Зе,Мур-ам-Зе,Մուր ամ Զե,滨湖穆尔', 49.1544500, 10.7184500, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40069, 'Postbauer-Heng', 'Postbauer-Heng', 'Postbauehr-Kheng,Postbauer-Geng,Postbauer-Heng,Postbauer-Kheng,bo si te bao ai er-heng,Постбауер-Генг,Постбауер-Хенг,Постбауэр-Хенг,Փոսթբաուեր Հենգ,波斯特鲍埃尔-亨', 49.3052800, 11.3572200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40070, 'Viereth-Trunstadt', 'Viereth-Trunstadt', 'Firet Trunstadt,Firet-Trunshtadt,Firet-Trunshtat,fei lei te-te lun si ta te,fireto=torunshutatto,Фирет-Трунштадт,Фирет-Трунштат,Фірет-Трунштадт,Ֆիրետ Տրունշտադտ,フィーレト＝トルンシュタット,菲雷特-特伦斯塔特', 49.9222200, 10.7771600, 'DE', '2012-11-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40071, 'Weilersbach', 'Weilersbach', '', 49.7500000, 11.1166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40072, 'Katlenburg-Lindau', 'Katlenburg-Lindau', 'Katelnborg-Lindau,Katlenburg-Lindau,ka te lun bu er ge-lin dao,katorenburuku=rindau,Катленбург-Линдау,カトレンブルク＝リンダウ,卡特伦布尔格-林道', 51.6833300, 10.1000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40073, 'Schulenberg im Oberharz', 'Schulenberg im Oberharz', 'Schulenberg in montibus Harthicis superioribus,Shulenberg,Shulenberg im Oberkharc,Shulenberg vo Goren Kharc,shang ha ci shan qu shu lun bei ge,Шуленберг,Шуленберг во Горен Харц,Шуленберг им Оберхарц,上哈茨山区舒伦贝格', 51.8333300, 10.4333300, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40074, 'Nemsdorf-Göhrendorf', 'Nemsdorf-Goehrendorf', 'Nemsdorf-Gohrendorf,Nemsdorf-Göhrendorf', 51.3500000, 11.6500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40075, 'Kromsdorf', 'Kromsdorf', 'Kromsdorf,ke luo mu si duo fu,Кромсдорф,克罗姆斯多夫', 51.0000000, 11.3666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40076, 'Schönstedt', 'Schoenstedt', 'Schoenstedt,Schönstedt', 51.1200000, 10.5774300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40077, 'Topfstedt', 'Topfstedt', 'Topfstedt', 51.2666700, 10.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40078, 'Urleben', 'Urleben', '', 51.1500000, 10.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40079, 'Vellmar', 'Vellmar', 'Fel''mar,Fell''mar,Felmar,fei er ma er,feruma,flmar,Фелльмар,Фелмар,Фельмар,فلمار,フェルマー,费尔马尔', 51.3580600, 9.4797400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40080, 'Scheden', 'Scheden', 'Scheden', 51.4500000, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40081, 'Möhnesee', 'Mohnesee', 'Moehnesee,Mohnesee,Möhnesee', 51.5000000, 8.1333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40082, 'Schieder-Schwalenberg', 'Schieder-Schwalenberg', 'Shider-Shvalenberg,shydr-ashwalnbrg,xi de er-shi wa lun bei ge,Шидер-Шваленберг,شیدر-اشوالنبرگ,席德尔-施瓦伦贝格', 51.8771300, 9.1953800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40083, 'Lautertal', 'Lautertal', '', 50.3333300, 10.9666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40084, 'Rödental', 'Rodental', 'Redental,Redental'',Rjodental'',Rodental,Roedental,Ryodental,Rödental,lei deng ta er,redentaru,rwdntal,Редентал,Реденталь,Рёденталь,Ռյոդենտալ,رودنتال,レーデンタール,勒登塔尔', 50.2951600, 11.0412200, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40085, 'Röslau', 'Roslau', 'Reslau,Rjoslau,Roeslau,Ryoslau,Röslau,lei si lao,resurau,Реслау,Рёслау,Ռյոսլաու,レスラウ,勒斯劳', 50.0833300, 11.9833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40086, 'Bocka', 'Bocka', '', 50.8166700, 11.9666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40087, 'Gneus', 'Gneus', 'Gneus', 50.8166700, 11.6833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40088, 'Oberbodnitz', 'Oberbodnitz', 'Oberbodnitz', 50.8000000, 11.6666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40089, 'Osthausen-Wülfershausen', 'Osthausen-Wulfershausen', '', 50.8500000, 11.0833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40090, 'Ruttersdorf-Lotschen', 'Ruttersdorf-Lotschen', 'Ruttersdorf-Lotschen', 50.8833300, 11.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40091, 'Saara', 'Saara', '', 50.8500000, 11.9666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40092, 'Bruchmühlbach-Miesau', 'Bruchmuhlbach-Miesau', 'Bruchmuehlbach-Miesau,Bruchmühlbach-Miesau,Brukhmjul''bakh-Mizau,Brumilbakh-Mizau,bu lu mi he er ba-mi shao,buruffumyurubahha=mizau,Брумилбах-Мизау,Брухмюльбах-Мизау,ブルッフミュールバッハ＝ミーザウ,布鲁米赫尔巴-米绍', 49.3833300, 7.4333300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40093, 'Gossersweiler-Stein', 'Gossersweiler-Stein', '', 49.1500000, 7.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40094, 'Hinzert-Pölert', 'Hinzert-Polert', '', 49.7000000, 6.9000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40095, 'Hirschthal', 'Hirschthal', '', 49.0333300, 7.7500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40096, 'Hochstetten-Dhaun', 'Hochstetten-Dhaun', 'Khokhshteten-Daun,Khokhshtetten-Daun,Khokstetten-Daun,huo si te teng-de hao en,Хокстеттен-Даун,Хохштетен-Даун,Хохштеттен-Даун,霍斯特滕-德豪恩', 49.8000000, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40097, 'Hoppstädten-Weiersbach', 'Hoppstadten-Weiersbach', 'Hoppstaedten-Weiersbach,Hoppstädten-Weiersbach,Khopshtedten-Vajersbakh,Khopshteten-Vajersbakh,huo pu si te teng-wei ai er si ba he,Хопштедтен-Вайерсбах,Хопштетен-Вајерсбах,霍普斯特滕-魏埃尔斯巴赫', 49.6166700, 7.2000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40098, 'Kreimbach-Kaulbach', 'Kreimbach-Kaulbach', 'Krajmbakh-Kaul''bakh,Krajmbakh-Kaulbakh,ke lai yin ba he-kao er ba he,Краймбах-Каульбах,Крајмбах-Каулбах,克赖因巴赫-考尔巴赫', 49.5500000, 7.6333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40099, 'Mannweiler-Cölln', 'Mannweiler-Colln', 'Mannweiler-Coelln,Mannweiler-Cölln', 49.6833300, 7.7833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40100, 'Neumagen-Dhron', 'Neumagen-Dhron', 'Nojmagen-Dkhron,Nojmagen-Dron,nuo yi ma gen-de he long,Ноймаген-Дхрон,Нојмаген-Дрон,ኖይማገን-ድሮን,诺伊马根-德赫龙', 49.8555300, 6.8977700, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40101, 'Oberweiler-Tiefenbach', 'Oberweiler-Tiefenbach', 'Obervajler-Tifenbakh,ao bo wei lei-di fen ba he,Обервайлер-Тифенбах,Обервајлер-Тифенбах,奥伯韦勒-蒂芬巴赫', 49.6000000, 7.6166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40102, 'Offenbach-Hundheim', 'Offenbach-Hundheim', 'Ofenbakh-Khundkhajm,Offenbakh-Khundkhajm,ao fen ba-hong de hai mu,Офенбах-Хундхајм,Оффенбах-Хундхайм,奥芬巴-洪德海姆', 49.6172900, 7.5511700, 'DE', '2017-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40103, 'Osann-Monzel', 'Osann-Monzel', '', 49.9166700, 6.9500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40104, 'Rieschweiler-Mühlbach', 'Rieschweiler-Muehlbach', 'Rieschweiler-Muehlbach,Rieschweiler-Mühlbach,Rieschwiller-Mihlbach,Rishvajler-Milbakh,Rishvajler-Mjul''bakh,li shi wei lei-mi er ba he,Ришвайлер-Мюльбах,Ришвајлер-Милбах,里施韦勒-米尔巴赫', 49.2333300, 7.5000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40105, 'Salmtal', 'Salmtal', 'Zal''mtal'',Zalmtal,sa er mu ta er,Залмтал,Зальмталь,萨尔姆塔尔', 49.9333300, 6.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40106, 'Schönenberg-Kübelberg', 'Schoenenberg-Kuebelberg', 'Schoenenberg-Kuebelberg,Schönenberg-Kübelberg,Shenenberg-Kibelberg,Shjonenberg-Kjubel''berg,she nen bei ge-qu bei er bei ge,shenenberuku=kyuberuberuku,Шененберг-Кибелберг,Шёненберг-Кюбельберг,シェーネンベルク＝キューベルベルク,舍嫩贝格-屈贝尔贝格', 49.4074000, 7.3723300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40107, 'Schweigen-Rechtenbach', 'Schweigen-Rechtenbach', 'Shvajgen-Rekhtenbakh,shi wei gen-lei xi teng ba he,Швайген-Рехтенбах,Швајген-Рехтенбах,施魏根-雷希滕巴赫', 49.0531400, 7.9563800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40108, 'Wilzenberg-Hußweiler', 'Wilzenberg-Hussweiler', '', 49.7000000, 7.2166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40109, 'Zeltingen-Rachtig', 'Zeltingen-Rachtig', 'Cel''tingen-Rakhtig,Celtingen-Rakhtig,Zeltingen-Rachtig,ce er ting gen-la di xi,Целтинген-Рахтиг,Цельтинген-Рахтиг,策尔廷根-拉蒂希', 49.9500000, 7.0166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40110, 'Merheim', 'Merheim', '', 50.9464000, 7.0465600, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40111, 'Ahrbrück', 'Ahrbrueck', 'Arbrik,Arbrjuk,Pons ad Aram,a er bu lu ke,ahrbrak,Арбрик,Арбрюк,اهربراک,阿尔布吕克', 50.4822500, 6.9880400, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40112, 'Birken-Honigsessen', 'Birken-Honigsessen', '', 50.8166700, 7.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40113, 'Bruttig-Fankel', 'Bruttig-Fankel', 'Brutig-Fankel,Bruttig-Fankel'',bu lu di ge-fan ke er,Брутиг-Фанкел,Бруттиг-Фанкель,布鲁蒂格-凡克尔', 50.1333300, 7.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40114, 'Caan', 'Caan', '', 50.4666700, 7.6166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40115, 'Dreikirchen', 'Dreikirchen', '', 50.4333300, 7.9500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40116, 'Dreis-Brück', 'Dreis-Bruck', '', 50.2660300, 6.7923000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40117, 'Ediger-Eller', 'Ediger-Eller', 'Ediger-Eler,Ediger-Eller,Ehdiger-Ehller,ai di ge er-ai lai er,Едигер-Елер,Эдигер-Эллер,埃迪格尔-埃莱尔', 50.1166700, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40118, 'Ellenz-Poltersdorf', 'Ellenz-Poltersdorf', '', 50.1000000, 7.2333300, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40119, 'Fischbach-Oberraden', 'Fischbach-Oberraden', '', 50.0000000, 6.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40120, 'Gondershausen', 'Gondershausen', '', 50.1500000, 7.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40121, 'Hainau', 'Hainau', '', 50.2228800, 7.7823500, 'DE', '2011-12-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40122, 'Hattert', 'Hattert', '', 50.6666700, 7.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40123, 'Heckenbach', 'Heckenbach', '', 50.4666700, 7.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40124, 'Herzfeld', 'Herzfeld', '', 50.1333300, 6.2166700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40125, 'Hohenfels-Essingen', 'Hohenfels-Essingen', '', 50.2500000, 6.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40126, 'Höhn', 'Hohn', 'Khen,Khjon,he he en,Хен,Хён,赫赫恩', 50.6166700, 7.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40127, 'Ingelbach', 'Ingelbach', 'Ingel''bakh,Ingelbakh,aynglbakh,yin ge er ba he,Ингелбах,Ингельбах,اینگلباخ,因格尔巴赫', 50.6829900, 7.7075000, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40128, 'Kalenborn-Scheuern', 'Kalenborn-Scheuern', '', 50.2500000, 6.6000000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40129, 'Kasbach-Ohlenberg', 'Kasbach-Ohlenberg', '', 50.5833300, 7.2666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40130, 'Katzwinkel', 'Katzwinkel', 'Katzwinkel', 50.8147000, 7.8223600, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40131, 'Kirchwald', 'Kirchwald', '', 50.3666700, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40132, 'Kobern-Gondorf', 'Kobern-Gondorf', 'Kobern-Gondorf,ke bo en-gong duo fu,koban=gondorufu,Коберн-Гондорф,コーバン＝ゴンドルフ,科伯恩-贡多夫', 50.3023000, 7.4561200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40133, 'Mittelfischbach', 'Mittelfischbach', '', 50.2536800, 7.9611400, 'DE', '2013-02-21', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40134, 'Mörsbach', 'Moersbach', '', 50.7266700, 7.7833300, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40135, 'Mülheim-Kärlich', 'Muelheim-Kaerlich', 'Milkhajm-Kerlikh,Mjul''khajm-Kerlikh,Muelheim-Kaerlich,Mulheim-Karlich,Mülheim-Kärlich,mi er hai mu-ke er li xi,mwlhaym-krlysh,mwlhaym-kyrlysh,myuruhaimu=kerurihi,Милхајм-Керлих,Мюльхайм-Керлих,مولهايم-كيرليش,مولهایم-کرلیش,ミュールハイム＝ケルリヒ,米尔海姆-克尔利希', 50.3851000, 7.4989000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40136, 'Oberehe-Stroheich', 'Oberehe-Stroheich', '', 50.2833300, 6.7666700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40137, 'Oberhonnefeld-Gierend', 'Oberhonnefeld-Gierend', '', 50.5559200, 7.5224500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40138, 'Ruppach-Goldhausen', 'Ruppach-Goldhausen', '', 50.4666700, 7.8833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40139, 'Sankt Katharinen', 'Sankt Katharinen', 'Sankt Katarinen,Sankt Katharinen,Sankt-Katarinen,Санкт Катаринен,Санкт-Катаринен', 50.5833300, 7.3833300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40140, 'Spay', 'Spay', 'Shpaj,Spay,shi pai,Шпай,Шпај,施派', 50.2588100, 7.6483900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40141, 'Stockum-Püschen', 'Stockum-Puschen', '', 50.6047200, 7.9036100, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40142, 'Wied', 'Wied', '', 50.6391700, 7.7572200, 'DE', '2017-03-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40143, 'Blankenbach', 'Blankenbach', 'Blankenbakh,Blankenbax,bu lan ken ba he,burankenbahha,Бланкенбах,Բլանկենբախ,ブランケンバッハ,布兰肯巴赫', 50.0666700, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40144, 'Riedenberg', 'Riedenberg', 'Ridenberg,li deng bei ge,Риденберг,Ріденберг,Ռիդենբերգ,里登贝格', 50.3199300, 9.8610000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40145, 'Sailauf', 'Sailauf', 'Zajlauf,Zaylauf,sai lao fu,sylf,zairaufu,Зайлауф,Зајлауф,Զայլաուֆ,سیلف,ザイラウフ,赛劳夫', 50.0246100, 9.2593200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40146, 'Florstadt', 'Florstadt', 'Florshtadt,Florshtat,Florstadt,flwrashtat,flwrshtat,fu luo er si ta te,furorushutatto,Флорштадт,Флорштат,فلوراشتات,فلورشتات,フロールシュタット,弗洛尔斯塔特', 50.3166700, 8.8666700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40147, 'Liederbach', 'Liederbach', '', 50.1222100, 8.4939700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40148, 'Schöffengrund', 'Schoeffengrund', 'Schoeffengrund,Schöffengrund,Shefengrund,Sheffengrund,Shjoffengrund,she fen lun de,Шефенгрунд,Шеффенгрунд,Шёффенгрунд,舍芬伦德', 50.4934500, 8.4718300, 'DE', '2015-09-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40149, 'Waldbrunn', 'Waldbrunn', 'Val''dbrunn,Valdbrun,Waldbrunn,Валдбрун,Вальдбрунн', 50.5187500, 8.1081200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40150, 'Waldems', 'Waldems', 'Val''dems,Valdems,Waldems,wa er de mu si,Валдемс,Вальдемс,瓦尔德姆斯', 50.2500000, 8.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40151, 'Walluf', 'Walluf', 'Valluf,Valuf,Walluf,wa lu fu,Валлуф,Валуф,瓦卢夫', 50.0400300, 8.1554500, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40152, 'Diekhusen-Fahrstedt', 'Diekhusen-Fahrstedt', 'Diekhusen-Fahrstedt', 53.9333300, 9.0166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40153, 'Groß Offenseth-Aspern', 'Gross Offenseth-Aspern', 'Gross Offenseth-Aspern,Groß Offenseth-Aspern', 53.8166700, 9.7333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40154, 'Heidmoor', 'Heidmoor', 'Heidmoor', 53.8333300, 9.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40155, 'Klein Offenseth-Sparrieshoop', 'Klein Offenseth-Sparrieshoop', 'Klein Offenseth-Sparrieshoop', 53.7974800, 9.6865300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40156, 'Krempdorf', 'Krempdorf', 'Krempdorf', 53.8333300, 9.4666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40157, 'Asbach-Bäumenheim', 'Asbach-Baumenheim', 'Asbach-Baeumenheim,Asbach-Bäumenheim', 48.6833300, 10.8166700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40158, 'Baar-Ebenhausen', 'Baar-Ebenhausen', 'Baar-Ebengauzen,Bar Ebenhauzen,Bar-Ebenkhauzen,Bar-Ehbenkhauzen,ba er-ai ben hao sen,bar-abnhawzn,Баар-Ебенгаузен,Бар-Ебенхаузен,Бар-Эбенхаузен,Բար Էբենհաուզեն,بار-ابنهاوزن,巴尔-埃本豪森', 48.6706500, 11.4698300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40159, 'Ettringen', 'Ettringen', 'Ehtringen,Etringen,Ettringen,Етринген,Еттрінген,Этринген,Էթրինգեն', 48.1000000, 10.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40160, 'Finningen', 'Finningen', 'Finingen,Finningen,fynyngn,Фининген,Финнинген,Фіннінген,Ֆինինգեն,فینینگن', 48.6545200, 10.4986400, 'DE', '2012-11-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40161, 'Kottgeisering', 'Kottgeisering', '', 48.1166700, 11.1333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40162, 'Medlingen', 'Medlingen', 'Medlingen,mdlyngn,mei de lin gen,Медлинген,Медлінген,Մեդլինգեն,مدلینگن,梅德林根', 48.5702700, 10.3160800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40163, 'Schondorf am Ammersee', 'Schondorf am Ammersee', 'Amerzei Sondorf,Schondorf,Shondorf,Shondorf am Amerze,Shondorf-am-Ammerzee,a mo hu pan xiong duo fu,shwndwrf,Шондорф,Шондорф ам Амерзе,Шондорф-ам-Аммерзее,Ամերզեի Շոնդորֆ,شوندورف,ショーンドルフ・アム・アンマーゼー,阿默湖畔雄多夫', 48.0529600, 11.0913800, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40164, 'Wörth', 'Worth', '', 48.2453100, 11.9021400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40165, 'Dohren', 'Dohren', '', 52.6500000, 7.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40166, 'Isterberg', 'Isterberg', '', 52.3500000, 7.1500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40167, 'Lünne', 'Luenne', 'Line,Ljunne,lu nei,Лине,Люнне,吕内', 52.4295800, 7.4265300, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40168, 'Neukamperfehn', 'Neukamperfehn', '', 53.3364200, 7.5618900, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40169, 'Ahrenshöft', 'Ahrenshoeft', '', 54.5500000, 9.0666700, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40170, 'Aukrug', 'Aukrug', 'Aukrug,ao ke lu ge,Аукруг,奥克鲁格', 54.0833300, 9.7833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40171, 'Bordelum', 'Bordelum', 'Boorlem,Bordelum,bo er de lu mu,Борделум,博尔德卢姆', 54.6333300, 8.9333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40172, 'Bornholt', 'Bornholt', 'Bornholt', 54.1000000, 9.3333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40173, 'Emmelsbüll-Horsbüll', 'Emmelsbull-Horsbull', 'Emmelsbull-Horsbull,Emmelsbüll-Horsbüll', 54.8166700, 8.7000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40174, 'Galmsbüll', 'Galmsbuell', 'Galmsbull,Galmsbüll', 54.7500000, 8.7500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40175, 'Helgoland', 'Helgoland', 'HGL,Helgoland,Khel''goland,Хельголанд', 54.1814300, 7.8863000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40176, 'Hooge', 'Hooge', '', 54.5700000, 8.5480600, 'DE', '2013-11-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40177, 'Jarplund-Weding', 'Jarplund-Weding', 'Jarplund-Weding', 54.7371400, 9.4181300, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40178, 'Lohe-Rickelshof', 'Lohe-Rickelshof', 'Loe-Rikelskhof,Loeh-Rikkel''skhof,Lohe-Rickelshof,luo hei-li ke er si huo fu,Лое-Рикелсхоф,Лоэ-Риккельсхоф,洛黑-里克尔斯霍夫', 54.1880300, 9.0706600, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40179, 'Mohrkirch', 'Mohrkirch', 'Mohrkirch', 54.6666700, 9.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40180, 'Oesterwurth', 'Oesterwurth', 'Oesterwurth', 54.2166700, 8.9833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40181, 'Oldsum', 'Oldsum', 'Ol''dzum,Oldsum,Oldsum auf Foehr,Oldsum auf Föhr,Oldzum,Olersem,ao er chu mu,Олдзум,Олдсум,Ольдзум,奥尔楚姆', 54.7310600, 8.4447100, 'DE', '2013-11-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40182, 'Rabenkirchen-Faulück', 'Rabenkirchen-Faulueck', 'Rabenkirchen-Fauluck,Rabenkirchen-Faulueck,Rabenkirchen-Faulück', 54.6333300, 9.8500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40183, 'Risum-Lindholm', 'Risum-Lindholm', 'Risem-Lonham,Risum-Lindkholm,Rizum-Lindkhol''m,Rizum-Lindkholm,li su mu-lin de huo er mu,Ризум-Линдхолм,Ризум-Линдхольм,Рисум-Линдхолм,里苏姆-林德霍尔姆', 54.7580200, 8.8690600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40184, 'Schnarup-Thumby', 'Schnarup-Thumby', 'Schnarup-Thumby', 54.6500000, 9.6500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40185, 'Süderdorf', 'Suderdorf', 'Suderdorf,Süderdorf', 54.2166700, 9.3500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40186, 'Sylt-Ost', 'Sylt-Ost', 'Sylt,Sylt-Ost', 54.8611000, 8.4114100, 'DE', '2012-04-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40187, 'Tensbüttel-Röst', 'Tensbuttel-Rost', 'Tensbuttel-Rost,Tensbüttel-Röst', 54.1000000, 9.2333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40188, 'Büddenstedt', 'Bueddenstedt', 'Bidenshtet,Bjuddenshtedt,Boeenste''e,Boeenstidde,Boeoenstidde,Böenste''e,Böenstidde,Böönstidde,bi deng si te,bȫənstēə,bǫ̈̄ənstiddə,Биденштет,Бюдденштедт,比登斯特', 52.1703500, 11.0187700, 'DE', '2011-03-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40189, 'Dahlum', 'Dahlum', '', 52.1333300, 10.8500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40190, 'Elbe', 'Elbe', '', 52.0833300, 10.2833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40191, 'Flöthe', 'Flothe', 'Flete,Fljote,Floethe,Flöthe,fu lei te,Флете,Флёте,弗勒特', 52.0833300, 10.4833300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40192, 'Heere', 'Heere', 'Khere,hei lei,Хере,黑雷', 52.0666700, 10.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40193, 'Ilsede', 'Ilsede', 'Il''zede,Ilsede,yi er sai de,Илседе,Ильзеде,伊尔塞德', 52.2634000, 10.1992200, 'DE', '2016-03-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40194, 'Obernholz', 'Obernholz', 'Obernkhol''c,Obernkholc,shang en huo er ci,Обернхолц,Обернхольц,上恩霍尔茨', 52.7664200, 10.5970900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40195, 'Sassenburg', 'Sassenburg', 'Sassenburg,Zasenburg,Zassenburg,sa sen bao,Засенбург,Зассенбург,萨森堡', 52.5166700, 10.6333300, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40196, 'Schwienau', 'Schwienau', '', 53.0056400, 10.4454200, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40197, 'Sickte', 'Sickte', 'Zikte,Зикте', 52.2184700, 10.6424000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40198, 'Vahlberg', 'Vahlberg', 'Fal''berg,Falberg,fa er bei ge,Фалберг,Фальберг,法尔贝格', 52.1333300, 10.7166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40199, 'Bensdorf', 'Bensdorf', 'Bensdorf,ben si duo fu,Бенсдорф,Բենսդորֆ,本斯多夫', 52.4166700, 12.3333300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40200, 'Ebersbach', 'Ebersbach', '', 51.2333300, 13.6500000, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40201, 'Mühlanger', 'Muehlanger', '', 51.8500000, 12.7500000, 'DE', '2015-11-29', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40202, 'Nessa', 'Nessa', '', 51.1456500, 12.0087400, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40203, 'Marschacht', 'Marschacht', 'Gemeen Meschacht,Marshakht,ma er sha te,Маршахт,马尔沙特', 53.4152000, 10.3752400, 'DE', '2011-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40204, 'Henstedt-Ulzburg', 'Henstedt-Ulzburg', 'Khenshtedt-Ul''cburg,Khenshtet-Ulcburg,heng shi tai te-wu er ci bao,Хенштедт-Ульцбург,Хенштет-Улцбург,亨施泰特-乌尔茨堡', 53.8050000, 9.9745200, 'DE', '2017-04-26', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40205, 'Wesenberg', 'Wesenberg', '', 53.8333300, 10.5500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40206, 'Fargau-Pratjau', 'Fargau-Pratjau', 'Fargau-Pratjau', 54.3333300, 10.4166700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40207, 'Admannshagen-Bargeshagen', 'Admannshagen-Bargeshagen', '', 54.1303800, 11.9991500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40208, 'Bartenshagen-Parkentin', 'Bartenshagen-Parkentin', 'Bartenshagen-Parkenthin,Bartenshagen-Parkentin,Bartenskhagen-Parkentin,ba er teng si ha gen-pa er ken ting,Бартенсхаген-Паркентин,巴尔滕斯哈根-帕尔肯廷', 54.0811600, 11.9784900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40209, 'Börgerende-Rethwisch', 'Boergerende-Rethwisch', 'Borgerende-Rethwisch,Börgerende-Rethwisch', 54.1417700, 11.9252800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40210, 'Gattendorf', 'Gattendorf', '', 50.3220700, 11.9977600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40211, 'Rossau', 'Rossau', '', 51.0000000, 13.0666700, 'DE', '2014-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40212, 'Kappel-Grafenhausen', 'Kappel-Grafenhausen', 'Kapel-Grafenkhauzen,Kappel''-Grafengauzen,Kappel''-Grafenkhauzen,Kappel-Grafenhausen,ka pei er-ge la fen hao sen,Капел-Графенхаузен,Каппель-Графенгаузен,Каппель-Графенхаузен,卡佩尔-格拉芬豪森', 48.2838200, 7.7660500, 'DE', '2013-04-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40213, 'Rheinau', 'Rheinau', 'Rajnaau,Rajnau,raynaw,Райнау,Рајнаау,رايناو,رایناو', 48.6660200, 7.9365900, 'DE', '2015-02-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40214, 'Hiddensee', 'Hiddensee', 'Hiddensee', 54.5668900, 13.1041100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40215, 'Diensdorf-Radlow', 'Diensdorf-Radlow', '', 52.2333300, 14.0500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40216, 'Bruchhausen', 'Bruchhausen', '', 50.6000000, 7.2500000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40217, 'Ebersbach-Musbach', 'Ebersbach-Musbach', 'Ebersbach-Musbach,Ebersbakh-Musbakh,Ehbersbakh-Musbakh,ai bei er si ba he-mu si ba he,Еберсбах-Мусбах,Эберсбах-Мусбах,埃贝尔斯巴赫-穆斯巴赫', 47.9666700, 9.5833300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40218, 'Reichenau', 'Reichenau', 'Niederzell', 47.6888500, 9.0635500, 'DE', '2017-07-01', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40219, 'Vogtsburg', 'Vogtsburg', 'Vogtsburg', 48.0968800, 7.6418500, 'DE', '2013-03-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40220, 'Rheinmünster', 'Rheinmuenster', 'Rajnaminster,Rajnmjunster,Rheinmuenster,Rheinmunster,Rheinmünster,lai yin ming si te er,Райнмюнстер,Рајнаминстер,赖因明斯特尔', 48.7522300, 8.0088600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40221, 'Brohl-Lützing', 'Brohl-Lutzing', 'Brol''-Ljutcing,Brol-Licing,bu luo er-lu qin ge,Брол-Лицинг,Броль-Лютцинг,布罗尔-吕钦格', 50.4829600, 7.3290800, 'DE', '2011-07-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40222, 'Burg Hohenstein', 'Burg Hohenstein', '', 50.1919200, 8.0573200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40223, 'Marktrodach', 'Marktrodach', 'Marktrodach,Marktrodakh,ma er ke te luo da,marukutorodahha,Марктродах,Մարքթրոդախ,マルクトローダッハ,马尔克特罗达', 50.2500000, 11.3833300, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40224, 'Triebel', 'Triebel', 'Tribel,Tribel'',te li bei er,Трибел,Трибель,特里贝尔', 50.3715300, 12.1211800, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40225, 'Schmedeswurth', 'Schmedeswurth', 'Schmedeswurth', 53.9166700, 9.0500000, 'DE', '2016-06-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40226, 'Barnitz', 'Barnitz', '', 53.8000000, 10.5000000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40227, 'Peterswald-Löffelscheid', 'Peterswald-Loffelscheid', 'Peterswald-Loeffelscheid,Peterswald-Löffelscheid', 50.0000000, 7.3000000, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40228, 'Ransbach-Baumbach', 'Ransbach-Baumbach', 'Ransbach-Baumbach,Ransbakh-Baumbakh,lan si ba-bo yin ba,ransbakh-bawmbakh,ransubahha=baumubahha,ranzbakh-bawmbakh,Рансбах-Баумбах,رانزباخ-باومباخ,رانسباخ-باومباخ,ランスバッハ＝バウムバッハ,兰斯巴-博因巴', 50.4649600, 7.7283000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40229, 'Ludweiler-Warndt', 'Ludweiler-Warndt', 'Ludweiler,Ludweiler-Warndt,Volkingen-Ludweiler,Völkingen-Ludweiler', 49.2207400, 6.8119500, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40230, 'Aachen', 'Aachen', 'AAH,Aachen,Aakhen,Aaxen,Achen,Achenas,Ahene,Aix-la-Chapelle,Aken,Akhen,Akisgran,Akwizgran,Aoke,Aquae Grani,Aquisgra,Aquisgran,Aquisgrana,Aquisgrano,Aquisgranum,Aquisgrà,Aquisgrán,Axhe,Axin,Axın,Cachy,Cáchy,Kreisfreie Stadt Aachen,Lungsod ng Aachen,Oche,Oochen,a chen,aakheni,achn,ahen,ahkan,akhana,akhn,xa khein,ya chen,Åxhe,Āhene,Άαχεν,Аахен,Ахен,Աախեն,אאכן,آخن,آچن,आखन,ஆஃகன்,ആക്കൻ,อาเคิน,აახენი,アーヘン,亚琛,阿臣,아헨', 50.7766400, 6.0834200, 'DE', '2014-05-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40231, 'Ubstadt-Weiher', 'Ubstadt-Weiher', 'Ubshtadt-Vajehr,Ubshtadt-Vajer,Ubshtadt-Vajger,Ubshtat-Vajkher,awbshtad wyr,wu bu si ta te-wei hei er,Убштадт-Вайгер,Убштадт-Вайер,Убштадт-Вайэр,Убштат-Вајхер,ابسٹاڈٹ-ویہیر,اوبشتاد ویر,乌布斯塔特-魏黑尔', 49.1629600, 8.6316500, 'DE', '2013-04-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40232, 'Stadecken-Elsheim', 'Stadecken-Elsheim', 'Shtadeken-Elskhajm,Shtadekken-Ehl''skhajm,shi ta de ken-ai er si hai mu,Штадекен-Елсхајм,Штадеккен-Эльсхайм,施塔德肯-埃尔斯海姆', 49.9122200, 8.1252800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40233, 'Dannstadt-Schauernheim', 'Dannstadt-Schauernheim', '', 49.4402800, 8.3086100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40234, 'Sankt Leon-Rot', 'Sankt Leon-Rot', 'Sankt Leon-Rot,St. Leon-Rot', 49.2659300, 8.6180300, 'DE', '2013-02-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40235, 'Rödersheim-Gronau', 'Rodersheim-Gronau', 'Roedersheim-Gronau,Rödersheim-Gronau', 49.4300000, 8.2613900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40236, 'Karlsdorf-Neuthard', 'Karlsdorf-Neuthard', 'Karlsdorf-Nojtard,ka er si duo fu-nuo yi ta de,Карлсдорф-Нойтард,Карлсдорф-Нојтард,卡尔斯多夫-诺伊塔德', 49.1347200, 8.5302800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40237, 'Graben-Neudorf', 'Graben-Neudorf', 'Graben-Nojdorf,Grawe-Naidorf,ge la ben-nuo yi duo fu,Грабен-Нойдорф,Грабен-Нојдорф,格拉本-诺伊多夫', 49.1669500, 8.4924300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40238, 'Mörfelden-Walldorf', 'Moerfelden-Walldorf', 'Gorad Mjorfel''dehn-Val''dorf,Merfel''den-Vall''dorf,Merfelden-Valdorf,Mjorfel''den-Val''dorf,Moerfelden-Walldorf,Morfelden-Walldorf,Mörfelden-Walldorf,meruferuden=vu~arudorufu,mo fei er deng-wa er duo fu,mwrfldn-waldwrf,Горад Мёрфельдэн-Вальдорф,Мерфелден-Валдорф,Мерфельден-Валльдорф,Мёрфельден-Вальдорф,مورفلدن-والدورف,メルフェルデン＝ヴァルドルフ,默费尔登-瓦尔多夫', 49.9947200, 8.5836100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40239, 'Linkenheim-Hochstetten', 'Linkenheim-Hochstetten', 'Linkengajm-Gokhshtetten,Linkenkhajm-Khokhshteten,Linkenkhajm-Khokhshtetten,lin ken hai mu-huo si te teng,Линкенхайм-Хохштеттен,Линкенхајм-Хохштетен,Лінкенгайм-Гохштеттен,林肯海姆-霍斯特滕', 49.1319700, 8.4124400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40240, 'Billigheim-Ingenheim', 'Billigheim-Ingenheim', 'Biligkhajm-Ingenkhajm,Billigkhajm-Ingenkhajm,bi li ge hai mu-yin gen hai mu,Билигхајм-Ингенхајм,Биллигхайм-Ингенхайм,比利格海姆-因根海姆', 49.1366700, 8.0905600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40241, 'Böhl-Iggelheim', 'Bohl-Iggelheim', 'Beel-Igglem,Bel-Igelkhajm,Bjol''-Iggel''khajm,Boehl-Iggelheim,Bohl-Iggelheim,Böhl-Iggelheim,bo he er-yi ge er hai mu,Бел-Игелхајм,Бёль-Иггельхайм,伯赫尔-伊格尔海姆', 49.3805600, 8.3038900, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40242, 'Hochdorf-Assenheim', 'Hochdorf-Assenheim', '', 49.4194400, 8.2816700, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40243, 'Alsbach-Hähnlein', 'Alsbach-Hahnlein', 'Al''sbakh-Genljajn,Al''sbakh-Khenlajn,Alsbach-Haehnlein,Alsbach-Hähnlein,Alsbakh-Khenlajn,a er si ba he-hei en lai yin,alsbakh-hahnlyn,arusubahha=henrain,Алсбах-Хенлајн,Альсбах-Генляйн,Альсбах-Хенлайн,السباخ-هاهنلین,アルスバッハ＝ヘーンライン,阿尔斯巴赫-黑恩莱因', 49.7386100, 8.5958300, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40244, 'Dittelsheim-Heßloch', 'Dittelsheim-Hessloch', 'Ditelskhajm-Kheslokh,Dittel''skhajm-Kheslokh,Dittelsheim-Hessloch,Dittelsheim-Heßloch,di te er si hai mu-hei si luo,Дителсхајм-Хеслох,Диттельсхайм-Хеслох,迪特尔斯海姆-黑斯洛', 49.7438900, 8.2369400, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40245, 'Riedstadt', 'Riedstadt', 'Gorad Rydshtat,Ridshtadt,Ridshtat,Ridstadt,Ridştadt,li ci ta te,ritoshutatto,rydashtat,rydshtat,Горад Рыдштат,Ридштадт,Ридштат,Рідштадт,ريدشتات,ریداشتات,リートシュタット,里茨塔特', 49.8341100, 8.4962100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40246, 'Hochstadt', 'Hochstadt', 'Hochstadt', 49.2475000, 8.2088900, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40247, 'Hochborn', 'Hochborn', '', 49.7238900, 8.2008300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40248, 'Leingarten', 'Leingarten', 'Lajngarten,Leingarten,Ljajngarten,lai yin jia er teng,layngardn,raingaruten,Лайнгартен,Лајнгартен,Ляйнгартен,لاینگاردن,ラインガルテン,莱因加尔滕', 49.1463900, 9.1169400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40249, 'Lauda-Königshofen', 'Lauda-Konigshofen', 'Lauda-Kenigsgofen,Lauda-Kenigskhofen,Lauda-Kjonigskhofen,Lauda-Koenigshofen,Lauda-Konigshofen,Lauda-Königshofen,lao da-ke ni xi si huo fen,lawda-kwnyghshwfn,lawda-kwnygzhwfn,rauda=kenihisuhofen,Лауда-Кенигсхофен,Лауда-Кенігсгофен,Лауда-Кёнигсхофен,لاودا-كونيغسهوفن,لاودا-کونیگزهوفن,ラウダ＝ケーニヒスホーフェン,劳达-柯尼希斯霍芬', 49.5652600, 9.7081600, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40250, 'Hesseneck', 'Hesseneck', 'Gessenek,Khesenek,Khessenek,hei sai nei ke,hessenekku,Гессенек,Хесенек,Хессенек,ヘッセネック,黑塞内克', 49.5698700, 9.0628600, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40251, 'Neunkirchen', 'Neunkirchen', '', 49.7072200, 9.4025000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40252, 'Altenbuch', 'Altenbuch', 'Al''tenbukh,Altenbukh,a er teng bu,arutenbufu,atnbakh,Алтенбух,Альтенбух,Ալթենբուխ,اتنباخ,アルテンブーフ,阿尔滕布', 49.8286100, 9.4013900, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40253, 'Mespelbrunn', 'Mespelbrunn', 'Mespel''brunn,Mespelbrun,mei si pei er bu lun,mesuperuburun,Меспелбрун,Меспельбрунн,Մեսպելբրուն,メスペルブルン,梅斯佩尔布伦', 49.9144400, 9.2919400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40254, 'Lützelbach', 'Lutzelbach', 'Licelbakh,Ljutcel''bakh,Luetzelbach,Lutzelbach,Lützelbach,lu ce er ba he,ryuttsu~erubahha,Лицелбах,Лютцельбах,リュッツェルバッハ,吕策尔巴赫', 49.7883300, 9.0752800, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40255, 'Heuchelheim-Klingen', 'Heuchelheim-Klingen', '', 49.1452800, 8.0550000, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40256, 'Filderstadt', 'Filderstadt', 'Fil''dershtadt,Fildershhat,Fildershtat,fei er de er si ta te,fyldrashtat,Филдерштат,Филдерщат,Фильдерштадт,فیلدراشتات,菲尔德尔斯塔特', 48.6569800, 9.2204900, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40257, 'Ostfildern', 'Ostfildern', '', 48.7270400, 9.2495400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40258, 'Rodgau', 'Rodgau', 'Gorad Rodgau,Rodgau,luo de gao,rdgaw,rotogau,rwdghaw,Горад Родгау,Родгау,ردگاو,رودغاو,ロートガウ,罗德高', 50.0262700, 8.8858800, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40259, 'Butjadingen', 'Butjadingen', 'But''jadingen,Butjadingen,Butujadingen,Bûtjadingen,bu te ya ding gen,Бутъядинген,Бутьядинген,Бутјадинген,布特亚丁根', 53.5472200, 8.3350000, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40260, 'Kaufungen', 'Kaufungen', 'Kaufungen,kao feng gen,kaufungen,Кауфунген,カウフンゲン,考丰根', 51.2811100, 9.6186100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40261, 'Jettingen-Scheppach', 'Jettingen-Scheppach', 'Ettingen-Sheppakh,Jetingen-Shepakh,Jettingen-Scheppach,ye ting gen-she pa,Єттінген-Шеппах,Јетинген-Шепах,Еттинген-Шеппах,Եթինգեն Շեփախ,耶廷根-舍帕', 48.3896000, 10.4381000, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40262, 'Gropiusstadt', 'Gropiusstadt', 'Berlin-Gropiusstadt,Gropiusstadt', 52.4250000, 13.4666700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40263, 'Seeheim-Jugenheim', 'Seeheim-Jugenheim', 'Zeegajm-Jugengajm,Zekhajm-Jugenkhajm,sai hai mu-you gen hai mu,syhym - ywjynhaym,zehaimu=yugenhaimu,Зеегайм-Югенгайм,Зехайм-Югенхайм,Зехајм-Југенхајм,سيهيم - يوجينهايم,ゼーハイム＝ユーゲンハイム,塞海姆-尤根海姆', 49.7650000, 8.6519400, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40264, 'Lauben', 'Lauben', '', 47.7787900, 10.3007100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40265, 'Kalbach', 'Kalbach', 'Kal''bakh,Kalbakh,ka er ba he,Калбах,Кальбах,卡尔巴赫', 50.4044700, 9.6825600, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40266, 'Charlottenburg-Nord', 'Charlottenburg-Nord', '', 52.5304800, 13.2937100, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40267, 'Mitte', 'Mitte', 'Berlin-Mitte,Mitte', 52.5200300, 13.4048900, 'DE', '2017-05-10', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40268, 'Plänterwald', 'Plaenterwald', '', 52.4810600, 13.4727600, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40269, 'Dallgow-Döberitz', 'Dallgow-Doeberitz', 'Dalgov-Deberic,Dall''gov-Djoberic,Dallgow-Doeberitz,Dallgow-Döberitz,da er ge-de bei li ci,Далгов-Дебериц,Далльгов-Дёбериц,Դալգով Դյոբերից,达尔戈-德贝里茨', 52.5426900, 13.0583700, 'DE', '2015-03-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40270, 'Borkwalde', 'Borkwalde', '', 52.2500000, 12.8333000, 'DE', '2010-11-22', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40271, 'Bertsdorf-Hörnitz', 'Bertsdorf-Hoernitz', 'Bertsdorf-Khernic,Bertsdorf-Khjornic,bei er ci duo fu-he er ni ci,Бертсдорф-Херниц,Бертсдорф-Хёрниц,Бертсдорф-Хөрниц,贝尔茨多夫-赫尔尼茨', 50.8859300, 14.7369600, 'DE', '2015-05-23', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40272, 'Spremberg', 'Spremberg', 'Grodk,Shpremberg,ashprmbrg,shi pu lun bei ge,Шпремберг,اشپرمبرگ,施普伦贝格', 51.5697100, 14.3735500, 'DE', '2010-11-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40273, 'Rheinstetten', 'Rheinstetten', 'Rajnashteten,Rajnshtetten,Raynstetten,Raynştetten,lai yin si te teng,raynshtytn,Райнштеттен,Рајнаштетен,راينشتيتن,راین‌اشتتن,赖因斯特滕', 48.9685000, 8.3070400, 'DE', '2010-11-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40274, 'Münstertal/Schwarzwald', 'Muenstertal/Schwarzwald', 'Muenstertal,Muenstertal  Black Forest,Münstertal,Münstertal  Black Forest', 47.8547200, 7.7841700, 'DE', '2013-11-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40275, 'Glottertal', 'Glottertal', 'Glotertal,Glottertal'',Glottertali vald,ge luo te er ta er,Глотертал,Глоттерталь,Գլոթերտալ,格洛特尔塔尔', 48.0507800, 7.9633700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40276, 'Salem', 'Salem', 'Baden,Salem,Zalem,Баден,Залем', 47.7625800, 9.2903100, 'DE', '2013-08-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40277, 'Altstadt Sud', 'Altstadt Sud', '', 50.9333100, 6.9595400, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40278, 'Altstadt Nord', 'Altstadt Nord', '', 50.9389300, 6.9575200, 'DE', '2013-08-03', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40279, 'Neuehrenfeld', 'Neuehrenfeld', '', 50.9575300, 6.9361100, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40280, 'Bilderstoeckchen', 'Bilderstoeckchen', 'Bilderstoeckchen,Bilderstöckchen', 50.9698300, 6.9299700, 'DE', '2017-07-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40281, 'Kloster Lehnin', 'Kloster Lehnin', 'Kloster-Lenin,Luise-Henrietten-Stift,Zisterzienserkloster Lehnin,Клостер-Ленин', 52.3203900, 12.7432000, 'DE', '2015-09-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40282, 'Neunkirchen am Brand', 'Neunkirchen am Brand', 'Brandi Noynkirxen,Nojnkirkhen am Brand,Nojnkirkhen-am-Brand,nuo yin ji er xing a mu bu lan de,Нойнкирхен-ам-Бранд,Нойнкірхен-ам-Бранд,Нојнкирхен ам Бранд,Բրանդի Նոյնկիրխեն,ノインキルヒェン・アム・ブラント,诺因基尔兴阿姆布兰德', 49.6120400, 11.1296700, 'DE', '2013-02-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40283, 'Rothenburgsort', 'Rothenburgsort', 'Hamburg-Rothenburgsort,Rotenburgsort,Ротенбургсорт', 53.5350000, 10.0408200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40284, 'Stuttgart-Ost', 'Stuttgart-Ost', 'S-Ost,Stgt-Ost', 48.7836300, 9.2103200, 'DE', '2014-03-15', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40285, 'Bochum-Hordel', 'Bochum-Hordel', '', 51.5016800, 7.1756000, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40286, 'St. Pauli', 'St. Pauli', 'Sankt-Pauli,Санкт-Паули', 53.5570000, 9.9640000, 'DE', '2016-01-16', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40287, 'Siegbach', 'Siegbach', 'Zigbakh,xi ge ba he,Зигбах,Зігбах,西格巴赫', 50.7389500, 8.4179300, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40288, 'Schwanau', 'Schwanau', 'Shvanau,shi wa nao,Шванау,施瓦瑙', 48.3666900, 7.7624400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40289, 'Kell am See', 'Kell am See', 'Kel am Ze,Kell''-am-Ze,bin hu ke er,Кел ам Зе,Келль-ам-Зе,ケル・アム・ゼー,滨湖克尔', 49.6330600, 6.8221700, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40290, 'Holzerath', 'Holzerath', '', 49.6795100, 6.7607100, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40291, 'Eidelstedt', 'Eidelstedt', 'Eidelstedt,Hamburg-Eidelstedt', 53.6069700, 9.9053800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40292, 'Schelfstadt', 'Schelfstadt', '', 53.6338200, 11.4171100, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40293, 'Werdervorstadt', 'Werdervorstadt', '', 53.6390900, 11.4276700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40294, 'Altstadt', 'Altstadt', '', 53.6280500, 11.4158200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40295, 'Feldstadt', 'Feldstadt', '', 53.6233100, 11.4067300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40296, 'Paulsstadt', 'Paulsstadt', '', 53.6328300, 11.4037200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40297, 'Weststadt', 'Weststadt', '', 53.6347200, 11.3956500, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40298, 'Lewenberg', 'Lewenberg', '', 53.6459100, 11.4076700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40299, 'Eisleben Lutherstadt', 'Eisleben Lutherstadt', 'Ajsleben,Eisleben,Eissleben [a. 1650],Eißleben [a. 1650],Islebia,Isleue [a. 1528],Islevo [a. 994],Isleŭe [a. 1528],Ljutershtadt Ajsleben,Lutershtat Ajsleben,Lutherstadt Eisleben,ai si lai ben,aiseulleben,aislebeni,aisureben,ayslbn,ayyzlbn,Айслебен,Ајслебен,Лутерштат Ајслебен,Лютерштадт Айслебен,آئیزلبن,آیسلبن,أيسلبن,აისლებენი,アイスレーベン,艾斯莱本,아이슬레벤', 51.5275400, 11.5483500, 'DE', '2016-07-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40300, 'Halle Neustadt', 'Halle Neustadt', 'Galle-Nojshtadt,Halle-Neustadt,Галле-Нойштадт', 51.4792400, 11.9160500, 'DE', '2016-07-06', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40301, 'Bergedorf', 'Bergedorf', 'Arrondissement de Bergedorf,Bardoerp,Bardörp,Bergedorf,Bezirk Bergedorf,Distretto di Bergedorf,Hamburg-Bergedorf,bei ge duo fu qu,brgdwrf,Бергедорф,برگدورف,贝格多夫区', 53.4846200, 10.2290400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40302, 'Spandau', 'Spandau', 'Berlin-Spandau,Spandau,Spandava,Špandava,שפנדאו,سپانڈو', 52.5511000, 13.1992100, 'DE', '2014-04-12', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40303, 'Berlin Schöneberg', 'Berlin Schoeneberg', 'Schoeneberg,Schöneberg', 52.4838800, 13.3477000, 'DE', '2012-08-28', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40304, 'Berlin Treptow', 'Berlin Treptow', 'Treptow', 52.4937600, 13.4446900, 'DE', '2012-06-08', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40305, 'Niederrad', 'Niederrad', 'Frankfurt Niederrad,Frankfurt-Niederrad,Niederrad', 50.0830900, 8.6285200, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40306, 'Haselbachtal', 'Haselbachtal', '', 51.2357000, 14.0257600, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40307, 'Rabenau', 'Rabenau', '', 50.6775300, 8.8642500, 'DE', '2011-04-25', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40308, 'Ebsdorfergrund', 'Ebsdorfergrund', 'Ebsdorfergrund,Ehbsdorfergrund,ai bu si duo fu ge lun de,epusudorufagurunto,Ебсдорфергрунд,Эбсдорфергрунд,エプスドルファーグルント,埃布斯多弗格伦德', 50.7260200, 8.8570400, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40309, 'Dachsberg', 'Dachsberg', '', 47.7294500, 8.1000100, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40310, 'Garbsen-Mitte', 'Garbsen-Mitte', 'Garbsen-Mitte', 52.4265900, 9.6038300, 'DE', '2014-07-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40311, 'Selfkant', 'Selfkant', 'Zel''fkant,Zelfkant,Zelfkantj,sai er fu kan te,sylfkant,Зелфкант,Зельфкант,سيلفكانت,塞尔夫坎特', 51.0221200, 5.9297800, 'DE', '2011-07-31', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40312, 'Barmbek-Nord', 'Barmbek-Nord', '', 53.6052000, 10.0398800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40313, 'Hammerbrook', 'Hammerbrook', '', 53.5452700, 10.0304200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40314, 'Farmsen-Berne', 'Farmsen-Berne', '', 53.6063900, 10.1197200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40315, 'Kleiner Grasbrook', 'Kleiner Grasbrook', '', 53.5311100, 9.9936100, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40316, 'Fehmarn', 'Fehmarn', 'Femarn,Femarnas,Femern,Fėmarnas,Isla de Fehmarn,fe mar n,fei ma en,femarun dao,fhmarn,fyhmarn,pemarni,Φέμαρν,Фемарн,فهمارن,فيهمارن,เฟมาร์น,ფემარნი,フェーマルン島,费马恩', 54.4378000, 11.1935200, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40317, 'Stadtrandsiedlung Malchow', 'Stadtrandsiedlung Malchow', '', 52.5829500, 13.4781100, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40318, 'Hansaviertel', 'Hansaviertel', 'Berlin-Hansaviertel', 52.5185300, 13.3417800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40319, 'Falkenhagener Feld', 'Falkenhagener Feld', 'Berlin-Falkenhagener Feld,فالکینہاگینیر فیلڈ', 52.5519100, 13.1680200, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40320, 'Neu-Hohenschönhausen', 'Neu-Hohenschoenhausen', 'Berlin-Neu-Hohenschoenhausen,Berlin-Neu-Hohenschönhausen', 52.5668100, 13.5125500, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40321, 'Waidmannslust', 'Waidmannslust', '', 52.6069100, 13.3196800, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40322, 'Alt-Hohenschönhausen', 'Alt-Hohenschoenhausen', 'Berlin-Alt-Hohenschoenhausen,Berlin-Alt-Hohenschönhausen,alt-shwhynzn,الت-شوهینزن', 52.5460800, 13.5013000, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40323, 'Fennpfuhl', 'Fennpfuhl', 'Berlin-Fennpfuhl', 52.5292100, 13.4726700, 'DE', '2012-06-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40324, 'Neustadt an der Orla', 'Neustadt an der Orla', 'Neustadt (Orla)', 50.7364000, 11.7461900, 'DE', '2017-06-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40325, 'Hamburg-Nord', 'Hamburg-Nord', 'Arrondissement de Hambourg-Nord,Bezirk Hamburg-Nord,Distretto di Hamburg-Nord,Hamborg-Noord,Hamburgo-Norte,Hamburgum Septentrionale,Khamburg-Nord,han bao bei qu,Хамбург-Норд,汉堡北区', 53.5893500, 9.9840000, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40326, 'Burg Unter-Falkenstein', 'Burg Unter-Falkenstein', 'Neu-Falkenstein', 47.7044000, 12.1046600, 'DE', '2012-08-24', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40327, 'Neu-Pattern', 'Neu-Pattern', '', 50.8885400, 6.2768800, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40328, 'Neustadt/Nord', 'Neustadt/Nord', '', 50.9490000, 6.9479000, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40329, 'Neustadt/Süd', 'Neustadt/Sued', '', 50.9250900, 6.9476200, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40330, 'Buchforst', 'Buchforst', '', 50.9509300, 7.0057900, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40331, 'Kalk', 'Kalk', '', 50.9401300, 7.0060500, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40332, 'Mülheim', 'Muelheim', '', 50.9663900, 7.0038400, 'DE', '2015-03-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40333, 'Gartenstadt', 'Gartenstadt', '', 49.4593700, 8.4037700, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40334, 'Lachen-Speyerdorf', 'Lachen-Speyerdorf', '', 49.3304900, 8.1998300, 'DE', '2015-09-05', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40335, 'Wittenberg', 'Wittenberg', '', 51.8663200, 12.6284400, 'DE', '2017-02-20', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40336, 'Osternienburger Land', 'Osternienburger Land', 'Osterninburger Land,ao si te er ning bu er ge er lan,Остернинбургер Ланд,奥斯特尔宁布尔格尔兰', 51.8000000, 12.0166700, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40337, 'Auf der Horst', 'Auf der Horst', 'Up de Host', 52.4194300, 9.6024800, 'DE', '2014-07-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40338, 'Dierkow-Neu', 'Dierkow-Neu', 'D-N', 54.1057100, 12.1675300, 'DE', '2014-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40339, 'Dierkow-West', 'Dierkow-West', 'D-W', 54.1060800, 12.1504100, 'DE', '2014-07-19', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40340, 'Kirchsahr', 'Kirchsahr', '', 50.5225400, 6.8997600, 'DE', '2014-08-14', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40341, 'Solms', 'Solms', 'Zol''ms,Zolms,suo er mu si,zlms,zwlms,Золмс,Зольмс,زلمس,زولمس,索尔姆斯', 50.5362000, 8.4070400, 'DE', '2015-09-04', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40342, 'Röchling-Höhe', 'Roechling-Hoehe', '', 49.2710200, 6.8345700, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40343, 'Luisenthal', 'Luisenthal', '', 49.2493200, 6.9005700, 'DE', '2016-01-02', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40344, 'Westhagen', 'Westhagen', '', 52.4042500, 10.7393900, 'DE', '2016-03-17', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40345, 'Düsseldorf-Pempelfort', 'Duesseldorf-Pempelfort', 'Pempelfort', 51.2381200, 6.7867800, 'DE', '2016-10-09', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40346, 'Burglesum', 'Burglesum', '', 53.1653200, 8.6887300, 'DE', '2017-06-30', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40347, 'Sachsenbrunn', 'Sachsenbrunn', '', 50.4471800, 10.9495100, 'DE', '2017-07-11', 83);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40924, 'Boumerdas', 'Boumerdas', 'Bou-Merdes,Boumerdas,Bumerdes,Cite de Boumerdes,Cité de Boumerdes,Le Rocher Noir,Roche Noire,Rocher Noir,Бумердес', 36.7663900, 3.4771700, 'DZ', '2012-01-14', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40925, 'Zeribet el Oued', 'Zeribet el Oued', 'Zeribet el Oued,Zribet el Oued', 34.6828400, 6.5110900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40926, 'Zeralda', 'Zeralda', 'Zeralda', 36.7116900, 2.8424400, 'DZ', '2012-05-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40927, 'Zemoura', 'Zemoura', 'Zemmora,Zemoura', 35.7225100, 0.7550900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40928, 'Touggourt', 'Touggourt', 'TGR,Touggourt,Tougourt,Tuggurt,Tugurtas,Tukkurt,to~ugura,tqrt,tqwrt  aljzayr,tu gu er te,tuguleuteu,Туггурт,Туггурт қаласы,تقرت,تقورت، الجزایر,トゥーグラ,图古尔特,투구르트', 33.1052700, 6.0579600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40929, 'Tolga', 'Tolga', 'Tolga,Толга', 34.7222400, 5.3784500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40930, 'Tlemcen', 'Tlemcen', 'Gorad Tlemsen,Pomaria,TLM,Termicen,Termicén,Tilimsan,Tilimsen,Tlemcen,Tlemsen,Tlemsenas,Tremecen,Tremecén,Wilaya ya Tlemcen,te lai mu sen,teullemsen,tlem sen,tlmsan,toremusen,Горад Тлемсен,Тлемсен,Тлемсен қаласы,תלמסאן,تلمسان,ตเลมเซน,トレムセン,特莱姆森,틀렘센', 34.8783300, -1.3150000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40931, 'Tizi Rached', 'Tizi Rached', 'Tizi Rached', 36.6717600, 4.1917600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40932, 'Tizi Ouzou', 'Tizi Ouzou', 'QZI,Tizi Ouzou,Tizi Uzu,Tizi Wuzu,Tizi-Ouzou,Tizi-Uzu,ti ji wu zu,tijiuju,tyzy wzw,Тизи Узу,Тизи-Узу,تيزي وزو,تیزی وزو,提济乌祖,티지우주', 36.7118200, 4.0459100, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40933, 'Tizi-n-Tleta', 'Tizi-n-Tleta', '', 36.5456900, 4.0571200, 'DZ', '2011-04-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40934, 'Tizi Gheniff', 'Tizi Gheniff', 'Tizi Ghenif,Tizi Gheniff,Tizi R''Nif,Tizi Renif,Tizi Rniff,Tizi R’Nif,Tizi-Reniff', 36.5883900, 3.7744500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40935, 'Tissemsilt', 'Tissemsilt', 'Tissemsil,Tissemsilt,Vialar,tsmsylt,تسمسيلت', 35.6072200, 1.8108100, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40936, 'Tirmitine', 'Tirmitine', 'Tirmitine', 36.6539300, 3.9814300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40937, 'Tipasa', 'Tipasa', 'Tipasa,Tipaza,Tipazo,Tipáza,ti pa sa,tipaja,tipasa,tybazt,Типаза,Типаса,Тіпаза,תיפאזה,تبسہ,تيبازة,تیبازہ,تی‌پازه,तिपजा,ტიპასა,ティパサ,提帕薩,티파자', 36.5897200, 2.4475000, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40938, 'Tindouf', 'Tindouf', 'Provinsi Tindouf,TIN,Tindouf,Tinduf,Tindufas,Tindúf,tindo~ufu,tindupeu,ting du fu,tndwf,Тиндуф,تندوف,ティンドゥフ,廷杜夫,틴두프', 27.6711100, -8.1474300, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40939, 'Timizart', 'Timizart', 'Timizart', 36.8000000, 4.2666700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40940, 'Timimoun', 'Timimoun', 'TMX,Timimoun,Timmoun', 29.2638800, 0.2309800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40941, 'el hed', 'el hed', 'El Maten,Il Maten,Il Matene,Il Matten,Timezrit Il Maten', 36.6500000, 4.7736100, 'DZ', '2007-03-25', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40942, 'Tiaret', 'Tiaret', 'TID,Tiaret,Tiaretas,Tijarat,ti ya lei te,tyart,Тиарет,Тіарет,تيارت,تیارت,提亚雷特', 35.3710300, 1.3169900, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40943, 'Theniet el Had', 'Theniet el Had', 'Teniet el Haad,Teniet el Had,Teniet-el-Ha,Theniet el Had', 35.8711100, 2.0280600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40944, 'Thenia', 'Thenia', 'Menerville,Ménerville,Thenia,Theniet Beni Aicha,Theniet Béni Aicha', 36.7254400, 3.5566500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40945, 'Telerghma', 'Telerghma', 'Telerghma,Telergma', 36.1165300, 6.3543400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40946, 'Tébessa', 'Tebessa', 'TEE,Tebesa,Tebessa,Theveste,Tibissa,Tébessa,tai bei sa,tbsh  aljzayr,tbst,Тебесса,Тебесса қаласы,تبسة,تبسه، الجزایر,تیبازہ,泰贝萨', 35.4041700, 8.1241700, 'DZ', '2017-06-05', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40947, 'Tebesbest', 'Tebesbest', 'Tebesbest', 33.1166700, 6.0833300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40948, 'Tazoult-Lambese', 'Tazoult-Lambese', 'Lambese,Lambèse,Tazoult,Tazoult-Lambese', 35.4817100, 6.2607400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40949, 'Tamanrasset', 'Tamanrasset', 'Fort Laperine,Fort Laperrine,TMR,Tamahrasset,Tamanghasset,Tamanraset,Tamanrasetas,Tamanrasset,Tamanrassete,Tamenghasset,Tamenɣest,ta man la sai te,tamanlaseteu,tamanrasetto,tamnrast,tmnrast,Таманрасет,Таманрассет,Таманрассете,תאמאנראסט,تامنراست,تمنراست,タマンラセット,塔曼拉塞特,타만라세트', 22.7850000, 5.5227800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40950, 'Tamalous', 'Tamalous', 'Tamalous', 36.8376300, 6.6401800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40951, 'Tadmaït', 'Tadmait', 'Camp du Marechal,Camp du Maréchal,Tadmait,Tadmaït', 36.7441300, 3.9004500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40952, 'Sour el Ghozlane', 'Sour el Ghozlane', 'Aumale,Aumale-d''Algerie,Aumale-d’Algérie,Aumate,Sour el Ghozlane', 36.1476600, 3.6912300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40953, 'Souma', 'Souma', '', 36.5183300, 2.9052800, 'DZ', '2006-01-27', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40954, 'Lardjem', 'Lardjem', '', 35.7492200, 1.5477800, 'DZ', '2015-03-01', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40955, 'Souk Ahras', 'Souk Ahras', 'QSK,Souk Ahras,Souk-Ahras,Soukaras,Souq Ahras,Suk Ahras,Suk Ahrasas,Suk Aras,Suk-Akhras,Suq Ahras,Szuk Ahrasz,Szúk Ahrász,Tagaste,su ge ai he la si,sukeualaseu,swq ahras,swq ahras  aljzayr,Сук-Ахрас,سوق أهراس,سوق اهراس، الجزایر,سوق اہراس,苏格艾赫拉斯,수크아라스', 36.2863900, 7.9511100, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40956, 'Sougueur', 'Sougueur', 'Nadhora,Nador,Sougueur,Trezel,Trézel', 35.1856800, 1.4961200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40957, 'Skikda', 'Skikda', 'Gorad Skikda,Philippeville,Phillippville,SKI,Skikda,Sukajkida,seukigda,si ji ke da,skikada,skykdt,Горад Скікда,Скикда,Скикда қаласы,Скікда,سكيكدة,سکیکدہ,ولاية سعيدة,স্কিকদা,斯基克达,스킥다', 36.8761700, 6.9092100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40958, 'Sig', 'Sig', 'QIL,Saint-Denis-du-Sig,Sig', 35.5283200, -0.1936900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40959, 'Sidi Okba', 'Sidi Okba', 'Sidi Okba', 34.7451200, 5.8983300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40960, 'Sidi Moussa', 'Sidi Moussa', 'Sidi Moussa', 36.6063700, 3.0878300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40961, 'Sidi Mérouane', 'Sidi Merouane', 'Sidi Merouan,Sidi Merouane,Sidi Mérouane', 36.5205600, 6.2611100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40962, 'Sidi Khaled', 'Sidi Khaled', 'Sidi Khaled,Sidi Kraled', 34.3870000, 4.9878500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40963, 'Sidi ech Chahmi', 'Sidi ech Chahmi', 'Sidi Chami,Sidi Chamy,Sidi ech Chahmi', 35.6590300, -0.5216800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40964, 'Sidi Bel Abbès', 'Sidi Bel Abbes', 'BFW,Gorad Sidy-Bel''-Abes,Sid Bel Abbes,Sid Bel Abbès,Sidi Bel Abbes,Sidi Bel Abbès,Sidi Bel Abes,Sidi Belabbas,Sidi Belɛebbas,Sidi Bilabbas,Sidi Bu-l-Abbas,Sidi bel Abbes,Sidi bel Abbès,Sidi bel Abesas,Sidi-Bal-Abbes,Sidi-Bal-Abbès,Sidi-Bel''-Abbes,Sidi-Bel-Abbes,Sidi-Bel-Abbès,Sidi-bel-Abbes,Sidi-bel-Abbès,sidibel-abeseu,xi di bei lei a ba si,Горад Сіды-Бель-Абес,Сиди Бел Абес,Сиди-Бель-Аббес,Сиди-Бель-Аббес қаласы,Сіді-Бель-Аббес,סידי בל-עבאס,سيدي بلعباس,سیدی بلعباس,سیدی بلعباس، الجزایر,ولاية سيدي بلعباس,西迪贝勒阿巴斯,시디벨아베스', 35.1899400, -0.6308500, 'DZ', '2013-07-01', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40965, 'Sidi Amrane', 'Sidi Amrane', 'Sidi Amrane', 33.4988500, 6.0080300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40966, 'Sidi Akkacha', 'Sidi Akkacha', 'Montenotte,Sidi Akacha,Sidi Akkacha', 36.4647200, 1.3025800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40967, 'Sidi Aïssa', 'Sidi Aissa', 'Sid Aissa,Sid Aïssa,Sidi Aissa,Sidi Aïssa,Sidi-Aissa,Сиди-Аисса', 35.8854800, 3.7723600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40968, 'Sidi Abdelli', 'Sidi Abdelli', 'Les Abdellys,Les Abdelys,Sidi Abdelli', 35.0693700, -1.1370600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40969, 'Sfizef', 'Sfizef', 'Mercier-Lacombe,Sfisef,Sfissef,Sfizef', 35.2346400, -0.2443500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40970, 'Sétif', 'Setif', 'Gorad Setyf,QSF,Sathif,Satif,Setif,Setifas,Sitifis,Stif,Sétif,sai ti fu,setifu,setipeu,stf,styf,styp,wlayt styf,Горад Сетыф,Сетиф,Сетиф қаласы,Сетіф,סטיף,سطف,سطيف,ولاية سطيف,Ṣṭif,セティフ,塞提夫,세티프', 36.1911200, 5.4137300, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40971, 'Sedrata', 'Sedrata', 'Sedrata', 36.1286800, 7.5337600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40972, 'Seddouk', 'Seddouk', 'Seddouk', 36.5472200, 4.6861100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40973, 'Sebdou', 'Sebdou', 'Sebdou', 34.6370300, -1.3314300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40974, 'Saoula', 'Saoula', 'Saoula', 36.7045600, 3.0246200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40975, 'Salah Bey', 'Salah Bey', 'Dzeira,Pascal,Salah Bey', 35.8545100, 5.2905300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40976, 'Saïda', 'Saida', 'Sa''ida,Saida,Sajda,Saïda,Sa’ida,sai yi da,saida,Саида,Сайда,Саїда,سعيدة,سعیده، الجزایر,سعیدہ، الجزائر,サイダ,塞伊达,사이다', 34.8303300, 0.1517100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40977, 'Rouissat', 'Rouissat', 'Rouissat', 31.9242700, 5.3501800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40978, 'Rouiba', 'Rouiba', 'Rouiba', 36.7382900, 3.2807900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40979, 'Rouached', 'Rouached', '', 36.4577400, 6.0426700, 'DZ', '2011-04-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40980, 'Robbah', 'Robbah', 'Robbah', 33.2796700, 6.9098400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40981, 'Remchi', 'Remchi', 'Montagnac,Remchi', 35.0619600, -1.4336200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40982, 'Relizane', 'Relizane', 'Ighil Izane,Prowincja Relizane,QZN,Relizan,Relizane,ghlyzan,wlayt ghlyzan,غلیزان,ولاية غليزان', 35.7373400, 0.5559900, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40983, 'Reguiba', 'Reguiba', 'Reguiba,alrqybt,الرقيبة', 33.5639100, 6.7032600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40984, 'Reghaïa', 'Reghaia', 'La Reghaia,La Reghaïa,La Reghia-Alma,Reghaia,Reghaïa', 36.7358700, 3.3401800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40985, 'Reggane', 'Reggane', 'Reggan,Reggane,Zaouiet Reggan,Zaouiet Reggane', 26.7157600, 0.1714000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40986, 'Râs el Oued', 'Ras el Oued', 'Ras el Oued,Ras-ehl''-Uehd,Rass el Oued,Râs el Oued,Tocqueville,Рас-эль-Уэд', 35.9441000, 5.0310700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40987, 'Râs el Aïoun', 'Ras el Aioun', 'Ras el Aioun,Ras el Ayoun,Rass el Aioun,Rass el Aïoun,Râs el Aïoun', 35.6738400, 5.6453000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40988, 'Oum el Bouaghi', 'Oum el Bouaghi', 'Canrobert,Oum el Bouaghi,Oum-el-Bouachi,QMH', 35.8754100, 7.1135300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40989, 'Oumache', 'Oumache', 'Oumach,Oumache,Umash', 34.6929200, 5.6809200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40990, 'Ouled Moussa', 'Ouled Moussa', 'Ouled Moussa,Saint Pierre,Saint-Pierre-Saint-Paul', 36.6839400, 3.3666100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40991, 'Ouled Mimoun', 'Ouled Mimoun', 'Altava,Lamariciere,Lamaricière,Lamoriciere,Lamoricière,Lemoriciere,Ouled Mimoun', 34.9047200, -1.0339400, 'DZ', '2012-07-24', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40992, 'Oued Sly', 'Oued Sly', 'Malakoff,Malakoft,Oued Sli,Oued Sly', 36.1012400, 1.1994900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40993, 'Oued Rhiou', 'Oued Rhiou', 'Inkermann,Oued Rhiou,Oued Riou,QOU', 35.9612400, 0.9189600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40994, 'Oued Fodda', 'Oued Fodda', 'Oued Fodda', 36.1850300, 1.5329900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40995, 'Oued el Alleug', 'Oued el Alleug', 'Oued Alleug,Oued el Alleng,Oued el Alleug', 36.5552800, 2.7902800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40996, 'Oued el Abtal', 'Oued el Abtal', 'Oued el Abtal,Torki-le-Djuk,Uzes-le-Duc,Uzes-le-Due,Uzès-le-Duc,Uzès-le-Due,Торки-ле-Дюк', 35.4559500, 0.6877800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40997, 'Ouargla', 'Ouargla', 'OGX,Ouargla,Quargla,Uargla,Warkala,Warqla,ualeugeulla,wa er ge la,war kla,warugura,wrqlh  aljzayr,wrqlt,Уаргла,Уаргла қаласы,ورقلة,ورقله، الجزایر,ورقلہ,วาร์กลา,ワルグラ,瓦尔格拉,우아르글라', 31.9493200, 5.3250200, 'DZ', '2010-08-03', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40998, 'Oran', 'Oran', 'Gorad Aran,ORN,Ora,Oran,Orana,Oranas,Orano,Orà,Orán,Orã,Orāna,Ouahran,Wahran,Wahrān,Waradinne,Wehran,olang,oran,orana,orani,vahirana,wa he lan,whran,whran  aljzayr,wlayt whran,xx ran,Οράν,Горад Аран,Оран,Оран қаласы,אוראן,ولاية وهران,وهران,وهران، الجزایر,وہران,وەھران,ওরান,ਵਹਿਰਾਨ,ออราน,ორანი,オラン,瓦赫蘭,오랑', 35.6990600, -0.6358800, 'DZ', '2017-05-23', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40999, 'Nedroma', 'Nedroma', 'Nedroma,QAN', 35.0136100, -1.7479900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41000, 'Naciria', 'Naciria', 'Azib Zamoun,Haussonviller,Haussonvillers,Naciria', 36.7462500, 3.8316300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41001, 'Naama', 'Naama', 'Naama', 33.2666700, -0.3166700, 'DZ', '2014-04-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41002, 'M’Sila', 'M''Sila', 'M''Sila,MSila,M’Sila,ZZS,almsylt,المسيلة', 35.7058300, 4.5419400, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41003, 'Mouzaïa', 'Mouzaia', 'Mouzaia,Mouzaiaville,Mouzaïa,Mouzaïaville', 36.4669500, 2.6899100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41004, 'Mostaganem', 'Mostaganem', 'MQV,Mastaganeam,Mostaganem,Mostaganemas,Mustaghanam,Mustaghanim,Mustɣanem,mostaghanemi,mstaghanm,mstghanm,mu si ta jia nai mu,Мостаганем,مستاغانم,مستغانم,მოსთაღანემი,穆斯塔加奈姆', 35.9311500, 0.0891800, 'DZ', '2016-09-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41005, 'Mila', 'Mila', 'Mila,milla,mylt,Мила,ميلة,میلہ، الجزائر,밀라', 36.4502800, 6.2644400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41006, 'Metlili Chaamba', 'Metlili Chaamba', 'Metlili,Metlili Chaamba,Metlili-les Chaamba,Mettlili Chaamba', 32.2666700, 3.6333300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41007, 'Messaad', 'Messaad', 'Messaad,Messad,Мессад', 34.1542900, 3.5030900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41008, 'Meskiana', 'Meskiana', 'La Meskiana,Meskiana', 35.6305800, 7.6660600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41009, 'Mers el Kebir', 'Mers el Kebir', 'Mers el Kabir,Mers el Kebir,Mers-ehl''-Kebir,Saint Andre de Mers-el-Kebir,Saint André de Mers-el-Kébir,bldyt almrsy alkbyr,Мерс-эль-Кебир,بلدية المرسى الكبير', 35.7279000, -0.7081000, 'DZ', '2016-09-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41010, 'Merouana', 'Merouana', 'Corneille,Merouana', 35.6310600, 5.9118600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41011, 'Melouza', 'Melouza', 'Melouda,Melouza,Ouan Ougha,Souk el Tleta', 35.9799900, 4.1866500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41012, 'Mekla', 'Mekla', 'Mekla', 36.6817800, 4.2637800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40361, 'Vrå', 'Vra', 'Vra,Vraa,Vrå', 57.3476300, 9.9515400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40362, 'Vordingborg', 'Vordingborg', 'Vordingborg,Вордингборг', 55.0080100, 11.9105700, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40363, 'Vojens', 'Vojens', 'SKS,Vojens', 55.2463900, 9.3060300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40364, 'Vodskov', 'Vodskov', 'Vodskov', 57.1085400, 10.0221500, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40365, 'Vissenbjerg', 'Vissenbjerg', 'Vissenbjerg,Vissenbjerg Kirke', 55.3848200, 10.1378400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40366, 'Virklund', 'Virklund', '', 56.1321800, 9.5558200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40367, 'Vipperød', 'Vipperod', '', 55.6676800, 11.7396700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40368, 'Vindinge', 'Vindinge', '', 55.6229800, 12.1387000, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40369, 'Vinderup', 'Vinderup', 'Vinderup,Vinderup Garde,Vinderup Gårde', 56.4751500, 8.7908100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40370, 'Vindeby', 'Vindeby', '', 55.0448900, 10.6130900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40371, 'Vildbjerg', 'Vildbjerg', 'Vilbjaerg,Vilbjerg,Vilbjærg,Vildbjerg', 56.2000000, 8.7666700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40372, 'Videbæk', 'Videbaek', 'Videbaek,Videbäk,Videbæk', 56.0876000, 8.6285200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40373, 'Viby', 'Viby', 'Viby', 55.5487200, 12.0239100, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40374, 'Viborg', 'Viborg', 'Vibor,Viborg,Viborga,Viborgas,Viburgo,Vimpornk,Wibergis,ZGX,biboleu,viborgi,vu~ibo,wei bao,Βίμποργκ,Вибор,Виборг,Віборг,ویبو، ڈنمارک,ვიბორგი,ヴィボー,維堡,비보르', 56.4531900, 9.4020100, 'DK', '2010-01-29', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40375, 'Vester Hassing', 'Vester Hassing', 'Vester Hasing,Vester Hassing', 57.0676700, 10.1255800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40376, 'Vestbjerg', 'Vestbjerg', 'QXF,Vestbjaerg,Vestbjerg,Vestbjærg', 57.1316600, 9.9594200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40377, 'Veksø', 'Vekso', 'Vekso,Veksø,Vikso,Viksø', 55.7547300, 12.2383700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40378, 'Vejle', 'Vejle', 'Vaile,Vailė,Vajle,Vejle,baille,vaile,vu~aire,wa ai lei,waylh,wile,Вайле,Вајле,Вејле,وایله,ไวเล,ვაილე,ヴァイレ,瓦埃勒,바일레', 55.7092700, 9.5357000, 'DK', '2010-01-29', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40379, 'Vejen', 'Vejen', 'Comuna Vejen,Kommun Vejen,Municipi de Vejen,Munisipalitas Vejen,Vayen,Vejen,Vejen Chu-ti-chhi,Vejen Chū-tī-chhī,Vejen Kommune,Vejen Komuun,Vejen Municipality,Vejen kommune,Vejenin kunta,wa yi en zi zhi shi,Վայեն,ვეიენის მუნიციპალიტეტი,瓦伊恩自治市', 55.4811700, 9.1379500, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40380, 'Varde', 'Varde', 'Varde,Варде', 55.6211200, 8.4806900, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40381, 'Vanløse', 'Vanlose', 'Vanlose,Vanløse', 55.6836100, 12.4871300, 'DK', '2014-12-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40382, 'Vamdrup', 'Vamdrup', 'Vamdrup', 55.4276400, 9.2843500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40383, 'Vallensbæk', 'Vallensbaek', 'Vallensbaek,Vallensbæk', 55.6333300, 12.3666700, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40384, 'Vadum', 'Vadum', 'Vadum', 57.1179000, 9.8570000, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40385, 'Ulstrup', 'Ulstrup', 'Ulstrup,Ulstrupbro', 56.3899400, 9.7935400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40386, 'Ullerslev', 'Ullerslev', '', 55.3617200, 10.6519000, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40387, 'Ulfborg', 'Ulfborg', 'Ulborg,Ulfborg,Ulfkaer,Ulfkær,Ulvborg Stationsby', 56.2672500, 8.3216700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40388, 'Tune', 'Tune', 'Tune', 55.5952800, 12.1831900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40389, 'Trørød', 'Trorod', 'Trorod,Trørød', 55.8394600, 12.5443200, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40390, 'Trige', 'Trige', 'Trige', 56.2529100, 10.1484000, 'DK', '2013-04-03', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40391, 'Tranebjerg', 'Tranebjerg', 'Tranebierg,Tranebjaerg,Tranebjerg,Tranebjærg', 55.8326000, 10.5972300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40392, 'Tranbjerg', 'Tranbjerg', 'Tranbjaerg,Tranbjerg,Tranbjerg J,Tranbjærg', 56.0901100, 10.1193700, 'DK', '2013-09-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40393, 'Tørring', 'Torring', 'Nye Torring,Nye Törring,Torring,Torring Stationsby,Tørring,Tørring Stationsby', 55.8500000, 9.4833300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40394, 'Tønder', 'Tonder', 'Tender,Tjonner,Tonder,Tondern,Tuner,Tynne,Tønder,tndr  danmark,toeneleu,to~una,Тендер,Тённер,تندر، دانمارک,トゥナー,퇴네르', 54.9330600, 8.8667400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40395, 'Tølløse', 'Tollose', 'Tollose,Tollose Stationsby,Töllöse Stationsby,Tølløse', 55.6125000, 11.7703400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40396, 'Tommerup Stationsby', 'Tommerup Stationsby', 'Tommerup,Tommerup Stationsby', 55.3453500, 10.1759400, 'DK', '2013-04-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40397, 'Tommerup', 'Tommerup', 'Tommerup', 55.3195200, 10.2065900, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40398, 'Toftlund', 'Toftlund', '', 55.1885800, 9.0692500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40399, 'Tjæreborg', 'Tjaereborg', 'Tjaereborg,Tjæreborg', 55.4645700, 8.5796800, 'DK', '2013-04-03', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40400, 'Tinglev', 'Tinglev', 'Tinglev', 54.9309900, 9.2524300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40401, 'Thyborøn', 'Thyboron', 'Thyboron,Thyborøn,Tyboron,Tyboron By,Tyborøn,Tyborøn By', 56.6984600, 8.2123800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40402, 'Thurø By', 'Thuro By', 'Thuro,Thuro By,Thurø,Thurø By,Turo By,Turö By', 55.0474000, 10.6638500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40403, 'Thisted', 'Thisted', 'TED,Thystad,Tisted', 56.9552300, 8.6949100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40404, 'Taulov', 'Taulov', 'Tavlov,Tavlov Nebel', 55.5458200, 9.6155300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40405, 'Taastrup', 'Taastrup', 'Taastrup,Tastrup,Tåstrup,Тааструп', 55.6517300, 12.2921600, 'DK', '2014-03-18', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40406, 'Tårs', 'Tars', 'Taars,Tars,Tors,Tårs', 57.3833300, 10.1166700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40407, 'Tårnby', 'Tarnby', 'Taarnby,Tarnby,Tornbju,Tårnby,Торнбю,ტორნბი', 55.6303000, 12.6003500, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40408, 'Tarm', 'Tarm', 'Tarm', 55.9086100, 8.5304100, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40409, 'Svogerslev', 'Svogerslev', 'Svogerslev', 55.6342300, 12.0146500, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40410, 'Svinninge', 'Svinninge', 'Svinninge', 55.7211100, 11.4654700, 'DK', '2013-04-03', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40411, 'Svenstrup', 'Svenstrup', '', 56.9723000, 9.8480600, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40412, 'Svendborg', 'Svendborg', 'QXV,Svenborg,Svendborg,Svennborge,svenborgi,Свендборг,Свеннборге,სვენბორგი', 55.0598200, 10.6067700, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40413, 'Svejbæk', 'Svejbaek', '', 56.1325500, 9.6328900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40414, 'Svebølle', 'Svebolle', 'Svebolle,Svebolle Stationsby,Svebølle,Svebølle Stationsby', 55.6518300, 11.2865800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40415, 'Sunds', 'Sunds', 'Sunde,Sunds', 56.2041700, 9.0126600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40416, 'Sundby', 'Sundby', 'Stadager,Sundby', 54.8640000, 11.7930200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40417, 'Stubbekøbing', 'Stubbekobing', 'Stubbekiobing,Stubbekiöbing,Stubbekjobing,Stubbekjöbing,Stubbekobing,Stubbekøbing', 54.8887500, 12.0410200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40418, 'Struer', 'Struer', 'Comuna Struer,Kommun Struer,Municipi de Struer,Munisipalitas Struer,QWQ,Struehr,Struer,Struer Chu-ti-chhi,Struer Chū-tī-chhī,Struer Kommune,Struer Komuun,Struer Municipality,Struer kommune,Struerin kunta,si chu e zi zhi shi,Струер,Струэр,斯楚厄自治市', 56.4912200, 8.5837600, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40419, 'Strøby Egede', 'Stroby Egede', '', 55.4138200, 12.2450200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40420, 'Strib', 'Strib', 'Strib,Стриб', 55.5402100, 9.7674800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40421, 'Strandby', 'Strandby', '', 57.4915000, 10.4960900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40422, 'Storvorde', 'Storvorde', 'Storevorde,Storvorde', 57.0039200, 10.1012500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40423, 'Store Heddinge', 'Store Heddinge', 'Store Hedinge', 55.3096500, 12.3888500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40424, 'Støvring', 'Stovring', '', 56.8853600, 9.8383900, 'DK', '2012-02-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40425, 'Stoholm', 'Stoholm', 'Stoholm', 56.4845400, 9.1461700, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40426, 'Stilling', 'Stilling', '', 56.0622400, 9.9882200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40427, 'Stige', 'Stige', 'Stige', 55.4394100, 10.4094000, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40428, 'Stenløse', 'Stenlose', '', 55.7682800, 12.1972300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40429, 'Stenlille', 'Stenlille', 'Stenlille', 55.5402200, 11.5914600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40430, 'Stege', 'Stege', 'Stege', 54.9870400, 12.2846100, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40431, 'Stavtrup', 'Stavtrup', 'Stautrup,Stavtrup', 56.1312400, 10.1198700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40432, 'Stavnsholt', 'Stavnsholt', '', 55.8147900, 12.4054500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40433, 'Starup', 'Starup', '', 55.2409700, 9.5350300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40434, 'Spentrup', 'Spentrup', '', 56.5370300, 10.0379200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40435, 'Sorø', 'Soro', 'Sora,Sore,Sorey,Sorjo,Soro,Sorė,Sórey,soloe,sore,suo lei,Соре,Соро,Сорё,ソレ,索勒,소뢰', 55.4318400, 11.5554700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40436, 'Søndersø', 'Sonderso', 'Sonderse,Sonderso,Sönderse,Søndersø', 55.4852600, 10.2554000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40437, 'Sønderborg', 'Sonderborg', 'Munisipalitas Sonderborg,Munisipalitas Sønderborg,SGD,Senderborg,Sionderborgas,Sjonnenborg,Sjonnerborg,Sonderborg,Sonderburg,Synneborre,Sønderborg,senabo,senerborgi,soeneleuboleu,Сендерборг,Сённенборг,Сённерборг,სენერბორგი,セナボー,쇠네르보르', 54.9089600, 9.7891700, 'DK', '2017-07-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40438, 'Sønder Bjert', 'Sonder Bjert', 'Bjaert,Bjært,Sonder Bjert,Sønder Bjert', 55.4527200, 9.5674100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40439, 'Søften', 'Soften', 'Soften,Søften', 56.2380100, 10.0851000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40440, 'Solrød Strand', 'Solrod Strand', '', 55.5328500, 12.2222700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40441, 'Solrød', 'Solrod', '', 55.5362800, 12.1827000, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40442, 'Solbjerg', 'Solbjerg', 'Solbjaerg,Solbjærg', 56.0427100, 10.0863100, 'DK', '2009-10-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40443, 'Snoghøj', 'Snoghoj', 'Snoghoj,Snoghøj', 55.5225300, 9.7212500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40444, 'Snejbjerg', 'Snejbjerg', 'Snejbjaerg,Snejbjerg,Snejbjærg', 56.1387500, 8.8989600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40445, 'Smørumnedre', 'Smorumnedre', 'Smorum,Smorumnedre,Smørum,Smørumnedre', 55.7423200, 12.3027600, 'DK', '2013-11-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40446, 'Slangerup', 'Slangerup', 'Gmina Slangerup,Slangerup', 55.8500000, 12.1833300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40447, 'Slagelse', 'Slagelse', 'Gorad Slagel''seh,Slagel''se,Slagelse,si la e er se zi zhi shi,slagelse,Горад Слагельсэ,Слагельсе,სლაგელსე,斯拉厄爾瑟自治市', 55.4027600, 11.3545900, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40448, 'Skævinge', 'Skaevinge', 'Gmina Skaevinge,Gmina Skævinge,Skaevinge,Skævinge', 55.9078500, 12.1503600, 'DK', '2013-12-13', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40449, 'Sherrebek', 'Sherrebek', 'Sherrebek,Skaerbaek,Skærbæk', 55.1573500, 8.7690100, 'DK', '2014-06-13', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40450, 'Skovby', 'Skovby', 'Skovby,Skovby Ostj,Skovby Østj', 56.1534000, 9.9569500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40451, 'Skørping', 'Skorping', 'Gmina Skorping,Gmina Skørping,Skoerping,Skorping,Skorping Stationsby,Skörping,Skörping Stationsby,Skørping', 56.8362600, 9.8925500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40452, 'Skælskør', 'Skaelskor', 'Skaelskor,Skjelskor,Skjelskör,Skælskør', 55.2505800, 11.2935200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40453, 'Skjern', 'Skjern', 'Gmina Skjern,STA,Skern,Skerne,Skjern', 55.9500000, 8.5000000, 'DK', '2013-05-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40454, 'Skive', 'Skive', 'SQW,Skive,Скиве', 56.5669900, 9.0270700, 'DK', '2017-07-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40455, 'Skibby', 'Skibby', 'Skibby,Skiby', 55.7512200, 11.9608300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40456, 'Skanderborg', 'Skanderborg', 'Skanderborg', 56.0343400, 9.9317700, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40457, 'Skagen', 'Skagen', 'Gorad Skagen,QJV,Skagen,Skagenas,askagn,si ka en,skajn,Горад Скаген,Скаген,اسکاگن,سكاجن,斯卡恩', 57.7209300, 10.5839400, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40458, 'Sindal', 'Sindal', 'CNL,Gmina Sindal,Sindal', 57.4711700, 10.2031200, 'DK', '2010-05-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40459, 'Silkeborg', 'Silkeborg', 'Sil''keborg,Silkeborg,Silkeborgas,XAH,shirukebo,silkeboleu,sylkybwrj,xi er ke bao,Силкеборг,Силькеборг,Сількеборг,سيلكيبورج,სილკებორგი,シルケボー,锡尔克堡,실케보르', 56.1697000, 9.5450800, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40460, 'Seden', 'Seden', 'Seden', 55.4264800, 10.4426500, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40461, 'Sæby', 'Saeby', 'Saeby,Sæby', 57.3318800, 10.5225100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40462, 'Sakskøbing', 'Sakskobing', 'Gmina Sakskobing,Gmina Sakskøbing,Sakskobing,Sakskøbing,Saxkiobing,Saxkiöbing,Saxkjobing,Saxkjöbing', 54.7997000, 11.6259900, 'DK', '2011-03-15', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40463, 'Sabro', 'Sabro', '', 56.2133300, 10.0344100, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40464, 'Ryomgård', 'Ryomgard', 'Ryomgaard,Ryomgard,Ryomgård,Ryumgaard,Ryumgard,Ryumgård', 56.3843000, 10.5029500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40465, 'Ry', 'Ry', 'Ry,Rye,Rye Stationsby', 56.0903800, 9.7650500, 'DK', '2014-04-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40466, 'Rudkøbing', 'Rudkobing', 'Rudkiobing,Rudkjobing,Rudkjöbing,Rudkobing,Rudkøbing', 54.9363900, 10.7101900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40467, 'Roskilde', 'Roskilde', 'Gorad Roskile,Hroarskelda,Hróarskelda,RKE,Roschildia,Roskil''de,Roskilde,Roskildė,Roskile,Roskille,loseukille,luo si ji lei,raskylh,rosukire,rx ski ld,Горад Роскіле,Роскилде,Роскиле,Роскилле,Роскильде,Роскілле,Ռոսկիլդե,راسکیله,راسکیلے,รอสกิลด์,როსკილე,ロスキレ,罗斯基勒,로스킬레', 55.6415200, 12.0803500, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40468, 'Rønnede', 'Ronnede', 'Gmina Ronnede,Gmina Rønnede,Ronnede,Rønnede', 55.2571000, 12.0212500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40469, 'Rønne', 'Ronne', 'Gorad Roneh,RNN,Rene,Renne,Rione,Rionė,Rjonne,Ronne,Rønne,ZDY,rene,Горад Ронэ,Рене,Рённе,レネ', 55.1009100, 14.7066400, 'DK', '2013-06-16', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40470, 'Rønde', 'Ronde', 'Ronde,Rønde', 56.3014500, 10.4750500, 'DK', '2012-02-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40471, 'Rødvig', 'Rodvig', 'Rjodvig,Rodvig,Rødvig,Рёдвиг', 55.2554000, 12.3793600, 'DK', '2017-06-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40472, 'Rødovre', 'Rodovre', 'Comuna Rodovre,Comuna Rødovre,Kommun Rodovre,Kommun Rødovre,Municipi de Rodovre,Municipi de Rødovre,Munisipalitas Rodovre,Munisipalitas Rødovre,Redovre,Rodovre,Rodovre Chu-ti-chhi,Rodovre Kommune,Rodovre Komuun,Rodovre Municipality,Rodovre koezseg,Rodovre kommune,Rodovren kunta,Rødovre,Rødovre Chū-tī-chhī,Rødovre Kommune,Rødovre Komuun,Rødovre Municipality,Rødovre kommune,Rødovre község,Rødovren kunta,lei zao lei zi zhi shi,Редовре,勒藻勒自治市', 55.6806200, 12.4537300, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40473, 'Rødekro', 'Rodekro', 'Gmina Rodekro,Gmina Rødekro,Rodekro,Rødekro', 55.0707600, 9.3353100, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40474, 'Rødding', 'Rodding', 'Rodding,Rødding', 55.3656900, 9.0631600, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40475, 'Rødbyhavn', 'Rodbyhavn', 'Rodby Havn,Rodbyhavn,Roedby-havn,Rødbyhavn', 54.6544200, 11.3520300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40476, 'Rødby', 'Rodby', 'Gmina Rodby,Gmina Rødby,Rodby,Rødby,lei ci bi,勒兹比', 54.6949500, 11.3888500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40477, 'Ringsted', 'Ringsted', 'Ringsted,ling si tai ci,Рингстед,რინგსტედი,灵斯泰兹', 55.4426000, 11.7901100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40478, 'Ringkøbing', 'Ringkobing', 'Ringkiobingas,Ringkjobing,Ringkjöbing,Ringkobing,Ringkøbing', 56.0900600, 8.2440200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40479, 'Ringe', 'Ringe', 'Ringe', 55.2382800, 10.4786000, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40480, 'Ribe', 'Ribe', 'Ribe,Ripar,Rípar,li bo,libe,ribe,rybh,Рибе,Рібе,ریبه,リーベ,里伯,리베', 55.3305100, 8.7696600, 'DK', '2010-07-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40481, 'Randers', 'Randers', 'Randers,Randersa,Randersas,Raners,Ranners,Ranters,ZIR,lan ne si,laneleuseu,ra nex s,ranasu,randrs,ranersi,Ράντερς,Рандерс,Ранерс,Раннерс,راندرس,رانڈرز,ราเนอส์,რანერსი,ラナース,蘭訥斯,라네르스', 56.4607000, 10.0363900, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40482, 'Præstø', 'Praesto', 'Gmina Praesto,Gmina Præstø,Praesto,Præstø', 55.1177700, 12.0572700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40483, 'Pandrup', 'Pandrup', 'Gmina Pandrup,Panderup,Pandrup', 57.2214700, 9.6756900, 'DK', '2010-05-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40484, 'Padborg', 'Padborg', 'Padborg,Падборг', 54.8265700, 9.3624700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40485, 'Otterup', 'Otterup', 'Otterup', 55.5152700, 10.3975600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40486, 'Osted', 'Osted', 'Osted,Ousted', 55.5622800, 11.9578600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40487, 'Ørslev', 'Orslev', '', 55.0435600, 11.9679200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40488, 'Ølstykke', 'Olstykke', 'Olstykke,Ølstykke', 55.7956700, 12.1550900, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40489, 'Ølgod', 'Olgod', 'Gmina Olgod,Gmina Ølgod,OElgod,Olgod,Ölgod,Ølgod', 55.8068200, 8.6285900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40490, 'Oksbøl', 'Oksbol', 'Oksbol,Oksbøl,Oxbol,Oxbøl,Oxsbol,Oxsböl', 55.6268000, 8.2875700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40491, 'Odense', 'Odense', 'Gorad Odehnseh,ODE,Odensa,Odense,Odensė,Odinsve,Ontense,Othania,adnsh,awdnsh,odense,odinse,ou deng sai,xo den se,Óðinsvé,Όντενσε,Горад Одэнсэ,Оденсе,Օդենսե,אודנזה,أودنسه,ادنسه,اودنسے,اوڈینس,ओडिन्से,โอเดนเซ,ოდენსე,オーデンセ,欧登塞,오덴세', 55.3959400, 10.3883100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40492, 'Odder', 'Odder', 'Odder,Оддер', 55.9731300, 10.1530000, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40493, 'Nyråd', 'Nyrad', 'Nyraad,Nyrad,Nyråd', 55.0051100, 11.9606000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40494, 'Nykøbing Falster', 'Nykobing Falster', 'Nikebing Falster,Niukiobingas,Njukebing Fal''ster,Njukjobing,Nykjobing,Никебинг Фалстер,Нюкебінґ Фальстер,Нюкёбинг,ニュークビン・ファルスター', 54.7690600, 11.8742500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40495, 'Nykøbing Sjælland', 'Nykobing Sjaelland', 'Nykiobing,Nykiöbing,Nykjobing,Nykjöbing', 55.9249100, 11.6710900, 'DK', '2014-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40496, 'Nykøbing Mors', 'Nykobing Mors', 'Nykjobing,Nykjöbing,Nykobing,Nykøbing', 56.7933400, 8.8528200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40497, 'Nyborg', 'Nyborg', 'Niborg,Njuborg,Nyborg,ni bao zi zhi shi,Ниборг,Нюборг,尼堡自治市', 55.3127400, 10.7896400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40498, 'Næstved', 'Naestved', 'Naestved,Nestved,Nestvedas,nai si te wei ci,neseuteubedeu,nesutovu~ezu,Нествед,ნესტვედი,ネストヴェズ,奈斯特韦兹,네스트베드', 55.2299200, 11.7609200, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40499, 'Nordby', 'Nordby', 'Nordby,Odden', 55.4460300, 8.3978600, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40500, 'Nordborg', 'Nordborg', 'Gmina Nordborg,Nordborg,Nordburg', 55.0573200, 9.7408000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40501, 'Nørresundby', 'Norresundby', 'Norresundby,Nørresundby,neresunbiu,ნერესუნბიუ', 57.0587700, 9.9228400, 'DK', '2017-06-27', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40502, 'Nørre Hvalsø', 'Norre Hvalso', '', 55.6049300, 11.8573300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40503, 'Nørre Alslev', 'Norre Alslev', 'Gmina Norre Alslev,Gmina Nørre Alslev,Norre Alslev,Nørre Alslev', 54.8978400, 11.8841400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40504, 'Nørre Åby', 'Norre Aby', 'Norre Aaby,Norre Aby,Nørre Aaby,Nørre Åby', 55.4610700, 9.8794000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40505, 'Nødebo', 'Nodebo', 'Nodebo,Nødebo', 55.9787700, 12.3468500, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40506, 'Nivå', 'Niva', 'Niva,Nivaa,Nivå', 55.9340500, 12.5048500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40507, 'Nibe', 'Nibe', 'Nibe,Нибе', 56.9815000, 9.6391700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40508, 'Nexø', 'Nexo', 'Nekso,Neksø', 55.0606700, 15.1305800, 'DK', '2010-07-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40509, 'Neder Vindinge', 'Neder Vindinge', '', 55.0321100, 11.8835600, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40510, 'Neder Holluf', 'Neder Holluf', 'Neder Holluf', 55.3645100, 10.4482400, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40511, 'Nakskov', 'Nakskov', 'Nakskov,Nakskovas,Naskov,Наксков', 54.8373400, 11.1283900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40512, 'Munkebo', 'Munkebo', 'Munkebo', 55.4618400, 10.5557700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40513, 'Middelfart', 'Middelfart', 'Middel''fart,Миддельфарт', 55.5059100, 9.7305400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40514, 'Marstal', 'Marstal', 'Marstal,Marstal'',Марсталь', 54.8562100, 10.5172600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40515, 'Mårslet', 'Marslet', 'Maarslet,Marslet,Mårslet', 56.0636100, 10.1623000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40516, 'Maribo', 'Maribo', 'MRW,Maribo,Марибо,Марібо', 54.7766200, 11.5001700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40517, 'Mariager', 'Mariager', 'Gmina Mariager,Mariager,Мариагер', 56.6498500, 9.9751500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40518, 'Måløv', 'Malov', 'Maalov,Maaløv,Malov,Måløv', 55.7552800, 12.3232700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40519, 'Malling', 'Malling', 'Malling', 56.0363200, 10.1963200, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40520, 'Lystrup', 'Lystrup', 'Lystrup', 56.2375000, 10.2377800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40521, 'Lynge', 'Lynge', 'Lynge', 55.8394100, 12.2772500, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40522, 'Lunderskov', 'Lunderskov', 'Lunderskov', 55.4837500, 9.2991700, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40523, 'Løkken', 'Lokken', 'Lekken,Ljokken,Лёккен', 57.3704700, 9.7146600, 'DK', '2017-05-18', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40524, 'Løjt Kirkeby', 'Lojt Kirkeby', 'Loitkirkeby,Lojt,Lojt Kirkeby,Löjt,Løjt Kirkeby', 55.0833300, 9.4666700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40525, 'Løgumkloster', 'Logumkloster', 'Gmina Logumkloster,Gmina Løgumkloster,Loegumkloster,Logumkloster,Logumkloster Sogn,Lögumkloster,Løgumkloster,Løgumkloster Sogn', 55.0594100, 8.9550800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40526, 'Løgten', 'Logten', '', 56.2745900, 10.3118100, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40527, 'Løgstør', 'Logstor', 'Gmina Logstor,Gmina Løgstør,Loegstoer,Logstor,Lögstör,Løgstør', 56.9624500, 9.2583000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40528, 'Liseleje', 'Liseleje', 'Liseleje', 56.0129500, 11.9654400, 'DK', '2017-07-04', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40529, 'Lind', 'Lind', '', 56.1000000, 8.9833300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40530, 'Værløse', 'Vaerlose', 'Lille Vaerlose,Lille Værløse,Vaerlose,Værløse', 55.7825100, 12.3685600, 'DK', '2016-09-27', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40531, 'Lillerød', 'Lillerod', '', 55.8749600, 12.3457900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40532, 'Lemvig', 'Lemvig', 'Lemvig,Лемвиг', 56.5485600, 8.3101900, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40533, 'Lejre', 'Lejre', '', 55.6046100, 11.9747700, 'DK', '2011-12-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40534, 'Langeskov', 'Langeskov', 'Langeskov', 55.3565500, 10.5844700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40535, 'Langå', 'Langa', 'Langa,Langaa,Langå', 56.3902600, 9.8948600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40536, 'Kruså', 'Krusa', 'Krusa,Krusaa,Kruså', 54.8509700, 9.4012900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40537, 'Korsør', 'Korsor', 'Gorad Korsjor,Korser,Korsjor,Korsor,Korsør,Горад Корсёр,Корсер,Корсёр', 55.3299300, 11.1385700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40538, 'Køge', 'Koge', 'Kege,Keje,Kioge,Kiogė,Kjoge,Koge,Køge,ke e,koie,kyuge,Кеге,Кеје,Кёге,კეგე,キューゲ,克厄,코이에', 55.4580200, 12.1821400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40539, 'Copenhagen', 'Copenhagen', 'CPH,Cobanhavan,Copenaga,Copenaghen,Copenaguen,Copenhaga,Copenhagen,Copenhague,Copenhaguen,Copenhaguen - Kobenhavn,Copenhaguen - København,Cóbanhávan,Hafnia,Kapehngagen,Kaupmannahoefn,Kaupmannahöfn,Keypmannahavn,Kjobenhavn,Kjopenhamn,Kjøpenhamn,Kobenhamman,Kobenhaven,Kobenhavn,Kodan,Kodaň,Koebenhavn,Koeoepenhamina,Koepenhamn,Kopenage,Kopenchage,Kopengagen,Kopenhaagen,Kopenhag,Kopenhaga,Kopenhage,Kopenhagen,Kopenhagena,Kopenhago,Kopenhāgena,Kopenkhagen,Koppenhaga,Koppenhága,Kòpenhaga,Köbenhavn,Köpenhamn,Kööpenhamina,København,Københámman,ge ben ha gen,khopenheken,kopanahagana,kopenahagena,kopenahegena,kopenhagen,kwbnhaghn,kwpnhgn,qwpnhgn,Κοπεγχάγη,Капэнгаген,Копенгаген,Копенхаген,Կոպենհագեն,קופנהאגן,קופנהגן,كوبنهاغن,كوپېنھاگېن,ܟܘܦܢܗܓܢ,कोपनहागन,কোপেনহাগেন,কোপেনহেগেন,โคเปนเฮเกน,ཀའོ་པེན་ཧ་ཀེན,კოპენჰაგენი,ኮፐንሀገን,ኮፕንሀግ,コペンハーゲン,哥本哈根,코펜하겐', 55.6759400, 12.5655300, 'DK', '2012-11-26', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40540, 'Kongens Lyngby', 'Kongens Lyngby', 'Kgs. Lyngby,Konigs Lyngby,Lyngby', 55.7704400, 12.5037800, 'DK', '2014-02-27', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40541, 'Kolt', 'Kolt', '', 56.1084500, 10.0698600, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40542, 'Kolding', 'Kolding', 'Gorad Kol''dyng,Kol''ding,Kolding,Koldinga,Koldingas,Koldingo,Kolling,ZBT,ke ling,khxleng,kolling,koringu,kwldngh,kwldyng,Горад Кольдынг,Колдинг,Коллинг,Кольдинг,كولدنغ,کولدینگ,کولڈنگ,คอเลง,კოლინგი,コリング,科靈,콜링', 55.4904000, 9.4721600, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40543, 'Kokkedal', 'Kokkedal', 'Kokkedal'',Коккедаль', 55.9117900, 12.4995200, 'DK', '2011-12-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40544, 'Klarup', 'Klarup', 'Klarup', 57.0119400, 10.0561700, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40545, 'Kjellerup', 'Kjellerup', 'Kellerup,Kjellerup,QJW', 56.2858100, 9.4352800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40546, 'Kirke Hvalsø', 'Kirke Hvalso', 'Hvalso,Hvalsø', 55.5917000, 11.8625300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40547, 'Kibæk', 'Kibaek', 'Kibaek,Kibæk', 56.0317000, 8.8569700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40548, 'Kerteminde', 'Kerteminde', 'Kierteminde,Kjerteminde', 55.4490300, 10.6576900, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40549, 'Kås', 'Kas', 'Kaas,Kas,Kås', 57.1977400, 9.6717300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40550, 'Karup', 'Karup', 'KRP,Karup,Midtjylland', 56.3067300, 9.1683500, 'DK', '2017-03-04', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40551, 'Kalundborg', 'Kalundborg', 'Kallundborg,Kalundborg', 55.6795400, 11.0886400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40552, 'Jyllinge', 'Jyllinge', 'Jyllinge', 55.7584300, 12.1122700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40553, 'Jyderup', 'Jyderup', 'Jyderup', 55.6639900, 11.4202900, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40554, 'Juelsminde', 'Juelsminde', 'Juelsminde', 55.7087600, 10.0166800, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40555, 'Jægerspris', 'Jaegerspris', 'Gmina Jaegerspris,Gmina Jægerspris,Jaegerspris,Jægerspris', 55.8524800, 11.9856500, 'DK', '2017-07-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40556, 'Jelling', 'Jelling', 'Eling,Elling,Gravhoegarna,Gravhögarna,Jelling,i~eringu,ye ling,yylyn,Еллинг,Елінг,יילין,イェリング,耶靈', 55.7558800, 9.4258000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40557, 'Ishøj', 'Ishoj', 'Ishoj,Ishøj', 55.6154300, 12.3518200, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40558, 'Ikast', 'Ikast', 'QLZ', 56.1388300, 9.1576800, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40559, 'Hvidovre', 'Hvidovre', 'Hvidovre,Khvidovre,Хвидовре', 55.6571900, 12.4736400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40560, 'Hvide Sande', 'Hvide Sande', '', 56.0045200, 8.1293700, 'DK', '2010-08-15', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40561, 'Hurup', 'Hurup', 'Hurup,Thy', 56.7494400, 8.4195300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40562, 'Hundested', 'Hundested', 'Gmina Hundested,Hundested', 55.9666700, 11.8666700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40563, 'Humlebæk', 'Humlebaek', '', 55.9618000, 12.5341000, 'DK', '2011-12-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40564, 'Horsens', 'Horsens', 'Horsens,Horsensas,Khorsens,h xr sens,holeusenseu,horsensi,hosensu,huo er sen si,hwrsyns,hwrzns,Хорсенс,هورزنس,هورسينس,ہارسنز,ฮอร์เซนส์,ჰორსენსი,ホーセンス,霍尔森斯,호르센스', 55.8606600, 9.8503400, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40565, 'Hornsyld', 'Hornsyld', 'Hornsyld', 55.7562100, 9.8564300, 'DK', '2017-07-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40566, 'Hornslet', 'Hornslet', 'Hornslet', 56.3155000, 10.3204100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40567, 'Hornbæk', 'Hornbaek', 'Hornbaek,Hornbæk', 56.0854100, 12.4504900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40568, 'Hørve', 'Horve', 'Horv,Horve,Hørv,Hørve', 55.7529200, 11.4529800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40569, 'Høruphav', 'Horuphav', '', 54.9101700, 9.8987200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40570, 'Hørsholm', 'Horsholm', 'Hiorsholmas,Horsholm,Hørsholm,Kherskhol''m,Khjorskhol''m,hersholmi,Херсхольм,Хёрсхольм,ჰერსჰოლმი', 55.8809800, 12.5011100, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40571, 'Hørning', 'Horning', 'Horning,Hørning', 56.0870100, 10.0371600, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40572, 'Høng', 'Hong', 'Gmina Hong,Gmina Høng,Hong,Høng', 55.5116500, 11.2903200, 'DK', '2010-05-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40573, 'Højslev', 'Hojslev', 'Hoislev,Hojslev,Höislev,Højslev', 56.5856500, 9.1363700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40574, 'Højby', 'Hojby', 'Hojby,Højby', 55.9114800, 11.5975600, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40575, 'Højby', 'Hojby', '', 55.3317700, 10.4372500, 'DK', '2017-07-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40576, 'Holte', 'Holte', 'Holte,Ny-Holte', 55.8166700, 12.4666700, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40577, 'Holsted', 'Holsted', 'Holsted', 55.5108600, 8.9187200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40578, 'Holstebro', 'Holstebro', 'Holstebro,Khol''stebro,Kholstebro,Kholtesbro,QWO,huo er si te bu luo,Холстебро,Холтесбро,Хольстебро,ჰოლსტებრო,霍爾斯特布羅', 56.3600900, 8.6160700, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40579, 'Holeby', 'Holeby', 'Gmina Holeby,Holeby', 54.7114800, 11.4641600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40580, 'Holbæk', 'Holbaek', 'Holbaek,Holbekas,Holbæk,Hollbaek,Hollbæk,Khol''bek,Kholbek,Холбек,Хольбек,ჰოლბეკი', 55.7135400, 11.7169000, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40581, 'Hobro', 'Hobro', 'Hobro,Khobro,hwbrw,Хобро,هوبرو', 56.6430600, 9.7902900, 'DK', '2012-02-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40582, 'Hjortshøj', 'Hjortshoj', 'Hjortshoj,Hjortshøj', 56.2481100, 10.2653300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40583, 'Hjørring', 'Hjorring', 'Hjoerring,Hjorring,Hjörring,Hjørring,Jering,Khjoring,ieringi,Јеринг,Хјоринг,იერინგი', 57.4641700, 9.9822900, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40584, 'Hjallerup', 'Hjallerup', 'Hjallerup', 57.1646600, 10.1457100, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40585, 'Hirtshals', 'Hirtshals', 'Hirtshals,Khirtskhal''s,Lilleheden Hornsnaes,Lilleheden Hornsnæs,XAJ,xi ci hai er si,Хиртсхальс,希茨海尔斯', 57.5881200, 9.9592200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40586, 'Hinnerup', 'Hinnerup', 'Gmina Hinnerup,Hinnerup,Hinnerup-Broby,Khinnerup,Хиннеруп', 56.2660800, 10.0629900, 'DK', '2012-02-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40587, 'Hillerød', 'Hillerod', 'Hillerod,Hillerød,Khillerod,hylrwd,Хиллерод,הילרוד', 55.9279100, 12.3008100, 'DK', '2013-11-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40588, 'Herning', 'Herning', 'Gerning,Herning,Herningas,Kherning,Munisipalitas Herning,Munisipaliti Herning,ZRY,hai ning,heaningu,herningi,Гернінг,Хернинг,ჰერნინგი,ヘアニング,海宁', 56.1393200, 8.9737800, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40589, 'Herlev', 'Herlev', 'Herlev', 55.7236600, 12.4399800, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40590, 'Helsingør', 'Helsingor', 'Elseneur,Elsinoer,Elsinor,Elsinore,Elsinör,Gel''singer,Gorad Khel''singjor,Helsingioras,Helsingjaeyri,Helsingoer,Helsingor,Helsingör,Helsingør,Khel''singjor,Khelsinger,he er xin ge,hel singnge xr,helsing-oeleu,helsingeri,herushingeru,hylysynkwr,xi xing jia,Гельсінгер,Горад Хельсінгёр,Хелсингер,Хельсингёр,هيليسينكور,เฮลซิงเงอร์,ჰელსინგერი,ヘルシンゲル,希星加,赫爾辛格,헬싱외르', 56.0360600, 12.6136000, 'DK', '2015-11-13', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40591, 'Helsinge', 'Helsinge', 'Khel''singe,Хельсинге', 56.0228300, 12.1975200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40592, 'Hellebæk', 'Hellebaek', 'Hellebaek,Hellebæk', 56.0682300, 12.5578200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40593, 'Hedensted', 'Hedensted', '', 55.7704300, 9.7011000, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40594, 'Havdrup', 'Havdrup', 'Havdrup', 55.5448100, 12.1239200, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40595, 'Haslev', 'Haslev', 'Khaslev,Хаслев', 55.3234600, 11.9638900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40596, 'Hårlev', 'Harlev', 'Haarlev,Harlev,Hårlev', 55.3493600, 12.2338200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40597, 'Hårby', 'Harby', 'Haarby,Harby,Hårby', 55.2150200, 10.1226200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40598, 'Harboøre', 'Harboore', 'Harboor,Harboør', 56.6175200, 8.1806900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40599, 'Hanstholm', 'Hanstholm', 'Gmina Hanstholm,Hanstholm', 57.1166700, 8.6166700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40600, 'Hammerum', 'Hammerum', 'Hammerum,Hamrum', 56.1336100, 9.0612100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40601, 'Hammel', 'Hammel', 'Gmina Hammel,Hammel,funmeru,フンメル', 56.2576200, 9.8631600, 'DK', '2012-08-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40602, 'Hals', 'Hals', 'Hals', 56.9960900, 10.3080700, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40603, 'Hadsund', 'Hadsund', 'Gmina Hadsund,Hadsund,Hadsundas,Khadsund,Khadsunn,hadsuni,qi xin,Хадсунд,Хадсунн,ჰადსუნი,乞信', 56.7148200, 10.1168200, 'DK', '2011-08-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40604, 'Hadsten', 'Hadsten', 'Hadsten Stationsby,Khadsten,Хадстен', 56.3281900, 10.0493100, 'DK', '2012-02-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40605, 'Haderslev', 'Haderslev', 'Gorad Khadehrsleu,Hadersleben,Haderslev,Haderslevas,Haderslevo,Khaderslev,haderslevi,Горад Хадэрслеў,Хадерслев,ჰადერსლევი', 55.2537700, 9.4898200, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40606, 'Gundsømagle', 'Gundsomagle', 'Gundsomagle,Gundsømagle', 55.7356500, 12.1515800, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40607, 'Guderup', 'Guderup', '', 54.9897800, 9.8717400, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40608, 'Græsted', 'Graested', 'Graested,Græsted', 56.0655800, 12.2851200, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40609, 'Grindsted', 'Grindsted', 'Grindsted', 55.7572600, 8.9275000, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40610, 'Greve', 'Greve', '', 55.5833300, 12.3000000, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40611, 'Grenaa', 'Grenaa', 'Grena,Grenaa,Grenå', 56.4157800, 10.8782500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40612, 'Gråsten', 'Grasten', 'Gmina Grasten,Gmina Gråsten,Graasten,Grasten,Gravenstein,Gråsten', 54.9191800, 9.5952300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40613, 'Gram', 'Gram', '', 55.2894800, 9.0491300, 'DK', '2009-10-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40614, 'Gørlev', 'Gorlev', 'Giorley,Gjorlev,Gjörlev,Gmina Gorlev,Gmina Gørlev,Gorlev,Gørlev', 55.5392600, 11.2270800, 'DK', '2010-05-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40615, 'Glostrup', 'Glostrup', 'Comuna Glostrup,Glostrup,Glostrup Chu-ti-chhi,Glostrup Chū-tī-chhī,Glostrup Kommune,Glostrup Komuun,Glostrup Municipality,Glostrup koezseg,Glostrup kommuna,Glostrup kommune,Glostrup község,Glostrupin kunta,Glostrups kommun,Gmina Glostrup,Kommun Glostrup,Municipi de Glostrup,Munisipalitas Glostrup,ge luo si chu pu zi zhi shi,Глоструп,Գլոստրուպ,გლოსტრუპი,格洛斯楚普自治市', 55.6666000, 12.4037700, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40616, 'Glamsbjerg', 'Glamsbjerg', 'Glamsbjaerg,Glamsbjerg,Glamsbjærg,Gmina Glamsbjerg', 55.2723700, 10.1048300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40617, 'Gjellerup Kirkeby', 'Gjellerup Kirkeby', 'Gjellerup,Gjellerup Kirkeby,Kirkeby', 56.1434100, 9.0498800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40618, 'Give', 'Give', 'Give', 55.8397700, 9.2499800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40619, 'Gistrup', 'Gistrup', 'Gistrup', 56.9943000, 9.9908500, 'DK', '2014-04-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40620, 'Gilleleje', 'Gilleleje', 'Gilleje,Gilleleje', 56.1219600, 12.3105600, 'DK', '2014-06-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40621, 'Ganløse', 'Ganlose', '', 55.7912400, 12.2642100, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40622, 'Galten', 'Galten', 'Galten,Sonder Galten', 56.1590200, 9.9169100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40623, 'Fuglebjerg', 'Fuglebjerg', 'Fuglebaerg,Fuglebjerg,Fuglebærg,Gmina Fuglebjerg', 55.3060400, 11.5476600, 'DK', '2010-09-29', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40624, 'Frejlev', 'Frejlev', 'Freilev,Frejlev', 57.0062300, 9.8171100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40625, 'Frederiksværk', 'Frederiksvaerk', 'Frederiksvaerk,Frederiksværk', 55.9707300, 12.0225000, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40626, 'Frederikssund', 'Frederikssund', 'Frederikssund,Frederikssunn,Frederiksund,Фредерикссунн,Фредериксунд', 55.8395600, 12.0689600, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40627, 'Frederikshavn', 'Frederikshavn', 'Fladstrand,Frederikshaunas,Frederikshavn kommuna,Frederikskhavn,Fredrikshamn,QFH,fei te lie gang,furezerikusuhaun,peuledeligseuhaun,prederikshavni,Фредериксхавн,ფრედერიქსჰავნი,フレゼリクスハウン,腓特烈港,프레데릭스하운', 57.4407300, 10.5366100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40628, 'Frederiksberg', 'Frederiksberg', 'Frederiksberg,Frederiksberg Kommune,Frederiksbergin kunta,Frenteriksmpernk,fei te lie si bei,frydryksbrgh,peuledeligseubeleu,prederikʼsbergi,Φρέντερικσμπεργκ,Фредериксберг,Фредеріксберг,فريدريكسبرغ,فریڈرکسبرگ,ფრედერიკსბერგი,腓特烈斯贝,프레데릭스베르', 55.6793800, 12.5346300, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40629, 'Frederiksberg', 'Frederiksberg', '', 55.4161800, 11.5693400, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40630, 'Fredericia', 'Fredericia', 'Fredericia,Fredericija,Frederisija,ZBJ,furezerishia,peuledelisia,prederisia,Фредерисия,Фредериција,ფრედერისია,フレゼリシア,프레데리시아', 55.5656800, 9.7525700, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40631, 'Fredensborg', 'Fredensborg', '', 55.9755800, 12.4031400, 'DK', '2011-12-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40632, 'Framlev', 'Framlev', '', 56.1566400, 10.0131800, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40633, 'Forlev', 'Forlev', '', 55.3744500, 11.2596600, 'DK', '2017-07-04', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40634, 'Fløng', 'Flong', 'Flong,Fløng', 55.6621200, 12.1869800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40635, 'Fjerritslev', 'Fjerritslev', 'Fjerreslev,Fjerritslev,Gmina Fjerritslev', 57.0882200, 9.2662200, 'DK', '2017-07-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40636, 'Fensmark', 'Fensmark', '', 55.2791900, 11.8038200, 'DK', '2010-09-29', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40637, 'Farum', 'Farum', 'Farum,Фарум', 55.8085800, 12.3606600, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40638, 'Farsø', 'Farso', 'Farso,Farsoe,Farsö,Farsø,Gmina Farso,Gmina Farsø', 56.7727600, 9.3392500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40639, 'Fakse Ladeplads', 'Fakse Ladeplads', 'Fakse Ladeplads,Faxe Havn', 55.2198100, 12.1701300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40640, 'Fakse', 'Fakse', 'Fakse,Faxe,Gmina Fakse,Факсе', 55.2556100, 12.1192600, 'DK', '2017-07-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40641, 'Faaborg', 'Faaborg', 'Fabberg,Faborg,Fåborg', 55.0951000, 10.2422600, 'DK', '2014-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40642, 'Espergærde', 'Espergaerde', 'Espergaerde,Espergjaerde,Espergjærde,Espergærde', 55.9946400, 12.5473300, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40643, 'Esbjerg', 'Esbjerg', 'EBJ,Ehsb''erg,Esber,Esberg,Esbjaerg,Esbjerg,Esbjerga,Esbjergas,Esbjærg,Esbyerq,ai si bi yue,asbjrg,asbyrg,aysbyrgh,esbieri,eseubieleu,esubyau,xe sbiyer,Есбер,Есбєрг,Есбјерг,Эсбьерг,אסביירג,إيسبيرغ,اسبجرگ,اسبیرگ,เอสบีเยร์,ესბიერი,エスビャウ,埃斯比约,에스비에르', 55.4702800, 8.4518700, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40644, 'Ejby', 'Ejby', 'Ejby', 55.6892300, 11.8472500, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40645, 'Ejby', 'Ejby', 'Ejby', 55.4858000, 12.0817100, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40646, 'Ejby', 'Ejby', 'Egby,Ejby,Gammel Ejby', 55.4301000, 9.9297300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40647, 'Egtved', 'Egtved', 'Egtved,Gmina Egtved', 55.6179600, 9.3010200, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40648, 'Ebeltoft', 'Ebeltoft', 'AEbeltoft,Ebeltoft kommune,Ehbel''toft,Æbeltoft,Эбельтофт', 56.1944200, 10.6821000, 'DK', '2012-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40649, 'Dybbøl', 'Dybbol', 'Dybbol,Dybbøl', 54.9107900, 9.7360100, 'DK', '2012-02-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40650, 'Dronninglund', 'Dronninglund', 'Dronninglund,Gmina Dronninglund', 57.1603500, 10.2928700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40651, 'Dragør', 'Dragor', 'Dragjor,Dragoer,Dragor,Dragör,Dragør,de la e zi zhi shi,Драгёр,德拉厄自治市', 55.5928000, 12.6722100, 'DK', '2017-07-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40652, 'Dianalund', 'Dianalund', 'Dianalund', 55.5313300, 11.4925000, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40653, 'Christianshavn', 'Christianshavn', 'Christianshavn', 55.6738300, 12.5954100, 'DK', '2014-12-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40654, 'Christiansfeld', 'Christiansfeld', 'Christianfeld,Christiansfeld,Gmina Christiansfeld', 55.3581700, 9.4870100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40655, 'Charlottenlund', 'Charlottenlund', 'Charlottenlund', 55.7523800, 12.5745000, 'DK', '2017-07-07', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40656, 'Byrum', 'Byrum', 'Byrum', 57.2567900, 10.9973800, 'DK', '2014-02-06', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40657, 'Bullerup', 'Bullerup', 'Bullerup', 55.4268600, 10.4713700, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40658, 'Buddinge', 'Buddinge', '', 55.7481800, 12.4953200, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40659, 'Brovst', 'Brovst', 'Brovst,Gmina Brovst', 57.0956200, 9.5280100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40660, 'Brørup', 'Brorup', 'Brorup,Brørup', 55.4819400, 9.0175600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40661, 'Brønderslev', 'Bronderslev', 'Bronderslev,Brønderslev,XAQ', 57.2702100, 9.9410200, 'DK', '2013-10-27', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40662, 'Brøndbyvester', 'Brondbyvester', 'Brondby,Brondbyvester,Brøndby,Brøndbyvester,West Brondby,West Bröndby', 55.6455000, 12.4100800, 'DK', '2017-07-08', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40663, 'Broager', 'Broager', 'Broacker,Broager,Broager Sogn,Gmina Broager', 54.8873600, 9.6809600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40664, 'Brenderup', 'Brenderup', 'Braenderup,Brenderup,Brænderup', 55.4900000, 9.9736500, 'DK', '2013-04-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40665, 'Brejning', 'Brejning', 'Bregning,Brejning', 55.6613000, 9.6770300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40666, 'Brædstrup', 'Braedstrup', 'Braedstrup,Bredstrup,Brædstrup', 55.9715300, 9.6112900, 'DK', '2013-10-29', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40667, 'Brande', 'Brande', 'Brande,Gmina Brande,ZMW', 55.9381400, 9.1217800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40668, 'Bramming', 'Bramming', 'Bramming,Bramminge,Bramminge Stationsby,Gmina Bramming', 55.4694600, 8.7000700, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40669, 'Borup', 'Borup', 'Borup', 55.4947200, 11.9758400, 'DK', '2012-05-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40670, 'Bording Kirkeby', 'Bording Kirkeby', 'Bording,Bording Kirkeby,Borring', 56.1687100, 9.2438400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40671, 'Børkop', 'Borkop', 'Borkop,Børkop', 55.6379300, 9.6482300, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40672, 'Bogense', 'Bogense', 'Bogense,Богенсе', 55.5669100, 10.0886300, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40673, 'Blovstrød', 'Blovstrod', '', 55.8703800, 12.3864000, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40674, 'Bjæverskov', 'Bjaeverskov', 'Bjaeverskov,Bjeverskov,Bjæverskov', 55.4575600, 12.0365100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40675, 'Bjerringbro', 'Bjerringbro', '', 56.3779700, 9.6606500, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40676, 'Birkerød', 'Birkerod', 'Birkerod,Birkerød', 55.8475900, 12.4279100, 'DK', '2014-03-03', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40677, 'Billund', 'Billund', 'BLL,Billund,Billunda,Billunn,Bilount,Bilundas,Gmina Billund,bi long,billun,bilundi,Μπιλούντ,Биллунн,ბილუნდი,比隆,빌룬', 55.7334900, 9.1078500, 'DK', '2014-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40678, 'Bellinge', 'Bellinge', 'Bellinge', 55.3353500, 10.3204500, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40679, 'Beder', 'Beder', 'Beder,Бедер', 56.0602500, 10.2117900, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40680, 'Ballerup', 'Ballerup', 'Balerup,Balleru,Ballerup,Ballerup Belediyesi,Ballerup Chu-ti-chhi,Ballerup Chū-tī-chhī,Ballerup Kommune,Ballerup Komuun,Ballerup Municipality,Ballerup koezseg,Ballerup kommune,Ballerup község,Ballerupin kunta,Comuna Ballerup,Kommun Ballerup,Municipi de Ballerup,Munisipalitas Ballerup,Munisipaliti Ballerup,ba lei lu pu zi zhi shi,Բալերուպ,巴勒魯普自治市', 55.7316500, 12.3632800, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40681, 'Avlum', 'Avlum', 'Aulum,Avlum', 56.2653900, 8.7925600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40682, 'Auning', 'Auning', 'Auning,Avning', 56.4307900, 10.3781800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40683, 'Augustenborg', 'Augustenborg', 'Augustenborg,Gmina Augustenborg,Аугустенборг', 54.9520100, 9.8721600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40684, 'Assentoft', 'Assentoft', 'Assentoft', 56.4421000, 10.1517000, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40685, 'Assens', 'Assens', 'Assens,Ассенс', 55.2702300, 9.9008100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40686, 'Asnæs', 'Asnaes', 'Asnaes,Asnæs', 55.8122900, 11.5012900, 'DK', '2016-03-10', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40687, 'Årup', 'Arup', 'Aarup,Arup,Årup', 55.3731500, 10.0413100, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40688, 'Årslev', 'Arslev', 'Aarslev,Arslev,Årslev', 55.3035300, 10.4642800, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40689, 'Aars', 'Aars', 'Aars,Ars,Gmina Aars,asu,Års,アース', 56.8039900, 9.5144100, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40690, 'Århus', 'Arhus', 'Aarhus,Aarhusium,Archous,Arhus,Arhuzo,Arosar,Orhusa,Orhūsa,Orkhus,ao hu si,ofusu,Árósar,Århus,Άρχους,Орхус,אורהוס,オーフス,奥胡斯', 56.1567400, 10.2107600, 'DK', '2016-07-05', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40691, 'Arden', 'Arden', 'Arden,Arden Stationsby', 56.7689900, 9.8618400, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40692, 'Allingåbro', 'Allingabro', 'Allingaabro,Allingabro,Allingåbro', 56.4649500, 10.3340900, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40693, 'Ålestrup', 'Alestrup', 'Aalestrup,Alestrup,Ålestrup', 56.6947000, 9.4933600, 'DK', '2012-01-17', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40694, 'Aalborg', 'Aalborg', 'AAL,Aalborg,Alaborg,Alborg,Almpornk,Gorad Ol''barg,Ol''borg,Olbor,Olborg,Olborga,Olborgas,albrg,albw,albwrg,albwrgh,ao er bao,olboleu,olborgi,orubo,xx lb xr,Álaborg,Ålborg,Άλμποργκ,Горад Ольбарг,Олбор,Олборг,Ольборг,Օլբորգ,אולבורג,آلبرگ,آلبو,آلبورغ,آلبورگ,ออลบอร์,ოლბორგი,オールボー,奥尔堡,올보르', 57.0480000, 9.9187000, 'DK', '2010-07-09', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40695, 'Albertslund', 'Albertslund', 'Al''bertslunn,Albertslun,Albertslund,Albertslund Chu-ti-chhi,Albertslund Chū-tī-chhī,Albertslund Kommune,Albertslund Komuun,Albertslund Municipality,Albertslund koezseg,Albertslund kommune,Albertslund község,Albertslundin kunta,Comuna Albertslund,Gmina Albertslund,Kommun Albertslund,Municipi dAlbertslund,Munisipalitas Albertslund,Munisipaliti Albertslund,a er bei te si long zi zhi shi,Альбертслунн,Ալբերտսլուն,شهر البرتس‌لاند,阿爾貝特斯隆自治市', 55.6569100, 12.3638100, 'DK', '2011-03-01', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40696, 'Åkirkeby', 'Akirkeby', 'Aakirkeby', 55.0708000, 14.9197800, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40697, 'Ærøskøbing', 'AEroskobing', 'AEroskiobing,AEroskjobing,AEroskobing,Æroskiobing,Æröskjöbing,Ærøskøbing', 54.8880300, 10.4111700, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40698, 'Åbybro', 'Abybro', 'Aabybro,Abybro,Gmina Aabybro,Åbybro', 57.1583600, 9.7367200, 'DK', '2011-12-20', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40699, 'Aabenraa', 'Aabenraa', 'Aabenra,Aabenraa,Aabenrå,Abenra,Abenrá,Abrenra,Apenrade,Obenro,XNR,ao ben luo,obenlo,obenro,Åbenrå,Åbrenrå,Обенро,オーベンロー,奥本罗,오벤로', 55.0443400, 9.4174100, 'DK', '2010-07-21', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40700, 'Christiansø', 'Christianso', '', 55.3200600, 15.1866200, 'DK', '2012-02-03', 61);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40355, 'Ḏânan', 'Danan', 'Danan,Ḏânan', 11.1833300, 42.9333300, 'DJ', '2013-05-05', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40356, '‘Arta', '`Arta', 'Arta,`Arta,‘Arta', 11.5222200, 42.8419400, 'DJ', '2015-06-25', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40357, '''Ali Sabieh', '''Ali Sabieh', 'Ali Sabie,Ali Sabieh,Ali Sabiet,Ali Sabih,Ali Sabiè,Ali-Sabie,`Ali Sabieh,`Ali Sabih,Али-Сабие,‘Ali Sabieh,‘Ali Sabîẖ', 11.1558300, 42.7125000, 'DJ', '2016-04-06', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40358, 'Alaïli Ḏaḏḏa‘', 'Alaili Dadda`', 'Alaili Dadda`,Alayli Dadda`,Alayli Ḏaḏḏa‘,Alaïli Ḏaḏḏa‘', 12.4216700, 42.8955600, 'DJ', '2012-01-19', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40359, 'Goubétto', 'Goubetto', 'Goubatto,Goubetto,Goubétto', 11.4238900, 43.0002800, 'DJ', '2013-05-05', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40360, 'Gâlâfi', 'Galafi', 'Galafi,Gâlâfi', 11.7158300, 41.8361100, 'DJ', '2012-05-06', 62);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40701, 'Woodford Hill', 'Woodford Hill', '', 15.5666700, -61.3333300, 'DM', '2006-01-17', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40702, 'Wesley', 'Wesley', 'La Soie,Wesley', 15.5666700, -61.3166700, 'DM', '2013-06-27', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40703, 'Soufrière', 'Soufriere', 'Soufriere,Soufrière', 15.2337400, -61.3588100, 'DM', '2013-06-27', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40704, 'Salisbury', 'Salisbury', 'Baroui,Barroui,Salisbury', 15.4333300, -61.4500000, 'DM', '2012-01-18', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40705, 'Saint Joseph', 'Saint Joseph', 'Saint Joseph', 15.4000000, -61.4333300, 'DM', '2013-06-27', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40706, 'Roseau', 'Roseau', 'Charlotte Town,Gorad Razo,Roseau,Roseo,Rozo,lojo,luo suo,ro so,rozo,rusa''u,rwsw,rwzw,uroco,Ροζό,Горад Разо,Розо,Ռոզո,רוזו,روسو,रुसाउ,ਰੋਜ਼ੋ,உறொசோ,โรโซ,རུ་ཟོ།,როზო,ሮዞ,ロゾー,羅索,로조', 15.3017400, -61.3880800, 'DM', '2010-08-16', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40707, 'Rosalie', 'Rosalie', 'Rosalie', 15.3666700, -61.2666700, 'DM', '2013-06-27', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40708, 'Portsmouth', 'Portsmouth', 'Grand-Anse,Portsmouth', 15.5833300, -61.4666700, 'DM', '2013-06-27', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40709, 'Pont Cassé', 'Pont Casse', 'Pont Casse,Pont Cassé', 15.3666700, -61.3500000, 'DM', '2013-05-05', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40710, 'Pointe Michel', 'Pointe Michel', 'La Pointe,Pointe Michel', 15.2597600, -61.3745200, 'DM', '2013-03-26', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40711, 'Marigot', 'Marigot', 'Marigot,Petit Marigot', 15.5333300, -61.3000000, 'DM', '2012-01-18', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40712, 'Mahaut', 'Mahaut', 'Mahaut', 15.3635700, -61.3970100, 'DM', '2013-03-26', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40713, 'La Plaine', 'La Plaine', 'La Plaine', 15.3333300, -61.2500000, 'DM', '2012-01-18', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40714, 'Colihaut', 'Colihaut', 'Colihaut,Coulihaut,Kulihao', 15.4847800, -61.4621500, 'DM', '2013-05-05', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40715, 'Castle Bruce', 'Castle Bruce', 'Castle Bruce', 15.4333300, -61.2666700, 'DM', '2012-01-18', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40716, 'Calibishie', 'Calibishie', 'Calibishi,Calibishie', 15.5833300, -61.3500000, 'DM', '2012-01-18', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40717, 'Berekua', 'Berekua', 'Berekua,Grand Baie,Grand Bay', 15.2333300, -61.3166700, 'DM', '2013-05-05', 63);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40718, 'Yayas de Viajama', 'Yayas de Viajama', 'Las Yayas,Las Yayas de Viajama,Yayas de Viajama', 18.6071000, -70.9275300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40719, 'Yamasá', 'Yamasa', 'Villa de Yamasa,Villa de Yamasá,Yamasa,Yamasá', 18.7731500, -70.0258300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40720, 'Yaguate', 'Yaguate', 'Villa de Yaguate,Yaguate', 18.3353000, -70.1811300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40721, 'Villa Vásquez', 'Villa Vasquez', 'Lucas Evangelista de Pena,Lucas Evangelista de Peña,Villa Isabel,Villa Vasquez,Villa Vazquez,Villa Vásquez,Villa Vázquez', 19.7411000, -71.4464000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40722, 'Villa Tapia', 'Villa Tapia', 'Villa Tapia', 19.3008400, -70.4219900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40723, 'Villarpando', 'Villarpando', 'Villarpando', 18.6586000, -71.0391600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40724, 'Villa Riva', 'Villa Riva', 'Riva,Rivas,Villa Riva,Villa Rivas', 19.1806900, -69.9131900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40725, 'Villa Jaragua', 'Villa Jaragua', 'Jaragua,Jose Trujillo Valdez,José Trujillo Valdéz,Villa Jaragua,Villa Jose Trujillo Valdez,Villa José Trujillo Valdéz', 18.4907700, -71.4837700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40726, 'Villa Isabela', 'Villa Isabela', 'La Isabela,Villa Isabela', 19.8156400, -71.0605600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40727, 'Villa González', 'Villa Gonzalez', 'Las Lagunas,Villa Gonzalez,Villa González', 19.5405700, -70.7885300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40728, 'Villa Francisca', 'Villa Francisca', 'Villa Francisca', 18.4827800, -69.8891400, 'DO', '2017-01-31', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40729, 'Villa Elisa', 'Villa Elisa', 'Villa Elisa', 19.6856000, -71.2700700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40730, 'Villa Consuelo', 'Villa Consuelo', 'Villa Consuelo', 18.4833300, -69.9000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40731, 'Villa Bisonó', 'Villa Bisono', 'Bisono,Bisonó,Jose E. Bisono,Jose Elias Bisono,José E. Bisonó,José Eliás Bisonó,Villa Bisono,Villa Bisonó', 19.5637800, -70.8758200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40732, 'Villa Altagracia', 'Villa Altagracia', 'Vil''ja-Al''tagrasija,Villa Altagracia,Вилья-Альтаграсия', 18.6729700, -70.1709500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40733, 'Vicente Noble', 'Vicente Noble', 'Vicente Noble,Villa de Vicente Noble', 18.3844300, -71.1800900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40734, 'Veragua Arriba', 'Veragua Arriba', 'Veragua,Veragua Arriba', 19.5833300, -70.3333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40735, 'Vallejuelo', 'Vallejuelo', 'Vallejuelo', 18.6535400, -71.3343100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40736, 'Tireo Arriba', 'Tireo Arriba', '', 18.9353700, -70.6885000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40737, 'Tenares', 'Tenares', 'Tenares,Villa Tenares,Villa de Tenares', 19.3743900, -70.3508700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40738, 'Tamboril', 'Tamboril', 'Pena,Peña,Tamboril', 19.4853800, -70.6110400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40739, 'Tamayo', 'Tamayo', 'Tamayo', 18.3947000, -71.2029000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40740, 'Tábara Arriba', 'Tabara Arriba', 'Tabara Arriba,Tábara Arriba,Villa Tabara Arriba,Villa Tábara Arriba', 18.5699900, -70.8797800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40741, 'San Víctor Arriba', 'San Victor Arriba', 'San Victor,San Victor Arriba,San Víctor Arriba', 19.4774100, -70.5358500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40742, 'Santo Domingo', 'Santo Domingo', 'Ciudad Trujillo,SDQ,Saint Domingue,Santo Domingo,Santo Domingo City,Santo Domingo de Guzman,Santo Domingo de Guzmán,Santo Ntomin''nko,Santo-Domingo,santodoming-go,Σάντο Ντομίνγκο,Санто-Доминго,산토도밍고', 18.5001200, -69.9885700, 'DO', '2017-06-22', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40743, 'Santiago de los Caballeros', 'Santiago de los Caballeros', 'STI,Sant''jago-de-los-Kabal''eros,Sant''jago-de-los-Trejnta-Kabal''eros,Santiago,Santiago de los Caballeros,Santiago de los Kampagieros,Santjago de los Kabaljerosas,santiagodeloseukabayeloseu,sheng de ya ge,Σαντιάγο δε λος Καμπαγιέρος,Сантьяго-де-лос-Кабальерос,Сантьяго-де-лос-Трейнта-Кабальерос,Сантьяго-де-лос-Трейнта-Кабальєрос,סנטיאגו דה לוס קביירוס,سانتیاغو دے لوس کابائیروس,サンティアゴ・デ・ロス・カバリェロス,聖地牙哥,산티아고데로스카바예로스', 19.4517000, -70.6970300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40744, 'Santa Cruz de El Seibo', 'Santa Cruz de El Seibo', 'El Seibo,Santa Cruz de El Seibo,Santa Cruz del Seibo,Santa Cruz del Seybo,Seibo,Seybo', 18.7655900, -69.0388600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40745, 'Santa Cruz de Barahona', 'Santa Cruz de Barahona', 'BRX,Barahona,Santa Cruz de Barahona,Santa-Krus-de-Baraona,Санта-Крус-де-Бараона', 18.2085400, -71.1007700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40746, 'Samaná', 'Samana', 'Samana,Samaná,Santa Barbara de Samana,Santa Bárbara de Samaná,Самана', 19.2056100, -69.3368500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40747, 'San Rafael del Yuma', 'San Rafael del Yuma', 'San Rafael de Yuma,San Rafael del Yuma,Yuma', 18.4299300, -68.6739000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40748, 'San Pedro de Macorís', 'San Pedro de Macoris', 'San Pedro Macoris,San Pedro de Macoris,San Pedro de Macorís', 18.4615600, -69.2971800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40749, 'San Juan de la Maguana', 'San Juan de la Maguana', 'SJM,San Juan,San Juan de la Maguana', 18.8058800, -71.2299100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40750, 'San José de Ocoa', 'San Jose de Ocoa', 'San Jose de Ocoa,San José de Ocoa', 18.5466100, -70.5063100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40751, 'San José de Las Matas', 'San Jose de Las Matas', 'San Jose de Las Matas,San Jose de los Matas,San José de Las Matas,San José de los Matas', 19.3391500, -70.9381900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40752, 'San Gregorio de Nigua', 'San Gregorio de Nigua', 'San Gregorio de Nigua', 18.3833300, -70.0833300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40753, 'San Francisco de Macorís', 'San Francisco de Macoris', 'San Francisco de Macoris,San Francisco de Macorís', 19.3009900, -70.2525900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40754, 'San Fernando de Monte Cristi', 'San Fernando de Monte Cristi', 'Monte Cristi,Monte Cristy,Monte-Christi,San Fernando de Monte Cristi', 19.8482600, -71.6459700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40755, 'Puerto Plata', 'Puerto Plata', 'POP,Port Plata,Puerto Plata,San Antonio de Guerra,San Felipe de Puerto Plata,San-Felipe-de-Puehrto-Plata,San-Felipe-de-Puerto-Plata,Vilojati Puehrto Plata,pueleutopeullata,pwrtw plata,sheng fei li-yin gang,Вилояти Пуэрто Плата,Сан-Фелипе-де-Пуэрто-Плата,Сан-Феліпе-де-Пуерто-Плата,פוארטו פלטה,پورتو پلاتا,プエルト・プラタ,聖斐利-銀港,푸에르토플라타', 19.7934400, -70.6884000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40756, 'Sánchez', 'Sanchez', 'Sanchez,Sánchez', 19.2281000, -69.6137000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40757, 'San Carlos', 'San Carlos', 'San Carlos', 18.4833300, -69.9000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40758, 'Salvaleón de Higüey', 'Salvaleon de Higueey', 'Higueey,Higuey,Higüey,Salvaleon de Higueey,Salvaleón de Higüey', 18.6150100, -68.7079800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40759, 'Salsipuedes', 'Salsipuedes', '', 19.4055200, -70.3798500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40760, 'Salcedo', 'Salcedo', 'Salcedo', 19.3776200, -70.4176200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40761, 'Sabaneta', 'Sabaneta', 'Sabaneta,San Ignacio de Sabaneta,Santiago Rodriguez,Santiago Rodríguez', 19.4779300, -71.3412500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40762, 'Sabana Yegua', 'Sabana Yegua', 'Sabana Yegua,Sabaneta Yegua', 18.7166700, -71.0166700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40763, 'Sabana Iglesia', 'Sabana Iglesia', 'Sabana Iglesia', 19.3211400, -70.7599200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40764, 'Sabana Grande de Palenque', 'Sabana Grande de Palenque', 'Sabana Grande,Sabana Grande Palenque,Sabana Grande de Palenque,Villa de Sabana Grande de Palenque', 18.2625600, -70.1482100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40765, 'Sabana Grande de Boyá', 'Sabana Grande de Boya', 'Sabana Grande,Sabana Grande Boya,Sabana Grande Boyá,Sabana Grande de Boya,Sabana Grande de Boyá,Villa de Sabana Grande de Boya,Villa de Sabana Grande de Boyá', 18.9449800, -69.7933100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40766, 'Sabana del Puerto', 'Sabana del Puerto', 'Sabana del Puerto', 19.0666700, -70.4166700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40767, 'Sabana de La Mar', 'Sabana de La Mar', 'SNX,Sabana de La Mar,Sabana la Mar,Savana la Mar', 19.0593400, -69.3884300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40768, 'Sabana Buey', 'Sabana Buey', 'Sabana Buey', 18.2735100, -70.5235200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40769, 'Río Verde Arriba', 'Rio Verde Arriba', 'Rio Verde Arriba,Río Verde Arriba', 19.3158300, -70.5664300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40770, 'Río San Juan', 'Rio San Juan', 'Laguna Grigri,Rio San Juan,Río San Juan', 19.6438500, -70.0763500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40771, 'Río Limpio', 'Rio Limpio', 'Colonia Rio Limpio,Colonia Río Limpio,Rio Limpio,Río Limpio', 19.2451300, -71.5307700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40772, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', 19.6666700, -70.7666700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40773, 'Rincón', 'Rincon', '', 19.1193800, -70.4063200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40774, 'Restauración', 'Restauracion', 'Restauracion,Restauración', 19.3153200, -71.6923900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40775, 'Ramón Santana', 'Ramon Santana', 'Ramon Santana,Ramón Santana', 18.5422400, -69.1797900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40776, 'Quisqueya', 'Quisqueya', 'Ingenio Quisquella,Quisqueya', 18.5554200, -69.4081400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40777, 'Punta Cana', 'Punta Cana', 'PUJ,Punta Cana,Punta Kana,Punta-Kana,Пунта Кана,Пунта-Кана', 18.5818200, -68.4043100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40778, 'Pueblo Viejo', 'Pueblo Viejo', 'Pueblo Viejo', 18.4000000, -70.7676500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40779, 'Postrer Río', 'Postrer Rio', 'Postrer Rio,Postrer Rios,Postrer Río,Postrer Ríos', 18.5437400, -71.6356100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40780, 'Polo', 'Polo', 'Polo', 18.0787300, -71.2872300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40781, 'Pizarrete', 'Pizarrete', 'Pizarrete', 18.2993500, -70.2264800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40782, 'Pimentel', 'Pimentel', 'Pimental,Pimentel', 19.1841600, -70.1088400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40783, 'Piedra Blanca', 'Piedra Blanca', 'Piedra Blanca', 18.8443100, -70.3168800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40784, 'Pescadería', 'Pescaderia', 'Pescaderia,Pescadería', 18.2676600, -71.1661200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40785, 'Peralta', 'Peralta', 'Peralta,Pinar de Peralta', 18.5816400, -70.7702900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40786, 'Pepillo Salcedo', 'Pepillo Salcedo', 'Manzanillo,Pepillo Salcedo,Puerto Alto', 19.6984100, -71.7451300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40787, 'Pedro Santana', 'Pedro Santana', 'Pedro Santana', 19.1051500, -71.6949800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40788, 'Pedro Sánchez', 'Pedro Sanchez', 'Pedro Sanches,Pedro Sanchez,Pedro Sánchez', 18.8637500, -69.1086800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40789, 'Pedro García', 'Pedro Garcia', 'Padre Garcia,Padre García,Pedro Garcia,Pedro García', 19.5920200, -70.6525600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40790, 'Pedro Corto', 'Pedro Corto', 'Pedro Corto', 18.8485600, -71.4104100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40791, 'Pedernales', 'Pedernales', 'Anse a Pitre,Anse à Pitre,Pedernales,Puerto de Pedernales', 18.0383800, -71.7440300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40792, 'Paya', 'Paya', '', 18.2619600, -70.2956000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40793, 'Partido', 'Partido', 'Partido', 19.4840300, -71.5473000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40794, 'Paraíso', 'Paraiso', '', 17.9917200, -71.1652600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40795, 'Palmar de Ocoa', 'Palmar de Ocoa', 'Palmar de Ocoa', 18.2965600, -70.5863500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40796, 'Palmar Arriba', 'Palmar Arriba', 'Palmar Arriba', 19.5395700, -70.7382600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40797, 'Padre Las Casas', 'Padre Las Casas', 'Padre Las Casas,Padre de las Casas,Villa de Padre Las Casas', 18.7317200, -70.9391700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40798, 'Oviedo', 'Oviedo', 'Oviedo,Trujin', 17.8013600, -71.4010000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40799, 'Otra Banda', 'Otra Banda', 'Otra Banda', 18.6501700, -68.6628100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40800, 'Nizao', 'Nizao', 'Hizao,Nizao,Villa de Nizao', 18.2469700, -70.2105300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40801, 'Neiba', 'Neiba', 'Neiba,Neyba', 18.4813700, -71.4196500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40802, 'Nagua', 'Nagua', 'Ciudad de Nagua,Julia Molina,Nagua,Villa Julia Molina,callejon a,Нагуа', 19.3832000, -69.8474000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40803, 'Monte Plata', 'Monte Plata', 'Monte Plata,San Antonio de Monte Plata,Монте Плата', 18.8070000, -69.7839900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40804, 'Monción', 'Moncion', 'Benito Moncion,Benito Monción,Moncion,Monción,Villa de Moncion,Villa de Monción', 19.4108300, -71.1525700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40805, 'Moca', 'Moca', 'Moca', 19.3935200, -70.5259800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40806, 'Miches', 'Miches', 'El Jovero,Jovero,Miches', 18.9836400, -69.0476000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40807, 'Mella', 'Mella', 'Los Yesos,Mella', 18.3587100, -71.4171600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40808, 'Matayaya', 'Matayaya', 'Matayaya', 18.8903600, -71.5945900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40809, 'Matanzas', 'Matanzas', 'Matanza,Matanzas', 18.2429700, -70.4176800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40810, 'Mao', 'Mao', 'Mao,Santa Cruz de Mao,Valverde,Мао', 19.5518600, -71.0781300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40811, 'Majagual', 'Majagual', 'Majagual', 19.0413400, -69.8361600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40812, 'Maizal', 'Maizal', 'Maizal', 19.6365500, -71.0273400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40813, 'Luperón', 'Luperon', 'Blanco,Luperon,Luperón,Puerto de Luperon', 19.8913100, -70.9620400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40814, 'Los Ríos', 'Los Rios', 'Los Rios,Los Ríos', 18.5213100, -71.5910600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40815, 'Los Llanos', 'Los Llanos', 'Los Llanos,San Jose de Los Llanos,San José de Los Llanos', 18.6203500, -69.4958100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40816, 'Los Hidalgos', 'Los Hidalgos', 'Los Hidalagos,Los Hidalgos', 19.7333300, -71.0333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40817, 'Los Botados', 'Los Botados', 'El Centro,Los Botados', 18.7322600, -69.9953600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40818, 'Loma de Cabrera', 'Loma de Cabrera', 'Loma de Cabrera,Villa de Loma de Cabrera', 19.4333300, -71.6000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40819, 'Licey al Medio', 'Licey al Medio', '', 19.4333300, -70.6000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40820, 'La Uvilla', 'La Uvilla', 'La Uvilla,Ubilla,Uvilla', 18.3618600, -71.2104600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40821, 'Las Terrenas', 'Las Terrenas', 'La Terenas,Las Terenas,Las Terrenas,Las Terreras,Laterriena,Terrenas', 19.3110200, -69.5428000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40822, 'Las Salinas', 'Las Salinas', 'La Salina,Las Salinas', 18.2748500, -71.3159600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40823, 'Las Matas de Santa Cruz', 'Las Matas de Santa Cruz', 'La Mata de Santa Cruz,Las Matas de Santa Cruz,Matas de Santa Cruz', 19.6711900, -71.5047100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40824, 'Las Matas de Farfán', 'Las Matas de Farfan', 'Las Matas,Las Matas de Farfan,Las Matas de Farfán,Las-Matas-de-Farfan,Matas de Farfan,Лас-Матас-де-Фарфан', 18.8730900, -71.5165600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40825, 'Las Guáranas', 'Las Guaranas', 'Las Guaranas,Las Guáranas', 19.1931000, -70.2083500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40826, 'Las Charcas', 'Las Charcas', 'Las Charcas', 18.4502600, -70.6172400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40827, 'La Romana', 'La Romana', 'LRM,La Romana,La-Romana,Romana,lalomana,lh rwmnh,luo ma na,Ла-Романа,לה רומנה,لا رومانا، جمہوریہ ڈومینیکن,ラ・ロマーナ,羅馬納,라로마나', 18.4273300, -68.9728500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40828, 'La Julia', 'La Julia', 'La Julia', 18.4666700, -69.9333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40829, 'Laguna Salada', 'Laguna Salada', 'Laguna Salada,Villa de Laguna Salada', 19.6504300, -71.0842900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40830, 'La Entrada', 'La Entrada', '', 19.5536700, -69.9076200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40831, 'La Descubierta', 'La Descubierta', 'Descubierta,La Descubierta', 18.5705300, -71.7296700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40832, 'La Ciénaga', 'La Cienaga', 'La Cienaga,La Cienega,La Ciénaga,La Ciénega', 18.0685800, -71.1065100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40833, 'La Caya', 'La Caya', 'La Caya', 19.6998100, -71.1208400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40834, 'La Canela', 'La Canela', 'Canela,La Canela', 19.4734100, -70.8162900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40835, 'La Agustina', 'La Agustina', 'La Agustina', 18.5000000, -69.9333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40836, 'Juncalito Abajo', 'Juncalito Abajo', 'Juncalito,Juncalito Abajo', 19.2199000, -70.8190500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40837, 'Juan Santiago', 'Juan Santiago', 'Juan Santiago', 18.7034200, -71.5897100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40838, 'Juan López Abajo', 'Juan Lopez Abajo', '', 19.4333300, -70.5000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40839, 'Juan de Herrera', 'Juan de Herrera', 'Juan de Herrera', 18.8740200, -71.2383000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40840, 'Juancho', 'Juancho', 'Juana,Juancho', 17.8578200, -71.2931100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40841, 'Juan Adrián', 'Juan Adrian', 'Juan Adrian,Juan Adrián,Juan Aldian,Juan Aldián', 18.7636500, -70.3373200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40842, 'Joba Arriba', 'Joba Arriba', 'Joba Arriba,Jobo Arriba', 19.5666700, -70.2666700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40843, 'Jimaní', 'Jimani', 'Jimani,Jimaní,San Jose de Jimani,San José de Jimaní', 18.4916900, -71.8502200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40844, 'Jima Abajo', 'Jima Abajo', 'Jima,Jima Abajo', 19.1329200, -70.3760700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40845, 'Jicomé', 'Jicome', 'Jicome,Jicomé', 19.6495500, -70.9492700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40846, 'Jarabacoa', 'Jarabacoa', 'Jarabacoa,Kharabakoa,Харабакоа', 19.1168300, -70.6359500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40847, 'Jaquimeyes', 'Jaquimeyes', 'Jaquimelles,Jaquimeyes,Las Jaquimelles,Los Jaquimelles,Los Jaquimeyes', 18.3117300, -71.1614500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40848, 'Jamao al Norte', 'Jamao al Norte', 'Jamao,Jamao Norte,Jamao al Morte,Jamao al Norte', 19.6355200, -70.4466400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40849, 'Jaibón', 'Jaibon', 'Jaibar,Jaibon,Jaibón', 19.6116900, -71.1484700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40850, 'Imbert', 'Imbert', 'Bajabonico,Imbert', 19.7537100, -70.8290600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40851, 'Hostos', 'Hostos', 'Hostos,Villa de Hostos', 19.1804300, -70.0204600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40852, 'Hondo Valle', 'Hondo Valle', 'Hondo Valle', 18.7159900, -71.6951100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40853, 'Hato Mayor del Rey', 'Hato Mayor del Rey', 'Hato Mayor,Hato Mayor del Rey', 18.7627800, -69.2568100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40854, 'Hatillo Palma', 'Hatillo Palma', 'Hatillo Palma', 19.6625600, -71.1940600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40855, 'Guerra', 'Guerra', 'Guerra,San Antonio de Guerra', 18.5589200, -69.7010300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40856, 'Guaymate', 'Guaymate', 'Guaimate,Guaymate', 18.5879300, -68.9786700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40857, 'Guayabo Dulce', 'Guayabo Dulce', 'Guajabo Dulce,Guayabo Dulce', 18.6500000, -69.2833300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40858, 'Guayabal', 'Guayabal', 'Guayabal', 18.5981000, -71.6418400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40859, 'Guatapanal', 'Guatapanal', 'Guatapanal', 19.5070500, -70.9171300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40860, 'Guananico', 'Guananico', 'Guananico', 19.7269300, -70.9229400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40861, 'Gonzalo', 'Gonzalo', 'Batey Gonzalo,Gonzalo', 18.9514700, -69.7511400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40862, 'Gaspar Hernández', 'Gaspar Hernandez', 'Gaspar Hernandez,Gaspar Hernández,Jaspar Hernandez', 19.6274800, -70.2777200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40863, 'Galván', 'Galvan', 'Galvah,Galvan,Galváh,Galván', 18.5022800, -71.3427100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40864, 'Fundación', 'Fundacion', 'Fundacion,Fundación', 18.2866800, -71.1814700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40865, 'Fantino', 'Fantino', 'Fantino,Villa de Fantino', 19.1214800, -70.2997200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40866, 'Estero Hondo', 'Estero Hondo', 'Estero Hondo', 19.8271200, -71.1741100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40867, 'Estebanía', 'Estebania', 'Estebania,Estebanía', 18.4577000, -70.6435000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40868, 'Esperanza', 'Esperanza', 'Esperanza', 19.5846900, -70.9848900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40869, 'Esperalvillo', 'Esperalvillo', 'El Centro,El Esperalvillo,Esperalvilla,Esperalvillo,Peraldillo,Peralvillo', 18.8150900, -70.0355700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40870, 'Ensanche Luperón', 'Ensanche Luperon', 'Ensanche Luperon,Ensanche Luperón', 18.5000000, -69.9000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40871, 'Enriquillo', 'Enriquillo', 'Enriquilla,Enriquillo,Petit Trou', 17.9000000, -71.2333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40872, 'El Valle', 'El Valle', 'El Valle,Villa Trujillo', 18.9756700, -69.3782700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40873, 'El Puerto', 'El Puerto', '', 18.7833300, -69.4666700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40874, 'El Pino', 'El Pino', 'El Pino', 19.4353700, -71.4754000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40875, 'El Peñón', 'El Penon', 'El Penon,El Peñón,Penon,Peñón', 18.2964300, -71.1841000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40876, 'El Palmar', 'El Palmar', 'El Palmar,Palmar', 18.4113900, -71.2455800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40877, 'El Llano', 'El Llano', 'El Llano', 18.8166700, -71.6333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40878, 'El Guayabal', 'El Guayabal', 'El Guayabal,Guayabal', 18.7496000, -70.8369000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40879, 'El Factor', 'El Factor', 'El Factor', 19.3183400, -69.8882700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40880, 'El Carril', 'El Carril', 'El Carril,El Corral', 18.4490500, -70.0278500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40881, 'El Cacao', 'El Cacao', 'El Cacao,Los Cacaos', 18.5271900, -70.2958500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40882, 'Duvergé', 'Duverge', 'Duverge,Duvergé,Las Damas', 18.3783900, -71.5246900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40883, 'Don Juan', 'Don Juan', 'Don Juan', 18.8277400, -69.9462900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40884, 'Dajabón', 'Dajabon', 'Dajabon,Dajabón', 19.5487800, -71.7082900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40885, 'Cristo Rey', 'Cristo Rey', 'Cristo Rey', 18.5000000, -69.9333300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40886, 'Cristóbal', 'Cristobal', 'Cristobal,Cristóbal,San Cristobal,San Cristóbal', 18.2940500, -71.2929800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40887, 'Cotuí', 'Cotui', 'Cotui,Cotuy,Cotuí', 19.0527200, -70.1493900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40888, 'Constanza', 'Constanza', 'Constanza,Costanza,Konstancija,Villa de Constanza,Констанция', 18.9091900, -70.7449900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40889, 'Concepción de La Vega', 'Concepcion de La Vega', 'Concepcion de La Vega,Concepcion de la Vega,Concepción de La Vega,Concepción de la Vega,Konsep''sion de La Vega,Konseps''jon-de-la-Vega,Konsepsion-de-la-Vega,La Vega,la wei jia,la wygha,labega,qwnspsywn dh lh wgh,Κονσεπσιόν δε Λα Βέγα,Консепсион-де-ла-Вега,Консепсьйон-де-ла-Вега,קונספסיון דה לה וגה,لا ویغا,コンセプシオン・デ・ラ・ベガ,拉維加,라베가', 19.2220700, -70.5295600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40890, 'Comendador', 'Comendador', 'Comendado,Comendador,Elias Pena,Elias Peña,Elias Pina,Elías Piña', 18.8775000, -71.7027800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40891, 'Ciudad Nueva', 'Ciudad Nueva', 'Ciudad Nueva', 18.4670700, -69.8933900, 'DO', '2017-01-31', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40892, 'Cevicos', 'Cevicos', 'Cevicos,Villa de Cevicos', 19.0044900, -69.9789600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40893, 'Cercado Abajo', 'Cercado Abajo', 'Cercado Abajo,El Cercado Abajo,El Sercado', 18.7268100, -71.5174200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40894, 'Cayetano Germosén', 'Cayetano Germosen', 'Cayetano Bermosen,Cayetano Germosen,Cayetano Germosén,Gayetano Germosen,Villa de Cayetano Germosen,Villa de Cayetano Germosén', 19.3441300, -70.4834200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40895, 'Castillo', 'Castillo', 'Cachanes,Castillo,Villa de Castillo', 19.2082400, -70.0272600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40896, 'Castañuelas', 'Castanuelas', 'Castanuela,Castanuelas,Castañuela,Castañuelas', 19.7138700, -71.4987600, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40897, 'Canoa', 'Canoa', 'Canoa,La Canoa', 18.3549900, -71.1585100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40898, 'Cana Chapetón', 'Cana Chapeton', 'Cana Chapeton,Cana Chapetón', 19.6070300, -71.2573400, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40899, 'Cambita Garabitos', 'Cambita Garabitos', 'Cambita,Cambita Garabitas,Cambita Garabito,Cambita Garabitos', 18.4545800, -70.1990700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40900, 'Cachón', 'Cachon', 'Cachon,Cachón,El Cachon,El Cachón', 18.2483300, -71.1891200, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40901, 'Cabrera', 'Cabrera', 'Cabrar,Cabrera', 19.6426000, -69.9048900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40902, 'Cabral', 'Cabral', 'Cabral,Rincon,Rincon Nuevo', 18.2500000, -71.2166700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40903, 'Cabarete', 'Cabarete', 'Cabarete,Kabarete,Кабарете', 19.7498200, -70.4082900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40904, 'Bonao', 'Bonao', 'Banao,Bonao,Monsenor Nouel,Monseñor Nouel,Бонао', 18.9368700, -70.4092300, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40905, 'Bohechío', 'Bohechio', 'Boechio,Boechío,Bohechio,Bohechío', 18.7751500, -70.9888900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40906, 'Boca de Yuma', 'Boca de Yuma', 'Boca de Yuma,Boca del Yuma,Yuma', 18.3782500, -68.6090000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40907, 'Boca Chica', 'Boca Chica', 'Boca Chica,Boka Chika,Бока Чика', 18.4500000, -69.6000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40908, 'San Cristóbal', 'San Cristobal', 'Benemerita de San Cristobal,Benemérita de San Cristóbal,San Cristobal,San Cristóbal', 18.4166700, -70.1000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40909, 'Bella Vista', 'Bella Vista', 'Bella Vista', 18.4553900, -69.9454000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40910, 'Bayaguana', 'Bayaguana', 'Bayaguana,San Juan Bautista de Bayaguana,San Juan de Bayaguana', 18.7503100, -69.6352500, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40911, 'Bánica', 'Banica', 'Banica,Bánica', 19.0823900, -71.7054000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40912, 'Baní', 'Bani', 'Ban,Bani,Banti,Bany,Baní,Бан', 18.2796400, -70.3318500, 'DO', '2016-06-08', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40913, 'Bajos de Haina', 'Bajos de Haina', 'Bajos de Haina,Bajos de Jaina', 18.4153800, -70.0331700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40914, 'Baitoa', 'Baitoa', 'Baitoa', 19.3251200, -70.7035700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40915, 'Azua', 'Azua', 'Asua-de-Kompostela,Azua,Azua de Compostela,Compostela de Azua,Асуа-де-Компостела', 18.4531900, -70.7349000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40916, 'Arroyo Salado', 'Arroyo Salado', 'Arroyo Salado,Paso del Rio,Paso del Río', 19.5000000, -69.9000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40917, 'Arenoso', 'Arenoso', 'Arenoso,Majagual', 19.1873200, -69.8591700, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40918, 'Amina', 'Amina', '', 19.5481300, -70.9959900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40919, 'Altamira', 'Altamira', 'Altamira', 19.6773000, -70.8442800, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40920, 'Agua Santa del Yuna', 'Agua Santa del Yuna', 'Agua Santa del Yuna,Trujillo del Yuna', 19.1507200, -69.8006900, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40921, 'Santo Domingo Oeste', 'Santo Domingo Oeste', '', 18.5000000, -70.0000000, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40922, 'Santo Domingo Este', 'Santo Domingo Este', 'Santo Domingo Este', 18.4884700, -69.8570700, 'DO', '2016-10-14', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(40923, 'Villa La Mata', 'Villa La Mata', '', 19.0166700, -70.2666100, 'DO', '2016-06-05', 64);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41013, 'Mehdia', 'Mehdia', 'Burdeau,Mahdia,Makhdija,Mehdia,Махдия', 35.4305800, 1.7571400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41014, 'Megarine', 'Megarine', 'Megarine,Meggarine', 33.1919500, 6.0869500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41015, 'Meftah', 'Meftah', 'Meftah,Meftakh,Rivet,Мефтах', 36.6204000, 3.2224800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41016, 'Médéa', 'Medea', 'Al-Madijja,Lambdia,Lemdiyyet,Medea,Medeah,Medeja,Medėja,Médéa,almdyh  aljzayr,almdyt,mai di ya,medea,Медеа,Медея,المدية,المدیه، الجزایر,مدیہ,麦迪亚,메데아', 36.2641700, 2.7539300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41017, 'Mazouna', 'Mazouna', 'Mazouna', 36.1223200, 0.8986500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41018, 'Mascara', 'Mascara', 'MUW,Mascara,Maskara,Mu''askar,Muaskar,Mu’askar,maseukala,maskara,masukara,mu a si kai er,mʿskr‎,Маскара,معسكر,معسكر‎,معسکر، الجزائر,মাস্কারা,マスカラ,穆阿斯凯尔,마스카라', 35.3966400, 0.1402700, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41019, 'Mansourah', 'Mansourah', 'Mansoura,Mansourah,Mansur,Мансур', 36.0872500, 4.4519200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41020, 'Mansoûra', 'Mansoura', 'Mansoura,Mansourah,Mansoûra,Mansura,Мансура', 34.8615800, -1.3393500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41021, 'Makouda', 'Makouda', 'Macouda,Makouda', 36.7856700, 4.0627300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41022, 'L’Arbaa Naït Irathen', 'L''Arbaa Nait Irathen', 'Fort National,L''Arbaa Irathen Nait,L''Arbaa Nait Irathen,Larbaa Nath Iraten,L’Arbaa Irathen Naït,L’Arbaa Naït Irathen', 36.6311200, 4.1986400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41023, 'Larbaâ', 'Larbaa', 'Arba,El-Arba,L''Arba,Larba,Larbaa,Larbaâ,L’Arba,ZZL,Ларба', 36.5647100, 3.1543400, 'DZ', '2013-10-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41024, 'Lakhdaria', 'Lakhdaria', 'Lakhdaria,Palestro', 36.5646300, 3.5933000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41025, 'Laghouat', 'Laghouat', 'Al-Aghwat,LOO,Laghouat,Laguat,Laguatas,Larhouat,aghwat,ai ge wa te,alaghwat,alaghwat  aljzayr,Лагуат,לאגוואט,اغواط,الأغواط,الاغواط، الجزایر,艾格瓦特', 33.8000000, 2.8651400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41026, 'Ksar el Boukhari', 'Ksar el Boukhari', 'Boghari,Borhari,Ksar el Boukhari', 35.8888900, 2.7490500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41027, 'Ksar Chellala', 'Ksar Chellala', 'Chellala,Chellala-Reibell,Ksar Chellala,Reibel,Reibell,Reïbell,Shelala', 35.2122200, 2.3188900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41028, 'Kolea', 'Kolea', 'Kolea', 36.6388800, 2.7684500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41029, 'Khenchela', 'Khenchela', 'Khenchela,Krenchela,QKJ,khnshlt,خنشلة', 35.4358300, 7.1433300, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41030, 'Khemis Miliana', 'Khemis Miliana', 'Affreville,El Khemis,El Khemis Miliana,Khemis Miliana,ZZK', 36.2610400, 2.2201500, 'DZ', '2012-07-24', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41031, 'Khemis el Khechna', 'Khemis el Khechna', 'Fondouk,Khemis El Khechma,Khemis el Khechna,Le Fondouk', 36.6499700, 3.3308000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41032, 'Kerkera', 'Kerkera', 'El Achra,Kerkera', 36.9291700, 6.5855600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41033, 'Jijel', 'Jijel', 'Djedjelli,Djidjelli,Dzhidzhel'',Dzidzelis,Dzidzili,Dżidżili,Džidželis,GJL,Giger,Gíger,Igilgili,Jijelli,ji jie lei,jijeru,jyjl,jyjl  aljzayr,Джиджель,جيجل,جیجل,جیجل، الجزایر,ジジェル,吉杰勒', 36.8205500, 5.7667100, 'DZ', '2016-09-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41034, 'Djidiouia', 'Djidiouia', 'Djidioua,Djidiouia,Djidjiouia,Jdiouia,Saint-Aime,Saint-Aimé', 35.9298900, 0.8287100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41035, 'Isser', 'Isser', 'Isser,Isserville', 36.7185900, 3.6692400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41036, 'I-n-Salah', 'I-n-Salah', 'Ain Salah,Aïn Salah,I-n-Salah', 27.1935100, 2.4606900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41037, 'Illizi', 'Illizi', 'Fort Polignac,Fort de Polignac,Illizi,Polignac,VVZ', 26.4833300, 8.4666700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41038, 'Ighram', 'Ighram', 'Ighram,Irhram', 36.4629500, 4.5053200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41039, 'Hennaya', 'Hennaya', 'Eugene Etienne,Eugene-Etienne Hennaya,Eugène Étienne,Eugéne-Étienne Hennaya,Hennaya', 34.9513900, -1.3680600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41040, 'Héliopolis', 'Heliopolis', 'Heliopolis,Héliopolis', 36.5036100, 7.4427800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41041, 'Hassi Messaoud', 'Hassi Messaoud', 'HME,Hassi Messaoud,Khasi Mesaud,Khassi-Messaud,ha xi mai sa wu de,hasimesaudeu,Хаси Месауд,Хасси-Мессауд,حاسي مسعود,哈西迈萨乌德,하시메사우드', 31.6804100, 6.0728600, 'DZ', '2010-10-07', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41042, 'Hammamet', 'Hammamet', 'Gidjel,Hammamet,Khammamet,Youks-les-Bains,Youks-les-Banins,Хаммамет', 35.4486200, 7.9518400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41043, 'Hammam Bou Hadjar', 'Hammam Bou Hadjar', 'Hammam Bou Hadjar,Hamman Bou Habjar,Hommam Bou Hadjar', 35.3788900, -0.9677800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41044, 'Hamma Bouziane', 'Hamma Bouziane', 'Hamma,Hamma Bouniane,Hamma Bouziane,Hamma-Plaisance,Le Hamma,Le Hamma-Plaisance', 36.4120500, 6.5960300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41045, 'Hadjout', 'Hadjout', 'Hadjout,Marengo', 36.5125700, 2.4138200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41046, 'Guelma', 'Guelma', 'Calama,Galma,Gel''ma,Gelma,Guelma,Kalima,QGE,gai lei ma,qalmh  aljzayr,qalmt,Гельма,قالمة,قالمه، الجزایر,قالمہ,盖勒马', 36.4621400, 7.4260800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41047, 'Ghardaïa', 'Ghardaia', 'GHA,Gardaja,Gardaya,Ghardaia,Ghardaja,Ghardaïa,Ghardája,Jimbo ya Ghardaia,Jimbo ya Ghardaïa,Rhardaia,Rhardaïa,Tagerdayt,Taγerdayt,gai er da ye,galeudaia,garudaia,ghrdayh,ghrdayt,wlayt ghrdayt,Гардая,Гардая қаласы,غرداية,غردایه,ولاية غرداية,ガルダイア,盖尔达耶,가르다이아', 32.4909400, 3.6734700, 'DZ', '2017-06-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41048, 'Frenda', 'Frenda', 'Frenda', 35.0654400, 1.0494500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41049, 'Freha', 'Freha', 'Freda,Freha', 36.7523400, 4.3155000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41050, 'Feraoun', 'Feraoun', 'Feraoun', 36.5604100, 4.8545400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41051, 'Es Senia', 'Es Senia', 'Es Senia,La Senia,La Sénia', 35.6477900, -0.6239700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41052, 'El Tarf', 'El Tarf', 'El Tarf,Le Tarf,altarf,الطارف', 36.7672000, 8.3137700, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41053, 'El Oued', 'El Oued', 'Al-Wadi,ELU,Ehl''-Uehd,El Oued,El Qued,Oued Souf,Uedas,alwady,wa de,wady,wady swf,Эль-Уэд,Эль-Уэд қаласы,אל-ואד,الوادي,اﻟﻮادى,وادي سوف,وادی,瓦德', 33.3560800, 6.8631900, 'DZ', '2013-11-21', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41054, 'El Malah', 'El Malah', 'El Malah,El Melah,Rio Salado,Zfissaf', 35.3913700, -1.0923800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41055, 'El Kseur', 'El Kseur', 'El Kseur,El-Kseur,Leqser,Leqṣer,alqsr,القصر', 36.6794200, 4.8555000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41056, 'El Khroub', 'El Khroub', 'El Khroub,El-Kroub,Kroubs,Le Khroub,Le Kroub', 36.2633300, 6.6936100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41057, 'El Kala', 'El Kala', 'Ehl''-Kaly,El Kala,La Calle,Port de la Calle,QLK,alqalt,Эль-Калы,القالة', 36.8955600, 8.4433300, 'DZ', '2016-09-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41058, 'El Idrissia', 'El Idrissia', 'El Idrissia,Zenina', 34.4454200, 2.5274900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41059, 'El Hadjira', 'El Hadjira', 'El Hadjira', 32.6133600, 5.5125900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41060, 'El Hadjar', 'El Hadjar', 'Duzerville,El Hadjar,QEH', 36.8037700, 7.7368400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41061, 'El Eulma', 'El Eulma', 'El Eulma,Saint-Arnaud,ZAE', 36.1528100, 5.6901600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41062, 'El Bayadh', 'El Bayadh', 'EBH,El Bayadh,El-Bayadh,Geryville,Géryville,Prowincja El Bayadh,Wilaya de El Bayadh,alblydh,wlayt albyd,البلیده,ولاية البيض', 33.6831800, 1.0192700, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41063, 'El Attaf', 'El Attaf', 'Ehl''-Attafom,El Attaf,Les Attafs,Les Attats,Les Attefs,Эль-Аттафом', 36.2239300, 1.6718700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41064, 'Chlef', 'Chlef', 'CFK,Castellum Tingitanum,Chlef,Ech Cheliff,Ech Chlef,El Asnam,Orleansville,Orléansville,Selifas,Shlef,Szalif,alshlf,shlf,shurefu,xie li fu,Šelifas,Шлеф,الشلف,شلف,シュレフ,谢利夫', 36.1652500, 1.3345200, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41065, 'El Aouinet', 'El Aouinet', 'Aouinet-ed-Dieb,Aouinet-el-Dieb,Aouïnet-ed-Dieb,Clairefontaine,Clairfontaine,El Aouinet', 35.8669100, 7.8867300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41066, 'El Amria', 'El Amria', 'El Amiria,El Amria,Lourmel,Lurmel', 35.5243900, -1.0157700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41067, 'El Affroun', 'El Affroun', 'El Affroun,El Afroun,El Alfroun', 36.4701000, 2.6252800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41068, 'El Achir', 'El Achir', 'El Achir', 36.0638600, 4.6274400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41069, 'El Abiodh Sidi Cheikh', 'El Abiodh Sidi Cheikh', 'El Abiod Sidi Cheikh,El Abiod Sidi Cheiki,El Abiod Sidi Cheikr,El Abiod Sidi Cheïkr,El Abiodh,El Abiodh Sidi Cheikh,El Abrod Sidi Cheikr,El-Abiod-Sidi-Cheik,Sidi Cheikh', 32.8930000, 0.5483900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41070, 'El Abadia', 'El Abadia', 'Al Abadia,Carnot,El Abadia', 36.2695100, 1.6860900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41071, 'Ech Chettia', 'Ech Chettia', 'Ech Chetia,Ech Chettia,Ech Chettiâ,Ech Chétia', 36.1959100, 1.2553700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41072, 'Drean', 'Drean', 'Drean,Mondovi', 36.6848200, 7.7511100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41073, 'Draa el Mizan', 'Draa el Mizan', 'Dra el Mizan,Dra el Mizane,Dra-ehl''-Mizan,Draa el Mizan,ZZD,Дра-эль-Мизан', 36.5362800, 3.8334000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41074, 'Draa Ben Khedda', 'Draa Ben Khedda', 'Dra Ben Khedda,Draa Ben Kheda,Draa Ben Khedda,Draa Ben Kredda,Mirabeau', 36.7343600, 3.9622300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41075, 'Douera', 'Douera', 'Ddwira,Douera,Douéra,bldyt dwyrt,بلدية دويرة,دویرہ', 36.6700000, 2.9444400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41076, 'Djelfa', 'Djelfa', 'Djelfa,Dzilfa,Dżilfa,Jelfa,QDJ,jlfh,wlayt aljlft,جلفه,ولاية الجلفة', 34.6727900, 3.2630000, 'DZ', '2015-11-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41077, 'Djamaa', 'Djamaa', 'Djama,Djamaa,Djemaa,Djemâa,جامعة', 33.5338800, 5.9930600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41078, 'Didouche Mourad', 'Didouche Mourad', 'Bizot,Didouche Mourad', 36.4525000, 6.6363900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41079, 'Dellys', 'Dellys', 'Delis,Dellys,dls,دلّس', 36.9171600, 3.9131100, 'DZ', '2016-09-17', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41080, 'Debila', 'Debila', 'Debila', 33.5166700, 6.9500000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41081, 'Dar el Beïda', 'Dar el Beida', 'Dar El Baida,Dar el Beida,Dar el Beïda,Dar-ehl''-Bejda,La Maison Blanche,Maison Blanche,Дар-эль-Бейда', 36.7133300, 3.2125000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41082, 'Dar Chioukh', 'Dar Chioukh', 'Dar Chioukh,Diar el Chioukh', 34.8963800, 3.4854300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41083, 'Constantine', 'Constantine', 'CZL,Cirta,Constantine', 36.3650000, 6.6147200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41084, 'Chorfa', 'Chorfa', 'Cheurfa,Chorfa,Чорфа', 36.3650500, 4.3263600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41085, 'Chiffa', 'Chiffa', 'Chiffa,La Chiffa', 36.4629300, 2.7387300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41086, 'Chetouane', 'Chetouane', 'Chetouane,Negrier,Négrier', 34.9212900, -1.2951200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41087, 'Cheria', 'Cheria', 'Cheria', 35.2730600, 7.7519400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41088, 'Cheraga', 'Cheraga', 'Cheraga,Cheragas', 36.7677500, 2.9592400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41089, 'Chemini', 'Chemini', 'Azerou Ait Chemini,Azerou Aït Chemini,Azrou-n-Ait Chemini,Azrou-n-Aït Chemini,Chemini', 36.6000000, 4.6166700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41090, 'Chelghoum el Aïd', 'Chelghoum el Aid', 'Chateaudun,Chateaudun de Rhumel,Chateaudun-du Rummel,Chateaudun-du-Rhumel,Chateaudun-du-Rhummel,Chelghoum el Aid,Chelghoum el Aïd,Châteaudun,Châteaudun de Rhumel,Châteaudun-du Rummel,Châteaudun-du-Rhumel,Châteaudun-du-Rhummel,Ghelghoum Elaid,Ghelghoum Elaïd,Ghelgoum Elaid,Ghelgoum Elaïd', 36.1628600, 6.1665100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41091, 'Chebli', 'Chebli', 'Chebli', 36.5772200, 3.0091700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41092, 'Charef', 'Charef', 'Charef,Charet', 34.6209800, 2.7950300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41093, 'Chabet el Ameur', 'Chabet el Ameur', 'Chabet -el -Ameuro,Chabet el Ameur', 36.6370900, 3.6947400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41094, 'Brezina', 'Brezina', 'Brexina,Brezina', 33.0989200, 1.2608200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41095, 'Bou Tlelis', 'Bou Tlelis', '', 35.5727200, -0.8996000, 'DZ', '2006-01-27', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41096, 'Boumagueur', 'Boumagueur', 'Boumagueur,bwmqr,بومقر', 35.5052000, 5.5525000, 'DZ', '2017-04-22', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41097, 'Boumahra Ahmed', 'Boumahra Ahmed', 'Boumahra Ahmed,Petit', 36.4583300, 7.5138900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41098, 'Boukadir', 'Boukadir', 'Bou Kadir,Boukadir,Bu-Kadir,Charon,Charron,Oued Ben Kader,ZAB,bwqadyr,Бу-Кадир,بوقادير', 36.0662900, 1.1260200, 'DZ', '2013-10-27', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41099, 'Bou Ismaïl', 'Bou Ismail', 'Bou Ismael,Bou Ismail,Bou Ismaël,Bou Ismaïl,Bu-Ismail,Castiglione,Бу-Исмаил', 36.6426200, 2.6900700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41100, 'Bouïra', 'Bouira', 'Bouira,Bouïra,QBZ', 36.3748900, 3.9020000, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41101, 'Bouinan', 'Bouinan', 'Bouinan,Bouinane,Bouïnane', 36.5316700, 2.9919400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41102, 'Bou Hanifia el Hamamat', 'Bou Hanifia el Hamamat', 'Bou Hanifia,Bou Hanifia el Hamamat,Bou Hanifia el Hammamet,Bou Hanifia-les Thermes,Sidi Bou Hanifia', 35.3147300, -0.0503700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41103, 'Bougara', 'Bougara', 'Bougara,Bouguera,Bouguerra,Rovigo', 36.5417800, 3.0810000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41104, 'Bougaa', 'Bougaa', 'Bougaa,Lafayette', 36.3329300, 5.0884300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41105, 'Boufarik', 'Boufarik', 'Boufarik,QFD', 36.5741300, 2.9121400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41106, 'Boudouaou', 'Boudouaou', 'Alma,Boudouaou,L''Alma,L’Alma', 36.7273500, 3.4099500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41107, 'Boudjima', 'Boudjima', 'Boudjima', 36.8021800, 4.1518700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41108, 'Boû Arfa', 'Bou Arfa', '', 36.4629800, 2.8146400, 'DZ', '2011-03-07', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41109, 'Bordj Zemoura', 'Bordj Zemoura', 'Bordj Zemoura,Zemmoura,Zemmours,Zemoura,Zemours', 36.2746200, 4.8566800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41110, 'Bordj Ghdir', 'Bordj Ghdir', 'Bordj Ghdir,Bordj R''dir,Bordj Redir,Bordj Rhedir,Bordj Rédir,Bordj R’dir', 35.9011100, 4.8980600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41111, 'Bordj el Kiffan', 'Bordj el Kiffan', 'Bordj El Kifan,Bordj el Kiffan,Fort de l''Eau,Fort de l’Eau', 36.7487100, 3.1924900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41112, 'Bordj Bou Arreridj', 'Bordj Bou Arreridj', 'Bordj Bou Arerridj,Bordj Bou Arreridj,Bordj-Bou-Arreridj,Borj Bu Arrerij,Burdz Bu Urajridz,Burdż Bu Urajridż,QBJ,brj bwʿryryj,برج بوعريريج', 36.0732100, 4.7610800, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41113, 'Boghni', 'Boghni', 'Boghari,Boghni,Borhni', 36.5422200, 3.9530600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41114, 'Blida', 'Blida', 'Al-Bulajda,Bilda,Blida,Buleyde,Dilida,El Bouleida,Gorad Blida,QLD,alblydh,alblydt,b li da,beullida,bo li da,burida,Блида,Бліда,Горад Бліда,البليدة,البلیده,بلیدہ,บลีดา,ブリダ,卜利达,블리다', 36.4700400, 2.8277000, 'DZ', '2013-08-03', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41115, 'Biskra', 'Biskra', 'BSK,Biskira,Biskra,Briskra,Tibeskert,bi si ke la,bisakra,biseukeula,bisukura,bskrh,bskrt,wlayt bskrt,Бискра,Біскра,بسكرة,بسکره,بسکرہ,ولاية بسكرة,বিসক্রা,ビスクラ,比斯克拉,비스크라', 34.8503800, 5.7280500, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41116, 'Birkhadem', 'Birkhadem', 'Birkadem,Birkhadem', 36.7149900, 3.0500200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41117, 'Birine', 'Birine', 'Birin,Birine', 35.6350000, 3.2250000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41118, 'Bir el Djir', 'Bir el Djir', 'Arcole,Bir el Djir', 35.7200000, -0.5450000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41119, 'Bir el Ater', 'Bir el Ater', 'Bir el Ater', 34.7448800, 8.0602400, 'DZ', '2013-04-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41120, 'Besbes', 'Besbes', 'Besbes,Randon', 36.7022200, 7.8472200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41121, 'Berrouaghia', 'Berrouaghia', 'Berrouaghia,Berrouarhia', 36.1351600, 2.9108500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41122, 'Berriane', 'Berriane', 'Berrian,Berriane,ZBI', 32.8264800, 3.7668900, 'DZ', '2012-05-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41123, 'Berrahal', 'Berrahal', 'Ain Mokra,Aine Mokra,Aïn Mokra,Aïne Mokra,Berrahal', 36.8352800, 7.4533300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41124, 'Bensekrane', 'Bensekrane', 'Ben Sokrane,Bensekrane,Pont de l''Isser,Pont de l’Isser', 35.0746500, -1.2243100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41125, 'Ben Mehidi', 'Ben Mehidi', 'Ben Mehidi,Morris', 36.7696700, 7.9064100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41126, 'Beni Saf', 'Beni Saf', 'Beni Saf,Beni Sat,ⴱⵏⵉ ⵙⴰⴼ', 35.3009900, -1.3822600, 'DZ', '2016-09-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41127, 'Beni Mester', 'Beni Mester', 'Beni Mester', 34.8704500, -1.4231900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41128, 'Beni Mered', 'Beni Mered', 'Beni Mered', 36.5238900, 2.8613100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41129, 'Beni Douala', 'Beni Douala', 'Beni Douala,Beni Doula', 36.6195400, 4.0828200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41130, 'Beni Amrane', 'Beni Amrane', 'Ait Belaid,Ait Bélaid,At Ɛemran,Beni Amran,Beni Amrane,بني عمران', 36.6677400, 3.5911500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41131, 'Bejaïa', 'Bejaia', 'BJA,Bedzaja,Bejaia,Bejaïa,Bijaya,Bougie,Bugia,Bugía,Béjaïa,bjayt,Беџаја,بجاية', 36.7558700, 5.0843300, 'DZ', '2016-12-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41132, 'Béchar', 'Bechar', 'Basyar,Baszszar,Bechar,Besaras,Beshar,Beshare,Bexar,Bešaras,Béchar,CBH,Colomb-Bechar,Colomb-Béchar,Wilaya de Beshar,bei sha er,besharu,besyaleu,bshar,bshar  aljzayr,Бешар,Бешаре,بشار,بشار، الجزایر,ベシャール,贝沙尔,베샤르', 31.6166700, -2.2166700, 'DZ', '2017-06-05', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41133, 'Batna', 'Batna', 'BLJ,Batina,Batna,Batna City,Batnah,Gorad Batna,Tbatent,Wilaya de Batna,ba te na,bateuna,batnh  aljzayr,batnt,batona,wlayt batnt,Батна,Батна қаласы,Горад Батна,باتنة,باتنه، الجزایر,باتنہ,باتنہ، الجزائر,ولاية باتنة,バトナ,巴特纳,바트나', 35.5559700, 6.1741400, 'DZ', '2013-06-06', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41134, 'Barika', 'Barika', 'Barika,ZZB,Барика', 35.3890100, 5.3658400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41135, 'Barbacha', 'Barbacha', 'Barbacha,Souk et Tleta,Souk et Tléta', 36.5666700, 4.9666700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41136, 'Baraki', 'Baraki', 'Baraki', 36.6665500, 3.0960600, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41137, 'Bab Ezzouar', 'Bab Ezzouar', 'Bab Ezzouar,Le Retour de la Chasse', 36.7261500, 3.1829100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41138, 'Azzaba', 'Azzaba', 'Azzaba,Jemmapes', 36.7394400, 7.1052800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41139, 'Azazga', 'Azazga', 'Agagza,Agazza,Azazga,ZZA', 36.7447200, 4.3722200, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41140, 'Arris', 'Arris', '', 35.2588100, 6.3470600, 'DZ', '2006-01-27', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41141, 'Arhribs', 'Arhribs', 'Aghribs,Arhribs', 36.7936100, 4.3115800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41142, 'Arbatache', 'Arbatache', 'Arbatach,Arbatache,L''Arbatach,L''Arbetache,Larbatache,L’Arbatach,L’Arbetache,Marechal Foch,Maréchal Foch', 36.6377300, 3.3712700, 'DZ', '2016-07-25', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41143, 'Aoulef', 'Aoulef', 'Aoulef,Aoulef el Arab', 26.9666700, 1.0833300, 'DZ', '2013-05-18', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41144, 'Annaba', 'Annaba', 'AAE,Anaba,Annaba,Annaba - syaht,Annaba - سياحة,Annába,Bona,Bone,Bône,Hippo,Hippo Regius,Unknown,an na ba,an''naba,annaba,Анаба,Аннаба,Аннаба қаласы,Աննաբա,عنابة,عنابه,عنابہ,আন্নাবা,アンナバ,安纳巴,안나바', 36.9000000, 7.7666700, 'DZ', '2016-09-26', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41145, 'Ammi Moussa', 'Ammi Moussa', 'Ammi Moussa', 35.8678100, 1.1114300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41146, 'Amizour', 'Amizour', 'Amizour,Colmar,Oued Amizour', 36.6402200, 4.9013100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41147, 'Algiers', 'Algiers', 'ALG,Al Jazair,Al-jezair,Alcher,Alge,Algeirsborg,Alger,Algeri,Algero,Algier,Algiers,Algir,Alg·èr,Algê,Algír,Alje,Aljer,Aljir,Alse,Alxer,Alzer,Alzhir,Alzhir khot,Alzhir shaary,Alziir,Alzir,Alzira,Alzirs,Alzyras,Alĝero,Alžiir,Alžir,Alžyras,Alžír,Alžěr,Alžīra,Alžīrs,Argel,Argier,Argièr,Arhel,Arjel,Arxel,Caesair,Cathair na hAilgeire,Cathair na hAilgéire,Cezayir,Cäsair,Gorad Alzhyr,Icosium,Jazoir,Zzayer,a er ji er,ala-jaza''ira,alajiyarsa,alje,alji''ersa,aljiyars,aljiyarsa,aljyrz,aljzayr,aljzyrh,alzhiri,aruje,jەzayyr,yaljyr,Əlcəzair,ʼlgyr,Αλγέρι,Алжир,Алжир хот,Алжир шаары,Алҷазоир,Горад Алжыр,Ալժիր,אלגיר,אלזשירס,ئالجىر,الجزائر,الجزائر شہر,الجزيره,الجزیره,الجیرز,جەزائیر,ܓܙܐܐܪ,अल्जीएर्स,अल्जीयर्स,আলজিয়ার্স,ਅਲ-ਜਜ਼ਾਇਰ,அல்ஜியர்ஸ்,അൾജിയേഴ്സ്,แอลเจียร์,ཨཱལ་ཇི་ཡར་སི།,အယ်လဂျီးယားမြို့,ალჟირი,አልጀርስ,アルジェ,阿爾及爾,알제', 36.7322500, 3.0874600, 'DZ', '2017-05-23', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41148, 'Akbou', 'Akbou', 'Akbou,Aqbu,Metz,aqbw,أقبو', 36.4575000, 4.5349400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41149, 'Aïn Touta', 'Ain Touta', 'Ain Touta,Aïn Touta,Mac Mahon', 35.3767500, 5.9000100, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41150, 'Aïn Temouchent', 'Ain Temouchent', 'Aebura,Ain Temonchent,Ain Temoucheni,Ain Temouchent,Ain Temushent,Aine Temouchent,Albulae,Aïn Temouchent,Aïn Témoucheni,Aïne Temouchent', 35.2974900, -1.1403700, 'DZ', '2015-07-03', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41151, 'Aïn Taya', 'Ain Taya', 'Ain Taya,Aine Taya,Aïn Taya,Aïne Taya', 36.7933300, 3.2869400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41152, 'Aïn Smara', 'Ain Smara', 'Ain Smara,Aine Smara,Aïn Smara,Aïne Smara', 36.2674000, 6.5013500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41153, 'Aïn Sefra', 'Ain Sefra', 'Ain Sefra,Aine Sefra,Aïn Sefra,Aïne Sefra', 32.7500000, -0.5833300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41154, 'Aïn Oussera', 'Ain Oussera', 'Ain Oussera,Aïn Oussera,El Oussera,Paul Cazelles', 35.4513900, 2.9058300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41155, '’Aïn Merane', '''Ain Merane', '''Ain Merane,Aine Merane,Aïne Merane,Rabelais,دائرة عين مران,’Aïn Merane', 36.1627700, 0.9703700, 'DZ', '2012-10-17', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41156, 'Aïn Kercha', 'Ain Kercha', 'Ain Kercha,Ain Kercka,Aine Kercha,Aïn Kercha,Aïn Kercka,Aïne Kercha', 35.9247200, 6.6952800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41157, 'Aïn Fakroun', 'Ain Fakroun', 'Ain Fakroun,Aine Fakroun,Aïn Fakroun,Aïne Fakroun', 35.9710800, 6.8737400, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41158, '’Aïn el Turk', '''Ain el Turk', '''Ain el Turk,Ain-et-Turk,Aine et Turk,Ajn-ehl''-Terk,Aïn-et-Turk,Aïne et Turk,Айн-эль-Терк,’Aïn el Turk', 35.7438100, -0.7693000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41159, '’Aïn el Melh', '''Ain el Melh', '''Ain el Melh,Ain Melah,Ain Melh,Ain Mellah,Aine Melah,Ajn-ehl''-Mel''kh,Aïn Melah,Aïn Melh,Aïne Melah,Айн-эль-Мельх,’Aïn el Melh', 34.8414600, 4.1638300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41160, '’Aïn el Hammam', '''Ain el Hammam', '''Ain el Hammam,Ain El Hamman,Ain-el-Hamam,Aine el Hammam,Ajn-ehl''-Khammam,Aïn El Hamman,Aïn-el-Hamam,Aïne el Hammam,Michelet,Айн-эль-Хаммам,’Aïn el Hammam', 36.5647100, 4.3061900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41161, '‘Aïn el Hadjel', '`Ain el Hadjel', 'Ain el Hadjel,Aine el Hadjel,Aïne el Hadjel,Selamate,`Ain el Hadjel,‘Aïn el Hadjel', 35.6700300, 3.8815300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41162, '’Aïn el Hadjar', '''Ain el Hadjar', '''Ain el Hadjar,Aine el Hadjar,Aïne el Hadjar,’Aïn el Hadjar', 34.7584600, 0.1452800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41163, 'Aïn el Bya', 'Ain el Bya', '''Ain el Bia,Ain el Bya,Aïn el Bya,Damesme,’Aïn el Bia', 35.8038900, -0.3017800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41164, '’Aïn el Berd', '''Ain el Berd', '''Ain el Berd,Oued Imbert,’Aïn el Berd', 35.3639500, -0.5127900, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41165, '’Aïn el Bell', '''Ain el Bell', '''Ain el Bell,Ain el Ibel,Ajn-ehl''-Bella,Aïn el Ibel,Fontaine des Chameaux,Айн-эль-Белла,’Aïn el Bell', 34.3438100, 3.2247500, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41166, '’Aïn Deheb', '''Ain Deheb', '''Ain Deheb,El Ousseukh,El Ousseukhr,El Ousseukr,La Fontaine,’Aïn Deheb', 34.8421800, 1.5469700, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41167, 'Aïn Defla', 'Ain Defla', 'Ain Defla,Aïn Defla,Duperre,Duperré,ʿyn aldfly‎,عين الدفلى‎', 36.2640500, 1.9679000, 'DZ', '2013-08-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41168, '’Aïn Boucif', '''Ain Boucif', '''Ain Boucif,Aine Boucif,Aïne Boucif,Bordj Ain Boucif,Bordj Aïn Boucif,’Aïn Boucif', 35.8912300, 3.1585000, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41169, 'Aïn Bessem', 'Ain Bessem', 'Ain Bessem,Aïn Bessem', 36.2933300, 3.6731900, 'DZ', '2013-04-04', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41170, '’Aïn Benian', '''Ain Benian', '''Ain Benian,Ain Berrian,Bou Ismail,Castiglione,Cuyotville,Guyotville,Guyoville,’Aïn Benian', 36.8027700, 2.9218500, 'DZ', '2015-03-05', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41171, 'Aïn Beïda', 'Ain Beida', 'Ain Beida,Aine Beida,Aïn Beïda,Aïne Beïda,QBP', 35.7963900, 7.3927800, 'DZ', '2013-04-21', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41172, 'Aïn Arnat', 'Ain Arnat', 'Ain Arnat,Aine Arnat,Arnat,Aïn Arnat,Aïne Arnat,ʿyn arnat,عين أرنات', 36.1868300, 5.3134700, 'DZ', '2013-05-11', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41173, '’Aïn Abid', '''Ain Abid', '''Ain Abid,Aine Abid,Aïne Abid,’Aïn Abid', 36.2319400, 6.9433300, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41174, 'Aflou', 'Aflou', 'Aflou,Aflu', 34.1127900, 2.1022800, 'DZ', '2012-01-19', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41175, 'Adrar', 'Adrar', 'AZR,Adrar,Adraras,a de la er,adeulaleu,adrar,adrar  aljzayr,xa drar,Адрар,أدرار,ادرار، الجزائر,อาดราร์,阿德拉尔,아드라르', 27.8742900, -0.2938800, 'DZ', '2016-01-30', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41176, 'Abou el Hassan', 'Abou el Hassan', 'Abou el Hassan,Abou el Hassen,Beni Madoun,Bordj Abou el Hassen,Cavaignac,dayrt abw alhsn,دائرة أبو الحسن', 36.4165700, 1.1961600, 'DZ', '2012-10-17', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41177, 'BABOR - VILLE', 'BABOR - VILLE', '', 36.4899400, 5.5393000, 'DZ', '2008-12-12', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41178, 'Smala', 'Smala', '', 35.7165200, 0.7543700, 'DZ', '2009-12-30', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41179, 'Djebilet Rosfa', 'Djebilet Rosfa', '', 34.8637500, 0.8349600, 'DZ', '2011-05-21', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41180, 'Commune des Béni Bou Attab', 'Commune des Beni Bou Attab', '', 35.9950300, 1.6175100, 'DZ', '2014-08-13', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41181, 'Ait Yahia', 'Ait Yahia', '', 36.5890700, 4.3350500, 'DZ', '2014-11-25', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41182, 'Boumagueur', 'Boumagueur', 'Boumagueur,bwmqr,بومقر', 35.5052700, 5.5525000, 'DZ', '2017-04-22', 4);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41183, 'Zaruma', 'Zaruma', 'Zaruma', -3.6913200, -79.6117400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41184, 'Zamora', 'Zamora', 'Zamora', -4.0668500, -78.9548800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41185, 'Yantzaza', 'Yantzaza', 'Yantzaza', -3.8326100, -78.7607600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41186, 'Yaguachi Nuevo', 'Yaguachi Nuevo', 'Yaguachi,Yaguachi Nuevo', -2.0968000, -79.6948500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41187, 'Vinces', 'Vinces', 'Vinces,Vinsesas', -1.5561100, -79.7519100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41188, 'Ventanas', 'Ventanas', 'Ventanas', -1.4415800, -79.4594300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41189, 'Velasco Ibarra', 'Velasco Ibarra', 'El Empalme,Empalme,Velasco Ibarra', -1.0437600, -79.6383700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41190, 'Valdez', 'Valdez', 'Limones,Valdes,Valdez,Valdés', 1.2491700, -78.9830600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41191, 'Tulcán', 'Tulcan', 'Gorad Tul''kan,TUA,Tul''kan,Tulcan,Tulchan,Tulcán,Tulkan,Tulkanas,to~urukan,tu er kan,tulkan,twlkan,Горад Тулькан,Тулькан,تولکان,トゥルカン,圖爾坎,툴칸', 0.8118700, -77.7172700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41192, 'Tosagua', 'Tosagua', 'Tosagua', -0.7867900, -80.2347300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41193, 'Tena', 'Tena', 'Napo,San Juan de Tena,TNW,Tena,Tina,te na,tena,tyna,تینا,تینا، ایکواڈور,特納,테나', -0.9938000, -77.8128600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41194, 'Taisha', 'Taisha', 'TSC,Taisha', -2.3396500, -77.4603100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41195, 'Sucúa', 'Sucua', 'SUQ,Sucua,Sucúa', -2.4586600, -78.1717100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41196, 'Sucre', 'Sucre', 'Sucre', -1.2797400, -80.4188500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41197, 'Saquisilí', 'Saquisili', 'Saquisili,Saquisilí', -0.8399000, -78.6670000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41198, 'San Vicente', 'San Vicente', 'San Vicente', -0.5898600, -80.4080600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41199, 'Santo Domingo de los Colorados', 'Santo Domingo de los Colorados', 'Santo Domingo,Santo Domingo de los Colorados,Santo-Domingo-de-los-Kolorados,Санто-Доминго-де-лос-Колорадос', -0.2530500, -79.1753600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41200, 'Santa Rosa', 'Santa Rosa', 'ETR,Santa Rosa', -3.4488200, -79.9595200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41201, 'Santa Lucía', 'Santa Lucia', '', -2.1833300, -80.0000000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41202, 'Santa Elena', 'Santa Elena', 'Santa Elena,santa alna,santa aylyna,santa-ellena,sheng ai lun na,Санта Елена,سانتا إيلينا,سانتا النا,سانتا الینا، ایکواڈور,سانتا ایلینا,聖埃倫娜,산타엘레나', -2.2262200, -80.8587300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41203, 'Santa Clara', 'Santa Clara', '', -1.2639900, -77.8873900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41204, 'Santa Ana', 'Santa Ana', '', -1.2072600, -80.3713200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41205, 'San Miguel de Salcedo', 'San Miguel de Salcedo', 'Salcedo,San Miguel,San Miguel de Salcedo', -1.0454700, -78.5906300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41206, 'San Miguel', 'San Miguel', 'San Miguel,San Miguel de Chimbo', -1.7088400, -79.0431100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41207, 'San Lorenzo de Esmeraldas', 'San Lorenzo de Esmeraldas', 'Puerto San Lorenzo,San Lorenzo,San Lorenzo de Esmeraldas', 1.2862600, -78.8351400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41208, 'Sangolquí', 'Sangolqui', 'Sangolkis,Sangolqui,sang ge er ji,桑戈爾基', -0.3340500, -78.4521700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41209, 'San Gabriel', 'San Gabriel', 'Montufar,Montúfar,San Gabriel', 0.5931800, -77.8307800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41210, 'Samborondón', 'Samborondon', 'Samborondon,Samborondón,Samrondon,Samrondón,Zamborondon,Zamborondón', -1.9627600, -79.7240200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41211, 'Salinas', 'Salinas', 'SNC,Salinas,Salinasas,sa li na si,sallinaseu,Салинас,Салінас,薩利納斯,살리나스', -2.2145200, -80.9515100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41212, 'Rosa Zarate', 'Rosa Zarate', 'Quininde,Quinindé,Rosa Zarate', 0.3277900, -79.4740700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41213, 'Rocafuerte', 'Rocafuerte', 'Rocafuerte', -0.9236000, -80.4494600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41214, 'Riobamba', 'Riobamba', 'Riobamba,Rispampa,li ao ban ba,liobamba,ri xoba m ba,riobamba,rywbamba,rywbmbh,Риобамба,Ріобамба,ריובמבה,ريوبامبا,ریؤبامبا,ریوبامبا,รีโอบัมบา,რიობამბა,里奧班巴,리오밤바', -1.6709800, -78.6471200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41215, 'Quito', 'Quito', 'Gorad Kita,Kitas,Kito,Kitu,Kuito,Quito,Quitu,Quitum,San Francisco de Quito,UIO,ji duo,ki to,kito,kitto,kvirrea,kvito,kwytw,kytw,qytw,Κίτο,Горад Кіта,Кито,Кіто,Կիտո,קיטא,קיטו,كىتو,كيتو,کوئتو,کیتو,کیٹو,क्वितो,क्वीटो,ਕੀਤੋ,கித்தோ,ക്വിറ്റോ,กีโต,ཁེ་ཐོ།,კიტო,ኪቶ,キト,基多,키토', -0.2298500, -78.5249500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41216, 'Quevedo', 'Quevedo', 'Kevedas,Kevedo,Quevedo,ke wei duo,Кеведо,კევედო,克韋多', -1.0286300, -79.4635200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41217, 'Quero', 'Quero', '', -1.3812200, -78.6081200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41218, 'Puyo', 'Puyo', 'El Puyo,Gorad Pujo,Pujas,Pujo,Puyo,Puyu llaqta,pu yue,puyo,pwyw,Горад Пуё,Пуйо,پویو,پویو، ایکواڈور,普約,푸요', -1.4836900, -78.0025700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41219, 'Pujilí', 'Pujili', 'Pajili,Pujili,Pujilí', -0.9575900, -78.6963600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41220, 'Puerto Villamil', 'Puerto Villamil', 'Puerto Villamil,Villamil', -0.9554200, -90.9665400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41221, 'Puerto Francisco de Orellana', 'Puerto Francisco de Orellana', 'Coca,Francisco de Orellana,La Coca,OCC,Puerto Francisco de Orellana', -0.4664500, -76.9871900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41222, 'Puerto Bolívar', 'Puerto Bolivar', 'Ponto Bolivar,Puerto Bolivar,Puerto Bolívar,Пуерто Боливар', -3.2664900, -79.9974900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41223, 'Puerto Baquerizo Moreno', 'Puerto Baquerizo Moreno', 'Baquerizo Moreno,Puehrto-Bakeriso-Moreno,Puerto Bakeriso Morenas,Puerto Baquerizo,Puerto Baquerizo Moreno,Puerto Chico,Puerto-Bakeriso-Moreno,ba ke li suo mo lei nuo gang,bwyrtw bkwyryzw mwrynw,pueleutobakelisomoleno,pwrtw bakwryzw mwrynw,pwyrtw bakwyrysw mwrynw,pyurto baikverizo moreno,Пуерто-Бакерісо-Морено,Пуэрто-Бакерисо-Морено,פוארטו בקריסו מורנו,بويرتو بكويريزو مورينو,پورتو باکوریزو مورینو,پویرتو باکویریسو مورینو,प्यूर्टो बैक्वेरीज़ो मोरेनो,プエルト・バケリソ・モレノ,巴克里索莫雷諾港,푸에르토바케리소모레노', -0.9232200, -89.6047400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41224, 'Puerto Ayora', 'Puerto Ayora', 'Puerto Ayora', -0.7401800, -90.3138000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41225, 'Portoviejo', 'Portoviejo', 'Gorad Partauekha,PVO,Portov''ekho,Portoviejo,Portovjechas,bo tuo wei ye huo,poleutobieho,pwrtw wyyjw,pwrtwbykhw,Горад Партаўеха,Портовьехо,پورتو ویئجو,پورتوبیخو,პორტოვიეხო,波托維耶霍,포르토비에호', -1.0545800, -80.4544500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41226, 'Portovelo', 'Portovelo', 'Portobelo,Portovelo,Portoviejo', -3.7214500, -79.6218700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41227, 'Playas', 'Playas', 'General Villamil,Playas,Villamil', -2.6319900, -80.3880800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41228, 'Piñas', 'Pinas', 'Pinas,Piñas', -3.6810700, -79.6808300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41229, 'Pimampiro', 'Pimampiro', 'Pimampiro,Pimanpiro', 0.3911600, -77.9406800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41230, 'Píllaro', 'Pillaro', 'Pillaro,Píllaro', -1.1741400, -78.5467600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41231, 'Pelileo', 'Pelileo', 'Pelileo', -1.3299000, -78.5434100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41232, 'Pedro Carbo', 'Pedro Carbo', 'Pedro Carbo', -1.8156300, -80.2330900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41233, 'Pedernales', 'Pedernales', '', 0.0716700, -80.0525000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41234, 'Pasaje', 'Pasaje', 'Pasaje', -3.3256100, -79.8069700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41235, 'Palora', 'Palora', 'Metzera,Palora', -1.7013100, -77.9651600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41236, 'Palestina', 'Palestina', 'Hacienda Palestina,Palestina', -1.9370900, -79.7139600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41237, 'Palenque', 'Palenque', '', -1.4379500, -79.7564700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41238, 'Paján', 'Pajan', 'Pajan,Paján', -1.5523800, -80.4295800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41239, 'Otavalo', 'Otavalo', 'Otavalas,Otavalo,Otovalo,Utawalu,ao ta wa luo,awtabalw,Отавало,اوتابالو,奧塔瓦洛', 0.2345700, -78.2624800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41240, 'Nulti', 'Nulti', 'Nulti', -2.9166700, -78.8500000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41241, 'Naranjito', 'Naranjito', '', -2.1667100, -79.4654000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41242, 'Naranjal', 'Naranjal', '', -2.6736400, -79.6183000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41243, 'Muisne', 'Muisne', 'Muisne', 0.6112900, -80.0186300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41244, 'Montecristi', 'Montecristi', 'Montecristi', -1.0457600, -80.6588900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41245, 'Montalvo', 'Montalvo', '', -2.0493400, -77.0085600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41246, 'Montalvo', 'Montalvo', '', -1.7900800, -79.2875900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41247, 'Milagro', 'Milagro', 'Milagras,Milagro,San Francisco de Milagro,mi la ge luo,milagro,მილაგრო,米拉格羅', -2.1340400, -79.5941500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41248, 'Manta', 'Manta', 'Gorad Manta,MEC,Manta,Manta Ecuador,Puerto de Manta,man ta,manta,Горад Манта,Манта,მანტა,曼塔,만타', -0.9621200, -80.7127100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41249, 'Machala', 'Machala', 'Gorad Machala,MCH,Macala,Machala,Maĉala,Mačala,ma cha la,machala,machalla,machara,matshala,mchala,Горад Мачала,Мачала,מצאלה,ماتشالا,ماچالا,مچالا,მაჩალა,マチャラ,馬查拉,마찰라', -3.2586100, -79.9605300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41250, 'Machachi', 'Machachi', 'Ciudad de Machachi,Machache,Machachi', -0.5101100, -78.5671200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41251, 'Macas', 'Macas', 'Macas,XMS', -2.3086800, -78.1113500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41252, 'Macará', 'Macara', 'MRR,Macara,Macará', -4.3818100, -79.9437000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41253, 'Lomas de Sargentillo', 'Lomas de Sargentillo', 'Lomas de Sargentillo', -1.8833300, -80.0833300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41254, 'Loja', 'Loja', 'LOH,Locha,Loha,Loja,Lokha,loha,lokha,luo ha,lwja,Лоха,لوجا,لوخا، ایکواڈور,ლოხა,洛哈,로하', -3.9931300, -79.2042200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41255, 'Llacao', 'Llacao', 'Llacao', -2.8666700, -78.8833300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41256, 'La Unión', 'La Union', 'La Union,La Unión', -2.8500000, -78.7833300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41257, 'La Troncal', 'La Troncal', 'La Troncal', -2.4235500, -79.3397700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41258, 'Latacunga', 'Latacunga', 'Gorad Latakunga,LTX,Latacunga,Latakunga,Latakunka,la ta kun jia,latakung-ga,latakwnga,latakwnga  akwadwr,Горад Латакунга,Латакунга,لاتاکونگا,لاتاکونگا، اکوادور,拉塔昆加,라타쿵가', -0.9352100, -78.6155400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41259, 'La Maná', 'La Mana', 'La Mana,La Maná', -0.9409400, -79.2250600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41260, 'La Libertad', 'La Libertad', 'La Libertad', -2.2330000, -80.9103900, 'EC', '2013-01-11', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41261, 'Nueva Loja', 'Nueva Loja', 'Gorad Nuehva-Lokha,Lago Agrio,Musuq Loja,Nuehva-Lokha,Nueva Locha,Nueva Loja,Nueva-Lokha,nuebaloha,nwywa lwja,nwywa lwkha,xin luo ha,Горад Нуэва-Лоха,Нуева-Лоха,Нуэва-Лоха,نوئوا لوجا,نویوا لوخا,ヌエバ・ロハ,新洛哈,누에바로하', 0.0860000, -76.8952800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41262, 'Junín', 'Junin', '', -0.9277700, -80.2058300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41263, 'Jipijapa', 'Jipijapa', 'JIP,Jipijapa', -1.3487200, -80.5787500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41264, 'Ibarra', 'Ibarra', 'Ibarra,Ибарра', 0.3517100, -78.1223300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41265, 'Huaquillas', 'Huaquillas', 'Huaquillas', -3.4752300, -80.2308400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41266, 'Guayaquil', 'Guayaquil', 'GYE,Gorad Guajakil'',Gouagiakil,Guaiaquil,Guaiaquilum,Guajakil,Guajakil'',Guayaquil,Gvajakil,Gvajakila,Gvajakilis,Santiago de Guayaquil,Wayakil,ghwayakyl,gu''a''i''akila,gua ya ji er,guayakiru,gvayakila,gwayakil,gwayakl,gwayakwyl,gwayakywl,kwa yaki l,Γουαγιακίλ,Гвајакил,Горад Гуаякіль,Гуаякил,Гуаякиль,Ґуаякіль,גואיאקיל,غواياكيل,گوآیاکوئل,گوایاکل,گوایاکیول,ग्वायाकिल,ਗੁਆਇਆਕੀਲ,กวายากิล,გუაიაკილი,グアヤキル,瓜亞基爾,과야킬', -2.2058400, -79.9079500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41267, 'Guaranda', 'Guaranda', 'Gorad Guaranda,Guaranda,Waranta,gua lan da,gwalanda,gwaranda,Горад Гуаранда,Гуаранда,Ґуаранда,گواراندا,瓜蘭達,과란다', -1.5926300, -79.0009800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41268, 'Guano', 'Guano', '', -1.6078900, -78.6310500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41269, 'Gualaquiza', 'Gualaquiza', 'Gualaquiza,Gualiquiza,Santiago', -3.4035900, -78.5816600, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41270, 'Gualaceo', 'Gualaceo', 'Gualaceo', -2.8926400, -78.7781400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41271, 'Esmeraldas', 'Esmeraldas', 'ESM,Esmeraldas,Volcan Chimborazo,Volcán Chimborazo', 0.9592000, -79.6539700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41272, 'El Triunfo', 'El Triunfo', '', -1.9333300, -79.9666700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41273, 'Eloy Alfaro', 'Eloy Alfaro', 'Alfaro,Duran,Durán,Eloy Alfaro', -2.1757900, -79.8551900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41274, 'El Ángel', 'El Angel', 'El Angel,El Ángel,Espejo', 0.6227900, -77.9400300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41275, 'Cuenca', 'Cuenca', 'CUE,Cuenca,Gorad Kuehnka,Kuehnka,Kuehnka shaary,Kuehnkae,Kuenka,Santa Ana de los cuatro rios de Cuenca,Santa Ana de los cuatro ríos de Cuenca,Tumipampa,ke wng ka,kuengka,kuenka,kun ka,kwanka,kwynka,Горад Куэнка,Куенка,Куэнкæ,Куэнка,Куэнка шаары,Կուենկա,קואנקה,کوئنکا,کوئنکا، ایکواڈور,کوانکا,เกวงกา,კუენკა,クエンカ,昆卡,쿠엥카', -2.9005500, -79.0045300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41276, 'Cube', 'Cube', '', 0.5736400, -79.6441800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41277, 'Cotacachi', 'Cotacachi', 'Cotacachi', 0.3010700, -78.2642800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41278, 'Coronel Marcelino Maridueña', 'Coronel Marcelino Mariduena', 'Coronel Marcelino Mariduena,Coronel Marcelino Maridueña,Coronel Mariduena,Coronel Maridueña,Mariduena,Maridueña', -2.2092400, -79.4324800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41279, 'Colimes', 'Colimes', 'Colimes', -1.5455300, -80.0116500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41280, 'Chone', 'Chone', 'Chone,Chuni,Cone,Čonė', -0.6981900, -80.0936100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41281, 'Celica', 'Celica', '', -4.1026600, -79.9566500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41282, 'Cayambe', 'Cayambe', 'Cayambe,Kajambe,Каямбе', 0.0408400, -78.1452400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41283, 'Catarama', 'Catarama', 'Catarama,Urdaneta', -1.5750400, -79.4599800, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41284, 'Catamayo', 'Catamayo', 'Catamayo,La Toma', -3.9865200, -79.3591200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41285, 'Catacocha', 'Catacocha', 'Catacocha', -4.0497400, -79.6494400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41286, 'Cariamanga', 'Cariamanga', 'Calvas,Cariamanga', -4.3279600, -79.5555400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41287, 'Cañar', 'Canar', '', -2.5606200, -78.9394000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41288, 'Calceta', 'Calceta', 'Bolivar,Bolívar,Calceta', -0.8458200, -80.1638900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41289, 'Pampanal de Bolívar', 'Pampanal de Bolivar', 'Bolivar,Bolívar,Pampanal de Bolivar,Pampanal de Bolívar', 1.3525100, -78.8936000, 'EC', '2017-02-04', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41290, 'Boca Suno', 'Boca Suno', 'Boca Suno,Suno', -0.6983200, -77.1408300, 'EC', '2013-01-11', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41291, 'Baños', 'Banos', 'Banos,Baños', -1.3969900, -78.4228900, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41292, 'Balzar', 'Balzar', 'Balzar', -1.3650100, -79.9049400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41293, 'Baláo', 'Balao', 'Balao,Baláo', -2.9110000, -79.8144100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41294, 'Bahía de Caráquez', 'Bahia de Caraquez', 'BHA,Bahia,Bahia de Caraques,Bahia de Caraquez,Bahia de Caráques,Bahija de Karakesas,Bahía,Bahía de Caráquez,Caracas,Sucre,ka la ke si gang,卡拉克斯港', -0.5979200, -80.4236700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41295, 'Babahoyo', 'Babahoyo', 'Babahojas,Babahoya,Babahoyo,ba ba ao yue,babaoyo,babawyw,باباویو,باباہویو,巴巴奧約,바바오요', -1.8021700, -79.5344300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41296, 'Azogues', 'Azogues', 'Asogesas,Asuwi,Azogues,Azoguez,a suo ge si,asogeseu,aswgws,azwgwys,آسوگوس,ازوگوئس,阿索格斯,아소게스', -2.7396900, -78.8486000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41297, 'Atuntaqui', 'Atuntaqui', '', 0.3324700, -78.2137100, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41298, 'Archidona', 'Archidona', '', -0.9095000, -77.8077200, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41299, 'Ambato', 'Ambato', 'ATF,Ambata,Ambatas,Ambato,Ampatu llaqta,San Juan de Ambato,ambato,ambatw,ambatw  akwadwr,an ba tuo,anbato,Амбата,Амбато,Ամբատո,آمباتو، اکوادور,أمباتو,امباتو,امباتو، ایکواڈور,ამბატო,アンバート,安巴托,암바토', -1.2490800, -78.6167500, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41300, 'Alfredo Baquerizo Moreno', 'Alfredo Baquerizo Moreno', 'Alfredo Baquerizo Moreno,Jujan,Juján', -1.9166700, -79.5166700, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41301, 'Alausí', 'Alausi', 'Alausi,Alausí', -2.2032900, -78.8471400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41302, 'Gonzalo Pizarro', 'Gonzalo Pizarro', '', 0.0167400, -77.3792400, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41303, 'Wilfrido Loor Moreira', 'Wilfrido Loor Moreira', '', -0.3529400, -79.6603300, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41304, 'Tutamandahostel', 'Tutamandahostel', '', -0.1972700, -78.4975000, 'EC', '2017-02-07', 65);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41518, 'Ziftá', 'Zifta', 'Zifta,Ziftá,zfty,Зифта,زفتى', 30.7142000, 31.2442500, 'EG', '2012-02-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41519, 'Toukh', 'Toukh', 'Toukh,Tukh,Tukh al Malaq,Tukh el-Malaq,Tûkh,Tûkh el-Malaq,twkh,Ţūkh,Ţūkh al Malaq,Тух,طوخ', 30.3539400, 31.2007100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41520, 'Tanda', 'Tanda', 'Tanda,Tanta,Tantā,tnta,tnth,Ţanţā,Танта,טנטא,טנטה,طنطا,Ṭanṭa,Ṭanṭā', 30.7884700, 31.0019200, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41521, 'Ţāmiyah', 'Tamiyah', 'Tamiya,Tamiyah,Tumyah,Tāmīya,Ţāmiyah', 29.4763900, 30.9611900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41522, 'Ţalkhā', 'Talkha', 'Talha,Talkha,tlkha,Ţalkhā,طلخا,Ṭalkha,Ṭalkhā', 31.0539000, 31.3778700, 'EG', '2013-06-05', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41523, 'Talā', 'Tala', 'Tala,Tale,Talla,Talā,Тале', 30.6802500, 30.9429200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41524, 'Ţahţā', 'Tahta', 'Tahta,Takhta,Ţahţā,Тахта', 26.7693000, 31.5021400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41525, 'Sumusţā as Sulţānī', 'Sumusta as Sultani', 'Sumusta as Sultani,Sumusta el Sultani,Sumusţā as Sulţānī,Sumusṭa el Sulṭâni', 28.9166700, 30.8500000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41526, 'Sohag', 'Sohag', 'HMB,Sauhadz,Sauhadż,Sawhaj,Sawhāj,Sevhac,Sogag,Sohag,Sohagas,Sokhag,Souhag,Suhag,Suhaj,Suwhaj,sohageu,suhagi,suo ha jie,swhaj,Согаґ,Сохаг,سوهاج,სუჰაგი,索哈傑,소하그', 26.5569500, 31.6947800, 'EG', '2016-01-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41527, 'Siwa Oasis', 'Siwa Oasis', 'Isiwan,Oase Siwa,SEW,Sekhetam,Siuah,Siva,Siwa,Siwa Oasis,Siwah,Siwe,Sīwah,Wahat Siwah,Wāḥat Sīwah,waht sywt,Сива,واحة سيوة', 29.2032000, 25.5196500, 'EG', '2014-08-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41528, 'Sīdī Sālim', 'Sidi Salim', 'Sidi Salim,Sīdī Sālim,sydy salm,سيدي سالم', 31.2713300, 30.7861700, 'EG', '2015-07-03', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41305, 'Vändra', 'Vaendra', 'Alt-Fennern,Fennern,Staryy Fennern'',Staryy Fennern’,Vaendra,Vana Vendre,Vana-Vandra,Vana-Vendra,Vana-Vyandra,Vana-Vändra,Vandra,Vendra,Vjandra,Vyandra,Vändra,Vėndra,Вяндра', 58.6480600, 25.0361100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41306, 'Võsu', 'Vosu', 'Vezo,Vezu,Vosu,Vysu,Võsu,Wesso,Woso,Wöso', 59.5725000, 25.9752800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41307, 'Võru', 'Voru', 'Gorad Vyru,Verava,Veri,Verro,Veru,Viru,Voru,Voru vald,Vuru,Vyro osh,Vyru,Võru,Võru vald,Vıru,Werro,Woru,Wöru,beolu,viru,vu~oru,wo lu,wwrw,Виру,Въру,Выро ош,Выру,Горад Выру,Վիռու,וורו,وورو,ვირუ,ヴォル,沃魯,버루', 57.8338900, 27.0194400, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41308, 'Võnnu', 'Vonnu', 'Mys Vynnu,Vendau,Vennu,Vonnu,Vynnu,Võnnu,Wendau', 58.2783300, 27.0480600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41309, 'Tabivere', 'Tabivere', 'Tabbifer,Tabivere,Voldi,Woldi,Табивере', 58.5541800, 26.5840400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41310, 'Voka', 'Voka', 'Voka', 59.4077600, 27.5826300, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41311, 'Võhma', 'Vohma', 'Gorad Vykhma,Myasto Vykhma,Vechma,Vehma,Vekhma,Vihma,Vikhma,Vohma,Vukhma,Vykhma,Võhma,Vıhma,Wochma,Wohma,Wöchma,Wöhma,vihma,wo he ma,wwhma,Вихма,Въхма,Выхма,Горад Выхма,Վիհմա,ووهما,ვიჰმა,沃赫馬', 58.6283300, 25.5483300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41312, 'Viru-Nigula', 'Viru-Nigula', 'Maholm,Makhol''m,Makhol’m,Nigula,Viru-Nigula,Виру-Нигула', 59.4441700, 26.6875000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41313, 'Vinni', 'Vinni', 'Myza Vinni,Vinni,Vinni Asundus', 59.2958300, 26.4322200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41314, 'Viljandi', 'Viljandi', 'Felin,Fellin,Gorad Vil''jandzi,Vil''jandi,Vil''yandi,Vilande,Vilandi,Viljandi,Viljandis,Vilyandi,Vil’yandi,Vylande,Vylandė,Vīlande,Wiljandi,billyandi,fylyandy,viliandi,vu~iryandi,wei er yang di,wylyandy,Вильянди,Вилянди,Виљанди,Вільянді,Горад Вільяндзі,Վիլյանդի,ויליאנדי,فيلياندي,ویلیاندی,ვილიანდი,ヴィリャンディ,維爾揚迪,빌랸디', 58.3638900, 25.5900000, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41315, 'Viiratsi', 'Viiratsi', 'Myza Viratsi,Viiratsi', 58.3600000, 25.6372200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41316, 'Viimsi', 'Viimsi', 'Myza Viymsi,Viimsi', 59.5050200, 24.8480700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41317, 'Kivi-Vigala', 'Kivi-Vigala', 'Fickel,Kivi-Vigala,Shteyn-Fikkel'',Shteyn-Fikkel’,Vigala,Киви-Вигала', 58.7152800, 24.3769400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41318, 'Veriora', 'Veriora', 'Veriora', 58.0041700, 27.3519400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41319, 'Vasalemma', 'Vasalemma', 'Vasalemma,Vasalemma Aedlinn,Vazalemma,Wassalem,Вазалемма', 59.2441700, 24.2900000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41320, 'Vastseliina', 'Vastseliina', 'Neuhausen,Neygauzen,Vastseliina,Vastseliyna', 57.7297200, 27.2936100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41321, 'Vastse-Kuuste', 'Vastse-Kuuste', 'Vaste-Kuste,Vaste-Kuuste,Vastse-Kuste,Vastse-Kuuste,Васте-Куусте', 58.1677800, 26.9286100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41322, 'Varstu', 'Varstu', 'Varstu,Варсту', 57.6391700, 26.6597200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41323, 'Värska', 'Vaerska', 'Vaerska,Varska,Verhoulitsa,Verhulitsa,Verkhoust''ye,Verkhoust’ye,Verska,Vjarska,Värska,Werchoustinsk,Werchoustje,Вярска', 57.9580600, 27.6380600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41324, 'Varbla', 'Varbla', 'Kirka Varbla,Varbla', 58.4319400, 23.7611100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41325, 'Vara', 'Vara', 'Myza Vara,Vara', 58.5208300, 26.8816700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41326, 'Vana-Antsla', 'Vana-Antsla', 'Vana-Antsla', 57.8661100, 26.5322200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41327, 'Valjala', 'Valjala', 'Val''yala,Valjala,Val’yala', 58.4061100, 22.8011100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41328, 'Vallapalu', 'Vallapalu', 'Palu,Palupaalne,Palupelne,Palupäälne,Rannu,Vallapalu,Ранну', 58.2513900, 26.1830600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41329, 'Valga', 'Valga', 'Gorad Valga,Valga,Valga i Estland,Valga osh,Valk,Valka,Valqa,Walga,Walk,balga,valga,vu~aruga,wa er jia,walga  astwny,walga  astwnya,wlgh,Валга,Валга ош,Валка,Горад Валга,Վալգա,ולגה,والگا، استونی,والگا، استونیا,ვალგა,ヴァルガ,瓦爾加,발가', 57.7778100, 26.0473000, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41330, 'Väike-Maarja', 'Vaeike-Maarja', 'Klein-Marien,Klein-Sankt-Marien,Kleyn Mariyen,Sankt-Marien,Vaeike-Maarja,Vaike-Maaja,Vaike-Maarja,Vjajke-Maar''ja,Väike-Maaja,Väike-Maarja,Вяйке-Маарья', 59.1263900, 26.2500000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41331, 'Vaida', 'Vaida', 'Vaida,Vajda,Vayda,Вайда', 59.2854600, 24.9789700, 'EE', '2017-05-07', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41332, 'Vyatsa', 'Vyatsa', 'Vaatsa,Vyatsa,Väätsa', 58.8855600, 25.4463900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41333, 'Uulu', 'Uulu', 'Udiu,Ulu,Uulu,Уулу', 58.2836100, 24.5872200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41334, 'Uuemõisa', 'Uuemoisa', 'Myza Uemyyza,Uuemoisa,Uuemõisa', 58.9394400, 23.5894400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41335, 'Ulvi', 'Ulvi', 'Myza Uley,Ulvi,Ulvi Asundus,Улви', 59.3241700, 26.6361100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41336, 'Ülenurme', 'UElenurme', 'Ilenurme,Julenurme,TAY,UElenurme,Ülenurme,Юленурме', 58.3162000, 26.7251700, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41337, 'Türi', 'Tueri', 'Thurgel,Tiri,Tiuris,Tiūris,Tjuri,Tjuri osh,Tueri,Turgel,Turi,Tyuri,Türi,di li,twry  astwny,Тюри,Тюри ош,Тјури,Тӱри,Տյուռի,توری، استونی,ტიური,蒂里', 58.8086100, 25.4325000, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41338, 'Turba', 'Turba', 'Turba,Турба', 59.0830600, 24.2250000, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41339, 'Tudulinna', 'Tudulinna', 'Commune de Tudulinna,Comuna Tudulinna,Gmina Tudulinna,Tuddolin,Tudolin,Tudolinna,Tudulinna,Tudulinna Parish,Tudulinna kommune,Tudulinna vald,dhstan twdwlyna,Тудулинна,Тудулінна,Տուդուլիննա,دهستان تودولینا,ტუდულინის მუნიციპალიტეტი', 59.0372200, 27.0852800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41340, 'Tõstamaa', 'Tostamaa', 'Testama,Testamaa,Toastamaa,Tostama,Tostamaa,Tystama,Tõstama,Tõstamaa', 58.3325000, 23.9997200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41341, 'Tõrva', 'Torva', 'Gorad Tyrva,Helmut,Khel''met,Khel’met,Terva,Tirva,Torrwa,Torva,Torwa,Turva,Tyrva,Tõrva,Törrwa,Törwa,Tırvа,te er wa,twrwa,Горад Тырва,Тирва,Търва,Тырва,Տիռվա,توروا,ტირვა,特爾瓦', 58.0027800, 25.9350000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41342, 'Torma', 'Torma', 'Torma,Торма', 58.8127800, 26.7383300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41343, 'Tori', 'Tori', 'Commune de Tori,Comuna Tori,Gmina Tori,Torgel,Tori,Tori Parish,Tori kommune,Tori vald,Тори,Торі,Տոռի,ტორის მუნიციპალიტეტი', 58.4788900, 24.8241700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41344, 'Tootsi', 'Tootsi', 'Tootsi,Totsi,Тоотси', 58.5780600, 24.7925000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41345, 'Tooni', 'Tooni', 'Tooni', 58.3730600, 27.5233300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41346, 'Toila', 'Toila', 'Commune de Toila,Comuna Toila,Gmina Toila,Toila,Toila Parish,Toila kommune,Toila vald,Tojla,Toyla,dhstan twyla,Тойла,Տոիլա,دهستان تویلا,ტოილის მუნიციპალიტეტი', 59.4212700, 27.5080700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41347, 'Tilsi', 'Tilsi', 'Myza Til''zi,Myza Til’zi,Tilsi,Tilsi Asundus', 57.9750000, 27.0122200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41348, 'Tempa', 'Tempa', 'Tempa', 58.9329900, 22.9225800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41349, 'Tartu', 'Tartu', 'Derpt,Dorpat,TAY,Tarbatum,Tartto,Tartu,Terbata,Tērbata,Yur''yev,Yurev,taleutu,taruto~u,trtw,Тарту,טרטו,ტარტუ,タルトゥ,타르투', 58.3806200, 26.7250900, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41350, 'Tapa', 'Tapa', 'Tap,Tapa,Tapa i Estland,Tape,Taps,Tаpа,ta pa,tapa,Тапа,Тапе,Տապա,تاپا,ტაპა,塔帕,타파', 59.2605600, 25.9586100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41351, 'Tamsalu', 'Tamsalu', 'Tamsal,Tamsalu,Тамсалу', 59.1586100, 26.1152800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41352, 'Tamme', 'Tamme', 'Tamme,Тамме', 58.9283300, 24.6438900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41353, 'Tallinn', 'Tallinn', 'Castrum Danorum,Gorad Talin,Kallinn,Kolyvan,Lindanaes,Lindanäs,Raeaeveli,Reval,Revel,Revel'',Rääveli,TLL,Taillinn,Talin,Talinas,Talini,Talino,Talins,Tallidn,Tallin,Tallin osh,Tallina,Tallinn,Tallinna,Talín,Tàllin,ta lin,talin,talina,tallin,tallina,tallyn,talyn,tarin,thallin n,Ταλίν,Ταλιν,Ταλλίν,Горад Талін,Талин,Таллин,Таллин ош,Таллинн,Таллінн,Տալլին,טאלין,تاللىن,تالين,تالین,تاڵین,ٹالن,तालिन,ताल्लिन,তাল্লিন,ਤਾਲਿਨ,தாலின்,ടാലിൻ,ทาลลินน์,ཏཱལ་་ལིན།,ტალინი,ታሊን,タリン,塔林,탈린', 59.4369600, 24.7535300, 'EE', '2016-09-15', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41354, 'Taebla', 'Taebla', 'Myza Taebla,Taebla,Taebla Asundus', 58.9538900, 23.7522200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41355, 'Tabasalu', 'Tabasalu', 'Tabasalu,Tabasalyu', 59.4260700, 24.5533000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41356, 'Kõpu', 'Kopu', 'Gross Keppo,Gross-Koppo,Gross-Köppo,Keppo,Kopu,Kypu,Kõpu,Sur-Kypu,Sure-Kypu,Suur Kopu,Suur Kõpu,Suure Kopu,Suure Kõpu,Кыпу', 58.3269400, 25.3116700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41357, 'Suure-Jaani', 'Suure-Jaani', 'Gros Iogannis,Gross-Sankt-Johannis,Sur-Yani,Sure Janis,Sure-Jani,Suure-Jaani,Suure-Yaani,Suure-Yani,Suurе-Yaаni,Sūre Janis,Sūre-Jāni,su wu lei ya ni,suure-iaani,swrh-yany,Сууре-Яани,Սուուռե-Յաանի,سوره-یانی,სუურე-იაანი,蘇烏雷亞尼', 58.5361100, 25.4705600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41358, 'Surju', 'Surju', 'Sur''yu,Surju,Sur’yu', 58.2350000, 24.7175000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41359, 'Sonda', 'Sonda', 'Commune de Sonda,Comuna Sonda,Gmina Sonda,Sonda,Sonda Parish,Sonda kommune,Sonda vald,dhstan swnda,Сонда,Սոնդա,دهستان سوندا,სონდის მუნიციპალიტეტი', 59.3436100, 26.8363900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41360, 'Sõmerpalu', 'Somerpalu', 'Somerpalu,Somerpalu Asundus,Symerpalu,Sõmerpalu,Sõmerpalu Asundus', 57.8500000, 26.8252800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41361, 'Sindi', 'Sindi', 'Sindi,Sindis,Tsintengof,Zinten,Zintenhof,sindi,syndy,xin di,Синди,Сінді,Սինդի,سیندی,სინდი,辛迪', 58.4005600, 24.6675000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41362, 'Sillamäe', 'Sillamaee', 'Commune de Sillamaee,Commune de Sillamäe,Gorad Silamjaeh,Silamae,Silameje,Silamejė,Silamiaje,Silamiajė,Sillamae,Sillamaee,Sillamagi,Sillame,Sillamjae,Sillamyae,Sillamäe,Sillamē,Sillаmyae,Suvilad,shirramae,silamiae,sillamaee,sillamjae,sillamjaeh,sylamayh,xi la mai ai,Горад Сіламяэ,Силламяе,Силламяэ,Сиљамае,Сілламяе,Սիլլամյաե,سیلامائه,სილამიაე,シッラマエ,錫拉邁埃,실라매에', 59.3969700, 27.7633100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41363, 'Saverna', 'Saverna', 'Myza Saverna,Saverna,Saverna Asundus', 58.0688900, 26.7247200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41364, 'Sauga', 'Sauga', 'Myza Sauga,Sauga', 58.4272000, 24.4949600, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41365, 'Saue', 'Saue', 'Gorad Saueh,Miza Saue,Myza Saue,Saue,Saue i Estland,Saueh,Saueh osh,Sauė,saue,sayw,shao ai,Горад Саўэ,Миза Сауе,Сауе,Сауэ,Сауэ ош,Սաուե,سائو,საუე,紹埃', 59.3225800, 24.5496700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41366, 'Särevere', 'Saerevere', 'Myza Syarevere,Saerevere,Sarevere,Sarevere Asundus,Sjarevere,Särevere,Särevere Asundus,Сяревере', 58.7900000, 25.4280600, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41367, 'Sangaste', 'Sangaste', 'Myza Sangaste,Sagnitz,Sangaste,Sangaste Asundus,Theal,Zagnits'',Zagnits’,Сангасте', 57.9252800, 26.3150000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41368, 'Salme', 'Salme', 'Salme', 58.1613900, 22.2622200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41369, 'Saku', 'Saku', 'Commune de Saku,Comuna Saku,Gmina Saku,Paroki Saku,Saku,Saku Pairish,Saku Parish,Saku kommune,Saku vald,dhstan sakw,saku shi,Саку,Սակու,دهستان ساکو,საკუს მუნიციპალიტეტი,サク市', 59.3035400, 24.6638200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41370, 'Syare', 'Syare', 'Saare,Saarekula,Syare,Sääre,Sääreküla', 58.1483300, 24.0175000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41371, 'Rummu', 'Rummu', '', 59.5352800, 24.7997200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41372, 'Rõuge', 'Rouge', 'Rauge,Rouge,Ryuge,Rõuge,Рыуге', 57.7277800, 26.9097200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41373, 'Roosna-Alliku', 'Roosna-Alliku', 'Myza Rosna Alliku,Roosna-Alliku,Роосна-Аллику', 59.0272200, 25.7083300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41374, 'Rõngu', 'Rongu', 'Ringen,Rongu,Ryngu,Rõngu,Рынгу', 58.1452800, 26.2480600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41375, 'Riisipere', 'Riisipere', 'Riesenberg,Riisipere,Rijzipere,Risipere,Riyzipere,Rizipere,Rozenberg'',Rozenberg’,Рийзипере', 59.1141700, 24.3105600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41376, 'Riidaja', 'Riidaja', 'Myza Riydaya,Riidaja,Riidaja Asundus', 58.0966700, 25.8975000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41377, 'Rapla', 'Rapla', 'Gorad Rapla,Odenkam,Rapl,Rapla,Rapla-kyulya,Raplakula,Raplaküla,Rappel,la pu la,lapeulla,rpla,Горад Рапла,Рапла,Ռապլա,رپلا,რაპლა,拉普拉,라플라', 59.0072200, 24.7927800, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41378, 'Räpina', 'Raepina', 'Raepina,Rapin,Rapina,Rapino,Rjapina,Ryapina,Räpina,Ряпина', 58.0980600, 27.4636100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41379, 'Rakvere', 'Rakvere', 'Gorad Rakvereh,Rakvere,Rakvere osh,Rakvere_vald,Rakverė,Rakwere,Rаkvеrе,Vezenberg,Wesenberg,la ke wei lei,lakeubele,rakuvu~ere,rakwrh,Горад Ракверэ,Раквере,Раквере ош,Ռակվեռե,راکوره,راکویرہ,რაკვერე,ラクヴェレ,拉克韋雷,라크베레', 59.3463900, 26.3558300, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41380, 'Rakke', 'Rakke', 'Racke,Rake,Rakke,Ракке', 58.9816700, 26.2544400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41381, 'Raja', 'Raja', 'Raja,Raja Alevik,Raya,Рая', 58.8219400, 26.9430600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41382, 'Raasiku', 'Raasiku', 'Commune de Raasiku,Comuna Raasiku,Gmina Raasiku,Harju Jani,Harju Jãni,Harju-Jaani,Paroki Raasiku,Raasiku,Raasiku Pairish,Raasiku Parish,Raasiku kommun,Raasiku kommune,Raasiku vald,Raaziku,Rasik,Rasiku,Razik'',Razik’,Sankt-Johannis,dhstan rasykw,Раазику,Раазіку,Ռաասիկու,دهستان راسیکو,რააზიკუს მუნიციპალიტეტი', 59.3663900, 25.1830600, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41383, 'Puurmani', 'Puurmani', 'Myza Purmani,Puurmani,Puurmani Asundus,Пуурмани', 58.5783300, 26.2752800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41384, 'Püssi', 'Puessi', 'Gorad Pjusi,Neu-Isenhof,Pisi,Piusis,Pjujssi,Pjussi,Puessi,Pussi,Pyusi,Pyussi,Püssi,pi xi,pwsy  astwny,Горад Пюсі,Пюйсси,Пюсси,Պյուսի,پوسی، استونی,პიუსი,皮西', 59.3600000, 27.0497200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41385, 'Pürksi', 'Puerksi', 'Birkas,Purksi,Pyurksi,Pürksi', 59.0111100, 23.5275000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41386, 'Puka', 'Puka', 'Bockenhof,Bokkengof'',Bokkengof’,Puka,Пука', 58.0497200, 26.2263900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41387, 'Puhja', 'Puhja', 'Kawelecht,Puhja,Pukh"ja,Pukh''ya,Pukhiya,Pukh’ya,Пухъя', 58.3419400, 26.3147200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41388, 'Põlva', 'Polva', 'Gorad Pylva,Pel''ve,Pelva,Pel’ve,Pilva,Polva,Polva Alevik,Polwa,Polwe,Pulva,Pyl''va,Pylva,Pylva osh,Pyl’va,Põlva,Põlva Alevik,Pölwa,Pölwe,Pılvа,peolba,po er wa,pwlwa,pylbh,Горад Пылва,Пилва,Пълва,Пылва,Пылва ош,Պիլվա,פילבה,پولوا,პილვა,珀爾瓦,펄바', 58.0602800, 27.0694400, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41389, 'Põltsamaa', 'Poltsamaa', 'Gorad Pyltsamaa,Ober"-Palen",Oberpahlen,Ober”-Palen”,Peltsama,Peltsamā,Pilcama,Piltsamaa,Poltsamaa,Poltsamaa_vald,Pyltsama,Pyltsamaa,Põltsamaa,Põltsamaa_vald,Pıltsаmаа,po er cha ma,pwltsama,Горад Пылтсамаа,Пилтсамаа,Пилцама,Пылтсамаа,Պիլցամաա,پولتساما,პილტსამაა,珀爾察馬', 58.6525000, 25.9705600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41390, 'Pihtla', 'Pihtla', 'Myza Pikhtla,Pihtla,Pihtla Asundus', 58.3041700, 22.6991700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41391, 'Peetri', 'Peetri', 'Peetri,Peetri Kirikud,Petri,Sankt-Petri', 58.9500000, 25.8333300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41392, 'Pärnu-Jaagupi', 'Paernu-Jaagupi', 'Jaagupi,Jakobi,Paernu-Jaagupi,Parnu-Jaagupi,Parnu-Jakobi,Pjarnu-Jaagupi,Pyarnu-Yaagupi,Pyarnu-Yagupi,Pärnu-Jaagupi,Pärnu-Jakobi,Sankt-Jakobi,Sankt-Jakoby,Svyatogo Iakova,Yakobi,Пярну-Яагупи', 58.6105200, 24.5068900, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41393, 'Pärnu', 'Paernu', 'EPU,Paernu,Parnawa,Parnu,Pernau,Pernava,Pernavia,Pernov,Piarnu,Pjarnu,Pyaonu,Pyarnu,Pärnu,Pērnava,Пярну,პიარნუ', 58.3858800, 24.4971100, 'EE', '2017-01-30', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41394, 'Paldiski', 'Paldiski', 'Baltiiskii Port,Baltijas Ports,Baltischport,Baltiski,Baltiysk Port,Baltiyskiy Port,Paldiski,Paldiski osh,Paldiskis,Paltiski,Port Baltic,Port Baltique,Pаldiski,Ragervik,Rogervik,Rogowik,Rågervik,pa er di si ji,paldiseuki,paldysky,parutisuki,Палдиски,Палдиски ош,Палдіскі,Պալդիսկի,پالدیسکی,പാൾഡിസ്കി,პალდისკი,パルティスキ,帕爾迪斯基,팔디스키', 59.3566700, 24.0530600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41395, 'Palamuse', 'Palamuse', 'Bartholomai,Bartholomäi,Bartolomey,Palamuse,Palamuze,Sankt-Bartholomai,Sankt-Bartholomäi,Паламузе', 58.6850000, 26.5788900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41396, 'Pala', 'Pala', 'Myza Pala,Pala,Pala Asundus,Palla,Пала,Палла', 58.6666700, 27.0219400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41397, 'Pajusti', 'Pajusti', 'Pajusti,Payusti,Паюсти', 59.2744400, 26.4233300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41398, 'Paikuse', 'Paikuse', 'Paikuse', 58.3791700, 24.6344400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41399, 'Paide', 'Paide', 'Gorad Pajdeh,Paide,Paide_vald,Paidė,Pajde,Pajde osh,Payde,Pаydе,Veisenshtein,Veisenshteyn,Veysenshteyn,Weissenstein,baydh,pai de,paide,paydh,Горад Пайдэ,Паиде,Пайде,Пайде ош,Պաիդե,פאידה,بايده,پایده,پایدے,პაიდე,パイデ,派德,파이데', 58.8855600, 25.5572200, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41400, 'Padise', 'Padise', 'Padise', 59.2311100, 24.1405600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41401, 'Õru', 'Oru', 'Eru,Oru,Oru Asundus,yru,Õru,Õru Asundus,Ыру', 57.9258300, 26.1788900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41402, 'Orissaare', 'Orissaare', 'Orisaara,Orisaare,Orisar,Orisare,Orissaar,Orissare,Orrisar,Orrissaar,Orrissar', 58.5591700, 23.0826200, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41403, 'Orava', 'Orava', 'Orava', 57.8966700, 27.4591700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41404, 'Karksi-Nuia', 'Karksi-Nuia', 'Karksi,Karksi-Nuaj,Karksi-Nuia,Karksi-Nuya,Karkus,Nuia,Nuiya,Nuya,Nuyya,Каркси,Каркси-Нуай', 58.1033300, 25.5627800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41405, 'Nõva', 'Nova', 'Nova,Nowa,Nyva,Nõva,Nõwa', 59.2163900, 23.6725000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41406, 'Nõo', 'Noo', 'Neo,Niggen'',Niggen’,Noo,Nueggen,Nuggen,Nyo,Nõo,Nüggen,Ныо', 58.2755600, 26.5375000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41407, 'Narva-Jõesuu', 'Narva-Joesuu', 'Gungerburg,Hungerburg,Naroova-Joesuu,Naroova-Jõesuu,Narva Ioesu,Narva Jeesu,Narva Jeesū,Narva Joesu,Narva-Iyesu,Narva-Iyesuu,Narva-Jesu,Narva-Joesu,Narva-Joesuu,Narva-Jyehsuu,Narva-Jyesuu,Narva-Jõesuu,Narva-Jēsū,Narva-Yiesuu,Narva-Yodsu,Narva-Yyesu,Narva-Yyesuu,Narva-Yıesuu,Narwa Joesuu,Narwa Jõesuu,na er wa yue ai su,narva-iiesuu,narwa-jwysw,Нарва-Јоесу,Нарва-Йыесуу,Нарва-Йыэсуу,ناروا-جوئسو,ნარვა-იიესუუ,納爾瓦約埃蘇', 59.4588900, 28.0408300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41408, 'Narva', 'Narva', 'Gorad Narva,Naarva,Narv,Narva,Narva osh,Narvae,Narve,Narwa,Nаrvа,na er wa,naleuba,nar wa,narfa,naruvu~a,narva,narwa,nrbh,Νάρβα,Горад Нарва,Наарва,Нарвæ,Нарва,Нарва ош,Нарве,Նառվա,נרבה,نارفا,ناروا,นาร์วา,ნარვა,ナルヴァ,纳尔瓦,나르바', 59.3772200, 28.1902800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41409, 'Mustvee', 'Mustvee', 'Chernii,Chernoe,Chernyy,Mustve,Mustvee,Mustveeh,Mustwee,Tschorna,Муствеэ', 58.8486100, 26.9397200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41410, 'Mustla', 'Mustla', 'Mustel,Mustla,Tarvast,Tarvastu,Tarwast,Мустла', 58.2333300, 25.8666700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41411, 'Mustjala', 'Mustjala', 'Must''yala,Mustel,Mustjala,Mustjula,Mustla,Must’yala,Myustel'',Myustel’', 58.4613900, 22.2416700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41412, 'Mooste', 'Mooste', 'Mooste,Moste,Myza Moste,Моосте', 58.1561100, 27.1927800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41413, 'Mõniste', 'Moniste', 'Moniste,Myniste,Mõniste,Мынисте', 57.6091700, 26.6136100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41414, 'Mõisaküla', 'Moisakuela', 'Moisakila,Moisakuela,Moisakula,Moisakull,Moisaküll,Moisekuell,Moisekull,Moiseküll,Moizekyul'',Moizekyul’,Myjzakjula,Myysakyula,Myyzakyuilya,Myyzakyula,Mõisaküla,Мыйзакюла', 58.0922200, 25.1863900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41415, 'Misso', 'Misso', 'Misso,Misso Asundus,Myza Misso', 57.6022200, 27.2377800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41416, 'Mikitamäe', 'Mikitamaee', 'Mikitamae,Mikitamaee,Mikitamjaeh,Mikitamyae,Mikitamäe,Микитамяэ', 58.0008300, 27.5480600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41417, 'Meremäe', 'Meremaee', 'Meremae,Meremaee,Meremjaeh,Meremyaya,Meremäe,Merimae,Merimäe,Меремяэ', 57.7447200, 27.4608300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41418, 'Melliste', 'Melliste', 'Meliste,Melliste', 58.3288900, 26.9813900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41419, 'Meeksi', 'Meeksi', 'Commune de Meeksi,Comuna Meeksi,Gmina Meeksi,Meehksi,Meeksi,Meeksi Parish,Meeksi kommune,Meeksi vald,Myza Meksi,dhstan myksy,Меекси,Меэкси,Меєксі,Մեեկսի,دهستان میکسی,მეეკსის მუნიციპალიტეტი', 58.2277800, 27.4322200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41420, 'Martna', 'Martna', 'Martna,Martna Kirik', 58.8558300, 23.8038900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41421, 'Märjamaa', 'Maerjamaa', 'Maerjamaa,Mar''yama,Marjamaa,Mar’yama,Mer''yama,Merjama,Merjamā,Mer’yama,Mjar''jamaa,Myar''yama,Myar''yamaa,Myar’yama,Myar’yamaa,Märjamaa,Мярьямаа', 58.9038900, 24.4305600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41422, 'Mäetaguse', 'Maeetaguse', 'Maeetaguse,Maetaguse,Mjaehtaguze,Myaetaguse,Mäetaguse,Мяэтагузе', 59.2297200, 27.2722200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41423, 'Maardu', 'Maardu', 'Gorad Maardu,Maardu,Mardu,Mārdu,ma er du,maardu,maleudu,mardw,marudo~u,Горад Маарду,Маарду,Марду,Մաառդու,ماردو,მაარდუ,マールドゥ,馬爾杜,마르두', 59.4652900, 24.9821500, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41424, 'Luunja', 'Luunja', 'Lun''ya,Lun’ya,Luun''ja,Luunga Asundus,Luunja,Myza Lun''ya,Myza Lun’ya,Луунья', 58.3558300, 26.8808300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41425, 'Lüganuse', 'Lueganuse', 'Luganuse,Lyuganuse,Lüganuse', 59.3805600, 27.0302800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41426, 'Loo', 'Loo', 'Loo', 59.4312300, 24.9494900, 'EE', '2017-05-07', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41427, 'Loksa', 'Loksa', 'Loksa,Loxa,Локса', 59.5763900, 25.7213900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41428, 'Lohusuu', 'Lohusuu', 'Logoves'',Logoves’,Logozu,Lohusu,Lohusuu,Lokhusu,Lokhusuu,Venekula,Venekyula,Veneküla,Лохусуу', 58.9436100, 27.0450000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41429, 'Liiva', 'Liiva', 'Liiva,Liyva,Moon,Muhu', 58.6019400, 23.2469400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41430, 'Lihula', 'Lihula', 'Fortecja i miza Likhula,Gmina Lihula,Leal,Ligulya,Lihula,Lihula vald,Likhula,Likhula osh,li hu la,lihula,lyhwla,Лихула,Лихула ош,Фортеця і миза Ліхула,Լիհուլա,لیهولا,ლიჰულა,利胡拉', 58.6813900, 23.8452800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41431, 'Leisi', 'Leisi', 'Laisberg,Leisi,Leizi,Leysi,Leyzi', 58.5705600, 22.6969400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41432, 'Lasva', 'Lasva', 'Lasva,Lasva Asundus,Myza Lasva,Ласва', 57.8627800, 27.1841700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41433, 'Laimjala', 'Laimjala', 'Laimjala,Laimjala Asundus,Laym''yala,Laym’yala,Myza Laim''yala,Myza Laim’yala', 58.4205600, 23.0155600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41434, 'Laeva', 'Laeva', 'Laehva,Laeva,Laevakula,Laevaküla,Layeva,Лаэва', 58.4919400, 26.3616700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41435, 'Laekvere', 'Laekvere', 'Ladikfer,Laehkvere,Laekvere,Лаэквере', 59.0655600, 26.5655600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41436, 'Laatre', 'Laatre', 'Laatre,Myza Latre,Лаатре', 57.8688900, 26.2536100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41437, 'Laanemetsa', 'Laanemetsa', 'Laanemetsa,Myza Lanemetsa', 57.6500000, 26.3166700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41438, 'Kuusalu', 'Kuusalu', 'Commune de Kuusalu,Comuna Kuusalu,Gmina Kuusalu,Kusal,Kusalu,Kuusalu,Kuusalu Pairish,Kuusalu Parish,Kuusalu kommun,Kuusalu kommune,Kuusalu vald,Kuzal'',Kuzal’,Paroki Kuusalu,dhstan kwsalw,ku sa lu xiang,Куусалу,Կուուսալու,دهستان کوسالو,კუუსალუს მუნიციპალიტეტი,库萨卢乡', 59.4438900, 25.4413900, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41439, 'Kuressaare', 'Kuressaare', 'Arensburg,Arensburga,Gorad Kurehssaareh,Kingisepp,Kingissepa,Kingissepp,Kuresaar,Kuresaare,Kuresaari,Kuresare,Kuresarė,Kuressaare,Kuressaare osh,Kuressaari,Kuresāre,Kurеssааrе,URE,ku lei sa lei,kulesale,kuresare,kwrsarh,Горад Курэссаарэ,Куресааре,Куресаре,Курессааре,Курессааре ош,Կուռեսաառե,קורסארה,کورساره,کورہ سارہ,კურესაარე,クレサーレ,库雷萨雷,쿠레사레', 58.2480600, 22.5038900, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41440, 'Kurepalu', 'Kurepalu', 'Kurepalu', 58.3186100, 26.8408300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41441, 'Kunda', 'Kunda', 'Kounda,Kund,Kunda,Kunda i Estland,Kundahafen,Kundа,Port-Kunda,kun da,kwnda  astwny,Кунда,Կունդա,کوندا، استونی,კუნდა,昆達', 59.4986100, 26.5261100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41442, 'Kunda', 'Kunda', 'Kunda,Kunda Asundus,Myza Kunda,Кунда', 59.4833300, 26.5333300, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41443, 'Kullamaa', 'Kullamaa', 'Gol''denbek,Goldenbeck,Gol’denbek,Kleyn-Gol''denbek,Kleyn-Gol’denbek,Kullama,Kullamaa,Кулламаа', 58.8788900, 24.0816700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41444, 'Kuldre', 'Kuldre', 'Kuldre', 57.8941700, 26.4788900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41445, 'Krootuse', 'Krootuse', 'Krootuse,Krootuse Asundus,Myza Krotuze', 58.0711100, 26.8350000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41446, 'Kose', 'Kose', 'Kose,Koze', 59.4600100, 24.8782400, 'EE', '2017-05-07', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41447, 'Kose', 'Kose', 'Kosch,Kose,Kosh', 59.1788900, 25.1730600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41448, 'Kõrveküla', 'Korvekuela', 'Korvekuela,Korvekula,Kyrvekjula,Kõrveküla,Кырвекюла', 58.4241700, 26.7822200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41449, 'Koonga', 'Koonga', 'Konga,Koonga,Myza Konga', 58.5825000, 24.1541700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41450, 'Kõo', 'Koo', 'Koo,Kõo,Myza Kyo', 58.6291700, 25.7211100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41451, 'Konguta', 'Konguta', 'Konguta,Конгута', 58.2252800, 26.2936100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41452, 'Kõmsi', 'Komsi', 'Kamsi,Kemsi,Komsi,Kõmsi', 58.6255600, 23.6616700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41453, 'Kolkja', 'Kolkja', 'Kolk''ja,Kolk''ya,Kolkja,Kolk’ya,Колкья', 58.5455600, 27.2150000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41454, 'Kolga-Jaani', 'Kolga-Jaani', 'Klein-Sankt-Johannis,Kleyn'' Iogannis,Kleyn’ Iogannis,Kolga-Jaani,Kolga-Yaani,Kolga-Yani,Колга-Яани', 58.5330600, 25.9458300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41455, 'Koigi', 'Koigi', 'Koigi,Koigi Asundus,Kojgi,Koygi,Myza Koygi,Койги', 58.8288900, 25.7544400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41456, 'Kohtla-Järve', 'Kohtla-Jaerve', 'Gorad Kokhtla-Jarveh,Jarve,Kochtel,Kohtla Jerve,Kohtla Jervė,Kohtla-Jaerve,Kohtla-Jaervi,Kohtla-Jarve,Kohtla-Jerve,Kohtla-Järve,Kohtla-Järvi,Kohtla-Yarve,Kohtla-Yerve,Kokhtla,Kokhtla-Jarve,Kokhtla-Yarve,Kotayarvi,Turpsal,Tyurpsal'',Tyurpsal’,Türpsal,ke he te la-ye er wei,kofutora=yaruvu~e,koheuteullayaeleube,kwtla-yarwh,kʼohtʼla-iarve,Горад Кохтла-Ярвэ,Кохтла-Јарве,Кохтла-Ярве,Կոհտլա-Յեռվե,کوتلا-یاروه,კოჰტლა-იარვე,コフトラ＝ヤルヴェ,科赫特拉-耶爾韋,코흐틀라얘르베', 59.3986100, 27.2730600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41457, 'Kohtla-Nõmme', 'Kohtla-Nomme', 'Kohtla,Kohtla Asundus,Kohtla-Nomme,Kohtla-Nõmme,Myza Kokhtla', 59.3516700, 27.1750000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41458, 'Kohila', 'Kohila', 'Kohila,Koil,Kokhil'',Kokhila,Kokhil’,Koyl'',Koyl’,Кохила', 59.1680600, 24.7575000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41459, 'Koeru', 'Koeru', 'Keras,Koehru,Koeru,Koyero,Koyeru,Kėras,Maria Magdaliny,Marien-Magdalenen,Myza Koyeru,Sankt-Marien-Magdalenen,Коэру', 58.9630600, 26.0308300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41460, 'Kiviõli', 'Kivioli', 'Kivieli,Kivielis,Kiviili,Kivioli,Kiviyli,Kiviõli,Kiviıli,ji wei e li,kibiolli,kivu~iori,kywywly,Кивиоли,Кивиыли,Կիվիիլի,کیویولی,კივიილი,キヴィオリ,基維厄利,키비올리', 59.3530600, 26.9711100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41461, 'Kilingi-Nõmme', 'Kilingi-Nomme', 'Kilingi-Nemme,Kilingi-Nomme,Kilingi-Nymme,Kilingi-Nõmme,Kilingi-nymme,Killingi-Nymme,Kurkund,Nemme,Nomme,Nõmme,Saara,Saarde,Tegnits,Килинги-нымме', 58.1502800, 24.9641700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41462, 'Kiiu', 'Kiiu', 'Kiiu,Kiyu,Myza Kioa', 59.4477800, 25.3794400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41463, 'Kiili', 'Kiili', 'Kiili,Kili,Venekula,Venekyula,Veneküla', 59.3077500, 24.8377600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41464, 'Kihelkonna', 'Kihelkonna', 'Kielkond,Kihelkonna,Kikhel''konna,Kikhel’konna,Kil''kond,Kil’kond', 58.3522200, 22.0469400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41465, 'Keila', 'Keila', 'Gorad Kejla,Kegel,Keil,Keila,Kejla,Keyla,Kеilа,kai yi la,keilla,keira,kyla  astwny,Горад Кейла,Кеила,Кейла,Կեիլա,کیلا، استونی,კეილა,ケイラ,凱伊拉,케일라', 59.3036100, 24.4130600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41466, 'Kehtna', 'Kehtna', 'Kehtna,Kehtna Asundus,Kekhna,Kekhtna,Кехтна', 58.9302800, 24.8780600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41467, 'Kehra', 'Kehra', 'Kedder,Kehra,Kekhra,Kekra,kai he la,khra,Кехра,Կեհռա,کهرا,კეჰრა,凱赫拉', 59.3361100, 25.3211100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41468, 'Karula', 'Karula', 'Karolen,Karula,Luellemaee,Lullemae,Lüllemäe,Карула', 57.7511100, 26.3838900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41469, 'Kyaru', 'Kyaru', 'Kaeru,Karu,Kerro,Keru,Kjaru,Kyaru,Käru,Кяру', 58.8338900, 25.1480600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41470, 'Tornimäe', 'Tornimaee', 'Karneri,Kyarneri,Kärneri,Tornimae,Tornimäe', 58.5016700, 23.1313900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41471, 'Kärdla', 'Kaerdla', 'Gorad Kjardla,KDL,Kaerdla,Kaerrdal,Kardla,Kartla,Kerdla,Kerdlya,Kerhl,Kertel,Kjardla,Kjardla osh,Kjardlae,Kyardla,Kärdla,Kärrdal,Kärtla,Myasto Kyardla,kaeleudeulla,kai er de la,kardla,karudora,qrdlh,Горад Кярдла,Кардла,Кярдлæ,Кярдла,Кярдла ош,Կեռդլա,קרדלה,کاردلا,კიარდლა,カルドラ,凱爾德拉,캐르들라', 58.9977800, 22.7491700, 'EE', '2017-01-30', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41472, 'Kanepi', 'Kanepi', 'Kanapaa,Kanape,Kanapää,Kanepi,Kannapah,Kannapäh,Канепи', 57.9830600, 26.7563900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41473, 'Kambja', 'Kambja', 'Kamb''ja,Kamb''ya,Kambi,Kambja,Kamby,Kamb’ya,Kleyn Kambi,Myza Kamb''ya,Myza Kamb’ya,Камбья', 58.2305600, 26.7005600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41474, 'Kallaste', 'Kallaste', 'Kalaste,Kalastė,Kallaste,Krasnaja Gora,Krasnaya Gora,Krasnogar,Krasnogor,Krasnyye Gory,ka la si tai,kalasth,Каласте,Калласте,Կալլաստե,کالاسته,კალასტე,卡拉斯泰', 58.6631200, 27.1616400, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41475, 'Kalana', 'Kalana', 'Kalana', 58.7177800, 26.0397200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41476, 'Kaiu', 'Kaiu', 'Kaiu,Myza Kayu', 59.0105600, 25.0597200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41477, 'Käina', 'Kaeina', 'Kaina,Keina,Keinis,Kerna,Keyna,Keynis,Kyayna,Käina', 58.8284800, 22.7771100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41478, 'Kadrina', 'Kadrina', 'Kadrina,Katharinen,Katrinen'',Katrinen’,Sankt-Katharinen,Кадрина', 59.3347200, 26.1450000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41479, 'Juuru', 'Juuru', 'Iyerden,Jorden,Juuru,Jörden,Yuru,Юуру', 59.0647200, 24.9502800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41480, 'Jüri', 'Jueri', 'Jueri,Juri,Jüri,Yuri,Юри', 59.3541700, 24.8941700, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41481, 'Jõhvi', 'Johvi', 'Gorad Jykhvi,Ievve,Iohvi,Iyeve,Iyevve,Iykhvi,Jechvi,Jehvi,Jehvis,Jeve,Jewe,Jikhvi,Johvi,Johwi,Johyl,Jukhvi,Jykhvi,Jõhvi,Jöhwi,Levve,Yihvi,Yokhvi,Yykhvi,Yıhvi,iihvi,yeoheubi,yue he wei,yufuvu~i,ywwy,Јихви,Горад Йыхві,Йихві,Йъхви,Йыхви,Յիհվի,یووی,یوہوی,იიჰვი,ユフヴィ,約赫維,여흐비', 59.3591700, 27.4211100, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41482, 'Jõgeva', 'Jogeva', 'Gorad Jygeva,Iyegeva,Iygeva,Jegeva,Jigeva,Jogeva,Jugeva,Jygeva,Jygeva osh,Jõgeva,Laisholm,Laysgol''m,Laysgol’m,Yigeva,Yogeva,Yygeva,Yıgeva,iigeva,yeogeba,yogevu~a,yue ge wa,ywgawa,ywgwa,yygbh,Јигева,Горад Йыгева,Йигева,Йъгева,Йыгева,Йыгева ош,Յիգևա,ייגבה,یوگاوا,یوگوا,იიგევა,ヨゲヴァ,約格瓦,여게바', 58.7466700, 26.3938900, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41483, 'Järve', 'Jaerve', 'Jarve,Järve,Yarve', 59.4058300, 27.3111100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41484, 'Järva-Madise', 'Jaerva-Madise', 'Jaerva-Madise,Jarva-Madise,Jarva-Madize,Järva-Madise,Madise,Sankt Mattai,Sankt Mattäi,Sankt-Matthai,Sankt-Matthäi,Svyatogo Mateya,Yarva-Madise,Ярва-Мадизе', 59.1163900, 25.6586100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41485, 'Järvakandi', 'Jaervakandi', 'Jaervakandi,Jarvakandi,Jarvakandi Klaasivabrik,Jarvakandi Tehasid,Jarwakandi Klaasi Wabrik,Järvakandi,Järvakandi Klaasivabrik,Järvakandi Tehasid,Järwakandi Klaasi Wabrik,Stekol''nyy Zavod Yarvakandi,Stekol’nyy Zavod Yarvakandi,Ярваканди', 58.7788900, 24.8258300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41486, 'Järva-Jaani', 'Jaerva-Jaani', 'J. Jaani,Jaani,Jaerva-Jaani,Jarva-Jaani,Jarvi-Jaani,Jerve Jani,Jerve Jāni,Järva-Jaani,Järvi-Jaani,Sankt-Johannis,Svyatogo Ioanna,Yarva-Yani,Yyarva-Yani,Ярва-Яани', 59.0386100, 25.8863900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41487, 'Imavere', 'Imavere', 'Commune de Imavere,Comuna Imavere,Gmina Imavere,Imavere,Imavere Parish,Imavere kommune,Imavere vald,Myza Imavere,dhstan aymawrh,Імавере,Имавере,Իմավեռե,دهستان ایماوره,იმავერეს მუნიციპალიტეტი', 58.7330600, 25.7725000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41488, 'Ilmatsalu', 'Ilmatsalu', 'Ilmatsalu,Myza Illmatsalu', 58.3863900, 26.5466700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41489, 'Illuka', 'Illuka', 'Commune de Illuka,Comuna Illuka,Gmina Illuka,Illuka,Illuka Parish,Illuka kommune,Illuka vald,Illuka-Asula,Iluka,dhstan aylwka,Іллука,Иллука,Իլուկա,دهستان ایلوکا,ილუკის მუნიციპალიტეტი', 59.2377800, 27.4847200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41490, 'Iisaku', 'Iisaku', 'Commune de Iisaku,Comuna Iisaku,Gmina Iisaku,Iisaku,Iisaku Parish,Iisaku kommune,Iisaku vald,Ijzaku,Isaak,Isak'',Isaku,Isak’,Iyzaku,Izak,dhstan aysakw,Ійзаку,Ийзаку,Իիսակու,دهستان ایساکو,იისაკუს მუნიციპალიტეტი', 59.1013900, 27.3080600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41491, 'Hummuli', 'Hummuli', 'Alt-Hummelshof,Hummelshof,Hummuli,Hummuli Asundus,Khummel''sgof,Khummel’sgof,Khummuli,Myza Khummuli', 57.9036100, 26.0583300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41492, 'Hullo', 'Hullo', 'Hullo,Khullo', 58.9900400, 23.2444100, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41493, 'Hellenurme', 'Hellenurme', 'Hellenurme,Khellenurme,Myza Khellenurme', 58.1361100, 26.3900000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41494, 'Halliste', 'Halliste', 'Gallist,Hallist,Halliste,Khalliste', 58.1500000, 25.4333300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41495, 'Haljala', 'Haljala', 'Haljala,Haljall,Khal''jala,Khal''yal'',Khal''yala,Khal’yala,Khal’yal’,Хальяла', 59.4336100, 26.2613900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41496, 'Haapsalu', 'Haapsalu', 'Gaapsalu,Gapsal'',Gapsal’,Gorad Khaapsalu,Haapsalu,Haapsula,Hapsal,Hapsalia,Hapsalu,Hāpsalu,Hааpsаlu,Khaapsalu,Khaapsalu osh,Khaapsalyu,Khapsalu,ha pu sha lu,haapsalu,habsallu,hapsalw,hapusaru,Горад Хаапсалу,Хаапсалу,Хаапсалу ош,Хапсалу,Հաապսալու,هاپسالو,ჰააფსალუ,ハープサル,哈普沙盧,합살루', 58.9430600, 23.5413900, 'EE', '2016-03-13', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41497, 'Haanja', 'Haanja', 'Haanja,Khaan''ya,Khaan’ya,Khan''ja,Khan''ya,Khan’ya,Myza Khan''ya,Myza Khan’ya,Ханья', 57.7216700, 27.0488900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41498, 'Haabneeme', 'Haabneeme', 'Haabneeme,Khaabneehme,Khaabneeme,Хаабнеэме', 59.5135800, 24.8222500, 'EE', '2017-05-07', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41499, 'Emmaste', 'Emmaste', 'Emmaste', 58.7036100, 22.6169400, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41500, 'Elva', 'Elva', 'Ehlva,Ehlva osh,Elv,Elva,Elva i Estland,Elwa,ai er wa,alwa  astwny,elba,elva,Елва,Элва,Элва ош,Էլվա,الوا، استونی,ელვა,埃尔瓦,엘바', 58.2225000, 26.4211100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41501, 'Avinurme', 'Avinurme', 'Avinorm,Avinurme,Avinurme Parish,Avinurme kommune,Avinurme vald,Awinorm,Awwinorm,Commune dAvinurme,Comuna Avinurme,Gmina Avinurme,dhstan awynwrmh,Авинурме,Авінурме,Ավինուռմե,دهستان آوینورمه,ავინურმეს მუნიციპალიტეტი', 58.9822200, 26.8641700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41502, 'Audru', 'Audru', 'Audru,Аудру', 58.4086100, 24.3738900, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41503, 'Aseri', 'Aseri', 'Asari,Aseri,Aseri Mois,Aseri Mõis,Aseri-Talukula,Aseri-Taluküla,Asserien,Asserin,Azeri,Azern,Азерн', 59.4505600, 26.8675000, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41504, 'Aruküla', 'Arukuela', 'Aru 21,Arukila,Arukiula,Arukjula,Arukula,Arukula Aedlinn,Arukyula,Aruküla,Aruküla Aedlinn,Арукила,Арукюла,Առուկյուլա', 59.3668600, 25.0761800, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41505, 'Antsla', 'Antsla', 'Antsen'',Antsen’,Antsla,Antzen,Anzen,Gauka,Hauka,Антсла', 57.8255600, 26.5405600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41506, 'Ambla', 'Ambla', 'Ambla,Амбла', 59.1911100, 25.8455600, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41507, 'Alatskivi', 'Alatskivi', 'Alatskivi', 58.5980600, 27.1336100, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41508, 'Alajõe', 'Alajoe', 'Alaiye,Alajoe,Alajyz,Alajõe,Alayye,Алайыз', 59.0125000, 27.4291700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41509, 'Ahja', 'Ahja', 'Ahja,Akh''ja,Akh''ya,Akh’ya,Ахья', 58.2038900, 27.0733300, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41510, 'Aegviidu', 'Aegviidu', 'Aegvidu,Aegviidu,Aegviydu,Aehgvijdu,Charlottenhof,Sharlotengof,Sharlottengof'',Sharlottengof’,Аэгвийду', 59.2858300, 25.6141700, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41511, 'Abja-Paluoja', 'Abja-Paluoja', 'Ab''ja-Paluoja,Ab''ja-Paluoja osh,Ab''ya,Ab''ya-Paluoya,Abbia,Abia,Abja Paluoja,Abja-Paluoja,Abya-Paluoya,Ab’ya,Ab’ya-Paluoya,Paluoja,Paluoya,a bi ya pa lu ao ya,abya-palwaya,Абья-Палуоя,Абья-Палуоя ош,Абя-Палуоя,Աբյա-Պալուոյա,آبیا-پالوایا,აბია-პალუოია,阿比亞帕盧奧亞', 58.1252800, 25.3497200, 'EE', '2017-07-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41512, 'Sõmeru', 'Someru', 'Someru,Sõmeru', 59.3611100, 26.4375000, 'EE', '2017-07-05', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41513, 'Tabivere', 'Tabivere', 'Tabivere,Табивере', 58.5541700, 26.5955600, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41514, 'Laagri', 'Laagri', '', 59.3508300, 24.6141800, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41515, 'Viimsi', 'Viimsi', '', 59.5008600, 24.8625400, 'EE', '2016-02-04', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41516, 'Iide', 'Iide', 'Iide', 57.9761100, 22.0652800, 'EE', '2017-07-05', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41517, 'Kääpa', 'Kaapa', 'Kaapa,Kääpa', 58.6941300, 26.8839500, 'EE', '2017-07-06', 70);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41529, 'Shirbīn', 'Shirbin', 'Sharbin,Sharbīn,Sherbin,Shirbin,Shirbîn,Shirbīn,shrbyn,شربين', 31.1968800, 31.5243000, 'EG', '2017-02-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41530, 'Shibīn al Qanāṭir', 'Shibin al Qanatir', 'Shabin al Qanatir,Shabir al-Kanatir,Shabīn al Qanātir,Shibin al Qanatir,Shibin el-Qanatir,Shibîn el-Qanâṭir,Shibīn al Qanāţir,shbyn alqnatr,شبين القناطر', 30.3126900, 31.3201800, 'EG', '2017-07-10', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41531, 'Shibīn al Kawm', 'Shibin al Kawm', 'Shabin al-Kum,Shebin al-Kom,Shibin al Kawm,Shibin el-Kom,Shibîn el-Kôm,Shibīn al Kawm,shbyn alkwm,شبين الكوم', 30.5525800, 31.0090400, 'EG', '2013-08-04', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41532, 'Sharm el-Sheikh', 'Sharm el-Sheikh', 'Awfir,Awfīr,Charm el-Cheikh,Cherm,Ofira,Ophira,Ras Muhammad,Ras Umm Sidd,SSH,Sharm al Shaikh,Sharm ash Shaykh,Sharm el Sheikh,Sharm el-Sheij,Sharm el-Sheikh,Sharm esh Sheikh,Sharm-ehl''-Shejkh,Sherm el Sheik,Sherm el Sheikh,Sherm el Shekh,sha mu sha yi he,sharumu・eru・sheiku,shrm alshykh,shrm‌alshykh,syaleum-elsyeikeu,sʼrm ʼ-syyh'',Шарм-эль-Шейх,שארם א-שייח'',شرم الشيخ,شرم‌الشیخ,シャルム・エル・シェイク,沙姆沙伊赫,샤름엘셰이크', 27.9158200, 34.3299500, 'EG', '2014-01-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41533, 'Samannūd', 'Samannud', 'Samannud,Samannûd,Samannūd,Samnud,Samnūd,Sebennytos,smnwd,سمنود', 30.9616000, 31.2406900, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41534, 'Samālūţ', 'Samalut', 'Samalut,Samālūţ', 28.3121400, 30.7100700, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41535, 'Rosetta', 'Rosetta', 'Ar-Rasid,Ar-Rašíd,Bolbitine,Er-Rashid,Rachid,Rashid,Rashîd,Rashīd,Rasid,Rasido,Raŝido,Rašid,Resid,Reşid,Roseta,Rosetta,Rosette,Rozeta,lojeta,luo sai ta,rashidi,rozetta,rshyd,rsyd,Ροζέτα,Рашид,Розета,רשיד,رشيد,رشید,რაშიდი,ロゼッタ,羅塞塔,로제타', 31.3995100, 30.4171800, 'EG', '2015-08-07', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41536, 'Ras Gharib', 'Ras Gharib', 'Ra''s Gharib,Ras Gharib,Ra’s Ghārib', 28.3583100, 33.0782900, 'EG', '2015-08-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41537, 'Rafaḩ', 'Rafah', 'Er Rafa,Rafa,Rafaa,Rafah,Rafah al Misriyah,Rafaḩ,Rafaḩ al Mişrīyah,Rafiah,Rafīah,Raphia,Rifah,rfh,رفح', 31.2820400, 34.2386900, 'EG', '2017-06-07', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41538, 'Quwaysinā', 'Quwaysina', 'Kuesnah,Quwaysina,Quwaysinā,Quweisna,qwysna,قويسنا', 30.5648200, 31.1577700, 'EG', '2012-02-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41539, 'Quţūr', 'Qutur', 'Kotur,Kotûr,Qotur,Qutur,Quţūr,Quṭûr,qtwr,قطور', 30.9722500, 30.9561400, 'EG', '2017-07-14', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41540, 'Kousa', 'Kousa', 'Apollinopolis Parva,Apollonopolis Parva,Kousa,Qus,Qūş,qws,قوص', 25.9140700, 32.7636200, 'EG', '2017-07-14', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41541, 'Qinā', 'Qina', 'Caene,Kena,Keneh,Qana,Qanā,Qena,Qina,Qinā,astan qna,qna,استان قنا,قنا', 26.1641800, 32.7267100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41542, 'Qaşr al Farāfirah', 'Qasr al Farafirah', 'Al Farafirah,Al Farāfirah,Farafra,Qasr Farafra,Qasr al Farafirah,Qaşr al Farāfirah,Фарафра', 27.0568000, 27.9697900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41543, 'Qalyūb', 'Qalyub', 'Kal''jub,Kalyub,Kalyûb,Qaliub,Qalyub,Qalyūb,qlywb,Кальюб,قليوب', 30.1792200, 31.2056000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41544, 'Nuwaybi‘a', 'Nuwaybi`a', 'Nueiba,Nuvejba,Nuwaiba,Nuwaiba`,Nuwaiba‘,Nuwaybi`a,Nuwaybi‘a,Nuweiba,Nuweibeh,Nuweibá,nwybʿ,Нувейба,نويبع', 29.0468100, 34.6634000, 'EG', '2016-09-26', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41545, 'Naja'' Ḥammādī', 'Naja'' Hammadi', 'Gebel el Hagif,Nag Hamadi,Nag Hamady,Nag Hammadi,Nag Hammadi-geschriften,Nag Hammádí,Nag Hammâdi,Nag-Hamado,Nag` Hammadi,Naga Hamadi,Nag‘ Hammādi,Naj` Hammadi,Naj` al Hammadi,Naj‘ al Ḩammādī,Naj‘ Ḩammādī,na ge ma di,njʿ hmady,نجع حمادى,ナグ・ハマディ,拿戈瑪第', 26.0494900, 32.2414200, 'EG', '2017-07-10', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41546, 'Minyat an Naşr', 'Minyat an Nasr', 'MINYAT AN-NASR,MINYAT AN-NAṢR,Minyat an Nasr,Minyat an Naşr,Minyet el-Nasr,Minyet el-Naṣr,mnyt alnsr,منية النصر', 31.1262400, 31.6431300, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41547, 'Munūf', 'Munuf', 'MINUF,MINŪF,Manuf,Manūf,Menouf,Menoufis,Menuf,Munuf,Munūf,mnwf,منوف', 30.4659700, 30.9319900, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41548, 'Maţāy', 'Matay', 'Matai,Matay,Matâi,Maţāy,Muttay', 28.4189900, 30.7792400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41549, 'Mashtūl as Sūq', 'Mashtul as Suq', 'Mashtul as Suq,Mashtul el-Suq,Mashtûl el-Sûq,Mashtūl as Sūq', 30.3605600, 31.3776000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41550, 'Mersa Matruh', 'Mersa Matruh', 'MUH,Madara,Marsa Matruh,Marsa-Matrukh,Marsá Maţrūḩ,Matruh,Maţrūḩ,Mersa Matrouh,Mersa Matruh,Mhadara,Paraetonium,mrsy mtrwh,Марса-Матрух,مرسى مطروح', 31.3529000, 27.2372500, 'EG', '2014-05-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41551, 'Marsa Alam', 'Marsa Alam', 'Marsa Alam,Marsa al `Alam,Marsá al `Alam,RMF,Марса Алам,مرسى علم', 25.0630500, 34.8900500, 'EG', '2014-07-16', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41552, 'Manfalūţ', 'Manfalut', 'Manfalut,Manfalūţ,Monfalut,mnflwt,منفلوط', 27.3104000, 30.9700400, 'EG', '2017-07-12', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41553, 'Mallawī', 'Mallawi', 'Mallauri,Mallavi,Mallawi,Mallawī,Маллави', 27.7314000, 30.8416500, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41554, 'Madīnat Sittah Uktūbar', 'Madinat Sittah Uktubar', '6 October City,Madinat Sittah Uktubar,Madīnat Sittah Uktūbar,October 6', 29.8166700, 31.0500000, 'EG', '2011-04-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41555, 'Ash Shaykh Zuwayd', 'Ash Shaykh Zuwayd', 'Ash Shaykh Zuwayd,Ash Shaykh Zuwayyid,El Sheikh Zuwaiyid,Korum el-Sheikh,Korûm el-Sheikh,Kurum ash Shaykh,Kurūm ash Shaykh,Sheikh Zuwayid,Sheikh Zuweiyid,Sheikh Zuwâyid,alshykh zwyd,الشيخ زويد', 31.2163000, 34.1107400, 'EG', '2013-08-07', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41556, 'Kawm Umbū', 'Kawm Umbu', 'Kawm Ombo,Kawm Umbu,Kawm Umbū,Kom Ombo,Kom Ombo - kwm ambw,Kom Ombo - كوم أمبو,Kum Ombu,Kôm Ombo,Omboi,Ombos,kom-ombo,Ком-Омбо,コム・オンボ', 24.4766900, 32.9462600, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41557, 'Kawm Ḩamādah', 'Kawm Hamadah', 'Kawm Hamadah,Kawm Ḩamādah,Kom Hamada,Kôm Ḥamâda', 30.7609500, 30.6973300, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41558, 'Kafr Şaqr', 'Kafr Saqr', 'Kafr Saqr,Kafr Şaqr,Kafr Ṣaqr,kfr sqr,كفر صقر', 30.7933600, 31.6257500, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41559, 'Kafr az Zayyāt', 'Kafr az Zayyat', 'Kafr az Zayat,Kafr az Zayyat,Kafr az Zayyāt,Kafr az Zayāt,Kafr el-Zaiyat,Kafr el-Zaiyât,Kafr el-Zayat,Kafr ez Zaiyat,Kafraz Zayyt,kfr alzyat,كفر الزيات', 30.8248000, 30.8180500, 'EG', '2017-07-12', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41560, 'Kafr ash Shaykh', 'Kafr ash Shaykh', 'Kafr al-Sheikh,Kafr ash Shaykh,Kafr el-Sheikh,Kafr-Sheikh,kfr alshykh,كفر الشيخ', 31.1117400, 30.9399100, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41561, 'Kafr ad Dawwār', 'Kafr ad Dawwar', 'Kafr ad Dawwar,Kafr ad Dawwār,Kafr al-Dawar,Kafr ed-Dauwar,Kafr ed-Dauwâr,Kafr el Dawdar,Kafr el-Dauwar,Kafr el-Dauwâr,kfr aldwar,كفر الدوار', 31.1337900, 30.1296900, 'EG', '2015-08-07', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41562, 'Juhaynah', 'Juhaynah', 'Giheina,Jihaynah,Juhaynah', 26.6731900, 31.4976000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41563, 'Jirjā', 'Jirja', 'Girga,Jirja,Jirjā', 26.3382600, 31.8916100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41564, '‘Izbat al Burj', '`Izbat al Burj', 'Ezbet el-Burg,`Ezbet el-Burg,`Izbat al Burj,ʿzbt albrj,عزبة البرج,‘Ezbet el-Burg,‘Izbat al Burj', 31.5084000, 31.8410600, 'EG', '2017-07-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41565, 'Iţsā', 'Itsa', '', 29.2376000, 30.7894400, 'EG', '2011-04-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41566, 'Isnā', 'Isna', 'Asna,Asnā,Ehsna,Esna,Esneh,Isna,Isnā,Latonpolis,Latopolia,Latopolis,Latónpolis,asna,Эсна,איסנא,אסנא,إسنا', 25.2933600, 32.5540200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41567, 'Idkū', 'Idku', 'Edkou,Idku,Idkū,adkw,Идку,إدكو', 31.3073000, 30.2981000, 'EG', '2015-08-10', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41568, 'Idfū', 'Idfu', 'Apollinopolis Magna,Apollonopolis Magna,Edfou,Edfu,Edfú,Ehdfu,Idfu,Idfu Bahari,Idfu Bahri,Idfu Baḥari,Idfū,Idfū Baḩri,adfw,edofu,Едфу,Эдфу,إدفو,エドフ', 24.9791600, 32.8772200, 'EG', '2015-08-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41569, 'Ibshawāy', 'Ibshaway', 'Ibshawai,Ibshaway,Ibshawāy', 29.3580500, 30.6814200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41570, 'Ḩalwān', 'Halwan', 'Halwan,Helouan,Helouan-les-Bains,Helwan,Helwan Les Bains,Hilwan,Hulwan,Hélouan-les-Bains,Kheluan,hlwan,Хелуан,حلوان,Ḥelwân,Ḩalwān,Ḩulwān', 29.8414400, 31.3008400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41571, 'Hihyā', 'Hihya', 'Hehia,Hihya,Hihyā,Rehia,hhya,ههيا', 30.6713000, 31.5880100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41572, 'Ḩawsh ‘Īsá', 'Hawsh `Isa', 'Haush `Isa,Haush ‘Isá,Hawsh `Isa,Hosh `Isa,Ḥôsh ‘Îsa,Ḩawsh ‘Īsá', 30.9128000, 30.2901900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41573, 'Fuwwah', 'Fuwwah', 'Fawwah,Fouah,Fowa,Fuwa,Fuwah,Fuwwah,fwt,فوة', 31.2036500, 30.5490800, 'EG', '2015-09-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41574, 'Farshūţ', 'Farshut', 'Farshut,Farshuut,Farshūţ', 26.0549400, 32.1632900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41575, 'Fāraskūr', 'Faraskur', 'Faraskur,Faraskûr,Fariskur,Fâriskûr,Fāraskūr,Fāriskūr,farskwr,فارسكور', 31.3297700, 31.7150700, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41576, 'Fāqūs', 'Faqus', 'Fakous,Fakus,Faqus,Fāqūs,faqws,فاقوس', 30.7281600, 31.7969700, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41577, 'Damietta', 'Damietta', 'Damiata,Damieta,Damieti,Damietta,Damiette,Damijeta,Dimyat,Dimyath,Dimyāṭ,Doemjat,Dumiat,Dumjat,Dumjata,Dumjatas,Dumját,Dumjāta,Dumqat,Dumujat,Dumyat,Dumyâṭ,Dumyāţ,QDX,Tamiathis,da meiy t ta,dami''ata,damieta,dimuyato,dmyat,du mu ya te,Δαμιέτη,Дамиета,Дамијета,Думъят,Думят,Դամիետա,דמיאט,دمياط,دمیاط,ਦਮੀਆਤ,ดาเมียตตา,დუმიატი,ディムヤート,杜姆亚特,다미에타', 31.4164800, 31.8133200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41578, 'Diyarb Najm', 'Diyarb Najm', 'Diarb Negm,Diyarb Najm,Diyarb Nigm,Diyarb Nijm,dyrb njm,ديرب نجم', 30.7543800, 31.4401600, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41579, 'Disūq', 'Disuq', 'Dasuq,Dasūq,Dessouk,Disuk,Disuq,Disūq,dswq,Дисук,دسوق', 31.1325900, 30.6478400, 'EG', '2015-09-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41580, 'Dishnā', 'Dishna', 'Dashna,Dashnā,Dechna,Deshna,Dishna,Dishnā', 26.1246700, 32.4759800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41581, 'Dikirnis', 'Dikirnis', 'DIKIRNIS,Dekernes,Dikinis,Dikirnis,dkrns,Дикирнис,دكرنس', 31.0889800, 31.5947800, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41582, 'Dhahab', 'Dhahab', 'Dahab,Dahabas,Dakhab,Dhahab,dhb,Дахаб,דהב,دهب', 28.5009800, 34.5133800, 'EG', '2016-11-04', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41583, 'Dayrūţ', 'Dayrut', 'Dairut,Dairut el Mahatta,Dairût,Dairût el Maḥaṭṭa,Dayrut,Dayrut al Mahattah,Dayrūţ,Dayrūţ al Maḩaţţah,Deirout,Deirut', 27.5560200, 30.8076400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41584, 'Dayr Mawās', 'Dayr Mawas', 'Dayr Mawas,Dayr Mawās,Deir Mawas,Deir Mawās', 27.6417600, 30.8466200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41585, 'Damanhūr', 'Damanhur', 'Bandar Damanhur,Bandar Damanhūr,Damanhour,Damanhur,Damanhûr,Damanhūr,Damankhur,Hermopolis Parva,Hermupolis Parva,dmnhwr,Даманхур,دمنهور', 31.0340800, 30.4682300, 'EG', '2014-03-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41586, 'Būsh', 'Bush', '', 29.1481600, 31.1273300, 'EG', '2011-04-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41587, 'Port Said', 'Port Said', 'Bor Sa`id,Bor Sa‘īd,Bur Sa`id,Bursaid,Būr Sa‘īd,Madinat Bur Sa`id,Madinet Port Said,Madînat Būr Sa‘īd,Madînet Port Said,PORTSAINT,PSD,Port Said,Port Saidas,Port Saíd,Port-Said,Port-Saïd,Porto Said,Puerto Said,Puerto Saíd,sai de gang,ΠΟΡΤΣΑΪΝΤ,Порт-Саид,פורט סעיד,بور سعيد,بورسعيد,塞德港', 31.2565400, 32.2841100, 'EG', '2016-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41588, 'Safaga', 'Safaga', 'Bur Safaga,Bur Safajah,Būr Safājah,Port Safaga,Safadza,Safadża,Safaga,sai fa jie,sfaja,Сафага,سفاجا,塞法杰', 26.7490600, 33.9389100, 'EG', '2017-04-21', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41589, 'Bilqās', 'Bilqas', 'Balqas,Balqās,Bilqas,Bilqas Qism Auwal,Bilqas Qism Awwal,Bilqâs,Bilqâs Qism Auwal,Bilqās,Bilqās Qism Awwal,blqas,بلقاس', 31.2145200, 31.3579800, 'EG', '2013-06-05', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41590, 'Bilbays', 'Bilbays', 'Belbeis,Bilbays,Bilbeis,Bilbes,Bilbês,blbys,بلبيس', 30.4203900, 31.5622300, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41591, 'Basyūn', 'Basyun', 'Basyun,Basyûn,Basyūn', 30.9397600, 30.8133800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41592, 'Banī Suwayf', 'Bani Suwayf', 'Bani Suwayf,Banī Suwayf,Beni Souef,Beni Sue,Beni Suef,Beni Suweif,bny swyf,بني سويف', 29.0744100, 31.0978500, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41593, 'Banī Mazār', 'Bani Mazar', 'Bani Mazar,Banī Mazār,Beni Mazar,Beni Mazâr', 28.5036000, 30.8004000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41594, 'Banhā', 'Banha', 'Athribis,Bandar Banha,Bandar Banhā,Banha,Banhā,Bankha,Benha,Benna,bnha,Банха,بنها', 30.4590600, 31.1785800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41595, 'Zagazig', 'Zagazig', 'Az Zaqaziq,Az Zaqāzīq,Ehz-Zakazik,Ez Zaqaziq,Ez Zaqāzīq,QZZ,Zagazig,Zaqaziq,Zaqazîq,alzqazyq,jagajigeu,zai jia ji ge,Эз-Заказик,الزقازيق,宰加济格,자가지그', 30.5876800, 31.5020000, 'EG', '2013-04-21', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41596, 'Awsīm', 'Awsim', 'Ausim,Ausîm,Awsim,Awsīm,Letopolis,Letous Polis,Usiim,awsym,أوسيم', 30.1230300, 31.1357100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41597, 'El-Tor', 'El-Tor', 'Al-Tur,At Tur,Aţ Ţūr,ELT,El-Tor,El-Tur,El-Tûr,Et Tor,Raithu,Thur,Tor,Tor Sinai City,Tur Sinai,altwr,الطور', 28.2416800, 33.6222000, 'EG', '2017-04-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41598, 'At Tall al Kabīr', 'At Tall al Kabir', 'At Tall al Kabir,At Tall al Kabīr,At Tell al Kebir,At Tell al Kebīr,El-Tell el-Kebir,El-Tell el-Kebîr,Et Tell el Kebir,Et Tell el Kebīr,Tel el Kebir,Tell el- Kebir,Tell el- Kebîr,altl alkbyr,التل الكبير', 30.5432300, 31.7850400, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41599, 'Asyūţ', 'Asyut', 'ATZ,As''jut,Assiout,Assiut,Assuit,Asyut,Asyūţ,Licopolis,Likupulis,Lycopolis,Līkūpūlīs,Siut,asywt,Асьют,أسيوط', 27.1809600, 31.1836800, 'EG', '2016-01-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41600, 'Aswan', 'Aswan', 'ASW,Assouan,Assuan,Assuao,Assuão,Asszuan,Asszuán,Asuan,Asuanas,Asuano,Asuán,Asvan,Aswan,Aswán,Aswân,Aswān,Es-Suan,Eswan,Gorad Asuan,Syena,Syene,Syeue,a si wang,aseuwan,asuani,asuwan,asvana,aswan,Ασσουάν,Асуан,Горад Асуан,אסואן,أسوان,اسوان,आस्वान,ასუანი,アスワン,阿斯旺,아스완', 24.0908200, 32.8994200, 'EG', '2015-06-03', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41601, 'Suez', 'Suez', 'Al Qulzum,As Suways,Clysma,El Seweis,El Suweis,El-Qulzum,Es Suweis,Klysma,Souez,Suais,Suec,Suecas,Suehc,Suehckij,Sues,Suesia,Suess,Sueveys,Suez,Suezi,Suezo,Suvajs,Suèz,Suës,Szuez,Súes,Süveyş,alswys,su yi shi,su''ejha,suejeu,suetsi,suezu,swys,swyyz,swyz,Σουέζ,Сувайс,Суец,Суэц,Суэцкий,Սուեզ,סואץ,السويس,سوئز,سوئیز,سويس,सुएझ,სუეცი,スエズ,苏伊士,蘇伊士,수에즈', 29.9737100, 32.5262700, 'EG', '2013-12-01', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41602, 'Aş Şaff', 'As Saff', 'As Saff,Aş Şaff,El-Saff,Es Saff,alsf,الصف', 29.5647200, 31.2811100, 'EG', '2017-07-16', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41603, 'Ash Shuhadā’', 'Ash Shuhada''', 'Ash Shuhada'',Ash Shuhadā’,El Shohada,El-Shuhada,Esh-Shuhada', 30.5961800, 30.8987500, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41604, 'Ashmūn', 'Ashmun', 'ASHMUN,ASHMŪN,Ashmun,Ashmūn,ashmwn,أشمون', 30.2973500, 30.9764100, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41605, 'Al Wāsiţah', 'Al Wasitah', 'Al Wasitah,Al Wāsiţah,El Wasta,El Wāsta,Wasta', 29.3377800, 31.2055600, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41606, 'Luxor', 'Luxor', 'Al Uqsur,El Aqsur,El Kusur,El Qusur,El Uqsor,El-Aksur,El-Uksur,Gorad Luksor,LXR,Louksor,Louxor,Loxor,Loxòr,Lucsar,Luksor,Luksor shaary,Luksora,Luksoras,Luksoro,Luqsor,Luxor,Luxor- alaqsr,Luxor- الأقصر,Lúxor,al-ukcur,alaqsr,aqsr,lak sxr,lakasara,laksara,le shu,lksr,lugsoleu,luksora,luksori,lwqswr,rukusoru,Λούξορ,Горад Луксор,Луксор,Луксор шаары,Լուքսոր,לוקסור,اقصر,الأقصر,الاقصر,لکسر,लक्सर,लुक्सोर,ਲਕਸਰ,அல்-உக்சுர்,ลักซอร์,ლუქსორი,ルクソール,樂蜀,룩소르', 25.6989300, 32.6421000, 'EG', '2016-01-28', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41607, 'Al Qūşīyah', 'Al Qusiyah', 'Al Qusiyah,Al Qūşīyah,Cusae,El Qusiya,El Qūsīya', 27.4402000, 30.8184100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41608, 'Al Quşayr', 'Al Qusayr', 'Al Qusayr,Al Quşayr,Al''-Kusajra,El Quseir,Koseir,Leucus Limen,Qosier,Qosseir,Quseir,alqsyr,Аль-Кусайра,القصير', 26.1042600, 34.2779300, 'EG', '2016-09-25', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41609, 'Al Qurayn', 'Al Qurayn', 'Al Qurayn,Al Qurayn wa Tawahin al Haysamiyah,Al Qurayn wa Ţawāḩīn al Ḩayşamīyah,Al''-Ehl''-Kurajn,El Qurein and Tawahin el Heisamiya,El Qurein and Tawaḥîn el Heiṣamîya,El-Qurein,El-Qurein wa Tawahir,El-Qurein wa Ṭawâḥîr,alqryn,Аль-Эль-Курайн,القرين', 30.6161800, 31.7351400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41610, 'Al Qanāyāt', 'Al Qanayat', 'Al Qanayat,Al Qanāyāt,El-Qanayat,El-Qanâyât,alqnayat,القنايات', 30.6188000, 31.4609900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41611, 'Al Qanāţir al Khayrīyah', 'Al Qanatir al Khayriyah', 'Al Qanatir al Khayriyah,Al Qanāţir al Khayrīyah,Barrage,Delta Barrage,Delta Barrage Station,Delta-Barrage,El-Qanatir el-Khairiya,El-Qanâtir el-Khairîya,El-Qanâṭir el-Khairîya,Muhammed `Ali Barrage,Muhammed ‘Ali Barrage,`Ezbet Shalaqan,`Izbat Shalqan,alqnatr alkhyryt,القناطر الخيرية,‘Ezbet Shalaqân,‘Izbat Shalqān', 30.1932700, 31.1370300, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41612, 'Cairo', 'Cairo', 'Al Qahirah,Al Qāhirah,CAI,Caire,Cairo,Cairo - alqahrt,Cairo - القاهرة,Cairu,Cairus,Caïro,El Caire,El Cairo,El Kahira,El Kahirah,El-Qahira,El-Qâhira,Il Cairo,Kaherah,Kahira,Kahirae,Kahire,Kahirä,Kair,Kaira,Kairas,Kairo,Kairó,Kajro,Kayro,Kaíró,Kaïro,Káhira,Le Caire,Lo Cayiro,Lungsod ng Cairo,Masr,Misr,Qahirə,alqahrt,kai luo,kailo,kairo,keyro,khiro,qahrh,qhyr,Ël Cairo,Ël Càiro,Κάιρο,Каир,Каиро,Кайро,Каїр,קהיר,القاهرة,قاهره,قاھىرە,قاہرہ,கெய்ரோ,ไคโร,ཁ་ཡི་རོ,ქაირო,ካይሮ,カイロ,开罗,카이로', 30.0626300, 31.2496700, 'EG', '2015-06-03', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41613, 'Al Minyā', 'Al Minya', 'Al Minya,Al Minyā,EMY,Ehl''-Min''ja,El Minia,El-Minya,Minia,Minieh,Minya,almnya,Эль-Минья,المنيا', 28.1098800, 30.7503000, 'EG', '2017-04-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41614, 'Al Maţarīyah', 'Al Matariyah', 'Al Matariyah,Al Maţarīyah,El Mataria,El-Matariya,El-Maṭarîya,Matarieh,almtryt,المطرية', 31.1828700, 32.0310800, 'EG', '2017-02-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41615, 'Al Manzalah', 'Al Manzalah', 'Al Manzalah,Al Manzilah,El-Manzala,almnzlt,المنزلة', 31.1582300, 31.9360000, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41616, 'Al Manşūrah', 'Al Mansurah', 'Al Mansurah,Al Manşūrah,Al-Mansura,Al-Mansurah,Al-Manṣūrah,El Mansura,El-Mansura,El-Manṣûra,El-Masura,El-Masûra,Manoura,Mansoura,Mansourah,Mansura,Mansurah,Mansûra,almnswrt,mnswrh,mnswrt,المنصورة,منصورة,منصوره', 31.0363700, 31.3806900, 'EG', '2013-06-05', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41617, 'Al Manshāh', 'Al Manshah', 'Al Manshah,Al Manshāh,El Manshah,El Manshāh,Ptolemais Hernnon,Ptolemaîs Hernnon', 26.4768600, 31.8035000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41618, 'Al Maḩallah al Kubrá', 'Al Mahallah al Kubra', 'Al Mahallah al Kubra,Al Maḩallah al Kubrá,Al-Mahallah al-Kubra'',Al-Maḥallah al-Kubra’,El Mahalla,El Mahalla el Kubra,El Mehalla el Kubra,El-Mahalla el-Kubra,El-Maḥalla el-Kubra,Mahalla el Kubra,Mehalla el Kobra,almhlt alkbry,المحلة الكبرى', 30.9706300, 31.1669000, 'EG', '2014-06-05', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41619, 'Al Khārijah', 'Al Kharijah', 'Al Kharijah,Al Khārijah,Al-Kharga,El Kharga,El Khârga,El-Charge,Kharga,Kharga Oasis,UVL,alkharjt,الخارجة', 25.4514100, 30.5463500, 'EG', '2017-04-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41620, 'Al Khānkah', 'Al Khankah', 'Al Khankah,Al Khānkah,El-Khanka,El-Khankah,El-Khânka,El-Khânkâh,Khanka', 30.2103500, 31.3681200, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41621, 'Giza', 'Giza', 'Al Jizah,Al Jīzah,El Gizeh,El-Giza,El-Gîza,Ghizeh,Giza,Gizah,Gize,Gizeh,Gizo,Gizé,Guiza,Gíza,Gîza,SPX,aljyzt,giza,jyzh,Гиза,الجيزة,جیزه,ギーザ', 30.0080800, 31.2109300, 'EG', '2016-07-10', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41622, 'Al Jammālīyah', 'Al Jammaliyah', 'Al Jamaliyah,Al Jammaliyah,Al Jammālīyah,Al Jamālīyah,El-Gamaliya,El-Gamalîya,al-Jammaliyyah,al-Jammāliyyah,aljmalyt,الجمالية', 31.1806500, 31.8649700, 'EG', '2017-05-08', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41623, 'Ismailia', 'Ismailia', 'Al Isma`iliya,Al Isma`iliyah,Al Ismā‘īlīya,Al Ismā‘īlīyah,Al-Isma''iliyah,Al-Ismā’īlīyah,Gorad Ismailija,Ismailia,Ismailieh,Ismailija,Ismailiya,Ismailiyah,Ismailiye,Ismailía,Ismailîya,Ismayilia,Ismaília,Ismaïlia,Ismoiliya,Ismáílíja,Iszmailija,Iszmáilija,QIV,asmaʿylyh,iseumaillia,isma''iliya,ismailia,isumairia,xis me xi li xa,yi si mei li ya,İsmailiye,Ισμαηλία,Ісмаїлія,Горад Ісмаілія,Исмаилия,Исмаилија,Իսմայիլիա,איסמעיליה,اسماعيليه,اسماعیلیه,اسماعیلیہ,الإسماعيلية,مدينة الإسماعيلية,इस्माइलिया,อิสเมอิลีอา,ისმაილია,イスマイリア,伊斯梅利亚,이스마일리아', 30.6042700, 32.2722500, 'EG', '2014-05-12', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41624, 'Alexandria', 'Alexandria', 'ALY,Al Iskandariyah,Al Iskandarīyah,Alegsandiri,Alegsàndiri,Alehandriya,Aleixandria,Aleixandría,Alejandria,Alejandría,Aleksandria,Aleksandrii,Aleksandrij,Aleksandrija,Aleksandrio,Aleksandriya,Aleksandrje,Aleksandryjo,Alesandria dEgito,Alessandria,Alessandria d''Egitto,Alessandria dEggittu,Alessandria e Naggitto,Alexandreia,Alexandria,Alexandria Magna,Alexandrie,Alexandrië,Alexandría,Alexàndria,Ałesandria dEgito,Cathair Alastair,El Iskandariya,El Iskandarīya,Gorad Aleksandryja,Iskandariah,Iskandariya,Iskandariyah,Iskandri,Iskenderiye,Iskindiriya,Iskindirîya,Lisandria dEgittu,Lisàndria dEgittu,Ol''oksandrija,Taskendrit,alaksantriya,alaskndryt,alegjandriya,alekajandriya,alekcantiriya,alekjhandriya,aleksandria,aleksandriya,allegsandeulia,arekusandoria,askndryh,elekjhandriya,sikadari''a,sikandariya,xa lek san de riy,ya li shan da gang,ya li shan zhuo,yەskەndەryە,İsgəndəriyyə,İskenderiye,Αλεξάνδρεια,Александрий,Александрия,Александрија,Александрія,Горад Александрыя,Искандри,Искәндәриә,Ӧльӧксандрия,Ալեքսանդրիա,אלכסנדריה,אלעקסאנדריע,ئەسکەندەریە,اسكندريه,اسکندریه,اسکندریہ,الإسكندرية,ܐܠܟܣܢܕܪܝܐ,अलेक्झांड्रिया,सिकन्दरिया,আলেকজান্দ্রিয়া,আলেক্সান্ড্রিয়া,ਸਿਕੰਦਰੀਆ,એલેક્ઝાન્ડ્રિયા,அலெக்சாந்திரியா,అలెగ్జాండ్రియా,ಅಲೆಕ್ಸಾಂಡ್ರಿಯ,അലക്സാണ്ട്രിയ,อะเล็กซานเดรีย,ཡ་ལི་ཧྲན་ད,အလက်ဇန္ဒရီးယားမြို့,ალექსანდრია,እስክንድርያ,アレクサンドリア,亚历山大港,亞歷山卓,亞歷山大港,알렉산드리아', 31.2156400, 29.9552700, 'EG', '2015-11-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41625, 'Al Ibrāhīmīyah', 'Al Ibrahimiyah', 'Al Ibrahimiyah,Al Ibrāhīmīyah,El-Ibrahimiya,El-Ibrâhîmîya,Ibrahimiya,Ibrahimiyyah,Ibrâhîmîya,alabrahymyt,الإبراهيمية', 30.7187700, 31.5629900, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41626, 'Al Ḩawāmidīyah', 'Al Hawamidiyah', 'Al Hawamidiyah,Al Ḩawāmidīyah,El-Hawamdiya,El-Ḥawâmdîya,Hawamidyah', 29.9000000, 31.2500000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41627, 'Al Ḩāmūl', 'Al Hamul', 'Al Hamul,Al Ḩāmūl,El-Hamul,El-Ḥâmûl,alhamwl,الحامول', 31.3114600, 31.1476600, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41628, 'Hurghada', 'Hurghada', 'Al Ghardaqah,Al-Ghardaqa,Chournkanta,El-Ghardaqa,Gorad Khurgada,Gurdaka,HRG,Hurgada,Hurghada,Khurgada,Khurgade,Urgada,alghrdqh,alghrdqt,furugada,ghrdqh,hong jia da,huleugada,Χουργκάντα,Горад Хургада,Хургада,Хургаде,Հուրգադա,ערדקה,الغردقة,الغردقه,غردقه,غردقہ,ელ-გურდაკა,フルガダ,洪加達,후르가다', 27.2573800, 33.8129100, 'EG', '2014-07-15', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41629, 'Al Fayyūm', 'Al Fayyum', 'Al Fayyum,Al Fayyūm,Al''-Fajum,Al-Fayyum,Arsinoe,Arsinoë,Crocodilopolis,El Faiyum,El Faiyûm,El-Fayum,Faijum,Faium,Fajum,Fayoom,Fayoum,Fayum,Fayyoum,Fayyum,Madinat al-Fayyum,Madinet el Faiyum,Madīnet el Faiyūm,Medinat Fayum,Medinat el-Fayoum,Médinat el-Fayoum,Shedit,alfywm,astan fywm,mhafzt alfywm,Аль-Фаюм,استان فیوم,الفيوم,محافظة الفيوم', 29.3099500, 30.8418000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41630, 'Al Fashn', 'Al Fashn', 'Al Fashn,El Fashn,Fashn', 28.8243100, 30.8994800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41631, 'Al Bawīţī', 'Al Bawiti', 'Al Bawiti,Al Bawīţī,Baviti,Bawiti,Bawīti,El Bawiti,El Bawîti,albawyty,Бавити,الباويطى', 28.3491900, 28.8659100, 'EG', '2017-07-11', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41632, 'Al Balyanā', 'Al Balyana', 'Al Balyana,Al Balyanā,Balyana,El Balyana', 26.2356800, 32.0034700, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41633, 'Al Bājūr', 'Al Bajur', 'Al Bajur,Al Bājūr,El Baqur,El-Bagur,El-Bâgûr,albajwr,الباجور', 30.4302600, 31.0368100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41634, 'Al Badārī', 'Al Badari', 'Al Badari,Al Badārī,El Badari,El Badâri', 26.9925700, 31.4155400, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41635, 'Al ‘Ayyāţ', 'Al `Ayyat', 'Al `Ayyat,Al ‘Ayyāţ,Ayat,El `Ayyat,El ‘Ayyat,El-`Aiyat,El-‘Aiyaṭ', 29.6197200, 31.2575000, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41636, 'Arish', 'Arish', 'AAC,Al ''Arish,Al Arish,Al `Arish,Al ‘Arīsh,Al-''Arish,Al-Arisch,Al-Arish,Al-Arisz,Al-Arix,Al-‘Arīsh,Alarixe,Aris,Arisas,Arish,Arišas,Aríš,City of Cut Noses,Ehl''-Arish,El Aris,El Arish,El Ariŝ,El Ariş,El''-Arish,El-''Arish,El-Arich,El-‘Arîsh,Rhinocolorum,Rhinocolura,Rhinocorura,Rhinokorura,a li shen,alisi,arishu,el-arishi,Ариш,Ель-Аріш,Эль-Ариш,אל עריש,על אריש,العريش,عریش,ელ-არიში,アリーシュ,阿里什,아리시', 31.1315900, 33.7984400, 'EG', '2016-09-20', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41637, 'Al ‘Alamayn', 'Al `Alamayn', 'Al `Alamayn,Al ‘Alamayn,Al-Alamajn,Alamein,Alamejn,Ehl''-Alamejn,El Alamein,El Alamejn,El `Alamein,El ‘Alamein,El-Alamein,El-`Alamen,El-‘Alamên,a lai man,alʿlmyn,Аламейн,Ел Аламејн,Эль-Аламейн,العلمين,阿莱曼', 30.8300700, 28.9550200, 'EG', '2013-12-01', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41638, 'Akhmīm', 'Akhmim', 'Akhmim,Akhmun,Akhmûn,Akhmīm,Ekhmin,Khemmis,Paloupolis,Panopolis,Panospolis,Ахмим', 26.5621700, 31.7450300, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41639, 'Ajā', 'Aja', 'Aga,Aja,Ajā,aja,Айа,أجا', 30.9416200, 31.2903900, 'EG', '2013-07-06', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41640, 'Ad Dilinjāt', 'Ad Dilinjat', 'Ad Dilinjat,Ad Dilinjāt,Delingat,Ed Dilingat,Ed Dilingāt,El-Dilingat,El-Dilingât,Tayyibat al Ism,Ţayyibat al Ism', 30.8279100, 30.5363300, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41641, 'Abū Tīj', 'Abu Tij', 'Abu Tig,Abu Tij,Abu Tîg,Abū Tīj', 27.0441100, 31.3189700, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41642, 'Abu Simbel', 'Abu Simbel', 'ABS,Abou Simbel,Abu Simbel,Abu Simbil,Abu Sinbil,Abu Sumbul,Abu Sunbul,Abu-Simbel,Abū Sunbul,abw smbl,Абу-Симбел,أبو سمبل', 22.3457000, 31.6162400, 'EG', '2016-12-24', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41643, 'Abū Qurqāş', 'Abu Qurqas', 'Abu Gurgas,Abu Kerkae,Abu Kirkas,Abu Qurqas,Abu-Qirqas,Abū Qurqāş', 27.9312000, 30.8384100, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41644, 'Abū Kabīr', 'Abu Kabir', 'Abu Kabir,Abu Kebir,Abu Kebîr,Abu Kibir,Abū Kabīr,Abū Kibīr,Kafr Abu Kabir,Kafr Abu Kebir,Kafr Abu Kebîr,Kafr Abū Kabīr,abw kbyr,أبو كبير', 30.7250800, 31.6714800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41645, 'Abū al Maţāmīr', 'Abu al Matamir', 'Abu `elwet-Matamir,Abu al Matamir,Abu el Matamir,Abu el Matāmīr,Abû ‘elwet-Maṭâmîr,Abū al Maţāmīr', 30.9101800, 30.1743800, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41646, 'Abnūb', 'Abnub', 'Abnub,Abnūb', 27.2696000, 31.1510500, 'EG', '2012-01-19', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41647, 'Bi’r al ‘Abd', 'Bi''r al `Abd', 'Bi''r al `Abd,Bir al `Abd,Bir el-`Abd,Bi’r al ‘Abd,Bîr el-‘Abd,Bīr al ‘Abd,byr alʿbd,بئر العبد,بير العبد', 31.0188700, 33.0098000, 'EG', '2013-10-09', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41648, 'Az Zarqā', 'Az Zarqa', 'Az Zarqa,Az Zarqā,Az-Zarqa,Az-Zarqā,alzrqa,الزرقا', 31.2086400, 31.6352800, 'EG', '2013-07-07', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41649, 'El Gouna', 'El Gouna', 'Ehl''-Guna,aljwnt,Эль-Гуна,الجونة', 27.3941700, 33.6782500, 'EG', '2016-09-23', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41650, 'Makadi Bay', 'Makadi Bay', 'Makadi,Makadi Bay,Makady,Макади', 26.9912300, 33.8995200, 'EG', '2013-11-26', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41651, 'Ain Sukhna', 'Ain Sukhna', 'Ain El Sukhna,Ain Sukhna,Ajn-Sukhna,alʿyn alskhnt,Айн-Сухна,العين السخنة', 29.6001800, 32.3167100, 'EG', '2016-09-20', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41652, 'Beheira', 'Beheira', '', 30.5147800, 30.3435500, 'EG', '2011-08-03', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41653, 'Saint Catherine', 'Saint Catherine', 'SKV,Saint Catherine', 28.5619100, 33.9493400, 'EG', '2013-05-09', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41654, 'Munshāt ‘Alī Āghā', 'Munshat ''Ali Agha', 'Monshaat Ali Agha,Monshat ''Ali Agha,Monshāt ‘Alī Āghā,Munshah ''Ali Agha,Munshāh ‘Alī Āghā,mnshat ʿly agha,منشأة علي آغا', 31.1579100, 30.7017700, 'EG', '2017-07-10', 66);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41658, 'Teseney', 'Teseney', 'TES,Tehsehnehj,Tesene,Tesenei,Tessenei,Тэсэнэй', 15.1100000, 36.6575000, 'ER', '2013-06-07', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41659, 'Massawa', 'Massawa', 'MSW,Macua,Masaoua,Masava,Masawa,Massaoua,Massau,Massaua,Massava,Massawa,Massawah,Massowa,Massowah,Maçuá,Mesewa,Mits''iwa,Mitsewa,Mitsiwa''e,Mitsiwa’e,Mits’iwa,ma sa wa,masaua,masava,masawa,massawa,mʼsʼwwh,Μασάουα,Массава,Массауа,מאסאווה,מאסאווע,مصوع,मासावा,მასაუა,ምጽዋ,ምጽዋዕ,マッサワ,马萨瓦,마사와', 15.6081100, 39.4745500, 'ER', '2012-08-05', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41660, 'Keren', 'Keren', 'Cheren,Hamelmalo,Kehrehn,Keren,Kerenas,Kereno,ke lun,kelen,keren,krn,kyryn  artrya,qrn,Κερέν,Керен,Кэрэн,קרן,كرن,کرن,کیرین، ارتریا,კერენი,ከረን,ケレン,克伦,케렌', 15.7779200, 38.4510700, 'ER', '2012-09-11', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41661, 'Edd', 'Edd', 'Adi,Ed,Edd,Eid,`Idi,Ēd,‘Idī', 13.9308800, 41.6938000, 'ER', '2012-08-05', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41662, 'Dek’emhāre', 'Dek''emhare', 'Decamere,Dek''emhare,Dekamere,Dekemehare,Dekemehre,Dek’emhāre,ደቀምሓረ', 15.0700000, 39.0475000, 'ER', '2012-09-06', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41663, 'Barentu', 'Barentu', 'Barehntu,Barentu,Mai Tsada,Барэнту,ባረንቱ', 15.1058200, 37.5906700, 'ER', '2012-09-06', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41664, 'Asmara', 'Asmara', 'ASM,Asmar,Asmara,Asmaro,Asmehra,Asmera,Aszmara,Gorad Asmara,a si ma la,asamara,aseumala,asmara,asmera,asmrh,asmrt,asumara,yەsmەrە,Əsməra,Ασμάρα,Асмара,Асмэра,Асмєра,Горад Асмара,Ասմարա,אסמרה,أسمرة,ئەسمەرە,اسمارا,اسمره,अस्मारा,ਅਸਮਾਰਾ,அஸ்மாரா,അസ്മാറ,แอสมารา,ཨཱ་སི་མི་ར།,ასმერა,አስመራ,ኣስመራ,アスマラ,阿斯馬拉,아스마라', 15.3380500, 38.9318400, 'ER', '2013-01-11', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41665, 'Assab', 'Assab', 'ASA,Aseb,Assab,Baia di Assab,`Aseb,a sa bu,عصب,ዓስብ,‘Aseb,阿萨布', 13.0091700, 42.7394400, 'ER', '2012-01-19', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41666, 'Ak’ordat', 'Ak''ordat', 'Agordat,Ak'' Wirdet,Ak''irdat,Ak''ordat,Ak''urdet,Ak’ordat,Figordat,Āk’ Wirdet,Āk’irdat,Āk’urdet,ኣቁርደት,ኣቆርዳት', 15.5479800, 37.8829100, 'ER', '2012-09-06', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41667, 'Mendefera', 'Mendefera', 'Addi Ugri,Adi Ugri,Mehndehfehra,Mendefera,`Adi Wegri,Ādī Ugrī,Мэндэфэра,መንደፈራ,‘Adī Wegrī', 14.8872200, 38.8152800, 'ER', '2012-01-19', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41668, 'Adi Keyh', 'Adi Keyh', 'Addi Caieh,Addi Kaye,Addicaie,Addicaiè,Adi Caieh,Adi K''eyih,Adi Keih,Adi Keyeh,Adi Keyh,Ādī K’eyih', 14.8444400, 39.3772200, 'ER', '2013-06-07', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41669, 'Mai-Mne', 'Mai-Mne', '', 14.5543800, 38.5029200, 'ER', '2015-03-01', 69);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41670, 'Zurgena', 'Zurgena', '', 37.3421800, -2.0398500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41671, 'Zújar', 'Zujar', 'Zujar,Zújar', 37.5428500, -2.8419700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41672, 'Zuheros', 'Zuheros', 'Zuheres,Zuhéres', 37.5433200, -4.3153100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41673, 'Zufre', 'Zufre', 'Zufre', 37.8333300, -6.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41674, 'Zubia', 'Zubia', 'La Zubia,Zubia', 37.1190600, -3.5840000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41675, 'Zorita', 'Zorita', 'Sorita,Zorita,suo li ta,zwryta,Сорита,Соріта,زوريتا,索里塔', 39.2852200, -5.6997300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41676, 'Zarza la Mayor', 'Zarza la Mayor', 'Zarza la Mayor', 39.8769200, -6.8621100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41677, 'Zarza de Montánchez', 'Zarza de Montanchez', 'Zarza,Zarza de Montanchez,Zarza de Montánchez', 39.2575600, -6.0324800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41678, 'Zarza de Alange', 'Zarza de Alange', 'Zarza,Zarza de Alange,Zarza de San Alanje,Zarza de junto Alange,Zarza junto Alange', 38.8181400, -6.2175600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41679, 'Zarra', 'Zarra', 'Zarra', 39.0917500, -1.0753200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41680, 'Zalamea la Real', 'Zalamea la Real', 'Zalamea,Zalamea la Real', 37.6801200, -6.6597700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41681, 'Zalamea de la Serena', 'Zalamea de la Serena', 'Zalamea de la Serena', 38.6513100, -5.6606300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41682, 'Zahinos', 'Zahinos', 'Zahinos,Zahínos', 38.3313500, -6.9553300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41683, 'Zahara de los Atunes', 'Zahara de los Atunes', 'Saara-de-los-Atunes,Zahara,Zahara de los Atunes,Саара-де-лос-Атунес', 36.1369000, -5.8459100, 'ES', '2015-09-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41684, 'Zahara', 'Zahara', '', 36.8405500, -5.3912800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41685, 'Zagra', 'Zagra', '', 37.2556100, -4.1690500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41686, 'Zafra de Záncara', 'Zafra de Zancara', 'Zafra de Zancara,Zafra de Záncara', 39.8920300, -2.5578600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41687, 'Zafra', 'Zafra', 'Cafra,Safra,Zafra,sa fu la,safura,Çafra,Зафра,Сафра,صفراء، بطليوس,サフラ,萨夫拉', 38.4166700, -6.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41688, 'Zafarraya', 'Zafarraya', '', 36.9755400, -4.1444200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41689, 'Yunquera', 'Yunquera', 'Yunquera', 36.7325200, -4.9212200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41690, 'Yeste', 'Yeste', 'Este,Yeste,Zoste,ysth,ysty,Єсте,Есте,يستي,یسته', 38.3685200, -2.3175600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41691, 'Yepes', 'Yepes', 'Epes,Yepes,ye pei si,yybys,Єпес,Епес,ييبيس,耶佩斯', 39.9019900, -3.6251700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41692, 'Yémeda', 'Yemeda', 'Yemeda,Yémeda', 39.7666700, -1.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41693, 'Yecla', 'Yecla', 'Ekla,Iecla,Yecla,ye ke la,ykla  mrsyt,Єкла,Екла,يكلا، مرسية,耶克拉', 38.6136500, -1.1146800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41694, 'Yátova', 'Yatova', 'Iatova,Iàtova,Yatova,Yátova', 39.3833300, -0.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41695, 'Yaiza', 'Yaiza', 'Yaiza', 28.9567800, -13.7653500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41696, 'Víznar', 'Viznar', '', 37.2314900, -3.5538200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41697, 'Viveros', 'Viveros', 'Viveros', 38.7726000, -2.5744900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41698, 'Viver', 'Viver', 'Vivel,Viver,bi wei er,fayfar,Вивер,Вівер,فايفار,比韦尔', 39.9166700, -0.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41699, 'Viso del Marqués', 'Viso del Marques', 'El Viso del Marques,El Viso del Marqués,Viso del Marques,Viso del Marqués', 38.5220800, -3.5634800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41700, 'Viñuela', 'Vinuela', '', 36.8630700, -4.1412400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41701, 'Vinalesa', 'Vinalesa', 'Vinalesa', 39.5333300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41702, 'Villena', 'Villena', 'Vil''ena,Villena,Вильена', 38.6373000, -0.8656800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41703, 'Villavieja', 'Villavieja', 'La Vila Vella,Villavieja', 39.8500000, -0.1833300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41704, 'Villaviciosa de Córdoba', 'Villaviciosa de Cordoba', 'Villaviciosa,Villaviciosa de Cordoba,Villaviciosa de Córdoba', 38.0833300, -5.0166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41705, 'Villaverde y Pasaconsol', 'Villaverde y Pasaconsol', 'Villaverde y Pasaconsol', 39.7709900, -2.2655200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41706, 'Villaverde del Río', 'Villaverde del Rio', 'Villaverde del Rio,Villaverde del Río', 37.5891900, -5.8744300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41707, 'Villaverde de Guadalimar', 'Villaverde de Guadalimar', 'Villaverde de Guadalimar', 38.4552500, -2.5178200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41708, 'Villavaliente', 'Villavaliente', 'Villavaliente', 39.1264600, -1.4571200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41709, 'Villatoya', 'Villatoya', '', 39.3333300, -1.3000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41710, 'Villatobas', 'Villatobas', 'Villatobas', 39.9018700, -3.3238600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41711, 'Villasequilla de Yepes', 'Villasequilla de Yepes', 'Villasequilla,Villasequilla de Yepes', 39.8758200, -3.7311000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41712, 'Villaseca de la Sagra', 'Villaseca de la Sagra', 'Villaseca,Villaseca de la Sagra', 39.9618500, -3.8829100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41713, 'Villarta de San Juan', 'Villarta de San Juan', 'Villarta de San Juan', 39.2378500, -3.4233300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41714, 'Villarta de los Montes', 'Villarta de los Montes', 'Villarta de los Montes', 39.2138600, -4.7922700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41715, 'Villarta', 'Villarta', 'Villarta', 39.4500000, -1.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41716, 'Villarrubio', 'Villarrubio', 'Villarrubio', 39.9451100, -2.8943100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41717, 'Villarrubia de Santiago', 'Villarrubia de Santiago', 'Villarrubia de Santiago', 39.9855500, -3.3689800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41718, 'Villarrubia de los Ojos', 'Villarrubia de los Ojos', 'Villarrubia de los Ojos,Villarrubia los Ojos', 39.2208500, -3.6080200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41719, 'Villarrubia', 'Villarrubia', 'Villariba,Villarrubia,Виллариба', 37.8500000, -4.9000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41720, 'Villarrobledo', 'Villarrobledo', 'Billarrobledo,Vil''jarrobledo,Villa Robletum,Villarrobledo,biryaroburedo,Βιλλαρροβλέδο,Вильярробледо,ビリャロブレド', 39.2699200, -2.6011900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41721, 'Villarrasa', 'Villarrasa', 'Villarrasa', 37.3884900, -6.6064100, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41722, 'Villargordo del Cabriel', 'Villargordo del Cabriel', 'Villagordo,Villargordo,Villargordo del Cabriel', 39.5333300, -1.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41723, 'Villares del Saz', 'Villares del Saz', 'Villares del Saz', 39.8410900, -2.5042700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41724, 'Villarejo-Periesteban', 'Villarejo-Periesteban', 'Villarejo-Periesteban', 39.8723100, -2.4414500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41725, 'Villarejo de Montalbán', 'Villarejo de Montalban', 'Villarejo de Montalban,Villarejo de Montalbán', 39.7691300, -4.5731400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41726, 'Villarejo de Fuentes', 'Villarejo de Fuentes', '', 39.7880900, -2.6968000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41727, 'Vila-real', 'Vila-real', 'Vila-Real,Vila-real,Villareal,Villarreal,Вила-Реал', 39.9383000, -0.1008700, 'ES', '2016-01-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41728, 'Villardompardo', 'Villardompardo', 'Villardompardo', 37.8373500, -4.0005100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41729, 'Villar de Rena', 'Villar de Rena', '', 39.0765100, -5.8107400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41730, 'Villar del Rey', 'Villar del Rey', 'Villar del Rey', 39.1331000, -6.8476200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41731, 'Villar del Pozo', 'Villar del Pozo', 'Villar del Pozo', 38.8501000, -3.9640500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41732, 'Villar del Pedroso', 'Villar del Pedroso', 'Villar del Pedroso', 39.7063100, -5.1958300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41733, 'Villar del Humo', 'Villar del Humo', 'Villar del Humo', 39.8666700, -1.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41734, 'Villar del Arzobispo', 'Villar del Arzobispo', 'El Villar,Villar del Arzobispo,Villora del Arzobispo', 39.7333300, -0.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41735, 'Villar de la Encina', 'Villar de la Encina', 'Villar de la Encima,Villar de la Encina', 39.6372500, -2.5215500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41736, 'Villar de Cañas', 'Villar de Canas', '', 39.7786000, -2.5642800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41737, 'Villaralto', 'Villaralto', 'Vil''jaral''to,Villaralto,bi li ya la er tuo,fylaraltw,Вильяральто,Вільяральто,فيلارالتو,比利亚拉尔托', 38.4500000, -4.9833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41738, 'Villapalacios', 'Villapalacios', 'Villapalacios', 38.5750000, -2.6338400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41739, 'Villanueva de Tapia', 'Villanueva de Tapia', 'Villanueva de Tapia', 37.1827600, -4.3338300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41740, 'Villanueva de San Juan', 'Villanueva de San Juan', 'Villanueva de San Juan', 37.0495500, -5.1754000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41741, 'Villanueva de San Carlos', 'Villanueva de San Carlos', 'Villanueva de San Carlos', 38.6217300, -3.9090300, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41742, 'Villanueva de Mesía', 'Villanueva de Mesia', 'Villanueva de Mesias,Villanueva de Mesías', 37.2145400, -4.0140400, 'ES', '2012-07-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41743, 'Villanueva del Trabuco', 'Villanueva del Trabuco', '', 37.0283200, -4.3389100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41744, 'Villanueva del Rosario', 'Villanueva del Rosario', 'Vil''januehva-del''-Rosario,Vil''janueva-del''-Rosario,Vilyanueva del Rosario,fyanwyfa dyl rwsaryw,luo sa li ao xin zhen,Вильянуэва-дель-Росарио,Вільянуева-дель-Росаріо,Վիլյանուևա դել Ռոսարիո,فيانويفا ديل روساريو,罗萨里奥新镇', 36.9967900, -4.3653500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41745, 'Villanueva del Río y Minas', 'Villanueva del Rio y Minas', 'Minas de la Reunion,Villanueva de las Minas,Villanueva del Rio y Minas,Villanueva del Río y Minas', 37.6550200, -5.7136900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41746, 'Villanueva de los Castillejos', 'Villanueva de los Castillejos', 'Villanueva de los Castillejos', 37.4994000, -7.2911800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41747, 'Villanueva del Fresno', 'Villanueva del Fresno', 'Villanueva del Fresno', 38.3760000, -7.1675300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41748, 'Villanueva del Duque', 'Villanueva del Duque', 'Villanueva del Duque', 38.3833300, -5.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41749, 'Villanueva de las Torres', 'Villanueva de las Torres', 'Villanueva de las Torres', 37.5571900, -3.0886800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41750, 'Villanueva de la Serena', 'Villanueva de la Serena', 'Vil''januehva-de-la-Serena,Vil''janueva-de-la-Serena,Villanueva de la Serena,Villanueva la Serena,fylanywfa dy la syryna,sai lei na xin zhen,Вильянуэва-де-ла-Серена,Вільянуева-де-ла-Серена,فيلانيوفا دي لا سيرينا,ビジャヌエバ・デ・ラ・セレーナ,塞雷纳新镇', 38.9765500, -5.7974000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41751, 'Villanueva de las Cruces', 'Villanueva de las Cruces', 'Villanueva de las Cruces', 37.6278300, -7.0235900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41752, 'Villanueva del Arzobispo', 'Villanueva del Arzobispo', 'Villanueva del Arzobispo', 38.1684200, -3.0074200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41753, 'Villanueva del Ariscal', 'Villanueva del Ariscal', 'Villanueva del Ariscal', 37.3962300, -6.1407700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41754, 'Villanueva de la Reina', 'Villanueva de la Reina', 'Villanueva de la Reina', 38.0043200, -3.9160300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41755, 'Villanueva de la Jara', 'Villanueva de la Jara', 'Vil''januehva-de-la-Khara,Vil''janueva-de-la-Khara,Villanueva de la Jara,fylanywfa dy la khara,ha la xin zhen,Вильянуэва-де-ла-Хара,Вільянуева-де-ла-Хара,فيلانيوفا دي لا خارا,哈拉新镇', 39.4333300, -1.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41756, 'Villanueva de la Fuente', 'Villanueva de la Fuente', 'Villanueva de la Fuente', 38.6946300, -2.6963700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41757, 'Villanueva de Córdoba', 'Villanueva de Cordoba', 'Villanueva de Cordoba,Villanueva de Cordova,Villanueva de Córdoba,Villanueva de Córdova', 38.3227700, -4.6287300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41758, 'Villanueva de Castellón', 'Villanueva de Castellon', 'Castello de la Ribera,Castelló de la Ribera,Villanueva de Castellan,Villanueva de Castellon,Villanueva de Castellán,Villanueva de Castellón', 39.0774100, -0.5116700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41759, 'Villanueva de Bogas', 'Villanueva de Bogas', 'Villanueva de Bogas', 39.7234700, -3.6574300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41760, 'Villanueva de Algaidas', 'Villanueva de Algaidas', '', 37.1835000, -4.4503200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41761, 'Villanueva de Alcardete', 'Villanueva de Alcardete', 'Villanueva de Alcardete,Villanueva del Cardete', 39.6732100, -3.0144500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41762, 'Villamuelas', 'Villamuelas', 'Villamuelas', 39.8178400, -3.7346100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41763, 'Villaminaya', 'Villaminaya', 'Villaminaya', 39.7119700, -3.8705500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41764, 'Villamiel de Toledo', 'Villamiel de Toledo', 'Villamiel de Toledo', 39.9648200, -4.1262700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41765, 'Villamesías', 'Villamesias', 'Villamesias,Villamesías', 39.2456800, -5.8730700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41766, 'Villamayor de Santiago', 'Villamayor de Santiago', 'Villamayor de Santiago', 39.7307200, -2.9235700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41767, 'Villamayor de Calatrava', 'Villamayor de Calatrava', 'Villamayor de Calatrava', 38.7876300, -4.1377400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41768, 'Villamartín', 'Villamartin', 'Villamartin,Villamartín', 36.8597900, -5.6448500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41769, 'Vilamarxant', 'Vilamarxant', 'Vilamarxant,Villamarchante', 39.5691600, -0.6245300, 'ES', '2015-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41770, 'Villamanrique de la Condesa', 'Villamanrique de la Condesa', 'Villamanrique,Villamanrique de la Condesa', 37.2448100, -6.3066500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41771, 'Villamanrique', 'Villamanrique', 'Villamanrique', 38.5463600, -2.9972900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41772, 'Villamalur', 'Villamalur', 'Vil''jamalur,Vilamalur,Villamalur,Villamaluz,bi li ya ma lu er,fylamalwr,Вильямалур,Вільямалур,فيلامالور,比利亚马卢尔', 39.9666700, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41773, 'Villamalea', 'Villamalea', 'Villamalea', 39.3666700, -1.5833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41774, 'Villaluenga del Rosario', 'Villaluenga del Rosario', 'Villaluenga del Rosario', 36.6964400, -5.3860100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41775, 'Villalpardo', 'Villalpardo', 'Villalpardo', 39.4666700, -1.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41776, 'Villalonga', 'Villalonga', 'Vilallonga,Villalonga', 38.8856600, -0.2079500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41777, 'Villalgordo del Marquesado', 'Villalgordo del Marquesado', 'Villalgordo del Marquesado', 39.6824500, -2.5088500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41778, 'Villalba de los Barros', 'Villalba de los Barros', 'Villalba de los Barros', 38.6129400, -6.5091400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41779, 'Villalba del Alcor', 'Villalba del Alcor', 'Villalba del Alcor', 37.3973100, -6.4746100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41780, 'Villajoyosa', 'Villajoyosa', 'La Vila Joiosa,Villajoyosa', 38.5075400, -0.2334600, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41781, 'Villahermosa', 'Villahermosa', 'Villahermosa', 38.7502300, -2.8706600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41782, 'Villaharta', 'Villaharta', 'Villaharta', 38.1333300, -4.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41783, 'Villagonzalo', 'Villagonzalo', 'Villagonzalo', 38.8632900, -6.1966500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41784, 'Villagarcía del Llano', 'Villagarcia del Llano', 'Villagarcia,Villagarcia del Llano,Villagarcía,Villagarcía del Llano', 39.3166700, -1.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41785, 'Villagarcía de la Torre', 'Villagarcia de la Torre', 'Villagarcia,Villagarcia de la Torre,Villagarcía de la Torre', 38.3000000, -6.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41786, 'Villafranca de los Caballeros', 'Villafranca de los Caballeros', '', 39.4282400, -3.3607900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41787, 'Villafranca de los Barros', 'Villafranca de los Barros', 'Villafranca de los Barros', 38.5614400, -6.3381000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41788, 'Villafranca de Córdoba', 'Villafranca de Cordoba', 'Villafranca de Cordoba,Villafranca de Córdoba', 37.9625700, -4.5454700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41789, 'Vilafranca de Bonany', 'Vilafranca de Bonany', 'Vilafranca de Bonany,Villafranca', 39.5689400, 3.0881500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41790, 'Villa de Ves', 'Villa de Ves', 'Villa de Ves', 39.2000000, -1.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41791, 'Villa del Río', 'Villa del Rio', 'Villa del Rio,Villa del Río', 37.9810800, -4.2900300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41792, 'Villa del Rey', 'Villa del Rey', 'Villa del Rey', 39.6595500, -6.8212200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41793, 'Villa de Don Fadrique', 'Villa de Don Fadrique', 'La Villa de Don Fadrique,Villa de Don Fabrique,Villa de Don Fadrique', 39.6150500, -3.2191500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41794, 'Villacarrillo', 'Villacarrillo', 'Vil''jakarril''jo,Vil''jakarril''o,Villacarillo,Villacarrillo,bi li ya ka li e,byyakaryyw,fyakaryw,Вильякаррильо,Вільякаррільйо,بییاکارییو,فياكاريو,比利亚卡里略', 38.1156000, -3.0848000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41795, 'Es Castell', 'Es Castell', 'Es Castell,Vilacarlos,Villacarlos', 39.8776000, 4.2899000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41796, 'Villacañas', 'Villacanas', '', 39.6236700, -3.3381300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41797, 'Villablanca', 'Villablanca', 'Villablanca', 37.3023900, -7.3441300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41798, 'Vilches', 'Vilches', 'Vil''ches,Vilches,bi er qie si,bylchs,fyltshys,Вильчес,Вільчес,Վիլչես,بیلچس,فيلتشيس,比尔切斯', 38.2069500, -3.5102500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41799, 'Vilaflor', 'Vilaflor', 'Vilaflor,Villaflor', 28.1562300, -16.6359200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41800, 'Vícar', 'Vicar', 'Vikar,bi ka er,bykar,Викар,Вікар,بيكار,بیکار,比卡尔', 36.8315500, -2.6427300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41801, 'Viator', 'Viator', '', 36.8900600, -2.4269500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41802, 'Vergel', 'Vergel', 'El Verger,Vergel', 38.8470900, 0.0103400, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41803, 'Vera', 'Vera', '', 37.2434500, -1.8590500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41804, 'Ventas de Huelma', 'Ventas de Huelma', 'Ventas de Huelma', 37.0684000, -3.8198300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41805, 'Ventas con Peña Aguilera', 'Ventas con Pena Aguilera', 'Ventas con Pena Aguilera,Ventas con Peña Aguilera', 39.6103300, -4.2312800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41806, 'Venta del Moro', 'Venta del Moro', 'Venta del Moro', 39.4833300, -1.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41807, 'Velez Rubio', 'Velez Rubio', 'Velez Rubio,Velez-Rubio,Vélez Rubio,Vélez-Rubio', 37.6484400, -2.0768600, 'ES', '2012-08-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41808, 'Vélez-Málaga', 'Velez-Malaga', 'Beleth-Malaga,Veles Malaga,Veles-Malaga,Velez-Malaga,Vélez-Màlaga,Vélez-Málaga,bei lai si-ma la jia,beresu=maraga,fylyth-malqt,Μπέλεθ-Μάλαγα,Вeлес-Мaлага,Велез-Малага,Велес-Малага,Վելես Մալագա,فيليث-مالقة,ベレス＝マラガ,贝莱斯-马拉加', 36.7810700, -4.1026600, 'ES', '2015-10-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41809, 'Vélez de Benaudalla', 'Velez de Benaudalla', 'Velez Benahudalla,Velez Benandalla,Velez de Benaudalla,Velez de Benaudilla,Vélez Benandalla,Vélez de Benaudalla', 36.8324400, -3.5153900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41810, 'Vélez-Blanco', 'Velez-Blanco', 'Velez-Blanco,Vélez-Blanco', 37.6917800, -2.0958700, 'ES', '2015-01-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41811, 'Velefique', 'Velefique', 'Velefique', 37.1940700, -2.4015500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41812, 'Velada', 'Velada', 'Velada', 39.9768700, -4.9764100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41813, 'Vejer de la Frontera', 'Vejer de la Frontera', 'Vejer de la Frontera,Vekher-de-la-Frontera,bei he er de la fu long te la,fykhyr dy la frwntyra,Вехер-де-ла-Фронтера,فيخير دي لا فرونتيرا,ベヘール・デ・ラ・フロンテーラ,贝赫尔德拉夫龙特拉', 36.2445600, -5.9695300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41814, 'Vega de San Mateo', 'Vega de San Mateo', 'San Mateo,Vega de San Mateo', 28.0089200, -15.5333000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41815, 'Vara de Rey', 'Vara de Rey', 'Vara de Rey', 39.4259500, -2.2940400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41816, 'Valverdejo', 'Valverdejo', 'Valverdejo', 39.6166700, -2.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41817, 'Valverde de Mérida', 'Valverde de Merida', 'Valverde de Merida,Valverde de Mérida', 38.9112200, -6.2199900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41818, 'Valverde de Llerena', 'Valverde de Llerena', 'Valverde de Llerena', 38.2166700, -5.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41819, 'Valverde de Leganés', 'Valverde de Leganes', 'Valverde de Leganes,Valverde de Leganés', 38.6705900, -6.9803600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41820, 'Valverde del Camino', 'Valverde del Camino', 'Valverde del Camino', 37.5751100, -6.7543200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41821, 'Valverde de Júcar', 'Valverde de Jucar', 'Valverde de Jucar,Valverde de Júcar,Valverde del Jucar,Valverde del Júcar', 39.7186600, -2.2213500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41822, 'Valverde de Burguillos', 'Valverde de Burguillos', 'Valverde de Burguillos', 38.3271000, -6.5364800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41823, 'Valverde', 'Valverde', 'VDE,Val''verde,Вальверде', 27.8062800, -17.9157800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41824, 'Valsequillo de Gran Canaria', 'Valsequillo de Gran Canaria', 'Valsequillo,Valsequillo de Gran Canaria', 27.9856200, -15.4972500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41825, 'Válor', 'Valor', '', 36.9961800, -3.0828700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41826, 'Valleseco', 'Valleseco', 'Valleseco', 28.0433000, -15.5762300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41827, 'Vallés', 'Valles', 'Valles,Vallès,Vallés', 38.9851800, -0.5569600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41828, 'Vallehermosa', 'Vallehermosa', 'Vallehermosa,Vallehermoso', 28.1794400, -17.2666400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41829, 'Valle de Santa Ana', 'Valle de Santa Ana', 'Valle de Santa Ana', 38.3663700, -6.7886000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41830, 'Valle de Matamoros', 'Valle de Matamoros', 'Valle de Matamoros', 38.3788900, -6.8037100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41831, 'Valle de la Serena', 'Valle de la Serena', 'Valle de la Serena', 38.7101000, -5.7984700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41832, 'Valldemossa', 'Valldemossa', 'Valldemosa,Valldemossa,fa de mo sa,法德摩薩', 39.7104200, 2.6223000, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41833, 'Vall de Ebo', 'Vall de Ebo', 'Vall d''Ebo,Vall de Ebo', 38.8056100, -0.1589000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41834, 'Vall de Almonacid', 'Vall de Almonacid', 'La Vall d''Almonesir,Vall de Almonacid', 39.9000000, -0.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41835, 'Vallada', 'Vallada', 'Vallada', 38.8957500, -0.6910400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41836, 'Valhermoso de la Fuente', 'Valhermoso de la Fuente', 'Valhermoso,Valhermoso de la Fuente', 39.5666700, -2.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41837, 'Valenzuela de Calatrava', 'Valenzuela de Calatrava', 'Valenzuela de Calatrava', 38.8525400, -3.7721000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41838, 'Valenzuela', 'Valenzuela', '', 37.7756000, -4.2203800, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41839, 'Valencina de la Concepción', 'Valencina de la Concepcion', 'Valencina,Valencina de la Concepcion,Valencina de la Concepción,Valencina del Alcor', 37.4161800, -6.0742200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41840, 'Valencia del Ventoso', 'Valencia del Ventoso', 'Valencia de Ventoso,Valencia del Barrial,Valencia del Mentoso,Valencia del Ventoso', 38.2666700, -6.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41841, 'Valencia del Mombuey', 'Valencia del Mombuey', 'Valencia del Mombuey,Valencita', 38.2424300, -7.1196500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41842, 'Valencia de las Torres', 'Valencia de las Torres', 'Valencia de las Torres', 38.4051800, -6.0040300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41843, 'Valencia de Alcántara', 'Valencia de Alcantara', 'Valencia dAlcantara,Valencia dAlcántara,Valencia de Alcantara,Valencia de Alcántara,Valencia del Alcantara,Valensija-de-Al''kantara,Valência de Alcântara,ba lun xi ya de ya er kan ta la,falnsya dy alkntara,Валенсия-де-Алькантара,Валенсія-де-Алькантара,فالنسيا دي الكنتارا,巴伦西亚德亚尔坎塔拉', 39.4114800, -7.2443500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41844, 'Valencia', 'Valencia', 'Balenzia,Gorad Valensija,Pa-lun-si-a,Pâ-lùn-sî-â,VLC,Valantsa,Valence,Valencia,Valencia - Valencia,Valencia - València,Valencie,Valencija,Valencio,Valenseje,Valensi,Valensia,Valensii,Valensij,Valensija,Valensiya,Valensyaa,Valensėjė,Valenthia,Valentia,Valentzia,Valenza,València,Valéncia,Valência,Vałénsia,Walencja,Walensiye,Walénsiye,ba len seiy,ba lun xi ya,ballensia,barenshia,blnsyt,hua lun xi ya,valainsi''a,valenciya,valensia,valensiya,valynsya,wa lun xi ya,walnsya,wlnsyh,wylnsya,Βαλένθια,Валенси,Валенсиа,Валенсий,Валенсия,Валенсија,Валенсія,Горад Валенсія,Վալենսիա,וואלענציע,ולנסיה,بلنسية,والنسیا,ویلنسیا,ویلنسیہ,ڤالينسيا,ڤالێنسیا,वालेन्सिया,ਵਾਲੈਂਸੀਆ,வாலேன்சியா,บาเลนเซีย,ვალენსია,バレンシア,巴倫西亞,瓦伦西亚,瓦倫西亞,華倫西亞,발렌시아', 39.4697500, -0.3773900, 'ES', '2015-12-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41845, 'Valdeverdeja', 'Valdeverdeja', 'Valdeverdeja,Valdeverja,Valle la Verja,Valverdeja', 39.7963500, -5.2454400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41846, 'Valdetorres', 'Valdetorres', 'Valdetorres', 38.9154200, -6.0676500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41847, 'Valdés', 'Valdes', '', 36.7583500, -4.2423500, 'ES', '2016-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41848, 'Valderrubio', 'Valderrubio', 'Valderrubio', 37.2337800, -3.8200500, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41849, 'Valdepeñas de Jaén', 'Valdepenas de Jaen', 'Valdepenas,Valdepenas de Jaen,Valdepeñas,Valdepeñas de Jaén', 37.5890300, -3.8145000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41850, 'Valdepeñas', 'Valdepenas', 'Val''depen''jase,Valdepenas,Valdepeñas,Yaldepenas,Вальдепеньясе', 38.7621100, -3.3848300, 'ES', '2013-11-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41851, 'Valdemorales', 'Valdemorales', 'Valdemorales', 39.2058800, -6.0662200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41852, 'Valdemanco del Esteras', 'Valdemanco del Esteras', 'Valdemanco del Esteras', 38.9385800, -4.8292000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41853, 'Valdelarco', 'Valdelarco', 'Valdelarco', 37.9487700, -6.6820200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41854, 'Valdelacasa de Tajo', 'Valdelacasa de Tajo', 'Valdelacasa de Tajo', 39.7258800, -5.2829600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41855, 'Valdehúncar', 'Valdehuncar', 'Valdehuncar,Valdehúncar', 39.8365900, -5.5230700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41856, 'Valdeganga', 'Valdeganga', 'Valdeganga', 39.1351400, -1.6770300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41857, 'Valdefuentes', 'Valdefuentes', 'Valdefuentes', 39.2743300, -6.1218300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41858, 'Valdecañas de Tajo', 'Valdecanas de Tajo', 'Valdecanas de Tajo,Valdecañas de Tajo', 39.7591900, -5.6195100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41859, 'Valdecaballeros', 'Valdecaballeros', 'Valdecaballero,Valdecaballeros', 39.2428900, -5.1900000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41860, 'Utrera', 'Utrera', 'Utrera,Утрера', 37.1851600, -5.7809300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41861, 'Utiel', 'Utiel', 'Ut''el'',Utiel,wu tie er,Утьель,Утьєль,乌铁尔', 39.5666700, -1.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41862, 'Usagre', 'Usagre', 'Usagre', 38.3500000, -6.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41863, 'Urrácal', 'Urracal', 'Urracal', 37.3974000, -2.3648500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41864, 'Urda', 'Urda', 'Urda', 39.4117900, -3.7149300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41865, 'Umbrete', 'Umbrete', 'Umbrete,wen fu lei te,Умбрете,温夫雷特', 37.3688100, -6.1584700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41866, 'Uleila del Campo', 'Uleila del Campo', 'Uleila,Uleila de Campo,Uleila del Campo', 37.1846000, -2.2049100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41867, 'Ulea', 'Ulea', 'Ulea', 38.1404500, -1.3300700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41868, 'Ugíjar', 'Ugijar', '', 36.9608700, -3.0552300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41869, 'Uclés', 'Ucles', 'Ucles,Uclès,Uclés,Ukles,aqlysh,ukuresu,wu ke lai si,Уклес,أقليش,ウクレス,乌克莱斯', 39.9793800, -2.8614300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41870, 'Ubrique', 'Ubrique', 'Ubrique', 36.6777700, -5.4460000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41871, 'Úbeda', 'Ubeda', 'Ubeda,abdt,awbda,ubeda,wu wei da,Úbeda,Убеда,أبدة,اوبدا,უბედა,ウベダ,乌韦达,우베다', 38.0132800, -3.3705000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41872, 'Turrillas', 'Turrillas', 'Turrillas', 37.0294800, -2.2660700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41873, 'Turre', 'Turre', 'Ture,Turre,tu lei,twrh,twrry,Туре,Турре,Տուռե,تورري,توره,图雷', 37.1522400, -1.8949700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41874, 'Turleque', 'Turleque', 'Torleque,Turleque', 39.6013800, -3.6140400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41875, 'Turís', 'Turis', 'Toris,Torís,Turis,Turís', 39.3833300, -0.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41876, 'Tuineje', 'Tuineje', 'Tuineje', 28.3237200, -14.0472200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41877, 'Tuéjar', 'Tuejar', 'Toixa,Tuehkhar,Tueixa,Tuejar,Tuekhar,Tuéjar,tu ai ha er,Туехар,Туэхар,图埃哈尔', 39.7666700, -1.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41878, 'Trujillo', 'Trujillo', 'Trujillo,toruhiryo,トルヒーリョ', 39.4578600, -5.8820300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41879, 'Trujillanos', 'Trujillanos', 'Trujillanos', 38.9523300, -6.2575900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41880, 'Trigueros', 'Trigueros', 'Trigeros,Trigueros,te li ge luo si,tryghyrws,Тригерос,Трігерос,Տրիգերոս,تريغيروس,特里格罗斯', 37.3860600, -6.8268000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41881, 'Tribaldos', 'Tribaldos', 'Tribaldos', 39.9726400, -2.8980900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41882, 'Trevélez', 'Trevelez', 'Trevelez,Trevélez', 37.0003700, -3.2654500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41883, 'Tresjuncos', 'Tresjuncos', 'Tresjuncos', 39.7008700, -2.7550200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41884, 'Trebujena', 'Trebujena', 'Trebujena', 36.8707500, -6.1758600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41885, 'Trasierra', 'Trasierra', 'Trasierra', 38.1833300, -6.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41886, 'Tous', 'Tous', 'Tous', 39.1395100, -0.5877700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41887, 'Totanés', 'Totanes', 'Totanes,Totanés', 39.7105700, -4.2265500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41888, 'Totana', 'Totana', 'Totana,Тотана', 37.7688000, -1.5022900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41889, 'Torrubia del Castillo', 'Torrubia del Castillo', 'Torrubia del Castillo', 39.6585200, -2.3117100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41890, 'Torrubia del Campo', 'Torrubia del Campo', 'Torrubia del Campo', 39.8974900, -2.9613300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41891, 'Torrox', 'Torrox', 'Torroks,trsh,tuo luo si,Торрокс,طرش,托罗斯', 36.7579300, -3.9523300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41892, 'Torrijos', 'Torrijos', 'Torrijas,Torrijos', 39.9819500, -4.2834900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41893, 'Torrico', 'Torrico', 'Torrico', 39.8291800, -5.2258100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41894, 'Torrevieja', 'Torrevieja', 'Malnovturo,Toreviekha,Toreviexa,Torevijekha,Torrev''ekha,Torrevekha,Torrevella,Torrevella de la Mata,Torrevieja,torebieha,trbykha,tuo lei wei ye ha,twrbyyhh,twrryfyykha,twryfayja,Торевиеха,Торевијеха,Торревьеха,Торревєха,Տոռեվիեխա,טורבייחה,تربیخا,تورريفييخا,توريفايجا,トレビエハ,托雷维耶哈', 37.9787200, -0.6822200, 'ES', '2015-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41895, 'Torres', 'Torres', '', 37.7853700, -3.5090200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41896, 'Torrequemada', 'Torrequemada', 'Torrequemada', 39.3666400, -6.2205200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41897, 'Torreperogil', 'Torreperogil', 'Torreperogil', 38.0354000, -3.2899800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41898, 'Torre-Pacheco', 'Torre-Pacheco', 'Torre Pacheco,Torre-Pacheco,Torre-Pacheko,Торре-Пачеко', 37.7429300, -0.9539600, 'ES', '2015-12-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41899, 'Torreorgaz', 'Torreorgaz', 'Torreorgaz', 39.3831000, -6.2494100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41900, 'Torrenueva', 'Torrenueva', '', 38.6396000, -3.3625900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41901, 'Torrent', 'Torrent', 'Torrent,Torrente', 39.4370500, -0.4654600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41902, 'Torremolinos', 'Torremolinos', 'Toremolinos,Toremolinos-Malaga,Toremolinos-Málaga,Torremolinos,Torremolinos-Malaga,Torremolinos-Málaga,UTL,tuo lei mo li nuo si,twrymwlynws,Τορρεμολίνος,Торемолинос,Торремолинос,Торремолінос,توريمولينوس,托雷莫利诺斯', 36.6203500, -4.4997600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41903, 'Torremocha', 'Torremocha', 'Torremocha', 39.3456500, -6.1733500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41904, 'Torremayor', 'Torremayor', 'Torremayor', 38.9014000, -6.5385800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41905, 'Torrella', 'Torrella', 'Torrella', 38.9844600, -0.5672700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41906, 'Torrejón el Rubio', 'Torrejon el Rubio', 'Torrejon,Torrejon el Rubio,Torrejón,Torrejón el Rubio', 39.7706800, -6.0126000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41907, 'Torrejoncillo del Rey', 'Torrejoncillo del Rey', 'Torrejoncillo del Rey', 40.0084000, -2.5710700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41908, 'Torrejoncillo', 'Torrejoncillo', 'Torrejoncillo,Torrekhonsil''jo,Torrekhonsil''o,Torrojoncillu,tuo lei hong xi e,twrykhwnsyyw,Торрехонсильо,Торрехонсільйо,توريخونسييو,托雷洪西略', 39.8967500, -6.4671200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41909, 'Torredonjimeno', 'Torredonjimeno', 'Torredongimeno,Torredonjimeno,Torredonkhimeno,trdnkhymnw,tuo lei dong xi mei nuo,twrydwnkhymynw,Торредонхимено,Торредонхімено,تردنخیمنو,توريدونخيمينو,托雷东希梅诺', 37.7674800, -3.9577600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41910, 'Torre de Santa María', 'Torre de Santa Maria', 'Torre de Santa Maria,Torre de Santa María', 39.2544100, -6.1161000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41911, 'Torre de Miguel Sesmero', 'Torre de Miguel Sesmero', 'Torre de Miguel Sesmero', 38.6191300, -6.7958000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41912, 'Torre del Campo', 'Torre del Campo', 'Torre del Compo', 37.7705100, -3.8973100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41913, 'Torre de la Horadada', 'Torre de la Horadada', 'Cortijo Torre de la Horadada,La Horadada,Torre de la Horadada,la Foradada', 37.8697000, -0.7584000, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41914, 'Torre de Juan Abad', 'Torre de Juan Abad', 'Torre de Juan Abad', 38.5841700, -3.0599400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41915, 'Torrecillas de la Tiesa', 'Torrecillas de la Tiesa', 'Torrecilla de la Tiesa,Torrecillas de la Tiesa', 39.5683700, -5.7423800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41916, 'Torrecilla de la Jara', 'Torrecilla de la Jara', 'Torrecilla,Torrecilla de la Jara', 39.7042500, -4.7718600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41917, 'Torre-Cardela', 'Torre-Cardela', '', 37.5045600, -3.3560900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41918, 'Torrecampo', 'Torrecampo', 'Torrecampo', 38.4666700, -4.6666700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41919, 'Torreblascopedro', 'Torreblascopedro', 'Torreblascopedro', 37.9975000, -3.6378000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41920, 'Torre Alháquime', 'Torre Alhaquime', 'Torre Alhaquime,Torre Alháquime', 36.9158800, -5.2338100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41921, 'Torralba de Oropesa', 'Torralba de Oropesa', 'Torralba de Oropesa', 39.9338400, -5.1540400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41922, 'Torralba del Pinar', 'Torralba del Pinar', 'Torral''ba-del''-Pinar,Torralba,Torralba del Pinar,tuo la er wa de er pi na er,twralba dyl baynar,Торральба-дель-Пинар,Торральба-дель-Пінар,تورالبا ديل باينار,托拉尔瓦德尔皮纳尔', 39.9833300, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41923, 'Torralba de Calatrava', 'Torralba de Calatrava', 'Torralba,Torralba de Calatrava', 39.0178500, -3.7510500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41924, 'Tormos', 'Tormos', 'Tormos', 38.8014300, -0.0716000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41925, 'Toril', 'Toril', '', 39.8974900, -5.7795000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41926, 'Torás', 'Toras', 'Toras,Torás', 39.9166700, -0.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41927, 'Tomelloso', 'Tomelloso', 'Tomel''joso,Tomel''oso,Tomeloso,tomejoso,tuo mei e suo,twmylwsw  sywdad ryal,Томельйосо,Томельосо,Томељосо,توميلوسو، سيوداد ريال,トメジョーソ,托梅略索', 39.1575900, -3.0215600, 'ES', '2015-05-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41928, 'Tomares', 'Tomares', 'Tomares', 37.3728100, -6.0458900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41929, 'Tolox', 'Tolox', 'Tolox', 36.6872100, -4.9051100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41930, 'Tollos', 'Tollos', 'Tollos', 38.7562900, -0.2746600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41931, 'Toledo', 'Toledo', 'Gorad Taleda,Toledas,Tolede,Toledo,Toledo i Spania,Toledu,Toletum,Toleu,Tolède,XTJ,tlytlt,to le do,toledo,toleto,tolledo,toredo,tuo lai duo,tuo li duo,twldw,twldw  aspanya,twlydw,Τολέδο,Горад Таледа,Толедо,Տոլեդո,טאלעדא,טולדו,تولدو، اسپانیا,توليدو,طليطلة,طلیطلہ,तोलेदो,ਤੋਲੇਦੋ,டொலேடோ,โตเลโด,ტოლედო,ቶሌዶ,トレド,托利多,托萊多,톨레도', 39.8581000, -4.0226300, 'ES', '2011-07-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41932, 'Tocina', 'Tocina', 'Tocina', 37.6090400, -5.7340300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41933, 'Tobarra', 'Tobarra', 'Tobarra', 38.5921300, -1.6919100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41934, 'Titaguas', 'Titaguas', 'Titaguas,Titaguees,Titagües', 39.8666700, -1.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41935, 'Tinajo', 'Tinajo', 'Tinajo', 29.0632600, -13.6764700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41936, 'Tíjola', 'Tijola', 'Tijola,Tikhola,Tíjola,di huo la,tykhwla,Тихола,Тијола,Тіхола,تيخولا,تیخولا,蒂霍拉', 37.3460600, -2.4332600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41937, 'Tijarafe', 'Tijarafe', 'Tijarafe,Tirajafe', 28.7000000, -17.9500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41938, 'Tibi', 'Tibi', 'Maigmo,Tibi,di wei,taybay,tyby,Тиби,Тібі,تايباي,تیبی,蒂维', 38.5307200, -0.5777600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41939, 'Tías', 'Tias', 'Tias,Tías', 28.9610800, -13.6450200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41940, 'Teulada', 'Teulada', 'Teulada', 38.7294000, 0.1038300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41941, 'Terrinches', 'Terrinches', 'Terrinches', 38.6105700, -2.8421500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41942, 'Terrateig', 'Terrateig', 'Terrateig', 38.8945300, -0.3199300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41943, 'Terque', 'Terque', 'Terque', 36.9839300, -2.5967900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41944, 'Teror', 'Teror', 'Teror,te luo er,tyrwr,Терор,تيرور,特罗尔', 28.0606200, -15.5490900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41945, 'Tembleque', 'Tembleque', 'Tembleke,Tembleque,teng fu lai ke,tmblkh,Темблеке,Տեմբլեկե,تمبلکه,滕夫莱克', 39.6954100, -3.5042900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41946, 'Telde', 'Telde', 'Tel''de,Telde,te er de,tyldy,Телде,Тельде,تيلدي,特尔德', 27.9924300, -15.4191500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41947, 'Tejeda', 'Tejeda', 'Tekheda,te he da,tykhyda,Техеда,تيخيدا,特赫达', 27.9950800, -15.6154300, 'ES', '2015-10-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41948, 'Teguise', 'Teguise', 'Teguise', 29.0604900, -13.5639700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41949, 'Tegueste', 'Tegueste', 'Tegueste', 28.5166700, -16.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41950, 'Tébar', 'Tebar', 'Tebar,Tébar', 39.5000000, -2.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41951, 'Teba', 'Teba', 'Teba,te wa,tyba  malqt,Теба,تيبا، مالقة,特瓦', 36.9835800, -4.9191300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41952, 'Tazacorte', 'Tazacorte', 'Tasakorte,Tazacorte,ta sa ke er te,tathakwrty,Тасакорте,تاثاكورتي,塔萨科尔特', 28.6418600, -17.9339400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41953, 'Tarifa', 'Tarifa', 'Gorad Taryfa,Tarifa,ta li fa,talipa,tarifa,tryfa,Горад Тарыфа,Тарифа,Таріфа,طريفا,タリファ,塔里法,타리파', 36.0139300, -5.6069500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41954, 'Tarazona de la Mancha', 'Tarazona de la Mancha', 'Tarazona,Tarazona de la Mancha', 39.2500000, -1.9166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41955, 'Tanque', 'Tanque', '', 28.3666700, -16.8333300, 'ES', '2006-01-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41956, 'Tamurejo', 'Tamurejo', 'Tamurejo', 38.9833300, -4.9333300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41957, 'Táliga', 'Taliga', 'Taliga,Táliga', 38.5286100, -7.0171300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41958, 'Tales', 'Tales', 'Tales', 39.9484400, -0.3071900, 'ES', '2012-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41959, 'Talayuelas', 'Talayuelas', 'Talayuelas', 39.8500000, -1.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41960, 'Talayuela', 'Talayuela', 'Talajuehla,Talajuela,Talayuela,ta lai wei la,talayla,Талаюела,Талаюэла,تالايلا,塔莱韦拉', 39.9870100, -5.6098200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41961, 'Talavera La Real', 'Talavera La Real', 'Talavera La Real', 38.8779400, -6.7685600, 'ES', '2012-02-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41962, 'Talavera de la Reina', 'Talavera de la Reina', 'Aebura,Caesarobriga,Ebora,Ebura,Elbora,QWT,Talavera de la Reina,Talavera de la Rejna,Talavera de la reina,Talavera del Tajo,Talavera-de-la-Rejna,ta la be ra de la rey na,ta la wei la de la lei na,talavera di la rina,tlbyrt,Талавера де ла Реина,Талавера де ла Рейна,Талавера-де-ла-Рейна,طلبيرة,टालावेरा दी ला रीना,ตาลาเบราเดลาเรย์นา,ታላቬራ ዴ ላ ሬና,タラベラ・デ・ラ・レイナ,塔拉韦拉德拉雷纳', 39.9634800, -4.8307600, 'ES', '2012-10-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41963, 'Talaván', 'Talavan', 'Talaban,Talabán,Talavan,Talaván,ta la wan,talafan,Талаван,تالافان,塔拉万', 39.7171500, -6.2814600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41964, 'Talarrubias', 'Talarrubias', 'Talarrubia,Talarrubias', 39.0369700, -5.2342300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41965, 'Tahal', 'Tahal', 'Tahal', 37.2279700, -2.2847000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41966, 'Tacoronte', 'Tacoronte', 'Tacoronte,Takoronte,ta ke long te,takrnth,takwrwnty,Такоронте,تاكورونتي,تاکرنته,塔科龙特', 28.4768800, -16.4101600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41967, 'Tavernes de la Valldigna', 'Tavernes de la Valldigna', 'Tabernas,Tabernes de Valldigna,Tavernes de la Valldigna', 39.0719500, -0.2662300, 'ES', '2015-05-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41968, 'Tavernes Blanques', 'Tavernes Blanques', 'Tabernes,Tabernes Blanques,Tavernes Blanques', 39.5000000, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41969, 'Tabernas', 'Tabernas', 'Tabernas', 37.0499200, -2.3908400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41970, 'Sumacàrcer', 'Sumacarcer', 'Sumacarcel,Sumacarcer,Sumacàrcer,Sumacárcel', 39.1000000, -0.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41971, 'Suflí', 'Sufli', 'Sufli,Suflí', 37.3386600, -2.3881700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41972, 'Sueca', 'Sueca', 'Sueca', 39.2026000, -0.3111400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41973, 'Sot de Ferrer', 'Sot de Ferrer', 'Sot de Ferrer', 39.8000000, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41974, 'Sot de Chera', 'Sot de Chera', 'Sot de Chera,Sot de Xera', 39.6333300, -0.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41975, 'Sorvilán', 'Sorvilan', 'Sorvilan,Sorvilán', 36.7950500, -3.2676900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41976, 'Sorihuela del Guadalimar', 'Sorihuela del Guadalimar', 'Sorihuela del Guadalimar', 38.2406200, -3.0536000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41977, 'Sorbas', 'Sorbas', 'Sorbas', 37.0976100, -2.1234900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41978, 'Soportújar', 'Soportujar', '', 36.9286300, -3.4054200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41979, 'Son Servera', 'Son Servera', 'Son Servera,Son-Servera,song sai er wei la,swn syrfyra,Сон-Сервера,سون سيرفيرا,松塞尔韦拉', 39.6207300, 3.3600800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41980, 'Sonseca', 'Sonseca', 'Sonseca con Casalgordo', 39.6774700, -3.9744800, 'ES', '2010-05-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41981, 'Soneja', 'Soneja', 'Sonecha,Soneixa,Soneja,Sonekha,suo nei ha,swnykha,Сонеха,سونيخا,索内哈', 39.8166700, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41982, 'Somontín', 'Somontin', 'Somolin,Somolín,Somontin,Somontín', 37.3917600, -2.3882800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41983, 'Sóller', 'Soller', 'Sol''er,Solera,Soller,Soļera,Sóller,soryeru,suo lie er,swyyr,Сольер,سويير,ソーリェル,索列尔', 39.7662300, 2.7152100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41984, 'Sollana', 'Sollana', 'Sollana', 39.2833300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41985, 'Solana de los Barros', 'Solana de los Barros', 'Solana,Solana de los Barros', 38.7252700, -6.5389900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41986, 'Socuéllamos', 'Socuellamos', 'Socuellamos,Socuéllamos,Sokuehl''jamos,Sokuel''jamos,suo ku ai li ya mo si,swkwylamws  sywdad ryal,Сокуельямос,Сокуэльямос,سوكويلاموس، سيوداد ريال,索库埃利亚莫斯', 39.2858100, -2.7920500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41987, 'Socovos', 'Socovos', '', 38.3323200, -1.9848500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41988, 'Sisante', 'Sisante', 'Sisante', 39.4084900, -2.2017300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41989, 'Siruela', 'Siruela', 'Siruela', 38.9771800, -5.0496900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41990, 'Sineu', 'Sineu', 'Sineu', 39.6425400, 3.0103400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41991, 'Sinarcas', 'Sinarcas', 'Sinarcas,Sinarques', 39.7333300, -1.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41992, 'Simat de la Valldigna', 'Simat de la Valldigna', 'Simat de Valldigna,Simat de la Valldigna', 39.0333300, -0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41993, 'Silla', 'Silla', 'Silla', 39.3625700, -0.4116900, 'ES', '2015-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41994, 'Siles', 'Siles', 'Siles', 38.3898300, -2.5819000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41995, 'Siete Aguas', 'Siete Aguas', 'Setaiguees,Setaigües,Siete Aguas', 39.4666700, -0.9166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41996, 'Sierro', 'Sierro', 'Sierro', 37.3223700, -2.3984400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41997, 'Sierra de Yeguas', 'Sierra de Yeguas', 'Sierra de Yeguas', 37.1242000, -4.8677300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41998, 'Sierra de Fuentes', 'Sierra de Fuentes', 'Sierra de Fuentes', 39.4399700, -6.2724200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41999, 'Sevilleja de la Jara', 'Sevilleja de la Jara', 'Sevilleja de la Jara', 39.5748800, -4.9638700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42000, 'Sevilla', 'Sevilla', 'Gorad Sevil''ja,Hispalis,Lungsod ng Sevilla,SVQ,Sebilla,Sebille,Sevidzheh,Sevil''ja,Sevila,Sevileje,Sevilha,Sevilia,Sevilija,Sevilja,Sevilla,Seville,Sevilo,Sevilya,Sevilėjė,Seviya,Seweliye,Sewilla,Sibilia,Siviglia,Sivilja,Séville,Séwéliye,ashbylyt,ceviya,isabili''a,sai wei li ya,sai wei ya,sbylyh,sebi ya,sebiria,sebirya,sebiya,sevilia,swya,sybyya,Σεβίλλη,Горад Севілья,Севиджэ,Севилья,Севиля,Севилја,Севиља,Севілья,Սևիլյա,סביליה,סעווילא,إشبيلية,اشبیلیہ,سویا,سيبييا,سێڤیلیا,सेबिया,ਇਸ਼ਬੀਲੀਆ,செவீயா,เซบียา,სევილია,セビリア,セビリャ,塞維亞,塞维利亚,세비야', 37.3828300, -5.9731700, 'ES', '2014-02-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42001, 'Setenil de las Bodegas', 'Setenil de las Bodegas', 'Setenil', 36.8639700, -5.1817700, 'ES', '2008-11-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42002, 'Ses Salines', 'Ses Salines', 'Ses Salines,les Salines,ses Salines', 39.3383100, 3.0527400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42003, 'Serrejón', 'Serrejon', 'Serrejon,Serrejón', 39.8173500, -5.8026300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42004, 'Serrato', 'Serrato', 'Serrato', 36.8854100, -4.9814700, 'ES', '2016-12-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42005, 'Serradilla', 'Serradilla', 'Serradilla', 39.8292000, -6.1403400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42006, 'Serra', 'Serra', 'Serra', 39.6833300, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42007, 'Serón', 'Seron', 'Seron,Serón', 37.3448500, -2.5091300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42008, 'Senija', 'Senija', 'Senija', 38.7280400, 0.0417600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42009, 'Senyera', 'Senyera', 'Senera,Senyera,Señera', 39.0666700, -0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42010, 'Sempere', 'Sempere', 'Sant Pere,Sempere', 38.9201400, -0.4814000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42011, 'Selva', 'Selva', 'Selva', 39.7550400, 2.9006900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42012, 'Sellent', 'Sellent', 'Sellent', 39.0322100, -0.5878400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42013, 'Sella', 'Sella', 'Sella', 38.6092600, -0.2730500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42014, 'Segura de León', 'Segura de Leon', 'Segura de Leon,Segura de León', 38.1166700, -6.5166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42015, 'Segura de la Sierra', 'Segura de la Sierra', 'Segura de la Sierra,Segura-de-la-S''erra,sai gu la de la xie la,sgwra d la syra,syghwra dy la syyra,Сегура-де-ла-Сьерра,Сегура-де-ла-Сьєрра,سيغورا دي لا سييرا,سگورا د لا سیرا,塞古拉德拉谢拉', 38.2977700, -2.6522900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42016, 'Segorbe', 'Segorbe', 'Segorbe,Sogorb', 39.8500000, -0.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42017, 'Segart', 'Segart', 'Segart,Segart de Albalat', 39.6833300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42018, 'Sedaví', 'Sedavi', 'Sedavi,Sedaví', 39.4333300, -0.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42019, 'Sayalonga', 'Sayalonga', 'Sajalonga,Sajjalonga,Sayalonga,sai a long jia,sayalwngha,Сайялонга,Саялонга,Սայալոնգա,سايالونغا,赛阿隆加', 36.7981900, -4.0132500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42020, 'Sax', 'Sax', 'Sax', 38.5372900, -0.8177900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42021, 'Sauzal', 'Sauzal', 'El Sauzal,Sauzal', 28.4666700, -16.4166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42022, 'Saucedilla', 'Saucedilla', 'Saucedilla,Sausedil''ja,sawsydayla,shao sai di li ya,Сауседилья,Сауседілья,ساوسيدايلا,绍塞迪利亚', 39.8528400, -5.6778100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42023, 'San Vicent del Raspeig', 'San Vicent del Raspeig', 'San Vicente,San Vicente del Raspeig,Sant Vicent del Raspeig,Sanvi', 38.3964000, -0.5255000, 'ES', '2013-12-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42024, 'San Vicente de Alcántara', 'San Vicente de Alcantara', '', 39.3613200, -7.1376600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42025, 'Santo Tomé', 'Santo Tome', 'Santo Tome,Santo Tomé', 38.0286100, -3.1009200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42026, 'Santomera', 'Santomera', '', 38.0614700, -1.0487700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42027, 'Santisteban del Puerto', 'Santisteban del Puerto', 'Santisteban del Puerto', 38.2482900, -3.2076200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42028, 'Santiponce', 'Santiponce', 'Santiponce', 37.4355300, -6.0410600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42029, 'Santiago del Teide', 'Santiago del Teide', 'Santiago,Santiago del Teide,Santiago del Teyde', 28.2940000, -16.8161800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42030, 'Santiago del Campo', 'Santiago del Campo', 'Santiago del Campo', 39.6284000, -6.3636200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42031, 'Santiago de la Ribera', 'Santiago de la Ribera', '', 37.7968100, -0.8054400, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42032, 'Santiago de Calatrava', 'Santiago de Calatrava', 'Santiago de Calatrava', 37.7538200, -4.1709300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42033, 'Es Migjorn Gran', 'Es Migjorn Gran', 'San Cristobal,San Cristóbal,Sant Cristofol,Sant Cristófol', 39.9465700, 4.0512100, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42034, 'Santa Úrsula', 'Santa Ursula', 'Santa Ursula,Santa Úrsula', 28.4261300, -16.4887600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42035, 'Santa Pola', 'Santa Pola', 'Santa Pola,Santa-Pola,santa bwla,santa pla,sheng bo la,Санта-Пола,سانتا بولا,سانتا پلا,圣波拉', 38.1916500, -0.5658000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42036, 'Santa Olalla del Cala', 'Santa Olalla del Cala', 'Santa Olalla,Santa Olalla de Cala,Santa Olalla del Cala,Santa Ololla del Cala', 37.9000000, -6.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42037, 'Santanyí', 'Santanyi', 'Santanyi,Santanyí', 39.3546100, 3.1290700, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42038, 'Santa Marta de Magasca', 'Santa Marta de Magasca', 'Santa Maria,Santa Marta,Santa Marta de Magasca,Santa María', 39.5115000, -6.0988100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42039, 'Santa Marta', 'Santa Marta', 'Santa Marta', 38.6142100, -6.6279900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42040, 'Santa María del Campo Rus', 'Santa Maria del Campo Rus', 'Santa Maria del Campo,Santa Maria del Campo Rus,Santa María del Campo Rus', 39.5594200, -2.4230600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42041, 'Santa Maria del Camí', 'Santa Maria del Cami', 'Santa Maria,Santa Maria del Cami,Santa Maria del Camí', 39.6511100, 2.7731700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42042, 'Santa Margalida', 'Santa Margalida', 'Santa Margalida,Santa Margarita', 39.7014300, 3.1021500, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42043, 'Santa Lucía', 'Santa Lucia', 'Santa Lucia de Tirajana,Santa Lucía de Tirajana,sheng lu xi ya,圣卢西亚', 27.9117400, -15.5407100, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42044, 'Santa Fe de Mondújar', 'Santa Fe de Mondujar', 'Santa Fe,Santa Fe de Mondujar,Santa Fe de Mondújar', 36.9747900, -2.5312600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42045, 'Santafé', 'Santafe', '', 37.1885600, -3.7188700, 'ES', '2015-10-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42046, 'Santa Eulària des Riu', 'Santa Eularia des Riu', 'Santa Eulalia del Rio,Santa Eulalia del Río,Santa Eularia del Riu,Santa Eularia des Riu,Santa Eulària del Riu,Santa Eulària des Riu,Santa-Ehulalija-del''-Rio,bin he sheng ai wu la li ya,santa aywlalya dyl ryw,Санта-Эулалия-дель-Рио,سانتا إيولاليا ديل ريو,滨河圣埃乌拉利亚', 38.9845700, 1.5340900, 'ES', '2012-10-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42047, 'Santa Eugènia', 'Santa Eugenia', 'Santa Eugenia,Santa Eugènia', 39.6236100, 2.8386400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42048, 'Santa Eufemia', 'Santa Eufemia', 'Santa Eufemia', 38.6000000, -4.9000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42049, 'Santaella', 'Santaella', 'Santaella', 37.5629400, -4.8436200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42050, 'Santa Elena', 'Santa Elena', 'Santa Elena', 38.3416200, -3.5395300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41655, 'Laayoune Plage', 'Laayoune Plage', 'Laayoune Plage,Playa de Aaiun,Playa de Aaiún,Playa del Aaiun,Playa del Aaiún', 27.0961100, -13.4158300, 'EH', '2013-03-16', 246);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41656, 'Laayoune', 'Laayoune', 'Aaium,Aaiun,Aaiún,Aiun,Ajuno,Al Ayoun,Al-Aaiun,Al-Ajoen,Al-Ayun,Al-Ujun,EUN,Ehl''-Ajun,Ejbei Uad el Aabd,El Aaiun,El Aaiún,El Aium,El Aiun,El Aiún,El Ajun,El Ayun,El-Aaiun,El-Aaiún,La''Youn,Laayoune,Laâyoune,La’Youn,O Aiún - العيون,a you en,aiun,el-aiun,Ел Ајун,Эль-Аюн,العيون,العیون,アイウン,阿尤恩,엘아이운', 27.1418000, -13.1879700, 'EH', '2016-11-23', 246);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(41657, 'Dakhla', 'Dakhla', 'Ad - Dakhla,Ad Dakhla,Dajla,Dakhla,Dakhlah,Factoria Villa Cisneros,VIL,Villa Cisneras,Villa Cisneros,aldakhlt,dakhlh,Дахла,الداخلة,داخله', 23.6847700, -15.9579800, 'EH', '2016-07-14', 246);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42051, 'Santa Cruz de Tenerife', 'Santa Cruz de Tenerife', 'Gorad Santa-Krus-deh-Tehnehryfeh,Sancta Crux Nivariae,Santa Cruz,Santa Cruz Tenerifekoa,Santa Cruz de Tenerife,Santa Cruz de Ténérife,Santa Krouth nte Tenerife,Santa Krus de Tenerife,Santa Kruz de Tenerife,Santa-Krus-de-Tenerife,Santakrusa de Tenerife,TCI,Tenerife,Tenerifes Santa Krusas,Teneriffa,Tenerifės Santa Krusas,san ta kru sde te ne rife,santa kruja de teneriphe,santa krujha de teneripha,santa krusa de tenarifa,santa krws,santa krws dy tynyryfa,santa krwth dy tynyryfh,santa krwz dy tynyrf,santakeuluseudetenelipe,sheng ke lu si-de te nei li fei,snth qrws dh tnryph,Σάντα Κρουθ ντε Τενερίφε,Горад Санта-Крус-дэ-Тэнэрыфэ,Санта Круз де Тенерифе,Санта Крус де Тенерифе,Санта-Крус-де-Тенерифе,Санта-Крус-де-Тенеріфе,סאנטא קרוז דע טענעריפע,סנטה קרוס דה טנריפה,سانتا كروث دي تينيريفه,سانتا كروس دى تينيريفا,سانتا کروز دی تینیرف,سانتا کروز ٹینرائف,سانتا کروس,सांता क्रुझ दे तेनेरीफ,सान्ता क्रूस दे तेनरीफ़,সান্টা ক্রুজ দে তেনেরিফে,ซานตากรุซเดเตเนรีเฟ,სანტა-კრუს-დე-ტენერიფე,サンタ・クルス・デ・テネリフェ,圣克鲁斯-德特内里费,산타크루스데테네리페', 28.4682400, -16.2546200, 'ES', '2016-01-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42052, 'Santa Cruz de Mudela', 'Santa Cruz de Mudela', 'Santa Cruz de Mudela', 38.6424100, -3.4665000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42053, 'Santa Cruz de Moya', 'Santa Cruz de Moya', 'Santa Cruz de Moya', 39.9500000, -1.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42054, 'Santa Cruz de los Cáñamos', 'Santa Cruz de los Canamos', 'Santa Cruz de los Canamos,Santa Cruz de los Cáñamos', 38.6375900, -2.8661800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42055, 'Santa Cruz de la Zarza', 'Santa Cruz de la Zarza', 'Santa Cruz de la Zaraza,Santa Cruz de la Zarza,Santa-Krus-de-la-Sarsa,santa krwz dy la zarza,sheng ke lu si de la sa er sa,Санта-Крус-де-ла-Сарса,سانتا كروز دي لا زارزا,圣克鲁斯德拉萨尔萨', 39.9810400, -3.1878700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42056, 'Santa Cruz de la Sierra', 'Santa Cruz de la Sierra', 'Santa Cruz de la Sierra', 39.3363500, -5.8456100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42057, 'Santa Cruz de la Palma', 'Santa Cruz de la Palma', 'SPC,Santa Cruz de La Palma,Santa Cruz de la Palma', 28.6835100, -17.7642100, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42058, 'Santa Brígida', 'Santa Brigida', 'Santa Brigida,Santa Brígida', 28.0319700, -15.5042500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42059, 'Santa Bárbara de Casa', 'Santa Barbara de Casa', 'Santa Barbara,Santa Barbara de Casa,Santa Barbara de Casas,Santa Bárbara,Santa Bárbara de Casa,Santa Bárbara de Casas', 37.7966500, -7.1873500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42060, 'Santa Ana la Real', 'Santa Ana la Real', 'Santa Ana la Real', 37.8624500, -6.7238500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42061, 'Santa Ana de Pusa', 'Santa Ana de Pusa', 'Santa Ana de Pusa', 39.7623800, -4.7090400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42062, 'Santa Ana', 'Santa Ana', 'Santa Ana', 39.3082300, -5.9902700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42063, 'Santa Amalia', 'Santa Amalia', '', 39.0111800, -6.0115800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42064, 'San Silvestre de Guzmán', 'San Silvestre de Guzman', 'San Silvestre de Guzman,San Silvestre de Guzmán', 37.3877000, -7.3490800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42065, 'San Sebastián de los Ballesteros', 'San Sebastian de los Ballesteros', 'San Sebastian de los Ballesteros,San Sebastián de los Ballesteros', 37.6537600, -4.8240900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42066, 'San Sebastián de la Gomera', 'San Sebastian de la Gomera', 'La Gomeros San Sebastianas,San Sebastian,San Sebastian de La Gomera,San Sebastian de la Gomera,San Sebastián de La Gomera,San Sebastián de la Gomera,San-Sebasc''jan-deh-la-Gamera,San-Sebast''jan-de-la-Gomera,san sbastyan d la gmra,san sybastyan dy la ghwmyra,sheng sai wa si di an de la ge mei la,Сан-Себастьян-де-ла-Гомера,Сан-Себасцьян-дэ-ла-Гамера,سان سباستیان د لا گمرا,سان سيباستيان دي لا غوميرا,圣塞瓦斯蒂安德拉戈梅拉', 28.0916300, -17.1133100, 'ES', '2012-02-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42067, 'San Roque', 'San Roque', 'San Roque', 36.2106700, -5.3841500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42068, 'San Pedro de Mérida', 'San Pedro de Merida', 'San Pedro de Merida,San Pedro de Mérida', 38.9500700, -6.1864500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42069, 'San Pedro del Pinatar', 'San Pedro del Pinatar', 'San Pedro del Pintar', 37.8356800, -0.7910200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42070, 'San Pedro de Alcántara', 'San Pedro de Alcantara', 'San Pedro,San Pedro de Alcantara,San Pedro de Alcántara,San-Pedro-de-Al''kantara,Сан-Педро-де-Алькантара', 36.4883900, -4.9912300, 'ES', '2015-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42071, 'San Pedro', 'San Pedro', 'San Pedro', 38.8249300, -2.1827600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42072, 'San Nicolás del Puerto', 'San Nicolas del Puerto', 'San Nicolas del Puerto,San Nicolás del Puerto', 38.0000000, -5.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42073, 'San Nicolás', 'San Nicolas', 'Aldea de San Nicolas', 27.9891000, -15.7812600, 'ES', '2008-08-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42074, 'San Miguel de Salinas', 'San Miguel de Salinas', 'San Miguehl'',San Miguel,San Miguel de Salinas,Sant Miquel de Salines,Сан Мигуэль', 37.9797200, -0.7890400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42075, 'San Miguel De Abona', 'San Miguel De Abona', 'San Miguel De Abona', 28.0982600, -16.6170800, 'ES', '2015-12-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42076, 'San Martín de Pusa', 'San Martin de Pusa', 'San Martin de Pusa,San Martín de Pusa', 39.7840400, -4.6325200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42077, 'San Martín de Montalbán', 'San Martin de Montalban', 'San Martin de Montalban,San Martín de Montalbán', 39.7018600, -4.3879600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42078, 'San Martín de Boniches', 'San Martin de Boniches', 'San Martin de Boniches,San Martín de Boniches', 39.9000000, -1.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42079, 'Sant Lluís', 'Sant Lluis', 'San Luis,San-Luis,Sant Lluis,Sant Lluís,san lwys,sang te liu yi si,Сан-Луис,سان لويس,桑特柳伊斯', 39.8493900, 4.2581900, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42080, 'Sanlúcar la Mayor', 'Sanlucar la Mayor', 'Sanlucar la Mayor,Sanlúcar la Mayor', 37.3875800, -6.2034600, 'ES', '2014-08-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42081, 'Sanlúcar de Guadiana', 'Sanlucar de Guadiana', 'Salucar de Guadiana,Sanlucar de Guadiana,Sanlúcar de Guadiana', 37.4726800, -7.4654600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42082, 'Sanlúcar de Barrameda', 'Sanlucar de Barrameda', 'San Lucar de Barrameda,Sanlucar de Barrameda,Sanlukar de Barameda,Sanlukar-de-Barrameda,Sanlúcar de Barrameda,Sunlucar de Barrameda,san luk arde bar ra me da,sang lu ka er de wa la mei da,sanlukaleudebalameda,shlwqt,Санлукар де Барамеда,Санлукар-де-Баррамеда,شلوقة,ซานลูการ์เดบาร์ราเมดา,სანლუკარ-დე-ბარამედა,サンルーカル・デ・バラメーダ,桑卢卡尔德瓦拉梅达,산루카르데바라메다', 36.7780800, -6.3515000, 'ES', '2012-08-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42083, 'San Lorenzo de la Parrilla', 'San Lorenzo de la Parrilla', 'San Lorenzo de la Parilla,San Lorenzo de la Parrilla', 39.8512900, -2.3607900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42084, 'Sant Llorenç des Cardassar', 'Sant Llorenc des Cardassar', 'San Lorenzo,Sant Llorenc,Sant Llorenc del Cardassar,Sant Llorenc des Cardassar,Sant Llorenç,Sant Llorenç del Cardassar,Sant Llorenç des Cardassar', 39.6100900, 3.2838000, 'ES', '2016-01-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42085, 'San Lorenzo de Calatrava', 'San Lorenzo de Calatrava', 'San Lorenzo,San Lorenzo de Calatrava', 38.4768100, -3.8260500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42086, 'San Juan del Puerto', 'San Juan del Puerto', 'Juan del Puerto,San Juan,San Juan del Puerto', 37.3166700, -6.8413900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42087, 'San Juan de la Rambla', 'San Juan de la Rambla', 'Juan de Rambla,San Juan de Rambla,San Juan de la Rambla', 28.3927600, -16.6501500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42088, 'San Juan de Énova', 'San Juan de Enova', 'San Juan de Enova,San Juan de Énova,Sant Joan de l''Enova,Sant Joan de l''Ènova', 39.0710400, -0.4870500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42089, 'San Juan de Aznalfarache', 'San Juan de Aznalfarache', 'San Juan de Aznalfarache,San-Khuan-de-Asnal''farache,sheng hu an de ya si na er fa la qie,Сан-Хуан-де-Аснальфараче,圣胡安德亚斯纳尔法拉切', 37.3581300, -6.0373100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42090, 'San Juan de Alicante', 'San Juan de Alicante', 'San Juan (bei Alicante),San Juan de Alicante,Sant Joan d''Alacant', 38.4014800, -0.4362300, 'ES', '2016-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42091, 'Sant Joan de Labritja', 'Sant Joan de Labritja', 'San Juan,San Juan Bautista,Sant Joan de Labritja', 39.0789100, 1.5139700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42092, 'Sant Joan', 'Sant Joan', 'Sant Joan', 39.5962100, 3.0392000, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42093, 'Sant Josep de sa Talaia', 'Sant Josep de sa Talaia', 'San Jose,San Jose de la Atalaya,Sant Josep de sa Talaia', 38.9223900, 1.2943700, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42094, 'San José', 'San Jose', 'Caserio San Jose,Caserío San José,San Khose,Сан Хосе', 36.7604800, -2.1091200, 'ES', '2014-05-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42095, 'San Javier', 'San Javier', 'MJV,San Javier', 37.8062600, -0.8373600, 'ES', '2015-10-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42096, 'San Isidro', 'San Isidro', 'San Isidro,Сан Исидро', 28.0761700, -16.5580000, 'ES', '2013-08-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42097, 'Sant Francesc de Formentera', 'Sant Francesc de Formentera', 'San Francisco,San Francisco Javier,Sant Francesc,Sant Francesc de Formentera', 38.7056600, 1.4289300, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42098, 'San Fernando', 'San Fernando', 'San Fernanando,San Fernando,San Fernando i Spania,San-Fernando,san frnandw  qads,sheng fei er nan duo,Сан Фернандо,Сан-Фернандо,سان فرناندو، قادس,サン・フェルナンド,圣费尔南多', 36.4759000, -6.1981700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42099, 'Sanet y Negrals', 'Sanet y Negrals', 'Sanet i els Negrals,Sanet y Negrals', 38.8196700, -0.0340600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42100, 'La Laguna', 'La Laguna', 'La Laguna,La-Laguna,San Cristobal de La Laguna,San Cristóbal de La Laguna,Ла-Лагуна', 28.4853000, -16.3201400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42101, 'San Clemente', 'San Clemente', 'San Clemente', 39.4041000, -2.4281900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42102, 'Sencelles', 'Sencelles', 'Sencelles', 39.6459800, 2.8976900, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42103, 'San Carlos del Valle', 'San Carlos del Valle', 'San Carlos del Valle', 38.8439900, -3.2414800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42104, 'San Bartolomé de Tirajana', 'San Bartolome de Tirajana', 'San Bartolome Tirajana,San Bartolome de Tirajana,San Bartolomé Tirajana,San Bartolomé de Tirajana', 27.9248100, -15.5732900, 'ES', '2015-06-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42105, 'San Bartolomé de la Torre', 'San Bartolome de la Torre', 'San Bartolome de la Torre,San Bartolomé de la Torre', 37.4451500, -7.1059700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42106, 'San Bartolomé de las Abiertas', 'San Bartolome de las Abiertas', 'San Bartolome de las Abiertas,San Bartolomé de las Abiertas', 39.8297200, -4.7190100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42107, 'San Bartolomé', 'San Bartolome', 'San - Bartolome,San Bartolome,San Bartolomé,Сан - Бартоломе', 29.0009300, -13.6130000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42108, 'Sant Antoni de Portmany', 'Sant Antoni de Portmany', 'Bahia de San Antonio,San Antonio,San Antonio Abad,San-Antonio-Abad,Sant Antoni de Portmany,san antwnyw abad,sang tan tuo ni de bo er te ma ni,Сан-Антонио-Абад,سان أنطونيو أباد,桑坦托尼德波尔特马尼', 38.9806800, 1.3036200, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42109, 'Salvatierra de Santiago', 'Salvatierra de Santiago', 'Salvatierra de Santiago', 39.3036300, -6.0320600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42110, 'Salvatierra de los Barros', 'Salvatierra de los Barros', 'Salvatierra,Salvatierra de los Barros', 38.4909100, -6.6842300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42111, 'Salvaleón', 'Salvaleon', 'Salvaleon,Salvaleón', 38.5102000, -6.7862700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42112, 'Salteras', 'Salteras', 'Salteras', 37.4206000, -6.1104900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42113, 'Salorino', 'Salorino', 'Salorino', 39.4801800, -7.0075800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42114, 'Salobreña', 'Salobrena', 'Salobrena,Salobreña', 36.7427700, -3.5871700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42115, 'Salobre', 'Salobre', 'Salobre', 38.5929700, -2.5503800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42116, 'Salinas', 'Salinas', 'Salinas', 38.5202500, -0.9120200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42117, 'Salares', 'Salares', '', 36.8546300, -4.0243400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42118, 'Salar', 'Salar', 'Salar', 37.1503600, -4.0657600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42119, 'Sagunto', 'Sagunto', 'Morvedre,Sagonte,Sagunt,Sagunto,Saguntum,sgwntwm,Сагунто,סגונטום', 39.6833300, -0.2666700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42120, 'Sagra', 'Sagra', 'Sagra', 38.8110200, -0.0655900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42121, 'Saelices', 'Saelices', 'Saelices', 39.9206100, -2.8050200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42122, 'Saceruela', 'Saceruela', 'Saceruela', 38.9438200, -4.6076800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42123, 'Sacañet', 'Sacanet', 'Sacanel,Sacanet,Sacanyet,Sacañel,Sacañet', 39.8666700, -0.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42124, 'Sabiote', 'Sabiote', 'Sabiote', 38.0691600, -3.3144800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42125, 'Rute', 'Rute', 'Rute,Rute foersamling,Rute församling', 37.3269000, -4.3682700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42126, 'Rus', 'Rus', 'Rus', 38.0475900, -3.4625400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42127, 'Ruidera', 'Ruidera', 'Ruidera', 38.9777500, -2.8832100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42128, 'Rugat', 'Rugat', 'Rugat', 38.8793300, -0.3611500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42129, 'Rubite', 'Rubite', 'Rubite', 36.8094700, -3.3481600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42130, 'Ruanes', 'Ruanes', 'Ruanes', 39.3281400, -6.0134700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42131, 'Rozalén del Monte', 'Rozalen del Monte', 'Rozalen del Monte,Rozalén del Monte', 39.9908300, -2.8052500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42132, 'Rótova', 'Rotova', 'Rotova,Ròtova,Rótova', 38.9320500, -0.2576500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42133, 'Rotglá y Corbera', 'Rotgla y Corbera', 'Rotgla i Corbera,Rotgla y Corbera,Rotglà i Corberà,Rotglá y Corbera', 39.0046500, -0.5648200, 'ES', '2014-06-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42134, 'Rota', 'Rota', 'ROZ,Rota,Рота', 36.6254500, -6.3622000, 'ES', '2015-09-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42135, 'Rosalejo', 'Rosalejo', 'Caserio Rosalejo,Caserío Rosalejo,Rosalejo', 39.4366000, -4.9082100, 'ES', '2013-08-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42136, 'Rosal de la Frontera', 'Rosal de la Frontera', 'El Rosal de la Frontera,Rosal,Rosal de la Frontera', 37.9675400, -7.2188900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42137, 'Roquetas de Mar', 'Roquetas de Mar', 'Roketas de Mar,Roketas-de-Mar,Roquetas,Roquetas de Mar,luo ke ta si de ma er,rktas d mar,rwkwytas dy mar,Рокетас де Мар,Рокетас-де-Мар,روكويتاس دي مار,رکتاس د مار,ロケタス・デ・マル,罗克塔斯德马尔', 36.7641900, -2.6147500, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42138, 'Ronda', 'Ronda', 'RRA,Ronda,Ронда', 36.7423100, -5.1670900, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42139, 'Romangordo', 'Romangordo', 'Romangordo', 39.7419900, -5.7008100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42140, 'Rojales', 'Rojales', 'Rojales,Rojals,Rokhales,Roxales,luo ha lai si,rkhals,Рохалес,Ռոխալես,رخالس,罗哈莱斯', 38.0879900, -0.7254400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42141, 'Rocafort', 'Rocafort', 'Rocafort', 39.5333300, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42142, 'Robledollano', 'Robledollano', 'Robledollano', 39.6096200, -5.5085500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42143, 'Robledo', 'Robledo', 'Robledo', 38.7580700, -2.4504200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42144, 'Robledillo de Trujillo', 'Robledillo de Trujillo', 'Robledillo de Trujillo', 39.2695600, -5.9800100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42145, 'Riópar', 'Riopar', 'Riopar,Riópar', 38.5000000, -2.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42146, 'Ríolobos', 'Riolobos', 'Riolobos,Ríolobos', 39.9207400, -6.3039700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42147, 'Riola', 'Riola', 'Riola', 39.2000000, -0.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42148, 'Rioja', 'Rioja', 'Rioja', 36.9450800, -2.4630200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42149, 'Ríogordo', 'Riogordo', 'Riogordo,Ríogordo', 36.9172700, -4.2931800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42150, 'Rincón de la Victoria', 'Rincon de la Victoria', 'Bezmiliana,Rinkon-de-la-Viktoria,Rinkon-de-la-Viktorija,lin kong de la wei ke tuo li ya,rynkwn dy la fyktwrya,Ринкон-де-ла-Викториа,Ринкон-де-ла-Виктория,Рінкон-де-ла-Вікторія,رينكون دي لا فيكتوريا,林孔德拉维克托里亚', 36.7171500, -4.2758300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42151, 'Rielves', 'Rielves', '', 39.9620600, -4.1930000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42152, 'Ricote', 'Ricote', 'Ricote', 38.1533800, -1.3655700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42153, 'Ribera del Fresno', 'Ribera del Fresno', 'Ribera del Fresno', 38.5517700, -6.2376800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42154, 'Ribarroja del Turia', 'Ribarroja del Turia', 'Riba-roja de Turia,Riba-roja de Túria,Ribarroja', 39.5459500, -0.5706900, 'ES', '2016-06-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42155, 'Retuerta de Bullaque', 'Retuerta de Bullaque', 'Retuerta,Retuerta de Bullaque,Returta', 39.4636300, -4.4136300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42156, 'Requena', 'Requena', 'Rekena,Requena,lei ke na,rekena,Рекена,レケナ,雷克纳', 39.4883400, -1.1004400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42157, 'Rena', 'Rena', '', 39.0525200, -5.8086800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42158, 'Relleu', 'Relleu', 'Relleu', 38.5872500, -0.3115700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42159, 'Reina', 'Reina', 'Reina', 38.1833300, -5.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42160, 'Reíllo', 'Reillo', 'Reillo,Reíllo', 39.9000000, -1.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42161, 'Redován', 'Redovan', 'Redova,Redovan,Redovà,Redován,lei duo wan,rdwban,Редован,ردوبان,雷多万', 38.1161900, -0.9098100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42162, 'Realejo Alto', 'Realejo Alto', 'Realejo Alto', 28.3764500, -16.5857500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42163, 'Real de Montroi', 'Real de Montroi', 'Real de Montroi,Real de Montroy', 39.3333300, -0.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42164, 'Real de Gandía', 'Real de Gandia', 'Real de Gandia,Real de Gandía', 38.9481700, -0.1923900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42165, 'Rágol', 'Ragol', 'Ragol,Rágol', 36.9952300, -2.6817800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42166, 'Ráfol de Salem', 'Rafol de Salem', 'El Rafol de Salem,El Ràfol de Salem,Rafol de Salem,Ráfol de Salem', 38.8665100, -0.3999100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42167, 'Rafelguaraf', 'Rafelguaraf', 'Rafelguaraf', 39.0512600, -0.4554300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42168, 'Rafelcofer', 'Rafelcofer', 'Rafelcofer', 38.9324800, -0.1677200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42169, 'Rafal', 'Rafal', 'Rafal,Rafal'',la fa er,rafal,Рафаль,رافال,拉法尔', 38.1045800, -0.8490400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42170, 'Rada de Haro', 'Rada de Haro', 'Rada de Haro', 39.5700200, -2.6208600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42171, 'Quintanar del Rey', 'Quintanar del Rey', '', 39.3333300, -1.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42172, 'Quintanar de la Orden', 'Quintanar de la Orden', 'Quintanar de la Orden,Quintanar la Orden', 39.5936900, -3.0416500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42173, 'Quintana de la Serena', 'Quintana de la Serena', 'Quintana de la Serena', 38.7459500, -5.6723300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42174, 'Quesada', 'Quesada', 'Quesada', 37.8433800, -3.0656100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42175, 'Quesa', 'Quesa', 'Quesa', 39.1197000, -0.7400000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42176, 'Quero', 'Quero', 'Quero', 39.5111100, -3.2474100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42177, 'Quéntar', 'Quentar', '', 37.1925300, -3.4665300, 'ES', '2008-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42178, 'Puçol', 'Pucol', 'Pucol,Puzol,Puçol', 39.6166700, -0.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42179, 'Purullena', 'Purullena', 'Parullena,Purullena', 37.3176300, -3.1905600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42180, 'Purchena', 'Purchena', 'Purchena,bwrtshyna,pu er qie na,pwrchna,Пурчена,بورتشينا,پورچنا,普尔切纳', 37.3474400, -2.3608000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42181, 'Puntallana', 'Puntallana', 'Puntallana,San Juan de Puntallana', 28.7333300, -17.7333300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42182, 'Puntagorda', 'Puntagorda', '', 28.7749000, -17.9774100, 'ES', '2015-06-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42183, 'Pulpí', 'Pulpi', 'Pulpi,Pulpí', 37.4115400, -1.7449600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42184, 'Pulianas', 'Pulianas', '', 37.2230200, -3.6083200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42185, 'Pulgar', 'Pulgar', 'Pulgar', 39.6938300, -4.1523300, 'ES', '2014-01-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42186, 'Pujerra', 'Pujerra', 'Pujerra', 36.6127400, -5.1497900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42187, 'Puigpunyent', 'Puigpunyent', 'Puigpunyent', 39.6251400, 2.5275900, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42188, 'Puig', 'Puig', 'El Puche,El Puig,Puig,Puig de Santa Maria,Puig de Santa María', 39.5886900, -0.3033300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42189, 'Puerto Serrano', 'Puerto Serrano', 'Puerto Serrano', 36.9220900, -5.5430400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42190, 'Puerto Real', 'Puerto Real', 'Puehrto-Real'',Puerto Real,Puerto-Real'',bwyrtw ryal,pueleutoleal,wang gang shi,Пуерто-Реаль,Пуэрто-Реаль,بويرتو ريال,王港市,푸에르토레알', 36.5281900, -6.1901100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42191, 'Puertollano', 'Puertollano', 'Puehrtol''jano,Puertojano,Puertolano,Puertollano,Puertolyano,UER,bwrtwlanw,pu ai er tuo li ya nuo,puerutoryano,Пуертояно,Пуертољано,Пуэртольяно,Պուերտոլյանո,بورتولانو,プエルトリャノ,普埃尔托利亚诺', 38.6871200, -4.1073400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42192, 'Puerto Lápice', 'Puerto Lapice', 'Puerto Lapice,Puerto Lápice', 39.3236000, -3.4814800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42193, 'Puerto de San Vicente', 'Puerto de San Vicente', 'Puerto de San Vicente', 39.5228300, -5.1140700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42194, 'Puerto de Santa Cruz', 'Puerto de Santa Cruz', 'Puerto de Santa Cruz', 39.3163100, -5.8587500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42195, 'Puerto del Rosario', 'Puerto del Rosario', 'Puehrto-del''-Rosario,Puerto Cabras,Puerto Rosario,Puerto de Cabras,Puerto del Rosario,Пуэрто-дель-Росарио', 28.5003800, -13.8627200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42196, 'Puerto de la Cruz', 'Puerto de la Cruz', 'Puehrto-de-la-Krus,Puerto de la Cruz,Puerto de la Krus,Puerto de la Krusas,Puerto-de-la-Krus,bwyrtw dy la krwth,pu ai er tuo de la ke lu si,Пуерто де ла Крус,Пуерто-де-ла-Крус,Пуэрто-де-ла-Крус,بويرتو دي لا كروث,普埃尔托德拉克鲁斯', 28.4139700, -16.5486700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42197, 'Puente-Genil', 'Puente-Genil', 'GEN,Puente Genil,Puente-Genil', 37.3894300, -4.7668600, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42198, 'Puente de Génave', 'Puente de Genave', 'Puente de Genave,Puente de Génave,Puente-Genave,Puente-Génave', 38.3554400, -2.8032000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42199, 'La Pobla Llarga', 'La Pobla Llarga', 'La Pobla Llarga,Puebla Larga', 39.0833300, -0.4666700, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42200, 'La Pobla de Vallbona', 'La Pobla de Vallbona', 'La Pobla de Vallbona,Puebla de Vallbona', 39.5974700, -0.5546800, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42201, 'Puebla de Sancho Pérez', 'Puebla de Sancho Perez', 'La Puebla,Puebla de Sancho Perez,Puebla de Sancho Pérez', 38.4000000, -6.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42202, 'Puebla de Obando', 'Puebla de Obando', 'Puebla de Obando', 39.1763000, -6.6276400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42203, 'Puebla del Salvador', 'Puebla del Salvador', 'Puebla del Salvador', 39.5666700, -1.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42204, 'Puebla del Prior', 'Puebla del Prior', 'Puebla del Prior', 38.5703200, -6.1958400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42205, 'Puebla del Príncipe', 'Puebla del Principe', 'Puebla del Principe,Puebla del Príncipe,Pueblo del Principe', 38.5676600, -2.9260500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42206, 'Puebla del Maestre', 'Puebla del Maestre', 'Puebla del Maestra,Puebla del Maestre,Puebla del Maestro', 38.0833300, -6.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42207, 'Puebla de la Reina', 'Puebla de la Reina', 'Puebla de la Reina', 38.6645500, -6.1021600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42208, 'Puebla de la Calzada', 'Puebla de la Calzada', 'Puebla de la Calzada', 38.8944100, -6.6259200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42209, 'Puebla de Guzmán', 'Puebla de Guzman', 'Puebla de Guzman,Puebla de Guzmán', 37.6142700, -7.2487800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42210, 'Puebla de Don Rodrigo', 'Puebla de Don Rodrigo', 'Puebla de Don Rodrigo', 39.0856400, -4.6196600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42211, 'Puebla de Don Fadrique', 'Puebla de Don Fadrique', 'La Puebla de Don Fadrique,Puebla de Don Fadrique', 37.9615600, -2.4396100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42212, 'Puebla de Almenara', 'Puebla de Almenara', 'Puebla-de-Al''menara,Puehbla-de-Al''menara,bwybla dy almnart,pu ai fu la de ya er mei na la,Пуебла-де-Альменара,Пуэбла-де-Альменара,بويبلا دي المنارة,普埃夫拉德亚尔梅纳拉', 39.7844000, -2.8143500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42213, 'Puebla de Alcocer', 'Puebla de Alcocer', 'Puebla de Alcocer,Puebla de Aloser,Puebla-de-Al''koser,Puehbla-de-Al''koser,bawybla dy alkwkyr,pu ai fu la de ya er ke sai er,Пуебла де Алосер,Пуебла-де-Алькосер,Пуэбла-де-Алькосер,باويبلا دي الكوكير,普埃夫拉德亚尔科塞尔', 38.9864800, -5.2563300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42214, 'Pruna', 'Pruna', 'Porcuna,Pruna', 36.9722600, -5.2223000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42215, 'Priego de Córdoba', 'Priego de Cordoba', 'Pr''ego-de-Kordoba,Priego,Priego-de-Kordova,bryghw dy qrtbt  qrtbt,pu lie ge de ke er duo wa,Прьего-де-Кордоба,Прієго-де-Кордова,بريغو دي قرطبة، قرطبة,普列戈德科尔多瓦', 37.4380700, -4.1952300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42216, 'Prado del Rey', 'Prado del Rey', 'Prado del Rey', 36.7875600, -5.5558900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42217, 'Pozuelo de Calatrava', 'Pozuelo de Calatrava', 'Posuehlo-de-Kalatrava,Posuelo de Kalatrava,Posuelo-de-Kalatrava,Pozuelo de Calatrava,bo su ai luo de ka la te la wa,bwzwylw dy kalatrafa,Посуело-де-Калатрава,Посуэло-де-Калатрава,Պոսուելո դե Կալատրավա,بوزويلو دي كالاترافا,波苏埃洛德卡拉特拉瓦', 38.5833300, -3.8333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42218, 'Pozuelo', 'Pozuelo', 'Pozuelo', 38.8098900, -2.1010100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42219, 'Pozorrubio', 'Pozorrubio', 'Posorrubio,Pozorrubio,Pozorrubio de Santiago,bo suo lu wei ao,bwzwrwbyw,Посоррубио,Посоррубіо,بوزوروبيو,波索鲁维奥', 39.8164500, -2.9493600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42220, 'Pozohondo', 'Pozohondo', 'Pozohondo', 38.7209500, -1.9119200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42221, 'Pozo-Cañada', 'Pozo-Canada', 'Pozo-Canada,Pozo-Cañada', 38.8033300, -1.7353200, 'ES', '2010-11-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42222, 'Pozoblanco', 'Pozoblanco', 'Posoblanko,Pozoblanco,bo suo fu lan ke,bwzwblankw  qrtbt,Пособланко,بوزوبلانكو، قرطبة,波索夫兰科', 38.3790600, -4.8482700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42223, 'Pozoamargo', 'Pozoamargo', 'Pozoamargo', 39.3655800, -2.1961700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42224, 'Pozo Alcón', 'Pozo Alcon', 'Pozo Alcon,Pozo Alcor,Pozo Alcón', 37.7025600, -2.9336700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42225, 'Povedilla', 'Povedilla', 'Povedilla', 38.7002200, -2.6021200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42226, 'Potríes', 'Potries', 'Potries,Potríes', 38.9161700, -0.1959400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42227, 'Posadas', 'Posadas', 'Posadas', 37.8020500, -5.1072600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42228, 'Porzuna', 'Porzuna', 'Porzuna', 39.1461800, -4.1540700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42229, 'Pórtugos', 'Portugos', '', 36.9419300, -3.3106600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42230, 'Porto Cristo', 'Porto Cristo', 'Porto Cristo,Porto Cristo Novo,Portocristo', 39.5395300, 3.3330200, 'ES', '2015-06-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42231, 'Portezuelo', 'Portezuelo', 'Portezuelo', 39.8123300, -6.4743300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42232, 'Portaje', 'Portaje', 'Portaje', 39.9175700, -6.5621800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42233, 'Porreres', 'Porreres', 'Porreras,Porreres', 39.5143400, 3.0219700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42234, 'Porcuna', 'Porcuna', 'Porcuna', 37.8710200, -4.1850100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42235, 'Polopos', 'Polopos', 'Polopos', 36.7946600, -3.2981600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42236, 'Polop', 'Polop', 'Polop,Polop de la Marina,bo luo pu,bwlwb,plp,Полоп,بولوب,پلپ,波洛普', 38.6225800, -0.1309000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42237, 'Pollença', 'Pollenca', 'Pollenca,Pollensa,Pollença', 39.8767800, 3.0162600, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42238, 'Polinyà de Xúquer', 'Polinya de Xuquer', 'Polina,Polina de Jucar,Polina del Jucar,Polinya de Xuquer,Polinyà de Xúquer,Poliña,Poliña de Júcar,Poliñá de Júcar,Poliñá del Júcar', 39.2000000, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42239, 'Polícar', 'Policar', 'Policar,Polícar', 37.2575900, -3.2337500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42240, 'Polán', 'Polan', 'Polan,Polán,bo lan,plan  aspanya,Полан,Պոլան,پلان، اسپانیا,波兰', 39.7876500, -4.1679200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42241, 'Poblete', 'Poblete', 'Poblete', 38.9355000, -3.9813700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42242, 'Pliego', 'Pliego', 'Pliego', 37.9894600, -1.5044400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42243, 'Playa Blanca', 'Playa Blanca', 'Plajja Blanka,Playa Blanca,QLY,Плайя Бланка', 28.8642600, -13.8281400, 'ES', '2015-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42244, 'Plasenzuela', 'Plasenzuela', 'Plasenzuela', 39.3819400, -6.0478600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42245, 'Planes', 'Planes', 'Planes,plans,pu la nei si,Планес,پلانس,普拉内斯', 38.7852400, -0.3427100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42246, 'Pizarra', 'Pizarra', '', 36.7654300, -4.7083300, 'ES', '2014-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42247, 'Piqueras del Castillo', 'Piqueras del Castillo', 'Piqueras del Castillo', 39.7166700, -2.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42248, 'Pinos Puente', 'Pinos Puente', 'Pinos Puente,Pinos-Puehnte,Pinos-Puente,bynws bwynty,pi nuo si peng te,Пинос-Пуэнте,Пінос-Пуенте,بينوس بوينتي,ピノス・プエンテ,皮诺斯蓬特', 37.2510900, -3.7496700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42249, 'Pinoso', 'Pinoso', 'El Pinos,El Pinós,El-Pinos,Pinos,Pinoso,Pinós,al baynws,pi nuo suo,pynsw,Ел-Пінос,Пиносо,إل باينوس,پینسو,皮诺索', 38.4016400, -1.0419600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42250, 'Pinos Genil', 'Pinos Genil', '', 37.1634600, -3.5021500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42251, 'Pinet', 'Pinet', 'Pinet', 38.9817600, -0.3387000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42252, 'Pinarejo', 'Pinarejo', 'Pinarejo', 39.6163900, -2.4259200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42253, 'Piñar', 'Pinar', 'Pinar,Piñar', 37.4445700, -3.4386100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42254, 'Piles', 'Piles', 'Piles', 38.9414300, -0.1328600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42255, 'Pilas', 'Pilas', 'Pilas', 37.3033700, -6.3009700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42256, 'Pilar de la Horadada', 'Pilar de la Horadada', 'El Pilar de Horadada,El Pilar de la Foradada,Pilar de la Horadada,Pilar-de-la-Oradada,baylar dy la hwradada,pi la er de la ao la da da,pylar dla hwradada,Пилар-де-ла-Орадада,Пілар-де-ла-Орадада,بايلار دي لا هورادادا,پیلار دلا هورادادا,皮拉尔德拉奥拉达达', 37.8659100, -0.7925600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42257, 'Piedras Albas', 'Piedras Albas', 'Piedras Albas', 39.7841700, -6.9258800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42258, 'Piedrabuena', 'Piedrabuena', 'Piedrabuena', 39.0353600, -4.1751200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42259, 'Picón', 'Picon', 'Picon,Picón', 39.0507400, -4.0608400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42260, 'Picassent', 'Picassent', 'Picasent,Picassent', 39.3635000, -0.4594900, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42261, 'Picanya', 'Picanya', 'Picana,Picanya,Picaña', 39.4333300, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42262, 'Pétrola', 'Petrola', 'Petrola,Pétrola', 38.8262800, -1.5566200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42263, 'Petrés', 'Petres', 'Petres,Petrés', 39.6833300, -0.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42264, 'Petra', 'Petra', 'Petra,Петра', 39.6135100, 3.1131200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42265, 'Pescueza', 'Pescueza', 'Pescueza', 39.9180700, -6.6458900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42266, 'Periana', 'Periana', '', 36.9293100, -4.1916300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42267, 'Peraleda de San Román', 'Peraleda de San Roman', 'Peraleda de San Roman,Peraleda de San Román', 39.7413000, -5.3872600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42268, 'Peraleda de la Mata', 'Peraleda de la Mata', 'Peraleda,Peraleda de la Mata', 39.8528800, -5.4606500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42269, 'Peñas de San Pedro', 'Penas de San Pedro', 'Penas de San Pedro,Peñas de San Pedro', 38.7288000, -2.0050000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42270, 'Peñarroya-Pueblonuevo', 'Penarroya-Pueblonuevo', 'Pen''jarroja-Pueblonuevo,Pen''jarroja-Puehblonuehvo,Penarroya-Pueblonuevo,Peñarroya-Pueblonuevo,Pueblonuevo del Terrible,bynyarwya-bwyblwnyyfw,pei ni ya luo ya-pu ai fu luo nu ai wo,Пеньярроя-Пуеблонуево,Пеньярроя-Пуэблонуэво,بينيارويا-بويبلونييفو,佩尼亚罗亚-普埃夫洛努埃沃', 38.3000000, -5.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42271, 'Peñalsordo', 'Penalsordo', 'Pen''jal''sordo,Penalsordo,Peñalsordo,bynyalswrdw,pei ni ya er suo er duo,Пеньяльсордо,Пењалсордо,بينيالسوردو,佩尼亚尔索尔多', 38.8201900, -5.1140500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42272, 'Peñaflor', 'Penaflor', 'Penaflor,Peñaflor', 37.7089200, -5.3450400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42273, 'Peligros', 'Peligros', '', 37.2323100, -3.6290100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42274, 'Pegalajar', 'Pegalajar', 'Pegalajar,Pegalapar', 37.7400800, -3.6494600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42275, 'Pedroso de Acim', 'Pedroso de Acim', 'Pedroso de Acim', 39.8252200, -6.4125100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42276, 'Pedro Muñoz', 'Pedro Munoz', 'Pedro Munoz,Pedro Muñoz', 39.4028500, -2.9466400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42277, 'Pedro Martínez', 'Pedro Martinez', 'Pedro Martinez,Pedro Martínez', 37.5029000, -3.2313400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42278, 'Pedroche', 'Pedroche', 'Pedroche', 38.4284800, -4.7632500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42279, 'Pedro Abad', 'Pedro Abad', 'Pedro Abad', 37.9668600, -4.4556000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42280, 'Pedrera', 'Pedrera', 'Pedrera,pei de lei la,Педрера,Պեդրերա,佩德雷拉', 37.2260400, -4.8942000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42281, 'Pedreguer', 'Pedreguer', 'Medreguer,Pedreguer', 38.7931200, 0.0341100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42282, 'Pedralba', 'Pedralba', 'Pedralba,Pedralva', 39.6000000, -0.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42283, 'Pechina', 'Pechina', 'Pechina', 36.9161900, -2.4368900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42284, 'Peal de Becerro', 'Peal de Becerro', 'Peal de Becerro', 37.9133800, -3.1214800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42285, 'Paymogo', 'Paymogo', 'Paymogo', 37.7399900, -7.3449900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42286, 'Pavías', 'Pavias', 'Pavias,Pavies,Pavías', 39.9666700, -0.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42287, 'Paterna de Rivera', 'Paterna de Rivera', 'Paterna de Rivera,Paterna de la Rivera', 36.5224600, -5.8657800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42288, 'Paterna del Río', 'Paterna del Rio', 'Palerna del Rio,Palerna del Río', 37.0222200, -2.9534300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42289, 'Paterna del Madera', 'Paterna del Madera', 'Paterna del Madera', 38.5975100, -2.3442100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42290, 'Paterna del Campo', 'Paterna del Campo', 'Paterna del Camino,Paterna del Campo', 37.4194800, -6.4024800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42291, 'Paterna', 'Paterna', 'Paterna,pa te er na,pateruna,Патерна,パテルナ,帕特尔纳', 39.5000000, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42292, 'Partaloa', 'Partaloa', 'Partaloa', 37.4076400, -2.2252600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42293, 'Parcent', 'Parcent', 'Parcent', 38.7450200, -0.0644600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42294, 'Parauta', 'Parauta', 'Parauta', 36.6562900, -5.1291600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42295, 'Paradas', 'Paradas', 'Paradas', 37.2904700, -5.4970300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42296, 'Paracuellos', 'Paracuellos', 'Paracuellos', 39.7166700, -1.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42297, 'Pampaneira', 'Pampaneira', '', 36.9401500, -3.3609600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42298, 'Palos de la Frontera', 'Palos de la Frontera', 'Palos,Palos de la Frontera,Palos-de-la-Frontera,balws dy la frwntyra,pa luo si de la fu long te la,Палос-де-ла-Фронтера,بالوس دي لا فرونتيرا,パロス・デ・ラ・フロンテーラ,帕洛斯德拉夫龙特拉', 37.2345700, -6.8947100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42299, 'Palomas', 'Palomas', 'Palomas', 38.6927700, -6.1349000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42300, 'Palomares del Río', 'Palomares del Rio', 'Palomares,Palomares del Rio,Palomares del Río', 37.3222500, -6.0586300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42301, 'Palomares del Campo', 'Palomares del Campo', 'Palomares del Campo', 39.9466400, -2.5977600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42302, 'Palmera', 'Palmera', 'Palmera', 38.9392700, -0.1541100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42303, 'Palma', 'Palma', 'Ciutat de Mallorca,Madina Mayurqa,PMI,Pal''ma,Palma,Palma Mallorcakoa,Palma de Maiorca,Palma de Majorque,Palma de Malhorca,Palma de Malhòrca,Palma de Mallorca,Palma di Maiorca,mywrqt,pa er ma,palmademayoleuka,plmh dh mywrqh,Пальма,פלמה דה מיורקה,ميورقة,パルマ・デ・マリョルカ,帕爾馬,팔마데마요르카', 39.5693900, 2.6502400, 'ES', '2016-12-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42304, 'Palma del Río', 'Palma del Rio', 'Pal''ma-del''-Rio,Palma del Rio,Palma del Río,balma dyl ryw,pa er ma de er li ao,Πάλμα δελ Ρίο,Пальма-дель-Рио,Пальма-дель-Ріо,بالما ديل ريو,帕尔马德尔里奥', 37.7002400, -5.2812100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42305, 'Palma de Gandía', 'Palma de Gandia', 'Palma de Gandia,Palma de Gandía', 38.9267200, -0.2202800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42306, 'Palenciana', 'Palenciana', 'Palenciana', 37.2485100, -4.5826100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42307, 'Pajaroncillo', 'Pajaroncillo', 'Pajaroncillo', 39.9500000, -1.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42308, 'Pajarón', 'Pajaron', 'Pajaron,Pajarón', 39.9500000, -1.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42309, 'Pájara', 'Pajara', 'Pajara,Pájara', 28.3503900, -14.1076000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42310, 'Paiporta', 'Paiporta', 'Paiporta,Pajporta,Пайпорта', 39.4281400, -0.4176500, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42311, 'Padules', 'Padules', 'Padules', 36.9981300, -2.7736700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42312, 'Padul', 'Padul', '', 37.0246200, -3.6267800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42313, 'Otura', 'Otura', '', 37.0884600, -3.6332100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42314, 'Otos', 'Otos', 'Otos', 38.8542700, -0.4439900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42315, 'Otívar', 'Otivar', 'Otivar,Otívar', 36.8158200, -3.6797900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42316, 'Otero', 'Otero', 'Otero', 40.0009600, -4.5153900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42317, 'Osuna', 'Osuna', 'Osuna,ao su na,ashwnt,osuna,Осуна,أشونة,オスナ,奥苏纳', 37.2376000, -5.1031100, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42318, 'Ossa de Montiel', 'Ossa de Montiel', 'Osa de Montiel,Ossa de Montiel', 38.9639800, -2.7455300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42319, 'Osa de la Vega', 'Osa de la Vega', 'Osa de la Vega', 39.6597700, -2.7599800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42320, 'Oropesa', 'Oropesa', 'Oropesa,Oropesa y Corchueta,Oropesay Corchuela', 39.9172600, -5.1737100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42321, 'Órjiva', 'Orjiva', 'Orgiva,Orjiva,Órgiva,Órjiva', 36.9025900, -3.4237900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42322, 'Orihuela', 'Orihuela', 'Auraiola,Aurariola,Orihuela,Oriola,Oriouela,Oriuehla,Oriuela,Orivela,ao li wei la,aryhwyla,awrywyla,oriuera,Οριουέλα,Оривела,Ориуэла,Оріуела,Օրիուելա,أوريويلا,اریهوئلا,اوریہیولا,オリウエラ,奥里韦拉', 38.0848300, -0.9440100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42323, 'Oria', 'Oria', 'Oria', 37.4853000, -2.2929200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42324, 'Orgaz', 'Orgaz', 'Orgas,ao er jia si,Оргас,奥尔加斯', 39.6482600, -3.8757700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42325, 'Orellana la Vieja', 'Orellana la Vieja', 'Orel''jana-la-V''ekha,Orel''jana-la-Vekha,Orelana la Viekha,Orellana la Vieja,ao lei li ya na la wei ye ha,awrylana la fayja,Орелана ла Виеха,Орельяна-ла-Вьеха,Орельяна-ла-Вєха,أوريلانا لا فايجا,奥雷利亚纳拉维耶哈', 39.0061700, -5.5344100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42326, 'Orcheta', 'Orcheta', 'Orcheta,Orxeta', 38.5639700, -0.2629900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42327, 'Orcera', 'Orcera', '', 38.3174200, -2.6648700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42328, 'Orce', 'Orce', 'Orce', 37.7212000, -2.4775200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42329, 'Orba', 'Orba', 'Orba', 38.7804100, -0.0627800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42330, 'Ontur', 'Ontur', 'Ontar,Ontur', 38.6150900, -1.4972400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42331, 'Ontígola', 'Ontigola', '', 40.0042100, -3.5722700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42332, 'Ontinyent', 'Ontinyent', 'Onten''ente,Onteniente,Ontinyent,Онтеньенте', 38.8219100, -0.6060300, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42333, 'Onil', 'Onil', 'Onil,Onil'',anyl,ao ni er,awnayl,Ониль,Оніл,أونايل,انیل,奥尼尔', 38.6260600, -0.6731300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42334, 'Ondara', 'Ondara', 'Ondara', 38.8281700, 0.0172000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42335, 'Onda', 'Onda', 'Onda,awnda,weng da,Онда,أوندا,翁达', 39.9649500, -0.2604100, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42336, 'Olvera', 'Olvera', 'Ol''vera,Olvera,ao er wei la,awlfyra,awlwyra,Ольвера,Օլվերա,أولفيرا,اولویرا,奥尔维拉', 36.9341800, -5.2667800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42337, 'Olula del Río', 'Olula del Rio', 'Olula', 37.3544500, -2.2975400, 'ES', '2015-09-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42338, 'Olula de Castro', 'Olula de Castro', 'Olula,Olula de Castro,Ulula de Castro', 37.1747500, -2.4743000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42339, 'Olocau', 'Olocau', 'Olocau', 39.7000000, -0.5333300, 'ES', '2014-05-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42340, 'Olmedilla de Alarcón', 'Olmedilla de Alarcon', 'Olmedilla de Alarcon,Olmedilla de Alarcón', 39.6166700, -2.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42341, 'Olmeda del Rey', 'Olmeda del Rey', 'Olmeda del Rey', 39.8000000, -2.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42342, 'L''Olleria', 'L''Olleria', 'L''Olleria,Olleria,Ollería', 38.9166700, -0.5500000, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42343, 'Olivares de Júcar', 'Olivares de Jucar', 'Olivares,Olivares de Jucar,Olivares de Júcar', 39.7610100, -2.3558900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42344, 'Olivares', 'Olivares', 'Olivares,ao li wa lei si,Оливарес,Оліварес,Օլիվարես,奥利瓦雷斯', 37.4180200, -6.1560300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42345, 'Oliva de Mérida', 'Oliva de Merida', 'Oliva de Merida,Oliva de Mérida,Oliva-de-Merida,ao li wa de mei li da,awlayfa dy myrayda,Олива де Мерида,Олива-де-Мерида,Оліва-де-Меріда,أولايفا دي ميرايدا,奥利瓦德梅里达', 38.7905100, -6.1240200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42346, 'Oliva de la Frontera', 'Oliva de la Frontera', 'Oliva de Frontera,Oliva de Jerez,Oliva de la Frontera,Oliva-de-la-Frontera,ao li wa de la fu long te la,awlayfa dy la frwntyra,Олива де ла Фронтера,Олива-де-ла-Фронтера,Оліва-де-ла-Фронтера,أولايفا دي لا فرونتيرا,奥利瓦德拉夫龙特拉', 38.2759500, -6.9187300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42347, 'Oliva', 'Oliva', 'Oliva,Олива', 38.9197100, -0.1193500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42348, 'Olías del Rey', 'Olias del Rey', '', 39.9443600, -3.9868400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42349, 'Ojós', 'Ojos', 'Ojos,Ojós', 38.1470000, -1.3426100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42350, 'Ojén', 'Ojen', 'Ojen,Ojén', 36.5648600, -4.8556100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42351, 'Ohanes', 'Ohanes', 'Ohanes', 37.0386100, -2.7452400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42352, 'Ogíjares', 'Ogijares', '', 37.1191300, -3.6077200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42353, 'Ocaña', 'Ocana', '', 39.9578500, -3.4982000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42354, 'Obejo', 'Obejo', 'Obejo,Ovejo', 38.1326500, -4.8001800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42355, 'Nules', 'Nules', 'Nules', 39.8536200, -0.1564300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42356, 'Nueva-Carteya', 'Nueva-Carteya', 'Nueva-Carteya', 37.5863000, -4.4675900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42357, 'Novelda', 'Novelda', 'Novel''da,Novelda,Новельда', 38.3847900, -0.7677300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42358, 'Nogales', 'Nogales', 'Nogales', 38.5862900, -6.7490100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42359, 'Noez', 'Noez', 'Noez', 39.7409400, -4.1840800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42360, 'Noblejas', 'Noblejas', '', 39.9806100, -3.4400100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42361, 'Noalejo', 'Noalejo', 'Noalejo', 37.5301700, -3.6561500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42362, 'Nívar', 'Nivar', '', 37.2590900, -3.5776800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42363, 'Níjar', 'Nijar', 'Nikhar,Нихар', 36.9665500, -2.2059500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42364, 'Nigüelas', 'Niguelas', '', 36.9776000, -3.5394900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42365, 'Niebla', 'Niebla', 'N''ebla,Niebla,lblt,nie fu la,Ньебла,Ньєбла,Նիեբլա,لبلة,涅夫拉', 37.3621300, -6.6789400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42366, 'Nerva', 'Nerva', 'Nerva', 37.6962700, -6.5496700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42367, 'Nerpio', 'Nerpio', 'Nerpio', 38.1475100, -2.3020200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42368, 'Nerja', 'Nerja', 'Nerja', 36.7527800, -3.8744000, 'ES', '2013-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42369, 'Nazaret', 'Nazaret', 'Nazaret,Назарет', 29.0381800, -13.5638600, 'ES', '2013-01-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42370, 'Navezuelas', 'Navezuelas', 'Navezuelas', 39.5091800, -5.4376600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42371, 'Navas del Madroño', 'Navas del Madrono', 'Navas del Madrono,Navas del Madroño,Navas del Modrono', 39.6229000, -6.6526000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42372, 'Navas de Jorquera', 'Navas de Jorquera', 'Navas de Jorquera', 39.2833300, -1.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42373, 'Navas de Estena', 'Navas de Estena', 'Navas de Estena', 39.4948100, -4.5215500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42374, 'Navarrés', 'Navarres', 'Navarres,Navarrés', 39.1019800, -0.6946900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42375, 'Navalvillar de Pela', 'Navalvillar de Pela', 'Naval''vil''jar-de-Pela,Navalvilar de Pela,na wa er wei li ya er de pei la,nafalfaylar dy byla,Навалвилар де Пела,Навальвильяр-де-Пела,Навальвільяр-де-Пела,نافالفايلار دي بيلا,纳瓦尔维利亚尔德佩拉', 39.0943600, -5.4681000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42376, 'Navalvillar de Ibor', 'Navalvillar de Ibor', 'Navalvillar de Ibor', 39.5838900, -5.4132800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42377, 'Navalpino', 'Navalpino', 'Navalpino', 39.2257300, -4.5913300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42378, 'Navalmoralejo', 'Navalmoralejo', 'Navalmoralejo', 39.7392900, -5.1435900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42379, 'Navalmoral de la Mata', 'Navalmoral de la Mata', 'Naval''moral''-de-la-Mata,Navalmoral,Navalmoral de la Mata,Navalmoral de la Mota,QWW,na wa er mo la er de la ma ta,nafalmwral dy la mata,Навальмораль-де-ла-Мата,نافالمورال دي لا ماتا,纳瓦尔莫拉尔德拉马塔', 39.8915800, -5.5406400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42380, 'Navajas', 'Navajas', 'Navachas,Navaixes,Navajas,Navakhas,na wa ha si,nafakhas,Навахас,نافاخاس,纳瓦哈斯', 39.8833300, -0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42381, 'Navahermosa', 'Navahermosa', 'Navahermosa', 39.6352600, -4.4701200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42382, 'Narboneta', 'Narboneta', 'Narboneta', 39.7500000, -1.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42383, 'Náquera', 'Naquera', 'Naquera,Nàquera,Náquera', 39.6500000, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42384, 'Nambroca', 'Nambroca', 'Nambroca', 39.7977100, -3.9443400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42385, 'Museros', 'Museros', 'Museros', 39.5666700, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42386, 'Murtas', 'Murtas', 'Murtas', 36.8850400, -3.1094500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42387, 'Muro del Alcoy', 'Muro del Alcoy', 'Muro,Muro de Alcoy,Muro del Alcoy', 38.7812000, -0.4360800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42388, 'Muro', 'Muro', 'Muro', 39.7366100, 3.0555900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42389, 'Murla', 'Murla', 'Murla', 38.7603700, -0.0820800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42390, 'Murcia', 'Murcia', 'Ciutat de Murcia,Ciutat de Múrcia,MJV,Murcia,Murcie,Murcio,Murcja,Mursia,Mursija,Múrcia,mrsyt,mu er xi ya,murushia,mwrsya,mwrsyh,Мурсия,מורסיה,مرسية,مورسیا,ムルシア,穆尔西亚', 37.9870400, -1.1300400, 'ES', '2013-03-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42391, 'Munera', 'Munera', 'Munera', 39.0421700, -2.4806800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42392, 'Mula', 'Mula', 'Mula', 38.0409500, -1.4901400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42393, 'Mutxamel', 'Mutxamel', 'Muchamiel,Mutxamel', 38.4158000, -0.4452900, 'ES', '2016-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42394, 'Moya', 'Moya', 'Moya', 39.9500000, -1.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42395, 'Moya', 'Moya', 'Moya', 28.1013600, -15.5891700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42396, 'Motril', 'Motril', 'Motril,Motril'',mo te li er,motoriru,mwtryl,Мотрил,Мотриль,Мотріль,موتريل,モトリル,莫特里尔', 36.7506600, -3.5179000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42397, 'Motilleja', 'Motilleja', 'Motilleja', 39.1833300, -1.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42398, 'Motilla del Palancar', 'Motilla del Palancar', 'Motilla del Palancar', 39.5666700, -1.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42399, 'Mota del Cuervo', 'Mota del Cuervo', 'Mata del Cuervo,Mota del Cuervo', 39.5018900, -2.8699400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42400, 'Mota de Altarejos', 'Mota de Altarejos', 'Mota de Altarejos', 39.8820100, -2.3095800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42401, 'Morón de la Frontera', 'Moron de la Frontera', 'Moron,Moron de la Frontera,Moron-de-la-Frontera,Morón,Morón de la Frontera,OZP,mo long de la fu long te la,mwrwr,Морон-де-ла-Фронтера,مورور,莫龙德拉夫龙特拉', 37.1208400, -5.4540300, 'ES', '2013-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42402, 'Moraira', 'Moraira', 'Moraira,Morajra,Морайра', 38.6886600, 0.1348400, 'ES', '2010-10-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42403, 'Moratalla', 'Moratalla', 'Moratalla', 38.1892800, -1.8918300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42404, 'Moraleda de Zafayona', 'Moraleda de Zafayona', 'Moraleda de Zafayona', 37.1672300, -3.9650500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42405, 'Moral de Calatrava', 'Moral de Calatrava', 'Moral de Calatrava', 38.8298900, -3.5781300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42406, 'Mora', 'Mora', 'Mora', 39.6849200, -3.7739400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42407, 'Monturque', 'Monturque', 'Monturke,meng tu er ke,mwntwrkwy  qrtbt,Монтурке,مونتوركوي، قرطبة,蒙图尔克', 37.4718600, -4.5816400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42408, 'Montuïri', 'Montuiri', 'Montuiri,Montuïri', 39.5674200, 2.9818900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42409, 'Montroy', 'Montroy', 'Montroi,Montroy', 39.3333300, -0.6166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42410, 'Montoro', 'Montoro', 'Aebura,Aipora,Aypora,Epora,Iipora,Montoro,Ypora', 38.0240900, -4.3834000, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42411, 'Montizón', 'Montizon', 'Montizon,Montizón', 38.3424900, -3.1040400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42412, 'Montillana', 'Montillana', 'Montillana', 37.5016800, -3.6736800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42413, 'Montilla', 'Montilla', 'Montil''ja,Montilla,Munda,OZU,meng di li ya,montiya,mwntyla  qrtbt,Монтилья,Монтілья,مونتيلا، قرطبة,蒙蒂利亚,몬티야', 37.5862700, -4.6380500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42414, 'Montijo', 'Montijo', 'Montijo', 38.9083900, -6.6178500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42415, 'Montiel', 'Montiel', 'Montiel', 38.6980200, -2.8644100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42416, 'Montichelvo', 'Montichelvo', 'Montichelvo,Montixelvo', 38.8912900, -0.3412300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42417, 'Montesa', 'Montesa', 'Montesa', 38.9503000, -0.6520000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42418, 'Monterrubio de la Serena', 'Monterrubio de la Serena', 'Monterrubio,Monterrubio de la Serena', 38.5887600, -5.4456900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42419, 'Montemolín', 'Montemolin', 'Montemolin,Montemolín', 38.1500000, -6.2000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42420, 'Montemayor', 'Montemayor', 'Montemayor', 37.6479000, -4.6977900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42421, 'Montellano', 'Montellano', 'Montellano', 36.9953100, -5.5714500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42422, 'Montejicar', 'Montejicar', 'Montejicar', 37.5722300, -3.5052700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42423, 'Montejaque', 'Montejaque', 'Montejaque', 36.7368400, -5.2499000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42424, 'Montefrío', 'Montefrio', 'Montefrio,meng te fu li ao,mwntyfryw,Монтефрио,Монтефріо,مونتيفريو,蒙特夫里奥', 37.3230800, -4.0089800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42425, 'Montecorto', 'Montecorto', '', 36.8158000, -5.2980300, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42426, 'Montearagón', 'Montearagon', 'Montearagon,Montearagón', 39.9642500, -4.6321400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42427, 'Montealegre del Castillo', 'Montealegre del Castillo', 'Montealegre,Montealegre del Castillo', 38.7885600, -1.3272200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42428, 'Monteagudo de las Salinas', 'Monteagudo de las Salinas', 'Monteagudo de las Salinas', 39.8000000, -1.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42429, 'Montánchez', 'Montanchez', 'Montanches,Montanchez,Montánchez,meng tan qie si,mwntanshyz,Монтанчес,مونتانشيز,蒙坦切斯', 39.2254800, -6.1491400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42430, 'Montalvos', 'Montalvos', 'Montalvos', 39.1666700, -2.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42431, 'Montalbo', 'Montalbo', 'Montalbo,Montalvo', 39.8799400, -2.6703800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42432, 'Montalbanejo', 'Montalbanejo', 'Montalbanejo', 39.7336900, -2.4991100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42433, 'Montalbán de Córdoba', 'Montalban de Cordoba', 'Montal''ban-de-Kordoba,Montal''ban-de-Kordova,Montalban de Cordoba,Montalbán de Córdoba,meng ta er wan de ke er duo wa,mwntalban dy qrtbt  qrtbt,Монтальбан-де-Кордоба,Монтальбан-де-Кордова,مونتالبان دي قرطبة، قرطبة,蒙塔尔万德科尔多瓦', 37.5799600, -4.7493500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42434, 'Montaberner', 'Montaberner', '', 38.8902100, -0.4958200, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42435, 'Monserrat', 'Monserrat', 'Monserrat,Montserrat d''Alcala,Montserrat d''Alcalà', 39.3666700, -0.6000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42436, 'Monreal del Llano', 'Monreal del Llano', 'Monreal del Llano', 39.5688800, -2.7604600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42437, 'Monóvar', 'Monovar', 'Monovar,Monover,Monòver,Monóvar,mo nuo wa er,mwnwbar,mwnwfar,Моновар,Моновер,مونوبار,مونوفار,莫诺瓦尔', 38.4380900, -0.8406200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42438, 'Monforte del Cid', 'Monforte del Cid', 'Monforte,Monforte de la Rambla,Monforte del Cid,Monforte-del''-Sid,Mont-fort,Montfort,Montfort del Cid,meng fu er te de er xi de,mnfrth dl syd,Монфорте-дель-Сид,Монфорте-дель-Сід,منفرته دل سید,蒙福尔特德尔西德', 38.3802700, -0.7285000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42439, 'Monesterio', 'Monesterio', 'Monasterio,Monesterio,Monestorio', 38.0833300, -6.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42440, 'Monda', 'Monda', 'Monda,meng da,mwnda,Монда,Մոնդա,موندا,蒙达', 36.6302700, -4.8319200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42441, 'Moncofa', 'Moncofa', 'Mocofar,Moncofa,Moncofar,Moncófar', 39.8090700, -0.1470100, 'ES', '2015-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42442, 'Moncada', 'Moncada', 'Moncada,Monkada,Montcada,Монкада', 39.5455500, -0.3955100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42443, 'Monachil', 'Monachil', 'Monachil', 37.1332000, -3.5372400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42444, 'Molvízar', 'Molvizar', 'Molvizar,Molvízar', 36.7859200, -3.6078300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42445, 'Mollina', 'Mollina', 'Mollina', 37.1253400, -4.6568600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42446, 'Molinicos', 'Molinicos', 'Molinicos', 38.4671700, -2.2393900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42447, 'Molina de Segura', 'Molina de Segura', 'Molina,Molina de Segura,Molina-de-Segura,mo li na de sai gu la,mwlyna dy syghwra,Молина де Сегура,Молина-де-Сегура,Моліна-де-Сегура,مولينا دي سيغورا,モリナ・デ・セグラ,莫利纳德塞古拉', 38.0545600, -1.2076300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42448, 'Mojacar', 'Mojacar', 'Mojacar,Mojacar Pueblo,Mojácar,Mojácar Pueblo', 37.1402000, -1.8510200, 'ES', '2015-06-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42449, 'Mohedas de la Jara', 'Mohedas de la Jara', 'Mohedas de la Jara', 39.6041700, -5.1424700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42450, 'Moguer', 'Moguer', 'Moger,Moguer,mo ge er,mwghyr,Могер,موغير,莫格尔', 37.2755900, -6.8385100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42451, 'Mogente', 'Mogente', 'Mogente', 38.8759800, -0.7515000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42452, 'Mogán', 'Mogan', 'Mogan,Mogán', 27.8838500, -15.7253800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42453, 'Moclinejo', 'Moclinejo', '', 36.7713400, -4.2551400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42454, 'Moclín', 'Moclin', '', 37.3395900, -3.7865100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42455, 'Mocejón', 'Mocejon', 'Mocejon,Mocejón', 39.9393400, -3.9171600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42456, 'Mislata', 'Mislata', 'Mislata,Mizlata,mi si la ta,Мислата,Міслата,米斯拉塔', 39.4752300, -0.4182500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42457, 'Mirandilla', 'Mirandilla', 'Mirandilla', 39.0020000, -6.2889300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42458, 'Miramar', 'Miramar', 'Miramar', 38.9503600, -0.1400700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42459, 'Mirabel', 'Mirabel', 'Mirabel,Mirabel'',mi la wei er,myrabl,Мирабель,Мірабель,ميرابل,米拉韦尔', 39.8623000, -6.2327400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42460, 'Mira', 'Mira', 'Mira,mi la,myra  qwnkt,Мира,Міра,ميرا، قونكة,米拉', 39.7166700, -1.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42461, 'Minglanilla', 'Minglanilla', 'Minglanil''ja,Minglanilla,Minglanillo,ming la ni li ya,mynghlanyla,Мингланилья,Мінгланілья,مينغلانيلا,明拉尼利亚', 39.5333300, -1.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42462, 'Minaya', 'Minaya', 'Minaya', 39.2705200, -2.3217600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42463, 'Millena', 'Millena', 'Millena', 38.7308200, -0.3627400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42464, 'Millares', 'Millares', 'Millares,Millars', 39.2500000, -0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42465, 'Millanes', 'Millanes', 'Millanes', 39.8491700, -5.5807900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42466, 'Mijas', 'Mijas', 'Mijas,Mikhas,mi ha si,mihasu,mykhas,Михас,Міхас,ميخاس,ミハス,米哈斯', 36.5957500, -4.6372800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42467, 'Miguelturra', 'Miguelturra', 'Migel''turra,Miguelturra,mi ge er tu la,myghwyltwra,Мигельтурра,Мігельтурра,ميغويلتورا,米格尔图拉', 38.9644200, -3.8904700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42468, 'Miguel Esteban', 'Miguel Esteban', 'Miguel Esteban', 39.5244800, -3.0761800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42469, 'Miajadas', 'Miajadas', 'M''jakhadas,Miajadas,Miajas,Miajás,Miakhadas,mi ya ha da si,myakhadas,Мьяхадас,Міахадас,مياخاداس,米亚哈达斯', 39.1512700, -5.9084100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42470, 'Mestanza', 'Mestanza', 'Mestanza', 38.5761600, -4.0709600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42471, 'Mesas de Ibor', 'Mesas de Ibor', 'Mesas de Ibor', 39.7558700, -5.5463700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42472, 'Mérida', 'Merida', 'Emerita Augusta,Merida,Merido,Mérida,QWX,merida,mryda,mrydh,Мерида,מרידה,مریدا,メリダ', 38.9161100, -6.3436600, 'ES', '2013-08-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42473, 'Mercadal', 'Mercadal', '', 39.9901400, 4.0938700, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42474, 'Mengibar', 'Mengibar', 'Mengibar', 37.9697800, -3.8088400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42475, 'Mengabril', 'Mengabril', 'Mengabril', 38.9355400, -5.9333500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42476, 'Menasalbas', 'Menasalbas', 'Menasalbas', 39.6395400, -4.2841800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42477, 'Membrilla', 'Membrilla', 'Membrilla', 38.9719800, -3.3433000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42478, 'Melilla', 'Melilla', 'Ciudad Autonoma de Melilla,Ciudad Autónoma de Melilla,Ciudad de Melilla,Korisnik:Slaven Kosanovic/Melila,Lungsod ng Melilla,M''lila,MLN,Melil''ja,Melila,Melilla,Melilo,Melilya,Meliya,Millela,Rusaddir,Rusadir,Russadir,me li ya,mei li li ya,melilia,melliya,merirya,mlylyh,mlylyt,mlyyh,Корисник:Славен Косановић/Мелиља,Мелила,Мелилья,Мелиља,מלייה,مليلية,ملیلیه,เมลียา,მელილია,メリリャ,梅利利亚,멜리야', 35.2936900, -2.9383300, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42479, 'Meliana', 'Meliana', 'Meliana', 39.5333300, -0.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42480, 'Medina Sidonia', 'Medina Sidonia', 'Medina Sidonia,Medina-Sidonia', 36.4569500, -5.9271700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42481, 'Medina de las Torres', 'Medina de las Torres', 'Medina de las Torres', 38.3333300, -6.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42482, 'Medellín', 'Medellin', 'Medellin,Medellín', 38.9626500, -5.9578500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42483, 'Mazo', 'Mazo', 'El Pueblo,Mazo', 28.6090600, -17.7780100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42484, 'Mazarrón', 'Mazarron', 'Masarron,Mazarron,Mazarrón,Масаррон', 37.5992000, -1.3149300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42485, 'Mazarambroz', 'Mazarambroz', '', 39.6941100, -4.0196200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42486, 'Mazagón', 'Mazagon', 'Caserio Marzagon,Caserío Marzagón,Marzagon,Marzagón,Mazagon,Mazagón', 37.1141700, -6.7644400, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42487, 'Matet', 'Matet', 'Matet', 39.9333300, -0.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42488, 'Mata de Alcántara', 'Mata de Alcantara', 'Mata de Alcantara,Mata de Alcántara', 39.7173800, -6.8182500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42489, 'Maspalomas', 'Maspalomas', 'Maspalomas,Maspalomasos,Маспаломас', 27.7605600, -15.5860200, 'ES', '2013-11-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42490, 'Masegoso', 'Masegoso', 'Masegoso', 38.7183300, -2.3161000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42491, 'Mascaraque', 'Mascaraque', 'Mascaraque', 39.7164300, -3.8125400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42492, 'Massamagrell', 'Massamagrell', 'Masamgrell', 39.5666700, -0.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42493, 'Masalavés', 'Masalaves', 'Masalaves,Masalavés,Massalaves,Massalavés', 39.1437700, -0.5226000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42494, 'Martos', 'Martos', 'Martos,ma er tuo si,marts,martws,martws  khayn,Мартос,مارتس,مارتوس,مارتوس، خاين,马尔托斯', 37.7210700, -3.9726400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42495, 'Martín de la Jara', 'Martin de la Jara', 'Martin de la Jara,Martín de la Jara', 37.1086700, -4.9634700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42496, 'Marratxí', 'Marratxi', 'Marrachi,Marratxi,Marratxí,Маррачи', 39.6214200, 2.7253000, 'ES', '2015-10-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42497, 'Marmolejo', 'Marmolejo', 'Aebura,Ipora,Marmolejo,Marmolekho,Marmolexo,ma er mo lai huo,marmlkhw,marmwlykhw,Мармолехо,Մարմոլեխո,مارملخو,مارموليخو,马尔莫莱霍', 38.0454900, -4.1702900, 'ES', '2012-08-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42498, 'Marjaliza', 'Marjaliza', '', 39.5632900, -3.9349900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42499, 'Marines', 'Marines', 'Marines,Marines el Viejo', 39.7416500, -0.5310300, 'ES', '2015-04-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42500, 'Marinaleda', 'Marinaleda', 'Marinaleda,ma li na lai da,Мариналеда,Маріналеда,马里纳莱达', 37.3712000, -4.9594900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42501, 'Maria de la Salut', 'Maria de la Salut', 'Maria,Maria de la Salut', 39.6630600, 3.0730000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42502, 'María', 'Maria', 'Maria,María', 37.7102300, -2.1645400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42503, 'Marchena', 'Marchena', 'Marchena', 37.3290000, -5.4168100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42504, 'Marchal', 'Marchal', 'Marchal', 37.2963900, -3.2035300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42505, 'Marbella', 'Marbella', 'Gorad Marbellja,Marbel''ja,Marbela,Marbelja,Marbella,Marbelya,Marvegia,QRL,ma bei la,maleubeya,marbella,marbla,marbya,marbyla,maruberya,Μαρβέγια,Горад Марбелля,Марбeлья,Марбелья,Марбеля,Марбеља,Մարբելյա,ماربلا,ماربيا,ماربيلا,ماربیا,मार्बेल्ला,マルベーリャ,马贝拉,마르베야', 36.5154300, -4.8858300, 'ES', '2015-04-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42506, 'Maracena', 'Maracena', '', 37.2076400, -3.6349300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42507, 'Manzanilla', 'Manzanilla', 'Manzanilla', 37.3898700, -6.4329500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42508, 'Manzaneque', 'Manzaneque', 'Manzaneque', 39.6354900, -3.7924900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42509, 'Manzanares', 'Manzanares', 'Manzanares,Manzanarre', 38.9991500, -3.3699100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42510, 'Manuel', 'Manuel', 'Manuel', 39.0505900, -0.4897800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42511, 'Manises', 'Manises', 'Manises,Манисес', 39.4913900, -0.4634900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42512, 'Manilva', 'Manilva', '', 36.3764500, -5.2502600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42513, 'Mancor de la Vall', 'Mancor de la Vall', 'Mancor,Mancor de la Vall', 39.7496600, 2.8728400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42514, 'Manchita', 'Manchita', 'Manchita', 38.8140400, -6.0204100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42515, 'Mancha Real', 'Mancha Real', 'Mancha Real', 37.7862700, -3.6122600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42516, 'Manacor', 'Manacor', 'Manacor,Manakor,Манакор', 39.5696400, 3.2095500, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42517, 'Malpica', 'Malpica', 'Malpica', 39.8974600, -4.5498800, 'ES', '2012-02-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42518, 'Malpartida de Plasencia', 'Malpartida de Plasencia', 'Mal''partida-de-Plasensia,Mal''partida-de-Plasensija,ma er pa er di da de pu la sen xi ya,malbartyda dy blasynthya,Мальпартида-де-Пласенсиа,Мальпартіда-де-Пласенсія,مالبارتيدا دي بلاسينثيا,马尔帕尔蒂达德普拉森西亚', 39.9796200, -6.0460900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42519, 'Malpartida de la Serena', 'Malpartida de la Serena', 'Malpartida de la Serena', 38.6747000, -5.6405400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42520, 'Malpartida de Cáceres', 'Malpartida de Caceres', 'Mal''partida-de-Kaseres,Malpartida de Caceres,Malpartida de Cáceres,ma er pa er di da de ka sai lei si,malbartyda dy qsrsh,Мальпартида-де-Касерес,Мальпартіда-де-Касерес,مالبارتيدا دي قصرش,马尔帕尔蒂达德卡塞雷斯', 39.4466400, -6.5076000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42521, 'Malcocinado', 'Malcocinado', 'Malcocinado', 38.1166700, -5.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42522, 'Malagón', 'Malagon', 'Malagon,Malagón,ma la gong,malajwn  sywdad ryal,Малагон,مالاجون، سيوداد ريال,马拉贡', 39.1666800, -3.8541900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42523, 'Málaga', 'Malaga', 'AGP,Gorad Malaga,Malaca,Malaga,Malagae,Malago,Malaqa,Màlaga,Málaga,ma la jia,malaga,malaja,malaka,malga,mallaga,malqt,maraga,mlqt,Μάλαγα,Горад Малага,Малагæ,Малага,Մալագա,מאלגה,מלאגה,مالاجا,مالاگا,مالقة,مالگا,ملقة,مەلەگا,मलागा,மாலாகா,มาลากา,მალაგა,マラガ,馬拉加,马拉加,말라가', 36.7201600, -4.4203400, 'ES', '2011-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42524, 'Majadas', 'Majadas', 'Majadas', 39.9429100, -5.7458900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42525, 'Mairena del Aljarafe', 'Mairena del Aljarafe', 'Aljarafe,Mairena del Aljarafe,Majrena-del''-Al''kharafe,mai lei na de la er ha la fei,Майрена-дель-Альхарафе,迈雷纳德拉尔哈拉费', 37.3446100, -6.0639100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42526, 'Mairena del Alcor', 'Mairena del Alcor', 'Mairano del Alcor,Mairena del Alcor,Maireno del Alcor', 37.3730100, -5.7495100, 'ES', '2016-04-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42527, 'Mahora', 'Mahora', 'Mahora', 39.2166700, -1.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42528, 'Maó', 'Mao', 'Mahon,Mahón,Mao,Maó,Мао', 39.8885300, 4.2658300, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42529, 'Maguilla', 'Maguilla', 'Maguilla', 38.3666700, -5.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42530, 'Magán', 'Magan', 'Magan,Magán', 39.9613800, -3.9316400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42531, 'Magacela', 'Magacela', 'Magacela', 38.8964800, -5.7343700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42532, 'Madroñera', 'Madronera', 'Madronera,Madroñera', 39.4252600, -5.7556800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42533, 'Madrigueras', 'Madrigueras', 'Madriguera,Madrigueras', 39.2333300, -1.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42534, 'Madrigalejo', 'Madrigalejo', '', 39.1385800, -5.6274000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42535, 'Madridejos', 'Madridejos', 'Madridejos,Madridekhos,Madridexos,ma de li de huo si,madrydkhs,Мадридехос,Мадрідехос,Մադրիդեխոս,مادریدخس,马德里德霍斯', 39.4682300, -3.5319600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42536, 'Macastre', 'Macastre', 'Macastre', 39.3833300, -0.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42537, 'Macael', 'Macael', 'Macael,Makaehl'',Makael,Makael'',ma kai er,makayl,Макаел,Макаель,Макаэль,ماكايل,ماکائل,马凯尔', 37.3331800, -2.3008700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42538, 'Luque', 'Luque', 'Luque', 37.5579700, -4.2797400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42539, 'Lupión', 'Lupion', 'Lupion,Lupión', 37.9965300, -3.5469900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42540, 'Puerto Lumbreras', 'Puerto Lumbreras', 'Lumbreras,Puehrto-Lumbreras,Puerto-Lumbreras,bwyrtw lwbryras,pu ai er tuo lun fu lei la si,Пуерто-Лумбрерас,Пуэрто-Лумбрерас,بويرتو لوبريراس,普埃尔托伦夫雷拉斯', 37.5632900, -1.8097400, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42541, 'Lújar', 'Lujar', 'Lujar,Lújar', 36.7883100, -3.4040000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42542, 'Lugros', 'Lugros', 'Lugros', 37.2294200, -3.2415000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42543, 'Llocnou de Sant Jeroni', 'Llocnou de Sant Jeroni', 'Llocnou de Sant Jeroni,Lugar Nuevo de San Jeronimo,Lugar Nuevo de San Jerónimo', 38.9166700, -0.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42544, 'Lucillos', 'Lucillos', 'Luc Villos,Lucillos', 39.9851000, -4.6127900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42545, 'Llutxent', 'Llutxent', 'Llutxent,Luchente', 38.9333300, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42546, 'Lucena del Puerto', 'Lucena del Puerto', 'Lucena del Puerto', 37.3039600, -6.7292600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42547, 'Lucena', 'Lucena', '', 37.4088100, -4.4852200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42548, 'Lúcar', 'Lucar', 'Lucar,Lúcar', 37.4003500, -2.4249600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42549, 'Lucainena de las Torres', 'Lucainena de las Torres', 'Lucainena de las Torres', 37.0403700, -2.2009500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42550, 'Lubrín', 'Lubrin', 'Lubrin,Lubrín', 37.2153800, -2.0667700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42551, 'Los Yébenes', 'Los Yebenes', 'Los Yebenes,Los Yébenes,Yebenes,Yébenes', 39.5815800, -3.8705800, 'ES', '2010-05-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42552, 'Los Silos', 'Los Silos', 'Los Silos,Silos', 28.3661000, -16.8155200, 'ES', '2008-01-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42553, 'Los Santos de Maimona', 'Los Santos de Maimona', 'Los Santos,Los Santos de Maimona', 38.4500000, -6.3833300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42554, 'Los Palacios y Villafranca', 'Los Palacios y Villafranca', 'Los Palacios y Villafranca,Villafranca Los Palacios', 37.1618100, -5.9243300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42555, 'Los Navalucillos', 'Los Navalucillos', 'Los Navalucillos', 39.6666500, -4.6420500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42556, 'Los Navalmorales', 'Los Navalmorales', 'Los Navalmorales', 39.7252600, -4.6422700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42557, 'Los Montesinos', 'Los Montesinos', 'Els Montesinos,Els Montesins,Los Montesinos,Los-Montesinos,Montesinos,luo si meng te xi nuo si,lws mwntsynws,Лос-Монтесинос,Лос-Монтесінос,لوس مونتسینوس,洛斯蒙特西诺斯', 38.0282200, -0.7450100, 'ES', '2008-11-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42558, 'Los Molares', 'Los Molares', 'Los Molares', 37.1570400, -5.7180200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42559, 'Los Llanos de Aridane', 'Los Llanos de Aridane', 'Llanos de Aridane,Los Llanos,Los Llanos de Aridane,Los-L''janos-de-Aridane,luo si li ya nuo si de ya li da nei,lws yanws dy arydany,Лос-Льянос-де-Аридане,Лос-Льянос-де-Арідане,لوس يانوس دي أريداني,洛斯利亚诺斯德亚里达内', 28.6585100, -17.9182100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42560, 'Los Hinojosos', 'Los Hinojosos', 'Los Hinojosos', 39.6041700, -2.8257200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42561, 'Los Corrales', 'Los Corrales', 'Los Corrales', 37.0991800, -4.9842900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42562, 'Los Barrios', 'Los Barrios', 'Barrios,Los-Barrios,luo si ba li ao si,lws baryws,lws bryws,Лос-Барриос,Лос-Барріос,לוס בריוס,لوس باريوس,洛斯巴里奥斯', 36.1848200, -5.4921300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42563, 'Los Alcázares', 'Los Alcazares', 'Alcazares,Alcázares', 37.7442500, -0.8504100, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42564, 'Losa del Obispo', 'Losa del Obispo', 'Llosa del Bisbe,Losa del Obispo', 39.7000000, -0.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42565, 'Lorquí', 'Lorqui', 'Lorqui,Lorquí', 38.0826100, -1.2510300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42566, 'Loriguilla', 'Loriguilla', 'Loriguilla', 39.6833300, -0.9166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42567, 'Lorca', 'Lorca', 'Llorca,Lorca,Lorka,Lorko,XJR,lwrka  mrsyt,lwrqh,roruka,Лорка,לורקה,لوركا، مرسية,ロルカ', 37.6711900, -1.7017000, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42568, 'Lora del Río', 'Lora del Rio', 'Lora del Rio,Lora del Río,Lora-del''-Rio,luo la de er li ao,lwra dyl ryw,lwrt,Лора-дель-Рио,Лора-дель-Ріо,لورا ديل ريو,لورة,洛拉德尔里奥', 37.6589600, -5.5275100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42569, 'Lora de Estepa', 'Lora de Estepa', 'Lora de Estepa', 37.2692600, -4.8275900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42570, 'Lopera', 'Lopera', 'Lopera', 37.9454200, -4.2146300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42571, 'Lomo de Arico', 'Lomo de Arico', 'Arico,Lomo de Arico', 28.1666700, -16.4833300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42572, 'Loja', 'Loja', 'Lokha,Лоха', 37.1688700, -4.1512900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42573, 'Logrosán', 'Logrosan', 'Logrosan,Logrosán,luo ge luo sang,lwghrwsan,Логросан,لوغروسان,洛格罗桑', 39.3364100, -5.4928100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42574, 'Lobras', 'Lobras', '', 36.9284900, -3.2123000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42575, 'Lobón', 'Lobon', 'Lobon,Lobón', 38.8487600, -6.6236500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42576, 'Llucmajor', 'Llucmajor', 'Llucmajor', 39.4909300, 2.8910800, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42577, 'Llubí', 'Llubi', 'Llubi,Llubí', 39.6993300, 3.0068100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42578, 'Lloseta', 'Lloseta', 'Lloseta', 39.7184900, 2.8669000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42579, 'Llosa de Ranes', 'Llosa de Ranes', 'Llosa de Ranes', 39.0216300, -0.5380300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42580, 'Lloret de Vistalegre', 'Lloret de Vistalegre', 'Lloret de Vistalegre', 39.6183500, 2.9749300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42581, 'Llombai', 'Llombai', 'Llombai,Llombay', 39.2833300, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42582, 'Llerena', 'Llerena', 'L''erena,Ljerena,Llerena,Lyerena,lie lei na,yrna,Љерена,Льерена,Льєрена,Լյերենա,یرنا,列雷纳', 38.2333300, -6.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42583, 'Llera', 'Llera', 'Llera', 38.4500000, -6.0500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42584, 'Llaurí', 'Llauri', 'Llauri,Llaurí', 39.1467100, -0.3294400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42585, 'Llanera de Ranes', 'Llanera de Ranes', 'Llanera de Ranes', 38.9950700, -0.5753400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42586, 'Llíria', 'Lliria', 'Liria,Lliria,Llíria', 39.6289400, -0.5978300, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42587, 'Linares de la Sierra', 'Linares de la Sierra', 'Linares de la Sierra', 37.8796300, -6.6232100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42588, 'Linares', 'Linares', 'Linares,Линарес', 38.0951900, -3.6360200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42589, 'Lillo', 'Lillo', 'Lillo', 39.7233100, -3.3061800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42590, 'Liétor', 'Lietor', 'Lieto,Lietor,Liéto,Liétor', 38.5426700, -1.9536700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42591, 'Librilla', 'Librilla', 'Librilla', 37.8864200, -1.3555700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42592, 'Lezuza', 'Lezuza', 'Lezuza', 38.9497000, -2.3541900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42593, 'Letur', 'Letur', 'Letur', 38.3662600, -2.1020600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42594, 'Lepe', 'Lepe', 'Lepe,Лепе', 37.2548200, -7.2043300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42595, 'Lentegí', 'Lentegi', 'Lentegi,Lentegí', 36.8361300, -3.6742600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42596, 'Ledaña', 'Ledana', 'Ledana,Ledaña', 39.3666700, -1.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42597, 'Lebrija', 'Lebrija', 'Lebrija,Lebrikha,Лебриха', 36.9207700, -6.0752900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42598, 'Layos', 'Layos', 'Layos', 39.7770300, -4.0644800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42599, 'La Yesa', 'La Yesa', 'La Iesa,La Ièsa,La Yesa,Yesa', 39.8833300, -0.9500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42600, 'La Victoria de Acentejo', 'La Victoria de Acentejo', 'La Victoria de Acentejo', 28.4323100, -16.4623200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42601, 'La Victoria', 'La Victoria', 'La Victoria,La Viktoria,La-Viktorija,la fyktwrya,la wei ke tuo li ya,Ла-Виктория,Ла-Вікторія,Լա Վիկտորիա,لا فيكتوريا,لا ویکتوریا، ہسپانیہ,拉维克托里亚', 37.6812600, -4.8519900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42602, 'La Unión', 'La Union', 'La Union,La Unión,La-Un''jon,La-Un''on,Unio,la awnyn,la awnywn,la wnywn  mwrkya,lao ni weng,Ла-Уньйон,Ла-Уньон,لا أونيون,لا اونین,لا ونیون، مورکیا,劳尼翁', 37.6191500, -0.8779900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42603, 'Laujar de Andarax', 'Laujar de Andarax', 'Lajuar de Andaraks,Laujar,Laujar de Andarax,Laukhar-de-Andaraks,Láujar de Andarax,andrsh,lao ha er de ya en da la si,lawkhar d andaraks,Лаухар-де-Андаракс,Лајуар де Андаракс,أندرش,لاوخار د آنداراکس,劳哈尔德亚恩达拉斯', 36.9951600, -2.8903300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42604, 'Las Torres de Cotillas', 'Las Torres de Cotillas', 'La Torres de Cotillas,Las Torres de Cotillas', 38.0282200, -1.2418800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42605, 'Las Pedroñeras', 'Las Pedroneras', 'Las Pedroneras,Las Pedroñeras', 39.4499700, -2.6739400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42606, 'Las Palmas de Gran Canaria', 'Las Palmas de Gran Canaria', 'Kanaria Handiko Las Palmas,LPA,Las Palmas,Las Palmas de G.C.,Las Palmas de Gran Canaria,Las Palmas de Gran Kanaria,Las-Pal''mas-de-Gran-Kanarija,Laspalmasa,Les Palmes de Gran Canaria,Les Palmes de Gran Canària,Palmas,Palmas de Gran Canaria,la si pa er ma si,Лас Палмас де Гран Канариа,Лас-Пальмас-де-Гран-Канария,ラス・パルマス・デ・グラン・カナリア,拉斯帕尔马斯', 28.0997300, -15.4134300, 'ES', '2012-11-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42607, 'La Solana', 'La Solana', 'La Solana', 38.9442200, -3.2381000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42608, 'Las Mesas', 'Las Mesas', 'Las Mesas', 39.3887100, -2.7652400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42609, 'Las Cabezas de San Juan', 'Las Cabezas de San Juan', 'Las Cabezas San Juan,Las Cabezas de San Juan', 36.9838000, -5.9393300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42610, 'Larva', 'Larva', 'Larva', 37.7606900, -3.2026900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42611, 'Laroya', 'Laroya', 'Laroya', 37.2977100, -2.3341900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42612, 'La Romana', 'La Romana', 'La Romana', 38.3675300, -0.8986200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42613, 'La Roda de Andalucía', 'La Roda de Andalucia', 'La Roda,Roda de Andulucia', 37.2038100, -4.7780200, 'ES', '2008-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42614, 'La Roda', 'La Roda', 'La Roda,La-Roda,Roda,la luo da,la rda,la rwda,Ла-Рода,لا ردا,لا رودا,拉罗达', 39.2073500, -2.1572300, 'ES', '2015-06-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42615, 'La Roca de la Sierra', 'La Roca de la Sierra', 'La Roca,La Roca de la Sierra', 39.1096600, -6.6891600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42616, 'La Rinconada', 'La Rinconada', 'La Rinconada,La-Rinkonada,la lin ke na da,Ла-Ринконада,Ла-Рінконада,拉林科纳达', 37.4861300, -5.9809100, 'ES', '2014-02-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42617, 'La Rambla', 'La Rambla', 'La Rambla,La-Rambla,la lan fu la,la rmblt,Ла-Рамбла,لا رمبلة,拉兰夫拉', 37.6076000, -4.7396200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42618, 'La Puerta de Segura', 'La Puerta de Segura', 'La Puerta,La Puerta de Segura', 38.3529300, -2.7395600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42619, 'La Pueblanueva', 'La Pueblanueva', 'La Pueblanueva', 39.9120800, -4.6793300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42620, 'La Puebla de Montalbán', 'La Puebla de Montalban', 'Aebura,La Puebla de Montalban,La Puebla de Montalbán,Puebla de Montalban,Puebla de Montalbán', 39.8629700, -4.3591700, 'ES', '2012-04-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42621, 'La Puebla del Río', 'La Puebla del Rio', 'La Puebla del Rio,La Puebla del Río,Puebla del Rio,Puebla del Río', 37.2678700, -6.0626400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42622, 'La Puebla de los Infantes', 'La Puebla de los Infantes', 'La Puebla de los Infantes', 37.7809000, -5.3883700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42623, 'La Puebla de Cazalla', 'La Puebla de Cazalla', 'La Puebla de Cazalla,Puebla de Cazalla', 37.2215500, -5.3115300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42624, 'La Puebla de Almoradiel', 'La Puebla de Almoradiel', 'La Puebla de Almoradiel,La Puebla de Almordier,Puebla de Almoradiel', 39.5986200, -3.1178200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42625, 'sa Pobla', 'sa Pobla', 'la Pobla,sa Pobla', 39.7692000, 3.0239400, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42626, 'La Parra', 'La Parra', 'La Parra', 38.5212000, -6.6226000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42627, 'La Palma del Condado', 'La Palma del Condado', 'La Palma,La Palma del Condado,La Palma del Kondado,La-Pal''ma-del''-Kondado,NDO,Palma del Kontado,la balma dyl kwndadw,la pa er ma de er kong da duo,Πάλμα δελ Κοντάδο,Ла-Пальма-дель-Кондадо,Լա Պալմա դել Կոնդադո,لا بالما ديل كوندادو,لا پالما ڈیل کونڈاڈو,拉帕尔马德尔孔达多', 37.3860500, -6.5523100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42628, 'La Orotava', 'La Orotava', 'La Orotava,La-Orotava,Orotava,Villa Orotava,Villa de la Orotava,la awrwtafa,lao luo ta wa,Ла-Оротава,Оротава,لا أوروتافا,劳罗塔瓦', 28.3907600, -16.5230900, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42629, 'La Oliva', 'La Oliva', 'La Oliva,Oliva', 28.6105200, -13.9291200, 'ES', '2015-08-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42630, 'la Nucia', 'la Nucia', 'La-Nusia,la Nucia,Ла-Нусиа', 38.6137200, -0.1269000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42631, 'Lanteira', 'Lanteira', 'Lanteira', 37.1687100, -3.1382300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42632, 'Lanjarón', 'Lanjaron', 'Lanjaron,Lanjarón', 36.9185300, -3.4818000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42633, 'Landete', 'Landete', 'Landete', 39.9000000, -1.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42634, 'La Nava de Santiago', 'La Nava de Santiago', 'La Nava,La Nava de Santiago', 39.0632800, -6.5052500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42635, 'La Mojonera', 'La Mojonera', 'Caserio La Mojonera,Caserío La Mojonera,La Mojonera', 37.2923300, -2.4373000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42636, 'La Matanza de Acentejo', 'La Matanza de Acentejo', 'La Matanza de Acentejo,La-Matansa-de-Asentekho,la ma tan sa de ya sen te huo,la matansa d asntkhw,la mtantha dy athyntykhw,Ла-Матанса-де-Асентехо,لا ماتانزا دے اسنتیجو,لا ماتانسا د آسنتخو,لا متانثا دي أثينتيخو,拉马坦萨德亚森特霍', 28.4524200, -16.4472000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42637, 'La Luisiana', 'La Luisiana', 'La Luisana,La Luisiana', 37.5260200, -5.2488300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42638, 'La Línea de la Concepción', 'La Linea de la Concepcion', 'La Linea,La Linea de la Concepcion,La Línea,La Línea de la Concepción,La-Linea-de-la-Konseps''jon,La-Linea-de-la-Konseps''on,La-Linea-deh-la-Kanseps''jon,Linea de Konsepsion,la li nei ya de la kong sai pu xi weng,la lnya dy la kanspchyan,la yyna dy la kwnsybsywn,Ла-Линеа-де-ла-Консепсьон,Ла-Лінеа-де-ла-Консепсьйон,Ла-Лінеа-дэ-ла-Кансепсьён,Линеа де Консепсион,لا لنیا دی لا کانسپچیان,لا يينا دي لا كونسيبسيون,ラ・リネア・デ・ラ・コンセプション,拉利内亚德拉孔塞普西翁', 36.1680900, -5.3477700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42639, 'La Lantejuela', 'La Lantejuela', 'La Lantejuela,La Lentejuela', 37.3535000, -5.2247700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42640, 'La Iruela', 'La Iruela', 'Iruela,La Iruela', 37.9198600, -2.9965900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42641, 'La Herradura', 'La Herradura', 'Herradura,La Herradura', 36.7349100, -3.7376000, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42642, 'La Haba', 'La Haba', 'La Haba', 38.9192900, -5.8003400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42643, 'La Guardia de Jaén', 'La Guardia de Jaen', 'La Guardia,La Guardia de Jaen,La Guardia de Jaén,La-Guardija-de-Khaen,La-Gvardia-de-Khaehn,la ghwardya dy khayn,la gua er di ya de hai en,la gwardya d khayn,Ла-Гвардиа-де-Хаэн,Ла-Гуардія-де-Хаен,لا غوارديا دي خاين,لا گواردیا د خائن,拉瓜尔迪亚德海恩', 37.7430300, -3.6931200, 'ES', '2011-01-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42644, 'La Guardia', 'La Guardia', 'La Gardia,La Guardia,La-Guardija,la gua er di ya,Ла Гардиа,Ла-Гуардия,Ла-Гуардія,Լա Գուարդիա,拉瓜尔迪亚', 39.7879500, -3.4760400, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42645, 'La Guancha', 'La Guancha', 'Guancha,La Guancha', 28.3732000, -16.6515800, 'ES', '2015-06-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42646, 'La Gineta', 'La Gineta', 'La Gineta', 39.1145200, -1.9960300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42647, 'Lagartera', 'Lagartera', 'Lagartera', 39.9055700, -5.2014300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42648, 'La Garrovilla', 'La Garrovilla', 'La Garrovilla', 38.9196100, -6.4774700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42649, 'L''Eliana', 'L''Eliana', 'L''Eliana,La Eliana', 39.5666700, -0.5333300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42650, 'La Cumbre', 'La Cumbre', 'La Cumbre', 39.4046000, -5.9763500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42651, 'La Coronada', 'La Coronada', 'Coronada,La Coronada', 38.9204500, -5.6697800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42652, 'La Codosera', 'La Codosera', '', 39.2087800, -7.1733000, 'ES', '2008-07-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42653, 'Láchar', 'Lachar', 'Lacen,Lachar,la cha er,latshar,Лачар,لاتشار,拉查尔', 37.1951900, -3.8327700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42654, 'La Carolina', 'La Carolina', 'La Carolina', 38.2755900, -3.6153500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42655, 'La Carlota', 'La Carlota', 'La Carlota,La-Karlota,la karlwta,Ла-Карлота,لا كارلوتا,لا کارلوٹا، سپاین,ラ・カルロータ', 37.6735900, -4.9312200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42656, 'La Campana', 'La Campana', 'La Campana', 37.5689100, -5.4267000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42657, 'La Calzada de Calatrava', 'La Calzada de Calatrava', 'Calzada de Calatrava,La Calzada,La Calzada de Calatrava', 38.7033900, -3.7756100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42658, 'La Antilla', 'La Antilla', 'Antilla,Caserio Las Antillas,Caserio de Las Antillas,Caserío Las Antillas,Caserío de Las Antillas', 37.2070900, -7.2090900, 'ES', '2016-10-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42659, 'La Algaba', 'La Algaba', 'Algaba,La Algaba', 37.4632500, -6.0111300, 'ES', '2014-02-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42660, 'La Albuera', 'La Albuera', 'Aebura,Albora,Albuera,La Albuera', 38.7177900, -6.8232600, 'ES', '2012-11-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42661, 'La Alberca de Záncara', 'La Alberca de Zancara', 'La Alberca,La Alberca de Zancara,La Alberca de Záncara', 39.5145800, -2.4927200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42662, 'Júzcar', 'Juzcar', 'Juzcar,Júzcar', 36.6244200, -5.1697100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42663, 'Juviles', 'Juviles', 'Joviles,Jubiles', 36.9487900, -3.2258600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42664, 'Jun', 'Jun', '', 37.2208300, -3.5940700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42665, 'Jumilla', 'Jumilla', 'Chumiella,Jumella,Jumilla,Khumil''e,Khumil''ja,hu mi li ya,khwmya,Хумилье,Хумилья,Хумілья,خوميا,胡米利亚', 38.4791700, -1.3250000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42666, 'Jubrique', 'Jubrique', 'Jubrique', 36.5647500, -5.2156000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42667, 'Jorquera', 'Jorquera', 'Jorquera', 39.1666700, -1.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42668, 'Jódar', 'Jodar', 'Jodar,Jódar', 37.8406400, -3.3526200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42669, 'Jimera de Líbar', 'Jimera de Libar', 'Jimera de Libar,Jimera de Líbar', 36.6511900, -5.2741200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42670, 'Jimena de la Frontera', 'Jimena de la Frontera', 'Jimena,Jimena de la Frontera,Khimena-de-la-Frontera,khymyna dy la frwntyra,xi mei na de la fu long te la,Химена-де-ла-Фронтера,Хімена-де-ла-Фронтера,خيمينا دي لا فرونتيرا,希梅纳德拉夫龙特拉', 36.4351700, -5.4538700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42671, 'Jimena', 'Jimena', 'Jimena', 37.8415700, -3.4771000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42672, 'Jijona', 'Jijona', 'Jijona,Xixona', 38.5408600, -0.5026300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42673, 'Jérica', 'Jerica', 'Exerica,Jerica,Jérica,Kherika,Xerica,Xèrica,he li ka,khyryka,Херика,Херіка,خيريكا,赫里卡', 39.9166700, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42674, 'Jerez de los Caballeros', 'Jerez de los Caballeros', 'Jerez de los Caballeros,Kheres de los Kabaleros,Kheres-de-los-Kabal''eros,he lei si de luo si ka wa lie luo si,jyryz dy lws kabalyrws,Херес де лос Кабалерос,Херес-де-лос-Кабальерос,Херес-де-лос-Кабальєрос,جيريز دي لوس كاباليروس,赫雷斯德洛斯卡瓦列罗斯', 38.3206300, -6.7726000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42675, 'Jerez de la Frontera', 'Jerez de la Frontera', 'Cheres de la Frontera,Gorad Kherehs-deh-la-Frantehra,Herezo,Jarez de la Frontera,Jerez,Jerez de la Frontera,Kheres de la Frontera,Kheres-de-la-Frontera,Kherez de la Frontera,XRY,Xeres,Xeresium,Xerez de la Frontera,Xerès,Xérès,he lei si-de la fu long te la,heleseudelapeulontela,hrs dh lh prwntrh,jyraz dy la frwntyra,shrysh,Ĥerezo,Горад Херэс-дэ-ла-Франтэра,Херез де ла Фронтера,Херес де ла Фронтера,Херес-де-ла-Фронтера,חרס דה לה פרונטרה,جیراز دی لا فرونتیرا,شريش,ヘレス・デ・ラ・フロンテーラ,赫雷斯-德拉弗龙特拉,헤레스데라프론테라', 36.6864500, -6.1360600, 'ES', '2013-03-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42676, 'Jérez del Marquesado', 'Jerez del Marquesado', 'Jeres del Marquesado,Jerez del Marquesado,Jérez del Marquesado', 37.1838200, -3.1596100, 'ES', '2015-12-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42677, 'Xeresa', 'Xeresa', 'Jeresa,Xeresa', 39.0166700, -0.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42678, 'Jayena', 'Jayena', 'Jayena', 36.9492000, -3.8231300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42679, 'Javea', 'Javea', 'Javea,Jávea,Xabia,Xàbia', 38.7833300, 0.1666700, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42680, 'Xàtiva', 'Xativa', 'Jativa,Játiva,Khativa,Xativa,Xàtiva,shatbt,Хатива,شاطبة', 38.9904200, -0.5185200, 'ES', '2015-05-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42681, 'Jaraicejo', 'Jaraicejo', 'Jaraicejo', 39.6662400, -5.8130800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42682, 'Jarafuel', 'Jarafuel', 'Jarafuel,Kharafuehl'',Kharafuel'',Xarafull,ha la fu ai er,jrafwl,Харафуель,Харафуэль,جرافول,哈拉富埃尔', 39.1401300, -1.0730600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42683, 'Xeraco,Jaraco', 'Xeraco,Jaraco', '', 39.0333300, -0.2166700, 'ES', '2006-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42684, 'Jamilena', 'Jamilena', 'Jamilena', 37.7471700, -3.9143300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42685, 'Jalón', 'Jalon', 'Jalon,Jalón,Khalon,Shalo,Xalo,Xaló,ha long,hallon,jalwn,jlwn,khaln,Халон,Шало,جالون,جلون,خالن,哈隆,할론', 38.7406300, -0.0112900, 'ES', '2006-04-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42686, 'Jalance', 'Jalance', 'Jalance,Xalans', 39.2000000, -1.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42687, 'Jaén', 'Jaen', 'Aurgi,Haeno,JEA,Jaen,Jaén,Khaehn,Xaen - Jaen,Xaén - Jaén,haen,jyan,Ĥaeno,Хаэн,جيان,ハエン', 37.7692200, -3.7902800, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42688, 'Jacarilla', 'Jacarilla', 'Jacarilla,Xacarella', 38.0624700, -0.8682200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42689, 'Jabugo', 'Jabugo', 'Jabugo', 37.9162200, -6.7296800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42690, 'Jabalquinto', 'Jabalquinto', 'Jabalquinto', 38.0193500, -3.7251200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42691, 'Iznatoraf', 'Iznatoraf', 'Iznatoraf', 38.1570600, -3.0324200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42692, 'Iznate', 'Iznate', 'Iznate', 36.7833300, -4.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42693, 'Iznalloz', 'Iznalloz', 'Iznalloz', 37.3925800, -3.5276200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42694, 'Iznájar', 'Iznajar', 'Iznar', 37.2576600, -4.3083600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42695, 'Ítrabo', 'Itrabo', 'Itrabo,Ítrabo', 36.7999800, -3.6389900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42696, 'Istán', 'Istan', 'Istan,Istán', 36.5827300, -4.9495600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42697, 'Isla Cristina', 'Isla Cristina', 'Isla-Kristina,asla krystyna,yi si la ke li si di na,Ісла-Крістіна,Исла-Кристина,إسلا كريستينا,イスラ・クリスティナ,伊斯拉克里斯蒂纳', 37.2000000, -7.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42698, 'Instinción', 'Instincion', 'Instincion,Instinción', 36.9934400, -2.6604600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42699, 'Iniesta', 'Iniesta', 'In''esta,Iniesta,aynysta,yi nie si ta,Іньєста,Иньеста,Ինիեստա,إينيستا,伊涅斯塔', 39.4333300, -1.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42700, 'Ingenio', 'Ingenio', 'Carrizal de Ingenio,Ingenio', 27.9185500, -15.4343300, 'ES', '2015-10-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42701, 'Infantes', 'Infantes', 'Infantes,Villanueva de Infantes,Villanueva de los Infantes', 38.7366900, -3.0121900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42702, 'Inca', 'Inca', 'Inca,Inka,Инка', 39.7211000, 2.9109300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42703, 'Illora', 'Illora', '', 37.2877100, -3.8810900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42704, 'Illar', 'Illar', 'Illar', 36.9856200, -2.6387100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42705, 'Illán de Vacas', 'Illan de Vacas', 'Illan de Vacas,Illán de Vacas', 39.9707900, -4.5574300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42706, 'Igualeja', 'Igualeja', 'Igualeja', 36.6320800, -5.1218800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42707, 'Icod de los Vinos', 'Icod de los Vinos', 'Icod,Icod de los Vinos,Ikod-de-los-Vinos,akwd dy lws fynws,aykd d ls byns,yi ke de luo si wei nuo si,Ікод-де-лос-Вінос,Икод-де-лос-Винос,إكود دي لوس فينوس,ایکد د لس بینس,伊科德洛斯维诺斯', 28.3724100, -16.7118800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42708, 'Ibros', 'Ibros', 'Ibros', 38.0210600, -3.5031300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42709, 'Ibiza', 'Ibiza', 'Eivissa,IBZ,Ibica,Ibiza,Ibiza Town,Ibiza-Stadt,Ibiza-stad,Vila d''Eivissa,Ибица', 38.9088300, 1.4329600, 'ES', '2016-01-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42710, 'Ibi', 'Ibi', 'Ibi,alby,ayby,yi wei,Ібі,Иби,Իբի,إلبي,ایبی,伊维', 38.6253300, -0.5722500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42711, 'Ibahernando', 'Ibahernando', 'Ibahernando', 39.3253800, -5.9183300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42712, 'Humilladero', 'Humilladero', 'Humilladero', 37.1139000, -4.7029800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42713, 'Huétor Vega', 'Huetor Vega', 'Huetor Vega,Huétor Vega', 37.1452900, -3.5696300, 'ES', '2015-11-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42714, 'Huétor-Tájar', 'Huetor-Tajar', 'Huetor Tajar,Huétor Tájar,Uehtor-Takhar,Uetor-Takhar,awytwr takhar,wei tuo er-ta ha er,Уетор-Тахар,Уэтор-Тахар,أويتور تاخار,韦托尔-塔哈尔', 37.1983400, -4.0469200, 'ES', '2012-07-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42715, 'Huétor Santillán', 'Huetor Santillan', 'Huetor Santillan,Huétor Santillán', 37.2209100, -3.5163400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42716, 'Huéscar', 'Huescar', 'Huescar,Huéscar,Osca,Uehskar,Ueskar,awyskar,wei si ka er,Уескар,Уэскар,أويسكار,韦斯卡尔', 37.8110400, -2.5411600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42717, 'Huesa', 'Huesa', 'Huesa', 37.7643400, -3.0763900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42718, 'Huerta de Valdecarábanos', 'Huerta de Valdecarabanos', 'Huerta,Huerta de Valdecarabanos,Huerta de Valdecarábanos', 39.8631900, -3.6127500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42719, 'Huerta de la Obispalía', 'Huerta de la Obispalia', 'Huerta de la Obispalia,Huerta de la Obispalía', 39.9890100, -2.4787500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42720, 'Huércal-Overa', 'Huercal-Overa', 'Huercal Overa,Huércal Overa,Khuercal Overa,Uehrkal''-Overa,Uerkal''-Overa,awyrkal-awwra,hwyrkal-awfyra,wei er ka er-ao wei la,Уеркаль-Овера,Уэркаль-Овера,Хуерцал Овера,اوئرکال-اوورا,هويركال-أوفيرا,韦尔卡尔-奥韦拉', 37.3889700, -1.9453600, 'ES', '2012-08-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42721, 'Huércal de Almería', 'Huercal de Almeria', 'Huercal de Almeria,Huércal de Almería', 36.8850700, -2.4376000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42722, 'Huéneja', 'Hueneja', 'Hueneja,Huéneja', 37.1766000, -2.9502400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42723, 'Huelva', 'Huelva', 'HEV,Huelva,Onubo,Uehl''va,ueruba,u~eruba,Уэльва,ウェルバ,ウエルバ', 37.2663800, -6.9400400, 'ES', '2013-12-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42724, 'Huelma', 'Huelma', 'Huelma', 37.6478400, -3.4598500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42725, 'Huélago', 'Huelago', 'Huelago,Huélago', 37.4197200, -3.2622600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42726, 'Huécija', 'Huecija', 'Huecija,Huécija,Khuecija,Uehsikha,Uesikha,awysykha,hwysayja,wei xi ha,Уесіха,Уэсиха,Хуеција,اوئسیخا,هويسايجا,韦西哈', 36.9680400, -2.6094100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42727, 'Hoya-Gonzalo', 'Hoya-Gonzalo', 'Hoya-Gonzalo', 38.9579000, -1.5567900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42728, 'Hornachuelos', 'Hornachuelos', 'Hornachuelos', 37.8333300, -5.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42729, 'Hornachos', 'Hornachos', 'Hornachos,Khornachos,Ornachos,ao er na qiao si,hwrnatshws,Орначос,Хорначос,هورناتشوس,奥尔纳乔斯', 38.5542800, -6.0682900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42730, 'Horcajo de Santiago', 'Horcajo de Santiago', 'Horcajo,Horcajo de Santiago', 39.8422100, -2.9972400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42731, 'Hontecillas', 'Hontecillas', 'Hontecillas', 39.7000000, -2.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42732, 'Hontanaya', 'Hontanaya', 'Hontanaya', 39.7155300, -2.8351600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42733, 'Hontanar', 'Hontanar', 'Hontanar', 39.6129700, -4.4966300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42734, 'Honrubia', 'Honrubia', 'Honrubia', 39.6135800, -2.2807700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42735, 'Hondón de los Frailes', 'Hondon de los Frailes', 'El Fondo dels Frares,El Fondó dels Frares,Fondo dels Frares,Fondó dels Frares,Hondon de los Frailes,Hondón de los Frailes,Ondon-de-los-Frajles,hwndwn d lws frayls,weng dong de luo si fu lai lai si,Ондон-де-лос-Фрайлес,هوندون د لوس فرایلس,翁东德洛斯夫赖莱斯', 38.2739000, -0.9293800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42736, 'Hondón de las Nieves', 'Hondon de las Nieves', 'Fondo de les Neus,Fondó de les Neus,Hondon de las Nieves,Hondón de las Nieves', 38.3084400, -0.8533000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42737, 'Holguera', 'Holguera', 'Holguera', 39.8991600, -6.3499900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42738, 'Hinojosas de Calatrava', 'Hinojosas de Calatrava', 'Hinojosa,Hinojosas', 38.6144600, -4.1397900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42739, 'Hinojosa del Valle', 'Hinojosa del Valle', 'Hinojosa del Valle', 38.4833300, -6.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42740, 'Hinojosa del Duque', 'Hinojosa del Duque', 'Hinojosa del Duque,Inokhosa-del''-Duke,hynwkhwsa dyl dwkwy  qrtbt,yi nuo huo sa de er du ke,Інохоса-дель-Дуке,Инохоса-дель-Дуке,هينوخوسا ديل دوكوي، قرطبة,伊诺霍萨德尔杜克', 38.5005700, -5.1465100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42741, 'Hinojos', 'Hinojos', 'Hinojos', 37.2917300, -6.3787200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42742, 'Hinojares', 'Hinojares', 'Hinojares', 37.7158600, -2.9976900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42743, 'Hinojales', 'Hinojales', 'Hinojales', 38.0000000, -6.5833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42744, 'Hinojal', 'Hinojal', 'Hinojal', 39.7090000, -6.3556700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42745, 'Higueruelas', 'Higueruelas', 'Figueroles,Higueruelas', 39.7833300, -0.8500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42746, 'Higueruela', 'Higueruela', 'Higueruela', 38.9637100, -1.4437000, 'ES', '2015-11-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42747, 'Higueras', 'Higueras', 'Higueras', 39.9833300, -0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42748, 'Higuera la Real', 'Higuera la Real', 'Higuera,Higuera la Real,Igera la Real,Igera-la-Real'',hyghwyra la ryal,hygra la ryal,yi ge la la lei ya er,Ігера-ла-Реаль,Игера ла Реал,Игера-ла-Реаль,هيغويرا لا ريال,هیگرا لا رئال,伊格拉拉雷亚尔', 38.1408800, -6.6892200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42749, 'Higuera de Vargas', 'Higuera de Vargas', 'Higuera de Vargas', 38.4470000, -6.9751700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42750, 'Higuera de la Sierra', 'Higuera de la Sierra', 'Higuera,Higuera de Aracena,Higuera de la Sierra', 37.8333300, -6.4500000, 'ES', '2017-06-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42751, 'Higuera de la Serena', 'Higuera de la Serena', 'Higuera de la Serena', 38.6461600, -5.7412900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42752, 'Higuera de Calatrava', 'Higuera de Calatrava', 'Higuera de Calatrava', 37.7984800, -4.1573700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42753, 'Higuera de Arjona', 'Higuera de Arjona', '', 37.9706400, -3.9906100, 'ES', '2011-10-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42754, 'Higuera', 'Higuera', 'Higuera', 39.7255100, -5.6669200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42755, 'Herreruela de Oropesa', 'Herreruela de Oropesa', 'Herreruela de Oropesa', 39.8892800, -5.2427900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42756, 'Herrera del Duque', 'Herrera del Duque', 'Ehrrera-del''-Duke,Erera del Duke,Errera-del''-Duke,Herrera del Duque,ai lei la de er du ke,hrra dl dwkh,hyryra dyl dwkwy,Ерера дел Дуке,Еррера-дель-Дуке,Эррера-дель-Дуке,Էռերա դել Դուկե,هررا دل دوکه,هيريرا ديل دوكوي,埃雷拉德尔杜克', 39.1684000, -5.0504900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42757, 'Herrera de Alcántara', 'Herrera de Alcantara', 'Herrera de Alcantara,Herrera de Alcántara', 39.6386500, -7.4061900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42758, 'Herrera', 'Herrera', 'Ehrrera,Erera,Errera,Herrer,Herrera,ai lei la,Еррера,Эррера,Էռերա,埃雷拉', 37.3639600, -4.8497900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42759, 'Hermigua', 'Hermigua', 'Ehrmigua,Ermigua,Hermigua,Hermigva,ai er mi gua,armyghwa,hrmygwa,Ермігуа,Эрмигуа,إرميغوا,هرمیگوا,埃尔米瓜', 28.1676600, -17.1905100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42760, 'Herguijuela', 'Herguijuela', 'Herguijuela', 39.3745200, -5.7600100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42761, 'Herencia', 'Herencia', '', 39.3661600, -3.3573500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42762, 'Henarejos', 'Henarejos', 'Henarejos', 39.8666700, -1.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42763, 'Hellín', 'Hellin', 'Ehl''in,Ehl''ine,El''in,Hellin,Hellín,ai lin,ayyn,hyyn,Ельїн,Эльин,Эльине,إيين,هیین,埃林', 38.5106000, -1.7009600, 'ES', '2014-08-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42764, 'Haría', 'Haria', 'Haria,Haría', 29.1455300, -13.4998600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42765, 'Güimar', 'Guimar', 'Guimar,Güimar', 28.3112200, -16.4127600, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42766, 'Guillena', 'Guillena', '', 37.5426200, -6.0562600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42767, 'Guía de Isora', 'Guia de Isora', 'Gia-de-Isora,Gija-de-Isora,Guia,Guia de Isora,Guia de Izara,Guía,Guía de Isora,ghya dy aswra,gwya d aysra,ji ya de suo la,Гия-де-Исора,Гіа-де-Ісора,غيا دي إسورا,گویا د ایسرا,吉亚德索拉', 28.2115400, -16.7794700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42768, 'Guia', 'Guia', 'Guia de Gran Canaria,Guía de Gran Canaria', 28.1397400, -15.6329400, 'ES', '2008-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42769, 'Güevéjar', 'Guevejar', '', 37.2575900, -3.5969100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42770, 'Güéjar-Sierra', 'Guejar-Sierra', '', 37.1599400, -3.4386300, 'ES', '2008-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42771, 'Guarromán', 'Guarroman', 'Guarroman,Guarromán', 38.1828200, -3.6869700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42772, 'Guaro', 'Guaro', '', 36.6563000, -4.8343300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42773, 'Guareña', 'Guarena', 'Guarena,Guareña', 38.8595200, -6.0998700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42774, 'Guardamar del Segura', 'Guardamar del Segura', 'Guardamar,Guardamar de la Safor,Guardamar de la Segura,Guardamar del Segura', 38.0903100, -0.6555600, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42775, 'Gualchos', 'Gualchos', 'Gualchos', 36.7446700, -3.3907900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42776, 'Guadix', 'Guadix', 'Acci,Guadiks,Guadis,Guadix,Gvadiks,Quadix,gua di si,guadikusu,wady ash,Гвадикс,Гуадис,Гуадікс,وادي آش,グアディクス,瓜迪斯', 37.2993200, -3.1392200, 'ES', '2016-07-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42777, 'Guadassuar', 'Guadassuar', 'Guadassuar,Guadasuar', 39.1866300, -0.4785900, 'ES', '2015-06-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42778, 'Guadasequies', 'Guadasequies', 'Guadasequies,Guadassequies,Guadassèquies', 38.9253900, -0.4858500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42779, 'Guadamur', 'Guadamur', 'Guadamur,Gvadamur,gua da mu er,Гвадамур,Гуадамур,瓜达穆尔', 39.8117800, -4.1488500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42780, 'Guadalupe', 'Guadalupe', 'Guadalupe,Guadalupi,Gundalupe,Gvadalupe,ghwadalwby,gua da lu pei,guadarupe,Гвадалупе,Гуадалупе,Գվադալուպե,غوادالوبي,グアダルーペ,瓜达卢佩', 39.4508000, -5.3258800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42781, 'Guadalmez', 'Guadalmez', 'Guadalmez', 38.7266500, -4.9710400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42782, 'Guadalcázar', 'Guadalcazar', 'Guadalcazar,Guadalcázar', 37.7573800, -4.9438700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42783, 'Guadalcanal', 'Guadalcanal', 'Guadal''kanal'',Guadalcanal,Guadalkanal,Gvadal''kanal'',gua da er ka na er,Гвадальканаль,Гуадальканаль,Գուադալկանալ,瓜达尔卡纳尔', 38.1000000, -5.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42784, 'Guadahortuna', 'Guadahortuna', 'Guadahortuna', 37.5571100, -3.3985900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42785, 'Grazalema', 'Grazalema', 'Grazalema', 36.7601800, -5.3683900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42786, 'Granja de Torrehermosa', 'Granja de Torrehermosa', 'Granja de Torrehermosa', 38.3166700, -5.5833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42787, 'Granja de Rocamora', 'Granja de Rocamora', 'Granja de Rocamora', 38.1515700, -0.8917000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42788, 'Granadilla de Abona', 'Granadilla de Abona', 'Granadil''ja-de-Abona,Granadilla,Granadilla de Abona,ge la na di li ya de ya wo na,ghranadya dy abwna,Гранадилья-де-Абона,Гранаділья-де-Абона,غراناديا دي أبونا,格拉纳迪利亚德亚沃纳', 28.1188200, -16.5759900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42789, 'Granada', 'Granada', 'GRX,Girnata,Gorad Granada,Grana,Granada,Granada - Grenada,Granado,Granata,Graná,Grenada,Grenade,Grenado,Grenayd,Gırnata,Lungsod ng Granada,Qranada,ge la na da,ge lin na da,geulanada,ghrnatt,granada,grndh,guranada,gurenada,jranada,jrynada,kiranata,kran a da,Γρανάδα,Горад Гранада,Гранада,Гренада,גרנדה,جرانادا,جرينادا,غرناطة,غرناطہ,ګرېنادا,گرانادا,گرېنادا,ग्रानादा,গ্রানাডা,கிரனாதா,กรานาดา,გრანადა,ግራናዳ,グラナダ,グレナダ,格拉纳达,格林纳达,그라나다', 37.1881700, -3.6066700, 'ES', '2015-04-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42790, 'Graja de Iniesta', 'Graja de Iniesta', 'Graja de Iniesta', 39.5166700, -1.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42791, 'Graja de Campalbo', 'Graja de Campalbo', 'Graja de Campalbo', 39.9000000, -1.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42792, 'Gorga', 'Gorga', 'Gorga', 38.7189600, -0.3558900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42793, 'Gor', 'Gor', 'Gor', 37.3693700, -2.9701600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42794, 'Golosalvo', 'Golosalvo', 'Golosalvo', 39.2333300, -1.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42795, 'Gójar', 'Gojar', 'Gojar,Gójar', 37.1045600, -3.6056500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42796, 'Godelleta', 'Godelleta', 'Godelleta', 39.4166700, -0.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42797, 'Godella', 'Godella', 'Godella', 39.5333300, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42798, 'Gobernador', 'Gobernador', 'Gobernador', 37.4784500, -3.3211900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42799, 'Gines', 'Gines', 'Gines', 37.3864700, -6.0772900, 'ES', '2014-02-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42800, 'Gilet', 'Gilet', 'Gilet', 39.6833300, -0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42801, 'Gilena', 'Gilena', 'Gilena', 37.2515000, -4.9144200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42802, 'Gibraleón', 'Gibraleon', 'Gibraleon,Gibraleón,Khibraleon,Xibraleon,xi fu la lai weng,Хибралеон,Хібралеон,Խիբրալեոն,جبل العيون,希夫拉莱翁', 37.3762800, -6.9689500, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42803, 'Gestalgar', 'Gestalgar', 'Gestalgar,Xestalgar', 39.6000000, -0.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42804, 'Gerindote', 'Gerindote', 'Gerindote', 39.9659400, -4.3027800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42805, 'Gérgal', 'Gergal', 'Gergal,Gérgal', 37.1188600, -2.5401200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42806, 'Gerena', 'Gerena', 'Gerena', 37.5295700, -6.1547900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42807, 'Genovés', 'Genoves', 'Genoves,Genovés', 38.9891500, -0.4699200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42808, 'Génave', 'Genave', 'Genave,Génave', 38.4306200, -2.7331000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42809, 'Genalguacil', 'Genalguacil', 'Genalguacil', 36.5454600, -5.2357200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42810, 'Gelves', 'Gelves', 'Gelves', 37.3348100, -6.0260100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42811, 'Geldo', 'Geldo', 'Geldo,Khel''do,Xeldo,he er duo,jyldw,Хельдо,Խելդո,جيلدو,赫尔多', 39.8333300, -0.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42812, 'Gaucín', 'Gaucin', 'Gaucin,Gaucín', 36.5178400, -5.3158100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42813, 'Gata de Gorgos', 'Gata de Gorgos', 'Gata,Gata de Gorgos', 38.7744300, 0.0853800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42814, 'Garvín', 'Garvin', 'Garvin,Garvín', 39.7198400, -5.3467800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42815, 'Garrucha', 'Garrucha', 'Garrucha,Garrucho,La Garrucha', 37.1814100, -1.8225200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42816, 'Garrovillas', 'Garrovillas', 'Garrovillas,Garrovillas de Alconetar,Garrovillas de Alconétar', 39.7108200, -6.5503400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42817, 'Garlitos', 'Garlitos', 'Garlitos', 38.8802200, -5.0475900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42818, 'Garbayuela', 'Garbayuela', 'Garbayuela', 39.0495600, -4.9985600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42819, 'Garafía', 'Garafia', 'Garafia,Garafia vald,Garafija,Garafía,Garafía vald,Santo Domingo,gharafya,jia la fei ya,Гарафиа,Гарафія,غارافيا,加拉菲亚', 28.8166700, -17.9333300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42820, 'Garachico', 'Garachico', 'Garachico,Garachiko,Гарачико', 28.7780700, -17.7645900, 'ES', '2016-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42821, 'Garachico', 'Garachico', 'Garachico,Garachiko,Garachiro,Гарачико', 28.3736500, -16.7634200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42822, 'Garaballa', 'Garaballa', 'Garaballa', 39.8166700, -1.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42823, 'Gandia', 'Gandia', 'Gandia,Gandie,Gandija,Gandía,Гандия', 38.9666700, -0.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42824, 'Gálvez', 'Galvez', 'Galvez,Gálvez', 39.7020800, -4.2723900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42825, 'Galisteo', 'Galisteo', 'Galisteo,Galisteu,jalystyw,jia li si te ao,Галистео,Галістео,جاليستيو,加利斯特奥', 39.9764200, -6.2678200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42826, 'Galera', 'Galera', '', 37.7426200, -2.5517500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42827, 'Gáldar', 'Galdar', 'Gal''dar,Galdar,Gáldar,Гальдар', 28.1470100, -15.6502000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42828, 'Galaroza', 'Galaroza', 'Galaroza', 37.9286400, -6.7073000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42829, 'Gaibiel', 'Gaibiel', 'Gaibiel', 39.9333300, -0.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42830, 'Gádor', 'Gador', 'Gador,Gádor', 36.9532200, -2.4925400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42831, 'Gavarda', 'Gavarda', 'Gabarda,Gavarda', 39.0833300, -0.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42832, 'Gabaldón', 'Gabaldon', 'Gabaldon,Gabaldón', 39.6166700, -1.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42833, 'Fuerte del Rey', 'Fuerte del Rey', 'Fuerte del Rey', 37.8749200, -3.8838900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42834, 'Fuente Vaqueros', 'Fuente Vaqueros', 'Fuente Vagueros,Fuente Vaqueros', 37.2201900, -3.7829400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42835, 'Fuente-Tójar', 'Fuente-Tojar', '', 37.5109500, -4.1463100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42836, 'Fuentes de León', 'Fuentes de Leon', 'Fuentes de Leon,Fuentes de León', 38.0686600, -6.5388400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42837, 'Fuentes de Andalucía', 'Fuentes de Andalucia', 'Fuentes de Andalucia,Fuentes de Andalucía', 37.4640900, -5.3461500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42838, 'Fuentes', 'Fuentes', 'Fuentes', 39.9666700, -2.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42839, 'Fuenterrobles', 'Fuenterrobles', 'Fuenterrobles', 39.5833300, -1.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42840, 'Fuente Palmera', 'Fuente Palmera', 'Fuente Palmera', 37.7049400, -5.0996500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42841, 'Fuente Obejuna', 'Fuente Obejuna', 'Fuente Obejuna,Fuenteovejuna', 38.2666700, -5.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42842, 'Fuentelespino de Moya', 'Fuentelespino de Moya', 'Fuentelespino de Moya', 39.9166700, -1.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42843, 'Fuentelespino de Haro', 'Fuentelespino de Haro', 'Fuentelespino de Haro', 39.6893400, -2.6686900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42844, 'Fuente la Lancha', 'Fuente la Lancha', 'Fuente la Lancha', 38.4166700, -5.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42845, 'La Font de la Figuera', 'La Font de la Figuera', 'Fuente la Higuera,La Font de la Figuera', 38.8000000, -0.8833300, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42846, 'Fuenteheridos', 'Fuenteheridos', 'Fuenteheridos', 37.9054500, -6.6610800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42847, 'Fuente el Fresno', 'Fuente el Fresno', 'Fuente del Fresno,Fuente el Fresno', 39.2283900, -3.7748700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42848, 'Fuente de Piedra', 'Fuente de Piedra', 'Fuente de Piedra', 37.1352600, -4.7300000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42849, 'Fuente de Pedro Naharro', 'Fuente de Pedro Naharro', 'Fuente de Pedro Naharro', 39.9243800, -3.0091600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42850, 'Fuente del Maestre', 'Fuente del Maestre', 'Fuente del Maestre', 38.5265600, -6.4478200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42851, 'Fuente de Cantos', 'Fuente de Cantos', 'Fuente de Cantos', 38.2500000, -6.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42852, 'Fuentealbilla', 'Fuentealbilla', 'Fuentealbilla', 39.2666700, -1.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42853, 'Fuente-Álamo de Murcia', 'Fuente-Alamo de Murcia', 'Fuente Alamo,Fuente Álamo,Fuente-Alamo de Murcia,Fuente-Álamo de Murcia', 37.7000000, -1.1000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42854, 'Fuente-Álamo', 'Fuente-Alamo', 'Fuente-Alamo,Fuente-Álamo', 38.6928800, -1.4315800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42855, 'Fuensanta de Martos', 'Fuensanta de Martos', 'Fuensanta de Martos', 37.6475600, -3.9084600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42856, 'Fuensanta', 'Fuensanta', 'Fuensanta', 39.2333300, -2.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42857, 'Fuenllana', 'Fuenllana', 'Fuenllana', 38.7559000, -2.9581400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42858, 'Fuenlabrada de los Montes', 'Fuenlabrada de los Montes', 'Fuenlabrada de los Montes,Fuentelabrada de los Montes', 39.1328800, -4.9351300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42859, 'Fuengirola', 'Fuengirola', 'FGR,Fuehnkhirola,Fuengirola,Fuenkhirola,feng xi luo la,fu en ji luo la,fwynkhyrwla,Фуенхирола,Фуенхірола,Фуэнхирoла,Фуэнхирола,فوينخيرولا,丰希罗拉,福恩吉罗拉', 36.5399800, -4.6247300, 'ES', '2013-10-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42860, 'Fuencaliente de la Palma', 'Fuencaliente de la Palma', 'Fuencaliente de la Palma,Los Canarios,fuencaliente', 28.4923600, -17.8452900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42861, 'Fuencaliente', 'Fuencaliente', 'Fuencaliente,La Fuencaliente', 39.1862400, -4.0257600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42862, 'Fuencaliente', 'Fuencaliente', '', 38.4060200, -4.3049200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42863, 'Frontera', 'Frontera', 'Frontera,La Frontera,Las Lapas,Фронтера', 27.7540400, -18.0036700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42864, 'Frigiliana', 'Frigiliana', 'Frigiliana', 36.7874700, -3.8944100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42865, 'Fresnedoso de Ibor', 'Fresnedoso de Ibor', 'Fresnedoso de Ibor', 39.6841800, -5.5089900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42866, 'Fresneda de Altarejos', 'Fresneda de Altarejos', 'Fresneda de Altarejos', 39.9257700, -2.3149800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42867, 'Freila', 'Freila', 'Freila', 37.5299000, -2.9082800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42868, 'Fregenal de la Sierra', 'Fregenal de la Sierra', 'Fregenal,Fregenal de la Siera,Fregenal de la Sierra,Frekhenal''-de-la-S''erra,fryjynal dy la sayra,fu lei he na er de la xie la,Фрегенал де ла Сиера,Фрехеналь-де-ла-Сьерра,Фрехеналь-де-ла-Сьєрра,فريجينال دي لا سايرا,ፍሬኄናል ዴ ላ ሲዬራ,夫雷赫纳尔德拉谢拉', 38.1692200, -6.6537000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42869, 'Frailes', 'Frailes', 'Frailes', 37.4861700, -3.8374300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42870, 'Foios', 'Foios', 'Foios,Foyos', 39.5333300, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42871, 'Fortuna', 'Fortuna', 'Fortuna', 38.1814000, -1.1259000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42872, 'Fortaleny', 'Fortaleny', 'Fortaleny', 39.1833300, -0.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42873, 'Fornalutx', 'Fornalutx', 'Fornalutx', 39.7823200, 2.7410700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42874, 'Formentera de Segura', 'Formentera de Segura', 'Formentera de Segura,Formentera del Segura', 38.0850900, -0.7460400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42875, 'Fontanars dels Alforins', 'Fontanars dels Alforins', 'Fontanares,Fontanars dels Alforins', 38.7842300, -0.7866700, 'ES', '2016-04-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42876, 'Fontanarejo', 'Fontanarejo', 'Fontanarejo', 39.2201400, -4.5175300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42877, 'Fonelas', 'Fonelas', 'Fonelas', 37.4104200, -3.1715800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42878, 'Fondón', 'Fondon', 'Fondon,Fondón', 36.9802000, -2.8595700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42879, 'Firgas', 'Firgas', 'Firgas', 28.1071100, -15.5629900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42880, 'Finestrat', 'Finestrat', 'Finestrat,faynstrat,fei nei si te la te,fynstrat,Финестрат,Фінестрат,فاينسترات,فینسترات,菲内斯特拉特', 38.5673700, -0.2123500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42881, 'Fines', 'Fines', 'Fines', 37.3607400, -2.2581000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42882, 'Fiñana', 'Finana', 'Finana,Fiñana,Pinana,Piñana', 37.1715000, -2.8401100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42883, 'Ferreries', 'Ferreries', 'Ferrerias,Ferreries,Ferrerías', 39.9832400, 4.0118100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42884, 'Ferreira', 'Ferreira', 'Ferreira', 37.1724700, -3.0353900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42885, 'Fernán-Núñez', 'Fernan-Nunez', 'Fernan Nunez,Fernan-Nun''es,Fernan-Nunez,Fernán Núñez,Fernán-Núñez,fei er nan-nu nie si,fyrnan-nwnyyz  qrtbt,Фернан-Нуньес,Фернан-Нуньєс,فيرنان-نونييز، قرطبة,费尔南-努涅斯', 37.6704400, -4.7264000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42886, 'Feria', 'Feria', 'Feria,Ferija,fei li ya,frya  aspanya,fyraya,Ферия,Ферија,Ферія,Ֆերիա,فریا، اسپانیا,فيرايا,费里亚', 38.5115100, -6.5641600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42887, 'Férez', 'Ferez', 'Ferez,Férez', 38.3500000, -2.0000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42888, 'Felanitx', 'Felanitx', 'Felanitx', 39.4696000, 3.1483100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42889, 'Favara', 'Favara', 'Favara,Favareta', 39.1166700, -0.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42890, 'Faura', 'Faura', 'Faura', 39.7166700, -0.2500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42891, 'Fasnia', 'Fasnia', 'Fasnea,Fasnia', 28.2363800, -16.4388600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42892, 'Faraján', 'Farajan', 'Farajan,Faraján', 36.6169500, -5.1883900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42893, 'Famorca', 'Famorca', 'Famorca', 38.7310100, -0.2472600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42894, 'Facheca', 'Facheca', 'Facheca,Fageca', 38.7350100, -0.2676600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42895, 'Estubeny', 'Estubeny', 'Estubeny', 39.0179200, -0.6237900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42896, 'Estivella', 'Estivella', 'Estivella', 39.7166700, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42897, 'Estepona', 'Estepona', 'EVO,Ehstepona,Estepona,ai si te bo na,astybwna,esutepona,Естепона,Эстепона,إستيبونا,エステポナ,埃斯特波纳', 36.4276400, -5.1458900, 'ES', '2016-06-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42898, 'Estepa', 'Estepa', 'Ehstepa,Estepa,ai si te pa,astbt,Естепа,Эстепа,إستبة,埃斯特帕', 37.2926300, -4.8789600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42899, 'Estellencs', 'Estellencs', 'Estellencs', 39.6533800, 2.4813000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42900, 'Esporles', 'Esporles', 'Esporles', 39.6679400, 2.5786700, 'ES', '2013-11-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42901, 'Espinoso del Rey', 'Espinoso del Rey', 'Espinoso del Rey', 39.6533300, -4.7837100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42902, 'Espiel', 'Espiel', 'Espiel', 38.2000000, -5.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42903, 'Espera', 'Espera', 'Espera', 36.8744600, -5.8060000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42904, 'Espelúy', 'Espeluy', 'Espeluy,Espelúy', 38.0318000, -3.8630900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42905, 'Espejo', 'Espejo', 'Espejo', 37.6798000, -4.5535500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42906, 'Espartinas', 'Espartinas', 'Espartinas', 37.3815400, -6.1257800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42907, 'Esparragosa de la Serena', 'Esparragosa de la Serena', 'Esparragosa de la Serena', 38.6510000, -5.6065700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42908, 'Esparragosa de Lares', 'Esparragosa de Lares', 'Ehsparragosa-de-Lares,Esparagosa de Lares,Esparragosa de Lares,Esparragosa-de-Lares,ai si pa la ge sa de la lei si,asbarjwza dy lars,Еспарагоса де Ларес,Еспаррагоса-де-Ларес,Эспаррагоса-де-Ларес,إسبارجوزا دي لارس,埃斯帕拉戈萨德拉雷斯', 38.9751700, -5.2696800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42909, 'Esparragalejo', 'Esparragalejo', 'Esparragalejo', 38.9433000, -6.4354900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42910, 'Eslida', 'Eslida', 'Eslida', 39.8833300, -0.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42911, 'Escúzar', 'Escuzar', 'Escuzar,Escúzar', 37.0621900, -3.7612600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42912, 'Escurial', 'Escurial', 'Escurial', 39.1685700, -5.8846500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42913, 'Escorca', 'Escorca', 'Escorca', 39.8213800, 2.8694100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42914, 'Escañuela', 'Escanuela', 'Escanuela,Escañuela', 37.8788500, -4.0337600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42915, 'Escalonilla', 'Escalonilla', 'Escalonilla', 39.9257000, -4.3509500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42916, 'Escacena del Campo', 'Escacena del Campo', 'Escacena,Escacena del Campo', 37.4083700, -6.3887000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42917, 'Erustes', 'Erustes', 'Erustes', 39.9566700, -4.4965600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42918, 'Entrín Bajo', 'Entrin Bajo', 'Entrin Bajo,Entrín Bajo', 38.7185500, -6.7134900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42919, 'Enix', 'Enix', 'Enix', 36.8773200, -2.6018000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42920, 'Enguídanos', 'Enguidanos', 'Enguidamos,Enguidanos,Enguídanos', 39.6666700, -1.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42921, 'Enguera', 'Enguera', 'Enguera,Ènguera,Énguera', 38.9797400, -0.6868300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42922, 'Encinas Reales', 'Encinas Reales', 'Encinas Reales', 37.2741900, -4.4882800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42923, 'Encinasola', 'Encinasola', 'Encinasola,Encinosola', 38.1341300, -6.8667500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42924, 'Emperador', 'Emperador', 'Emperador', 39.5500000, -0.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42925, 'El Viso del Alcor', 'El Viso del Alcor', 'El Viso del Alcor,Viso del Alcor', 37.3910600, -5.7199300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42926, 'El Viso', 'El Viso', 'El Viso', 38.4833300, -4.9500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42927, 'El Varadero', 'El Varadero', 'Barriada El Varadero,El Varadero,Varadero', 36.7252100, -3.5218300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42928, 'El Toboso', 'El Toboso', 'Ehl''-Toboso,El Toboso,El''-Toboso,ai er tuo wo suo,altwbwsw,Ель-Тобосо,Эль-Тобосо,التوبوسو,埃尔托沃索', 39.5133300, -2.9972600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42929, 'El Saucejo', 'El Saucejo', 'El Saucejo,Saucejo', 37.0723700, -5.0981800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42930, 'El Rubio', 'El Rubio', 'El Rubio', 37.3561700, -4.9889600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42931, 'El Ronquillo', 'El Ronquillo', 'El Ronquillo,Ronquillo', 37.7262800, -6.1762000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42932, 'El Rompido', 'El Rompido', 'El Rompido', 37.2177300, -7.1220600, 'ES', '2016-10-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42933, 'El Robledo', 'El Robledo', 'El Robledo', 39.2189800, -4.2809900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42934, 'El Puerto de Santa María', 'El Puerto de Santa Maria', 'Ehl''-Puehrto-de-Santa-Marija,El Puerto,El Puerto de Santa Maria,El Puerto de Santa María,El''-Puerto-de-Santa-Marija,PXS,Portus Sanctae Mariae,Pto. de Sta. Maria,Pto. de Sta. María,Puerto,Puerto de Santa Maria,Puerto de Santa Marija,Puerto de Santa María,al bwyrtw dy santa marya,elpueleutodesantamalia,sheng ma li ya gang,xelpwyr to de san ta ma ri xa,Ель-Пуерто-де-Санта-Марія,Пуерто де Санта Марија,Эль-Пуэрто-де-Санта-Мария,إل بويرتو دي سانتا ماريا,เอลปวยร์โตเดซานตามารีอา,エル・プエルト・デ・サンタ・マリア,圣玛丽亚港,엘푸에르토데산타마리아', 36.5938900, -6.2329800, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42935, 'El Puente del Arzobispo', 'El Puente del Arzobispo', 'El Puente del Arzobispo,Puente del Arzobispo', 39.8017400, -5.1717800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42936, 'El Provencio', 'El Provencio', 'El Provencio', 39.3774000, -2.5744800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42937, 'Port de Sóller', 'Port de Soller', 'Port de Soller,Port de Sóller,Puerto de Soller,Puerto de Sóller', 39.7975900, 2.6963700, 'ES', '2016-09-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42938, 'El Pedernoso', 'El Pedernoso', 'El Pedernoso', 39.4858000, -2.7464200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42939, 'El Paso', 'El Paso', 'Ehl''-Paso,El Paso,El''-Paso,Paso,ai er pa suo,al basw  santa krwth dy tynyryfh,Ель-Пасо,Эль-Пасо,إل باسو، سانتا كروث دي تينيريفه,埃尔帕索', 28.6500700, -17.8827400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42940, 'El Grao', 'El Grao', 'El Grao,El Grao de Gandia,El Grao de Gandía,Grao,Grao de Castellon,Grao de Castellón', 39.9735800, 0.0128400, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42941, 'El Gastor', 'El Gastor', 'El Gastor', 36.8547800, -5.3233400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42942, 'El Ejido', 'El Ejido', 'Barriada El Ejido,Ehl''-Ehkhido,Ejido,Ekhido,El Edzido,El Ejido,El''-Ekhido,ai lai xi duo,al akhydw,alayjaydw,Ел Еџидо,Ель-Ехідо,Ехидо,Эль-Эхидо,إلإيجايدو,ال اخیدو,エル・エヒド,埃莱希多', 36.7762900, -2.8145600, 'ES', '2015-09-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42943, 'Elda', 'Elda', 'Ehl''da,El''da,Elda,ai er da,alda,xe lda,Елда,Ельда,Эльда,Էլդա,إلدا,الدا,เอลดา,埃尔达', 38.4778300, -0.7915700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42944, 'El Coronil', 'El Coronil', 'El Coronil,El Goronil', 37.0795500, -5.6341000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42945, 'Elche de la Sierra', 'Elche de la Sierra', 'Elche Sierra,Elche de la Sierra', 38.4512300, -2.0476000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42946, 'Elche', 'Elche', 'Ehl''ch,Ehl''che,El''che,Elce,Elch,Elche,Elig,Elx,Elčė,Illici,ai er qie,alchh,alsh,elche,eruche,xelche,ʼls,Елч,Елче,Ельче,Эльч,Эльче,אלש,إلش,الش,الچه,เอลเช,ელჩე,エルチェ,埃爾切,엘체', 38.2621800, -0.7010700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42947, 'El Cerro de Andévalo', 'El Cerro de Andevalo', 'El Cerro,El Cerro de Andevalo,El Cerro de Andévalo', 37.7353700, -6.9369200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42948, 'El Castillo de las Guardas', 'El Castillo de las Guardas', 'El Castello de las Guardas,El Castillo de las Guardas', 37.6931400, -6.3150300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42949, 'El Casar', 'El Casar', 'Cortijo El Casar,El Casar', 38.5308900, -5.9251300, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42950, 'El Carpio de Tajo', 'El Carpio de Tajo', 'El Carpio de Tajo', 39.8879600, -4.4538800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42951, 'El Carpio', 'El Carpio', 'El Carpio', 37.9408500, -4.4969600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42952, 'El Bosque', 'El Bosque', '', 36.7582800, -5.5053500, 'ES', '2008-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42953, 'El Bonillo', 'El Bonillo', 'Bonillo,El Bonillo', 38.9504800, -2.5404800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42954, 's''Arenal', 's''Arenal', 'Arenal'',El Arenal,S''Arenal,l''Arenal,Ареналь', 39.5000000, 2.7500000, 'ES', '2013-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42955, 'El Arahal', 'El Arahal', 'Arahal,El Arahal', 37.2627300, -5.5453000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42956, 'Écija', 'Ecija', 'Ecija,Ehsikha,Esikha,Exija,ai xi ha,astjt,Écija,Есіха,Эсиха,إستجة,埃西哈', 37.5422000, -5.0826000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42957, 'Dúrcal', 'Durcal', '', 36.9878800, -3.5660100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42958, 'Dúdar', 'Dudar', 'Dudar,Dúdar', 37.1857900, -3.4834700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42959, 'Dos Torres', 'Dos Torres', 'Dos Torres', 38.4500000, -4.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42960, 'Dos Hermanas', 'Dos Hermanas', 'Dos Ermanas,Dos Hermanas,Дос Ерманас', 37.2828700, -5.9208800, 'ES', '2013-12-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42961, 'Dosbarrios', 'Dosbarrios', 'Dosbarrios', 39.8819900, -3.4841900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42962, 'Dos Aguas', 'Dos Aguas', 'Dos Aguas,Dos-Aguas,Dosaiguees,Dosaigües,duo sa gua si,Дос-Агуас,多萨瓜斯', 39.2833300, -0.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42963, 'Don Benito', 'Don Benito', 'Don Benito,Don Benitu,Don-Benito,dong wei ni tuo,dwn bynaytw,Дон Бенито,Дон-Бенито,Дон-Беніто,دون بينايتو,ドン・ベニート,东韦尼托', 38.9562700, -5.8616200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42964, 'Doña Mencía', 'Dona Mencia', 'Dona Mencia,Doña Mencía', 37.5534600, -4.3560200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42965, 'Don Álvaro', 'Don Alvaro', 'Don Alvaro,Don Álvaro', 38.8483700, -6.2747500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42966, 'Domingo Pérez', 'Domingo Perez', 'Domingo Perez,Domingo Pérez', 39.9766100, -4.5055400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42967, 'Domingo Pérez', 'Domingo Perez', 'Domingo Perez,Domingo Pérez', 37.4959100, -3.5092900, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42968, 'Domeño', 'Domeno', 'Domeno,Domenyo,Domeño', 39.6611500, -0.6707700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42969, 'Dolores', 'Dolores', 'Dolores,Dolors', 38.1400200, -0.7708800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42970, 'Dílar', 'Dilar', 'Dilar,Dílar', 37.0728200, -3.6013400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42971, 'Diezma', 'Diezma', 'Diezma', 37.3198200, -3.3325600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42972, 'Deià', 'Deia', 'Deia,Deià', 39.7480600, 2.6482300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42973, 'Denia', 'Denia', 'Denia,Denija,Dénia,Дения', 38.8407800, 0.1057400, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42974, 'Deleitosa', 'Deleitosa', 'Deleitosa', 39.6435900, -5.6457600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42975, 'Deifontes', 'Deifontes', 'Deifontes', 37.3262000, -3.5956800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42976, 'Dehesas Viejas', 'Dehesas Viejas', 'Dehesas Viejas', 37.4741400, -3.5522500, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42977, 'Dehesas de Guadix', 'Dehesas de Guadix', 'Deehsas-de-Guadiks,Deesas-de-Guadiks,Deesas-de-Gvadiks,Dehesas de Guadix,de ai sa si de gua di si,dyyysas dy ghwadyks,Деесас-де-Гвадикс,Деесас-де-Гуадікс,Деэсас-де-Гуадикс,Դեեսաս դե Գուադիքս,ديئيساس دي غواديكس,德埃萨斯德瓜迪斯', 37.5887600, -3.1031700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42978, 'Daya Vieja', 'Daya Vieja', 'Daia Vella,Daya Vieja', 38.1048000, -0.7380400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42979, 'Daya Nueva', 'Daya Nueva', 'Daia Nova,Daya Nueva', 38.1131300, -0.7602800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42980, 'Darro', 'Darro', 'Darro', 37.3498700, -3.2946500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42981, 'Dalías', 'Dalias', 'Dalias,da li ya si,dalyas,dlayt,Далиас,Даліас,دالیاس,دلاية,达利亚斯', 36.8217900, -2.8713800, 'ES', '2008-11-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42982, 'Daimús', 'Daimus', 'Daimus,Daimuz,Daimús', 38.9666700, -0.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42983, 'Daimiel', 'Daimiel', 'Daimiel,Dajm''el'',Dajmel'',dai mi ye er,daymyl  sywdad ryal,Даймьель,Даймєль,دايميل، سيوداد ريال,代米耶尔', 39.0700400, -3.6149800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42984, 'Cútar', 'Cutar', 'Cutar,Cútar', 36.8313400, -4.2273900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42985, 'Cumbres Mayores', 'Cumbres Mayores', 'Cumbres Mayores', 38.0619400, -6.6456500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42986, 'Cullera', 'Cullera', 'Cullera,Kul''era,ku lie la,Кульера,Кульєра,库列拉', 39.1666700, -0.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42987, 'Cúllar-Vega', 'Cullar-Vega', '', 37.1536100, -3.6707200, 'ES', '2008-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42988, 'Cuevas de San Marcos', 'Cuevas de San Marcos', 'Cuevas de San Marcos', 37.2666600, -4.4143200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42989, 'Cuevas del Campo', 'Cuevas del Campo', 'Cuevas del Campo', 37.6075500, -2.9293800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42990, 'Cuevas del Becerro', 'Cuevas del Becerro', 'Cuevas del Becerro', 36.8753700, -5.0448800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42991, 'Cuevas del Almanzora', 'Cuevas del Almanzora', 'Cuevas de Almanzora,Cuevas de Vera,Cuevas del Almanzora,Kevas del Almazora,Kuehvas-del''-Al''mansora,Kuevas-del''-Al''mansora,khwf almnswrt,ku ai wa si de la er man suo la,kwybas dl almanswra,Кевас дел Алмазора,Куевас-дель-Альмансора,Куэвас-дель-Альмансора,كهوف المنصورة,کوئباس دل آلمانسورا,クエバス・デル・アルマンソーラ,库埃瓦斯德拉尔曼索拉', 37.2964600, -1.8846600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42992, 'Cuevas Bajas', 'Cuevas Bajas', 'Cuevas Bajas', 37.2352600, -4.4871400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42993, 'Cuerva', 'Cuerva', 'Aebura,Cuerva,Libora', 39.6637400, -4.2108500, 'ES', '2012-03-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42994, 'Quatretonda', 'Quatretonda', 'Cuatretonda,Quatretonda', 38.9500000, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42995, 'Quartell', 'Quartell', 'Cuartell,Quartell', 39.7333300, -0.2666700, 'ES', '2010-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42996, 'Quart de Poblet', 'Quart de Poblet', 'Cuart de Poblet,Kuart-de-Poblet,Quart de Poblet,Куарт-де-Поблет', 39.4813900, -0.4393700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42997, 'Quart de les Valls', 'Quart de les Valls', 'Cuart de les Valls,Quart de les Valls', 39.7333300, -0.2666700, 'ES', '2010-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42998, 'Cristina', 'Cristina', 'Cristina', 38.8374500, -6.0986700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(42999, 'Crevillente', 'Crevillente', 'Crevillent,Crevillente,Krevil''ente,Кревильенте', 38.2499400, -0.8097500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43000, 'Cózar', 'Cozar', '', 38.6621900, -3.0720500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43001, 'Cox', 'Cox', 'Coix,Cox', 38.1416400, -0.8873600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43002, 'Cotillas', 'Cotillas', 'Cotillas', 38.4311500, -2.5055000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43003, 'Cotes', 'Cotes', 'Cotes', 39.0701000, -0.5744900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43004, 'Costitx', 'Costitx', 'Costitx', 39.6567500, 2.9495300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43005, 'Cortes de Pallás', 'Cortes de Pallas', 'Cortes de Pallas,Cortes de Pallás,Cortez de Pallas', 39.2500000, -0.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43006, 'Cortes de la Frontera', 'Cortes de la Frontera', 'Cortes de la Frontera', 36.6171000, -5.3426600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43007, 'Cortes de Baza', 'Cortes de Baza', 'Cortes de Baza', 37.6551400, -2.7716700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43008, 'Cortelazor', 'Cortelazor', 'Cortelazor', 37.9363900, -6.6246200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43009, 'Cortegana', 'Cortegana', '', 37.9111600, -6.8204500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43010, 'Corte de Peleas', 'Corte de Peleas', 'Corte de Peleas', 38.7263100, -6.6703500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43011, 'Corteconcepción', 'Corteconcepcion', 'Corteconcepcion,Corteconcepción', 37.9000000, -6.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43012, 'Corral-Rubio', 'Corral-Rubio', 'Corral-Rubio', 38.8346200, -1.4603400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43013, 'Corralejo', 'Corralejo', 'Corralejo,Koral''ekho,QFU,Коральехо', 28.7307900, -13.8674900, 'ES', '2014-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43014, 'Corral de Calatrava', 'Corral de Calatrava', 'Corral de Calatrava', 38.8579300, -4.0814000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43015, 'Corral de Almaguer', 'Corral de Almaguer', 'Corral de Almaguer', 39.7598700, -3.1645200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43016, 'Coripe', 'Coripe', 'Coripe', 36.9733500, -5.4402200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43017, 'Coria del Río', 'Coria del Rio', 'Coria del Rio,Coria del Río,Koria-del''-Rio,Кориа-дель-Рио,コリア・デル・リオ', 37.2876600, -6.0541000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43018, 'Coria', 'Coria', 'Coria', 39.9840600, -6.5360300, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43019, 'Cordobilla de Lácara', 'Cordobilla de Lacara', 'Cordobilla de Lacara,Cordobilla de Lácara,Kordobil''ja-de-Lakara,Kordobila de Lakara,ke er duo wei li ya de la ka la,kwrdwbayla dy lakara,Кордобила де Лакара,Кордобилья-де-Лакара,Кордобілья-де-Лакара,كوردوبايلا دي لاكارا,科尔多维利亚德拉卡拉', 39.1476300, -6.4361900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43020, 'Córdoba', 'Cordoba', 'Cardoue,Cordoa,Cordoba,Cordoba i Spania,Cordoue,Cordova,Corduba,Còrdoa,Còrdova,Córdoba,Córdoba i Spania,Córdova,Córduba,Gorad Kordava,Kordoba,Kordova,Kordovo,Kordowa,ODB,ge duo hua,ke er duo wa,koleudoba,kordoba,korudoba,kurtupa,kwrdwba,kxr do ba,kۆrdۆba,qrtbh,qrtbt,qwrdwbh,Κόρδοβα,Горад Кордава,Кордоба,Кордова,Կորդովա,קארדאבע,קורדובה,قرطبة,قرطبه,قرطبہ,كوردوبا,کوردوبا,کۆردۆبا,कोर्दोबा,குர்துபா,กอร์โดบา,კორდობა,コルドバ,哥多華,科爾多瓦,코르도바', 37.8915500, -4.7727500, 'ES', '2013-09-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43021, 'Corbera', 'Corbera', 'Corbera,Corbera de Alcira', 39.1500000, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43022, 'Consuegra', 'Consuegra', 'Aebura,Consuegra,Konsuegra,Konsuehgra,kong su ai ge la,Консуегра,Консуэгра,孔苏埃格拉', 39.4624600, -3.6080000, 'ES', '2012-10-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43023, 'Constantina', 'Constantina', 'Constantina,Konstantina,Laconimurgi,kong si tan di na,Константина,Константіна,孔斯坦蒂纳', 37.8666700, -5.6166700, 'ES', '2015-10-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43024, 'Consell', 'Consell', 'Consell', 39.6686100, 2.8126700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43025, 'Conquista de la Sierra', 'Conquista de la Sierra', 'Conquista de la Sierra,Konkista-de-la-S''erra,kong ji si ta de la xie la,kwnkwysta dy la sayra,Конкиста-де-ла-Сьерра,Конкіста-де-ла-Сьєрра,كونكويستا دي لا سايرا,孔基斯塔德拉谢拉', 39.3507000, -5.7346400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43026, 'Conquista', 'Conquista', 'Conquista', 38.4000000, -4.5000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43027, 'Conil de la Frontera', 'Conil de la Frontera', 'Conil,Conil de la Frontera', 36.2771900, -6.0885000, 'ES', '2013-02-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43028, 'Confrides', 'Confrides', 'Confrides,Konfrides,kong fu li de si,kwnfarydz,kwnfryds,Конфридес,Конфрідес,كونفاريدز,کونفریدس,孔夫里德斯', 38.6845100, -0.2689000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43029, 'Cómpeta', 'Competa', 'Competa,Cómpeta', 36.8335200, -3.9743000, 'ES', '2014-10-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43030, 'Comares', 'Comares', 'Comares', 36.8492900, -4.2466400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43031, 'Colomera', 'Colomera', 'Colomera', 37.3715600, -3.7139300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43032, 'Colmenar', 'Colmenar', '', 36.9051900, -4.3355700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43033, 'Coín', 'Coin', '', 36.6594700, -4.7563900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43034, 'Cogollos de Guadix', 'Cogollos de Guadix', 'Cogollos de Guadix', 37.2252100, -3.1609400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43035, 'Cofrentes', 'Cofrentes', 'Cofrentes,Cofrents,Kofrentes,ke fu lun te si,Кофрентес,科夫伦特斯', 39.2292600, -1.0606100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43036, 'Cocentaina', 'Cocentaina', 'Cocentaina,Kosentajna,ke sen tai na,kwkyntayna,kwsntayna,Косентайна,كوكينتاينا,کوسنتاینا,科森泰纳', 38.7397500, -0.4397600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43037, 'Cobisa', 'Cobisa', 'Cobisa', 39.8042500, -4.0252800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43038, 'Cóbdar', 'Cobdar', 'Cobdar,Cóbdar', 37.2616600, -2.2109800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43039, 'Ciudad Real', 'Ciudad Real', 'CQM,Cidade Real,Ciuda Real,Ciudad Real,Ciudá Real,Gorad S''judad-Rehal'',S''judad-Real'',Sijudad Real,Villa-Real,lei a er cheng,siudadeuleal,sywdad ryal,thywdad ryal,Горад Сьюдад-Рэаль,Сијудад Реал,Сьюдад-Реаль,סיודאד ריאל,ثيوداد ريال,سیوداد رئال,シウダー・レアル,雷阿爾城,시우다드레알', 38.9862600, -3.9290700, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43040, 'Ciruelos', 'Ciruelos', '', 39.9388100, -3.6138300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43041, 'Cijuela', 'Cijuela', '', 37.1980000, -3.8117400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43042, 'Cieza', 'Cieza', 'Cieza,S''esa,Siesa,sysa,thytha,xi ye sa,Сьеса,Сьєса,Սիեսա,ثيثا,سیسا,希耶萨', 38.2399800, -1.4198700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43043, 'Churriana de la Vega', 'Churriana de la Vega', 'Churriana', 37.1449900, -3.6461700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43044, 'Chumillas', 'Chumillas', 'Chumillas', 39.7666700, -2.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43045, 'Chulilla', 'Chulilla', 'Chulilla,Xulella', 39.6500000, -0.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43046, 'Chueca', 'Chueca', 'Chueca', 39.7319100, -3.9436500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43047, 'Chucena', 'Chucena', 'Chucena', 37.3630500, -6.3930400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43048, 'Chóvar', 'Chovar', 'Chovar,Chóvar,Xovar', 39.8500000, -0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43049, 'Chiva', 'Chiva', 'Chiva,Xiva de Bunyol,qi wa,Чива,奇瓦', 39.4666700, -0.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43050, 'Xirivella', 'Xirivella', 'Chirivel''ja,Чиривелья', 39.4658800, -0.4258900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43051, 'Chirivel', 'Chirivel', 'Chirivel', 37.5952700, -2.2684400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43052, 'Chipiona', 'Chipiona', 'Chipiana,Chipiona,chipiona,qi pi ao na,tshaybywna,Чипиона,Чипіона,تشايبيونا,奇皮奥纳,치피오나', 36.7366300, -6.4370300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43053, 'Chinchilla de Monte Aragón', 'Chinchilla de Monte Aragon', 'Chinchilla,Chinchilla de Monte Aragon,Chinchilla de Monte Aragón', 38.9208800, -1.7201800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43054, 'Chimeneas', 'Chimeneas', 'Chimeneas', 37.1312500, -3.8213000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43055, 'Chilluévar', 'Chilluevar', 'Chilluevar,Chilluévar', 38.0008800, -3.0324000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43056, 'Chillón', 'Chillon', 'Chillon,Chillón', 38.7959500, -4.8662800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43057, 'Chilches', 'Chilches', 'Chilches,Xilxes', 39.7823800, -0.1874200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43058, 'Chiclana de Segura', 'Chiclana de Segura', 'Chiclana,Chiclana de Segura', 38.3118700, -3.0421900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43059, 'Chiclana de la Frontera', 'Chiclana de la Frontera', 'Chiclana,Chiclana de la Frontera,Chiklana-de-la-Frontera,Чиклана-де-ла-Фронтера', 36.4191500, -6.1494100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43060, 'Cheste', 'Cheste', 'Cheste,Xest', 39.4833300, -0.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43061, 'Chercos', 'Chercos', 'Chercos', 37.2545000, -2.2665700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43062, 'Chera', 'Chera', 'Chera,Xera', 39.6000000, -0.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43063, 'Chelva', 'Chelva', 'Chel''va,Chelva,Xelva,qie er wa,Чельва,Չելվա,切尔瓦', 39.7493000, -0.9968400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43064, 'Chella', 'Chella', 'Chella,Xella', 39.0420300, -0.6591600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43065, 'Cheles', 'Cheles', 'Cheles', 38.5122500, -7.2817700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43066, 'Chauchina', 'Chauchina', '', 37.1997700, -3.7715700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43067, 'Ceuti', 'Ceuti', 'Ceuti', 38.0785900, -1.2746700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43068, 'Cervera del Llano', 'Cervera del Llano', 'Cervera del Llano', 39.7831200, -2.4201900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43069, 'Cerdà', 'Cerda', 'Cerda,Cerdà,Cerdá', 38.9833300, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43070, 'Cenizate', 'Cenizate', 'Cenizate', 39.3000000, -1.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43071, 'Cenes de la Vega', 'Cenes de la Vega', 'Cenes de la Vega', 37.1600600, -3.5354800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43072, 'Cehegín', 'Cehegin', 'Cehegin,Cehegín', 38.0924200, -1.7985000, 'ES', '2010-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43073, 'Cedillo', 'Cedillo', 'Cedillo', 39.6509900, -7.4981700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43074, 'Ceclavín', 'Ceclavin', 'Ceclavin,Ceclavín', 39.8223100, -6.7732900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43075, 'Cebolla', 'Cebolla', 'Cebolla', 39.9489700, -4.5717500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43076, 'Cazorla', 'Cazorla', 'Cazorla,Kasorla,ka suo er la,kasrla,kathwrla  khayn,Касорла,كاثورلا، خاين,کاسرلا,卡索尔拉', 37.9149500, -3.0034200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43077, 'Cazalla de la Sierra', 'Cazalla de la Sierra', 'Cazalla,Cazalla de la Sierra', 37.9333300, -5.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43078, 'Cazalilla', 'Cazalilla', 'Cazalilla', 37.9838900, -3.8829500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43079, 'Caudete de las Fuentes', 'Caudete de las Fuentes', 'Caudete de las Fuentes', 39.5596500, -1.2785300, 'ES', '2015-06-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43080, 'Caudete', 'Caudete', 'Cabdet,Caudete', 38.7067900, -0.9872300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43081, 'Catral', 'Catral', 'Barrio de Catral,Barrio de Catral y Callosa,Catral,Katral'',ka te la er,katral,Катраль,كاترال,کاترال,卡特拉尔', 38.1606100, -0.8020900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43082, 'Catarroja', 'Catarroja', 'Catarroja,Katarrokh,Катаррох', 39.4000000, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43083, 'Catadau', 'Catadau', 'Catadau', 39.2666700, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43084, 'Castuera', 'Castuera', 'Castuera,Kastuehra,Kastuera,ka si tu ai la,kastwyra,Кастуера,Кастуэра,كاستويرا,卡斯图埃拉', 38.7320400, -5.5439000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43085, 'Castro del Río', 'Castro del Rio', 'Castro del Rio,Castro del Río,Kastro-del''-Rio,ka si te luo de er li ao,kastrw dyl ryw  qrtbt,Кастро-дель-Рио,Кастро-дель-Ріо,كاسترو ديل ريو، قرطبة,卡斯特罗德尔里奥', 37.6912500, -4.4805800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43086, 'Castro de Filabres', 'Castro de Filabres', 'Castro de Filabres', 37.1848400, -2.4402400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43087, 'Castril', 'Castril', 'Castril,Kastril'',ka si te li er,kastryl  ghrnatt,Кастриль,Кастріль,كاستريل، غرناطة,卡斯特里尔', 37.7958100, -2.7800200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43088, 'Castillo de Locubín', 'Castillo de Locubin', '', 37.5285800, -3.9422000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43089, 'Castillo de Garcimuñoz', 'Castillo de Garcimunoz', 'Castillo de Garcimunoz,Castillo de Garcimuñoz', 39.6592800, -2.3803000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43090, 'Castillejo de Iniesta', 'Castillejo de Iniesta', 'Castillejo de Iniesta', 39.5333300, -1.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43091, 'Castilléjar', 'Castillejar', 'Castillejar,Castilléjar', 37.7169700, -2.6406000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43092, 'Castilleja del Campo', 'Castilleja del Campo', 'Castilleja del Campo', 37.3862700, -6.3344300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43093, 'Castilleja de la Cuesta', 'Castilleja de la Cuesta', 'Castilleja,Castilleja de la Cuesta', 37.3859400, -6.0525800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43094, 'Castilleja de Guzmán', 'Castilleja de Guzman', 'Castilleja de Guzman,Castilleja de Guzmán', 37.4095500, -6.0551500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43095, 'Castilblanco de los Arroyos', 'Castilblanco de los Arroyos', 'Castilblanco,Castilblanco de los Arroyos', 37.6757600, -5.9888600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43096, 'Castilblanco', 'Castilblanco', 'Castilblanco,Kastil''blanko,Kastilblanko,ka si di er fu lan ke,kastylblankw,Кастилбланко,Кастильбланко,Кастільбланко,كاستيلبلانكو,卡斯蒂尔夫兰科', 39.2848700, -5.0909800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43097, 'Castellonet de la Conquesta', 'Castellonet de la Conquesta', 'Castellonet,Castellonet de la Conquesta', 38.9166700, -0.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43098, 'Castelló de Rugat', 'Castello de Rugat', 'Castello de Rugat,Castellon de Rugat,Castelló de Rugat,Castellón de Rugat', 38.8833300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43099, 'Castelló de la Plana', 'Castello de la Plana', 'CDT,Castello,Castello de la Plana,Castellon,Castellon de la Plana,Castelló,Castelló de la Plana,Castellón,Castellón de la Plana,Kastel''on-de-la-Plana,Kastelon de la Plana,ka si te li weng-de la pu la na,qʼstywn dh lh plʼnh,Кастельон-де-ла-Плана,Кастељон де ла Плана,קאסטיון דה לה פלאנה,カステリョン・デ・ラ・プラナ,卡斯特利翁-德拉普拉納', 39.9856700, -0.0493500, 'ES', '2016-05-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43100, 'Castellnovo', 'Castellnovo', 'Castellnou de Sogorb,Castellnovo', 39.8666700, -0.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43101, 'Castell de Ferro', 'Castell de Ferro', 'Castell de Ferro', 36.7256900, -3.3550000, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43102, 'Castell de Castells', 'Castell de Castells', 'Castell de Castells,Castells de Castells', 38.7255500, -0.1924200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43103, 'Castellar de Santiago', 'Castellar de Santiago', 'Castellar de Santiago', 38.5392800, -3.2757300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43104, 'Castellar de la Frontera', 'Castellar de la Frontera', 'Castellar,Castellar de la Frontera,Kastel''jar-de-la-Frontera,ka si te li ya er de la fu long te la,kastylar dy la frwntyra,Кастельяр-де-ла-Фронтера,كاستيلار دي لا فرونتيرا,卡斯特利亚尔德拉夫龙特拉', 36.3173600, -5.4540700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43105, 'Cástaras', 'Castaras', 'Castaras,Cástaras', 36.9316400, -3.2540600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43106, 'Castañar de Ibor', 'Castanar de Ibor', 'Castanar de Ibor,Castañar de Ibor', 39.6284300, -5.4170900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43107, 'Castalla', 'Castalla', 'Castalla,Kastal''ja,ka si ta li ya,kastala,kastaya,Касталья,كاستالا,کاستایا,卡斯塔利亚', 38.5969400, -0.6720700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43108, 'Casinos', 'Casinos', 'Casinos', 39.7000000, -0.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43109, 'Casillas de Coria', 'Casillas de Coria', 'Casillas de Coria', 39.9654300, -6.6371100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43110, 'Casatejada', 'Casatejada', 'Casatejada', 39.8864200, -5.6819300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43111, 'Casasimarro', 'Casasimarro', 'Casasimarro,Kasasimarro,ka sa xi ma luo,kasasymarw,Касасимарро,Касасімарро,كاساسيمارو,卡萨西马罗', 39.3666700, -2.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43112, 'Casas Ibáñez', 'Casas Ibanez', 'Casas Ibanez,Casas Ibáñez', 39.2833300, -1.4666700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43113, 'Casas de Ves', 'Casas de Ves', 'Casas de Ves', 39.2500000, -1.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43114, 'Casas de Reina', 'Casas de Reina', 'Casas de Reina,Las Casas', 38.2000000, -5.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43115, 'Casas de Miravete', 'Casas de Miravete', 'Casas de Miravete', 39.7268700, -5.7436300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43116, 'Casas de Millán', 'Casas de Millan', 'Casas de Millan,Casas de Millán', 39.8175700, -6.3296600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43117, 'Casas de los Pinos', 'Casas de los Pinos', 'Casas de los Pinos', 39.3337500, -2.3698400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43118, 'Casas de Lázaro', 'Casas de Lazaro', 'Casas de Lazaro,Casas de Lázaro', 38.7705600, -2.2404400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43119, 'Casas de Juan Núñez', 'Casas de Juan Nunez', 'Casas de Juan Nunez,Casas de Juan Núñez', 39.1019000, -1.5582100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43120, 'Casas de Haro', 'Casas de Haro', 'Casas de Haro', 39.3335500, -2.2727300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43121, 'Casas de Guijarro', 'Casas de Guijarro', 'Casas de Guijarro', 39.3500000, -2.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43122, 'Casas de Garcimolina', 'Casas de Garcimolina', 'Casas de Garcimolina', 40.0000000, -1.4166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43123, 'Casas de Fernando Alonso', 'Casas de Fernando Alonso', 'Casas de Fernando Alonso,Casas de los Teatinos', 39.3506500, -2.3240200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43124, 'Casas de Don Pedro', 'Casas de Don Pedro', '', 39.1082200, -5.3307700, 'ES', '2009-03-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43125, 'Casas de Don Antonio', 'Casas de Don Antonio', 'Casas de Don Antonio', 39.2357800, -6.2914300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43126, 'Casas de Benítez', 'Casas de Benitez', 'Casas de Benitez,Casas de Benítez', 39.3666700, -2.1333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43127, 'Casasbuenas', 'Casasbuenas', 'Casasbuenas', 39.7611700, -4.1255800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43128, 'Casariche', 'Casariche', 'Casariche,Kasariche,ka sa li qie,Касариче,Касаріче,卡萨里切', 37.2938900, -4.7597200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43129, 'Casares', 'Casares', 'Casares,Kasares,ka sa lei si,kasars,kasarys,Касарес,Կասարես,كاساريس,کاسارس,卡萨雷斯', 36.4468900, -5.2858000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43130, 'Casar de Cáceres', 'Casar de Caceres', 'Casal de Cacris,Casal de Caçris,Casar de Caceres,Casar de Cáceres,Kasar de Kaseres,Kasar-de-Kaseres,ka sa er de ka sai lei si,kasar dy qsrsh,Касар-де-Касерес,Կասար դե Կասերես,كاسار دي قصرش,卡萨尔德卡塞雷斯', 39.5610600, -6.4194400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43131, 'Casarabonela', 'Casarabonela', 'Casarabonela', 36.7861600, -4.8427600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43132, 'Casabermeja', 'Casabermeja', 'Casabermeja', 36.8926000, -4.4293800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43133, 'Cartaya', 'Cartaya', 'Cartaya', 37.2811400, -7.1507100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43134, 'Estación de Cártama', 'Estacion de Cartama', '', 36.7333300, -4.6166700, 'ES', '2006-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43135, 'Cártama', 'Cartama', 'Kartama,ka er ta ma,kartama,Картама,كارتاما,卡尔塔马', 36.7106800, -4.6329700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43136, 'Cartajima', 'Cartajima', 'Cartajima', 36.6454800, -5.1541000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43137, 'Cartagena', 'Cartagena', 'Cartachena,Cartagena,Cartagena i Spania,Cartaxena,Carthagene,Carthago Nova,Carthagène,Gorad Kartakhena,Kartachena,Kartagena,Kartagina,Kartagjena,Kartahena,Kartaheno,Kartakhena,Kartaĥeno,Karthageni,XUF,ka ta he na,kaleutahena,kartagna,kartajena,kartajina,kartakhyna,kartygana,karutahena,qrthnh,Καρθαγένη,Горад Картахена,Картагена,Картагина,Картахена,קרטחנה,كارتاخينا,کارتاگنا,کارتیگانا,कार्टाजेना,कार्ताजिना,კარტახენა,ካርታሔና,カルタヘナ,卡塔赫纳,카르타헤나', 37.6051200, -0.9862300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43138, 'Carrizosa', 'Carrizosa', 'Carrizosa', 38.8420400, -2.9925000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43139, 'Carrizal', 'Carrizal', 'Carrizal de Ingenio,El Carrizal', 27.9116100, -15.4055800, 'ES', '2016-10-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43140, 'Carrión de los Céspedes', 'Carrion de los Cespedes', 'Carrion de los Cespedes,Carrión de los Céspedes', 37.3700700, -6.3292300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43141, 'Carrión de Calatrava', 'Carrion de Calatrava', 'Carrion,Carrion de Calatrava,Carrión,Carrión de Calatrava', 39.0189700, -3.8168300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43142, 'Carrícola', 'Carricola', 'Carricola,Carrícola', 38.8413300, -0.4726000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43143, 'Carriches', 'Carriches', 'Carriches', 39.9641700, -4.4586400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43144, 'Carratraca', 'Carratraca', 'Carratraca', 36.8529000, -4.8199800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43145, 'Carrascosa de Haro', 'Carrascosa de Haro', 'Carrascosa de Haro', 39.5975700, -2.5418200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43146, 'Carrascalejo', 'Carrascalejo', 'Carrascalejo', 39.6333300, -5.2166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43147, 'Carmonita', 'Carmonita', 'Carmonita', 39.1545500, -6.3386400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43148, 'Carmona', 'Carmona', 'Carmona,Karmona,Кармона', 37.4712500, -5.6460800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43149, 'Carmena', 'Carmena', 'Carmena', 39.9556200, -4.4014900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43150, 'Carlet', 'Carlet', 'Carlet,Karlet,ka er lai te,Карлет,卡尔莱特', 39.2266000, -0.5214200, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43151, 'Cardenete', 'Cardenete', 'Cardenete', 39.7666700, -1.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43152, 'Cardeña', 'Cardena', 'Cardena,Cardenas,Cardeña,Cárdenas', 38.2702300, -4.3235800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43153, 'Càrcer', 'Carcer', 'Carcer,Càrcer,Cárcer', 39.0666700, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43154, 'Carcelén', 'Carcelen', 'Carcelen,Carcelén', 39.1020200, -1.3087900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43155, 'Carcaixent', 'Carcaixent', 'Carcagente,Carcaixen,Carcaixent,Carcaixén,Karkakhente,Каркахенте', 39.1218000, -0.4481200, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43156, 'Carcabuey', 'Carcabuey', '', 37.4442000, -4.2747100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43157, 'Carboneros', 'Carboneros', 'Carboneros', 38.2295800, -3.6313900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43158, 'Carboneras de Guadazaón', 'Carboneras de Guadazaon', 'Carbon,Carboneras,Carboneras de Guadazaon,Carboneras de Guadazaón', 39.8833300, -1.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43159, 'Carboneras', 'Carboneras', 'Karboneras,ka er wo nei la si,karbwnras,karbwnyras,Карбонерас,كاربونيراس,کاربونراس,卡尔沃内拉斯', 36.9966600, -1.8965100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43160, 'Carbajo', 'Carbajo', 'Carbajo', 39.6033300, -7.1956500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43161, 'Caravaca', 'Caravaca', '', 38.1055800, -1.8634300, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43162, 'Carataunas', 'Carataunas', 'Caratauna,Caratáuna', 36.9220400, -3.4083400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43163, 'Capilla', 'Capilla', 'Capilla,Kapil''ja,Kapila,ka pi li ya,kabayla,kapyya,Капила,Капилья,Капілья,كابايلا,کاپییا,卡皮利亚', 38.8203700, -5.0841700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43164, 'Capileira', 'Capileira', '', 36.9614800, -3.3586400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43165, 'Capdepera', 'Capdepera', 'Capdepera,Kapdepera,ka pu de pei la,kabdybyra,Капдепера,كابديبيرا,卡普德佩拉', 39.7023700, 3.4353200, 'ES', '2013-11-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43166, 'Cantoria', 'Cantoria', 'Cantoria', 37.3514600, -2.1920900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43167, 'Cantillana', 'Cantillana', 'Cantillana', 37.6103200, -5.8247200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43168, 'Can Picafort', 'Can Picafort', 'C''an Picafort,Can Picafort', 39.7656700, 3.1548800, 'ES', '2016-09-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43169, 'Canjáyar', 'Canjayar', 'Canjayar,Canjáyar,Lanjavar', 37.0095900, -2.7394300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43170, 'Canillas de Albaida', 'Canillas de Albaida', 'Canillas de Albaida', 36.8466500, -3.9867800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43171, 'Canillas de Aceituno', 'Canillas de Aceituno', 'Canillas,Canillas de Aceituna,Kanil''jas-de-Asejtuno,ka ni li ya si de ya sai tu nuo,kanyas dy athytwnw,Канильяс-де-Асейтуно,Канільяс-де-Асейтуно,كانياس دي أثيتونو,卡尼利亚斯德亚塞图诺', 36.8730300, -4.0825400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43172, 'Caniles', 'Caniles', 'Caniles', 37.4367100, -2.7248200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43173, 'Cañete la Real', 'Canete la Real', 'Aebura,Kan''ete-la-Real'',Kaniete la Real,Sabora,ka nie te la lei ya er,kanyth la ryal,kanyty la ryal,Каньете-ла-Реаль,Каньєте-ла-Реаль,Կանիետե լա Ռեալ,كانيتي لا ريال,کانیته لا ریال,卡涅特拉雷亚尔', 36.9515400, -5.0244000, 'ES', '2012-08-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43174, 'Cañete de las Torres', 'Canete de las Torres', 'Canete de las Torres,Cañete de las Torres', 37.8671700, -4.3183500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43175, 'Canet d''En Berenguer', 'Canet d''En Berenguer', 'Canet d''En Berenguer,Canet de Berenguer', 39.6833300, -0.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43176, 'Canena', 'Canena', 'Canena', 38.0493000, -3.4831000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43177, 'Candelaria', 'Candelaria', 'Cancelaria,Candelaria,Kandelaria,Kandelarii,Kandelarija,kan de la li ya,kanderaria,kandylarya  santa krwth dy tynyryfh,Κανδελάρια,Канделарии,Канделария,Канделарія,קאנדלאריה,كانديلاريا، سانتا كروث دي تينيريفه,カンデラリア,坎德拉里亚', 28.3548000, -16.3726800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43178, 'Cañaveral de León', 'Canaveral de Leon', 'Canaveral de Leon,Cañaveral de León', 38.0166700, -6.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43179, 'Cañaveral', 'Canaveral', 'Canaveral,Cañaveral', 39.7919800, -6.3913000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43180, 'Cáñar', 'Canar', '', 36.9268400, -3.4280800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43181, 'Cañamero', 'Canamero', 'Canamera,Canamero,Cañamera,Cañamero,Kan''jamero,ka ni ya mei luo,kanyamyrw,Каньямеро,كانياميرو,卡尼亚梅罗', 39.3799500, -5.3885700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43182, 'Canals', 'Canals', 'Canals,Canals de Canolas,Canals de Cañolas', 38.9625100, -0.5844300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43183, 'Cañada Rosal', 'Canada Rosal', 'Canada Rosal,Cañada Rosal', 37.5992400, -5.2101600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43184, 'Cañada del Hoyo', 'Canada del Hoyo', 'Canada del Hoyo,Cañada del Hoyo', 39.9666700, -1.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43185, 'Cañada de Calatrava', 'Canada de Calatrava', 'Canada,Canada de Calatrava,Cañada,Cañada de Calatrava', 38.8542900, -4.0210300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43186, 'Cañada', 'Canada', 'Canada,Cañada,La Canyada', 38.6739000, -0.8133000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43187, 'Camuñas', 'Camunas', '', 39.4270400, -3.4550300, 'ES', '2006-08-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43188, 'Campotéjar', 'Campotejar', 'Campotejar,Campotéjar', 37.4823500, -3.6177100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43189, 'Campos del Río', 'Campos del Rio', 'Campos del Rio,Campos del Río', 38.0396600, -1.3530600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43190, 'Campos', 'Campos', 'Campos', 39.4309900, 3.0193500, 'ES', '2016-09-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43191, 'Camporrobles', 'Camporrobles', 'Camporrobles,Camporrobres,Kamporrobles,kan bo luo fu lai si,Кампорроблес,坎波罗夫莱斯', 39.6500000, -1.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43192, 'Campofrío', 'Campofrio', 'Campofrio,Campofrío', 37.7665200, -6.5736300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43193, 'Campo de Criptana', 'Campo de Criptana', 'Kampo-de-Kriptana,kambw dy kraybtana,kan bo de ke li pu ta na,Кампо-де-Криптана,Кампо-де-Кріптана,كامبو دي كرايبتانا,坎波德克里普塔纳', 39.4046300, -3.1249200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43194, 'Campiña', 'Campina', 'Campina,Campiña,Caserio Campina,Caserío Campiña', 38.2189600, -2.9806900, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43195, 'Campillos-Paravientos', 'Campillos-Paravientos', 'Campillos-Paravientos', 39.9833300, -1.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43196, 'Campillos', 'Campillos', '', 37.0482600, -4.8630800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43197, 'Campillo de Llerena', 'Campillo de Llerena', 'Campillo de Llerena', 38.5019600, -5.8313900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43198, 'Campillo de Deleitosa', 'Campillo de Deleitosa', 'Campillo de Deleitosa', 39.7029700, -5.5743600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43199, 'Campillo de Arenas', 'Campillo de Arenas', 'Campillo de Arenas', 37.5553500, -3.6355200, 'ES', '2016-06-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43200, 'Campillo de Altobuey', 'Campillo de Altobuey', 'Campillo de Altobuey', 39.6000000, -1.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43201, 'El Campello', 'El Campello', 'Campello,El Campello', 38.4288500, -0.3977400, 'ES', '2016-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43202, 'Campanet', 'Campanet', 'Campanet', 39.7747000, 2.9650600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43203, 'Campanario', 'Campanario', 'Campanario,Kampanario,kampanaryw,kan pa na li ao,Кампанарио,Кампанаріо,کامپاناریو,坎帕纳里奥', 38.8644000, -5.6174400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43204, 'Cambil', 'Cambil', 'Cambil,Cambril', 37.6793400, -3.5653700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43205, 'Camas', 'Camas', 'Camas,Kamas,ka ma si,Камас,Կամաս,卡马斯', 37.4020200, -6.0331400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43206, 'Calvià', 'Calvia', 'Calvia,Calvià,Calviá,Kal''vija,Kalvia,Kalvija,ka er wei ya,kalbi xa,kalbya,kalfya,karubia,Калвиа,Калвија,Кальвия,Кальвія,كالفيا,کالبیا,กัลบีอา,カルビア,卡尔维亚', 39.5657000, 2.5062100, 'ES', '2015-09-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43207, 'Calp', 'Calp', 'Calp,Calpe,Kal''p,Kalp,ka er pei,kalby,kalp,Калп,Кальп,كالبي,کالپ,卡尔佩', 38.6447000, 0.0445000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43208, 'Calonge', 'Calonge', 'Calonge', 39.4003900, 3.2033500, 'ES', '2016-09-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43209, 'Callosa de Segura', 'Callosa de Segura', 'Callosa de Segura,Kal''josa-de-Segura,Kal''osa-de-Segura,Kalyosa de Segura,ka e sa de sai gu la,kalwsa dy swjwra,kaywsa d sgwra,Кальйоса-де-Сегура,Кальоса-де-Сегура,Կալյոսա դե Սեգուրա,كالوسا دي سوجورا,کایوسا د سگورا,卡略萨德塞古拉', 38.1249700, -0.8782200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43210, 'Callosa d''En Sarrià', 'Callosa d''En Sarria', 'Callosa d''En Sarria,Callosa d''En Sarrià,Callosa de Ensarria,Callosa de Ensarriá', 38.6500000, -0.1166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43211, 'Calles', 'Calles', 'Calles', 39.7211800, -0.9705700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43212, 'Calicasas', 'Calicasas', 'Calicasas', 37.2713000, -3.6134500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43213, 'Caleruela', 'Caleruela', 'Caleruela', 39.8748300, -5.2569300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43214, 'Calera y Chozas', 'Calera y Chozas', 'Calera,Calera y Chozas', 39.8827800, -4.9821300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43215, 'Calera de León', 'Calera de Leon', 'Calera de Leon,Calera de León', 38.1000000, -6.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43216, 'Calasparra', 'Calasparra', 'Calasparra,Kalasparra,ka la si pa la,kalasbara,Каласпарра,كالاسبارا,卡拉斯帕拉', 38.2299700, -1.6998600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43217, 'Cala Rajada', 'Cala Rajada', 'Cala Rajada,Cala Ratjada', 39.7117400, 3.4631000, 'ES', '2016-09-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43218, 'Calañas', 'Calanas', 'Calanas,Calañas', 37.6556800, -6.8805000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43219, 'Calamonte', 'Calamonte', 'Calamonte', 38.8886100, -6.3879100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43220, 'Cala', 'Cala', 'Cala,Minas de Cala', 37.9666700, -6.3166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43221, 'Cájar', 'Cajar', 'Cajar,Cájar', 37.1338100, -3.5727400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43222, 'Cadiz', 'Cadiz', 'CDZ,Cadice,Cadis,Cadix,Cadiz,Cai,Càdice,Cádice,Cádis,Cádiz,Gadeira,Gades,Gadir,Gaðes,Iungadir,Kadis,Kadisas,Kadiz,Kadizo,Kadyks,Kantith,La tacita de plata,jia de si,kadi s,kadiseu,kadisu,kads,kadydh,kadys,qads,qdys,Κάντιθ,Кадиз,Кадис,Кадіс,קדיס,قادس,كاديذ,کادس,کادیس,กาดิซ,კადისი,ካዲዝ,カディス,加的斯,카디스', 36.5267200, -6.2891000, 'ES', '2017-05-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43223, 'Cádiar', 'Cadiar', '', 36.9459100, -3.1802000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43224, 'Cachorrilla', 'Cachorrilla', 'Cachorrilla', 39.9155700, -6.6690900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43225, 'Cáceres', 'Caceres', 'Caceres,Caceres i Spania,Cacris,Caçris,Càceres,Cáceres,Cáceres i Spania,Gorad Kaserehs,Kaseres,Kaseresa,Kaseresas,Katheres,Norba Caesarina,QUQ,ka sai lei si,ka se res,ka sha li si,kakeresa,kakyrys  spyn,kaseleseu,kaseresu,kasrs,katheresa,qsrs,qsrsh,Κάθερες,Горад Касерэс,Касерес,קסרס,قصرش,کاسرس,کاسیریس، ہسپانیہ,کاکیریس، سپین,काकेरेस,ਕਾਥੇਰੇਸ,กาเซเรส,კასერესი,カセレス,卡塞雷斯,卡沙利斯,카세레스', 39.4764900, -6.3722400, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43226, 'Cabra del Santo Cristo', 'Cabra del Santo Cristo', 'Cabra de Santo Cristo,Cabra del San Cristo,Cabra del Santo Cristo', 37.7037900, -3.2876500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43227, 'Cabra', 'Cabra', 'Cabra,Kabra,Кабра', 37.4724900, -4.4420600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43228, 'Cabezas Rubias', 'Cabezas Rubias', '', 37.7266000, -7.0873800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43229, 'Cabezarados', 'Cabezarados', 'Cabezarados', 38.8446900, -4.2983000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43230, 'Cabezamesada', 'Cabezamesada', 'Cabezamesada', 39.8163000, -3.1023600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43231, 'Cabeza la Vaca', 'Cabeza la Vaca', 'Cabeza la Vaca', 38.0833300, -6.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43232, 'Cabeza del Buey', 'Cabeza del Buey', 'Cabeza de Buey,Cabeza del Buey,Cabezabuei,Kabesa-del''-Buehj,Kabesa-del''-Buej,Kabeza del Bej,ka wei sa de er wu ai,kabyza dyl by,Кабеза дел Беј,Кабеса-дель-Буей,Кабеса-дель-Буэй,كابيزا ديل بي,卡韦萨德尔武埃', 38.7222700, -5.2194600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43233, 'Cabañas de Yepes', 'Cabanas de Yepes', '', 39.8905100, -3.5350200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43234, 'Cabañas del Castillo', 'Cabanas del Castillo', 'Cabanas,Cabanas del Castillo,Cabañas,Cabañas del Castillo', 39.5480400, -5.5120300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43235, 'Busquístar', 'Busquistar', '', 36.9379600, -3.2944400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43236, 'Busot', 'Busot', 'Busot,Buzot,bu suo te,bwswt,Бузот,Бусот,Բուսոտ,بوسوت,布索特', 38.4820600, -0.4191800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43237, 'Burujón', 'Burujon', 'Burujon,Burujón', 39.9011300, -4.2973000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43238, 'Burriana', 'Burriana', 'Borriana,Burriana,bu li ya na,bwrayna,Борріана,Бурриана,بوراينا,布里亚纳', 39.8890100, -0.0849900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43239, 'Burjassot', 'Burjassot', 'Bujursot,Burjassot,Burkhasot,Бурхасот', 39.5098400, -0.4132700, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43240, 'Burguillos de Toledo', 'Burguillos de Toledo', 'Burguillos,Burguillos de Toledo', 39.7963500, -3.9925400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43241, 'Burguillos del Cerro', 'Burguillos del Cerro', 'Burguillos,Burguillos del Cerro', 38.3800800, -6.5903700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43242, 'Burguillos', 'Burguillos', 'Burguillos', 37.5844000, -5.9665400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43243, 'Bunyola', 'Bunyola', 'Bunyola', 39.6963400, 2.6995500, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43244, 'Buñol', 'Bunol', 'Bun''jol'',Bun''ol'',Bunol,Bunyol,Buñol,bu ni ao er,bunyol,bunyoru,Буньйоль,Буньоль,ブニョール,布尼奥尔,부뇰', 39.4166700, -0.7833300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43245, 'Bullas', 'Bullas', 'Abula,Aebura,Bullas,Bulles', 38.0466700, -1.6722700, 'ES', '2012-08-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43246, 'Bujalance', 'Bujalance', 'Bujalance,Bukhalanse,bu ha lan sai,bwkhalanky  qrtbt,Бухалансе,بوخالانكي، قرطبة,布哈兰塞', 37.8955600, -4.3807400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43247, 'Búger', 'Buger', 'Buger,Buzher,Búger,bu he er,bwghyr,bwkhr,Бужер,بوخر,بوغير,布赫尔', 39.7580900, 2.9834900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43248, 'Bugarra', 'Bugarra', 'Bugarra', 39.6166700, -0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43249, 'Bufali', 'Bufali', 'Bufali,Bufalí,Bufatl,bu fa li,bwfaly,Буфали,Буфалі,بوفالی,布法利', 38.8677500, -0.5161700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43250, 'Buenavista del Norte', 'Buenavista del Norte', 'Buehnavista-del''-Norte,Buenavista,Buenavista del Norte,Buenavista-del''-Norte,bu ai na wei si ta de er nuo er te,bwynafysta dyl nwrty,Буенавіста-дель-Норте,Буэнависта-дель-Норте,بوينافيستا ديل نورتي,布埃纳维斯塔德尔诺尔特', 28.3745800, -16.8609800, 'ES', '2014-04-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43251, 'Buenache de Alarcón', 'Buenache de Alarcon', 'Buenache,Buenache de Alarcon,Buenache de Alarcón,Buenoche de Alarcon,Buenoche de Alarcón', 39.6500000, -2.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43252, 'Bubión', 'Bubion', '', 36.9490000, -3.3561500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43253, 'Brozas', 'Brozas', 'Brosas,Brozas,brwzas,bu luo sa si,Бросас,بروزاس,布罗萨斯', 39.6127800, -6.7777000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43254, 'Brenes', 'Brenes', 'Brenes,bu lei nei si,Бренес,布雷内斯', 37.5494400, -5.8713900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43255, 'Breña Baja', 'Brena Baja', 'Brena Baja,Breña Baja', 28.6301100, -17.7895300, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43256, 'Breña Alta', 'Brena Alta', 'Brena Alta,Breña Alta', 28.6500000, -17.7833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43257, 'Brazatortas', 'Brazatortas', 'Brazatortas', 38.6586900, -4.2936800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43258, 'Botija', 'Botija', 'Botija', 39.3449800, -6.0731800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43259, 'Bornos', 'Bornos', 'Bornos', 36.8167700, -5.7444800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43260, 'Bormujos', 'Bormujos', 'Bormujos', 37.3735800, -6.0723300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43261, 'Bonrepòs i Mirambell', 'Bonrepos i Mirambell', 'Bonrepos,Bonrepós', 39.5166700, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43262, 'Boniches', 'Boniches', 'Boniches', 39.9833300, -1.6166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43263, 'Bonete', 'Bonete', 'Bonete', 38.8713600, -1.3485100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43264, 'Bonares', 'Bonares', 'Bonares', 37.3242300, -6.6807300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43265, 'Bolulla', 'Bolulla', 'Bolulla', 38.6752900, -0.1118400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43266, 'Bollullos par del Condado', 'Bollullos par del Condado', 'Bollullos,Bollullos par del Condado', 37.3412700, -6.5397000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43267, 'Bollullos de la Mitación', 'Bollullos de la Mitacion', 'Bollullos de la Mitacion,Bollullos de la Mitación', 37.3401400, -6.1371900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43268, 'Bolbaite', 'Bolbaite', 'Bol''bajte,Bolbait,Bolbaite,blbayth,bo er wa yi te,Больбайте,بلبایته,博尔瓦伊特', 39.0604100, -0.6746600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43269, 'Bolaños de Calatrava', 'Bolanos de Calatrava', 'Bolan''jos-de-Kalatrava,Bolan''os-de-Kalatrava,Bolanos,Bolanos de Calatrava,Bolaños,Bolaños de Calatrava,bo la ni ao si de ka la te la wa,bwlanyws dy kalatrafa,Боланьйос-де-Калатрава,Боланьос-де-Калатрава,بولانيوس دي كالاترافا,博拉尼奥斯德卡拉特拉瓦', 38.9069000, -3.6634500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43270, 'Bohonal de Ibor', 'Bohonal de Ibor', 'Bohonal de Ibor', 39.7845700, -5.4850000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43271, 'Bogarra', 'Bogarra', 'Bogarra', 38.5813900, -2.2129000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43272, 'Bodonal de la Sierra', 'Bodonal de la Sierra', 'Bodonal de la Sierra', 38.1475100, -6.5595000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43273, 'Bocairent', 'Bocairent', 'Bocairent,Bocairente', 38.7666700, -0.6166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43274, 'Blanca', 'Blanca', 'Blanca', 38.1791000, -1.3747300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43275, 'Binissalem', 'Binissalem', 'Binissalem', 39.6874400, 2.8439600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43276, 'Bigastro', 'Bigastro', 'Bigastre,Bigastro', 38.0623700, -0.8984100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43277, 'Bienvenida', 'Bienvenida', 'B''envenida,Benvenida,Bienvenida,Bjenvenida,baynfynayda,bi en wei ni da,bynbnyda,Бьенвенида,Бєнвеніда,Бјенвенида,Բիենվենիդա,باينفينايدا,بینبنیدا,比恩韦尼达', 38.3000000, -6.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43278, 'Bienservida', 'Bienservida', 'Bienservida', 38.5171600, -2.6108700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43279, 'Bicorp', 'Bicorp', 'Bicorb,Bicorp', 39.1321500, -0.7872000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43280, 'Biar', 'Biar', 'B''jar,Biar,bi ya er,byar,Бьяр,Біар,بيار,بیار,比亚尔', 38.6311700, -0.7645800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43281, 'Bétera', 'Betera', 'Betera,Bétera', 39.5911100, -0.4615100, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43282, 'Berrocalejo', 'Berrocalejo', 'Berro del Calejo,Berrocalejo', 39.8194800, -5.3495100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43283, 'Berrocal', 'Berrocal', 'Berrocal', 37.6086300, -6.5414700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43284, 'Berlanga', 'Berlanga', 'Berlanga', 38.2833300, -5.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43285, 'Berja', 'Berja', 'Berdza,Berha,Berkha,Vergis,bei er ha,brjt,brkha,Берха,Берџа,برجة,برخا,贝尔哈', 36.8469300, -2.9496600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43286, 'Bérchules', 'Berchules', '', 36.9767800, -3.1906700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43287, 'Bentarique', 'Bentarique', 'Bentarique', 36.9882300, -2.6199100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43288, 'Benquerencia', 'Benquerencia', 'Benquerencia,Bona Querencia', 39.3099400, -6.0846500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43289, 'Benizalón', 'Benizalon', 'Benizalon,Benizalón', 37.2121300, -2.2418000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43290, 'Benitagla', 'Benitagla', 'Benitagla', 37.2313800, -2.2393500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43291, 'Benitachell', 'Benitachell', 'Benitachell,El Poble Nou de Benitatxell', 38.7327300, 0.1435400, 'ES', '2016-02-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43292, 'Benisuera', 'Benisuera', 'Benissuera,Benisuera', 38.9132000, -0.4778400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43293, 'Benissoda', 'Benissoda', 'Benisoda,Benissoda', 38.8333300, -0.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43294, 'Benisanó', 'Benisano', 'Benisano,Benisanó,Benissano,Benissanó', 39.6166700, -0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43295, 'Benissa', 'Benissa', 'Benissa', 38.7149200, 0.0484900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43296, 'Benirredrà', 'Benirredra', 'Benirredra,Benirredrà,Benirredrá', 38.9666700, -0.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43297, 'Beniparrell', 'Beniparrell', 'Beniparrell', 39.3833300, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43298, 'Benimuslem', 'Benimuslem', 'Benimuslem', 39.1316200, -0.4928800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43299, 'Benimodo', 'Benimodo', 'Benimodo', 39.2140300, -0.5267900, 'ES', '2015-06-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43300, 'Benimeli', 'Benimeli', 'Benimeli,bei ni mei li,bnymly,bynaymylay,Бенимели,Бенімелі,بنیملی,بينايميلاي,贝尼梅利', 38.8236200, -0.0422100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43301, 'Benimassot', 'Benimassot', 'Benimasot,Benimassot', 38.7500000, -0.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43302, 'Benimarfull', 'Benimarfull', 'Benimarfull', 38.7759000, -0.3907900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43303, 'Benimantell', 'Benimantell', 'Benimantell', 38.6770900, -0.2105700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43304, 'Benillup', 'Benillup', 'Benillup', 38.7539700, -0.3799100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43305, 'Benilloba', 'Benilloba', 'Benil''joba,Benil''oba,Benilloba,bei ni e wa,bnyywba,bynaylwba,Бенильоба,Бенільйоба,بنییوبا,بينايلوبا,贝尼略瓦', 38.7001200, -0.3899800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43306, 'Benijófar', 'Benijofar', 'Benijofar,Benijófar', 38.0778500, -0.7368000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43307, 'Benigànim', 'Beniganim', 'Beniganim,Benigànim,Benigánim', 38.9500000, -0.4333300, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43308, 'Beniflá', 'Benifla', 'Benifla,Beniflà,Beniflá', 38.9281300, -0.1781600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43309, 'Benifaió', 'Benifaio', 'Banifaio,Banifaió,Benifayo,Benifayó', 39.2843900, -0.4259800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43310, 'Benifallim', 'Benifallim', 'Benifallim', 38.6625900, -0.3999400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43311, 'Benifairó de les Valls', 'Benifairo de les Valls', 'Benifairo de Les Valls,Benifairo de les Valls,Benifairó de Les Valls,Benifairó de les Valls', 39.7333300, -0.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43312, 'Beniel', 'Beniel', '', 38.0463600, -1.0023300, 'ES', '2016-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43313, 'Benidorm', 'Benidorm', 'Benidorm,Benidormo,bei ni duo er mu,benidoleum,benidorumu,bnydwrm,Бенидорм,Бенідорм,Բենիդորմ,بنيدورم,بنیدورم,ベニドルム,贝尼多尔姆,베니도름', 38.5381600, -0.1309800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43314, 'Benidoleig', 'Benidoleig', 'Benidoleig', 38.7927800, -0.0299200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43315, 'Benicolet', 'Benicolet', 'Benicolet', 38.9198700, -0.3469400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43316, 'Beniatjar', 'Beniatjar', 'Beniatjar', 38.8475400, -0.4173600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43317, 'Beniarrés', 'Beniarres', 'Ben''jarres,Beniarres,Beniarrés,bei ni ya lei si,bnyars,bynyarys,Бениаррес,Беньяррес,Беніаррес,بنیارس,بينياريس,贝尼亚雷斯', 38.8201900, -0.3774100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43318, 'Beniarjó', 'Beniarjo', 'Beniarjo,Beniarjó', 38.9324900, -0.1863400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43319, 'Beniardá', 'Beniarda', 'Beniarda,Beniardà,Beniardá', 38.6843300, -0.2162900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43320, 'Beniarbeig', 'Beniarbeig', 'Beniarbeig', 38.8223200, -0.0021000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43321, 'Benferri', 'Benferri', 'Benferri,ben fei li,bnfry,bynfyrray,Бенферри,Бенферрі,بنفری,بينفيرراي,本费里', 38.1412900, -0.9621200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43322, 'Benetússer', 'Benetusser', '', 39.4226500, -0.3968600, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43323, 'Benejúzar', 'Benejuzar', 'Benejusser,Benejuzar,Benejússer,Benejúzar', 38.0772800, -0.8394200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43324, 'Beneixama', 'Beneixama', 'Beneixama,Benejama', 38.7000000, -0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43325, 'Beneixida', 'Beneixida', 'Benegida,Beneixida', 39.0666700, -0.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43326, 'Benavites', 'Benavites', 'Benavites', 39.7333300, -0.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43327, 'Benatae', 'Benatae', 'Benatae', 38.3532300, -2.6512100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43328, 'Benasau', 'Benasau', 'Benasau', 38.6904700, -0.3427800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43329, 'Benarrabá', 'Benarraba', 'Benarraba,Benarrabá', 36.5512000, -5.2760800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43330, 'Benaoján', 'Benaojan', 'Benaojan,Benaoján', 36.7192900, -5.2522000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43331, 'Benaocaz', 'Benaocaz', 'Benaocaz', 36.7006900, -5.4222200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43332, 'Benamocarra', 'Benamocarra', 'Benamocarra', 36.7907500, -4.1614600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43333, 'Benamejí', 'Benameji', 'Benameji,Benamejí', 37.2683300, -4.5412300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43334, 'Benamaurel', 'Benamaurel', 'Benamaurel', 37.6082600, -2.7025000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43335, 'Benamargosa', 'Benamargosa', 'Benam,Benamargosa', 36.8349900, -4.1936200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43336, 'Benalúa de las Villas', 'Benalua de las Villas', 'Benalua de las Villas,Benalúa de las Villas', 37.4274200, -3.6834600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43337, 'Benalúa de Guadix', 'Benalua de Guadix', 'Benalua de Guadix,Benalúa de Guadix', 37.3519100, -3.1640400, 'ES', '2012-02-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43338, 'Benalmádena', 'Benalmadena', 'Benal''madena,Benalmadena,Benalmádena,bei na er ma de na,benalmadena,bnalmadna,bynalmadyna,Беналмадена,Бенальмадена,Բենալմադենա,بنالمادنا,بينالمادينا,贝纳尔马德纳,베날마데나', 36.5961000, -4.5726700, 'ES', '2017-05-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43339, 'Benalauría', 'Benalauria', 'Benalauria,Benalauría', 36.5944500, -5.2609900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43340, 'Benahavís', 'Benahavis', 'Benahavis,Benahavís', 36.5236100, -5.0463100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43341, 'Benahadux', 'Benahadux', 'Benahadur,Benahadux', 36.9249300, -2.4594100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43342, 'Benaguasil', 'Benaguasil', 'Benaguacil,Benaguasil', 39.6000000, -0.5833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43343, 'Benagéber', 'Benageber', 'Benagebe,Benageber,Benagever,Benagébe,Benagéber,Benagéver,Benaixep,Benaixeve,Benakheber,bei na he wei er,bnakhbr,Бенахебер,بناخبر,贝纳赫韦尔', 39.7166700, -1.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43344, 'Benacazón', 'Benacazon', 'Benacazon,Benacazón', 37.3528900, -6.1966300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43345, 'Belvis de la Jara', 'Belvis de la Jara', 'Belvis de la Jara', 39.7576800, -4.9493200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43346, 'Belmontejo', 'Belmontejo', 'Belmontejo', 39.8221200, -2.3446700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43347, 'Belmonte', 'Belmonte', '', 39.5574600, -2.7046100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43348, 'Bélmez de la Moraleda', 'Belmez de la Moraleda', '', 37.7238200, -3.3820700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43349, 'Bélmez', 'Belmez', 'Belmez,Bélmez', 38.2666700, -5.2000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43350, 'Bellús', 'Bellus', 'Bellus,Bellús', 38.9458000, -0.4869700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43351, 'Bellreguard', 'Bellreguard', 'Bellreguard,Bellreguart', 38.9500000, -0.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43352, 'Bèlgida', 'Belgida', 'Belgida,Bèlgida,Bélgida', 38.8500000, -0.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43353, 'Belalcázar', 'Belalcazar', 'Balalcazar,Belal''kasar,Belalcazar,Belalcázar,bei la er ka sa er,blal qsr,blalkzar,Белалькасар,بلال قصر,بلالكزار,贝拉尔卡萨尔', 38.5756600, -5.1665300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43354, 'Beires', 'Beires', 'Beires', 37.0123700, -2.7913400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43355, 'Begíjar', 'Begijar', 'Begijar,Begíjar', 37.9849200, -3.5309400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43356, 'Bédar', 'Bedar', 'Bedar,Bédar', 37.1938900, -1.9816600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43357, 'Betxí', 'Betxi', 'Bechi,Betxi', 39.9333300, -0.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43358, 'Beas de Segura', 'Beas de Segura', 'Beas de Segura,Beas-de-Segura,bei ya si de sai gu la,byas d sgwra,byas dy syghwra,Беас-де-Сегура,بئاس د سگورا,بياس دي سيغورا,贝亚斯德塞古拉', 38.2524000, -2.8887500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43359, 'Beas de Guadix', 'Beas de Guadix', 'Beas de Guadix', 37.2786100, -3.2057900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43360, 'Beas de Granada', 'Beas de Granada', '', 37.2180300, -3.4809500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43361, 'Beas', 'Beas', 'Beas,bei ya si,byas,Беас,Բեաս,بياس,贝亚斯', 37.4257000, -6.7931800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43362, 'Baza', 'Baza', 'Baza,База', 37.4907300, -2.7725900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43363, 'Bayarque', 'Bayarque', 'Bayarque', 37.3306200, -2.4361000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43364, 'Bayárcal', 'Bayarcal', 'Bayarcal,Bayárcal', 37.0307300, -2.9960600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43365, 'Baterno', 'Baterno', 'Baterno', 38.9557800, -4.9103900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43366, 'Barrax', 'Barrax', 'Barrax', 39.0460700, -2.2015200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43367, 'Barlovento', 'Barlovento', '', 28.8270800, -17.8037700, 'ES', '2012-02-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43368, 'Barx', 'Barx', 'Barig,Barx,Bárig', 39.0166700, -0.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43369, 'Bargas', 'Bargas', '', 39.9411300, -4.0197900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43370, 'Barcience', 'Barcience', 'Barcience', 39.9836700, -4.2343700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43371, 'Barchín del Hoyo', 'Barchin del Hoyo', 'Barchin del Hoyo,Barchín del Hoyo', 39.6666700, -2.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43372, 'Barxeta', 'Barxeta', 'Barcheta,Barxeta', 39.0166700, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43373, 'Barcarrota', 'Barcarrota', 'Barcarrota', 38.5147300, -6.8492300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43374, 'Barbate de Franco', 'Barbate de Franco', 'Barbate,Barbate de Franco', 36.1923700, -5.9218600, 'ES', '2014-12-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43375, 'Baños de la Encina', 'Banos de la Encina', 'Ban''jos-de-la-Ensina,Ban''os-de-la-Ehnsina,Banios de la Ensita,Banos de Encina,Banos de la Encina,Baños de Encina,Baños de la Encina,ba ni ao si de lai en xi na,banys d la ansyna,banyws dy la anthyna,Баньйос-де-ла-Енсіна,Баньос-де-ла-Энсина,Բանիոս դե լա Էնսիտա,بانيوس دي لا إنثينا,بانیس د لا انسینا,巴尼奥斯德莱恩西纳', 38.1737900, -3.7747700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43376, 'Banyalbufar', 'Banyalbufar', 'Banyalbufar', 39.6873400, 2.5140900, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43377, 'Balsa de Ves', 'Balsa de Ves', 'Balsa de Ves', 39.2666700, -1.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43378, 'Balones', 'Balones', 'Balones', 38.7372600, -0.3432400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43379, 'Balazote', 'Balazote', 'Balazote', 38.8844400, -2.1518000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43380, 'Bailén', 'Bailen', 'Bailen,Bailèn,Bailén,Bajlen,bai lun,baillen,bayln,baylyn,Байлен,بايلين,بایلن,拜伦,바일렌', 38.0963900, -3.7778600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43381, 'Baeza', 'Baeza', 'Baeza', 37.9938400, -3.4710300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43382, 'Baena', 'Baena', 'Baehna,Baena,bai na,byant,Баена,Баэна,بيانة,拜纳', 37.6167000, -4.3224500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43383, 'Badolatosa', 'Badolatosa', 'Badolatosa', 37.3078500, -4.6729600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43384, 'Badajoz', 'Badajoz', 'Ara Pacis Augustalis,BJZ,Badahozo,Badajoz,Badakhos,Badaĥozo,badahosu,badakhwz,Бадахос,باداخوز,バダホス', 38.8778900, -6.9706100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43385, 'Azután', 'Azutan', 'Azutan,Azután', 39.7856400, -5.1273000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43386, 'Azuébar', 'Azuebar', 'Assuevar,Assuévar,Azuebar,Azuébar', 39.8333300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43387, 'Azuaga', 'Azuaga', 'Asuaga,Azuaga,a su a jia,aswaga,azwagha,Азуага,Асуага,آسواگا,أزواغا,阿苏阿加', 38.2666700, -5.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43388, 'Aznalcóllar', 'Aznalcollar', 'Aznacollar,Aznacóllar,Aznalcollar,Aznalcóllar', 37.5191400, -6.2698800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43389, 'Aznalcázar', 'Aznalcazar', 'Aznalcazar,Aznalcázar', 37.3042200, -6.2496300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43390, 'Ayora', 'Ayora', 'Aiora,Ajora,Ayora,ai ao la,ayra,Айора,آیرا,艾奥拉', 39.0585200, -1.0563500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43391, 'Ayódar', 'Ayodar', 'Aioder,Ayodar,Ayódar', 40.0000000, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43392, 'Ayna', 'Ayna', 'Aina,Ajna,Ayna,Aýna,ai na,ayn,ayna,Айна,Аїна,آینا,أين,艾納,艾纳', 38.5500000, -2.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43393, 'Aielo de Malferit', 'Aielo de Malferit', 'Aielo de Malferit,Ayelo de Malferit', 38.8833300, -0.5833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43394, 'Ayamonte', 'Ayamonte', 'Ajamonte,Ajjamonte,Ayamonte,ai a meng te,ayamwnty,Айямонте,Аямонте,أيامونتي,艾阿蒙特', 37.2132900, -7.4080700, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43395, 'Atarfe', 'Atarfe', '', 37.2247900, -3.6868600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43396, 'Atamaría', 'Atamaria', 'Atamaria,Atamarija,Atamaría,Caserio Atamaria,Caserío Atamaría,Атамария', 37.5998900, -0.8068200, 'ES', '2015-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43397, 'Atalaya del Cañavate', 'Atalaya del Canavate', 'Atalaya del Canavate,Atalaya del Cañavate', 39.5186400, -2.2517500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43398, 'Atalaya', 'Atalaya', 'Atalaya', 38.3333300, -6.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43399, 'Atajate', 'Atajate', 'Atajate', 36.6401700, -5.2460600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43400, 'Aspe', 'Aspe', 'Asp,Aspe,a si pei,asby,asph,Аспе,آسپه,أسبي,阿斯佩', 38.3451100, -0.7672100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43401, 'Arucas', 'Arucas', 'Arucas,Arukas,Арукас', 28.1198300, -15.5232500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43402, 'Artenara', 'Artenara', 'Artenara', 28.0205500, -15.6469300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43403, 'Artana', 'Artana', 'Arlana', 39.8910400, -0.2575800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43404, 'Artà', 'Arta', 'Arta,Artà,Artá,a er ta,arta  jzr alblyar,Арта,ארטה,أرتا، جزر البليار,阿尔塔', 39.6931500, 3.3497900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43405, 'Arroyomolinos de León', 'Arroyomolinos de Leon', 'Arroyomolinos de Leon,Arroyomolinos de León', 38.0166700, -6.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43406, 'Arroyo de San Serván', 'Arroyo de San Servan', 'Arroyo de San Servan,Arroyo de San Serván', 38.8544300, -6.4540200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43407, 'Arroyo del Ojanco', 'Arroyo del Ojanco', 'Arroyo del Ojanco', 38.3206500, -2.8948600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43408, 'Arroyo de la Luz', 'Arroyo de la Luz', 'Arrojo-de-la-Lus,Arroyo de la Luz,Arroyo del Puerco,a luo yue de la lu si,arwyw dy la lwz,Арройо-де-ла-Лус,أرويو دي لا لوز,阿罗约德拉卢斯', 39.4851100, -6.5840100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43409, 'Arriate', 'Arriate', 'Arriate', 36.8000500, -5.1408000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43410, 'Arrecife', 'Arrecife', 'ACE,Aresife,Arrecife,Аресифе', 28.9630200, -13.5476900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43411, 'Arquillos', 'Arquillos', 'Arquillos', 38.1814800, -3.4282700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43412, 'Arona', 'Arona', 'Aron,Arona,Arona pa Tenerife,Arona på Tenerife,a luo na,arwna  asbanya,Арон,Арона,أرونا، إسبانيا,阿罗纳', 28.0996200, -16.6810200, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43413, 'Aroche', 'Aroche', 'Aroche', 37.9421300, -6.9576000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43414, 'Armuña de Almanzora', 'Armuna de Almanzora', '', 37.3503000, -2.4115000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43415, 'Armilla', 'Armilla', 'Armil''ja,Armilya,a er mi li ya,armya,Армилья,Армілья,Արմիլյա,أرميا,阿尔米利亚', 37.1438600, -3.6253400, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43416, 'Arjonilla', 'Arjonilla', 'Arjonilla', 37.9742200, -4.1067700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43417, 'Arjona', 'Arjona', 'Arjona,Arkhona,Arxona,a er huo na,arkhna,arkhwna,Архона,Արխոնա,آرخنا,أرخونا,阿尔霍纳', 37.9349300, -4.0547800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43418, 'Cruce de Arinaga', 'Cruce de Arinaga', 'Puerto de Arinaga', 27.8765600, -15.4279800, 'ES', '2007-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43419, 'Ariany', 'Ariany', 'Ariany', 39.6504800, 3.1105500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43420, 'Arguisuelas', 'Arguisuelas', 'Arguisuelas', 39.8333300, -1.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43421, 'Argamasilla de Calatrava', 'Argamasilla de Calatrava', '', 38.7298500, -4.0762700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43422, 'Argamasilla de Alba', 'Argamasilla de Alba', 'Argamasilla de Alba', 39.1291700, -3.0924700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43423, 'Arenas de San Juan', 'Arenas de San Juan', 'Arenas de San Juan', 39.2186100, -3.5021100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43424, 'Arenas del Rey', 'Arenas del Rey', 'Arenas del Rey', 36.9579900, -3.8936200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43425, 'Arenas', 'Arenas', 'Arenas', 36.8162500, -4.0441100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43426, 'Ardales', 'Ardales', '', 36.8780400, -4.8469400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43427, 'Arcos de las Salinas', 'Arcos de las Salinas', 'Arcos de las Salinas,Arkos-de-las-Salinas,a er ke si de la sa li na si,arks d las salynas,Аркос-де-лас-Салинас,Аркос-де-лас-Салінас,آرکس د لاس سالیناس,阿尔科斯德拉萨利纳斯', 39.9833300, -1.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43428, 'Arcos de la Frontera', 'Arcos de la Frontera', 'Arcos,Arcos de la Frontera,Arkos-de-la-Frontera,a er ke si-de la fu long te la,aleukoseudelapeulontela,arkws dyla frwntyra,Аркос-де-ла-Фронтера,أركوس ديلا فرونتيرا,アルコス・デ・ラ・フロンテーラ,阿尔科斯-德拉弗龙特拉,아르코스데라프론테라', 36.7507500, -5.8105600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43429, 'Archidona', 'Archidona', 'Archidona,a er qi duo na,arshdhwnt,Арчидона,أرشذونة,阿尔奇多纳', 37.0965400, -4.3886900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43430, 'Árchez', 'Archez', 'Archez,Árchez', 36.8399200, -3.9920800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43431, 'Archena', 'Archena', 'Archena', 38.1163100, -1.3004300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43432, 'Arboleas', 'Arboleas', '', 37.3502400, -2.0738400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43433, 'Arafo', 'Arafo', 'Arafo,Arato', 28.3397100, -16.4224400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43434, 'Aracena', 'Aracena', 'Aracena,Arasena,a la sai na,arathyna,Арасена,أراثينا,阿拉塞纳', 37.8939600, -6.5611600, 'ES', '2014-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43435, 'Antigua', 'Antigua', 'La Antigua', 28.4230700, -14.0137900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43436, 'Antequera', 'Antequera', 'Anteguera,Antekera,Antequera,an te ke la,antqyrt,Антекера,أنتقيرة,安特克拉', 37.0193800, -4.5612300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43437, 'Antella', 'Antella', 'Antella', 39.0797700, -0.5919500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43438, 'Antas', 'Antas', 'Antas', 37.2453600, -1.9176000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43439, 'Añover de Tajo', 'Anover de Tajo', 'Anover de Tajo,Añover de Tajo', 39.9887300, -3.7657900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43440, 'Añora', 'Anora', 'Anora,Añora', 38.4166700, -4.9000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43441, 'Anna', 'Anna', 'Anna', 39.0202900, -0.6462100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43442, 'Andújar', 'Andujar', 'Anducharas,Andujar,Andukhar,Andújar,an du ha er,ando~uharu,andwjr,andwkhar,Андухар,آندوخار,أندوجر,アンドゥハル,安杜哈尔', 38.0392200, -4.0507700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43443, 'Andratx', 'Andratx', 'Andratx', 39.5755300, 2.4201700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43444, 'Andilla', 'Andilla', 'Andilla', 39.8333300, -0.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43445, 'Anchuras', 'Anchuras', 'Anchuras', 39.4805900, -4.8338100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43446, 'Altura', 'Altura', 'Al''tura,Altura,altwra,Альтура,التورا', 39.8500000, -0.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43447, 'Altea', 'Altea', 'Altea', 38.5988500, -0.0513900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43448, 'Altarejos', 'Altarejos', 'Altarejos', 39.9125800, -2.3569200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43449, 'Alsodux', 'Alsodux', 'Alsodux', 37.0024700, -2.5947600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43450, 'Alquife', 'Alquife', 'Alquife', 37.1802400, -3.1155300, 'ES', '2015-12-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43451, 'L''Alqueria de la Comtessa', 'L''Alqueria de la Comtessa', 'Alqueria de la Condesa,Alquería de la Condesa,L''Alqueria de la Comtessa', 38.9333300, -0.1500000, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43452, 'Alpuente', 'Alpuente', 'Alpont,Alpuente', 39.8666700, -1.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43453, 'Alpera', 'Alpera', 'Alpera', 38.9666700, -1.2166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43454, 'Alpandeire', 'Alpandeire', 'Alpandeire', 36.6340200, -5.2021600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43455, 'Alozaina', 'Alozaina', 'Alozaina', 36.7273600, -4.8576100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43456, 'Alosno', 'Alosno', 'Alosno', 37.5486100, -7.1147000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43457, 'Alora', 'Alora', 'Iluro', 36.8235800, -4.7057500, 'ES', '2012-11-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43458, 'Almussafes', 'Almussafes', 'Almusafes,Almussafes', 39.2833300, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43459, 'Almuñécar', 'Almunecar', 'Al''mun''ekar,Almunecar,Almuñécar,Sexi Firmum Iulium,a er mu nie ka er,almnkb,almunyekaleu,arumunyekaru,Альмуньекар,Альмуньєкар,المنكب,アルムニェーカル,阿尔穆涅卡尔,알무녜카르', 36.7339300, -3.6907200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43460, 'Almudaina', 'Almudaina', 'Almudaina', 38.7599900, -0.3514900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43461, 'Almoradí', 'Almoradi', 'Al''moradi,Almoradi,Almoradí,Almordi,a er mo la di,almwrady,Альморади,Альмораді,آلمورادی,ألمورادي,阿尔莫拉迪', 38.1087900, -0.7919700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43462, 'Almonte', 'Almonte', 'Al''monte,Almonte,a er meng te,almwnt  aspanya,almwnty,Альмонте,Ալմոնտե,ألمونتي,المونت، اسپانیا,阿尔蒙特', 37.2647000, -6.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43463, 'Almonacid del Marquesado', 'Almonacid del Marquesado', '', 39.8234400, -2.7677000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43464, 'Almoines', 'Almoines', 'Almoines', 38.9432500, -0.1815500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43465, 'Almoharín', 'Almoharin', 'Almoharin,Almoharín', 39.1768500, -6.0428300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43466, 'Almogía', 'Almogia', 'Almogia,Almogía,Almojia', 36.8255000, -4.5407000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43467, 'Almodóvar del Río', 'Almodovar del Rio', 'Almodovar del Rio,Almodóvar del Río', 37.8107000, -5.0203700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43468, 'Almodóvar del Pinar', 'Almodovar del Pinar', 'Almodovar del Pinar,Almodóvar del Pinar', 39.7166700, -1.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43469, 'Almodóvar del Campo', 'Almodovar del Campo', 'Almodovar,Almodovar del Campo,Almodóvar del Campo', 38.7093600, -4.1790800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43470, 'Almócita', 'Almocita', 'Almocita,Almorcita,Almócita,Almórcita', 37.0026200, -2.7905100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43471, 'Almiserà', 'Almisera', 'Almisera,Almiserat,Almiserà', 38.9166700, -0.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43472, 'Almería', 'Almeria', 'Al''meri,Al''merija,Almeria,Almerija,Almerio,Almería,Gorad Al''meryja,LEI,Unci,a er mei li ya,almelia,almeriya,almrya,almryt,almyrya,arumeria,Αλμερία,Алмерия,Алмерија,Альмери,Альмерия,Альмерія,Горад Альмерыя,Ալմերիա,אלמריה,آلمریا,ألمرية,المریہ,المیریا,अल्मेरिया,आल्मेरिया,அல்மேரீயா,アルメリア,阿尔梅里亚,알메리아', 36.8381400, -2.4597400, 'ES', '2013-03-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43473, 'Almensilla', 'Almensilla', 'Almensilla', 37.3109900, -6.1099800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43474, 'Almendralejo', 'Almendralejo', 'Al''mendralekho,Almendralechas,Almendralejo,Almendraleju,Almendralekho,a er men de la lai huo,almndralykhw,Алмендралехо,Альмендралехо,ألمندراليخو,阿尔门德拉莱霍', 38.6831600, -6.4074700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43475, 'Almendral', 'Almendral', 'Al''mendral'',Almendral,a er men de la er,almndral,almyndral,Алмендрал,Альмендраль,آلمندرال,الميندرال,阿尔门德拉尔', 38.6141800, -6.8209700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43476, 'Almenara', 'Almenara', '', 39.7500000, -0.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43477, 'Almegíjar', 'Almegijar', 'Almegijar,Almegíjar', 36.9025800, -3.3012200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43478, 'Almedinilla', 'Almedinilla', '', 37.4390200, -4.0905200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43479, 'Almedina', 'Almedina', 'Almedina', 38.6245300, -2.9538200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43480, 'Almedíjar', 'Almedijar', 'Almedijar,Almedíjar', 39.8666700, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43481, 'Almassora', 'Almassora', 'Almassora,Almazora', 39.9472900, -0.0631300, 'ES', '2015-05-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43482, 'Almargen', 'Almargen', 'Almargen', 37.0021000, -5.0217800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43483, 'Almaraz', 'Almaraz', 'Almaraz', 39.8141600, -5.6769800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43484, 'Almansa', 'Almansa', 'Al''mansa,Almansa,a er man sa,almansa,almnsy,yan man sha,Альманса,آلمانسا,المنسى,阿尔曼萨,顏曼莎', 38.8691700, -1.0971300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43485, 'Almagro', 'Almagro', 'Almagro', 38.8894100, -3.7113100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43486, 'Almadén de la Plata', 'Almaden de la Plata', 'Almaden de la Plata,Almadén de la Plata', 37.8722100, -6.0808500, 'ES', '2012-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43487, 'Almadén', 'Almaden', 'Al''maden,Almaden,Almadenas,Almadén,a er ma deng,almadeni,almadn,Альмаден,المادن,ალმადენი,阿尔马登', 38.7754100, -4.8315600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43488, 'Almáchar', 'Almachar', 'Almachar,Almáchar', 36.8089200, -4.2161400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43489, 'Aljucén', 'Aljucen', 'Aljucen,Aljucén', 39.0442500, -6.3310900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43490, 'Aljaraque', 'Aljaraque', 'Aljaraque', 37.2698900, -7.0231300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43491, 'Aliseda', 'Aliseda', 'Aliseda', 39.4232900, -6.6922800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43492, 'Alicún de Ortega', 'Alicun de Ortega', 'Alicun de Ortega,Alicún de Ortega', 37.6089800, -3.1364800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43493, 'Alicún', 'Alicun', 'Alicun,Alicún', 36.9658000, -2.6021200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43494, 'Alicante', 'Alicante', 'A-li-kham-thit,ALC,Akra Leuke,Alacant,Alakanto,Alicant,Alicante,Alicanti,Alikante,Alikantė,Alíkante,Gorad Alikanteh,Lucentum,a li kan te,alikante,allikante,alykant,alykanth,alykanty,arikante,xa li kan te,Â-li-kham-thi̍t,Αλικάντε,Аликанте,Аліканте,Горад Алікантэ,Ալիկանտե,אליקנטה,آلیکانته,أليكانتي,الیکانت,الیکانتے,आलिकांते,आलिकान्ते,อาลีกันเต,ალიკანტე,アリカンテ,阿利坎特,알리칸테', 38.3451700, -0.4814900, 'ES', '2011-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43495, 'Aliaguilla', 'Aliaguilla', 'Aliaguilla', 39.7333300, -1.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43496, 'Alía', 'Alia', 'Alia,Alija,Alía,a li ya,alya,Алиа,Алія,أليا,阿利亚', 39.4480300, -5.2175400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43497, 'Alhendín', 'Alhendin', '', 37.1087900, -3.6455700, 'ES', '2012-12-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43498, 'Alhaurín el Grande', 'Alhaurin el Grande', 'Al''khaurin-ehl''-Grande,Alaurin-ehl''-Grande,Alaurin-el''-Grande,Alhaurin el Grande,Alhaurín el Grande,a er ao li nei er ge lan de,alawryn la ghrandy,Алаурин-эль-Гранде,Алаурін-ель-Гранде,Альхаурин-эль-Гранде,ألاورين لا غراندي,阿尔奥里内尔格兰德', 36.6430000, -4.6872800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43499, 'Alhaurín de la Torre', 'Alhaurin de la Torre', 'Al''khaurin-de-la-Torre,Alaurin de la Tore,Alaurin-de-la-Torre,a er ao lin de la tuo lei,alhaywryn dw la twr,brj alhwaryyn,Алаурин-де-ла-Торре,Алаурін-де-ла-Торре,Альхаурин-де-ла-Торре,Ալաուրին դե լա Տոռե,الهائورین دو لا تور,برج الهواريين,阿尔奥林德拉托雷', 36.6640100, -4.5613900, 'ES', '2014-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43500, 'Alhambra', 'Alhambra', 'Alhambra', 38.8992500, -3.0533300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43501, 'Alhama de Murcia', 'Alhama de Murcia', 'Al''khama-de-Mursija,Alama-de-Mursija,Alfama de Murcia,Alhama,Alhama de Murcia,Alhama de Múrcia,a er a ma de mu er xi ya,alama dy mrsyt,Алама-де-Мурсія,Альхама-де-Мурсия,ألاما دي مرسية,阿尔阿马德穆尔西亚', 37.8510300, -1.4250700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43502, 'Alhama de Granada', 'Alhama de Granada', 'Al''khama-de-Granada,Alama-de-Granada,Alhama,Alhama de Granada,a er a ma de ge la na da,alama dy ghranada,Алама-де-Гранада,Альхама-де-Гранада,ألاما دي غرانادا,阿尔阿马德格拉纳达', 37.0068900, -3.9896300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43503, 'Alhama de Almería', 'Alhama de Almeria', 'Al''khama-de-Al''meria,Alama-de-Al''merija,Alhama,Alhama de Almeria,Alhama de Almería,Alkhama de Almerija,a er a ma de ya er mei li ya,alama d almrya,hmt almryt,Алама-де-Альмерія,Алхама де Алмерија,Альхама-де-Альмериа,آلاما د آلمریا,حمة المرية,阿尔阿马德亚尔梅里亚', 36.9569200, -2.5686100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43504, 'Alhabia', 'Alhabia', 'Alhabia', 36.9900300, -2.5865500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43505, 'Algueña', 'Alguena', 'Al''gen''ja,Alguena,Algueña,L''Alguenya,LAlguenya,a er ge ni ya,alghynya,algwynya,Альгенья,آلگوئنیا,ألغينيا,阿尔格尼亚', 38.3390500, -1.0043300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43506, 'Alguazas', 'Alguazas', 'Alguazas', 38.0535600, -1.2505100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43507, 'Algorfa', 'Algorfa', 'Al''gorfa,Algorfa,a er ge er fa,alghrft,algwrfa,Альгорфа,آلگورفا,الغرفة,阿尔戈尔法', 38.0863600, -0.7964600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43508, 'Algodonales', 'Algodonales', '', 36.8804400, -5.4053600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43509, 'Alginet', 'Alginet', 'Alginet', 39.2666700, -0.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43510, 'Algimia de Almonacid', 'Algimia de Almonacid', 'Algimia d''Almonesir,Algimia de Almonacid', 39.9166700, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43511, 'Algimia de Alfara', 'Algimia de Alfara', 'Algimia de Alfara,Algimia de la Baronia', 39.7500000, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43512, 'Algemesí', 'Algemesi', 'Al''khemesi,Aldzhemezi,Algemesi,Algemesí,a er he mei xi,Алджемезі,Альхемеси,阿尔赫梅西', 39.1904200, -0.4357200, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43513, 'Algeciras', 'Algeciras', 'AEI,Al Jezita,Al''khesiras,Alchesirasas,Alchethiras,Alchezira,Algeciras,Algecires,Algesiras,Algesires,Algésiras,Alkhesiras,Alxeciras,a er he xi la si,alghykras,alhesilaseu,alkhythyras,aruheshirasu,Αλχεθίρας,Алхесирас,Альхесирас,Альхесірас,الجزيرة الخضراء,الخيثيراس,الغیکراس,アルヘシラス,阿尔赫西拉斯,알헤시라스', 36.1332600, -5.4505100, 'ES', '2016-02-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43514, 'Algatocín', 'Algatocin', '', 36.5735600, -5.2755400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43515, 'Algarrobo', 'Algarrobo', 'Algarrobe,Algarrobo', 36.7738800, -4.0395200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43516, 'Algarra', 'Algarra', 'Algarra', 40.0000000, -1.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43517, 'Algarinejo', 'Algarinejo', 'Algarmejo', 37.3252600, -4.1585000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43518, 'Algar', 'Algar', 'Algar', 36.6574800, -5.6555800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43519, 'Algámitas', 'Algamitas', 'Algamitas,Algámitas', 37.0151600, -5.1494900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43520, 'Algaida', 'Algaida', 'Algaida', 39.5589900, 2.8954100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43521, 'Alfondeguilla', 'Alfondeguilla', 'Alfondeguilla,Fondeguilla', 39.8333300, -0.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43522, 'Alfarrasí', 'Alfarrasi', 'Alfarrasi,Alfarrassi,Alfarrassí,Alfarrasí', 38.9000000, -0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43523, 'Alfarp', 'Alfarp', 'Al''farp,Alfarb,Alfarp,a er fa er pu,alfarp,Альфарп,آلفارپ,阿尔法尔普', 39.2833300, -0.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43524, 'Alfarnatejo', 'Alfarnatejo', '', 36.9957000, -4.2606400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43525, 'Alfarnate', 'Alfarnate', 'Alfarnate', 36.9942600, -4.2592900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43526, 'Alfara del Patriarca', 'Alfara del Patriarca', 'Alfara,Alfara del Patriarca', 39.5500000, -0.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43527, 'Alfara de Algimia', 'Alfara de Algimia', 'Alfara d''Algimia,Alfara de Algimia', 39.7666700, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43528, 'Alfauir', 'Alfauir', 'Alfahuir,Alfauir', 38.9333300, -0.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43529, 'Alfafara', 'Alfafara', 'Alfafara,Alfarara', 38.7733900, -0.5555100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43530, 'Alfafar', 'Alfafar', 'Al''fafar,Alfafar,a er fa fa er,Алфафар,Альфафар,阿尔法法尔', 39.4166700, -0.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43531, 'Alfacar', 'Alfacar', '', 37.2374400, -3.5680700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43532, 'Aledo', 'Aledo', 'Aledo', 37.7934100, -1.5735600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43533, 'Aldeire', 'Aldeire', 'Aldeire', 37.1601200, -3.0720400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43534, 'Aldeaquemada', 'Aldeaquemada', 'Aldeaquemada', 38.4121500, -3.3713700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43535, 'Aldeanueva de San Bartolomé', 'Aldeanueva de San Bartolome', 'Aldeanueva de San Bartolome,Aldeanueva de San Bartolomé', 39.6360800, -5.1130700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43536, 'Aldeanueva de Barbarroya', 'Aldeanueva de Barbarroya', 'Aldeanueva de Barbarroya', 39.7593400, -5.0228700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43537, 'Aldea del Rey', 'Aldea del Rey', 'Aldea del Rey', 38.7383000, -3.8401700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43538, 'Aldea del Cano', 'Aldea del Cano', 'Aldea del Cano', 39.2887400, -6.3180600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43539, 'Aldeacentenera', 'Aldeacentenera', 'Aldeacentenera', 39.5272500, -5.6293600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43540, 'Aldaia', 'Aldaia', 'Al''dajja,Aldaia,Aldaya,Альдайя', 39.4656900, -0.4600500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43541, 'Alcuéscar', 'Alcuescar', 'Alcuescar,Alcuéscar', 39.1809100, -6.2291700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43542, 'Alcudia de Veo', 'Alcudia de Veo', 'Alcudia de Veo', 39.9166700, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43543, 'Alcudia de Monteagud', 'Alcudia de Monteagud', 'Alcudia de Monteagud', 37.2352900, -2.2665000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43544, 'L''Alcúdia de Crespìns', 'L''Alcudia de Crespins', 'Alcudia de Crespins,L''Alcudia de Crespins,L''Alcúdia de Crespìns', 38.9666700, -0.5833300, 'ES', '2006-04-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43545, 'L''Alcúdia', 'L''Alcudia', 'Alcudia,Alcudia de Carlet,L''Alcudia,L''Alcúdia', 39.1971700, -0.5053700, 'ES', '2015-06-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43546, 'Alcúdia', 'Alcudia', 'Alcudia,Alcúdia', 39.8531600, 3.1213800, 'ES', '2016-06-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43547, 'Alcublas', 'Alcublas', 'Alcublas,Les Alcubles', 39.8000000, -0.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43548, 'Alcubillas', 'Alcubillas', 'Alcubillas', 38.7531200, -3.1340700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43549, 'Alcoy', 'Alcoy', 'Al''ka,Al''koj,Alco,Alcodium,Alcoi,Alcoy,Alkoj,Alkojus,a er ke yi,alkwy,arukoi,Алкој,Алька,Алькой,آلکوی,ألكوي,アルコイ,阿尔科伊', 38.7054500, -0.4743200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43550, 'Alcóntar', 'Alcontar', 'Alcontar,Alcóntar', 37.3364700, -2.5972500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43551, 'Alconera', 'Alconera', 'Alconera', 38.4000000, -6.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43552, 'Alconchel de la Estrella', 'Alconchel de la Estrella', 'Alconchel de la Estrella', 39.7196300, -2.5736600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43553, 'Alconchel', 'Alconchel', 'Alconchel', 38.5164800, -7.0716100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43554, 'Alcollarín', 'Alcollarin', 'Alcollarin,Alcollarín', 39.2447000, -5.7392400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43555, 'Alcolea de Tajo', 'Alcolea de Tajo', 'Alcolea de Tajo', 39.8096600, -5.1473800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43556, 'Alcolea del Río', 'Alcolea del Rio', 'Alcolea,Alcolea del Rio,Alcolea del Río', 37.6150600, -5.6669400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43557, 'Alcolea de Calatrava', 'Alcolea de Calatrava', 'Alcolea de Calatrava', 38.9868000, -4.1159700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43558, 'Alcolea', 'Alcolea', '', 36.9745800, -2.9615000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43559, 'Alcocer de Planes', 'Alcocer de Planes', 'Alcocer de Planes,Alcosser de Planes', 38.7950100, -0.4024400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43560, 'Alcoba', 'Alcoba', 'Alcoba', 39.2598800, -4.4771500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43561, 'Alzira', 'Alzira', 'Al''sira,Alchezira,Alcira,Alsira,Alzira,a er xi la,alzyra,alzyra  walnsya,jzyrt shqr,Алзіра,Альсира,Ալսիրա,الزیرا,الزیرا، والنسیا,جزيرة شقر,阿尔西拉', 39.1500000, -0.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43562, 'Alcázar de San Juan', 'Alcazar de San Juan', 'Al''kasar-de-San-Khuan,Alcaraz de San Juan,Alcazar,Alcáraz de San Juan,Alcázar,a er ka sa er de sheng hu an,alkzar dy san khwan,Алькасар-де-Сан-Хуан,الكزار دي سان خوان,阿尔卡萨尔德圣胡安', 39.3901100, -3.2082700, 'ES', '2014-01-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43563, 'Alcaudete', 'Alcaudete', 'Alcaudete', 37.5909100, -4.0823700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43564, 'Alcaucín', 'Alcaucin', '', 36.9030100, -4.1140600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43565, 'Alcaraz', 'Alcaraz', 'Al''karas,Alcaraz,alkaras,alkrz  albsyt,Алькарас,آلکاراس,الكرز، البسيط', 38.6668000, -2.4910500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43566, 'Alcaracejos', 'Alcaracejos', 'Al''karasekhos,Alcaracejos,Alcaraces,Alcarazejos,a er ka la sai huo si,alkarakykhws  qrtbt,Алькарасехос,الكاراكيخوس، قرطبة,阿尔卡拉塞霍斯', 38.3833300, -4.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43567, 'Alcantarilla', 'Alcantarilla', 'Al''kantaril''ja,Alcantarilla,Алькантарилья', 37.9693900, -1.2171400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43568, 'Alcàntera de Xúquer', 'Alcantera de Xuquer', 'Alcantara de Jucar,Alcantera de Xuquer,Alcàntera de Xúquer,Alcántara de Júcar', 39.0666700, -0.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43569, 'Alcántara', 'Alcantara', 'Al''kantara,Alcantara,Alcántara,Alcântara,Alkantara,Bruecke von Alcantara,Brücke von Alcántara,a er kan ta la,alkantala,alkntara,arukantara,Αλκάνταρα,Алькантара,الكنتارا,アルカンタラ,阿尔坎塔拉,알칸타라', 39.7189500, -6.8837500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43570, 'Alcañizo', 'Alcanizo', 'Alcanizo,Alcañizo', 39.9031500, -5.1058800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43571, 'Alcalalí', 'Alcalali', 'Al''kalali,Alcalali,Alcalalí,Alkalali,a er ka la li,alkalaly,benarossa gardens,Алкалалі,Алькалали,آلکالالی,ألكالالي,阿尔卡拉利', 38.7503800, -0.0401300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43572, 'Alcalá la Real', 'Alcala la Real', 'Aebura,Al''kala-la-Real'',Alcala la Real,Alcalá la Real,Ebora,a er ka la la lei ya er,alkala la ryal,Алькала-ла-Реаль,آلکالا لا رئال,ألكالا لا ريال,アルカラ・ラ・レアル,阿尔卡拉拉雷亚尔', 37.4614000, -3.9230100, 'ES', '2012-08-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43573, 'Alcalá del Valle', 'Alcala del Valle', 'Al''kala-del''-Val''e,Alcala del Valle,Alcalá del Valle,Alkala del Valye,alkala dl wal,alkala dyl faly,ba lie bao,Алькала-дель-Валье,Алькала-дель-Вальє,Ալկալա դել Վալյե,الكالا ديل فالي,الکالا دل وال,巴列堡', 36.9044800, -5.1724000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43574, 'Alcalá de los Gazules', 'Alcala de los Gazules', 'Alcala de los Gazules,Alcalá de los Gazules', 36.4621200, -5.7238200, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43575, 'Alcalá del Júcar', 'Alcala del Jucar', 'Alcala de Jucar,Alcala del Jucar,Alcalá de Jucar,Alcalá del Júcar', 39.1931300, -1.4301700, 'ES', '2014-09-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43576, 'Alcalá de Guadaira', 'Alcala de Guadaira', 'Al''kala-de-Gvadaira,Alcala de Guadaira,Alcalá de Guadaira,Alcalá de Guadaíra,Алькала-де-Гвадаира', 37.3379100, -5.8395100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43577, 'Alcadozo', 'Alcadozo', 'Alcadozo', 38.6491600, -1.9799800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43578, 'Alcàsser', 'Alcasser', '', 39.3679100, -0.4444700, 'ES', '2014-03-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43579, 'Alcabón', 'Alcabon', 'Alcabon,Alcabón', 40.0022400, -4.3685200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43580, 'Alburquerque', 'Alburquerque', 'Alburquerque', 39.2207600, -7.0023400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43581, 'Albuñuelas', 'Albunuelas', '', 36.9282800, -3.6318400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43582, 'Albuñol', 'Albunol', '', 36.7920300, -3.2050000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43583, 'Albuñán', 'Albunan', 'Albunan,Albuñán', 37.2270800, -3.1332100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43584, 'Albuixech', 'Albuixech', 'Albuixec,Albuixech', 39.5500000, -0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43585, 'Albudeite', 'Albudeite', 'Albudeite', 38.0289500, -1.3866400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43586, 'Albox', 'Albox', '', 37.3885600, -2.1494900, 'ES', '2012-08-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43587, 'Alborea', 'Alborea', 'Alborea', 39.2833300, -1.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43588, 'Alboraya', 'Alboraya', 'Al''boraja,Al''borajja,Alboraia,Alboraya,a er wo lai a,albraya,Альборайя,Альборая,Ալբորայա,آلبرایا,阿尔沃赖阿', 39.5000000, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43589, 'Alborache', 'Alborache', 'Alborache,Alboraig', 39.3833300, -0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43590, 'Albondón', 'Albondon', '', 36.8277000, -3.2114400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43591, 'Albolote', 'Albolote', '', 37.2308800, -3.6551000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43592, 'Alberic', 'Alberic', 'Alberic,Alberique', 39.1166700, -0.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43593, 'Albatera', 'Albatera', 'Al''batera,Albatera,a er wa te la,albatra,albatyra,Альбатера,آلباترا,ألباتيرا,阿尔瓦特拉', 38.1790200, -0.8705900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43594, 'Albatana', 'Albatana', 'Albatana', 38.5705700, -1.5221000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43595, 'Albarreal de Tajo', 'Albarreal de Tajo', 'Albarreal de Tajo', 39.8969800, -4.2289500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43596, 'Albánchez', 'Albanchez', 'Albanchez,Albánchez', 37.2836100, -2.1822900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43597, 'Albalat dels Tarongers', 'Albalat dels Tarongers', 'Albalat,Albalat de Segart,Albalat de Taronchers,Albalat dels Taronchers,Albalat dels Tarongers', 39.7000000, -0.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43598, 'Albalat dels Sorells', 'Albalat dels Sorells', 'Albalat dels Sorells', 39.5333300, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43599, 'Albalat de la Ribera', 'Albalat de la Ribera', 'Al''balat-de-la-Ribera,Albalat de la Ribera,Albalat-de-la-Ribera,a er wa la te de la li wei la,albalat d la rybra,albalat dy la rybyra,Албалат-де-ла-Рібера,Альбалат-де-ла-Рибера,آلبالات د لا ریبرا,ألبالات دي لا ريبيرا,阿尔瓦拉特德拉里韦拉', 39.2000000, -0.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43600, 'Albaladejo del Cuende', 'Albaladejo del Cuende', 'Albaladejo,Albaladejo del Cuende', 39.8068400, -2.2290300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43601, 'Albaladejo', 'Albaladejo', 'Albadalejo,Albaladejo', 38.6188700, -2.8078400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43602, 'Albalá', 'Albala', 'Albala,Albalá', 39.2559200, -6.1852800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43603, 'Albal', 'Albal', 'Albal', 39.4000000, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43604, 'Albaida del Aljarafe', 'Albaida del Aljarafe', 'Albaida del Aljarafe', 37.4235400, -6.1667500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43605, 'Albaida', 'Albaida', 'Albaida', 38.8379800, -0.5172100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43606, 'Albacete', 'Albacete', 'ABC,Al''basete,Albacet,Albacete,Albasete,Albasetė,Gorad Al''baseteh,a er wa sai te,albasete,albasth,albsyt,arubasete,Албасете,Альбасете,Горад Альбасетэ,אלבסטה,آلباسته,الباچیتے,البسيط,アルバセテ,阿尔瓦塞特,阿爾瓦塞特,알바세테', 38.9942400, -1.8564300, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43607, 'Alaior', 'Alaior', 'Alaior,Alayor', 39.9303400, 4.1403900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43608, 'Alatoz', 'Alatoz', 'Alatoz', 39.0949500, -1.3609800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43609, 'Alaró', 'Alaro', 'Alaro,Alaró', 39.7044100, 2.7918100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43610, 'Alarcón', 'Alarcon', 'Alarcon,Alarcón', 39.5500000, -2.0833300, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43611, 'Alanís', 'Alanis', 'Alanis,Alanís', 38.0333300, -5.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43612, 'Alange', 'Alange', 'Alange', 38.7849500, -6.2457400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43613, 'Alamillo', 'Alamillo', 'Alamillo', 38.6784200, -4.7900800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43614, 'Alamedilla', 'Alamedilla', 'Alamedilla', 37.5823200, -3.2424100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43615, 'Alameda', 'Alameda', 'Alameda', 37.2087000, -4.6586000, 'ES', '2013-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43616, 'Alajeró', 'Alajero', 'Alajero,Alajeró', 28.0620500, -17.2407300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43617, 'Alájar', 'Alajar', 'Alajar,Alájar', 37.8740800, -6.6653600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43618, 'Alaquàs', 'Alaquas', 'Alacuas,Alacuás,Alakuas,Alaquas,Alaquàs,Алакуас', 39.4556800, -0.4610000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43619, 'Ajofrín', 'Ajofrin', '', 39.7108800, -3.9822000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43620, 'Ahillones', 'Ahillones', 'Ahillones', 38.2666700, -5.8500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43621, 'Agulo', 'Agulo', 'Agulo', 28.1877800, -17.1967800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43622, 'Agullent', 'Agullent', 'Agullent', 38.8227300, -0.5483300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43623, 'Agüimes', 'Aguimes', 'Agueimes,Aguimes,Agüimes,Агуимес', 27.9053900, -15.4460900, 'ES', '2013-07-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43624, 'Águilas', 'Aguilas', 'Agilas,Agudas,Aguilas,a ji la si,aghylas,agillaseu,agirasu,Águilas,Агилас,Агілас,أغيلاس,アギラス,阿吉拉斯,아길라스', 37.4063000, -1.5828900, 'ES', '2015-07-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43625, 'Aguilar', 'Aguilar', 'Aguilar de la Frontera', 37.5147600, -4.6571700, 'ES', '2013-03-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43626, 'Agudo', 'Agudo', 'Agudo', 38.9818300, -4.8713300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43627, 'Aigües', 'Aiguees', 'Aguas de Busot,Aiguees,Aigues,Aigües', 38.5000000, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43628, 'Aguadulce', 'Aguadulce', 'Aguadulce', 37.2527300, -4.9926900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43629, 'Aguadulce', 'Aguadulce', 'Barriada de Aguadulce', 36.8140900, -2.5723500, 'ES', '2009-05-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43630, 'Agrón', 'Agron', 'Agron,Agrón', 37.0302300, -3.8287000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43631, 'Agres', 'Agres', 'Agres,a ge lei si,aghrys,agrs,Агрес,آگرس,أغريس,阿格雷斯', 38.7833300, -0.5166700, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43632, 'Agost', 'Agost', 'Agost,a ge si te,aghwst,dhstan agst,Агост,Ագոստ,أغوست,دهستان آگست,阿戈斯特', 38.4400300, -0.6383600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43633, 'Agaete', 'Agaete', 'Agaehte,Agaete,a gai te,agaete,aghayty,Агаете,Агаэте,أغايتي,アガエテ,阿盖特', 28.1002300, -15.6999800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43634, 'Atzeneta d''Albaida', 'Atzeneta d''Albaida', 'Adzaneta de Albaida,Atzeneta d''Albaida', 38.8333300, -0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43635, 'Adsubia', 'Adsubia', 'Adsubia,L''Atzuvia,L''Atzúvia', 38.8481900, -0.1532400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43636, 'Adra', 'Adra', 'Abdera,Adra,Адра', 36.7496100, -3.0205500, 'ES', '2014-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43637, 'Ador', 'Ador', 'Ador', 38.9182300, -0.2224700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43638, 'Adeje', 'Adeje', 'Adeche,Adechė,Adeje,Adekhe,Costa Adeje,a de he,adykhy,Адехе,أديخي,阿德赫', 28.1227100, -16.7260000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43639, 'Adamuz', 'Adamuz', 'Adamuz', 38.0267400, -4.5223100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43640, 'Aceuchal', 'Aceuchal', 'Acebuchal,Acenchal,Aceuchal', 38.6462700, -6.4863600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43641, 'Acedera', 'Acedera', '', 39.0767800, -5.5738400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43642, 'Acalá del Río', 'Acala del Rio', 'Acala del Rio,Acalá del Río,Alcala,Alcalá', 37.5178000, -5.9818500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43643, 'Abrucena', 'Abrucena', 'Abrucena', 37.1322600, -2.7971100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43644, 'Abla', 'Abla', 'Abla,Abula,Aebura', 37.1424500, -2.7780800, 'ES', '2012-08-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43645, 'Abertura', 'Abertura', 'Abertura', 39.2435200, -5.8139400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43646, 'Abenójar', 'Abenojar', 'Abenojar,Abenójar', 38.8803200, -4.3570200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43647, 'Abengibre', 'Abengibre', 'Abengibre', 39.2166700, -1.5333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43648, 'Abarán', 'Abaran', 'Abaran,Abarán,Albaran', 38.2055100, -1.3990700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43649, 'Abanilla', 'Abanilla', 'Abanil''ja,Abanilla,Albanilla,Avanigia,Fabaniella,Favanella,La Zarza de Abanilla,a wa ni li ya,abanya,Αβανίγια,Абанилья,Абанілья,أبانيا,阿瓦尼利亚', 38.2053700, -1.0415300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43650, 'Punta Umbría', 'Punta Umbria', 'Punta Umbria,Punta Umbría', 37.1821300, -6.9660500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43651, 'Grao de Murviedro', 'Grao de Murviedro', '', 39.6416700, -0.2388900, 'ES', '2016-12-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43652, 'Zúñiga', 'Zuniga', '', 42.6924700, -2.2998200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43653, 'Zuñeda', 'Zuneda', 'Zuneda,Zuñeda', 42.6050100, -3.2263200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43654, 'Zumaia', 'Zumaia', 'Zumaia,Zumaya', 43.2946900, -2.2534100, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43655, 'Zumarraga', 'Zumarraga', 'Sumaraga,Sumarraga,Zumarraga,Zumárraga,su ma la jia,sumalaga,sumaraga,thwmaragha,Сумарага,Сумаррага,Սումառագա,ثوماراغا,スマラガ,苏马拉加,수마라가', 43.0885800, -2.3140800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43656, 'Zugarramurdi', 'Zugarramurdi', 'Zugarramurdi', 43.2696400, -1.5411300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43657, 'Zuera', 'Zuera', 'Suehra,Suera,Zuera,su ai la,thwyra,Суера,Суэра,ثويرا,苏埃拉', 41.8677500, -0.7898400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43658, 'Zucaina', 'Zucaina', 'Sucaina,Zucaina', 40.1166700, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43659, 'Zubieta', 'Zubieta', '', 43.1247300, -1.7421900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43660, 'Zotes del Páramo', 'Zotes del Paramo', 'Zotes del Paramo,Zotes del Páramo', 42.2726800, -5.7361700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43661, 'Zorraquín', 'Zorraquin', 'Zorraquin,Zorraquín', 42.3256500, -3.0392500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43662, 'Zorita de los Canes', 'Zorita de los Canes', 'Zorita de los Canes', 40.3305200, -2.8876400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43663, 'Zorita del Maestrazgo', 'Zorita del Maestrazgo', 'Sorita,Zorita,Zorita del Maestrazgo', 40.7281700, -0.1666700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43664, 'Zorita de la Frontera', 'Zorita de la Frontera', 'Zorita de la Frontera', 41.0145300, -5.1965900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43665, 'Zazuar', 'Zazuar', '', 41.6952800, -3.5545100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43666, 'Zas', 'Zas', '', 43.0988500, -8.9155800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43667, 'Zarzuela del Pinar', 'Zarzuela del Pinar', 'Zarzuela del Pinar', 41.2601800, -4.1845700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43668, 'Zarzuela del Monte', 'Zarzuela del Monte', 'Zarzuela del Monte', 40.8088800, -4.3361300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43669, 'Zarzuela de Jadraque', 'Zarzuela de Jadraque', 'Zarzuela de Jadraque', 41.0683800, -3.0443600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43670, 'Zarzuela', 'Zarzuela', 'Zarzuela', 40.2590200, -2.1103400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43671, 'Zarzosa', 'Zarzosa', 'Zarzosa', 42.1829400, -2.3429700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43672, 'Zarzalejo', 'Zarzalejo', '', 40.5481100, -4.1817600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43673, 'Zarza de Tajo', 'Zarza de Tajo', 'Zarza de Tajo', 40.0159100, -3.1287700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43674, 'Zarza de Granadilla', 'Zarza de Granadilla', 'Zarza de Granadilla', 40.2372300, -6.0485000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43675, 'Zarratón', 'Zarraton', 'Zarraton,Zarratón', 42.5164900, -2.8809400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43676, 'Zarautz', 'Zarautz', 'Zarautz,Zarauz', 43.2844400, -2.1699200, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43677, 'Zaratán', 'Zaratan', 'Zaratan,Zaratán', 41.6597100, -4.7841700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43678, 'Zaratamo', 'Zaratamo', 'Zaratamo,Zarátamo', 43.2166700, -2.8666700, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43679, 'Zarapicos', 'Zarapicos', 'Zarapicos', 41.0383000, -5.8452600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43680, 'Zaragoza', 'Zaragoza', 'Caesaraugusta,Caesarea Augusta,Caragoca,Salduba,Salduie,Saragoca,Saragosa,Saragosae,Saragoso,Saragossa,Saragosse,Saragoza,Saragozza,Saragoça,Saragòssa,Saraqosa,ZAZ,ZGZ,Zaragosa,Zaragoza,Zaragozo,Zargoza,sa la ge sa,sa ra ko sa,salagosa,saragosa,saragwsa,sarajwsa,srgwsh,srqstt,sەrەgۆsa,taragota,Çaragoça,Żaragoża,Σαραγόσα,Сарагосæ,Сарагоса,Сарагосо,Սարագոսա,סאראגאסא,סרגוסה,ساراجوسا,ساراگوسا,سرقسطة,سەرەگۆسا,सारागोसा,ਤਾਰਾਗੋਤਾ,ซาราโกซา,სარაგოსა,サラゴサ,萨拉戈萨,사라고사', 41.6560600, -0.8773400, 'ES', '2014-05-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43681, 'Zapardiel de la Ribera', 'Zapardiel de la Ribera', 'Zapardiel de la Ribera', 40.3555400, -5.3282600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43682, 'Zapardiel de la Cañada', 'Zapardiel de la Canada', 'Zapardiel de la Canada,Zapardiel de la Cañada', 40.6064800, -5.3379100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43683, 'Zaorejas', 'Zaorejas', 'Zaorejas', 40.7620900, -2.2012000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43684, 'Zamudio', 'Zamudio', 'Zamudia,Zamudio,Zamudio-Derio', 43.2860000, -2.8700000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43685, 'Zamora', 'Zamora', 'Samora,ZOB,Zamora,Zamoro,samora,thamora,zamwra,Самора,زامورا,থামোরা,サモラ', 41.5063300, -5.7445600, 'ES', '2012-12-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43686, 'Zambrana', 'Zambrana', 'Zambrana,Zanbrana', 42.6610200, -2.8790900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43687, 'Zamayón', 'Zamayon', 'Zamayon,Zamayón', 41.1486100, -5.8305400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43688, 'Zamarra', 'Zamarra', 'Samarra,Zamarra', 40.5189300, -6.4524800, 'ES', '2012-08-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43689, 'Zaldibia', 'Zaldivia', 'Zaldibia,Zaldivia', 43.0372000, -2.1506000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43690, 'Zaldibar', 'Zaldibar', 'Zaldibar,Zaldivar,Zaldua,Zaldívar', 43.1666700, -2.5333300, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43691, 'Zaidín', 'Zaidin', 'Saidi,Saidi / Zaidin,Saidí,Saidí / Zaidín,Zaidin,Zaidín', 41.6040200, 0.2642900, 'ES', '2015-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43692, 'Zafrilla', 'Zafrilla', 'Zafrilla', 40.2000000, -1.6166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43693, 'Zael', 'Zael', 'Zael', 42.1058700, -3.8262300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43694, 'Iurreta', 'Iurreta', 'Iurreta,Ixorreta,Yurreta', 43.1833300, -2.6333300, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43695, 'Yunquera de Henares', 'Yunquera de Henares', 'Yunquera,Yunquera de Henares,Yunqueria de Henares,Yunquería de Henares', 40.7513900, -3.1626000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43696, 'Yuncos', 'Yuncos', 'Yuncos', 40.0859000, -3.8710600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43697, 'Yuncler', 'Yuncler', 'Yuncler', 40.0407900, -3.8997900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43698, 'Yésero', 'Yesero', 'Yesero,Yésero', 42.6191100, -0.2502000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43699, 'Yesa', 'Yesa', '', 42.6202500, -1.2036000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43700, 'Yelo', 'Yelo', 'Yelo', 41.2166700, -2.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43701, 'Yeles', 'Yeles', '', 40.1203500, -3.8048700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43702, 'Yélamos de Arriba', 'Yelamos de Arriba', 'Yelamos de Arriba,Yélamos de Arriba', 40.6400800, -2.8434000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43703, 'Yélamos de Abajo', 'Yelamos de Abajo', 'Yelamos de Abajo,Yélamos de Abajo', 40.6309200, -2.8580300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43704, 'Yecla de Yeltes', 'Yecla de Yeltes', 'Yecla,Yecla de Yeltes', 40.9591700, -6.4890400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43705, 'Yebra de Basa', 'Yebra de Basa', 'Aebura', 42.4864700, -0.2817800, 'ES', '2012-03-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43706, 'Yebra', 'Yebra', 'Aebura,Yebra', 40.3570200, -2.9663000, 'ES', '2012-03-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43707, 'Yebes', 'Yebes', 'Yebes', 40.5316200, -3.1078200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43708, 'Yanguas de Eresma', 'Yanguas de Eresma', 'Yanguas de Eresma', 41.0720100, -4.2390500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43709, 'Yanguas', 'Yanguas', 'Janguas,Jangvas,Yangua,Yanguas,yi an gua si,Янгвас,Янгуас,伊安瓜斯', 42.1017100, -2.3398600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43710, 'Igantzi', 'Igantzi', 'Igantzi,Yanci', 43.2252600, -1.7004800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43711, 'Wamba', 'Wamba', 'Wamba', 41.6752500, -4.9174800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43712, 'Vozmediano', 'Vozmediano', 'Vosmediano,Vozmediano,bo si mei di ya nuo,Восмедиано,Восмедіано,博斯梅迪亚诺', 41.8375200, -1.8558000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43713, 'Vizmanos', 'Vizmanos', 'Vizmanos', 42.0234200, -2.4086900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43714, 'Vizcaínos', 'Vizcainos', 'Vizcainos,Vizcaínos', 42.1035900, -3.2669800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43715, 'Viveiro', 'Viveiro', '', 43.6622800, -7.5934400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43716, 'Vivel del Río Martín', 'Vivel del Rio Martin', 'Vivel,Vivel del Rio,Vivel del Rio Martin,Vivel del Río Martín', 40.8709100, -0.9388900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43717, 'Biure', 'Biure', 'Biure', 42.3373400, 2.8951300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43718, 'Gasteiz / Vitoria', 'Gasteiz / Vitoria', 'Bittorixa,Gasteiz,VIT,Victoriacum,Vitoria,Vitoria-Gasteiz,Vitorija,Vitorio,Vitòria,Vitória,bitoria,wytwryh,Витория,ויטוריה,ビトリア', 42.8499800, -2.6726800, 'ES', '2013-05-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43719, 'Vitigudino', 'Vitigudino', 'Vitigudino,bi di gu di nuo,Витигудино,Вітігудіно,比蒂古迪诺', 41.0091200, -6.4340400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43720, 'Vita', 'Vita', 'Vita', 40.8117800, -5.0058300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43721, 'Vistabella del Maestrazgo', 'Vistabella del Maestrazgo', 'Vistabella,Vistabella de Maestrazgo,Vistabella del Maestrat,Vistabella del Maestrazgo', 40.2961700, -0.2943500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43722, 'Vistabella', 'Vistabella', 'Vistabella', 41.2185000, -1.1535800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43723, 'Visiedo', 'Visiedo', 'Visedo,Visiedo,Viziedo', 40.6855800, -1.0970900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43724, 'Vinuesa', 'Vinuesa', 'Vinuehsa,Vinuesa,bi nu ai sa,Винуэса,Вінуеса,比努埃萨', 41.9103200, -2.7648300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43725, 'Viñuelas', 'Vinuelas', 'Vinuelas,Viñuelas', 40.7922900, -3.3403600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43726, 'Viniegra de Arriba', 'Viniegra de Arriba', 'Viniegra de Arriba', 42.0951300, -2.8330400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43727, 'Viniegra de Abajo', 'Viniegra de Abajo', 'Viniegra de Abajo', 42.1505500, -2.8893000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43728, 'Viñegra de Moraña', 'Vinegra de Morana', 'Vinegra de Morana,Viñegra de Moraña', 40.8507400, -4.9211500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43729, 'Vinebre', 'Vinebre', 'Vinebre', 41.1846400, 0.5894500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43730, 'Vindel', 'Vindel', 'Vindel', 40.5874300, -2.3806000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43731, 'Viñas', 'Vinas', '', 41.7733000, -6.4711700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43732, 'Vinaròs', 'Vinaros', 'Vinaros,Vinarose,Vinaroz,Винаросе', 40.4703300, 0.4755900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43733, 'Vinaixa', 'Vinaixa', '', 41.4333300, 0.9833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43734, 'Vimianzo', 'Vimianzo', '', 43.1098800, -9.0335100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43735, 'Vimbodí', 'Vimbodi', 'Vimbodi,Vimbodí', 41.4006900, 1.0505600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43736, 'Vilviestre del Pinar', 'Vilviestre del Pinar', 'Vil''v''estre-del''-Pinar,Vil''vestre-del''-Pinar,Vilviestre del Pinar,bi er wei ye si te lei de er pi na er,fylfystry dyl baynar,Вильвьестре-дель-Пинар,Вільвєстре-дель-Пінар,فيلفيستري ديل باينار,比尔维耶斯特雷德尔皮纳尔', 41.9503300, -3.0780300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43737, 'Vilvestre', 'Vilvestre', 'Vil''vestre,Vilvestre,bi er wei si te lei,Вильвестре,Вільвестре,比尔韦斯特雷', 41.1063600, -6.7272500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43738, 'Vilobí d''Onyar', 'Vilobi d''Onyar', 'Vilobi d''Onyar,Vilobí d''Onyar,Vilovi de Onar,Vilovi de Oñar,Viloví de Oñar', 41.8833300, 2.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43739, 'Vilobí del Penedès', 'Vilobi del Penedes', 'Vilobi del Penedes,Vilobí del Penedès,Vilovi,Viloví', 41.3833300, 1.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43740, 'Viloria de Rioja', 'Viloria de Rioja', 'Viloria de Rioja', 42.4260800, -3.1005600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43741, 'Viloria', 'Viloria', 'Viloria', 41.4460400, -4.3835600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43742, 'Vilopriu', 'Vilopriu', '', 42.1000000, 3.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43743, 'Villovieco', 'Villovieco', 'Villovieco', 42.2947800, -4.4812200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43744, 'Villota del Páramo', 'Villota del Paramo', 'Villota del Paramo,Villota del Páramo', 42.5523400, -4.8489300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43745, 'Villoslada de Cameros', 'Villoslada de Cameros', 'Villoslada,Villoslada de Cameros', 42.1138300, -2.6741300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43746, 'Villoruela', 'Villoruela', 'Villoruela', 41.0086000, -5.3938100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43747, 'Villoruebo', 'Villoruebo', 'Villoruebo', 42.1687400, -3.4415900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43748, 'Villoría', 'Villoria', 'Villoria,Villoría', 40.9943500, -5.3736300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43749, 'Villores', 'Villores', 'Villores', 40.6747800, -0.2002300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43750, 'Villoldo', 'Villoldo', 'Villoldo', 42.2833300, -4.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43751, 'Villodrigo', 'Villodrigo', 'Villadrigo,Villodrigo', 42.1443600, -4.0952700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43752, 'Villodre', 'Villodre', '', 42.2116100, -4.2448400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43753, 'Villel de Mesa', 'Villel de Mesa', 'Villel,Villel de Mesa', 41.1261600, -1.9907200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43754, 'Villel', 'Villel', 'Villel', 40.2346300, -1.1861100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43755, 'Villeguillo', 'Villeguillo', 'Villeguillo', 41.2529000, -4.5795100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43756, 'Villegas', 'Villegas', 'Villegas', 42.4686600, -4.0175900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43757, 'Villazopeque', 'Villazopeque', '', 42.1984500, -4.0168800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43758, 'Villazanzo de Valderaduey', 'Villazanzo de Valderaduey', 'Villazanzo de Valderaduey', 42.5359200, -4.9646200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43759, 'Villazala', 'Villazala', 'Villazala', 42.3614600, -5.8560000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43760, 'Vilaión', 'Vilaion', 'Villayon,Villayón', 43.4485900, -6.7053400, 'ES', '2012-02-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43761, 'Villaviudas', 'Villaviudas', 'Villaviudas', 41.9622700, -4.3420000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43762, 'Villavieja de Yeltes', 'Villavieja de Yeltes', 'Villarieja,Villavieja,Villavieja de Yeltes', 40.8757300, -6.4679200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43763, 'Villavieja del Lozoya', 'Villavieja del Lozoya', 'Villavieja del Lozoya', 41.0039600, -3.6687000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43764, 'Villaviciosa de Odón', 'Villaviciosa de Odon', 'Vil''javisiosa-de-Odon,Villaviciosa de Odon,Villaviciosa de Odón,Вильявисиоса-де-Одон', 40.3569200, -3.9001100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43765, 'Villaviciosa', 'Villaviciosa', '', 43.4812600, -5.4357400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43766, 'Villavicencio de los Caballeros', 'Villavicencio de los Caballeros', 'Villavicencio de los Caballeros', 42.0589300, -5.2356600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43767, 'Villaveza de Valverde', 'Villaveza de Valverde', 'Villaveza,Villaveza de Valverde', 41.9451600, -5.8484900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43768, 'Villaveza del Agua', 'Villaveza del Agua', 'Villaveza del Agua', 41.9192200, -5.6787100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43769, 'Villaverde-Mogina', 'Villaverde-Mogina', 'Villaverde-Mogina', 42.1604100, -4.0502400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43770, 'Villaverde de Rioja', 'Villaverde de Rioja', 'Villaverde de Rioja', 42.3205100, -2.8137000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43771, 'Villaverde de Montejo', 'Villaverde de Montejo', 'Villaverde de Montejo', 41.5222500, -3.6545200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43772, 'Villaverde de Medina', 'Villaverde de Medina', 'Villaverde de Medina', 41.3068700, -5.0262500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43773, 'Villaverde del Monte', 'Villaverde del Monte', 'Villaverde del Monte', 42.1607500, -3.8142100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43774, 'Villaverde de Guareña', 'Villaverde de Guarena', 'Villaverde de Guarena,Villaverde de Guareña', 41.0640600, -5.5249200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43775, 'Villaverde', 'Villaverde', '', 40.3500000, -3.7000000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43776, 'Villavendimio', 'Villavendimio', 'Villavendimio', 41.5781200, -5.3428700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43777, 'Villavellid', 'Villavellid', 'Villavellid', 41.6921800, -5.2763000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43778, 'Villavelayo', 'Villavelayo', 'Villavelayo', 42.1308400, -2.9856500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43779, 'Villavaquerín', 'Villavaquerin', 'Villavaquerin,Villavaquerín', 41.6635700, -4.4628700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43780, 'Villaumbrales', 'Villaumbrales', 'Villaumbrales', 42.0887300, -4.6138400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43781, 'Villaturiel', 'Villaturiel', 'Vil''jatur''el'',Vil''jaturel'',Villaturiel,bi li ya tu lie er,Вильятурьель,Вільятурєль,比利亚图列尔', 42.5181900, -5.4861500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43782, 'Villaturde', 'Villaturde', 'Villaturde', 42.3776900, -4.6708500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43783, 'Villatuerta', 'Villatuerta', '', 42.6602200, -1.9924700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43784, 'Villatuelda', 'Villatuelda', 'Villatuelda', 41.8149900, -3.8805400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43785, 'Villatoro', 'Villatoro', 'Villatoro,Villatoros', 40.5560900, -5.1126200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43786, 'Villastar', 'Villastar', 'Villastar', 40.2810200, -1.1513900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43787, 'Villasrubias', 'Villasrubias', 'Villasrubias', 40.3382200, -6.6392000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43788, 'Villasila de Valdavia', 'Villasila de Valdavia', 'Villasila,Villasila de Valdavia', 42.5319200, -4.5588400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43789, 'Villasexmir', 'Villasexmir', 'Villasexmir', 41.6394300, -5.0647000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43790, 'Villaselán', 'Villaselan', 'Villaselan,Villaselán', 42.5610500, -5.0482000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43791, 'Villaseco de los Reyes', 'Villaseco de los Reyes', 'Villaseco de los Reyes', 41.1626200, -6.1842600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43792, 'Villaseco de los Gamitos', 'Villaseco de los Gamitos', 'Villaseco de los Gamitos', 41.0362100, -6.1132300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43793, 'Villaseca de Uceda', 'Villaseca de Uceda', 'Villaseca de Uceda', 40.8182700, -3.3490400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43794, 'Villaseca de Henares', 'Villaseca de Henares', 'Villaseca de Henares', 40.9606000, -2.7977500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43795, 'Villaseca de Arciel', 'Villaseca de Arciel', 'Villaseca de Arciel', 41.6243000, -2.1617600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43796, 'Villasdardo', 'Villasdardo', 'Villasdardo', 41.0044900, -6.1630300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43797, 'Villasbuenas de Gata', 'Villasbuenas de Gata', 'Villasbuenas de Gata', 40.1787900, -6.6264100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43798, 'Villasbuenas', 'Villasbuenas', 'Villasbuenas', 41.0626300, -6.5966200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43799, 'Villasayas', 'Villasayas', 'Villasayas', 41.3529100, -2.6101100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43800, 'Villasarracino', 'Villasarracino', 'Villasarracino', 42.4120700, -4.4963300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43801, 'Villasandino', 'Villasandino', '', 42.3707200, -4.1097500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43802, 'Villasana de Mena', 'Villasana de Mena', 'Valle de Mena,Villasana de Mena,Villasana de Mona', 43.1001700, -3.2825300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43803, 'Villasabariego', 'Villasabariego', 'Villasabariego', 42.5328800, -5.4132200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43804, 'Villarta-Quintana', 'Villarta-Quintana', 'Villarta-Quintana', 42.4299800, -3.0484000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43805, 'Villarroya de los Pinares', 'Villarroya de los Pinares', 'Villarroya de los Pinares', 40.5291700, -0.6690000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43806, 'Villarroya del Campo', 'Villarroya del Campo', 'Villarroya,Villarroya del Campo', 41.1430900, -1.3241600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43807, 'Villarroya de la Sierra', 'Villarroya de la Sierra', 'Villarroya,Villarroya de la Sierra', 41.4634600, -1.7835000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43808, 'Villarroya', 'Villarroya', 'Villarrolla,Villarroya', 42.1305300, -2.0689600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43809, 'Villarrín de Campos', 'Villarrin de Campos', 'Villarrin de Campos,Villarrín de Campos', 41.7952200, -5.6389800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43810, 'Urretxu', 'Urretxu', 'Urretxu,Villarreal de Urrechu,Villarreal de Urrechua', 43.0910000, -2.3170100, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43811, 'Villarreal de Huerva', 'Villarreal de Huerva', 'Villareal,Villarreal de Huerva', 41.1903400, -1.2898300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43812, 'Villarramiel', 'Villarramiel', 'Villarramiel', 42.0430100, -4.9121500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43813, 'Villarrabé', 'Villarrabe', 'Villarrabe,Villarrabé', 42.4209000, -4.7844500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43814, 'Villarquemado', 'Villarquemado', 'Villarquemado', 40.5175000, -1.2650000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43815, 'Areatza', 'Areatza', 'Areatza,Villaro', 43.1166700, -2.7666700, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43816, 'Villarmuerto', 'Villarmuerto', 'Villarmuerto', 41.0562000, -6.3629400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43817, 'Villarmentero de Esgueva', 'Villarmentero de Esgueva', 'Villarmentero de Esgueva', 41.6851500, -4.5463600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43818, 'Villarmentero de Campos', 'Villarmentero de Campos', 'Villarmentero de Campos', 42.2977700, -4.4999200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43819, 'Villarmayor', 'Villarmayor', 'Villarmayor', 41.0151400, -5.9715100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43820, 'Villarluengo', 'Villarluengo', 'Villarluengo', 40.6484200, -0.5306600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43821, 'Villarino de los Aires', 'Villarino de los Aires', 'Vil''jarino-de-los-Ajres,Villarino,Villarino de los Aires,Villarino dels Aires,Villarino dos Ares,bi li ya li nuo de luo sai lei si,Вильярино-де-лос-Айрес,Вільяріно-де-лос-Айрес,比利亚里诺德洛赛雷斯', 41.2710200, -6.4684700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43822, 'Vilariño de Conso', 'Vilarino de Conso', 'San Martin de Villarino de Conso', 42.1666700, -7.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43823, 'Villariezo', 'Villariezo', 'Villariezo', 42.2696500, -3.7327200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43824, 'Villares de Yeltes', 'Villares de Yeltes', 'Villares de Yeltes', 40.8659400, -6.4130000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43825, 'Villares de Órbigo', 'Villares de Orbigo', 'Villares de Orbigo,Villares de Órbigo', 42.4695500, -5.9100200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43826, 'Villares de la Reina', 'Villares de la Reina', 'Villares de la Reina', 41.0083200, -5.6488100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43827, 'Villares de Jadraque', 'Villares de Jadraque', 'Villares de Jadraque', 41.1016900, -3.0255800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43828, 'Villarejo de Salvanés', 'Villarejo de Salvanes', 'Villarejo de Salvanes,Villarejo de Salvanés', 40.1666300, -3.2727700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43829, 'Villarejo de Órbigo', 'Villarejo de Orbigo', 'Villarejo de Orbigo,Villarejo de Órbigo', 42.4455900, -5.9046200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43830, 'Villarejo del Valle', 'Villarejo del Valle', 'Villarejo del Valle', 40.2863800, -4.9967400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43831, 'Villarejo de la Peñuela', 'Villarejo de la Penuela', 'Villarejo de la Penuela,Villarejo de la Peñuela', 40.0874500, -2.4099600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43832, 'Villarejo', 'Villarejo', 'Villarejo', 42.3741700, -2.8871200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43833, 'Villardondiego', 'Villardondiego', 'Villardondiego', 41.5848300, -5.3770700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43834, 'Villárdiga', 'Villardiga', 'Villardiga,Villárdiga', 41.8195000, -5.4643900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43835, 'Villardiegua de la Ribera', 'Villardiegua de la Ribera', 'Villardiegua de la Ribera', 41.5354300, -6.1832700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43836, 'Villar de Torre', 'Villar de Torre', 'Villar de Torre', 42.3713300, -2.8641100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43837, 'Villar de Samaniego', 'Villar de Samaniego', 'Villar de Samaniego', 41.1166700, -6.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43838, 'Villar de Plasencia', 'Villar de Plasencia', 'Villar de Plasencia', 40.1377300, -6.0279000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43839, 'Villar de Peralonso', 'Villar de Peralonso', 'Villar de Peralonso', 41.0322300, -6.2228400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43840, 'Villar de Olalla', 'Villar de Olalla', 'Villar de Olalla,Villar de Ollala', 40.0149600, -2.1956100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43841, 'Villar del Salz', 'Villar del Salz', 'Villar del Salz', 40.6820000, -1.4996700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43842, 'Villar del Río', 'Villar del Rio', 'Vil''jar-del''-Rio,Villar del Rio,Villar del Río,bi li ya er de er li ao,Вильяр-дель-Рио,Вільяр-дель-Ріо,比利亚尔德尔里奥', 42.0757400, -2.3508200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43843, 'Villar de los Navarros', 'Villar de los Navarros', 'Villar de los Navarros', 41.1594900, -1.0419900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43844, 'Villar del Olmo', 'Villar del Olmo', 'Villar del Olmo', 40.3346800, -3.2339900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43845, 'Villar del Infantado', 'Villar del Infantado', 'Villar del Infantado', 40.4551400, -2.4790500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43846, 'Villar del Cobo', 'Villar del Cobo', 'Villar del Cobo', 40.3947500, -1.6733200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43847, 'Villar del Campo', 'Villar del Campo', 'Villar del Campo', 41.7888100, -2.1495500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43848, 'Villar del Buey', 'Villar del Buey', 'Villar del Buey', 41.3302400, -6.1893500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43849, 'Villar de la Yegua', 'Villar de la Yegua', 'Villar de la Yegua', 40.7255400, -6.7036400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43850, 'Villar del Ala', 'Villar del Ala', 'Villar del Ala', 41.9163800, -2.5665100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43851, 'Villar de Gallimazo', 'Villar de Gallimazo', 'Villar de Gallimazo', 40.9536700, -5.2881900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43852, 'Villardefrades', 'Villardefrades', 'Villardefrades', 41.7235800, -5.2551300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43853, 'Villar de Fallaves', 'Villar de Fallaves', 'Villar de Fallaves', 41.9250300, -5.3403900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43854, 'Villar de Domingo García', 'Villar de Domingo Garcia', 'Villar de Domingo Garcia,Villar de Domingo García', 40.2373200, -2.2913600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43855, 'Villar de Corneja', 'Villar de Corneja', 'Villar de Corneja', 40.4746200, -5.4330700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43856, 'Villardeciervos', 'Villardeciervos', 'Villardeciervos', 41.9420600, -6.2864700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43857, 'Villar de Ciervo', 'Villar de Ciervo', 'Villar de Ciervo', 40.7377200, -6.7385000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43858, 'Villaralbo', 'Villaralbo', 'Villaralbo', 41.4922400, -5.6835900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43859, 'Villaquirán de los Infantes', 'Villaquiran de los Infantes', 'Villaquiran,Villaquirán', 42.2274400, -4.0086400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43860, 'Villaquirán de la Puebla', 'Villaquiran de la Puebla', '', 42.2828700, -4.1003700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43861, 'Villaquilambre', 'Villaquilambre', 'Vil''jakilambre,Villaquilambre,bi li ya ji lan fu lei,Вильякиламбре,Вільякіламбре,比利亚基兰夫雷', 42.6468500, -5.5583500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43862, 'Villaquejida', 'Villaquejida', 'Villaquejida', 42.1450000, -5.5969900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43863, 'Villaprovedo', 'Villaprovedo', 'Villaprovedo', 42.5167400, -4.3964500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43864, 'Villaobispo de Otero', 'Villaobispo de Otero', 'Villaobispo,Villaobispo de Otero', 42.5006500, -6.0580900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43865, 'Villanuño de Valdavia', 'Villanuno de Valdavia', 'Villanuno de Valdavia,Villanuño de Valdavia', 42.5077500, -4.5188700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43866, 'Vilanova i la Geltrú', 'Vilanova i la Geltru', 'Vilanova,Vilanova i la Geltru,Vilanova i la Geltrú', 41.2239200, 1.7251100, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43867, 'Villanueva de Viver', 'Villanueva de Viver', 'Vilanova de la Reina,Villanueva de Viver', 40.0500000, -0.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43868, 'Villanueva de Valdegovía', 'Villanueva de Valdegovia', 'Uribarri Gaubea,Valdegobia,Valdegovia,Villanueva de Valdegovia,Villanueva de Valdegovía', 42.8477700, -3.0988300, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43869, 'Villanueva de Teba', 'Villanueva de Teba', 'Villanueva de Teba', 42.6489000, -3.1631300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43870, 'Villanueva de Sigena', 'Villanueva de Sigena', '', 41.7157600, -0.0089700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43871, 'Villanueva de San Mancio', 'Villanueva de San Mancio', 'Villanueva de San Mancio', 41.9284200, -5.0120000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43872, 'Villanueva de Perales', 'Villanueva de Perales', 'Villanueva de Perales', 40.3454100, -4.0989100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43873, 'Villanueva de Oscos', 'Villanueva de Oscos', 'Vil''januehva-de-Oskos,Vil''janueva-de-Oskos,Vilanova dOzcos,Vilanova de Ozcos,Villanueva de Oscos,ao si ke si xin zhen,byyanwyba d asks,fyanwyfa dy awskws,Вильянуэва-де-Оскос,Вільянуева-де-Оскос,بییانوئبا د اسکس,فيانويفا دي أوسكوس,奥斯科斯新镇', 43.3114400, -6.9864500, 'ES', '2016-08-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43874, 'Villanueva del Rebollar de la Sierra', 'Villanueva del Rebollar de la Sierra', 'Villanueva del Rebollar de la Sierra', 40.8910800, -1.0083700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43875, 'Villanueva del Rebollar', 'Villanueva del Rebollar', 'Villanueva del Rebollar', 42.2411400, -4.7428800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43876, 'Villanueva del Pardillo', 'Villanueva del Pardillo', 'Villanueva del Pardillo', 40.4901400, -3.9638300, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43877, 'Villanueva de los Caballeros', 'Villanueva de los Caballeros', 'Villanueva de los Caballeros', 41.7591600, -5.2478600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43878, 'Villanueva del Conde', 'Villanueva del Conde', 'Villanueva del Conde', 40.5103900, -6.0121000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43879, 'Villanueva del Campo', 'Villanueva del Campo', 'Villanueva,Villanueva del Campo', 41.9849200, -5.4066000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43880, 'Villanueva del Campillo', 'Villanueva del Campillo', 'Villanueva del Campillo', 40.5764600, -5.1800200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43881, 'Villanueva de la Vera', 'Villanueva de la Vera', 'Vil''januehva-de-la-Vera,Vil''janueva-de-la-Vera,Villanueva de la Vera,bei la xin zhen,fylanywfa dy lafyra,Вильянуэва-де-ла-Вера,Вільянуева-де-ла-Вера,فيلانيوفا دي لافيرا,贝拉新镇', 40.1299800, -5.4625000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43882, 'Villanueva de la Torre', 'Villanueva de la Torre', 'Villanueva de la Torre', 40.5821600, -3.2976400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43883, 'Villanueva de las Peras', 'Villanueva de las Peras', 'Villanueva de las Peras', 41.9347800, -5.9794200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43884, 'Villanueva de las Manzanas', 'Villanueva de las Manzanas', 'Villanueva de las Manzanas', 42.4726400, -5.4804300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43885, 'Villanueva de la Sierra', 'Villanueva de la Sierra', 'Villanueva de la Sierra,Villanueva de la Sierre', 40.2016300, -6.4061100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43886, 'Villanueva de la Condesa', 'Villanueva de la Condesa', 'Villanueva de la Condesa', 42.1491400, -5.0955000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43887, 'Villanueva del Aceral', 'Villanueva del Aceral', 'Villanueva del Aceral', 41.0409500, -4.8541900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43888, 'Villanueva de la Cañada', 'Villanueva de la Canada', 'Villanueva de la Canada,Villanueva de la Cañada', 40.4468900, -4.0042800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43889, 'Villanueva de Jiloca', 'Villanueva de Jiloca', 'Villanueva', 41.0762500, -1.3896000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43890, 'Villanueva de Gumiel', 'Villanueva de Gumiel', 'Villanueva de Gumiel', 41.7377800, -3.6265800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43891, 'Villanueva de Gormaz', 'Villanueva de Gormaz', 'Villanueva de Gormaz', 41.4674000, -3.0622300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43892, 'Villanueva de Gómez', 'Villanueva de Gomez', 'Villanueva,Villanueva de Gomez,Villanueva de Gómez', 40.8826900, -4.7165000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43893, 'Villanueva de Gállego', 'Villanueva de Gallego', 'Villanueva de Gallego,Villanueva de Gállego,Villanueva del Gallego,Villanueva del Gállego', 41.7691700, -0.8235000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43894, 'Villanueva de Duero', 'Villanueva de Duero', 'Villanueva de Duero', 41.5194600, -4.8667100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43895, 'Villanueva de Carazo', 'Villanueva de Carazo', 'Villanueva de Carazo', 41.9827500, -3.3242800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43896, 'Villanueva de Campeán', 'Villanueva de Campean', 'Villanueva de Campean,Villanueva de Campeán', 41.3544700, -5.7702000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43897, 'Villanueva de Cameros', 'Villanueva de Cameros', 'Villanueva,Villanueva de Cameros', 42.1671900, -2.6504000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43898, 'Villanueva de Azoague', 'Villanueva de Azoague', 'Villanueva de Azoague', 41.9760700, -5.6640000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43899, 'Vilanova de Arousa', 'Vilanova de Arousa', 'Villanueva', 42.5666700, -8.8333300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43900, 'Villanueva de Argecilla', 'Villanueva de Argecilla', 'Villanueva de Argecilla', 40.9025700, -2.9143100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43901, 'Villanueva de Argaño', 'Villanueva de Argano', '', 42.3804500, -3.9335300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43902, 'Villanueva de Alcorón', 'Villanueva de Alcoron', 'Villanueva de Alcoron,Villanueva de Alcorón', 40.6795600, -2.2514500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43903, 'Villanubla', 'Villanubla', 'Villanubla', 41.6987700, -4.8417300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43904, 'Villanúa', 'Villanua', 'Bellanuga,Vil''janua,Villanua,Villanuga,Villanúa,bi li ya nu a,Вильянуа,Вільянуа,比利亚努阿', 42.6797000, -0.5376900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43905, 'Villangómez', 'Villangomez', 'Villangomez,Villangómez', 42.1796100, -3.7741900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43906, 'Villán de Tordesillas', 'Villan de Tordesillas', 'Villan de Tordesillas,Villán de Tordesillas', 41.5931100, -4.9221400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43907, 'Villanázar', 'Villanazar', 'Villanazar,Villanázar', 41.9739800, -5.7804300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43908, 'Villamuriel de Cerrato', 'Villamuriel de Cerrato', 'Villamuriel de Cerrato', 41.9493500, -4.5158400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43909, 'Villamuriel de Campos', 'Villamuriel de Campos', 'Villamuriel de Campos', 41.9469000, -5.2071700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43910, 'Villamuera de la Cueza', 'Villamuera de la Cueza', 'Villamuera de la Cueza', 42.2584300, -4.6886000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43911, 'Villamoronta', 'Villamoronta', 'Villamoronta', 42.4033700, -4.6989900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43912, 'Villamor de los Escuderos', 'Villamor de los Escuderos', 'Villamor de los Escuderos', 41.2524400, -5.5748500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43913, 'Villamoratiel de las Matas', 'Villamoratiel de las Matas', 'Villamoratiel de las Matas', 42.3975500, -5.3006400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43914, 'Villamontán de la Valduerna', 'Villamontan de la Valduerna', 'Villamontan,Villamontan de la Valduerna,Villamontán,Villamontán de la Valduerna', 42.3096200, -5.9965600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43915, 'Villamol', 'Villamol', 'Villamol', 42.4276600, -5.0483200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43916, 'Villamiel de la Sierra', 'Villamiel de la Sierra', 'Villamiel de la Sierra', 42.1912400, -3.4177100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43917, 'Villamiel', 'Villamiel', 'Villamiel', 40.1863500, -6.7842500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43918, 'Villameriel', 'Villameriel', 'Villameriel', 42.5282200, -4.4757200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43919, 'Villamejil', 'Villamejil', 'Villamejil', 42.5620500, -6.0251400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43920, 'Villamedianilla', 'Villamedianilla', 'Villamedianilla', 42.1607000, -4.1459200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43921, 'Villamediana de Iregua', 'Villamediana de Iregua', 'Vil''jamed''jana-de-Iregua,Vil''jamediana-de-Iregua,Vil''jamediana-de-Iregva,Viliamediana de Iregua,Villamediana de Iregua,bi li ya mei di ya na de lei gua,Вильямедиана-де-Ирегва,Вильямедьяна-де-Ирегуа,Вільямедіана-де-Ірегуа,Վիլիամեդիանա դե Իրեգուա,比利亚梅迪亚纳德雷瓜', 42.4265800, -2.4194300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43922, 'Villamediana', 'Villamediana', '', 42.0502400, -4.3611500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43923, 'Villamayor de Treviño', 'Villamayor de Trevino', 'Villamayor de Trevino,Villamayor de Treviño', 42.4604800, -4.1192300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43924, 'Villamayor de Monjardín', 'Villamayor de Monjardin', 'Villamayor de Monjardin,Villamayor de Monjardín', 42.6293700, -2.1050300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43925, 'Villamayor de los Montes', 'Villamayor de los Montes', 'Villamayor de los Montes', 42.1056500, -3.7654200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43926, 'Villamayor de Campos', 'Villamayor de Campos', 'Villamayor de Campos', 41.8987000, -5.3596300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43927, 'Villamayor', 'Villamayor', 'Villamayor', 40.9993900, -5.6957900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43928, 'Villamartín de Don Sancho', 'Villamartin de Don Sancho', 'Villamartin de Don Sancho,Villamartín de Don Sancho', 42.5694300, -5.0605600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43929, 'Villamartín de Campos', 'Villamartin de Campos', 'Villamartin de Campos,Villamartín de Campos', 42.0159800, -4.6641400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43930, 'Vilamarín', 'Vilamarin', '', 42.4648800, -7.8911900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43931, 'Villamantilla', 'Villamantilla', 'Villamantilla', 40.3384600, -4.1298600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43932, 'Villamanta', 'Villamanta', '', 40.2985800, -4.1088000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43933, 'Villamanrique de Tajo', 'Villamanrique de Tajo', 'Villamanrique de Tajo', 40.0661700, -3.2366800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43934, 'Villamanín', 'Villamanin', 'Vil''jamanin,Villamanin,Villamanín,bi li ya ma ning,bijamanin,Вильяманин,Вільяманін,ビジャマニン,比利亚马宁', 42.9386400, -5.6566900, 'ES', '2013-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43935, 'Villamandos', 'Villamandos', 'Villamandos', 42.1805800, -5.5939700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43936, 'Villamañán', 'Villamanan', 'Vil''jaman''jan,Villamanan,Villamañan,Villamañán,bi li ya ma ni yang,Вильяманьян,Вільяманьян,比利亚马尼扬', 42.3219800, -5.5819500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43937, 'Villaluenga de la Vega', 'Villaluenga de la Vega', '', 42.5238600, -4.7648900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43938, 'Villalube', 'Villalube', 'Villalube', 41.6100500, -5.5454500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43939, 'Villalpando', 'Villalpando', 'Vil''jal''pando,Villalpando,Villapando,bi li ya er pan duo,Вильяльпандо,Вільяльпандо,比利亚尔潘多', 41.8651700, -5.4123100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43940, 'Villalonso', 'Villalonso', 'Villalonso', 41.5976700, -5.2976900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43941, 'Villalón de Campos', 'Villalon de Campos', 'Villalon,Villalon de Campos,Villalón,Villalón de Campos', 42.0999400, -5.0344000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43942, 'Villalobos', 'Villalobos', 'Villalobos', 41.9456700, -5.4751700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43943, 'Villalobón', 'Villalobon', 'Villalobon,Villalobón', 42.0303700, -4.5034000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43944, 'Villalobar de Rioja', 'Villalobar de Rioja', 'Villalobar de Rioja', 42.4912300, -2.9640400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43945, 'Villalmanzo', 'Villalmanzo', 'Villalmanzo', 42.0484000, -3.7419500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43946, 'Villalengua', 'Villalengua', 'Villalengua', 41.4354800, -1.8412500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43947, 'Villaldemiro', 'Villaldemiro', 'Villaldemiro', 42.2471900, -3.9853400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43948, 'Villalcón', 'Villalcon', '', 42.2928700, -4.8552700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43949, 'Villalcázar de Sirga', 'Villalcazar de Sirga', 'Villalcazar de Sirga,Villalcázar de Sirga', 42.3166200, -4.5427800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43950, 'Villalcampo', 'Villalcampo', 'Villalcampo', 41.5222900, -6.0480100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43951, 'Villalbilla de Gumiel', 'Villalbilla de Gumiel', 'Villalbilla de Gumiel', 41.8062100, -3.6258400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43952, 'Villalbilla de Burgos', 'Villalbilla de Burgos', '', 42.3475700, -3.7810100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43953, 'Villalbilla', 'Villalbilla', 'Villalbilla', 40.4304400, -3.2990400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43954, 'Villalbarba', 'Villalbarba', 'Villalbarba,Villarbarba', 41.6038900, -5.2128100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43955, 'Villalba de Rioja', 'Villalba de Rioja', 'Villalba de Rioja', 42.6096700, -2.8868700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43956, 'Villalba de Perejil', 'Villalba de Perejil', 'Villalba de Perejil', 41.3274200, -1.5483300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43957, 'Villalba del Rey', 'Villalba del Rey', 'Villalba del Rey', 40.3465300, -2.6390200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43958, 'Villalba de los Llanos', 'Villalba de los Llanos', 'Villalba de los Llanos', 40.8002000, -5.9758000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43959, 'Vilalba dels Arcs', 'Vilalba dels Arcs', 'Vilalba dels Arcs,Villalba,Villalba de los Arcos,Villalva de los Arcos', 41.1166700, 0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43960, 'Villalba de los Alcores', 'Villalba de los Alcores', 'Villalba de los Alcores', 41.8636100, -4.8606300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43961, 'Villalba de la Sierra', 'Villalba de la Sierra', 'Villalba de la Sierra', 40.2343700, -2.0892900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43962, 'Villalba de la Loma', 'Villalba de la Loma', 'Villalba de la Loma', 42.1747200, -5.1902300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43963, 'Villalba de la Lampreana', 'Villalba de la Lampreana', 'Villalba de la Lampreana', 41.7432700, -5.6409400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43964, 'Villalba de Guardo', 'Villalba de Guardo', 'Villalba de Guardo', 42.7222900, -4.8232800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43965, 'Villalba de Duero', 'Villalba de Duero', 'Vil''jal''ba-de-Duehro,Vil''jal''ba-de-Duero,Villalba de Duero,Vilyalba de Duero,bi li ya er wa de du ai luo,byyalba d dwyrw,fylaalba dy dwyrw,Вильяльба-де-Дуэро,Вільяльба-де-Дуеро,Վիլյալբա դե Դուերո,بییالبا د دوئرو,فيلاألبا دي دويرو,比利亚尔瓦德杜埃罗', 41.6824300, -3.7444300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43966, 'Vilalba', 'Vilalba', 'Vilalba,Villalba', 43.2980600, -7.6813000, 'ES', '2015-06-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43967, 'Villalazán', 'Villalazan', 'Villalazan,Villalazán', 41.4941400, -5.5891000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43968, 'Villalar de los Comuneros', 'Villalar de los Comuneros', 'Villalar,Villalar de los Comuneros', 41.5496600, -5.1381000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43969, 'Villalán de Campos', 'Villalan de Campos', 'Villalan de Campos,Villalon de Campos,Villalán de Campos,Villalón de Campos', 42.0148400, -5.2364200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43970, 'Villalaco', 'Villalaco', 'Villalaco', 42.1556900, -4.2594000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43971, 'Villahoz', 'Villahoz', 'Villahoz', 42.0758700, -3.9129000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43972, 'Villaherreros', 'Villaherreros', 'Villaherreros', 42.3896400, -4.4625400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43973, 'Villahermosa del Río', 'Villahermosa del Rio', 'Vilafermosa,Villahermosa,Villahermosa del Rio,Villahermosa del Río', 40.2026800, -0.4199000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43974, 'Villahermosa del Campo', 'Villahermosa del Campo', 'Villahermosa,Villahermosa del Campo', 41.1094200, -1.2469200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43975, 'Villahán', 'Villahan', 'Villahan,Villahan de Palenzuela,Villahán,Villahán de Palenzuela', 42.0503100, -4.1310400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43976, 'Villagonzalo-Pedernales', 'Villagonzalo-Pedernales', 'Villagonzalo-Pedernales', 42.3014500, -3.7353900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43977, 'Villagonzalo de Tormes', 'Villagonzalo de Tormes', 'Villagonzalo de Tormes', 40.8922100, -5.4966400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43978, 'Villagómez la Nueva', 'Villagomez la Nueva', 'Villagomez la Nueva,Villagómez la Nueva', 42.1559200, -5.1420800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43979, 'Villageriz', 'Villageriz', 'Villageriz', 42.1188400, -5.9555400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43980, 'Villagatón', 'Villagaton', 'Villagaton,Villagatón', 42.6341300, -6.1618400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43981, 'Villagarcía de Campos', 'Villagarcia de Campos', 'Villagarcia de Campos,Villagarcía de Campos', 41.7803200, -5.1924200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43982, 'Vilagarcía de Arousa', 'Vilagarcia de Arousa', '', 42.5963100, -8.7642600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43983, 'Villagalijo', 'Villagalijo', 'Villagalijo', 42.3487200, -3.1920300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43984, 'Villafufre', 'Villafufre', 'Villafufre', 43.2655700, -3.8937000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43985, 'Villafuerte', 'Villafuerte', '', 41.7343100, -4.3236500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43986, 'Villafruela', 'Villafruela', 'Villafruela', 41.9164700, -3.9137100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43987, 'Villafrechós', 'Villafrechos', 'Villafrechos,Villafrechós', 41.8929000, -5.2185900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43988, 'Ordizia', 'Villafranca de Ordizia', 'Ordizia,Villafranca de Ordicia,Villafranca de Ordizia,Villafranca de Oria,Villafrancia Oria,Villafrancia de Oria', 43.0541000, -2.1763200, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43989, 'Vilafranca del Penedès', 'Vilafranca del Penedes', 'Vil''jafranka-del''-Penedes,Vilafranca Penedes,Vilafranca del Penedes,Vilafranca del Penedès,Vilafranca do Penedes - Vilafranca del Penedes,Vilafranca do Penedés - Vilafranca del Penedès,Villafranca del Panades,Villafranca del Panadés,Villafranca del Penedes,Villafranca del Penedés,Вильяфранка-дель-Пенедес', 41.3461800, 1.6971300, 'ES', '2015-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43990, 'Villafranca del Cid', 'Villafranca del Cid', 'Vilafranca del Maestrat,Villafranca del Cid', 40.4288500, -0.2577500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43991, 'Villafranca del Campo', 'Villafranca del Campo', 'Villafranca del Campo', 40.6954500, -1.3472200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43992, 'Villafranca del Bierzo', 'Villafranca del Bierzo', 'Villafranca del Bierzo', 42.6060100, -6.8106900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43993, 'Villafranca de la Sierra', 'Villafranca de la Sierra', 'Vil''jafranka-de-la-S''erra,Vilafranka de la Siera,Villafranca de la Sierra,byyafranka d la syra,fyafranka dy la syyra,xie la zi you zhen,Вилафранка де ла Сиера,Вильяфранка-де-ла-Сьерра,Вільяфранка-де-ла-Сьєрра,بییافرانکا د لا سیرا,فيافرانكا دي لا سييرا,谢拉自由镇', 40.4980600, -5.2300500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43994, 'Villafranca de Ebro', 'Villafranca de Ebro', 'Villafranca de Ebro', 41.5747300, -0.6503900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43995, 'Villafranca de Duero', 'Villafranca de Duero', 'Villafranca de Duero', 41.4331000, -5.3019200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43996, 'Villafranca', 'Villafranca', 'Villafranca', 42.2793300, -1.7462800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43997, 'Villafrades de Campos', 'Villafrades de Campos', 'Villafrades de Campos', 42.0785300, -4.9712500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43998, 'Villaflores', 'Villaflores', 'Villaflores', 41.0839700, -5.2343600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(43999, 'Villaflor', 'Villaflor', 'Villaflor', 40.7586500, -4.8737900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44000, 'Villaferrueña', 'Villaferruena', 'Villaferruena,Villaferrueña', 42.0983000, -5.8580200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44001, 'Villafeliche', 'Villafeliche', 'Villafeliche', 41.1950900, -1.5098300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44002, 'Villafamés', 'Villafames', 'Vilafames,Villafames,Villafamés', 40.1166700, -0.0500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44003, 'Villafáfila', 'Villafafila', 'Villafafila,Villafáfila', 41.8469200, -5.6152700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44004, 'Villaespasa', 'Villaespasa', 'Villaespasa', 42.0999100, -3.4043600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44005, 'Villaescusa la Sombría', 'Villaescusa la Sombria', 'Villaescusa la Sombria,Villaescusa la Sombría', 42.4151800, -3.4184000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44006, 'Villaescusa de Roa', 'Villaescusa de Roa', 'Villaescusa de Roa', 41.7272700, -4.0172000, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44007, 'Villaescusa', 'Villaescusa', 'Vil''jaehskusa,Villaescusa,Вильяэскуса', 42.9626200, -4.1670600, 'ES', '2013-10-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44008, 'Villaescusa', 'Villaescusa', 'Villaescusa', 41.2061700, -5.4640600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44009, 'Villaeles de Valdavia', 'Villaeles de Valdavia', 'Villaeles de Valdavia', 42.5655600, -4.5831800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44010, 'Villadoz', 'Villadoz', 'Villadoz', 41.1623400, -1.2880000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44011, 'Villadiego', 'Villadiego', 'Vil''jad''ego,Vil''jadiego,bi li ya die ge,fyladyyghw,Вильядьего,Вільядієго,فيلادييغو,比利亚迭戈', 42.5158900, -4.0095800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44012, 'Villadepera', 'Villadepera', 'Villadepera', 41.5470000, -6.1330500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44013, 'Villademor de la Vega', 'Villademor de la Vega', 'Villademor de la Vega', 42.2696400, -5.5680800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44014, 'Villa del Prado', 'Villa del Prado', 'Villa del Prado', 40.2785200, -4.3053400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44015, 'Villa del Campo', 'Villa del Campo', 'Vil''ja-del''-Kampo,Villa del Campo,Villa el Campu,fyla dyl kambw,kan bo zhen,Вилья-дель-Кампо,Вілья-дель-Кампо,فيلا ديل كامبو,坎波镇', 40.1422300, -6.4267900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44016, 'Villadecanes', 'Villadecanes', 'Villadecanes', 42.5797300, -6.7597100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44017, 'Villadangos del Páramo', 'Villadangos del Paramo', 'Villadangos del Paramo,Villadangos del Páramo', 42.5167200, -5.7673700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44018, 'Villada', 'Villada', 'Villada', 42.2511100, -4.9670800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44019, 'Villaconejos de Trabaque', 'Villaconejos de Trabaque', 'Villaconejos,Villaconejos de Trabaque', 40.4006400, -2.3195600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44020, 'Villaconejos', 'Villaconejos', 'Villaconejos', 40.1013900, -3.4825800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44021, 'Villaconancio', 'Villaconancio', 'Villaconancio', 41.8717400, -4.2237900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44022, 'Villaco', 'Villaco', 'Villaco', 41.7402200, -4.2681700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44023, 'Villaciervos', 'Villaciervos', 'Villaciervos', 41.7622700, -2.6267800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44024, 'Villacid de Campos', 'Villacid de Campos', 'Villacid de Campos', 42.0825000, -5.1249800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44025, 'Villacidaler', 'Villacidaler', 'Villacidaler', 42.2216800, -4.9766800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44026, 'Villacastín', 'Villacastin', 'Vil''jakastin,Villacastin,Villacastín,bi li ya ka si ting,Вильякастин,Вільякастін,比利亚卡斯廷', 40.7796000, -4.4135700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44027, 'Villacarriedo', 'Villacarriedo', 'Vil''jakarr''edo,Vil''jakarredo,Villacarriedo,bi li ya ka lie duo,fylakaraydw,Вильякаррьедо,Вільякаррєдо,فيلاكارايدو,比利亚卡列多', 43.2285100, -3.8105700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44028, 'Villacarralón', 'Villacarralon', 'Villacarralon,Villacarralón', 42.1899900, -5.0432400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44029, 'Villabuena del Puente', 'Villabuena del Puente', 'Villabuena del Puente', 41.3807400, -5.4078700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44030, 'Eskuernaga / Villabuena de Álava', 'Villabuena de Alava', 'Eskuernaga,Uriona,Villabuena de Alava,Villabuena de Álava', 42.5478700, -2.6655200, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44031, 'Villabrázaro', 'Villabrazaro', 'Villabrazaro,Villabrázaro', 42.0539400, -5.7274800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44032, 'Villabraz', 'Villabraz', 'Villabraz', 42.2465800, -5.4459300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44033, 'Villabrágima', 'Villabragima', 'Villabragima,Villabrágima', 41.8217800, -5.1154600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44034, 'Villabona', 'Villabona', 'Villabona', 43.1854000, -2.0530400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44035, 'Villablino', 'Villablino', 'Vil''jablino,Villablino,bi li ya fu li nuo,Вильяблино,Вільябліно,比利亚夫利诺', 42.9393200, -6.3194300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44036, 'Villabaruz de Campos', 'Villabaruz de Campos', 'Villabaruz,Villabaruz de Campos', 42.0109900, -4.9962400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44037, 'Villabáñez', 'Villabanez', 'Villabanez,Villabáñez', 41.6309700, -4.5219200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44038, 'Atarrabia', 'Atarrabia', 'Atarrabia,Villava', 42.8323000, -1.6073500, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44039, 'Vileña', 'Vilena', 'Vilena,Vileña', 42.6222700, -3.3229300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44040, 'Vila-seca', 'Vila-seca', 'Vila-seca,Vilaseca,Vilaseca de Solcina', 41.1111800, 1.1476400, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44041, 'Vilaseca', 'Vilaseca', 'Vila-seka,Vilaseca,Вила-сека', 42.0617400, 2.2552800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44042, 'Vilasantar', 'Vilasantar', 'Santiago,Vilasantar', 43.0666700, -8.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44043, 'Vila-sacra', 'Vila-sacra', 'Vila-sacra', 42.2657800, 3.0183900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44044, 'Vilaplana', 'Vilaplana', 'Vilaplana', 41.2280000, 1.0332500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44045, 'Vilanova de Sau', 'Vilanova de Sau', 'Vilanova de Sau', 41.9470000, 2.3844000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44046, 'Vilanova de Prades', 'Vilanova de Prades', 'Vilanova de Prades', 41.3485000, 0.9566700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44047, 'Vilanova del Camí', 'Vilanova del Cami', 'Vilanova del Cami,Vilanova del Camí', 41.5716500, 1.6375100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44048, 'Vilanova d''Escornalbou', 'Vilanova d''Escornalbou', 'Vilanova d''Escornalbou,Vilanova de Escornalbou', 41.1166700, 0.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44049, 'Vilanova de Bellpuig', 'Vilanova de Bellpuig', 'Vilanova de Bellpuig', 41.6137900, 0.9643200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44050, 'Vilanant', 'Vilanant', 'Vilanant', 42.2547100, 2.8892300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44051, 'Vilamaniscle', 'Vilamaniscle', 'Vilamaniscle', 42.3752200, 3.0675500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44052, 'Vilamalla', 'Vilamalla', 'Vilamalla', 42.2172000, 2.9700900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44053, 'Vilamacolum', 'Vilamacolum', 'Vilamacolum', 42.1961800, 3.0566200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44054, 'Vilajuïga', 'Vilajuiga', 'Vilajuiga,Vilajuïga', 42.3253300, 3.0930200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44055, 'Vilafant', 'Vilafant', 'Vilafant', 42.2466800, 2.9382000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44056, 'Viladrau', 'Viladrau', '', 41.8474600, 2.3901900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44057, 'Viladasens', 'Viladasens', 'Viladasens,Viladesens,Viladeséns', 42.0833300, 2.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44058, 'Vilademuls', 'Vilademuls', 'Vilademuls', 42.1389000, 2.8881900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44059, 'Viladecans', 'Viladecans', 'Biladakans,Viladekans,bi la de kan si,fyladykans,Біладаканс,Виладеканс,فيلاديكانس,比拉德坎斯', 41.3140500, 2.0142700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44060, 'Viladecavalls', 'Viladecavalls', 'Viladecaballs,Viladecavalls', 41.5500000, 1.9500000, 'ES', '2015-09-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44061, 'Vilada', 'Vilada', 'Vilada', 42.1369500, 1.9316200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44062, 'Vilablareix', 'Vilablareix', 'Vilablareix', 41.9574600, 2.7737700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44063, 'Vilabertran', 'Vilabertran', 'Vilabertran', 42.2825500, 2.9814400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44064, 'Vilabella', 'Vilabella', 'Vilabella', 41.2477900, 1.3301900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44065, 'Viguera', 'Viguera', 'Vigera,Viguera,bi ge la,bqyrt,Вигера,Вігера,Վիգերա,بقيرة,比格拉', 42.3093400, -2.5333400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44066, 'Vigo', 'Vigo', 'Bigo,Gorad Viga,VGO,Vigas,Vigo,Vigo shaary,Vigu,bi ko,bigo,bygw,fyghw,vigo,wei ge,wgw,wygw,Βίγο,Виго,Виго шаары,Віго,Горад Віга,Վիգո,ויגו,بیگو,فيغو,وگو,ویگو,वीगो,บีโก,ვიგო,ビーゴ,維戈,비고', 42.2328200, -8.7226400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44067, 'Vierlas', 'Vierlas', 'Vierlas', 41.9270800, -1.6812300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44068, 'Vielha', 'Vielha', 'V''el''ja,Vielha,Vielha e Mijaran,Viella,Viella Mitg Aran,Viella Mitg Arán,Вьелья', 42.7019600, 0.7955600, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44069, 'Vidreres', 'Vidreres', 'Vidreras,Vidreres', 41.7833300, 2.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44070, 'Vidrà', 'Vidra', 'Vidra,Vidrà,Vidrá', 42.1228500, 2.3097700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44071, 'Videmala', 'Videmala', 'Videmala', 41.6129900, -6.0405600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44072, 'Vidayanes', 'Vidayanes', 'Vidayanes', 41.9101100, -5.5742400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44073, 'Vic', 'Vic', 'Vic,a''usa,আউসা', 41.9301200, 2.2548600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44074, 'Vicálvaro', 'Vicalvaro', 'Vicalvaro distritu,Vicálvaro distritu,Vikal''varo,Vikalvaro,bikarubaro,Викальваро,ビカルバロ', 40.4000000, -3.6000000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44075, 'Viandar de la Vera', 'Viandar de la Vera', 'Viandar de la Vera', 40.1219100, -5.5359300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44076, 'Viana de Jadraque', 'Viana de Jadraque', 'Viana de Jadraque', 41.0257700, -2.7696600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44077, 'Viana de Duero', 'Viana de Duero', 'Viana,Viana de Duero,Viana-de-Duehro,Viana-de-Duero,bi ya na de du ai luo,Виана-де-Дуэро,Віана-де-Дуеро,比亚纳德杜埃罗', 41.5340600, -2.4609900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44078, 'Viana de Cega', 'Viana de Cega', '', 41.5292700, -4.7524500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44079, 'Viana', 'Viana', 'Viana', 42.5155200, -2.3712300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44080, 'Vezdemarbán', 'Vezdemarban', 'Vezdemarban,Vezdemarbán', 41.6548000, -5.3660900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44081, 'Vertavillo', 'Vertavillo', 'Vertavillo', 41.8328100, -4.3270700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44082, 'Verín', 'Verin', '', 41.9414900, -7.4380900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44083, 'Verges', 'Verges', '', 42.0628300, 3.0457900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44084, 'Bergara', 'Bergara', 'Bergara,Vergara', 43.1151000, -2.4175000, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44085, 'Verea', 'Verea', 'Santiago', 42.1065300, -8.0009200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44086, 'Verdú', 'Verdu', '', 41.6105700, 1.1428400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44087, 'Vera de Moncayo', 'Vera de Moncayo', 'Vera,Vera de Moncayo', 41.8240000, -1.6879900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44088, 'Bera', 'Bera', 'Bera,Vera,Vera de Bidasoa', 43.2817700, -1.6863200, 'ES', '2012-12-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44089, 'Venturada', 'Venturada', 'Venturada', 40.7971700, -3.6197400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44090, 'Ventrosa', 'Ventrosa', 'Ventrosa', 42.1570500, -2.8504400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44091, 'Ventosa del Río Almar', 'Ventosa del Rio Almar', 'Ventosa del Rio Almar,Ventosa del Río Almar', 40.9272800, -5.3483800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44092, 'Ventosa de la Cuesta', 'Ventosa de la Cuesta', 'Ventosa de la Cuesta', 41.4111000, -4.8293200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44093, 'Ventosa', 'Ventosa', 'Ventosa,ben tuo sa,Вентоса,Վենտոսա,本托萨', 42.4049500, -2.6265100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44094, 'Ventalló', 'Ventallo', 'Ventallo,Ventalló', 42.1492100, 3.0263500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44095, 'Venta de Baños', 'Venta de Banos', 'Venta de Banos,Venta de Baños,Venta-de-Ban''jos,Venta-de-Ban''os,ben ta de wa ni ao si,Вента-де-Баньйос,Вента-де-Баньос,本塔德瓦尼奥斯', 41.9211000, -4.4908900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44096, 'Venialbo', 'Venialbo', 'Venialbo', 41.3895700, -5.5359600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44097, 'El Vendrell', 'El Vendrell', 'El Vendrell,Vendrel'',Vendrell,el Vendrell,Вендрель', 41.2166700, 1.5333300, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44098, 'Velliza', 'Velliza', 'Velliza', 41.5791800, -4.9465500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44099, 'Vellisca', 'Vellisca', 'Vellisca', 40.1296500, -2.8144400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44100, 'Velilla de San Antonio', 'Velilla de San Antonio', 'Velilla de San Antonio', 40.3651600, -3.4848400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44101, 'Velilla del Río Carrión', 'Velilla del Rio Carrion', 'Velil''ja-del''-Rio-Karrion,Velilla de Guardo,Velilla del Rio Carrion,Velilla del Río Carrión,bei li li ya de er li ao ka li weng,Велилья-дель-Рио-Каррион,Велілья-дель-Ріо-Карріон,贝利利亚德尔里奥卡里翁', 42.8261100, -4.8462600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44102, 'Velilla de los Ajos', 'Velilla de los Ajos', 'Velilla de los Ajos', 41.4905800, -2.2557900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44103, 'Velilla de Jiloca', 'Velilla de Jiloca', 'Velilla de Jiloca', 41.2750900, -1.6039600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44104, 'Velilla de Ebro', 'Velilla de Ebro', 'Velilla de Ebro', 41.3741600, -0.4348300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44105, 'Velilla', 'Velilla', 'Velilla', 41.5592000, -5.0045400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44106, 'Velayos', 'Velayos', 'Velayos', 40.8415700, -4.6232400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44107, 'Velascálvaro', 'Velascalvaro', 'Velascalvaro,Velascálvaro', 41.2302800, -4.9724200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44108, 'Velamazán', 'Velamazan', 'Velamasan,Velamazan,Velamazán,Vilamazan,Vilamazán,bei la ma sang,Веламасан,贝拉马桑', 41.4489500, -2.6993500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44109, 'Veguillas de la Sierra', 'Veguillas de la Sierra', 'Veguillas,Veguillas de la Sierra', 40.1500000, -1.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44110, 'Vegas de Matute', 'Vegas de Matute', 'Vegas de Matute', 40.7947600, -4.2776200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44111, 'Vegaquemada', 'Vegaquemada', 'Vegaquemada', 42.8187000, -5.3324200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44112, 'Veganzones', 'Veganzones', 'Beganzones,Veganzones', 41.1930800, -3.9932900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44113, 'Vegalatrave', 'Vegalatrave', 'Vegalatrave', 41.7002600, -6.1067500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44114, 'Vega de Villalobos', 'Vega de Villalobos', 'Vega de Villalobos', 41.9705700, -5.4632400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44115, 'Vega de Valdetronco', 'Vega de Valdetronco', 'Vega de Valdetronco', 41.5936400, -5.1131900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44116, 'Vega de Valcarce', 'Vega de Valcarce', 'A Veiga de Valcarce,Vega de Valcarce,Vega-de-Val''karse,bei jia de wa er ka er sai,Вега-де-Валькарсе,ベガ・デ・バルカルセ,贝加德瓦尔卡尔塞', 42.6606800, -6.9378500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44117, 'Vega de Tirados', 'Vega de Tirados', 'Vega de Tirados', 41.0254300, -5.8866700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44118, 'Vega de Tera', 'Vega de Tera', 'Vega de Tera', 41.9975900, -6.1250000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44119, 'Vega de Santa María', 'Vega de Santa Maria', 'Vega de Santa Maria,Vega de Santa María', 40.8361800, -4.6428700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44120, 'Vega de Ruiponce', 'Vega de Ruiponce', 'Vega de Ruiponce', 42.1880800, -5.1147700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44121, 'Vega de Pas', 'Vega de Pas', 'Vega de Pas,Vega-de-Pas,bei jia de pa si,fyja dy bas,Вега-де-Пас,فيجا دي باس,贝加德帕斯', 43.1569200, -3.7831600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44122, 'Vegadeo', 'Vegadeo', 'A Veiga,Vegadeo,bei jia de ao,bgadyw,fyghadyw,Вегадео,بگادئو,فيغاديو,贝加德奥', 43.4683400, -7.0539000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44123, 'Vega de Infanzones', 'Vega de Infanzones', 'Vega,Vega de Infanzones', 42.4811600, -5.5329500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44124, 'Vega de Espinareda', 'Vega de Espinareda', 'A Veiga de Espinareda,A Veiga de Espiñareda,Vega de Espinareda,Vega del Espinareda,Vega-de-Ehspinareda,Vega-de-Espinareda,bei jia de ai si pi na lei da,Вега-де-Еспінареда,Вега-де-Эспинареда,ベガ・デ・エスピナレーダ,贝加德埃斯皮纳雷达', 42.7253700, -6.6543900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44125, 'Vegacervera', 'Vegacervera', 'Vegacervera', 42.8880800, -5.5354900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44126, 'Vedra', 'Vedra', 'Santa Eulalia,Vedra', 42.7781700, -8.4763600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44127, 'Vecinos', 'Vecinos', 'Vecinos', 40.7787500, -5.8781500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44128, 'Valverdón', 'Valverdon', 'Valverdon,Valverdón', 41.0469100, -5.7695500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44129, 'Valverde-Enrique', 'Valverde-Enrique', 'Valverde-Enrique', 42.3045900, -5.2999000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44130, 'Valverde de Valdelacasa', 'Valverde de Valdelacasa', 'Valverde de Valdelacasa', 40.4815500, -5.7814500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44131, 'Valverde de los Arroyos', 'Valverde de los Arroyos', 'Valverde de los Arroyos', 41.1293000, -3.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44132, 'Valverde del Majano', 'Valverde del Majano', 'Valverde del Majano', 40.9568900, -4.2346800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44133, 'Valverde del Fresno', 'Valverde del Fresno', 'Valverde del Fresno', 40.2221000, -6.8784800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44134, 'Valverde de la Virgen', 'Valverde de la Virgen', 'Val''verde-de-la-Virkhen,Valverde de la Virgen,ba er wei er de de la wei er heng,Вальверде-де-ла-Вирхен,Вальверде-де-ла-Вірхен,巴尔韦尔德德拉维尔亨', 42.5682300, -5.6846100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44135, 'Valverde de la Vera', 'Valverde de la Vera', 'Valverde de la Vera', 40.1226800, -5.4954100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44136, 'Valverde de Campos', 'Valverde de Campos', 'Valverde,Valverde de Campos', 41.8351000, -5.0367400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44137, 'Valverde de Alcalá', 'Valverde de Alcala', 'Valverde de Alcala,Valverde de Alcalá', 40.4166700, -3.2963100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44138, 'Valtorres', 'Valtorres', 'Valtorres', 41.2985500, -1.7408000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44139, 'Valtierra', 'Valtierra', 'Valtierra', 42.1965300, -1.6345900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44140, 'Valtiendas', 'Valtiendas', 'Valtiendas', 41.4785100, -3.9176600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44141, 'Valtajeros', 'Valtajeros', 'Val''takheros,Valtajeros,ba er ta he luo si,Вальтахерос,巴尔塔赫罗斯', 41.9380800, -2.2228900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44142, 'Valtablado del Río', 'Valtablado del Rio', 'Valtablado del Rio,Valtablado del Río', 40.7142000, -2.4022500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44143, 'Valseca', 'Valseca', 'Valseca', 40.9993300, -4.1751400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44144, 'Valsalobre', 'Valsalobre', 'Valsalobre', 40.6174200, -2.0929700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44145, 'Valsalabroso', 'Valsalabroso', 'Valsalabroso', 41.1096200, -6.5026900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44146, 'Valpalmas', 'Valpalmas', 'Valpalmas', 42.1582100, -0.8548100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44147, 'Valoria la Buena', 'Valoria la Buena', 'Valoria,Valoria la Buena,Valoria la Bueno,Viloria la Buena', 41.7996600, -4.5305500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44148, 'Valmojado', 'Valmojado', '', 40.2044400, -4.0914600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44149, 'Balmaseda', 'Balmaseda', 'Balmaseda,Valmaseda', 43.2000000, -3.2000000, 'ES', '2015-09-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44150, 'Valmala', 'Valmala', 'Valmala', 42.3059000, -3.2545600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44151, 'Valmadrid', 'Valmadrid', 'Valmadrid', 41.4435100, -0.8848200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44152, 'Valluércanes', 'Valluercanes', 'Valluercanes,Valluércanes', 42.5722000, -3.1211300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44153, 'Valls', 'Valls', 'Val''s,Valls,Вальс', 41.2861200, 1.2499300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44154, 'Vallromanes', 'Vallromanes', 'Vallromanas,Vallromanes', 41.5333300, 2.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44155, 'Vallmoll', 'Vallmoll', 'Vallmoll', 41.2431100, 1.2490000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44156, 'Vallirana', 'Vallirana', 'Vallirana', 41.3867600, 1.9320500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44157, 'Vallibona', 'Vallibona', 'Vallibana,Vallibona', 40.6030000, 0.0464200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44158, 'Vallgorguina', 'Vallgorguina', 'Vallgorguina', 41.6482200, 2.5099600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44159, 'Vallfogona de Riucorb', 'Vallfogona de Riucorb', 'Val''fogona-de-Riukorb,Valfogona de Riukorb,Vallfogona de Riucorb,Vallfogona de Riucorp,Vallfogona de Ríucorp,ba li fu ge na de liu ke er bu,bayfgna d rywkrb,falfwghwna dy rywkrb,Вальфогона-де-Риукорб,Վալֆոգոնա դե Ռիուկորբ,بایفگنا د ریوکرب,فالفوغونا دي ريوكرب,巴利福戈纳德留科尔布', 41.5628000, 1.2369100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44160, 'Vallfogona de Balaguer', 'Vallfogona de Balaguer', 'Vallfogona de Balaguer', 41.7521100, 0.8138500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44161, 'Valles de Palenzuela', 'Valles de Palenzuela', 'Valles de Palenzuela', 42.1201900, -4.0775000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44162, 'Vallesa de la Guareña', 'Vallesa de la Guarena', 'Vallesa de la Guarena,Vallesa de la Guareña', 41.1353200, -5.3261100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44163, 'Valleruela de Sepúlveda', 'Valleruela de Sepulveda', 'Valleruela de Sepulveda,Valleruela de Sepúlveda', 41.1879400, -3.7727700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44164, 'Valleruela de Pedraza', 'Valleruela de Pedraza', 'Valleruela de Pedraza', 41.1793700, -3.8071700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44165, 'Vallelado', 'Vallelado', 'Vallelado', 41.4043600, -4.4266200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44166, 'Vallejera de Riofrío', 'Vallejera de Riofrio', 'Vallejera de Riofrio,Vallejera de Riofrío', 40.4091000, -5.7194300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44167, 'Valle de Tabladillo', 'Valle de Tabladillo', 'Valle de Tabladillo', 41.3630400, -3.8396600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44168, 'Valle de Cerrato', 'Valle de Cerrato', 'Valle de Cerrato', 41.8804500, -4.3624300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44169, 'Vallecillo', 'Vallecillo', 'Vallecillo', 42.3560400, -5.2108800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44170, 'Vallclara', 'Vallclara', 'Vallclara', 41.3795800, 0.9834200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44171, 'Vallcebre', 'Vallcebre', 'Valcebre,Vallcebre', 42.2034700, 1.8181500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44172, 'Vallbona de les Monges', 'Vallbona de les Monges', 'Vallbona de les Monges', 41.5263100, 1.0887200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44173, 'Vallarta de Bureba', 'Vallarta de Bureba', 'Vallarta de Bureba', 42.5886400, -3.2045700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44174, 'Vallanca', 'Vallanca', 'Vallanca', 40.0666700, -1.3333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44175, 'Valladolid', 'Valladolid', 'Gorad Val''jadalid,Lungsod ng Valladolid,Pincia,Pucela,VLL,Vagiadolid,Val''jadolid,Valadoli,Valadolid,Valadolido,Valdoletum,Valhadolid,Valjadolid,Valjadolida,Valjadolidas,Valladolid,Valladolis,Valladolit,Valladolíd,Valladolís,Vallis Tolitum,Valyadolid,Vayadolid,Vaładołì,ba li ya duo li de,ba ya do lid,baryadoriddo,bayadollideu,bld alwlyd,fayadwlydh,valiadolidi,vayadolida,wayadwlyd,wʼyʼdwlyd,Βαγιαδολίδ,Вальядолид,Вальядолід,Валядолид,Ваљадолид,Горад Вальядалід,ואיאדוליד,بلد الوليد,فايادوليذ,والاڈولڈ,وایادولید,ڤایادۆلید,वायादोलिद,บายาโดลิด,ვალიადოლიდი,バリャドリッド,巴利亚多利德,바야돌리드', 41.6551800, -4.7237200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44176, 'Valjunquera', 'Valjunquera', 'Valjunquera,Valljunquera', 40.9525000, 0.0257500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44177, 'Valhermoso', 'Valhermoso', 'Valhermoso', 40.7859000, -1.9612100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44178, 'Valgañón', 'Valganon', 'Val''gan''jon,Val''gan''on,Valganion,Valganon,Valgañón,ba er jia ni weng,Вальганьйон,Вальганьон,Վալգանիոն,巴尔加尼翁', 42.3178200, -3.0672500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44179, 'Valga', 'Valga', '', 42.6979200, -8.6395900, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44180, 'Valfermoso de Tajuña', 'Valfermoso de Tajuna', 'Valfermoso de Tajuna,Valfermoso de Tajuña', 40.6190200, -2.9540700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44181, 'Valfarta', 'Valfarta', 'Valfarta', 41.5572600, -0.1330400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44182, 'Valero', 'Valero', '', 40.5353300, -5.9430700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44183, 'Valencia de Don Juan', 'Valencia de Don Juan', 'Valencia de Don Juan,Valensija-de-Don-Khuan,ba lun xi ya de dong hu an,Валенсия-де-Дон-Хуан,Валенсія-де-Дон-Хуан,巴伦西亚德东胡安', 42.2937400, -5.5172000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44184, 'Valdunquillo', 'Valdunquillo', 'Valdunquillo', 42.0423200, -5.3133900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44185, 'Valdunciel', 'Valdunciel', 'Valdunciel', 41.0854400, -5.6721700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44186, 'Valdoviño', 'Valdovino', 'Santa Eulalia,Valdovino,Valdoviño', 43.6000000, -8.1333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44187, 'Valdorros', 'Valdorros', 'Valdorros', 42.1723200, -3.7093800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44188, 'Valdilecha', 'Valdilecha', 'Valdilecha', 40.2953000, -3.3023300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44189, 'Valdezate', 'Valdezate', 'Valdezate', 41.6023100, -3.9304500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44190, 'Valdevimbre', 'Valdevimbre', 'Val''devimbre,Valdevimbre,ba er de wen fu lei,Вальдевимбре,Вальдевімбре,巴尔德温夫雷', 42.4195900, -5.6197500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44191, 'Valdevacas de Montejo', 'Valdevacas de Montejo', 'Valdevacas de Montejo', 41.5206800, -3.6357100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44192, 'Valdetorres de Jarama', 'Valdetorres de Jarama', 'Valdetorres de Jarama', 40.6936600, -3.5115600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44193, 'Valdestillas', 'Valdestillas', 'Valdestillas', 41.4769700, -4.7711600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44194, 'Valdesotos', 'Valdesotos', 'Valdesotos', 40.9554600, -3.3254200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44195, 'Valdescorriel', 'Valdescorriel', 'Valdescorriel', 42.0223300, -5.5099800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44196, 'Val de San Martín', 'Val de San Martin', '', 41.0578700, -1.4493400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44197, 'Val de San Lorenzo', 'Val de San Lorenzo', 'Val de San Lorenzo', 42.4181900, -6.1239100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44198, 'Valdesamario', 'Valdesamario', 'Val''desamario,Valdesamario,ba er de sa ma li ao,Вальдесамарио,Вальдесамаріо,巴尔德萨马里奥', 42.7209400, -5.9510400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44199, 'Valderrueda', 'Valderrueda', 'Valderrueda', 42.8155800, -4.9473100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44200, 'Valderrodrigo', 'Valderrodrigo', 'Valderrodrigo', 41.0652400, -6.5087800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44201, 'Valderrodilla', 'Valderrodilla', 'Val''derrodil''ja,Valderrodilla,ba er de luo di li ya,Вальдерродилья,Вальдерроділья,巴尔德罗迪利亚', 41.5634600, -2.8077700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44202, 'Valderrobres', 'Valderrobres', 'Baldecaxicos,Valderrobres,Vall-de-roures,Vallderroures', 40.8720900, 0.1543100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44203, 'Valderrey', 'Valderrey', 'Valderrey', 42.3940800, -6.0215100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44204, 'Valderrebollo', 'Valderrebollo', 'Valderrebollo', 40.8103500, -2.7288700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44205, 'Valderrábano', 'Valderrabano', 'Valderrabano,Valderrábano', 42.6067400, -4.6558400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44206, 'Valderas', 'Valderas', 'Val''deras,Valderas,ba er de la si,waldras,Вальдерас,والدراس,巴尔德拉斯', 42.0783000, -5.4435500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44207, 'Valdeprados', 'Valdeprados', 'Valdeprados', 40.8176600, -4.2573400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44208, 'Valdeprado', 'Valdeprado', 'Valdeprado', 41.9376800, -2.1091500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44209, 'Valdepolo', 'Valdepolo', 'Valdepolo', 42.5768600, -5.2251300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44210, 'Valdepiélagos', 'Valdepielagos', 'Valdepielagos,Valdepiélagos', 40.7584200, -3.4616300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44211, 'Valdepiélago', 'Valdepielago', 'Valdepielago,Valdepiélago', 42.8689500, -5.3976300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44212, 'Valdepeñas de la Sierra', 'Valdepenas de la Sierra', 'Val''depen''jas-de-la-S''erra,Valdepenas de la Sierra,Valdepeñas de la Sierra,ba er de pei ni ya si de la xie la,Вальдепеньяс-де-ла-Сьерра,Вальдепеньяс-де-ла-Сьєрра,巴尔德佩尼亚斯德拉谢拉', 40.9056200, -3.3841400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44213, 'Valdeolmos', 'Valdeolmos', 'Valdeolmos', 40.6370800, -3.4506400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44214, 'Valdeolmillos', 'Valdeolmillos', 'Valdeolmillos', 42.0412300, -4.4001500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44215, 'Valdeolivas', 'Valdeolivas', 'Valdeolivas', 40.5060000, -2.4453200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44216, 'Valdeobispo', 'Valdeobispo', 'Valdeobispo', 40.0829700, -6.2475700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44217, 'Valdenebro de los Valles', 'Valdenebro de los Valles', 'Valdenebro de los Valles', 41.8569000, -4.9700500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44218, 'Valdenebro', 'Valdenebro', 'Valdenebro', 41.5716700, -2.9642400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44219, 'Valdemoro-Sierra', 'Valdemoro-Sierra', 'Valdemoro de la Sierra,Valdemoro-Sierra', 40.1000000, -1.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44220, 'Valdemoro', 'Valdemoro', 'Val''demoro,Valdemoro,Vallis Mauri,ba er de mo luo,fladymwrw,Валдеморо,Вальдеморо,فلاديمورو,巴尔德莫罗', 40.1908100, -3.6788700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44221, 'Valdemorillo de la Sierra', 'Valdemorillo de la Sierra', 'Valdemorillo,Valdemorillo de la Sierra', 40.0333300, -1.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44222, 'Valdemorillo', 'Valdemorillo', 'Valdemorillo', 40.5006400, -4.0671000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44223, 'Valdemora', 'Valdemora', 'Valdemora', 42.1954100, -5.4274700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44224, 'Valdemierque', 'Valdemierque', 'Valdemierque', 40.8217600, -5.5822500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44225, 'Valdemeca', 'Valdemeca', 'Valdemeca', 40.2236700, -1.7435800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44226, 'Valdemaqueda', 'Valdemaqueda', 'Valdemaqueda', 40.5120100, -4.2972200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44227, 'Valdemanco', 'Valdemanco', 'Valdemanco', 40.8703900, -3.6587300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44228, 'Valdemaluque', 'Valdemaluque', 'Val''demaluke,Valdemaluque,ba er de ma lu ke,Вальдемалуке,巴尔德马卢克', 41.6737700, -3.0464300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44229, 'Valdemadera', 'Valdemadera', 'Valdemadera', 41.9840800, -2.0740300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44230, 'Valdeltormo', 'Valdeltormo', 'Valdeltormo,Valldeltormo', 40.9871600, 0.0834200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44231, 'Valdelosa', 'Valdelosa', 'Valdelosa', 41.1715700, -5.7839000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44232, 'Valdelinares', 'Valdelinares', 'Valdelinares', 40.3911400, -0.6059300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44233, 'Valdelcubo', 'Valdelcubo', 'Valdelcubo', 41.2263700, -2.6758800, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44234, 'Valdelagua del Cerro', 'Valdelagua del Cerro', 'Val''delagua-del''-Serro,Val''delagva-del''-Serro,Valdelagua del Cerro,ba er de la gua de er sai luo,baldlagwa dl srw,Вальделагва-дель-Серро,Вальделагуа-дель-Серро,بالدلاگوا دل سرو,巴尔德拉瓜德尔塞罗', 41.8882500, -2.1153800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44235, 'Valdelageve', 'Valdelageve', 'Valdelageve', 40.3694900, -5.9907800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44236, 'Valdelacasa', 'Valdelacasa', 'Valdelacasa', 40.5063100, -5.7635400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44237, 'Valdehorna', 'Valdehorna', '', 41.0727500, -1.4237600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44238, 'Valdehijaderos', 'Valdehijaderos', 'Valdehijaderos', 40.4191600, -5.8479200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44239, 'Valdegrudas', 'Valdegrudas', 'Valdegrudas', 40.7112500, -3.0120900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44240, 'Valdefuentes de Sangusín', 'Valdefuentes de Sangusin', 'Valdefuentes de Sangusin,Valdefuentes de Sangusín', 40.4657800, -5.8328600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44241, 'Valdefuentes del Páramo', 'Valdefuentes del Paramo', 'Valdefuentes del Paramo,Valdefuentes del Páramo', 42.3237000, -5.8309700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44242, 'Valdefresno', 'Valdefresno', 'Val''defresno,Valdefresno,ba er de fu lei si nuo,barudefuresuno,Вальдефресно,バルデフレスノ,巴尔德夫雷斯诺', 42.5949200, -5.4935500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44243, 'Valdefinjas', 'Valdefinjas', 'Valdefinjas', 41.4517200, -5.4523200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44244, 'Valdecuenca', 'Valdecuenca', 'Valdecuenca', 40.2977600, -1.4082900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44245, 'Valdeconcha', 'Valdeconcha', 'Valdeconcha', 40.4564300, -2.8766300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44246, 'Valdecasa', 'Valdecasa', 'Val''dekasa,Valdecasa,Valdekasa,ba er de ka sa,baldkasa,faldykasa,Валдекаса,Вальдекаса,بالدکاسا,فالديكاسا,巴尔德卡萨', 40.6593100, -5.0118300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44247, 'Valdecarros', 'Valdecarros', 'Valdecarros', 40.7700700, -5.4221900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44248, 'Valdeaveruelo', 'Valdeaveruelo', 'Valdeaveruelo', 40.6347300, -3.3136700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44249, 'Valdeavero', 'Valdeavero', 'Valdeavero', 40.6298000, -3.3300100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44250, 'Valdeavellano de Tera', 'Valdeavellano de Tera', 'Valdeavellano de Tera', 41.9422900, -2.5763400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44251, 'Valdeavellano', 'Valdeavellano', 'Valdeavellano', 40.6656000, -2.9697700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44252, 'Valdearenas', 'Valdearenas', 'Valdearenas', 40.8093900, -2.9921800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44253, 'Valdearcos de la Vega', 'Valdearcos de la Vega', 'Valdearcos de la Vega', 41.6426000, -4.0484500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44254, 'Valdeande', 'Valdeande', 'Valdeande', 41.8330200, -3.5279200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44255, 'Valdealgorfa', 'Valdealgorfa', 'Valdealgorfa', 40.9906600, -0.0343300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44256, 'Valdastillas', 'Valdastillas', 'Valdastillas', 40.1329300, -5.8793200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44257, 'Valdarachas', 'Valdarachas', 'Valdarachas', 40.5171000, -3.1265200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44258, 'Valdaracete', 'Valdaracete', 'Valdaracete', 40.2077000, -3.1910100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44259, 'Valcabado', 'Valcabado', 'Valcabado', 41.5486300, -5.7491600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44260, 'Valbuena de Pisuerga', 'Valbuena de Pisuerga', 'Valbuena,Valbuena de Pisuerga', 42.1458400, -4.2401000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44261, 'Valbuena de Duero', 'Valbuena de Duero', 'Valbuena de Duero', 41.6432300, -4.2927100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44262, 'Valbona', 'Valbona', 'Valbona', 40.2287700, -0.8107900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44263, 'Valacloche', 'Valacloche', 'Valacloche', 40.1909200, -1.0913400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44264, 'Vadocondes', 'Vadocondes', 'Vadocondes', 41.6392500, -3.5737800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44265, 'Vadillo de la Sierra', 'Vadillo de la Sierra', 'Vadillo de la Sierra', 40.6063400, -5.1250600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44266, 'Vadillo de la Guareña', 'Vadillo de la Guarena', 'Vadillo de la Guarena,Vadillo de la Guareña', 41.2824200, -5.3530000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44267, 'Vadillo', 'Vadillo', 'Vadillo', 41.7911100, -3.0084500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44268, 'Rivas-Vaciamadrid', 'Rivas-Vaciamadrid', 'Vaciamadrid,Vasiamadrid,Васиамадрид', 40.3260500, -3.5108900, 'ES', '2016-02-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44269, 'Utrillas', 'Utrillas', 'Utrella,Utrillas', 40.8126700, -0.8454500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44270, 'Uterga', 'Uterga', '', 42.7098100, -1.7600400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44271, 'Utebo', 'Utebo', 'Utebo', 41.7082600, -0.9991600, 'ES', '2015-06-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44272, 'Utande', 'Utande', 'Utande', 40.8483200, -2.9277000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44273, 'Usurbil', 'Usurbil', 'Usurbil,Usúrbil', 43.2716400, -2.0491200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44274, 'Used', 'Used', '', 41.0555400, -1.5595400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44275, 'Urzainqui', 'Urzainqui', 'Urzainqui', 42.8302900, -0.9461700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44276, 'Uruñuela', 'Urunuela', 'Urunuela,Uruñuela', 42.4431000, -2.7074900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44277, 'Urueñas', 'Uruenas', 'Uruenas,Urueñas', 41.3558900, -3.7739100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44278, 'Urueña', 'Uruena', 'Uruena,Urueña', 41.7273800, -5.2030400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44279, 'Urriés', 'Urries', '', 42.5194300, -1.1302200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44280, 'Urrea de Jalón', 'Urrea de Jalon', 'Urrea de Jalon,Urrea de Jalón', 41.6671500, -1.2342000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44281, 'Urones de Castroponce', 'Urones de Castroponce', 'Urones de Castroponce', 42.0991100, -5.2822200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44282, 'Urnieta', 'Urnieta', '', 43.2472700, -1.9908400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44283, 'Urdiales del Páramo', 'Urdiales del Paramo', '', 42.3703400, -5.7729700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44284, 'Unzué', 'Unzue', '', 42.6525200, -1.6259800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44285, 'Undués de Lerda', 'Undues de Lerda', '', 42.5657200, -1.1694400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44286, 'Uncastillo', 'Uncastillo', 'Uncastiello,Uncastillo,Unkastil''jo,Unkastil''o,awnkastyw,wen ka si di e,Ункастильо,Ункастільйо,أونكاستيو,温卡斯蒂略', 42.3596300, -1.1284200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44287, 'Uña de Quintana', 'Una de Quintana', 'Una de Quintana,Uña de Quintana', 42.0866200, -6.1447500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44288, 'Uña', 'Una', 'Una,Uña', 40.2241000, -1.9778800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44289, 'Umbrías', 'Umbrias', 'Umbrias,Umbrías', 40.3153000, -5.5803700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44290, 'Ultramort', 'Ultramort', 'Ultramort', 42.0364000, 3.0345500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44291, 'Ullastret', 'Ullastret', 'Ullastret,Ullestret', 42.0000000, 3.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44292, 'Ulldemolins', 'Ulldemolins', 'Ulldemolins', 41.3221600, 0.8765000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44293, 'Ulldecona', 'Ulldecona', '', 40.5973400, 0.4471800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44294, 'Ullastrell', 'Ullastrell', 'Ullastrell', 41.5264300, 1.9553700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44295, 'Ullà', 'Ulla', 'Ulla,Ullà,Ullá', 42.0496400, 3.1075400, 'ES', '2017-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44296, 'Ujué', 'Ujue', 'Ujue,Ujué,Ukhue,Ukhueh,Uxue,Uxué,wu hu ai,Ухуе,Ухуэ,乌胡埃', 42.5000000, -1.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44297, 'Ujados', 'Ujados', 'Ujados', 41.2352600, -3.0048200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44298, 'Ugena', 'Ugena', '', 40.1557200, -3.8760300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44299, 'Ucero', 'Ucero', 'Ucero,Usero,wu sai luo,Усеро,乌塞罗', 41.7168500, -3.0515400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44300, 'Uceda', 'Uceda', 'Uceda', 40.8394400, -3.4604000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44301, 'Tui', 'Tui', 'Tui,Tuy', 42.0471300, -8.6443500, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44302, 'Turégano', 'Turegano', 'Turegano,Turégano', 41.1561000, -4.0069600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44303, 'Turcia', 'Turcia', 'Turcia', 42.5343100, -5.8784400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44304, 'Tulebras', 'Tulebras', 'Tulebras', 41.9769500, -1.6761800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44305, 'Tudelilla', 'Tudelilla', 'Tudelilla', 42.3002300, -2.1174900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44306, 'Tudela de Duero', 'Tudela de Duero', 'Tudela,Tudela de Duera,Tudela de Duero', 41.5845000, -4.5809300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44307, 'Tudela', 'Tudela', 'EEL,Tudela,Тудела', 42.0616600, -1.6045200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44308, 'Tubilla del Lago', 'Tubilla del Lago', 'Tubilla del Lago', 41.8015400, -3.5862500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44309, 'Tubilla del Agua', 'Tubilla del Agua', 'Tubil''ja-del''-Agua,Tubil''ja-del''-Agva,Tubilla del Agua,tu wei li ya de la gua,twbayla dyl aghwa,Тубилья-дель-Агва,Тубілья-дель-Агуа,توبايلا ديل أغوا,图维利亚德拉瓜', 42.7093200, -3.8011600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44310, 'Truchas', 'Truchas', 'Truchas,Trueitas,te lu cha si,Тручас,特鲁查斯', 42.2609300, -6.4360500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44311, 'Tronchón', 'Tronchon', 'Tronchon,Tronchón', 40.6209100, -0.3983300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44312, 'Triollo', 'Triollo', 'Triollo', 42.9245600, -4.6813000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44313, 'Trillo', 'Trillo', 'Tril''jo,Tril''o,Trillo,Trilyo,te li e,Трильо,Трільйо,Տրիլյո,特里略', 40.7008600, -2.5926500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44314, 'Trijueque', 'Trijueque', 'Trijeque,Trijueque', 40.7742600, -2.9925300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44315, 'Trigueros del Valle', 'Trigueros del Valle', 'Trigueros del Valle', 41.8304900, -4.6517900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44316, 'Tricio', 'Tricio', 'Tritium', 42.4022300, -2.7191200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44317, 'Treviana', 'Treviana', 'Treviana', 42.5590100, -3.0503200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44318, 'Tresviso', 'Tresviso', 'Tresviso', 43.2575300, -4.6676800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44319, 'Trespaderne', 'Trespaderne', 'Trespaderne,te lei si pa de er nei,trspadrnh,Треспадерне,ترسپادرنه,特雷斯帕德尔内', 42.8022100, -3.3898900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44320, 'Trescasas', 'Trescasas', 'Trescasas', 40.9644200, -4.0359000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44321, 'Tremp', 'Tremp', 'Tremp', 42.1670300, 0.8948700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44322, 'Tremedal de Tormes', 'Tremedal de Tormes', 'Tremedal de Tormes', 41.0742300, -6.1816400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44323, 'Trefacio', 'Trefacio', 'Trefacio', 42.1216500, -6.6540700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44324, 'Trazo', 'Trazo', 'Santa Maria,Santa María,Trac,Trazo,Traç', 43.0166700, -8.5333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44325, 'Traspinedo', 'Traspinedo', 'Traspinedo', 41.5750900, -4.4756900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44326, 'Trasobares', 'Trasobares', 'Trasobares', 41.6430800, -1.6419200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44327, 'Trasmoz', 'Trasmoz', 'Trasmoz', 41.8259900, -1.7227900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44328, 'Trasmiras', 'Trasmiras', 'Trasmiras', 42.0254000, -7.6173500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44329, 'Tramaced', 'Tramaced', 'Tramaced', 41.9731800, -0.2975200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44330, 'Tramacastilla', 'Tramacastilla', 'Tramacastilla', 40.4305900, -1.5746600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44331, 'Tramacastiel', 'Tramacastiel', 'Tramacastiel', 40.1884200, -1.2408100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44332, 'Traiguera', 'Traiguera', 'Traiguera', 40.5251100, 0.2902300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44333, 'Trabazos', 'Trabazos', 'Trabazos', 41.7479300, -6.4909400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44334, 'Trabanca', 'Trabanca', 'Trabanca', 41.2327800, -6.3848400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44335, 'Trabadelo', 'Trabadelo', 'Trabadelo,te la wa de luo,torabadero,Трабадело,トラバデーロ,特拉瓦德洛', 42.6487400, -6.8800000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44336, 'Trabada', 'Trabada', '', 43.4447500, -7.1952700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44337, 'Touro', 'Touro', 'San Juan,Touro,touro,twarw,twrw,Тоуро,توارو,تورو,トウロ', 42.8681200, -8.3076400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44338, 'Tossa de Mar', 'Tossa de Mar', 'Tossa,Tossa de Mar', 41.7166700, 2.9333300, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44339, 'Tosos', 'Tosos', 'Tosos', 41.3154200, -1.0729200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44340, 'Toses', 'Toses', '', 42.3216200, 2.0158200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44341, 'Tosantos', 'Tosantos', 'Tosantos', 42.4136800, -3.2428600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44342, 'Tortuero', 'Tortuero', 'Tortuera,Tortuero', 40.9341400, -3.3502400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44343, 'Tortuera', 'Tortuera', 'Tortuera', 40.9718100, -1.7976400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44344, 'Tortosa', 'Tortosa', 'Tortosa,Tortoza,Turtoza,to~urutoza,trtwsht,tuo er tuo sa,twrtwsh,Тортоса,Туртоза,טורטוסה,طرطوشة,トゥルトーザ,托尔托萨', 40.8124900, 0.5216000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44345, 'Tórtoles', 'Tortoles', 'Tortoles,Tórtoles', 40.5612000, -5.2612000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44346, 'Tórtola de Henares', 'Tortola de Henares', 'Tortola,Tortola de Henares,Tórtola de Henares', 40.7042500, -3.1231600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44347, 'Torrubia de Soria', 'Torrubia de Soria', 'Torrubia de Soria', 41.6304500, -2.0915100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44348, 'Torrubia', 'Torrubia', 'Torrubia', 40.9658100, -1.9006400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44349, 'Torroella de Montgrí', 'Torroella de Montgri', 'Torroella,Torroella de Montgri,Torroella de Montgrí', 42.0425400, 3.1270300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44350, 'Torroella de Fluvià', 'Torroella de Fluvia', 'Torroella de Fluvia,Torroella de Fluvià', 42.1752200, 3.0402500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44351, 'Torrijo del Campo', 'Torrijo del Campo', 'Torrijo del Campo', 40.8257500, -1.3376600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44352, 'Torrijo de la Cañada', 'Torrijo de la Canada', 'Torrijo,Torrijo de la Canada,Torrijo de la Cañada', 41.4730400, -1.8744100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44353, 'Torrijas', 'Torrijas', 'Torrijas', 40.0166700, -0.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44354, 'Torrevelilla', 'Torrevelilla', 'Torrevelilla,la Torre de Vilella', 40.9020000, -0.1097700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44355, 'Torre Val de San Pedro', 'Torre Val de San Pedro', 'Torre Val de San Pedro', 41.0753400, -3.8711600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44356, 'Torresmenudas', 'Torresmenudas', 'Torresmenudas', 41.1024900, -5.7847500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44357, 'Torres de Segre', 'Torres de Segre', 'Torres de Segre,Torres del Segre', 41.5339900, 0.5142000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44358, 'Torres del Río', 'Torres del Rio', 'Torres del Rio,Torres del Río', 42.5516200, -2.2728500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44359, 'Torres del Carrizal', 'Torres del Carrizal', 'Torres del Carrizal', 41.6170100, -5.6717300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44360, 'Torres de la Alameda', 'Torres de la Alameda', 'Torres de la Alameda', 40.4026400, -3.3576700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44361, 'Torres de Berrellén', 'Torres de Berrellen', 'Torres de Berellen,Torres de Berellén,Torres de Berrellen,Torres de Berrellén', 41.7579700, -1.0655000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44362, 'Torres de Barbués', 'Torres de Barbues', 'Torres de Barbues,Torres de Barbués', 41.9605000, -0.4335000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44363, 'Torres de Alcanadre', 'Torres de Alcanadre', 'Torres de Alcanadre', 41.9672700, -0.1109600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44364, 'Torres de Albarracín', 'Torres de Albarracin', 'Torres de Albarracin,Torres de Albarracín', 40.4270900, -1.5324200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44365, 'Torrescárcela', 'Torrescarcela', 'Torrescarcela,Torrescárcela', 41.4845500, -4.3192000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44366, 'Torresandino', 'Torresandino', 'Torresandino', 41.8292000, -3.9098100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44367, 'Torrent', 'Torrent', '', 41.9524300, 3.1268400, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44368, 'Torremormojón', 'Torremormojon', 'Torremormojon,Torremormojón', 41.9601800, -4.7776500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44369, 'Torremontalbo', 'Torremontalbo', 'Torremontalbo', 42.5000000, -2.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44370, 'Torremochuela', 'Torremochuela', 'Torremochuela', 40.7652800, -1.8419000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44371, 'Torremocha del Pinar', 'Torremocha del Pinar', 'Torremocha del Pinar', 40.8895400, -2.0449700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44372, 'Torremocha del Campo', 'Torremocha del Campo', 'Torremocha del Campo', 40.9781900, -2.6188100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44373, 'Torremocha de Jarama', 'Torremocha de Jarama', 'Torremocha', 40.8414800, -3.4966600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44374, 'Torremocha de Jadraque', 'Torremocha de Jadraque', 'Torremocha de Jadraque', 41.0188100, -2.8991800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44375, 'Torremenga', 'Torremenga', 'Torremenga', 40.0465800, -5.7747100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44376, 'Torre los Negros', 'Torre los Negros', 'Torre los Negros', 40.8530800, -1.0978200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44377, 'Torrelodones', 'Torrelodones', '', 40.5765400, -3.9265800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44378, 'Torrelobatón', 'Torrelobaton', 'Tarrelobaton,Tarrelobatón,Torrelobaton,Torrelobatón', 41.6494200, -5.0252600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44379, 'Torrelles de Llobregat', 'Torrelles de Llobregat', 'Torrellas de Llobregat,Torrelles,Torrelles de Llobregat', 41.3500000, 1.9833300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44380, 'Torrellas', 'Torrellas', 'Torrellas', 41.8944400, -1.7713900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44381, 'Torrelavega', 'Torrelavega', 'Torelavega,Torrelavega,torerabega,tuo lei la wei jia,twrylafyja,Торелавега,Торрелавега,Տոռելավեգա,توريلافيجا,ٹوریلاویگا,トレラベーガ,托雷拉韦加', 43.3494300, -4.0478500, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44382, 'Torrelara', 'Torrelara', 'Torrelara', 42.1667300, -3.5168900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44383, 'Torrelapaja', 'Torrelapaja', 'Torrelapaja', 41.5813300, -1.9518100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44384, 'Torrelaguna', 'Torrelaguna', 'Torrelaguna,tuo lei la gu na,twrylajwna,Торрелагуна,توريلاجونا,托雷拉古纳', 40.8276400, -3.5368300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44385, 'Torrejón de Velasco', 'Torrejon de Velasco', '', 40.1874600, -3.7768100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44386, 'Torrejón del Rey', 'Torrejon del Rey', 'Torrejon,Torrejon del Rey,Torrejón del Rey', 40.6432500, -3.3337600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44387, 'Torrejón de la Calzada', 'Torrejon de la Calzada', 'Torrejon de la Calzada,Torrejón de la Calzada', 40.1988600, -3.7970000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44388, 'Torrejón de Ardoz', 'Torrejon de Ardoz', 'Torechon de Ardosas,Torekhon de Ardos,Torrejon de Ardoz,Torrejón de Ardoz,Torrekhon-de-Ardos,Turricula Ardozensis,tuo lei hong de ya er duo si,Торехон де Ардос,Торрехон-де-Ардос,トレホン・デ・アルドス,托雷洪德亚尔多斯', 40.4553500, -3.4697300, 'ES', '2014-11-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44389, 'Torreiglesias', 'Torreiglesias', 'Torreiglesias', 41.1023600, -4.0328000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44390, 'Torrehermosa', 'Torrehermosa', 'Torrehermosa', 41.2376700, -2.1280000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44391, 'Torregamones', 'Torregamones', 'Torregamones', 41.4870000, -6.1833500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44392, 'Torregalindo', 'Torregalindo', 'Torregalindo', 41.5829900, -3.7522200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44393, 'Torrefarrera', 'Torrefarrera', 'Torrefarrera', 41.6731800, 0.6067100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44394, 'Torre en Cameros', 'Torre en Cameros', 'Torre en Cameros', 42.2413300, -2.5180500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44395, 'Torre de Peñafiel', 'Torre de Penafiel', 'Torre de Penafiel,Torre de Peñafiel', 41.5364600, -4.0883300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44396, 'Torredembarra', 'Torredembarra', 'Torredembara', 41.1450500, 1.3986100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44397, 'Torre del Compte', 'Torre del Compte', 'Torre del Compte,Torre del Comte', 40.9362500, 0.1093400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44398, 'Torre del Burgo', 'Torre del Burgo', 'Torre del Burgo', 40.7917600, -3.0772300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44399, 'Torre del Bierzo', 'Torre del Bierzo', 'Albares,Albares de la Ribera,Torre del Bierzo', 42.6076900, -6.3667500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44400, 'Torre de las Arcas', 'Torre de las Arcas', 'Torre de las Arcas', 40.8416600, -0.7178300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44401, 'Torre de Esgueva', 'Torre de Esgueva', 'Torre de Esgueva', 41.7682100, -4.2000300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44402, 'Torre de Don Miguel', 'Torre de Don Miguel', 'Torre de Don Miguel', 40.2233300, -6.5768600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44403, 'Torre de Arcas', 'Torre de Arcas', 'Torre de Arcas', 40.7513700, -0.0689200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44404, 'Torrecuadradilla', 'Torrecuadradilla', 'Torrecuadradilla', 40.8536400, -2.5321500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44405, 'Torrecuadrada de Molina', 'Torrecuadrada de Molina', 'Torrecuadrada de Molina', 40.7494700, -1.8070700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44406, 'Torrecilla sobre Alesanco', 'Torrecilla sobre Alesanco', 'Torrecilla', 42.4082500, -2.8337900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44407, 'Torrecilla en Cameros', 'Torrecilla en Cameros', 'Toresilia en Kameros,Torreciella en Cameros,Torrecilla de Cameros,Torrecilla en Cameros,Torresil''ja-ehn-Kameros,Torresil''ja-en-Kameros,tuo lei xi li ai en ka mei luo si,Торресилья-эн-Камерос,Торресілья-ен-Камерос,Տոռեսիլիա էն Կամերոս,托雷西利艾恩卡梅罗斯', 42.2553200, -2.6310900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44408, 'Torrecilla del Rebollar', 'Torrecilla del Rebollar', 'Torrecilla del Rebollar', 40.9097800, -1.0724400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44409, 'Torrecilla del Pinar', 'Torrecilla del Pinar', 'Torrecilla del Pinar', 41.3736000, -4.0383800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44410, 'Torrecilla de los Ángeles', 'Torrecilla de los Angeles', 'Torrecilla de los Angeles,Torrecilla de los Ángeles', 40.2478800, -6.4160600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44411, 'Torrecilla del Monte', 'Torrecilla del Monte', 'Torrecilla del Monte', 42.0949000, -3.6935600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44412, 'Torrecilla de la Torre', 'Torrecilla de la Torre', 'Torrecilla de la Torre', 41.6671600, -5.0498200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44413, 'Torrecilla de la Orden', 'Torrecilla de la Orden', 'Torrecilla de la Orden', 41.2188500, -5.2238400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44414, 'Torrecilla de la Abadesa', 'Torrecilla de la Abadesa', 'Torrecilla de la Abadesa', 41.4849800, -5.0876200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44415, 'Torrecilla de Alcañiz', 'Torrecilla de Alcaniz', 'Torrecilla de Alcaniz,Torrecilla de Alcañiz', 40.9605600, -0.0907700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44416, 'Torrechiva', 'Torrechiva', 'Torre-xiva,Torrechiva', 40.0500000, -0.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44417, 'Torrecaballeros', 'Torrecaballeros', 'Torrecaballeros', 40.9921100, -4.0247000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44418, 'Torreblanca', 'Torreblanca', 'Torreblanca', 40.2203300, 0.1965000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44419, 'Torreblacos', 'Torreblacos', 'Torreblacos', 41.6692700, -2.8788100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44420, 'Torrebesses', 'Torrebesses', 'Torrebeses,Torrebesses', 41.4333300, 0.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44421, 'Torreadrada', 'Torreadrada', 'Torreadrada', 41.4447400, -3.8400000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44422, 'Torralbilla', 'Torralbilla', 'Torralbilla', 41.2100900, -1.3380000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44423, 'Torralba de Ribota', 'Torralba de Ribota', 'Torralba de Ribota', 41.4180300, -1.6842900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44424, 'Torralba de los Sisones', 'Torralba de los Sisones', 'Torralba de los Sisones', 40.8908400, -1.4586600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44425, 'Torralba de los Frailes', 'Torralba de los Frailes', 'Torralba de los Frailes', 41.0362200, -1.6604600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44426, 'Torralba de Aragón', 'Torralba de Aragon', 'Torralba de Aragon,Torralba de Aragón', 41.9348700, -0.5105300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44427, 'Torralba', 'Torralba', 'Torralba', 40.3025300, -2.2854600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44428, 'Torquemada', 'Torquemada', 'Torquemada', 42.0349000, -4.3184100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44429, 'Toro', 'Toro', 'Toro,Toro  Zamora', 41.5241700, -5.3953400, 'ES', '2014-07-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44430, 'Tornos', 'Tornos', '', 40.9618800, -1.4338900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44431, 'Tornavacas', 'Tornavacas', 'Tornavacas', 40.2549800, -5.6887600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44432, 'Tornadizos de Ávila', 'Tornadizos de Avila', '', 40.6275700, -4.6142600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44433, 'Tornabous', 'Tornabous', 'Tornabous', 41.7011700, 1.0538400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44434, 'Tormón', 'Tormon', 'Tormon,Tormón', 40.2026600, -1.3540600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44435, 'Tormellas', 'Tormellas', 'Tormellas', 40.3040400, -5.5118500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44436, 'Tormantos', 'Tormantos', '', 42.4943100, -3.0744600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44437, 'Torlengua', 'Torlengua', 'Torlengua', 41.4548300, -2.1618300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44438, 'Torija', 'Torija', 'Torija', 40.7425100, -3.0283000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44439, 'Toreno', 'Toreno', 'Toreno,Torenu,tuo lei nuo,Торено,托雷诺', 42.6995500, -6.5123600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44440, 'Torelló', 'Torello', 'Torel''o,Torello,Torelló,tuo lei e,twrylw,Торельо,توريلو,托雷略', 42.0462700, 2.2667900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44441, 'Tordómar', 'Tordomar', 'Tordomar,Tordómar', 42.0463000, -3.8651400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44442, 'Tordillos', 'Tordillos', 'Tordillos', 40.8526600, -5.3527800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44443, 'Tordesilos', 'Tordesilos', 'Tordesilos', 40.6707400, -1.5937200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44444, 'Tordesillas', 'Tordesillas', 'Tordesil''jas,Tordesilas,Tordesilhas,Tordesillas,toleudesiyaseu,torudeshiryasu,tuo er de xi li ya si,Тордесильяс,Тордесиљас,Тордесільяс,トルデシリャス,托尔德西利亚斯,토르데시야스', 41.5020200, -5.0014600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44445, 'Tordera', 'Tordera', 'Tordera', 41.6991400, 2.7188800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44446, 'Tordelrábano', 'Tordelrabano', 'Tordelrabano,Tordelrábano', 41.2182700, -2.7579200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44447, 'Tordellego', 'Tordellego', 'Tordellego', 40.7216500, -1.6703600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44448, 'Tordehumos', 'Tordehumos', 'Tordehumos', 41.8153100, -5.1581100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44449, 'Toral de los Guzmanes', 'Toral de los Guzmanes', 'Toral de los Guzmanes', 42.2427400, -5.5677100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44450, 'Torà de Riubregós', 'Tora de Riubregos', 'Tora,Tora de Rulbregos,Torá,Torá de Rulbregos', 41.8166700, 1.4000000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44451, 'Topas', 'Topas', 'Topas', 41.1575900, -5.6340200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44452, 'Tona', 'Tona', 'Tona', 41.8478900, 2.2280800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44453, 'Tomiño', 'Tomino', 'Santa Maria,Santa María,Tomino,Tomiño', 41.9877200, -8.7550200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44454, 'Tolosa', 'Tolosa', 'Tolosa', 43.1348400, -2.0780100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44455, 'Toloriu', 'Toloriu', '', 42.3621000, 1.6276100, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44456, 'Tolocirio', 'Tolocirio', 'Tolocirio', 41.1342500, -4.6512100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44457, 'Tolbaños', 'Tolbanos', 'Tolbanos,Tolbaños', 40.7516800, -4.5819100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44458, 'Toga', 'Toga', 'Toga', 40.0500000, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44459, 'Toén', 'Toen', 'Toen,Toén', 42.3176500, -7.9543500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44460, 'Todolella', 'Todolella', 'Todolella', 40.6467500, -0.2467500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44461, 'Tobía', 'Tobia', 'Tobia,Tobía', 42.2984600, -2.8139900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44462, 'Tobed', 'Tobed', 'Tobed', 41.3386600, -1.3997500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44463, 'Tobar', 'Tobar', '', 42.4838400, -3.9398400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44464, 'Tivissa', 'Tivissa', 'Tivisa,Tivissa', 41.0333300, 0.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44465, 'Tivenys', 'Tivenys', 'Tivenys', 40.9078700, 0.5123600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44466, 'Tiurana', 'Tiurana', 'Tiurana', 41.9752700, 1.2560800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44467, 'Titulcia', 'Titulcia', 'Titulcia', 40.1353700, -3.5676300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44468, 'Tirgo', 'Tirgo', 'Tirgo,di er ge,Тирго,Тірго,Տիրգո,蒂尔戈', 42.5458700, -2.9494000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44469, 'Tirapu', 'Tirapu', 'Tirapu', 42.6574000, -1.7026300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44470, 'Tiñosillos', 'Tinosillos', 'Tinosillos,Tiñosillos', 40.9340000, -4.7276700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44471, 'Tineo', 'Tineo', 'Tineo,Tineu,Tinéu,di nei ao,tynyw,Тинео,Тінео,تينيو,تینئو,蒂内奥', 43.3376500, -6.4145200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44472, 'Tinajas', 'Tinajas', 'Tinajas', 40.3254700, -2.5822800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44473, 'Tierzo', 'Tierzo', 'Tierzo', 40.7492500, -1.9306900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44474, 'Tierz', 'Tierz', 'Tierz', 42.1335600, -0.3548900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44475, 'Tielmes', 'Tielmes', '', 40.2465200, -3.3146100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44476, 'Tiedra', 'Tiedra', 'Tiedra', 41.6523900, -5.2668800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44477, 'Tiana', 'Tiana', 'Tiana', 41.4820100, 2.2670200, 'ES', '2015-05-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44478, 'Teià', 'Teia', 'Teia,Teià', 41.4980400, 2.3220600, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44479, 'Tetuán de las Victorias', 'Tetuan de las Victorias', 'Tetuan,Tetuan de las Victorias,Tetuán,Tetuán de las Victorias', 40.4597500, -3.6975000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44480, 'Terzaga', 'Terzaga', 'Terzaga', 40.6950800, -1.9038600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44481, 'Teruel', 'Teruel', 'Gorad Tehruehl'',Provincia Terulium,TEJ,TEV,Tergueel,Tergüel,Terol,Teruehl'',Teruel,Teruel'',Teruelis,Teruelo,Terulium,Teròl,te lu ai er,teluel,terueru,trwyl,tyrwal,tyrwyl,Горад Тэруэль,Теруел,Теруель,Теруэль,تروئل,تيروال,تیرویل,ტერუელი,テルエル,特鲁埃尔,테루엘', 40.3456000, -1.1064600, 'ES', '2015-12-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44482, 'Terroba', 'Terroba', 'Terroba', 42.2580900, -2.4437500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44483, 'Terriente', 'Terriente', 'Terriente', 40.2974100, -1.5039900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44484, 'Terrer', 'Terrer', 'Terrer', 41.3281100, -1.7132900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44485, 'Terradillos de Esgueva', 'Terradillos de Esgueva', 'Terradillos de Esgueva', 41.8188500, -3.8431800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44486, 'Terradillos', 'Terradillos', 'Terradillos', 40.8383600, -5.5416000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44487, 'Terrades', 'Terrades', 'Terrades', 42.3103200, 2.8385500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44488, 'Térmens', 'Termens', 'Termens,Térmens', 41.7166700, 0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44489, 'Teo', 'Teo', 'Santa Maria,Santa María,Teo', 42.7500000, -8.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44490, 'Tenebrón', 'Tenebron', 'El Tenebron,Tenebron,Tenebrono,Tenebrón,Tenebróno', 40.6244900, -6.3545000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44491, 'Tendilla', 'Tendilla', 'Tendilla', 40.5437900, -2.9578200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44492, 'Tejeda y Segoyuela', 'Tejeda y Segoyuela', 'Tejeda y Segoyuela', 40.6315500, -6.0231100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44493, 'Tejeda de Tiétar', 'Tejeda de Tietar', 'Tejeda de Tietar,Tejeda de Tiétar', 40.0179000, -5.8695300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44494, 'Tejado', 'Tejado', 'Tejado,Tekhado,te ha duo,Техадо,特哈多', 41.5888700, -2.2672100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44495, 'Tejadillos', 'Tejadillos', 'Tejadillos', 40.1333300, -1.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44496, 'Tejada', 'Tejada', 'Tejada', 41.9524900, -3.5351400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44497, 'Tavertet', 'Tavertet', 'Tavertet', 41.9957200, 2.4185900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44498, 'Tauste', 'Tauste', 'Deustia,Tauest,Taust,Tauste,Taüst,tao si te,tawsty,Таусте,تاوستي,陶斯特', 41.9180400, -1.2534300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44499, 'Tartanedo', 'Tartanedo', 'Tartanedo', 40.9934700, -1.9245900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44500, 'Tàrrega', 'Tarrega', 'Tarrega,Tàrrega', 41.6470400, 1.1395700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44501, 'Terrassa', 'Terrassa', 'Terasa,Terrassa,telasa,terrasa,Τεράσα,Террасса,テッラーサ,테라사', 41.5666700, 2.0166700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44502, 'Tarragona', 'Tarragona', 'QGN,Taragono,Tarraco,Tarrago,Tarragona,Tarragone,taragona,taragwna,trgwnh,Таррагона,טרגונה,تاراگونا,タラゴナ', 41.1166700, 1.2500000, 'ES', '2010-08-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44503, 'Taroda', 'Taroda', 'Taroda', 41.3479800, -2.4331800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44504, 'Tardienta', 'Tardienta', 'Tardienta', 41.9778100, -0.5373100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44505, 'Tardelcuende', 'Tardelcuende', 'Tardel''kuehnde,Tardel''kuende,Tardelcuende,ta er de er kun de,Тарделькуенде,Тарделькуэнде,塔尔德尔昆德', 41.5940200, -2.6443900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44506, 'Tardajos', 'Tardajos', 'Tardajos', 42.3490900, -3.8170000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44507, 'Tardáguila', 'Tardaguila', 'Tardaguila,Tardáguila', 41.1149300, -5.5742300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44508, 'Tarazona de Guareña', 'Tarazona de Guarena', 'Taracena de Guarena,Taracena de Guareña,Tarazona,Tarazona de Guarena,Tarazona de Guareña,Tarazona de la Guarena,Tarazona de la Guareña', 41.1720600, -5.2500500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44509, 'Tarazona', 'Tarazona', 'Taracona,Tarasona,Tarassona,Tarazona,Tarazona de Aragon,Tarazona de Aragón,Taraçona,Turiasso,ta la suo na,tarasona,tarathwna,Тарасона,تاراثونا,タラソナ,塔拉索纳', 41.9047500, -1.7267800, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44510, 'Taravilla', 'Taravilla', 'Taravilla', 40.6974300, -1.9681700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44511, 'Tarancón', 'Tarancon', 'Tarancon,Tarancón,Tarankon,ta lan kong,tarankwn,Таранкон,تارانكون,塔兰孔', 40.0085100, -3.0073100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44512, 'Taramundi', 'Taramundi', 'Taramundi,ta la meng di,taramwndy,Тарамунди,Тарамунді,تاراموندي,تاراموندی,塔拉蒙迪', 43.3602000, -7.1082800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44513, 'Taragudo', 'Taragudo', 'Taragudo', 40.8210600, -3.0768000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44514, 'Taradell', 'Taradell', 'Taradell', 41.8749500, 2.2866200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44515, 'Tapioles', 'Tapioles', 'Tapioles', 41.8574100, -5.4962300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44516, 'Tapia de Casariego', 'Tapia de Casariego', 'Tapia,Tapia-de-Kasar''ego,Tapija-de-Kasarego,ta pi ya de ka sa lie ge,tabya dy kasaryyghw,tapya d kasarygw,Тапиа-де-Касарьего,Тапія-де-Касарєго,تابيا دي كاسارييغو,تاپیا د کاساریگو,塔皮亚德卡萨列戈', 43.5701900, -6.9438300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44517, 'Tamarón', 'Tamaron', 'Tamaron,Tamarón', 42.2738600, -3.9915400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44518, 'Tamariz de Campos', 'Tamariz de Campos', 'Tamariz,Tamariz de Campos', 41.9770600, -5.0233500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44519, 'Tamarit de Llitera / Tamarite de Litera', 'Tamarit de Llitera / Tamarite de Litera', 'Tamarit de Litera,Tamarit de Llitera,Tamarit de Llitera / Tamarite de Litera,Tamarite de Litera', 41.8691000, 0.4221400, 'ES', '2007-02-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44520, 'Tamames', 'Tamames', 'Tamames', 40.6572500, -6.1053600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44521, 'Tamajón', 'Tamajon', 'Tamajon,Tamajón,Tamakhon,ta ma hong,Тамахон,塔马洪', 40.9991400, -3.2474300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44522, 'Talamantes', 'Talamantes', 'Talamantes', 41.7305100, -1.6785700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44523, 'Talamanca de Jarama', 'Talamanca de Jarama', 'Talamanca de Jarama,Talamanka de Xarama,Talamanka-de-Kharama,Talamanko de Haramo,Talamanko de Ĥaramo,ha la ma he pan ta la man ka,talamanka dy jarama,Таламанка-де-Харама,Տալամանկա դե Խարամա,تالامانكا دي جاراما,哈拉马河畔塔拉曼卡', 40.7432500, -3.5088900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44524, 'Talamanca', 'Talamanca', 'Talamanca', 41.7374000, 1.9779100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44525, 'Tajueco', 'Tajueco', 'Tajueco', 41.5364100, -2.8484500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44526, 'Tajahuerce', 'Tajahuerce', 'Tajahuerce', 41.7399100, -2.1506900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44527, 'Tagamanent', 'Tagamanent', 'Tagamanent', 41.7374700, 2.2672000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44528, 'Tafalla', 'Tafalla', 'Tafal''ja,Tafalla,Tubalia,ta fa li ya,tafarya,Тафалья,ታፋላ,タファリャ,塔法利亚', 42.5268700, -1.6744600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44529, 'Tabuenca', 'Tabuenca', 'Tabuenca', 41.6950000, -1.5433500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44530, 'Taboadela', 'Taboadela', 'Taboadela', 42.2423400, -7.8271900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44531, 'Taboada', 'Taboada', '', 42.6990000, -7.8229800, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44532, 'Tabera de Abajo', 'Tabera de Abajo', 'Tabera de Abajo', 40.9102100, -6.0022700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44533, 'Tábara', 'Tabara', 'Tabara,Tábara,ta wa la,Табара,塔瓦拉', 41.8245800, -5.9642000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44534, 'Tabanera la Luenga', 'Tabanera la Luenga', 'Tabanera la Luenga', 41.0964700, -4.2393700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44535, 'Tabanera de Valdavia', 'Tabanera de Valdavia', 'Tabanera de Valdavia', 42.6472800, -4.6941400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44536, 'Tabanera de Cerrato', 'Tabanera de Cerrato', 'Tabanera de Cerrato', 42.0246900, -4.1236100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44537, 'Susqueda', 'Susqueda', 'Suskeda,Susqueda,su si ke da,swskda,swskyda,Сускеда,Սուսկեդա,سوسكيدا,سوسکدا,苏斯克达', 41.9777600, 2.5165200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44538, 'Susinos del Páramo', 'Susinos del Paramo', '', 42.4710800, -3.9255500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44539, 'Súria', 'Suria', 'Suria,Súria', 41.8333300, 1.7500000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44540, 'Sunyer', 'Sunyer', 'Sune,Sunyer,Suñé', 41.5166700, 0.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44541, 'Sunbilla', 'Sunbilla', 'Sumbilla,Sunbilla', 43.1666700, -1.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44542, 'Suellacabras', 'Suellacabras', 'Suehl''jakabras,Suel''jakabras,Suellacabras,su ai li ya ka fu la si,Суельякабрас,Суэльякабрас,苏埃利亚卡夫拉斯', 41.8529800, -2.2239800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44543, 'Subirats', 'Subirats', 'Subirats', 41.4000000, 1.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44544, 'Suances', 'Suances', 'Suances', 43.4334100, -4.0433800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44545, 'Sotresgudo', 'Sotresgudo', 'Sotresgudo', 42.5793500, -4.1772500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44546, 'Sotragero', 'Sotragero', '', 42.4099600, -3.7131200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44547, 'Soto y Amío', 'Soto y Amio', 'Soto y Amio,Soto y Amío', 42.7747700, -5.8869300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44548, 'Sotoserrano', 'Sotoserrano', 'Sotoserrano,suo tuo sai la nuo,Сотосеррано,索托塞拉诺', 40.4349900, -6.0326100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44549, 'Sotosalbos', 'Sotosalbos', 'Sotosalbos,Sotosalvos', 41.0353700, -3.9411500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44550, 'Soto en Cameros', 'Soto en Cameros', 'Soto en Cameros,Soto en Kameros,Soto-ehn-Kameros,Soto-en-Kameros,suo tuo en ka mei luo si,Сото-ен-Камерос,Сото-эн-Камерос,Սոտո էն Կամերոս,索托恩卡梅罗斯', 42.2859100, -2.4259700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44551, 'Sotodosos', 'Sotodosos', 'Sotodosos', 40.9214900, -2.3921100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44552, 'Soto del Barco', 'Soto del Barco', 'San Pedro,Soto,Soto del Barco,Soto-del''-Barko,Sotu''l Barcu,Sotul Barcu,stw dl barkw,suo tuo de er wa er ke,swtw dyl barkw,Сото-дель-Барко,ستو دل بارکو,سوتو ديل باركو,索托德尔瓦尔科', 43.5328800, -6.0698400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44553, 'Soto de la Vega', 'Soto de la Vega', 'Soto de la Vega', 42.3322700, -5.8822500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44554, 'Soto de Cerrato', 'Soto de Cerrato', 'Soto de Cerrato', 41.9531200, -4.4299800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44555, 'Sotobañado y Priorato', 'Sotobanado y Priorato', 'Sotobanado y Priorato,Sotobañado y Priorato', 42.5898700, -4.4418500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44556, 'Sotillo del Rincón', 'Sotillo del Rincon', 'Sotillo del Rincon,Sotillo del Rincón', 41.9322000, -2.6029700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44557, 'Sotillo de las Palomas', 'Sotillo de las Palomas', 'Sotillo de las Palomas', 40.1035900, -4.8273600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44558, 'Sotillo de la Ribera', 'Sotillo de la Ribera', 'Sotillo de la Ribera,Sotillo de la Rivera', 41.7771700, -3.8252500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44559, 'Sotillo de la Adrada', 'Sotillo de la Adrada', 'Sotil''jo-de-la-Adrada,Sotil''o-de-la-Adrada,Sotillo de la Adrada,Sotilo de la Adrada,styyw d la adrada,suo di e de la de la da,swtyw dy la adrada,Сотило де ла Адрада,Сотильо-де-ла-Адрада,Сотільйо-де-ла-Адрада,ستییو د لا آدرادا,سوتيو دي لا أدرادا,索蒂略德拉德拉达', 40.2912000, -4.5838500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44560, 'Sotillo', 'Sotillo', 'Sotillo', 41.2584600, -3.6372900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44561, 'Sotalbo', 'Sotalbo', 'Sota Albo,Sotalbo,Sotalvo', 40.5417000, -4.8454800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44562, 'Soses', 'Soses', '', 41.5333300, 0.4833300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44563, 'Sos del Rey Católico', 'Sos del Rey Catolico', 'Sause,Sos,Sos del Rey Catolico,Sos del Rey Católico', 42.4968600, -1.2151400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44564, 'Sorzano', 'Sorzano', 'Sorzano', 42.3430700, -2.5287200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44565, 'Sort', 'Sort', 'Sor,Sort,suo er te,Σορτ,Сор,Сорт,Սորտ,索尔特', 42.4131900, 1.1304500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44566, 'Sorlada', 'Sorlada', 'Sorlada', 42.6150700, -2.2152500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44567, 'Sorihuela', 'Sorihuela', 'Sorihuela', 40.4437800, -5.6781800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44568, 'Soria', 'Soria', 'Gorad Soryja,Soria,Sorija,Sorio,Soriya,Sòria,Sória,XJO,solia,soria,srya,suo li ya,swryh,Горад Сорыя,Сория,Сорија,Сорія,סוריה,سریا,ソリア,索里亚,소리아', 41.7640100, -2.4688300, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44569, 'Sordillos', 'Sordillos', 'Sordillos', 42.4619700, -4.1072600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44570, 'Sora', 'Sora', 'Sora', 42.1123600, 2.1608300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44571, 'Sopela', 'Sopela', 'Sopela,Sopelana', 43.3789100, -2.9831300, 'ES', '2014-08-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44572, 'Porto do Son', 'Porto do Son', 'Son', 42.7248200, -9.0052700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44573, 'Somozas', 'Somozas', 'Santiago Sere,Santiago Seré,Somozas', 43.5333300, -7.9333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44574, 'Somosierra', 'Somosierra', 'Somosierra', 41.1326900, -3.5823700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44575, 'Somolinos', 'Somolinos', '', 41.2460600, -3.0600400, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44576, 'Solsona', 'Solsona', 'Solsona', 41.9939500, 1.5170600, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44577, 'Solosancho', 'Solosancho', 'Solosancho,slsanchw,suo luo sang qiao,swlwsantshw,Солосанчо,سلسانچو,سولوسانتشو,索洛桑乔', 40.5529400, -4.9047900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44578, 'Solórzano', 'Solorzano', 'Solorzano,Solórzano', 43.3823300, -3.5878500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44579, 'Soliedra', 'Soliedra', 'Soliedra', 41.4693200, -2.3816400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44580, 'Solarana', 'Solarana', 'Solarana', 41.9716800, -3.6587600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44581, 'Solanillos del Extremo', 'Solanillos del Extremo', 'Solanillos del Extremo', 40.7508800, -2.6979900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44582, 'Sojuela', 'Sojuela', 'Sojuela', 42.3698800, -2.5452500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44583, 'Sobrado', 'Sobrado', 'Sobrado', 43.0388200, -8.0278400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44584, 'Sobrado', 'Sobrado', '', 42.5166700, -6.8500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44585, 'Sobradillo', 'Sobradillo', 'Sobradillo', 40.9175400, -6.7972900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44586, 'Sobradiel', 'Sobradiel', 'Sobradiel', 41.7387500, -1.0376500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44587, 'Sober', 'Sober', 'Vello', 42.4612700, -7.5864000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44588, 'Sitges', 'Sitges', 'Sitges,Sitzhes,Ситжес', 41.2350600, 1.8119300, 'ES', '2013-03-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44589, 'Sisamón', 'Sisamon', 'Sisamon,Sisamón', 41.1712400, -2.0038600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44590, 'Sinlabajos', 'Sinlabajos', 'Sinlabajos', 41.0765000, -4.8324200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44591, 'Singra', 'Singra', 'Singra', 40.6550800, -1.3115800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44592, 'Simancas', 'Simancas', 'Simancas', 41.5907200, -4.8279600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44593, 'Sils', 'Sils', 'Sils', 41.8084200, 2.7450700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44594, 'Silleda', 'Silleda', 'Silleda,Sillede', 42.6960500, -8.2465300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44595, 'Sigüés', 'Siguees', 'Siguehs,Sigues,Zigoze,syghwys,xi ge si,Сигуэс,Сігуес,سيغويس,西格斯', 42.6303000, -1.0121200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44596, 'Sigüenza', 'Siguenza', 'Segontia,Sigueenza,Siguehnsa,Siguensa,Siguenza,Sigvenco,Sigüenza,shiguensa,xi gong sa,Сигуэнса,Сігуенса,シグエンサ,西贡萨', 41.0689200, -2.6430800, 'ES', '2013-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44597, 'Sigeres', 'Sigeres', 'Sigeres', 40.7993900, -4.9336100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44598, 'Siete Iglesias de Trabancos', 'Siete Iglesias de Trabancos', 'Siete Iglesias,Siete Iglesias de Trabancos', 41.3522300, -5.1848800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44599, 'Siétamo', 'Sietamo', 'Sietamo,Sietemo,Siétamo', 42.1239200, -0.2806600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44600, 'Sierra-Engarcerán', 'Sierra-Engarceran', 'Sierra-Engarceran,Sierra-Engarcerán', 40.2692900, -0.0189200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44601, 'Sierra de Luna', 'Sierra de Luna', 'Sierra de Luna', 42.0481800, -0.9102500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44602, 'Sienes', 'Sienes', 'Sienes', 41.2009600, -2.6533200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44603, 'Sidamon', 'Sidamon', 'Sidamon,Sidamunt', 41.6333300, 0.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44604, 'Sevilla La Nueva', 'Sevilla La Nueva', 'Sevilla La Nueva', 40.3477500, -4.0272700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44605, 'Seva', 'Seva', 'Seva', 41.8383100, 2.2800700, 'ES', '2014-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44606, 'Setiles', 'Setiles', 'Setiles', 40.7341900, -1.6172000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44607, 'Sesué', 'Sesue', 'Sesue,Sesué', 42.5513100, 0.4721200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44608, 'Sestrica', 'Sestrica', 'Sestrica', 41.4859500, -1.5950100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44609, 'Sestao', 'Sestao', 'Sestao,sai si tao,systaw,Сестао,سيستاو,塞斯陶', 43.3097500, -3.0071600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44610, 'Sesma', 'Sesma', 'Sesma', 42.4774800, -2.0835300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44611, 'Seseña', 'Sesena', '', 40.1047300, -3.6979300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44612, 'Sesa', 'Sesa', 'Sesa', 41.9948400, -0.2451100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44613, 'Serranillos del Valle', 'Serranillos del Valle', 'Serranillos,Serranillos del Valle', 40.2021100, -3.8818700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44614, 'Serranillos', 'Serranillos', 'Serranillos', 40.3362500, -4.9116500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44615, 'Serradilla del Llano', 'Serradilla del Llano', 'Serradilla del Llano', 40.4999600, -6.3570100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44616, 'Serradilla del Arroyo', 'Serradilla del Arroyo', 'Serradilla del Arroyo', 40.5213300, -6.3600800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44617, 'Serra de Daró', 'Serra de Daro', '', 42.0287700, 3.0722200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44618, 'Serrada', 'Serrada', 'Serrada', 41.4572200, -4.8627900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44619, 'Seròs', 'Seros', 'Seros,Seròs,Serós', 41.4666700, 0.4166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44620, 'Sequeros', 'Sequeros', 'Sequeros', 40.5129500, -6.0249500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44621, 'Sequera de Fresno', 'Sequera de Fresno', 'Sequera de Fresno', 41.3664000, -3.5461200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44622, 'Sepúlveda', 'Sepulveda', 'Sepulveda,Sepúlveda,Valleruca de Sepulveda', 41.2969500, -3.7422100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44623, 'la Seu d''Urgell', 'la Seu d''Urgell', 'LEU,La Seo d''Urgel,La Seo de Urgel,La Seu d''Urgell,La Seu de Urgell,Orgellis civitas,Orgellum,Seo de Urgel,Urgelitana sedes,Urgellum,la Seu d''Urgell', 42.3587700, 1.4614400, 'ES', '2017-01-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44624, 'Seno', 'Seno', 'Seno', 40.8122500, -0.3381600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44625, 'Sentmenat', 'Sentmenat', 'Sentmenat', 41.6086200, 2.1353200, 'ES', '2011-10-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44626, 'Senés de Alcubierre', 'Senes de Alcubierre', 'Senes de Alcubierre,Senés de Alcubierre', 41.9073100, -0.4890600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44627, 'Senan', 'Senan', 'Senan,Senant', 41.4699400, 1.0854100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44628, 'Sena de Luna', 'Sena de Luna', 'Sena de Luna', 42.9290600, -5.9526700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44629, 'Semillas', 'Semillas', 'Semillas', 41.0585700, -3.1194500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44630, 'Selaya', 'Selaya', 'Selaya', 43.2137600, -3.8056300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44631, 'Selas', 'Selas', 'Selas', 40.9515000, -2.1020300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44632, 'Seira', 'Seira', 'Seira', 42.4769600, 0.4312700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44633, 'Segurilla', 'Segurilla', 'Segurilla', 40.0238600, -4.8641800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44634, 'Segura de Toro', 'Segura de Toro', 'Segura de Toro', 40.2242700, -5.9483600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44635, 'Segura de los Baños', 'Segura de los Banos', 'Segura de los Banos,Segura de los Baños', 40.9408800, -0.9511100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44636, 'Segura', 'Segura', 'Segura', 43.0075300, -2.2540000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44637, 'Segovia', 'Segovia', 'Gorad Segovija,Segovia,Segovie,Segovija,Segovio,Segowia,Segòvia,Segóvia,Segóvía,Senkovia,Ségovie,XOU,sai ge wei ya,se ko beiy,segobia,segovi''a,segovia,sgwbya,sgwbyh,shqwbyt,syjwvya,Σεγκόβια,Горад Сеговія,Сеговия,Сеговија,Сеговія,סגוביה,سيجوڤيا,سگوبیا,شقوبية,सेगोविआ,เซโกเบีย,სეგოვია,セゴビア,塞哥维亚,세고비아', 40.9480800, -4.1183900, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44638, 'Sediles', 'Sediles', 'Sediles', 41.3461300, -1.5317700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44639, 'Secastilla', 'Secastilla', 'Secastilla', 42.1811200, 0.2673600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44640, 'Sebúlcor', 'Sebulcor', 'Sebulcor,Sebúlcor', 41.2709100, -3.8839800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44641, 'Sayatón', 'Sayaton', 'Sayaton,Sayatón', 40.3763500, -2.8525300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44642, 'Sauquillo de Cabezas', 'Sauquillo de Cabezas', 'Sauquillo de Cabezas', 41.1942200, -4.0688400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44643, 'Saucelle', 'Saucelle', 'Saucelle,Sausel''e,shao sai lie,Сауселье,Саусельє,绍塞列', 41.0476900, -6.7532800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44644, 'Saúca', 'Sauca', 'Sauca,Saúca', 41.0309800, -2.5290500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44645, 'Sástago', 'Sastago', 'Sastago,Sástago', 41.3216600, -0.3507500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44646, 'Sasamón', 'Sasamon', '', 42.4168700, -4.0428800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44647, 'Sartajada', 'Sartajada', 'Sartajada', 40.2132000, -4.7942700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44648, 'Sartaguda', 'Sartaguda', 'Sartaguda', 42.3833300, -2.0570900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44649, 'Sarrión', 'Sarrion', 'Sarrion,Sarrión', 40.1333300, -0.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44650, 'Sarrià de Ter', 'Sarria de Ter', 'Sarria de Ter,Sarrià de Ter,Sarriá de Ter', 42.0166700, 2.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44651, 'Sarria', 'Sarria', 'Sarria,Sarrija,Sorria,sa li ya,saria,Сарриа,Саррія,サリア,萨里亚', 42.7814800, -7.4143100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44652, 'Sarreaus', 'Sarreaus', '', 42.0878400, -7.6034800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44653, 'Sarratella', 'Sarratella', 'Sarratella', 40.3128400, 0.0315000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44654, 'Sarracín', 'Sarracin', '', 42.2581300, -3.6860800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44655, 'Saro', 'Saro', 'Saro', 43.2596100, -3.8428300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44656, 'Sariñena', 'Sarinena', 'Sarinena,Sariñena', 41.7912800, -0.1580400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44657, 'Sariegos', 'Sariegos', 'Sar''egos,Saregos,Sariegos,sa lie ge si,Сарьегос,Сарєгос,萨列戈斯', 42.6500000, -5.6333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44658, 'Sariego', 'Sariego', 'Santiago,Sariego,Sariegu', 43.4000000, -5.5333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44659, 'Sargentes de la Lora', 'Sargentes de la Lora', 'Sargentes,Sargentes de la Lora,Sarkhentes-de-la-Lora,sa er heng te si de la luo la,sarjyntys dy la lwra,Сархентес-де-ла-Лора,سارجينتيس دي لا لورا,萨尔亨特斯德拉洛拉', 42.7691700, -3.8727800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44660, 'Sardón de los Frailes', 'Sardon de los Frailes', 'Sardon de los Frailes,Sardón de los Frailes', 41.2137300, -6.2710100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44661, 'Sardón de Duero', 'Sardon de Duero', 'Sardon de Duero,Sardón de Duero', 41.6084700, -4.4339700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44662, 'Cerdanyola del Vallès', 'Cerdanyola del Valles', 'Cerdanyola,Cerdanyola del Valles,Cerdanyola del Vallès', 41.4910900, 2.1407900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44663, 'Sanzoles', 'Sanzoles', 'Sanzoles', 41.4323500, -5.5671000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44664, 'San Vitero', 'San Vitero', 'San Vitero', 41.7774000, -6.3487700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44665, 'Sant Vicenç de Montalt', 'Sant Vicenc de Montalt', 'San Vicente de Mont-Alt,Sant Vicenc de Montalt,Sant Vicenç de Montalt', 41.5785300, 2.5087900, 'ES', '2016-10-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44666, 'San Vicente del Valle', 'San Vicente del Valle', 'San Vicente del Valle', 42.3375600, -3.1621000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44667, 'Sant Vicenç dels Horts', 'Sant Vicenc dels Horts', 'Sant Vicenc dels Horts,Sant Vicenç dels Horts', 41.3931700, 2.0068900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44668, 'San Vicente del Palacio', 'San Vicente del Palacio', 'San Vicente del Palacio', 41.2190100, -4.8515800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44669, 'San Vicente de la Sonsierra', 'San Vicente de la Sonsierra', 'San Vicente,San Vicente de la Sonsierra,San Vincente de la Sonsierra,San Visente de la Sonsiera,San-Visente-de-la-Sons''erra,sheng bi sen te de la song xie la,Сан-Висенте-де-ла-Сонсьерра,Сан-Вісенте-де-ла-Сонсьєрра,Սան Վիսենտե դե լա Սոնսիեռա,圣比森特德拉松谢拉', 42.5632100, -2.7607100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44670, 'San Vicente de la Cabeza', 'San Vicente de la Cabeza', 'San Vicente de la Cabeza', 41.8069600, -6.2499300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44671, 'San Vicente de la Barquera', 'San Vicente de la Barquera', 'San Vicente,San Vicente de la Barquera,San Vicente la Barquera,San-Visente-de-la-Barkera,san faysynt dy la barjwyra,sheng bi sen te de la wa er ke la,Сан-Висенте-де-ла-Баркера,Сан-Вісенте-де-ла-Баркера,سان فايسينت دي لا بارجويرا,圣比森特德拉瓦尔克拉', 43.3850900, -4.3993400, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44672, 'Sant Vicenç de Castellet', 'Sant Vicenc de Castellet', 'San Vicente de Castellet,Sant Vicenc de Castellet,Sant Vicenç de Castellet', 41.6666700, 1.8666700, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44673, 'Barakaldo', 'Barakaldo', 'Baracaldo,Barakaldo,Done Bikendi,San Bizente,San Bizenti-Barakaldo,San Vicente de Baracaldo,Sanbi', 43.2963900, -2.9881300, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44674, 'San Vicente de Arévalo', 'San Vicente de Arevalo', 'San Vicente de Arevalo,San Vicente de Arévalo', 40.9677300, -4.8019400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44675, 'Santurdejo', 'Santurdejo', 'Santurdejo', 42.3769600, -2.9543700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44676, 'Santurtzi', 'Santurtzi', 'Santurce,Santurce-Antiguo,Santurtzi', 43.3284200, -3.0324800, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44677, 'Sants', 'Sants', 'Sants', 41.3742600, 2.1382600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44678, 'Santoyo', 'Santoyo', 'Santoyo', 42.2147300, -4.3429600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44679, 'Santovenia de Pisuerga', 'Santovenia de Pisuerga', 'Santovenia de Pisuerga', 41.6945700, -4.6902900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44680, 'Santovenia', 'Santovenia', 'Santovenia', 41.8785700, -5.7100300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44681, 'Santo Tomé de Zabarcos', 'Santo Tome de Zabarcos', 'Santo Tome de Zabarcos,Santo Tomé de Zabarcos', 40.7872600, -4.9104800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44682, 'San Torcuato', 'San Torcuato', 'San Torcuato', 42.4821900, -2.8892300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44683, 'Santorcaz', 'Santorcaz', '', 40.4717600, -3.2346200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44684, 'Santoña', 'Santona', 'Santon''ja,Santona,Santonija,Santoña,sang tuo ni ya,santwnya,Сантония,Сантонья,سانتونيا,桑托尼亚', 43.4438600, -3.4575700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44685, 'Santo Domingo de Silos', 'Santo Domingo de Silos', 'Santo Domingo de Silos,Santo Domingo de los Silos', 41.9640000, -3.4174000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44686, 'Santo Domingo de Pirón', 'Santo Domingo de Piron', 'Santo Domingo de Piron,Santo Domingo de Pirón', 41.0410400, -3.9893300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44687, 'Santo Domingo de las Posadas', 'Santo Domingo de las Posadas', 'Santo Domingo de las Posadas', 40.8120000, -4.6338300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44688, 'Santo Domingo de la Calzada', 'Santo Domingo de la Calzada', 'Ozkabarte,Santo Domingo de la Calzada,Santo Domingo de la Kalsada,Santo-Domingo-de-la-Kal''sada,santodoming-godelakalsada,sheng duo ming ge-de la ka er sa da,Санто-Доминго-де-ла-Кальсада,Санто-Домінго-де-ла-Кальсада,Սանտո Դոմինգո դե լա Կալսադա,サント・ドミンゴ・デ・ラ・カルサーダ,圣多明各-德拉卡尔萨达,산토도밍고데라칼사다', 42.4401500, -2.9536500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44689, 'Sant Just Desvern', 'Sant Just Desvern', 'Sant Just Desvern', 41.3838900, 2.0675800, 'ES', '2017-06-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44690, 'Sant Julià de Vilatorta', 'Sant Julia de Vilatorta', 'Sant Julia,Sant Julia de Vilatorta,Sant Julià,Sant Julià de Vilatorta', 41.9218900, 2.3244700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44691, 'Sant Joan les Fonts', 'Sant Joan les Fonts', 'Sant Joan les Fonts', 42.2118600, 2.5129100, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44692, 'Sant Joan de Vilatorrada', 'Sant Joan de Vilatorrada', 'San Joan de Vilatorrada', 41.7454900, 1.8047600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44693, 'Santiz', 'Santiz', 'Santiz,Sontiz', 41.2057900, -5.8965400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44694, 'Santiuste de San Juan Bautista', 'Santiuste de San Juan Bautista', 'Santiuste de San Juan Bautista', 41.1559300, -4.5720200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44695, 'Santiuste', 'Santiuste', 'Santiuste', 41.0846200, -2.8095300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44696, 'Santiurde de Toranzo', 'Santiurde de Toranzo', 'Santiurde de Toranzo,Santiurde-de-Toranso,sang di wu er de de tuo lan suo,santaywrdy dy twranzw,Сантиурде-де-Торансо,Сантіурде-де-Торансо,سانتايوردي دي تورانزو,桑蒂乌尔德德托兰索', 43.2381900, -3.9394700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44697, 'Santiurde de Reinosa', 'Santiurde de Reinosa', 'Santiurde de Reinosa', 43.0614400, -4.0835100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44698, 'Santiso', 'Santiso', 'Santa Maria,Santa María,Santiso', 42.8738800, -8.0549700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44699, 'Santillana', 'Santillana', 'Santillana,Santillana del Mar', 43.3890300, -4.1084400, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44700, 'Santibáñez el Bajo', 'Santibanez el Bajo', 'Santibanez el Bajo,Santibáñez el Bajo', 40.1763700, -6.2244100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44701, 'Santibáñez el Alto', 'Santibanez el Alto', 'Santibanez el Alto,Santibáñez el Alto', 40.1852500, -6.5478200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44702, 'Santibáñez de Vidriales', 'Santibanez de Vidriales', 'Santibanez de Vidriales,Santibáñez de Vidriales', 42.0736200, -6.0154900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44703, 'Santibáñez de Valcorba', 'Santibanez de Valcorba', 'Santibanez de Valcorba,Santibanez de Valcorva,Santibáñez de Valcorba,Santibáñez de Valcorva', 41.5698300, -4.4493800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44704, 'Santibáñez de Tera', 'Santibanez de Tera', 'Santibanez de Tera,Santibáñez de Tera', 41.9856300, -5.9225700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44705, 'Santibáñez del Val', 'Santibanez del Val', 'Santibanez del Val,Santibáñez del Val', 41.9735400, -3.4814200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44706, 'Santibáñez de la Sierra', 'Santibanez de la Sierra', 'Santibanez de la Sierra,Santibáñez de la Sierra', 40.4946400, -5.9157600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44707, 'Santibáñez de la Peña', 'Santibanez de la Pena', 'Santiban''es-de-la-Pen''ja,Santibanez de la Pena,Santibáñez de la Peña,sang di wa nie si de la pei ni ya,Сантибаньес-де-ла-Пенья,Сантібаньєс-де-ла-Пенья,桑蒂瓦涅斯德拉佩尼亚', 42.8092900, -4.7302600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44708, 'Santibáñez de Ecla', 'Santibanez de Ecla', 'Santibanez de Ecla,Santibáñez de Ecla', 42.7078400, -4.3726300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44709, 'Santibáñez de Béjar', 'Santibanez de Bejar', 'Santiban''es-de-Bekhar,Santibanez de Bejar,Santibáñez de Béjar,sang di wa nie si de wei ha er,Сантибаньес-де-Бехар,Сантібаньєс-де-Бехар,桑蒂瓦涅斯德韦哈尔', 40.4878500, -5.6111000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44710, 'Santiago Millas', 'Santiago Millas', 'Santiago Millas', 42.3837900, -6.1053800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44711, 'Santiago del Collado', 'Santiago del Collado', 'Santiago del Collado', 40.4332600, -5.3563100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44712, 'Santiago de la Puebla', 'Santiago de la Puebla', 'Santiago de la Puebla', 40.8013200, -5.2807300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44713, 'Santiago de Compostela', 'Santiago de Compostela', 'Compostela,Compostelako Donejakue,Compostella,Compostèla,Gorad Santjaga-deh-Kampastehla,Lungsod ng Santiago de Compostela,SCQ,Saint-Jacques-de-Compostelle,Sant''jago-de-Kompostela,Sant''jago-de-Kompostelae,Santiago,Santiago de Compostela,Santiago de Compostella,Santiago de Compostel·la,Santiago de Kompostela,Santiago di Compostela,Santiago nte Kompostela,Santiagu de Compostela,Santiaqo de Kompostela,Santijago de Kompostela,Santjago de Kompostela,Sint-Djake-el-Galice,Sint-Djåke-el-Galice,cantiyako te kompocutela,kong bo si te la de sheng de ya ge,san teiy ko dek xm po s te la,santi''ago de komaposatela,santi''ago de kompostela,santiagodekomposeutella,santiyago de kompostela,santyaghw dy kwmbwstyla,santyagw d kmpwstla,santyajw dy kwmbwstyla,sheng de ya ge jin bo si te la,sheng de ya ge-de kong bo si te la,Σαντιάγο ντε Κομποστέλα,Горад Сантяга-дэ-Кампастэла,Сантијаго де Компостела,Сантьяго-де-Компостелæ,Сантьяго-де-Компостела,Сантяго де Компостела,Сантјаго де Компостела,Սանտիագո դե Կոմպոստելա,סאנטיאגא דע קאמפאסטעלא,סנטיאגו דה קומפוסטלה,سانتياجو دى كومبوستيلا,سانتياغو دي كومبوستيلا,سانتیاگو د کمپوستلا,سانتیاگو دے کومپوستیلا,सांतिआगो दे कोम्पोस्तेला,सांतियागो दे कोंपोस्तेला,ਸਾਂਤੀਆਗੋ ਦੇ ਕੋਮਪੋਸਤੇਲਾ,சாந்தியாகோ தே கோம்போசுதேலா,සන්තියාගෝ ඩි කොම්පොස්ටෙලා,ซานเตียโกเดกอมโปสเตลา,სანტიაგო-დე-კომპოსტელა,サンティアゴ・デ・コンポステーラ,孔波斯特拉的聖地牙哥,聖地亞哥-德孔波斯特拉,聖地亞哥金波斯特拉,산티아고데콤포스텔라', 42.8805200, -8.5456900, 'ES', '2016-12-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44714, 'Doneztebe', 'Doneztebe', 'Doneztebe,Santesteban', 43.1333300, -1.6666700, 'ES', '2007-01-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44715, 'Santervás de la Vega', 'Santervas de la Vega', 'Santervas de la Vega,Santervás de la Vega', 42.5067700, -4.8000200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44716, 'Santervás de Campos', 'Santervas de Campos', 'Santervas de Campos,Santervás de Campos', 42.2182000, -5.1002700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44717, 'Santed', 'Santed', '', 41.0317200, -1.5102800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44718, 'Santa Susanna', 'Santa Susanna', 'Santa Susana,Santa Susanna,Santa-Susanna,Санта-Сусанна', 41.6333300, 2.7166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44719, 'Santas Martas', 'Santas Martas', 'Santa Martas,Santas Martas', 42.4322000, -5.3706600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44720, 'Santa Perpètua de Mogoda', 'Santa Perpetua de Mogoda', 'Santa Perpetua de Mogoda,Santa Perpetua de Moguda,Santa Perpètua de Mogoda', 41.5333300, 2.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44721, 'Santa Pau', 'Santa Pau', '', 42.1443000, 2.5712300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44722, 'Santa Oliva', 'Santa Oliva', 'Santa Oliva', 41.2535700, 1.5508600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44723, 'Santa Olalla de Bureba', 'Santa Olalla de Bureba', 'Santa Olalla de Bureba', 42.4772100, -3.4410900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44724, 'Santa Olalla', 'Santa Olalla', 'Santa Olalla,Santa Olalla de Toledo', 40.0234800, -4.4302500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44725, 'Sant Aniol de Finestres', 'Sant Aniol de Finestres', 'Sant Aniol de Finestres', 42.0902300, 2.5868800, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44726, 'Santander', 'Santander', 'Gorad Santandehr,Portus Victoriae Iuliobrigensium,SDR,Sanandere,Santandel,Santander,Santandera,Santanderas,Santandero,Santandèr,Santandér,cantanter,sang tan de,santandeleu,santandera,santanderu,santandr,santandyr,sntndr,Горад Сантандэр,Сантандер,סנטנדר,سانتاندر,سانتاندير,سانٹانڈر,सांतांदेर,சான்தான்தேர்,サンタンデール,桑坦德,산탄데르', 43.4647200, -3.8044400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44727, 'Santa Marta de Tormes', 'Santa Marta de Tormes', 'Santa Marta de Tormes', 40.9506500, -5.6272300, 'ES', '2015-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44728, 'Santa Marta de Ortigueira', 'Santa Marta de Ortigueira', 'Ortigueira,Santa Marta de Ortigueira', 43.6833300, -7.8500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44729, 'Santa Marta del Cerro', 'Santa Marta del Cerro', 'Santa Marta del Cerro', 41.2184300, -3.6858200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44730, 'Santa Marina del Rey', 'Santa Marina del Rey', 'Santa Marina del Rey', 42.5133400, -5.8606500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44731, 'Santa María la Real de Nieva', 'Santa Maria la Real de Nieva', 'Santa Maria de la Nieva,Santa Maria la Real de Nieva,Santa María la Real de Nieva,Santa-Maria de Nieva,Santa-Marija-la-Real''-de-N''eva,Santa-María de Nieva,sheng ma li ya la lei ya er de nie wa,Санта-Мария-ла-Реаль-де-Ньева,Санта-Марія-ла-Реаль-де-Ньєва,圣马里亚拉雷亚尔德涅瓦', 41.0699800, -4.4070900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44732, 'Santa María de Valverde', 'Santa Maria de Valverde', 'Santa Maria de Valverde,Santa María de Valverde', 41.9347900, -5.9356000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44733, 'Santa María de Sando', 'Santa Maria de Sando', 'Santa Maria de Sando,Santa María de Sando', 40.9790900, -6.1290400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44734, 'Santa Maria de Palautordera', 'Santa Maria de Palautordera', '', 41.7000000, 2.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44735, 'Santa María de Ordás', 'Santa Maria de Ordas', 'Santa Maria,Santa Maria de Ordas,Santa María de Ordás', 42.7265300, -5.8230100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44736, 'Santa Maria d''Oló', 'Santa Maria d''Olo', 'Santa Maria d''Olo,Santa Maria d''Oló', 41.8666700, 2.0333300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44737, 'Santa María del Val', 'Santa Maria del Val', 'Santa Maria del Val,Santa María del Val', 40.5043900, -2.0411500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44738, 'Santa María del Páramo', 'Santa Maria del Paramo', 'Santa Maria,Santa-Marija-del''-Paramo,sheng ma li ya de er pa la mo,Санта-Мария-дель-Парамо,Санта-Марія-дель-Парамо,圣马里亚德尔帕拉莫', 42.3551200, -5.7515100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44739, 'Santa María de los Caballeros', 'Santa Maria de los Caballeros', 'Santa Maria de los Caballeros,Santa María de los Caballeros', 40.3892500, -5.4511200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44740, 'Santa María del Monte de Cea', 'Santa Maria del Monte de Cea', 'Santa Maria del Monte,Santa Maria del Monte de Cea,Santa María del Monte,Santa María del Monte de Cea', 42.4913700, -5.1168900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44741, 'Santa María del Invierno', 'Santa Maria del Invierno', 'Santa Maria del Invierno,Santa María del Invierno', 42.4428800, -3.4378200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44742, 'Santa María del Campo', 'Santa Maria del Campo', 'Santa Maria,Santa Maria del Campo,Santa María del Campo,Santo Maria del Campo', 42.1330400, -3.9728300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44743, 'Santa María del Berrocal', 'Santa Maria del Berrocal', 'Santa Maria del Berrocal,Santa María del Berrocal', 40.5084500, -5.4048300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44744, 'Santa María de la Vega', 'Santa Maria de la Vega', '', 42.0849700, -5.8085100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44745, 'Santa María de las Hoyas', 'Santa Maria de las Hoyas', 'Santa Maria de las Hoyas,Santa María de las Hoyas', 41.7714500, -3.1417200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44746, 'Santa María de la Isla', 'Santa Maria de la Isla', 'Santa Maria de la Isla,Santa María de la Isla', 42.3553300, -5.9287000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44747, 'Santa María de la Alameda', 'Santa Maria de la Alameda', '', 40.5949200, -4.2577200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44748, 'Santa María de Huerta', 'Santa Maria de Huerta', 'Santa Maria de Huert,Santa Maria de Huerta,Santa Maria de Huerto,Santa María de Huerta', 41.2666700, -2.1666700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44749, 'Santa Maria de Corcó', 'Santa Maria de Corco', 'Santa Maria de Corco,Santa Maria de Corcó,l''Esquirol', 42.0333300, 2.3666700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44750, 'Santa María de Cayón', 'Santa Maria de Cayon', 'Santa Maria de Cayon,Santa María de Cayón,Santa-Marija-de-Kajon,santa marya dy kaywn,sheng ma li ya de kai weng,Санта-Мария-де-Кайон,Санта-Марія-де-Кайон,سانتا ماريا دي كايون,圣马里亚德凯翁', 43.3084900, -3.8368000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44751, 'Barberà del Vallès', 'Barbera del Valles', 'Barbera Del Valles,Barbera del Valles,Barberà del Vallès,Santa Maria de Barbera,Santa María de Barberà', 41.5159000, 2.1245700, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44752, 'Santa Magdalena de Pulpis', 'Santa Magdalena de Pulpis', 'Santa Magdalena de Pulpis', 40.3562500, 0.3025800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44753, 'Santa Inés', 'Santa Ines', 'Santa Ines,Santa Inés', 42.0401300, -3.7032200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44754, 'Santa Gadea del Cid', 'Santa Gadea del Cid', 'Santa Gadea del Cid', 42.7153100, -3.0588500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44755, 'Santa Eulàlia de Ronçana', 'Santa Eulalia de Roncana', '', 41.6500000, 2.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44756, 'Santa Eulalia de Oscos', 'Santa Eulalia de Oscos', 'Santa Eulalia,Santa Eulalia de Oscos', 43.2595000, -7.0189500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44757, 'Santa Eulalia de Gállego', 'Santa Eulalia de Gallego', 'Santa Eulalia de Gallego,Santa Eulalia de Gállego,Santolaria de Galligo', 42.2870000, -0.7606500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44758, 'Santa Eulalia Bajera', 'Santa Eulalia Bajera', 'Santa Eulalia Bajera', 42.2096000, -2.1917400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44759, 'Santa Eulalia', 'Santa Eulalia', 'Cabranes', 43.4162100, -5.4112800, 'ES', '2008-07-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44760, 'Santa Eulalia', 'Santa Eulalia', 'Santa Eulalia', 40.5674200, -1.3135400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44761, 'Santa Eugènia de Berga', 'Santa Eugenia de Berga', 'Santa Eugenia de Berga,Santa Eugènia de Berga', 41.9000000, 2.2833300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44762, 'Santa Eufemia del Barco', 'Santa Eufemia del Barco', 'Santa Eufemia,Santa Eufemia del Barco', 41.6780800, -5.8983100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44763, 'Santa Eufemia del Arroyo', 'Santa Eufemia del Arroyo', 'Santa Eufemia del Arroyo', 41.8950500, -5.2657500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44764, 'Santa Elena de Jamuz', 'Santa Elena de Jamuz', 'Santa Elena de Jamuz', 42.2606400, -5.8876200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44765, 'Santa Cruz de Yanguas', 'Santa Cruz de Yanguas', 'Santa Cruz de Yanguas,Santa-Krus-de-Janguas,Santa-Krus-de-Jangvas,sheng ke lu si de an gua si,Санта-Крус-де-Янгвас,Санта-Крус-де-Янгуас,圣克鲁斯德安瓜斯', 42.0625000, -2.4489400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44766, 'Santa Cruz de Pinares', 'Santa Cruz de Pinares', 'Santa Cruz de Pinares', 40.5426500, -4.5803600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44767, 'Santa Cruz de Paniagua', 'Santa Cruz de Paniagua', 'Santa Cruz de Paniagua', 40.1916700, -6.3400300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44768, 'Santa Cruz de Nogueras', 'Santa Cruz de Nogueras', 'Santa Cruz de Nogueras', 41.1147500, -1.0893300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44769, 'Santa Cruz de Moncayo', 'Santa Cruz de Moncayo', 'Santa Cruz de Moncayo', 41.8824000, -1.7563700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44770, 'Santa Cruz del Valle Urbión', 'Santa Cruz del Valle Urbion', 'Santa Cruz del Valle Urbion,Santa Cruz del Valle Urbión', 42.3055800, -3.2214000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44771, 'Santa Cruz del Valle', 'Santa Cruz del Valle', 'Santa Cruz del Valle', 40.2516000, -5.0013300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44772, 'Santa Cruz del Retamar', 'Santa Cruz del Retamar', 'Santa Cruz de Retamar', 40.1191700, -4.2415800, 'ES', '2008-10-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44773, 'Santa Cruz de la Serós', 'Santa Cruz de la Seros', 'Santa Cruz d''as Serors,Santa Cruz de la Seros,Santa Cruz de la Serós', 42.5227100, -0.6751500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44774, 'Santa Cruz de la Salceda', 'Santa Cruz de la Salceda', 'Santa Cruz de la Salceda', 41.5959100, -3.5931700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44775, 'Santa Cruz de Grío', 'Santa Cruz de Grio', 'Santa Cruz de Grio,Santa Cruz de Grío', 41.3705000, -1.4300900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44776, 'Santa Cruz de Boedo', 'Santa Cruz de Boedo', 'Santa Cruz de Boedo', 42.5253100, -4.3739800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44777, 'Santa Cruz de Bezana', 'Santa Cruz de Bezana', 'Santa-Krus-de-Besana,santa krwz dy byzana,sheng ke lu si de wei sa na,Санта-Крус-де-Бесана,سانتا كروز دي بيزانا,圣克鲁斯德韦萨纳', 43.4437000, -3.9032400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44778, 'Santa Croya de Tera', 'Santa Croya de Tera', 'Santa Croya de Tera', 41.9833400, -5.9772500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44779, 'Santa Cristina de Valmadrigal', 'Santa Cristina de Valmadrigal', 'Santa Cristina de Valmadrigal', 42.3544600, -5.3092900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44780, 'Santa Cristina de la Polvorosa', 'Santa Cristina de la Polvorosa', 'Santa Cristina de la Polvorosa', 41.9998500, -5.7135500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44781, 'Santa Cristina d''Aro', 'Santa Cristina d''Aro', 'Santa Cristina d''Aro,Santa Cristina de Aro', 41.8166700, 3.0000000, 'ES', '2016-10-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44782, 'Santa Comba', 'Santa Comba', 'Santa Comba', 43.0330600, -8.8092500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44783, 'Santa Colomba de Somoza', 'Santa Colomba de Somoza', 'Santa Colomba de Somoza', 42.4446600, -6.2448300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44784, 'Santa Colomba de las Monjas', 'Santa Colomba de las Monjas', 'Santa Colomba de las Monjas', 41.9583300, -5.6838900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44785, 'Santa Colomba de Curueño', 'Santa Colomba de Curueno', 'Santa Colomba de Curueno,Santa Colomba de Curueño', 42.7505800, -5.4120100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44786, 'Santa Coloma de Queralt', 'Santa Coloma de Queralt', 'Santa Coloma,Santa Coloma de Queralt', 41.5333300, 1.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44787, 'Santa Coloma de Gramenet', 'Santa Coloma de Gramenet', 'Santa Coloma de Gramenet,Santa-Koloma-de-Gramanet,Санта-Колома-де-Граманет', 41.4515200, 2.2081000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44788, 'Santa Coloma de Farners', 'Santa Coloma de Farners', 'Santa Colama de Farnes,Santa Colama de Farnés,Santa Coloma de Farners,Santa Coloma de Farnes,Santa Coloma de Farnés', 41.8666700, 2.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44789, 'Santa Coloma de Cervelló', 'Santa Coloma de Cervello', 'Santa Coloma,Santa Coloma de Cervello,Santa Coloma de Cervelló,Santa Colomba de Cervello,Santa Colomba de Cervelló', 41.3673600, 2.0142600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44790, 'Santa Coloma', 'Santa Coloma', 'Santa Coloma', 42.3671700, -2.6559800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44791, 'Santa Clara de Avedillo', 'Santa Clara de Avedillo', 'Santa Clara de Avedillo', 41.3387700, -5.6769200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44792, 'Santa Cecília de Voltregà', 'Santa Cecilia de Voltrega', 'Santa Cecilia de Voltrega,Santa Cecília de Voltregà', 42.0000000, 2.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44793, 'Santa Cecilia del Alcor', 'Santa Cecilia del Alcor', 'Santa Cecilia del Alcor', 41.9322700, -4.6554600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44794, 'Santa Cecilia', 'Santa Cecilia', 'Santa Cecilia', 42.0522500, -3.8034500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44795, 'Santacara', 'Santacara', 'Santacara', 42.3666700, -1.6333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44796, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 40.7154200, 0.4929200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44797, 'Sansol', 'Sansol', 'Sansol', 42.5536200, -2.2667600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44798, 'San Sebastián de los Reyes', 'San Sebastian de los Reyes', 'S.S. de los Reyes,SS de los Reyes,San Sebastian de los Rejesas,San Sebastian de los Reyes,San Sebastijan de los Rejes,San Sebastián de los Reyes,San-Sebast''jan-de-los-Rees,San-Sebastian-de-los-Rejes,Sanctus Sebastianus Regum,Sanse,san sbastyan dy lws ryys,sheng sai wa si di an de luo si lei ai si,Сан Себастијан де лос Рејес,Сан-Себастиан-де-лос-Рейес,Сан-Себастьян-де-лос-Реєс,سان سباستيان دي لوس رييس,サン・セバスティアン・デ・ロス・レイエス,圣塞瓦斯蒂安德洛斯雷埃斯', 40.5555500, -3.6273300, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44799, 'Donostia / San Sebastián', 'San Sebastian', 'Donosti,Donostia,Donostia-San Sebastian,Donostia-San Sebastián,Donostio,EAS,La Bella Easo,Saint-Sebastien,Saint-Sébastien,San Sebastian,San Sebastián,San-Sebast''jan,Sanse,Sant Sebastia,Sant Sebastià,Sao Sebastiao,São Sebastião,san sbastyan,sheng sai wa si ti an,Сан-Себастьян,סן סבסטיאן,سان سباستيان,サン・セバスティアン,圣塞瓦斯提安', 43.3128300, -1.9749900, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44800, 'San Sadurniño', 'San Sadurnino', '', 43.5333300, -8.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44801, 'San Salvador', 'San Salvador', '', 41.6206000, -5.0871300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44802, 'Sant Sadurní d''Anoia', 'Sant Sadurni d''Anoia', 'Sant Sadurni,Sant Sadurni d''Anoia,Sant Sadurní,Sant Sadurní d''Anoia', 41.4255500, 1.7851900, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44803, 'San Román de la Cuba', 'San Roman de la Cuba', '', 42.2625700, -4.8572400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44804, 'San Román de Hornija', 'San Roman de Hornija', 'San Roman,San Roman de Hornija,San Roman de la Hornija,San Román,San Román de Hornija,San Román de la Hornija', 41.4813100, -5.2845400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44805, 'San Román de Cameros', 'San Roman de Cameros', 'San Roman de Cameros,San Roman de Kameros,San Román de Cameros,San-Roman-de-Kameros,sheng luo man de ka mei luo si,Сан-Роман-де-Камерос,Սան Ռոման դե Կամերոս,圣罗曼德卡梅罗斯', 42.2325500, -2.4743600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44806, 'San Román', 'San Roman', 'Cervantes,San Roman,San Román', 42.8693200, -7.0626100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44807, 'Sant Quirze Safaja', 'Sant Quirze Safaja', 'San Quirico Safaja,San Quírico Safaja,Sant Quirze Safaja', 41.7333300, 2.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44808, 'Sant Quirze del Vallès', 'Sant Quirze del Valles', 'San Quirico de Tarrasa,San Quírico de Tarrasa,Sant Quirze del Valles,Sant Quirze del Vallès', 41.5333300, 2.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44809, 'Sant Pol de Mar', 'Sant Pol de Mar', 'San Pol de Mar,Sant Pol de Mar,Сант Пол де Мар', 41.6017700, 2.6174100, 'ES', '2014-05-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44810, 'San Pelayo de Guareña', 'San Pelayo de Guarena', 'San Pelayo de Guarena,San Pelayo de Guareña', 41.1157900, -5.8570200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44811, 'San Pelayo', 'San Pelayo', '', 41.6803300, -5.0340300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44812, 'Sant Pere Pescador', 'Sant Pere Pescador', 'Sant Pere Pescador', 42.1881200, 3.0821200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44813, 'San Pedro Palmiches', 'San Pedro Palmiches', 'San Pedro Palmiches', 40.4295600, -2.4060200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44814, 'San Pedro Manrique', 'San Pedro Manrique', 'San Pedro Manrique,San-Pedro-Manrike,sheng pei de luo man li ke,Сан-Педро-Манрике,Сан-Педро-Манріке,圣佩德罗曼里克', 42.0286000, -2.2310400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44815, 'Sant Pere de Vilamajor', 'Sant Pere de Vilamajor', 'San Pedro de Vilamajor,Sant Pere de Vilamajor', 41.6833300, 2.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44816, 'San Pedro de Rozados', 'San Pedro de Rozados', 'San Pedro de Rozados', 40.7900800, -5.7371600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44817, 'Sant Pere de Riudebitlles', 'Sant Pere de Riudebitlles', 'Sant Pere de Riudebitlles', 41.4500000, 1.7000000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44818, 'Sant Pere de Ribes', 'Sant Pere de Ribes', 'San Pedro de Ribas,Sant Pere de Ribes', 41.2604500, 1.7739100, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44819, 'San Pedro del Valle', 'San Pedro del Valle', 'San Pedro del Valle', 41.0333200, -5.8602500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44820, 'San Pedro del Romeral', 'San Pedro del Romeral', 'San Pedro del Romeral', 43.1151400, -3.8186000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44821, 'San Pedro de Latarce', 'San Pedro de Latarce', 'San Pedro de Latarce', 41.7355600, -5.3259200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44822, 'San Pedro del Arroyo', 'San Pedro del Arroyo', 'San Pedro del Arroyo', 40.8021300, -4.8707500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44823, 'San Pedro de Gaíllos', 'San Pedro de Gaillos', 'San Pedro de Gaillos,San Pedro de Gaíllos', 41.2266200, -3.8092100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44824, 'San Pedro de Ceque', 'San Pedro de Ceque', 'San Pedro de Ceque', 42.0433400, -6.0724200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44825, 'San Pedro Bercianos', 'San Pedro Bercianos', '', 42.3914500, -5.7134100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44826, 'San Pascual', 'San Pascual', 'San Pascual', 40.8814100, -4.7561200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44827, 'San Pablo de la Moraleja', 'San Pablo de la Moraleja', 'San Pablo de la Moraleja', 41.1610000, -4.7776100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44828, 'San Muñoz', 'San Munoz', 'Munoz,Muñoz,San Munoz,San Muñoz', 40.7833400, -6.1275800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44829, 'Sant Mori', 'Sant Mori', 'Sant Mori', 42.1559000, 2.9894600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44830, 'San Morales', 'San Morales', 'San Morales', 40.9935800, -5.5023400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44831, 'San Millán de Yécora', 'San Millan de Yecora', 'San Millan de Yecora,San Millán de Yécora', 42.5470500, -3.0968100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44832, 'San Millán de los Caballeros', 'San Millan de los Caballeros', 'San Millan de los Caballeros,San Millán de los Caballeros', 42.2852000, -5.5610700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44833, 'San Millán de Lara', 'San Millan de Lara', 'San Millan de Lara,San Millán de Lara', 42.1362100, -3.3451500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44834, 'San Millán de la Cogolla', 'San Millan de la Cogolla', 'Donemiliaga Kukula,San Milian de la Kogolia,San Millan,San Millán,San-Mil''jan-de-la-Kogol''ja,Sveti Milan od Kogole,sheng mi liang de la ke ge li ya,Сан-Мильян-де-ла-Коголья,Сан-Мільян-де-ла-Коголья,Свети Миљан од Когоље,Սան Միլիան դե լա Կոգոլիա,圣米良德拉科戈利亚', 42.3297400, -2.8618500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44835, 'San Miguel de Valero', 'San Miguel de Valero', 'San Miguel de Valero', 40.5436100, -5.9228000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44836, 'San Miguel de Serrezuela', 'San Miguel de Serrezuela', 'San Miguel,San Miguel de Serrezuela', 40.6706400, -5.2885700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44837, 'San Miguel de Meruelo', 'San Miguel de Meruelo', 'Meruelo,San Miguel de Meruelo', 43.4621100, -3.5887700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44838, 'San Miguel del Pino', 'San Miguel del Pino', '', 41.5094100, -4.9114900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44839, 'San Miguel del Arroyo', 'San Miguel del Arroyo', 'San Miguel del Arroyo', 41.4432800, -4.4599000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44840, 'San Miguel de la Ribera', 'San Miguel de la Ribera', 'San Miguel de la Ribera', 41.3330100, -5.5768900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44841, 'Sant Miquel de Fluvià', 'Sant Miquel de Fluvia', 'Sant Miquel de Fluvia,Sant Miquel de Fluvià', 42.1720000, 2.9925900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44842, 'San Miguel de Corneja', 'San Miguel de Corneja', 'San Miguel de Corneja', 40.4872200, -5.2865400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44843, 'Sant Miquel de Campmajor', 'Sant Miquel de Campmajor', 'San Miguel de Campmajor,Sant Miquel de Campmajor', 42.1333300, 2.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44844, 'San Miguel de Aguayo', 'San Miguel de Aguayo', 'San Miguel de Aguayo', 43.0538300, -4.0255000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44845, 'San Mateo de Gállego', 'San Mateo de Gallego', 'San Mateo de Gallego,San Mateo de Gállego', 41.8304300, -0.7657800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44846, 'Sant Martí Vell', 'Sant Marti Vell', 'San Martivell,San Martívell,Sant Marti Vell,Sant Martí Vell', 42.0166700, 2.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44847, 'Sant Martí Sarroca', 'Sant Marti Sarroca', 'Sant Marti Sarroca,Sant Martí Sarroca', 41.3857600, 1.6112100, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44848, 'San Martín de Valvení', 'San Martin de Valveni', 'San Martin de Valveni,San Martín de Valvení', 41.7533600, -4.5672400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44849, 'San Martín de Valderaduey', 'San Martin de Valderaduey', 'San Martin de Valderaduey,San Martín de Valderaduey', 41.8141400, -5.4724900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44850, 'San Martín de Valdeiglesias', 'San Martin de Valdeiglesias', 'San Martin de Valdeiglesias,San Martin de Valdieglesias,San-Martin-de-Val''deiglesias,San-Martin-de-Val''dejgles''jas,san martn dy faldyjlysyas,sheng ma ding-de ba er dai ge lai xi ya si,Сан-Мартин-де-Вальдейглесьяс,Сан-Мартін-де-Вальдеіглесіас,Սան Մարտին դե Վալդեիգլեսիաս,سان مارتن دي فالديجليسياس,圣马丁-德巴尔代格莱西亚斯', 40.3618500, -4.3983100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44851, 'San Martín de Unx', 'San Martin de Unx', 'San Martin de Unx,San Martín de Unx', 42.5247300, -1.5609100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44852, 'San Martín de Trevejo', 'San Martin de Trevejo', 'San Martin de Trevejo,San Martín de Trevejo', 40.2124100, -6.7953500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44853, 'Sant Martí de Tous', 'Sant Marti de Tous', 'San Martin de Tous,San Martín de Tous,Sant Marti de Tous,Sant Martí de Tous', 41.5500000, 1.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44854, 'San Martín de Rubiales', 'San Martin de Rubiales', 'San Martin de Rubiales,San Martín de Rubiales', 41.6419100, -3.9913400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44855, 'San Martín de Oscos', 'San Martin de Oscos', 'San Martin,San Martin de Oscos,San Martín de Oscos', 43.2658700, -6.9624100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44856, 'San Martín del Río', 'San Martin del Rio', 'San Martin del Rio,San Martín del Río', 41.0663300, -1.3873300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44857, 'San Martín del Pimpollar', 'San Martin del Pimpollar', 'San Martin del Pimpollar,San Martín del Pimpollar', 40.3683000, -5.0544300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44858, 'San Martín del Castañar', 'San Martin del Castanar', 'San Martin del Castanar,San Martín del Castañar', 40.5226400, -6.0638700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44859, 'San Martín de la Vega del Alberche', 'San Martin de la Vega del Alberche', 'San Martin de la Vega del Alberche,San Martín de la Vega del Alberche', 40.4305300, -5.1550000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44860, 'San Martín de la Vega', 'San Martin de la Vega', 'San Martin de la Vega,San Martín de la Vega,San-Martin-de-la-Vega,san martyn dy la fygha,sheng ma er ting de la wei jia,Сан-Мартин-де-ла-Вега,Сан-Мартін-де-ла-Вега,سان مارتين دي لا فيغا,圣马尔廷德拉韦加', 40.2073500, -3.5706300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44861, 'San Martín de Elines', 'San Martin de Elines', 'San Martin,San Martin de Elines,San Martín de Elines,Valderredible', 42.8286400, -3.8686500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44862, 'Sant Martí de Centelles', 'Sant Marti de Centelles', 'Sant Marti de Centelles,Sant Martí de Centelles', 41.7661700, 2.2056600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44863, 'San Mamés de Campos', 'San Mames de Campos', 'San Mames de Campos,San Mamés de Campos', 42.3551200, -4.5656500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44864, 'San Mamés de Burgos', 'San Mames de Burgos', '', 42.3368500, -3.7939700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44865, 'San Lorenzo de Tormes', 'San Lorenzo de Tormes', 'Lorenzo de Tormes,San Lorenzo de Tormes', 40.3698400, -5.4884800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44866, 'Sant Llorenç de la Muga', 'Sant Llorenc de la Muga', 'Sant Llorenc de la Muga,Sant Llorenç de la Muga', 42.3197600, 2.7888800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44867, 'Sant Llorenç d''Hortons', 'Sant Llorenc d''Hortons', 'San Lorenzo de Hortons,San Lorenzo de Hortóns,Sant Llorenc d''Hortons,Sant Llorenç d''Hortons', 41.4666700, 1.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44868, 'San Lorenzo de El Escorial', 'San Lorenzo de El Escorial', 'El Escorial,Eskorialo,San Lorenzo,San Lorenzo del Escorial,San-Lorenso-de-Ehl''-Ehskorial'',San-Lorenso-de-El''-Eskorial'',san lwrnzw dy sh alaskwryal,sanlolensodeel-eseukolial,sheng luo lun suo de ai lai si ke li ya er,Сан-Лоренсо-де-Ель-Ескоріаль,Сан-Лоренсо-де-Эль-Эскориаль,سان لورنزو دي ش الإسكوريال,圣洛伦索德埃莱斯科里亚尔,산로렌소데엘에스코리알', 40.5914400, -4.1473800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44869, 'San Llorente', 'San Llorente', 'San Llorente', 41.6863100, -4.0660000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44870, 'San Leonardo de Yagüe', 'San Leonardo de Yague', 'Leonardo,San Leonardo,San Leonardo de Yague,San Leonardo de Yaguee,San Leonardo de Yagüe,San-Leonardo-de-Jague,San-Leonardo-de-Jagueh,sheng lai ao na er duo de a ge,Сан-Леонардо-де-Ягуе,Сан-Леонардо-де-Ягуэ,圣莱奥纳尔多德阿格', 41.8303400, -3.0688000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44871, 'San Justo de la Vega', 'San Justo de la Vega', 'San Justo de la Vega,San-Khusto-de-la-Vega,sheng hu si tuo de la wei jia,Сан-Хусто-де-ла-Вега,圣胡斯托德拉韦加', 42.4569600, -6.0182500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44872, 'San Justo', 'San Justo', '', 42.1332100, -6.6238800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44873, 'San Julián de Muskiz', 'San Julian de Muskiz', 'Muskiz,Musques,Muzquiz,San Julian de Muskiz,San Julian de Musques,San Julián de Musques', 43.3333300, -3.1000000, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44874, 'Sant Julià de Cerdanyola', 'Sant Julia de Cerdanyola', '', 42.2235000, 1.8930800, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44875, 'Vilassar de Mar', 'Vilassar de Mar', 'Vilassar de Mar,Vilassar del Mar', 41.5050700, 2.3922700, 'ES', '2015-06-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44876, 'Sant Joan Despí', 'Sant Joan Despi', 'Sant Joan Despi,Sant Joan Despí', 41.3671800, 2.0574000, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44877, 'San Juan de Moró', 'San Juan de Moro', 'Caserio San Juan de Moro,Caserío San Juan de Moró,San Juan de Moro,San Juan de Moró,Sant Joan de Moro', 40.0599000, -0.1369100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44878, 'Sant Joan de Mollet', 'Sant Joan de Mollet', 'San Juan de Mollet,Sant Joan de Mollet', 42.0500000, 2.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44879, 'San Juan del Monte', 'San Juan del Monte', 'San Juan del Monte', 41.6831300, -3.5233700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44880, 'San Juan del Molinillo', 'San Juan del Molinillo', 'San Juan del Molinillo', 40.4590900, -4.8171100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44881, 'Sant Joan de les Abadesses', 'Sant Joan de les Abadesses', 'Sant Joan de les Abadesses', 42.2333200, 2.2852400, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44882, 'San Juan de la Nava', 'San Juan de la Nava', 'San Juan de la Nava', 40.4788000, -4.6823800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44883, 'San Juan de la Encinilla', 'San Juan de la Encinilla', 'San Juan de la Encinilla', 40.8302000, -4.8395700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44884, 'Sant Jordi', 'Sant Jordi', 'San Jorge,Sant Jordi del Maestrat', 40.5098200, 0.3320800, 'ES', '2015-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44885, 'Sant Jordi Desvalls', 'Sant Jordi Desvalls', 'San Jordi Desvalls,Sant Jordi Desvalls', 42.0666700, 2.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44886, 'Sant Jaume dels Domenys', 'Sant Jaume dels Domenys', 'San Jaime dels Domenys,Sant Jaume dels Domenys', 41.3000000, 1.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44887, 'San Ildefonso', 'San Ildefonso', 'La Granja,La Granja de San Ildefonso,Real Sitio de San Ildefonso,San Ildefonso,San-Il''defonso,Sankta Ildefonso,sheng yi er de feng suo,Сан-Ільдефонсо,Сан-Ильдефонсо,圣伊尔德丰索', 40.9018200, -4.0068500, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44888, 'Sant Hilari Sacalm', 'Sant Hilari Sacalm', 'San Hilario Sacalm,Sant Hilari Sacalm', 41.8833300, 2.5166700, 'ES', '2012-04-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44889, 'Sangüesa', 'Sanguesa', 'Sangossa,Sangueesa,Sanguehsa,Sanguesa,Sangòssa,Sangüesa,Zangotza,Zangoza,sang ge sa,sanguesa,Сангуеса,Сангуэса,サングエサ,桑格萨', 42.5748300, -1.2828300, 'ES', '2008-07-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44890, 'Sant Gregori', 'Sant Gregori', 'San Gregorio,Sant Gregori', 41.9833300, 2.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44891, 'Sanxenxo', 'Sanxenxo', 'Sangenjo,Sanxenxo', 42.3999600, -8.8069800, 'ES', '2015-08-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44892, 'Sangarrén', 'Sangarren', 'Sangarren,Sangarrén', 42.0192100, -0.4332300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44893, 'San García de Ingelmos', 'San Garcia de Ingelmos', 'San Garcia de Ingelmos,San García de Ingelmos', 40.7691200, -5.1152300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44894, 'Sangarcía', 'Sangarcia', 'Sangarcia,Sangarcía', 40.9502300, -4.4108500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44895, 'Sant Fruitós de Bages', 'Sant Fruitos de Bages', 'San Fructuoso,San Fructuoso de Bages,San Fructuoso de Bagés,San Frutos,Sant Fruitos de Bages,Sant Fruitós de Bages', 41.7500000, 1.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44896, 'Sant Ferriol', 'Sant Ferriol', 'San Ferreol,Sant Ferriol', 42.2000000, 2.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44897, 'San Fernando de Henares', 'San Fernando de Henares', 'San Fernando de Enares,San Fernando de Henares,San-Fernando de Henaro,San-Fernando-de-Ehnares,San-Fernando-de-Enares,ai na lei si he pan sheng fei er nan duo,san frnandw dy hynarys,Сан-Фернандо-де-Енарес,Сан-Фернандо-де-Энарес,Սան Ֆերնանդո դե Էնարես,سان فرناندو دي هيناريس,埃纳雷斯河畔圣费尔南多', 40.4238600, -3.5326100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44898, 'Sant Feliu Sasserra', 'Sant Feliu Sasserra', 'San Feliu Saserra,San Felíu Saserra,Sant Feliu Sasserra', 41.9500000, 2.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44899, 'Sant Feliu de Pallerols', 'Sant Feliu de Pallerols', 'Sant Feliu de Pallerols', 42.0770800, 2.5093500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44900, 'Sant Feliu de Llobregat', 'Sant Feliu de Llobregat', 'Feliu-de-L''obregat,San Feliu de Llobregat,San Feliú de Llobregat,Sant Feliu,Sant Feliu de Llobregat,Фелиу-де-Льобрегат', 41.3833300, 2.0500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44901, 'Sant Feliu de Guíxols', 'Sant Feliu de Guixols', 'San Feliu de Gisols,San Feliu de Guixols,San Felíu de Guixols,San-Faliu-da-Gishuls,San-Feliu-de-Gishol''s,Sant Feliu de Guixols,Sant Feliu de Guíxols,san fylyw dy ghykswls,sant flyw d gyksls,sheng fei liu-de ji ke suo er si,Сан-Фаліу-да-Ґішулс,Сан-Фелиу-де-Гишольс,Սան Ֆելիու դե Գիշոլս,سان فيليو دي غيكسولس,سانت فلیو د گیکسلس,圣费柳-德吉克索尔斯', 41.7833300, 3.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44902, 'Sant Feliu de Codines', 'Sant Feliu de Codines', 'San Feliu de Codinas,San Felíu de Codinas,Sant Feliu de Codines', 41.7000000, 2.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44903, 'San Felices de los Gallegos', 'San Felices de los Gallegos', 'San Felices,San Felices de Gallegos,San Felices de los Gallegos', 40.8495400, -6.7080400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44904, 'San Felices', 'San Felices', '', 41.9370800, -2.0263800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44905, 'San Esteban de Nogales', 'San Esteban de Nogales', 'San Esteban de Nogales', 42.1599500, -5.9306500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44906, 'San Esteban del Valle', 'San Esteban del Valle', 'San Esteban del Valle', 40.2751000, -4.9821500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44907, 'San Esteban de los Patos', 'San Esteban de los Patos', 'San Esteban de los Patos', 40.7470500, -4.6241300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44908, 'San Esteban del Molar', 'San Esteban del Molar', 'San Esteban del Molar', 41.9371700, -5.5515800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44909, 'San Esteban de la Sierra', 'San Esteban de la Sierra', 'San Esteban de la Sierra', 40.5068000, -5.9061900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44910, 'San Esteban de Gormaz', 'San Esteban de Gormaz', 'San Esteban de Gormaz,San-Ehsteban-de-Gormas,San-Esteban-de-Gormas,sheng ai si te wan de ge er ma si,shnt ashtybn,Сан-Естебан-де-Гормас,Сан-Эстебан-де-Гормас,شنت إشتيبن,圣埃斯特万德戈尔马斯', 41.5743600, -3.2041800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44911, 'San Emiliano', 'San Emiliano', 'San Emiliano', 42.9716400, -6.0007500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44912, 'Sando', 'Sando', 'Sando', 40.9677300, -6.1113600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44913, 'Sant Cugat del Vallès', 'Sant Cugat del Valles', 'Sant Cugat,Sant Cugat del Valles,Sant Cugat del Vallès', 41.4706300, 2.0861100, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44914, 'San Cristóbal de Segovia', 'San Cristobal de Segovia', 'San Cristobal de Segovia,San Cristóbal de Segovia', 40.9522500, -4.0765200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44915, 'San Cristóbal de la Vega', 'San Cristobal de la Vega', 'San Cristobal de la Vega,San Cristóbal de la Vega', 41.1121400, -4.6444800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44916, 'San Cristóbal de la Polantera', 'San Cristobal de la Polantera', 'San Cristobal de la Polantera,San Cristóbal de la Polantera', 42.3904100, -5.9073200, 'ES', '2013-07-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44917, 'San Cristóbal de la Cuesta', 'San Cristobal de la Cuesta', 'San Cristobal de la Cuesta,San Cristóbal de la Cuesta', 41.0291900, -5.6177100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44918, 'San Cristóbal de Entreviñas', 'San Cristobal de Entrevinas', 'San Cristobal de Entrevinas,San Cristóbal de Entreviñas', 42.0457500, -5.6346800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44919, 'San Cristóbal de Cuéllar', 'San Cristobal de Cuellar', 'San Cristobal de Cuellar,San Cristóbal de Cuéllar', 41.4059100, -4.4044500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44920, 'San Cristóbal de Boedo', 'San Cristobal de Boedo', 'San Cristobal de Boedo,San Cristóbal de Boedo', 42.5419400, -4.3532500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44921, 'Sanchotello', 'Sanchotello', 'Sanchotello', 40.4381200, -5.7539400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44922, 'Sanchorreja', 'Sanchorreja', 'Sanchorreja', 40.6647500, -4.9149400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44923, 'Sanchonuño', 'Sanchonuno', 'Sanchonuno,Sanchonuño', 41.3232500, -4.3053100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44924, 'Sanchón de la Sagrada', 'Sanchon de la Sagrada', 'Sanchon de la Sagrada,Sanchón de la Sagrada', 40.7428700, -6.0250200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44925, 'Sanchón de la Ribera', 'Sanchon de la Ribera', 'Sanchon de la Ribera,Sanchon de la Rivera,Sanchón de la Ribera,Sanchón de la Rivera', 41.0884400, -6.4131400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44926, 'Sanchidrián', 'Sanchidrian', '', 40.8934700, -4.5813200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44927, 'Sant Celoni', 'Sant Celoni', 'San Celoni,Sant Celoni', 41.6892100, 2.4896500, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44928, 'Sancedo', 'Sancedo', 'Sancedo', 42.6666600, -6.6345600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44929, 'San Cebrián de Mudá', 'San Cebrian de Muda', 'San Cebrian de Muda,San Cebrián de Mudá', 42.8926100, -4.3871900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44930, 'San Cebrián de Mazote', 'San Cebrian de Mazote', '', 41.6802200, -5.1484700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44931, 'San Cebrián de Castro', 'San Cebrian de Castro', 'San Cebrian de Castro,San Cebrián de Castro', 41.7063200, -5.7560500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44932, 'San Cebrián de Campos', 'San Cebrian de Campos', 'San Cebrian,San Cebrian de Campos,San Cebrián,San Cebrián de Campos', 42.2006300, -4.5312700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44933, 'Sant Carles de la Ràpita', 'Sant Carles de la Rapita', 'San Carlos des la Rapida,San-Karlos-de-la-Rapita,Sant Carles de la Rapita,Sant Carles de la Ràpita,Сан-Карлос-де-ла-Рапита', 40.6166700, 0.6000000, 'ES', '2016-01-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44934, 'Sant Boi de Lluçanès', 'Sant Boi de Llucanes', 'San Baudilio de Llusanes,San Baudilio de Llusanés,San baudilio de Llusanes,San baudilio de Llusanés,Sant Boi de Llucanes,Sant Boi de Lluçanès', 42.0500000, 2.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44935, 'Sant Boi de Llobregat', 'Sant Boi de Llobregat', 'Sant Boi de Llobregat', 41.3435700, 2.0365900, 'ES', '2010-07-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44936, 'San Bartolomé de Corneja', 'San Bartolome de Corneja', 'San Bartolome de Corneja,San Bartolomé de Corneja', 40.4925700, -5.3851900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44937, 'San Bartolomé de Béjar', 'San Bartolome de Bejar', 'San Bartolome de Bejar,San Bartolomé de Béjar', 40.4078300, -5.6626100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44938, 'San Asensio', 'San Asensio', 'San Asensio,San-Asensio,sheng a sen xi ao,Сан-Асенсио,Сан-Асенсіо,Սան Ասենսիո,圣阿森西奥', 42.4967700, -2.7505700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44939, 'San Antolín', 'San Antolin', 'Ibias,San Antolin,San Antolin de Ibias,San Antolín', 43.0384900, -6.8737600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44940, 'Sant Andreu Salou', 'Sant Andreu Salou', 'San Andres Salou,San Andrés Salou,Sant Andreu Salou', 41.8666700, 2.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44941, 'Sant Andreu', 'Sant Andreu', 'Distrito Sant Andreu,Sant Andreu,Sant Andreu de Palomar', 41.4354100, 2.1898200, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44942, 'San Andrés del Rey', 'San Andres del Rey', 'San Andres del Rey,San Andrés del Rey', 40.6383700, -2.8202000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44943, 'San Andrés del Rabanedo', 'San Andres del Rabanedo', 'San Andres de Rabanedo,San Andres del Rabanedo,San Andrés de Rabanedo,San Andrés del Rabanedo,San-Andres-del''-Rabanedo,sheng an de lei si de er la wa nei duo,Сан-Андрес-дель-Рабанедо,圣安德雷斯德尔拉瓦内多', 42.6117400, -5.6167100, 'ES', '2015-12-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44944, 'Sant Andreu de Llavaneres', 'Sant Andreu de Llavaneres', '', 41.5666700, 2.4833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44945, 'San Andrés del Congosto', 'San Andres del Congosto', 'San Andres del Congosto,San Andrés del Congosto', 40.9977500, -3.0242300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44946, 'Sant Andreu de la Barca', 'Sant Andreu de la Barca', 'San Andres de la Barca,San Andrés de la Barca,Sant Andreu de la Barca', 41.4465900, 1.9718700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44947, 'San Amaro', 'San Amaro', 'San Amaro', 42.3738500, -8.0734700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44948, 'San Agustín del Pozo', 'San Agustin del Pozo', 'San Agustin del Pozo,San Agustín del Pozo', 41.8861300, -5.5935100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44949, 'San Agustín de Guadalix', 'San Agustin de Guadalix', 'San Agustin,San Agustin del Guadalix,San Agustín,San Agustín del Guadalix', 40.6788200, -3.6163900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44950, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', 40.0500000, -0.6833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44951, 'San Adrián del Valle', 'San Adrian del Valle', 'San Adrian del Valle,San Adrián del Valle', 42.1303300, -5.7290500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44952, 'San Adrián de Juarros', 'San Adrian de Juarros', 'San Adrian de Juarros,San Adrián de Juarros', 42.2742700, -3.4755100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44953, 'Sant Adrià de Besòs', 'Sant Adria de Besos', 'San Adrian de Besos,San Adrián de Besós,Sant Adria,Sant Adria de Besos,Sant Adrià,Sant Adrià de Besòs,Sant Adrià de Besós,Sant-Adria-da-Bazos,san adryan dy byzws,sang ta de li ya de wei suo si,Сант-Адріа-да-Базос,سان أدريان دي بيزوس,サント・アドリアー・ダ・バゾス,桑塔德里亚德韦索斯', 41.4307300, 2.2185500, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44954, 'San Adrián', 'San Adrian', 'San Adrian,San Adrián', 42.3343300, -1.9350900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44955, 'Sant Iscle de Vallalta', 'Sant Iscle de Vallalta', 'San Acisclo de Vallalta,Sant Iscle de Vallalta', 41.6166700, 2.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44956, 'Samper del Salz', 'Samper del Salz', 'Samper del Sal,Samper del Salz', 41.2345800, -0.8251000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44957, 'Samper de Calanda', 'Samper de Calanda', 'Samper de Calanda,Samper de Galanda', 41.1893300, -0.3888300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44958, 'Santpedor', 'Santpedor', 'Sampedor,Sanpedor,Santpedor', 41.7830900, 1.8467300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44959, 'Samos', 'Samos', 'Samos,sa mo si,samosu,Самос,Սամոս,サモス,萨莫斯', 42.7310000, -7.3258200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44960, 'Samir de los Caños', 'Samir de los Canos', 'Samir de los Canos,Samir de los Caños', 41.6728000, -6.1641500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44961, 'Samboal', 'Samboal', 'Samboal', 41.2575800, -4.4172700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44962, 'Samaniego', 'Samaniego', 'Samaniego', 42.5685400, -2.6797400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44963, 'Sama', 'Sama', 'Langreo,Llangreu,Llangréu,Sama de Langreo,Same,Саме', 43.2956800, -5.6841600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44964, 'Salvatierra de Tormes', 'Salvatierra de Tormes', 'Salvatierra,Salvatierra de Tormes', 40.5900700, -5.5976300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44965, 'Salvatierra de Esca', 'Salvatierra de Esca', 'Salvatierra,Salvatierra de Esca', 42.6700200, -1.0047500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44966, 'Agurain / Salvatierra', 'Salvatierra', 'Agurain,Salvatierra', 42.8516200, -2.3912300, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44967, 'Salvador de Zapardiel', 'Salvador de Zapardiel', 'Salvador de Zapardiel', 41.1169600, -4.8748600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44968, 'Salvadiós', 'Salvadios', 'Salvadios,Salvadiós', 40.8783600, -5.0962900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44969, 'Salvacañete', 'Salvacanete', 'Salvacanete,Salvacañete', 40.1000000, -1.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44970, 'Salt', 'Salt', 'Salt', 41.9748900, 2.7928100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44971, 'Salou', 'Salou', 'Salou,sa luo,salw,sarou,Салоу,سالو,サロウ,萨洛', 41.0766300, 1.1416300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44972, 'Salomó', 'Salomo', 'Salomo,Salomó', 41.2295500, 1.3744500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44973, 'Salobral', 'Salobral', 'Salobral', 40.6117900, -4.8101300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44974, 'Salmoral', 'Salmoral', 'Salmoral', 40.8013700, -5.2191000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44975, 'Salmerón', 'Salmeron', 'Salmeron,Salmerón', 40.5452900, -2.4931500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44976, 'Sallent de Gállego', 'Sallent de Gallego', 'Sal''ent-de-Gal''ego,Sallen de Galligo,Sallent,Sallent de Gallego,Sallent de Galligo,Sallén de Galligo,sa lian te de jia lie ge,Сальент-де-Гальего,Сальєнт-де-Гальєго,萨连特德加列戈', 42.7712700, -0.3344800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44977, 'Sallent', 'Sallent', 'Sallent,Sallent de Llobregat', 41.8260200, 1.8955000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44978, 'Salinillas de Bureba', 'Salinillas de Bureba', 'Salinillas de Bureba', 42.5524300, -3.3875300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44979, 'Salinas de Pisuerga', 'Salinas de Pisuerga', 'Salinas de Pisuerga', 42.8504600, -4.3778300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44980, 'Salinas de Oro', 'Salinas de Oro', '', 42.7748700, -1.8899900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44981, 'Salinas del Manzano', 'Salinas del Manzano', 'Salinas del Manzano', 40.0833300, -1.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44982, 'Leintz-Gatzaga', 'Leintz-Gatzaga', 'Gatzaga,Leintz Gatzaga,Salinas de Leniz,Salinas de Léniz', 42.9868400, -2.5685100, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44983, 'Salillas de Jalón', 'Salillas de Jalon', 'Salillas de Jalon,Salillas de Jalón', 41.5678900, -1.3234400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44984, 'Salillas', 'Salillas', 'Salillas', 41.9949800, -0.2227800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44985, 'Salduero', 'Salduero', 'Salduero', 41.8894600, -2.7967000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44986, 'Saldón', 'Saldon', 'Saldon,Saldón', 40.3251300, -1.4278200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44987, 'Saldías', 'Saldias', 'Saldias,Saldías', 43.0885800, -1.7794600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44988, 'Saldes', 'Saldes', '', 42.2333300, 1.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44989, 'Saldeana', 'Saldeana', 'Saldeana', 41.0206800, -6.6401500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44990, 'Saldaña de Burgos', 'Saldana de Burgos', '', 42.2583800, -3.6970700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44991, 'Saldaña', 'Saldana', 'Sal''dan''ja,Saldanya,sa er da ni ya,Сальданья,萨尔达尼亚', 42.5214600, -4.7360500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44992, 'Salcedillo', 'Salcedillo', 'Salcedillo', 40.9620000, -1.0043300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44993, 'Salce', 'Salce', 'Salce', 41.2699600, -6.2187500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44994, 'Salas de los Infantes', 'Salas de los Infantes', 'Salas-de-los-Infantes,sa la si de luo xin fan te si,salas dy lws anfants,Салас-де-лос-Інфантес,Салас-де-лос-Инфантес,سالاس دي لوس إنفانتس,萨拉斯德洛辛凡特斯', 42.0224200, -3.2863100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44995, 'Sales de Llierca', 'Sales de Llierca', 'Salas de Llierca,Sales de Llierca', 42.2333300, 2.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44996, 'Salas de Bureba', 'Salas de Bureba', 'Salas de Bureba', 42.6919000, -3.4735900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44997, 'Salas Bajas', 'Salas Bajas', 'Salas Bajas', 42.1004600, 0.0834900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44998, 'Salas Altas', 'Salas Altas', 'Salas Altas', 42.1140700, 0.0682100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(44999, 'Salas', 'Salas', 'Salas', 43.4118000, -6.2602300, 'ES', '2014-02-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45000, 'Salamanca', 'Salamanca', 'Helmantica,SLM,Salamanca,Salamanka,Salamanko,Salamanque,Salmantica,saramanka,slmnqt,Саламанка,سلمنقة,サラマンカ', 40.9688200, -5.6638800, 'ES', '2015-04-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45001, 'Sajazarra', 'Sajazarra', 'Sajazarra', 42.5888400, -2.9612400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45002, 'Sahagún', 'Sahagun', 'Saagun,Safagun,Safagún,Sahagun,Sahagún,Sant Fagund,sa a gong,saagun,sahagwn,Саагун,ساهاگون,سہاگن، اسپین,サアグン,萨阿贡', 42.3708500, -5.0294200, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45003, 'Sagàs', 'Sagas', 'Sagas,Sagàs,Sagás', 42.0500000, 1.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45004, 'Saelices el Chico', 'Saelices el Chico', 'Saelices,Saelices el Chico', 40.6699800, -6.6327100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45005, 'Saelices de Mayorga', 'Saelices de Mayorga', 'Saelices de Mayorga', 42.2120600, -5.2053400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45006, 'Saelices de la Sal', 'Saelices de la Sal', 'Saelices de la Sal', 40.9072300, -2.3232500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45007, 'Sádaba', 'Sadaba', 'Sadaba,Sádaba', 42.2818000, -1.2695100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45008, 'Sada', 'Sada', 'Sada,Sada da Area,Santa Maria de Sada,Santa María de Sada', 43.3561900, -8.2579600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45009, 'Sacramenia', 'Sacramenia', 'Sacramenia', 41.4941900, -3.9621000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45010, 'Sacedón', 'Sacedon', 'Sacedon,Sacedón', 40.4807600, -2.7333700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45011, 'Saceda-Trasierra', 'Saceda-Trasierra', 'Saceda-Trasierra', 40.1552500, -2.8536900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45012, 'Sacecorbo', 'Sacecorbo', 'Sacecorbo', 40.8328000, -2.4183800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45013, 'Sabiñánigo', 'Sabinanigo', 'Sabin''janigo,Sabinanigo,Sabiñánigo,Samianigo,sa wei ni ya ni ge,Сабиньяниго,Сабіньяніго,萨维尼亚尼戈', 42.5192400, -0.3660700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45014, 'Sabero', 'Sabero', 'Sabero', 42.8359300, -5.1487500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45015, 'Sabadell', 'Sabadell', 'QSA,Sabadell', 41.5432900, 2.1094200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45016, 'Rupià', 'Rupia', 'Rupia,Rupià,Rupiá', 42.0166700, 3.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45017, 'Ruesga', 'Ruesga', 'Ruesga', 42.8641300, -4.5294200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45018, 'Ruesca', 'Ruesca', 'Ruesca', 41.2835000, -1.4814200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45019, 'Ruente', 'Ruente', 'Ruente', 43.2582600, -4.2679100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45020, 'Rueda de la Sierra', 'Rueda de la Sierra', 'Rueda de la Sierra', 40.9179500, -1.8543900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45021, 'Rueda', 'Rueda', 'Rueda,Ruehda,Руеда,Руэда,Ռուեդա', 41.4123100, -4.9588500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45022, 'Rucandio', 'Rucandio', 'Rucandio', 42.7511100, -3.5416600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45023, 'Rublacedo de Abajo', 'Rublacedo de Abajo', 'Rublacedo de Abajo', 42.5533200, -3.5023600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45024, 'Rubielos de Mora', 'Rubielos de Mora', 'Rubielos,Rubielos de Mora,Rubiols', 40.1889400, -0.6530700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45025, 'Rubielos de la Cérida', 'Rubielos de la Cerida', 'Rubielos de la Cerida,Rubielos de la Cérida', 40.7705800, -1.2129100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45026, 'Rubí de Bracamonte', 'Rubi de Bracamonte', 'Rubi de Bracamonte,Rubí de Bracamonte', 41.2142100, -4.9249100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45027, 'Rubiales', 'Rubiales', 'Rubiales', 40.2762300, -1.2716700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45028, 'Rubí', 'Rubi', 'Rubi,Rubí,Руби', 41.4922600, 2.0330500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45029, 'Rubena', 'Rubena', '', 42.3874600, -3.5748500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45030, 'Rozas de Puerto Real', 'Rozas de Puerto Real', 'Rozas de Puerto Real', 40.3166700, -4.4833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45031, 'Royuela de Río Franco', 'Royuela de Rio Franco', 'Royuela de Rio Franco,Royuela de Río Franco', 42.0021700, -3.9554700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45032, 'Royuela', 'Royuela', '', 40.3784600, -1.5133700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45033, 'Roturas', 'Roturas', 'Roturas', 41.6679100, -4.1190100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45034, 'Rosell', 'Rosell', 'Rosell,Rossell', 40.6179200, 0.2213300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45035, 'Roses', 'Roses', 'Rhode,Rosas,Roses,Росас', 42.2619900, 3.1768900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45036, 'O Rosal', 'O Rosal', '', 41.9353600, -8.8367700, 'ES', '2012-02-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45037, 'Roperuelos del Páramo', 'Roperuelos del Paramo', 'Roperuelos del Paramo,Roperuelos del Páramo', 42.2378000, -5.7823500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45038, 'Romanos', 'Romanos', 'Romanos', 41.1263600, -1.2750200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45039, 'Romanones', 'Romanones', 'Romanones', 40.5714900, -2.9907200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45040, 'Romanillos de Atienza', 'Romanillos de Atienza', 'Romanillos de Atienza', 41.2666700, -2.9000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45041, 'Rollán', 'Rollan', 'Rollan,Rollán', 40.9623000, -5.9175300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45042, 'Rollamienta', 'Rollamienta', 'Rollamienta', 41.9259200, -2.5312500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45043, 'Rojas', 'Rojas', 'Rojas', 42.5778100, -3.4419500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45044, 'Rois', 'Rois', 'Rois', 42.7629500, -8.7052800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45045, 'Rodezno', 'Rodezno', '', 42.5257600, -2.8459700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45046, 'Ródenas', 'Rodenas', 'Rodenas,Ródenas', 40.6407600, -1.5161700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45047, 'Rodeiro', 'Rodeiro', '', 42.6519300, -7.9551900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45048, 'Roda de Eresma', 'Roda de Eresma', 'Roda de Eresma', 41.0285200, -4.1813000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45049, 'Roda de Barà', 'Roda de Bara', 'Roda de Bara,Roda de Barà,Roda de Bará,Roda de Bera,Roda de Berà,Roda-de-Bara,luo da de wa la,rda d bara,Рода-де-Бара,Ռոդա դե Բարա,ردا د بارا,罗达德瓦拉', 41.1864500, 1.4589300, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45050, 'Robres del Castillo', 'Robres del Castillo', 'Robres del Castillo,Robres del Kastilio,Robres-del''-Kastil''jo,Robres-del''-Kastil''o,luo fu lei si de er ka si di e,Робрес-дель-Кастильо,Робрес-дель-Кастільйо,Ռոբրես դել Կաստիլիո,罗夫雷斯德尔卡斯蒂略', 42.2759300, -2.2924500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45051, 'Robres', 'Robres', 'Robre,Robres', 41.8674600, -0.4609400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45052, 'Robregordo', 'Robregordo', 'Robregordo', 41.1065700, -3.5936900, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45053, 'Robliza de Cojos', 'Robliza de Cojos', 'Robliza de Cojos,Robliza de los Cojos', 40.8676600, -5.9778600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45054, 'Robledo de Corpes', 'Robledo de Corpes', 'Robledo de Corpes', 41.1183800, -2.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45055, 'Robledo de Chavela', 'Robledo de Chavela', 'Robledo-de-Chavela,luo fu lai duo de cha wei la,rwblydw dy tshafyla,Робледо-де-Чавела,روبليدو دي تشافيلا,罗夫莱多德查韦拉', 40.5006200, -4.2363500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45056, 'Robledillo de Mohernando', 'Robledillo de Mohernando', 'Robledillo de Mohernando', 40.8511800, -3.2316200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45057, 'Robledillo de la Vera', 'Robledillo de la Vera', 'Robledillo de la Vera', 40.1009300, -5.5889600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45058, 'Robledillo de la Jara', 'Robledillo de la Jara', 'Robledillo de la Jara', 40.9505400, -3.5218100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45059, 'Robledillo de Gata', 'Robledillo de Gata', '', 40.3223400, -6.4712900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45060, 'Robleda-Cervantes', 'Robleda-Cervantes', 'Robleda,Robleda-Cervantes', 42.0824600, -6.5941400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45061, 'Robleda', 'Robleda', 'Robleda', 40.3846900, -6.6072600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45062, 'Robladillo', 'Robladillo', 'Robladillo', 41.6083800, -4.9099200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45063, 'Roales', 'Roales', 'Roales', 41.5517000, -5.7721100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45064, 'Roa', 'Roa', 'Roa,Roa de Duero,luo a,rwa  brghsh,Роа,روا، برغش,罗阿', 41.6969900, -3.9278200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45065, 'Rivilla de Barajas', 'Rivilla de Barajas', 'Rivilla de Barajas', 40.9021000, -4.9883600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45066, 'Riumors', 'Riumors', 'Riumors', 42.2272600, 3.0419000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45067, 'Riudoms', 'Riudoms', 'Riudors,Ruidoms,Ruidons', 41.1333300, 1.0500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45068, 'Riudellots de la Selva', 'Riudellots de la Selva', '', 41.8932700, 2.8045200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45069, 'Riudecols', 'Riudecols', 'Riudecols', 41.1690000, 0.9762500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45070, 'Riudecanyes', 'Riudecanyes', 'Riudecanas,Riudecanyes,Riudecañas,Ruidecana,Ruidecaña,Ríudecañas', 41.1333300, 0.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45071, 'Riudarenes', 'Riudarenes', 'Riudarenas,Riudarenes', 41.8166700, 2.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45072, 'Ripollet', 'Ripollet', 'Ripol''et,Ripollet,Ripolyet,Ripul''et,li bo lie te,rybwlyt,rypyt,Рипольет,Ріпульєт,Ռիպոլյետ,ريبوليت,ریپیت,里波列特', 41.4968600, 2.1573900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45073, 'Ripoll', 'Ripoll', 'Ripoll,Rivipolli,Rivipullo', 42.2006400, 2.1903300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45074, 'Ríotorto', 'Riotorto', 'Riotorto,Ríotorto,San Pedro', 43.3500000, -7.2333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45075, 'Riós', 'Rios', 'Rios,Riós', 41.9745700, -7.2823400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45076, 'Ríofrío de Aliste', 'Riofrio de Aliste', 'Riofrio,Riofrio de Aliste,Ríofrío de Aliste', 41.8172400, -6.1774100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45077, 'Riodeva', 'Riodeva', 'Riodeva', 40.1166700, -1.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45078, 'Riocavado de la Sierra', 'Riocavado de la Sierra', 'Riocabado de la Sierra,Riocavado de la Sierra', 42.1520900, -3.1975900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45079, 'Ruayer', 'Ruayer', 'Rio Aller,Río Aller', 43.0537200, -5.5501900, 'ES', '2017-02-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45080, 'Rincón de Soto', 'Rincon de Soto', 'Rinkon de Soto,Rinkon-de-Soto,lin kong de suo tuo,Ринкон-де-Сото,Рінкон-де-Сото,Ռինկոն դե Սոտո,林孔德索托', 42.2347500, -1.8521400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45081, 'Rillo de Gallo', 'Rillo de Gallo', 'Rillo de Gallo', 40.8663500, -1.9374000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45082, 'Rillo', 'Rillo', 'Rillo', 40.7223300, -0.9962300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45083, 'Errigoiti', 'Errigoiti', 'Errigoiti,Rigoitia', 43.3166700, -2.7166700, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45084, 'Riells i Viabrea', 'Riells i Viabrea', 'Riells,Riells i Viabrea', 41.7833300, 2.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45085, 'Riego de la Vega', 'Riego de la Vega', 'Riego de la Vega', 42.3913800, -5.9810200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45086, 'Ricla', 'Ricla', 'Ricla', 41.5058000, -1.4046800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45087, 'Ribota', 'Ribota', 'Ribota', 41.3647700, -3.4296400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45088, 'Ribesalbes', 'Ribesalbes', 'Ribesalbes', 40.0166700, -0.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45089, 'Riberos de la Cueza', 'Riberos de la Cueza', 'Riberos de la Cueza', 42.2788100, -4.7250300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45090, 'Ribeira', 'Ribeira', 'Ribeira', 42.7461100, -8.4439200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45091, 'Ribatejada', 'Ribatejada', 'Ribatejada', 40.6642000, -3.3897600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45092, 'Luintra', 'Luintra', 'San Estebo', 42.4096400, -7.7268200, 'ES', '2007-02-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45093, 'Ribes de Freser', 'Ribes de Freser', 'Ribes de Freser', 42.3041700, 2.1675700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45094, 'Ribas de Campos', 'Ribas de Campos', 'Ribas,Ribas de Campos', 42.1524900, -4.5164900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45095, 'Ribaforada', 'Ribaforada', 'Ribaforada', 41.9981400, -1.5127200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45096, 'Ribadumia', 'Ribadumia', 'Ribadumia,Santa Eulalia', 42.5166700, -8.7500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45097, 'Ribadesella', 'Ribadesella', 'Ribadesel''ja,Ribadeselja,Ribadesella,Ribesella,Ribeseya,li wa de sai li ya,rybadsya,rybadysya,Рибадеселья,Рібадеселья,ريباديسيا,ریبادسیا,里瓦德塞利亚', 43.4614500, -5.0595500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45098, 'Riba de Saelices', 'Riba de Saelices', 'Riba de Saelices', 40.9114500, -2.2971500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45099, 'Ribadeo', 'Ribadeo', 'Ribadeo', 43.5370400, -7.0409500, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45100, 'Ribadavia', 'Ribadavia', 'Abobrica,Adobriga', 42.2880400, -8.1436200, 'ES', '2012-10-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45101, 'Riaza', 'Riaza', 'Riasa,Riaza,Riofrio de Riaza,li ya sa,Риаса,Ріаса,里亚萨', 41.2782600, -3.4778700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45102, 'Riaño', 'Riano', 'Riano,Riaño', 42.9770500, -5.0035200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45103, 'Rianxo', 'Rianxo', 'Rianxo', 42.6497700, -8.8176300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45104, 'Riaguas de San Bartolomé', 'Riaguas de San Bartolome', 'Riaguas de San Bartolome,Riaguas de San Bartolomé', 41.4264000, -3.4889300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45105, 'Reznos', 'Reznos', 'Reznos', 41.5909000, -2.0277900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45106, 'Rezmondo', 'Rezmondo', 'Rezmondo', 42.5156500, -4.2387700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45107, 'Reyero', 'Reyero', 'Reyero', 42.9488200, -5.1989200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45108, 'Revillarruz', 'Revillarruz', 'Revillarruz', 42.2300600, -3.6524600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45109, 'Revilla del Campo', 'Revilla del Campo', 'Revilla del Campo', 42.2108100, -3.5428900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45110, 'Revilla de Collazos', 'Revilla de Collazos', 'Revilla de Collazos', 42.6296000, -4.5034300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45111, 'Revenga de Campos', 'Revenga de Campos', 'Revenga de Campos', 42.2840100, -4.4821800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45112, 'Revellinos', 'Revellinos', 'Revellinos', 41.8898200, -5.5687100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45113, 'Reus', 'Reus', 'REU,Reus,Реус', 41.1561200, 1.1068700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45114, 'Retuerta', 'Retuerta', 'Retuerta', 42.0294500, -3.5067900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45115, 'Retortillo de Soria', 'Retortillo de Soria', 'Retortil''jo-de-Sorija,Retortil''o-de-Sorija,Retortillo,Retortillo de Soria,lei tuo er di e de suo li ya,Ретортильо-де-Сория,Ретортільйо-де-Сорія,雷托尔蒂略德索里亚', 41.3109200, -2.9822800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45116, 'Retortillo', 'Retortillo', 'Retortillo', 40.8013200, -6.3595100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45117, 'Retiendas', 'Retiendas', 'Retiendas', 40.9683500, -3.2722900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45118, 'Retascón', 'Retascon', '', 41.1435000, -1.3837600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45119, 'Respenda de la Peña', 'Respenda de la Pena', 'Respenda de la Pena,Respenda de la Peña', 42.7651200, -4.6854000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45120, 'Requena de Campos', 'Requena de Campos', 'Requena de Campos', 42.3079600, -4.3430400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45121, 'Requejo', 'Requejo', 'Requejo', 42.0304400, -6.7422700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45122, 'Reocín', 'Reocin', 'Reocin,Reocín', 43.3391500, -4.0940300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45123, 'Errenteria', 'Errenteria', 'Errenteria,Orereta,Renteria,Rentería', 43.3119500, -1.9023400, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45124, 'Renieblas', 'Renieblas', 'Renieblas', 41.8200900, -2.3723600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45125, 'Renera', 'Renera', 'Renera', 40.4897600, -3.0136700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45126, 'Renedo de la Vega', 'Renedo de la Vega', 'Renedo de la Vega', 42.4534800, -4.7029800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45127, 'Renau', 'Renau', 'Renau', 41.2244800, 1.3108300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45128, 'Remondo', 'Remondo', 'Remondo', 41.3410000, -4.4839000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45129, 'Remolinos', 'Remolinos', 'Remolinos', 41.8394600, -1.1776800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45130, 'Rello', 'Rello', 'Rello', 41.3329700, -2.7492500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45131, 'Reinoso de Cerrato', 'Reinoso de Cerrato', 'Reinoso de Cerrato', 41.9762400, -4.3833700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45132, 'Reinoso', 'Reinoso', 'Reinoso', 42.5091500, -3.3846600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45133, 'Reinosa', 'Reinosa', 'Reinosa,Rejnosa,lei nuo sa,raynwsa,reinosa,Рейноса,راينوسا,レイノーサ,雷诺萨', 42.9995900, -4.1380100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45134, 'Regumiel de la Sierra', 'Regumiel de la Sierra', 'Regumiel de la Sierra', 41.9562300, -2.9884300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45135, 'Regueras de Arriba', 'Regueras de Arriba', '', 42.2941400, -5.8595800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45136, 'Errezil', 'Errezil', 'Errezil,Regil,Régil', 43.1650500, -2.1739500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45137, 'Regencós', 'Regencos', 'Regencos,Regencós', 41.9527100, 3.1700600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45138, 'Redueña', 'Reduena', 'Reduena,Redueña', 40.8168500, -3.5983700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45139, 'Redondela', 'Redondela', 'Redondela,Редондела', 42.2833700, -8.6096000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45140, 'Redecilla del Campo', 'Redecilla del Campo', 'Redecilla del Campo', 42.4667500, -3.1153100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45141, 'Redecilla del Camino', 'Redecilla del Camino', 'Redecilla del Camino', 42.4380400, -3.0654700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45142, 'Recuerda', 'Recuerda', 'Recuerda,Rekuehrda,Rekuerda,lei ku ai er da,Рекуерда,Рекуэрда,雷库埃尔达', 41.4740800, -2.9946000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45143, 'Recas', 'Recas', 'Recas', 40.0528600, -3.9909000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45144, 'Rebollosa de Jadraque', 'Rebollosa de Jadraque', 'Rebollosa de Jadraque', 41.0904000, -2.8420100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45145, 'Rebollo', 'Rebollo', 'Rebollo', 41.1931800, -3.8577100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45146, 'Rebolledo de la Torre', 'Rebolledo de la Torre', 'Rebol''edo-de-la-Torre,Rebolledo de la Torre,lei wo lie duo de la tuo lei,rybwlydw dy la twry,Ребольедо-де-ла-Торре,Ребольєдо-де-ла-Торре,ريبوليدو دي لا توري,雷沃列多德拉托雷', 42.6893100, -4.2269300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45147, 'Rasueros', 'Rasueros', 'Rasueros', 41.0234400, -5.0737700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45148, 'Rasquera', 'Rasquera', 'Rasquera', 41.0026700, 0.5996700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45149, 'Rasines', 'Rasines', 'Rasines', 43.3050500, -3.4291900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45150, 'Rascafría', 'Rascafria', 'Rascafria,Rascafría,Raskafria,Raskafrija,Raskafrio,la si ka fu li ya,raskafra,Раскафриа,Раскафрія,راسكافرا,拉斯卡夫里亚', 40.9040700, -3.8789800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45151, 'Rapariegos', 'Rapariegos', 'Rapariegos', 41.0949800, -4.6527100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45152, 'Ramiro', 'Ramiro', 'Ramiro', 41.2284500, -4.7860800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45153, 'Ramales de la Victoria', 'Ramales de la Victoria', 'Ramales,Ramales de la Victoria,Ramales-de-la-Viktoria,Ramales-de-la-Viktorija,la ma lai si de la wei ke tuo li ya,ramalys dy la fyktwrya,Рамалес-де-ла-Викториа,Рамалес-де-ла-Вікторія,راماليس دي لا فيكتوريا,拉马莱斯德拉维克托里亚', 43.2572000, -3.4651600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45154, 'Rajadell', 'Rajadell', 'Rajadell', 41.7280200, 1.7062100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45155, 'Rairiz de Veiga', 'Rairiz de Veiga', 'Rairiz de Veiga', 42.0836400, -7.8350300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45156, 'Rágama', 'Ragama', 'Ragama,Rágama', 40.9976800, -5.1272400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45157, 'Ráfales', 'Rafales', 'Rafales,Rafels,Ráfales,Ráfels', 40.8377000, 0.0192300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45158, 'Rabós', 'Rabos', 'Rabos,Rabós', 42.3789000, 3.0282800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45159, 'Rabé de las Calzadas', 'Rabe de las Calzadas', 'Rabe de las Calzadas,Rabé de las Calzadas', 42.3406500, -3.8341400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45160, 'Rábanos', 'Rabanos', 'Rabanos,Rábanos', 42.3197100, -3.2702900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45161, 'Rábano de Aliste', 'Rabano de Aliste', 'Rabano de Aliste,Rábano de Aliste', 41.7443000, -6.4330200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45162, 'Rábano', 'Rabano', 'Rabano,Rábano', 41.5331400, -4.0621400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45163, 'Rabanera del Pinar', 'Rabanera del Pinar', 'Rabanera del Pinar,Rabanera-del''-Pinar,la wa nei la de er pi na er,rabanyra dyl baynar,Рабанера-дель-Пинар,Рабанера-дель-Пінар,رابانيرا ديل باينار,拉瓦内拉德尔皮纳尔', 41.8937500, -3.1966500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45164, 'Rabanera', 'Rabanera', 'Rabanera', 42.1895500, -2.4865400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45165, 'Rabanales', 'Rabanales', 'Rabanales', 41.7428700, -6.2767400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45166, 'Rábade', 'Rabade', 'Rabade,Rábade,Santa Marina', 43.1170000, -7.6171400, 'ES', '2015-07-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45167, 'Quismondo', 'Quismondo', 'Quismondo', 40.1053300, -4.3239400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45168, 'Quiruelas de Vidriales', 'Quiruelas de Vidriales', 'Quiruelas de Vidriales', 42.0176200, -5.8294700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45169, 'Quiroga', 'Quiroga', 'Quiroga', 42.4767800, -7.2746300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45170, 'Quinto', 'Quinto', 'Quinto', 41.4237800, -0.4959200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45171, 'Quintela de Leirado', 'Quintela de Leirado', '', 42.1396700, -8.1012600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45172, 'Quintanilla de Urz', 'Quintanilla de Urz', 'Quintanilla de Urz', 42.0329000, -5.8486600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45173, 'Quintanilla de Trigueros', 'Quintanilla de Trigueros', 'Quintanilla,Quintanilla de Trigueros', 41.8544900, -4.6593100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45174, 'Quintanilla de Onsoña', 'Quintanilla de Onsona', 'Kintanil''ja-de-Onson''ja,Kintanil''ja-de-Onsonija,Quintanilla de Onsona,Quintanilla de Onsoña,jin ta ni li ya de weng suo ni ya,Кинтанилья-де-Онсония,Кінтанілья-де-Онсонья,金塔尼利亚德翁索尼亚', 42.4693700, -4.6638500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45175, 'Quintanilla de Onésimo', 'Quintanilla de Onesimo', 'Quintanilla de Abajo,Quintanilla de Onesimo,Quintanilla de Onésimo', 41.6249000, -4.3629100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45176, 'Quintanilla del Olmo', 'Quintanilla del Olmo', 'Quintanilla del Olmo', 41.9056100, -5.4072600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45177, 'Quintanilla del Monte', 'Quintanilla del Monte', 'Quintanilla,Quintanilla del Monte', 41.8681200, -5.3492800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45178, 'Quintanilla del Molar', 'Quintanilla del Molar', 'Quintanilla del Molar', 41.9893500, -5.4492800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45179, 'Quintanilla del Coco', 'Quintanilla del Coco', 'Quintanilla del Coco', 41.9833300, -3.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45180, 'Quintanilla de la Mata', 'Quintanilla de la Mata', 'Quintanilla de la Mata', 41.9885500, -3.7675600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45181, 'Quintanilla de Arriba', 'Quintanilla de Arriba', 'Quintanilla de Arriba', 41.6197400, -4.2177400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45182, 'Quintana y Congosto', 'Quintana y Congosto', 'Quintana y Congosto', 42.2558500, -6.0363600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45183, 'Quintanavides', 'Quintanavides', 'Quintanavides', 42.4808400, -3.4244900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45184, 'Quintanas de Gormaz', 'Quintanas de Gormaz', 'Quintanas de Gormaz', 41.5092600, -2.9763100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45185, 'Quintana Redonda', 'Quintana Redonda', 'Kintana-Redonda,Quintana Redonda,jin ta na lei dong da,Кинтана-Редонда,Кінтана-Редонда,金塔纳雷东达', 41.6390500, -2.6144900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45186, 'Quintanar de la Sierra', 'Quintanar de la Sierra', 'Quintanar de la Sierra', 41.9828800, -3.0376500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45187, 'Quintanapalla', 'Quintanapalla', '', 42.4091400, -3.5329600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45188, 'Quintanaortuño', 'Quintanaortuno', 'Quintanaortuno,Quintanaortuño', 42.4500000, -3.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45189, 'Quintanaélez', 'Quintanaelez', 'Quintanaelez,Quintanaélez', 42.6692100, -3.2987700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45190, 'Quintana del Puente', 'Quintana del Puente', 'Quintana del Puente', 42.0847100, -4.2064900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45191, 'Quintana del Pidio', 'Quintana del Pidio', 'Quintana del Pidio', 41.7588600, -3.7512100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45192, 'Quintana del Marco', 'Quintana del Marco', 'Quintana del Marco', 42.2067000, -5.8503000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45193, 'Quintana del Castillo', 'Quintana del Castillo', 'Quintana del Castillo', 42.6598700, -6.0497800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45194, 'Quintanabureba', 'Quintanabureba', 'Quintanabureba', 42.5866500, -3.3668500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45195, 'Quijorna', 'Quijorna', 'Quijorna', 40.4276300, -4.0568300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45196, 'Quicena', 'Quicena', '', 42.1479700, -0.3604900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45197, 'Querol', 'Querol', 'Querol', 41.4229300, 1.3968400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45198, 'Quer', 'Quer', 'Quer', 40.6053200, -3.2753000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45199, 'Quemada', 'Quemada', '', 41.7007300, -3.5747600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45200, 'Quel', 'Quel', 'Kel,Kel'',Quel,Кель,Կել', 42.2297900, -2.0519600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45201, 'Quart d’Onyar', 'Quart d''Onyar', 'Quart,Quart d''Onyar,Quart d’Onyar', 41.9404700, 2.8407900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45202, 'Purujosa', 'Purujosa', 'Purujosa', 41.6825900, -1.7651900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45203, 'Puras', 'Puras', 'Puras', 41.1833300, -4.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45204, 'Punxín', 'Punxin', 'Las Pungin,Santa Maria,Santa María', 42.3707200, -8.0105800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45205, 'Pujalt', 'Pujalt', 'Pujalt', 41.7171000, 1.4208800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45206, 'Puig-reig', 'Puig-reig', 'Puig-reig,Puigreig', 41.9666700, 1.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45207, 'Puigpelat', 'Puigpelat', 'Puigpelat', 41.2789900, 1.2971300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45208, 'Puigcerdà', 'Puigcerda', 'Puigcerda,Puigcerdà', 42.4316000, 1.9281900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45209, 'Pueyo de Santa Cruz', 'Pueyo de Santa Cruz', 'Puidemoros', 41.8579900, 0.1566000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45210, 'Pueyo', 'Pueyo', 'Pueyo', 42.5650600, -1.6482600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45211, 'Puerto Seguro', 'Puerto Seguro', 'Puerto Seguro', 40.8271800, -6.7610900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45212, 'Puertomingalvo', 'Puertomingalvo', 'Puertomingalvo', 40.2643000, -0.4575600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45213, 'Portomarín', 'Portomarin', 'Portomarin,Portomarín,Puehrtomarin,Puertomarin,Puertomarín,San Pedro,bo er tuo ma lin,porutomarin,Портомарін,Пуэртомарин,ポルトマリン,波尔托马林', 42.8062000, -7.6164400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45214, 'Puértolas', 'Puertolas', '', 42.5474800, 0.1321400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45215, 'Puerto de Béjar', 'Puerto de Bejar', 'Puerto de Bejar,Puerto de Béjar', 40.3505200, -5.8375600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45216, 'Puerto Castilla', 'Puerto Castilla', 'Puerto Castilla', 40.2880000, -5.6236600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45217, 'Puertas', 'Puertas', 'Puertas', 41.0968100, -6.2875200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45218, 'Puente Viesgo', 'Puente Viesgo', 'Puehnte-V''esgo,Puente Viesgo,Puente-Vesgo,bwynty faysjw,peng te wei ye si ge,Пуенте-Вєсго,Пуэнте-Вьесго,بوينتي فايسجو,蓬特维耶斯戈', 43.2981500, -3.9681700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45219, 'As Pontes de García Rodríguez', 'As Pontes de Garcia Rodriguez', 'As Pontes De Garcia Rodriguez,As Pontes De García Rodríguez,As Pontes de Garcia Rodriguez,As Pontes de García Rodríguez', 43.4526600, -7.8517800, 'ES', '2014-02-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45220, 'Puente la Reina', 'Puente la Reina', 'Gares,Pons Reginae,Pont de la Reina,Puehnte-la-Rejna,Puent de la Reina,Puente La Reina,Puente La Reina – Gares,Puente de la Reina,Puente la Reina-Gares,Puente-la-Rejna,peng te la lei na,Пуенте-ла-Рейна,Пуэнте-ла-Рейна,プエンテ・ラ・レイナ,蓬特拉雷纳', 42.6729100, -1.8141200, 'ES', '2007-11-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45221, 'Puentedura', 'Puentedura', 'Puentedura', 42.0413400, -3.5822700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45222, 'Puente de Vallecas', 'Puente de Vallecas', 'Barrio Puente de Vallecas,Ponto de Valjeko,Puente de Vallecas,Puente de Vallecas distritu,プエンテ・デ・バリェカス', 40.3935400, -3.6620000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45223, 'Puente del Congosto', 'Puente del Congosto', 'Puente del Congosto', 40.4904100, -5.5262800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45224, 'Puente de Domingo Flórez', 'Puente de Domingo Florez', 'Puente de Domingo Florez,Puente de Domingo Flórez', 42.4116600, -6.8207700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45225, 'Ponte Caldelas', 'Ponte Caldelas', '', 42.3891100, -8.5023500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45226, 'Ponteareas', 'Ponteareas', '', 42.1747600, -8.5039800, 'ES', '2015-05-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45227, 'Pueblica de Valverde', 'Pueblica de Valverde', 'Pueblica de Valverde', 41.9184300, -5.8997500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45228, 'Puebla de Yeltes', 'Puebla de Yeltes', 'Puebla de Yeltes', 40.6252800, -6.1815000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45229, 'Puebla de San Miguel', 'Puebla de San Miguel', 'La Pobla de Sant Miquel,La Puebla de Sant Miguel,Puebla de San Miguel,Puebla-de-San-Migel'',Puehbla-de-San-Migel'',pu ai fu la de sheng mi ge er,Пуебла-де-Сан-Мігель,Пуэбла-де-Сан-Мигель,普埃夫拉德圣米格尔', 40.0500000, -1.1333300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45230, 'Puebla de San Medel', 'Puebla de San Medel', 'Puebla de San Medel', 40.5107300, -5.7367300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45231, 'Puebla de Sanabria', 'Puebla de Sanabria', 'Pobra de Seabra,Puebla de Sanabria,Puebla-de-Sanabrija,Puehbla-de-Sanabria,pu ai fu la de sa na fu li ya,Пуебла-де-Санабрія,Пуэбла-де-Санабриа,プエブラ・デ・サナブリア,普埃夫拉德萨纳夫里亚', 42.0540100, -6.6335000, 'ES', '2012-03-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45232, 'Puebla de Pedraza', 'Puebla de Pedraza', 'Puebla de Pedraza', 41.2055700, -3.9137800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45233, 'Puebla de Lillo', 'Puebla de Lillo', 'Lillo', 43.0069100, -5.2738700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45234, 'A Pobra do Brollon', 'A Pobra do Brollon', 'A Pobra do Brollon,Puebla de Brollon,Puebla de Brollón', 42.5561200, -7.3914000, 'ES', '2015-09-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45235, 'Puebla de Beleña', 'Puebla de Belena', 'Puebla de Belena,Puebla de Beleña', 40.8879400, -3.2162400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45236, 'Puebla de Azaba', 'Puebla de Azaba', 'Puebla de Azaba,Puebla-de-Asaba,Puehbla-de-Asaba,pu ai fu la de ya sa wa,Пуебла-де-Асаба,Пуэбла-де-Асаба,普埃夫拉德亚萨瓦', 40.4473200, -6.7461600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45237, 'Puebla de Arenoso', 'Puebla de Arenoso', 'La Pobla d''Arenos,Puebla de Arenoso', 40.1000000, -0.5833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45238, 'Puebla de Alfindén', 'Puebla de Alfinden', '', 41.6318800, -0.7515400, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45239, 'Puebla de Albortón', 'Puebla de Alborton', 'Aebura,Ebora,Puebla de Alborton,Puebla de Albortón', 41.3851700, -0.8555800, 'ES', '2012-09-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45240, 'Proaza', 'Proaza', 'Proasa,Proaza,brwatha,pryasa,pu luo a sa,Проаса,برواثا,پرئاسا,普罗阿萨', 43.2517800, -6.0163300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45241, 'Prioro', 'Prioro', 'Prioro', 42.8948100, -4.9634900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45242, 'Priego', 'Priego', 'Priego', 40.4493600, -2.3143500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45243, 'Priaranza del Bierzo', 'Priaranza del Bierzo', 'Priaranza del Bierzo', 42.5097800, -6.6701700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45244, 'Presencio', 'Presencio', '', 42.1865600, -3.9013500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45245, 'Premià de Mar', 'Premia de Mar', 'Premia de Mar,Premija-de-Mar,Premià de Mar,Премия-де-Мар', 41.4920600, 2.3652400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45246, 'Préjano', 'Prejano', 'Prejano,Préjano', 42.1864800, -2.1799800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45247, 'Pravia', 'Pravia', 'Pravia,Pravija,brafya,prabya,pu la wei ya,Правиа,Правія,برافيا,پرابیا,普拉维亚', 43.4886100, -6.1117000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45248, 'Prats de Lluçanès', 'Prats de Llucanes', 'Prat de Llusanes,Prat de Llusanés,Prats de Llucanes,Prats de Llusanas,Prats de Llusanes,Prats de Llusanás,Prats de Llusanés,Prats de Lluçanès', 42.0166700, 2.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45249, 'Prados Redondos', 'Prados Redondos', 'Prados Redondos', 40.7850500, -1.7932900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45250, 'Pradosegar', 'Pradosegar', 'Pradosegar', 40.5502000, -5.0701500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45251, 'Pradoluengo', 'Pradoluengo', 'Pradoluengo', 42.3248400, -3.2028400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45252, 'Prado de la Guzpeña', 'Prado de la Guzpena', 'Prado,Prado de la Guzpena,Prado de la Guzpeña', 42.7830900, -5.0255400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45253, 'Prado', 'Prado', 'Prado', 41.9207700, -5.4202700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45254, 'Pradillo', 'Pradillo', 'Pradillo', 42.1766000, -2.6418500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45255, 'Pradilla de Ebro', 'Pradilla de Ebro', 'Pradilla de Ebro', 41.8611100, -1.2632500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45256, 'Prades', 'Prades', 'Prades', 41.3098300, 0.9886600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45257, 'Prádena del Rincón', 'Pradena del Rincon', 'Pradena del Rincon,Prádena del Rincón', 41.0441400, -3.5407500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45258, 'Prádena de Atienza', 'Pradena de Atienza', 'Pradena de Atienza,Prádena de Atienza', 41.1724500, -3.0072800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45259, 'Prádena', 'Pradena', 'Pradena,Prádena', 41.1391100, -3.6882300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45260, 'Pradejón', 'Pradejon', 'Pradejon,Pradejón,Pradekhon,Pradexon,pu la de hong,Прадехон,Պրադեխոն,普拉德洪', 42.3344600, -2.0685100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45261, 'Prádanos de Ojeda', 'Pradanos de Ojeda', 'Pradanos de Ojeda,Prádanos de Ojeda', 42.6815600, -4.3465900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45262, 'Prádanos de Bureba', 'Pradanos de Bureba', 'Pradanos de Bureba,Prádanos de Bureba', 42.5026400, -3.3475200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45263, 'Pradales', 'Pradales', 'Pradales', 41.4555500, -3.7075300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45264, 'Pozuelo de Zarzón', 'Pozuelo de Zarzon', 'Pocuelu Carcon,Posuehlo-de-Sarson,Posuelo-de-Sarson,Pozuelo de Zarzon,Pozuelo de Zarzón,Poçuelu Çarçón,bo su ai luo de sa er song,bwzylw dy zarzwn,Посуело-де-Сарсон,Посуэло-де-Сарсон,بوزيلو دي زارزون,波苏埃洛德萨尔松', 40.1480500, -6.4145800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45265, 'Pozuelo de Tábara', 'Pozuelo de Tabara', 'Pozuelo de Tabara,Pozuelo de Tábara', 41.7850200, -5.8945500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45266, 'Pozuelo del Rey', 'Pozuelo del Rey', 'Pozuelo del Rey', 40.3646300, -3.3169900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45267, 'Pozuelo del Páramo', 'Pozuelo del Paramo', 'Pozuelo del Paramo,Pozuelo del Páramo', 42.1710100, -5.7681300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45268, 'Pozuelo de la Orden', 'Pozuelo de la Orden', 'Pozuelo de la Orden', 41.8213800, -5.2589100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45269, 'Pozuelo de Aragón', 'Pozuelo de Aragon', 'Pozuelo de Aragon,Pozuelo de Aragón', 41.7643000, -1.4230500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45270, 'Pozuelo de Alarcón', 'Pozuelo de Alarcon', 'Posuehlo-de-Alarkon,Posuelo-de-Alarkon,Pozolum,Pozuelo,Pozuelo de Alarcon,Pozuelo de Alarcón,Pozuelo de Alarkon,bo su ai luo de ya la er kong,bwzwylw dy alarkwn,posuellodeallaleukon,Позуело де Аларкон,Посуело-де-Аларкон,Посуэло-де-Аларкон,بوزويلو دي الاركون,波苏埃洛德亚拉尔孔,포수엘로데알라르콘', 40.4329300, -3.8133800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45271, 'Pozuel del Campo', 'Pozuel del Campo', 'Pozuel del Campo', 40.7712500, -1.5057500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45272, 'Pozuel de Ariza', 'Pozuel de Ariza', 'Pozuel de Ariza,Pozuelo de Ariza', 41.3500000, -2.1500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45273, 'Pozos de Hinojo', 'Pozos de Hinojo', 'Pozos de Hinojo', 40.9130300, -6.4114400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45274, 'Pozondón', 'Pozondon', 'Pozondon,Pozondón', 40.5611200, -1.4703300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45275, 'Pozo de Urama', 'Pozo de Urama', '', 42.2543800, -4.8938900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45276, 'Pozo de Guadalajara', 'Pozo de Guadalajara', 'Pozo de Guadalajara', 40.4953300, -3.1814000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45277, 'Pozo de Almoguera', 'Pozo de Almoguera', 'Pozo de Almoguera', 40.3403000, -3.0263800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45278, 'Pozoantiguo', 'Pozoantiguo', 'Pozoantiguo', 41.5973000, -5.4366000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45279, 'Pozán de Vero', 'Pozan de Vero', 'Pozan de Vero,Pozán de Vero', 42.0821900, 0.0306600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45280, 'Pozanco', 'Pozanco', 'Pozanco', 40.8009500, -4.6677200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45281, 'Pozalmuro', 'Pozalmuro', 'Pozalmuro', 41.7744900, -2.1021500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45282, 'Pozal de Gallinas', 'Pozal de Gallinas', 'Pozal de Gallinas', 41.3183100, -4.8393600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45283, 'Poza de la Vega', 'Poza de la Vega', 'Poza de la Vega', 42.5782300, -4.7984500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45284, 'Poza de la Sal', 'Poza de la Sal', 'Posa-de-la-Sal'',Poza de la Sal,Poza de la Sol,bo sa de la sa er,bwza dy la sal,Поса-де-ла-Саль,بوزا دي لا سال,波萨德拉萨尔', 42.6654200, -3.5014000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45285, 'Poio', 'Poio', 'San Juan', 42.4477500, -8.6859400, 'ES', '2015-06-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45286, 'Poio', 'Poio', 'San Salvador', 42.4292900, -8.6607500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45287, 'Poyales del Hoyo', 'Poyales del Hoyo', 'Poyales del Hoyo', 40.1725400, -5.1659700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45288, 'Poveda de la Sierra', 'Poveda de la Sierra', 'Poveda,Poveda de la Sierra,Povedo de la Sierra', 40.6432900, -2.0290500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45289, 'Poveda de las Cintas', 'Poveda de las Cintas', 'Poveda de las Cintas', 41.0459600, -5.2601900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45290, 'Poveda', 'Poveda', 'Poveda', 40.5679900, -5.0790900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45291, 'Potes', 'Potes', 'Potes,bo te si,bwtys,Потес,بوتيس,波特斯', 43.1545700, -4.6205500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45292, 'Posada de Valdeón', 'Posada de Valdeon', '', 43.1515400, -4.9210200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45293, 'Portugalete', 'Portugalete', 'Portu,Portugalete,Portugaleto,Portus Gallorum,bo er tu jia lai te,bwrtghalyty,la villa jarrillera,poruto~ugarete,Португалете,بورتغاليتي,ポルトゥガレテ,波尔图加莱特', 43.3209900, -3.0206400, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45294, 'Porto', 'Porto', 'Porto', 42.1673700, -6.8993400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45295, 'Portillo de Toledo', 'Portillo de Toledo', '', 40.0641500, -4.2279300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45296, 'Portillo de Soria', 'Portillo de Soria', 'Portillo de Soria', 41.6350400, -2.1214200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45297, 'Portillo', 'Portillo', 'Portillo', 41.4786700, -4.5896700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45298, 'Portilla', 'Portilla', 'Portilla', 40.2895700, -2.0817800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45299, 'Portell de Morella', 'Portell de Morella', 'Portell de Morella', 40.5326700, -0.2624900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45300, 'Portbou', 'Portbou', 'Portbou,Portbu,Портбу', 42.4265000, 3.1580500, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45301, 'Portas', 'Portas', 'Portas,Santa Maria,Santa María', 42.5853100, -8.6557300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45302, 'Porriño', 'Porrino', '', 42.1615600, -8.6198000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45303, 'Porqueres', 'Porqueres', 'Porqueras,Porqueres', 42.1168200, 2.7414300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45304, 'Porqueira', 'Porqueira', 'Santa Maria,Santa María', 42.0166700, -7.8500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45305, 'Pontós', 'Pontos', 'Pontos,Pontós', 42.1866500, 2.9170600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45306, 'Pontevedra', 'Pontevedra', 'PTE,Pontevedra,Pontevedro,pontebedora,Понтеведра,ポンテベドラ', 42.4310000, -8.6443500, 'ES', '2012-12-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45307, 'Pont de Molins', 'Pont de Molins', 'Pont de Molins', 42.3144000, 2.9299600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45308, 'Ponts', 'Ponts', 'Ponts,Ponts-sous-Avranches', 41.9160700, 1.1851500, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45309, 'Ponferrada', 'Ponferrada', 'PFE,Pomeriada,Ponferada,Ponferado,Ponferrada,bwnfyrada,peng fei la da,ponferada,ponpelada,Понферада,Понферрада,بونفيرادا,ポンフェラーダ,蓬费拉达,폰페라다', 42.5466400, -6.5961900, 'ES', '2012-12-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45310, 'Pomer', 'Pomer', 'Pomer', 41.6376500, -1.8410400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45311, 'Pomar de Valdivia', 'Pomar de Valdivia', 'Pomar de Valdivia,Pomar-de-Val''divia,Pomar-de-Val''divija,bo ma er de wa er di wei ya,Помар-де-Вальдивиа,Помар-де-Вальдівія,波马尔德瓦尔迪维亚', 42.7743700, -4.1675600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45312, 'Pollos', 'Pollos', 'Pollos', 41.4440600, -5.1249100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45313, 'Polinyà', 'Polinya', 'Polinya,Polinya del Valles,Polinyà,Polinyà del Vallès,Polinyá', 41.5500000, 2.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45314, 'Polentinos', 'Polentinos', 'Polentinos', 42.9393200, -4.5288700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45315, 'Poleñino', 'Polenino', 'Polenino,Poleñino', 41.8697200, -0.3100900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45316, 'Pola de Somiedo', 'Pola de Somiedo', 'Pola de Somieda,Pola de Somiedo,Somiedo', 43.0929000, -6.2562900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45317, 'Pola de Siero', 'Pola de Siero', 'Pola de Siero,Pola-de-S''ero,Siero,Пола-де-Сьеро', 43.3922800, -5.6633500, 'ES', '2015-10-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45318, 'Pola de Lena', 'Pola de Lena', 'Lena,Llena,Pola de Lena,Pola de Llena', 43.1608900, -5.8287800, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45319, 'Pola de Laviana', 'Pola de Laviana', 'Labiana,Laviana,Llaviana,Pola de Labiana,Pola de Laviana', 43.2453800, -5.5629000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45320, 'Pola de Allande', 'Pola de Allande', 'Allande,La Puela,La Puela d''Ayande,Pola de Allande', 43.2730700, -6.6215200, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45321, 'Pol', 'Pol', '', 43.1489200, -7.3302200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45322, 'Pobladura de Valderaduey', 'Pobladura de Valderaduey', 'Pobladura de Valderaduey', 41.7000900, -5.5418900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45323, 'Pobladura de Pelayo García', 'Pobladura de Pelayo Garcia', 'Pobladura de Pelayo Garcia,Pobladura de Pelayo García', 42.3060200, -5.6856000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45324, 'Pobladura del Valle', 'Pobladura del Valle', 'Pobladura del Valle', 42.1025700, -5.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45325, 'la Pobla de Massaluca', 'la Pobla de Massaluca', 'Pobla de Masaluca,la Pobla de Massaluca', 41.1833300, 0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45326, 'Población de Cerrato', 'Poblacion de Cerrato', 'Poblacion de Cerrato,Población de Cerrato', 41.7929800, -4.4287400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45327, 'Población de Campos', 'Poblacion de Campos', 'Poblacion de Campos,Población de Campos', 42.2699400, -4.4474400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45328, 'Población de Arroyo', 'Poblacion de Arroyo', '', 42.3367500, -4.8739800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45329, 'el Poal', 'el Poal', 'Poal,el Poal', 41.6833300, 0.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45330, 'Plou', 'Plou', 'Plou', 40.9927400, -0.8544100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45331, 'Plentzia', 'Plentzia', 'Gaminiz,Plencia,Plentzia', 43.4053000, -2.9479400, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45332, 'Plenas', 'Plenas', 'Plenas', 41.1120900, -0.9644200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45333, 'Pleitas', 'Pleitas', 'Pleitas', 41.7113500, -1.2025100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45334, 'Plasencia de Jalón', 'Plasencia de Jalon', 'Plasencia,Plasencia de Jalon,Plasencia de Jalón', 41.6815400, -1.2299600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45335, 'Plasencia', 'Plasencia', 'Plasence,Plasencia,Plasencio,Plasensia,Plasensija,Plasentia,Plasència,Prasencia,Praséncia,blasynthya,plasnsya,pu la sen xi ya,purasenshia,Пласенсиа,Пласенсия,Пласенсія,بلاسينثيا,پلاسنسیا,プラセンシア,普拉森西亞', 40.0311600, -6.0884500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45336, 'Planoles', 'Planoles', 'Planolas,Planoles', 42.3166700, 2.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45337, 'Plan', 'Plan', 'Plan', 42.5812600, 0.3374200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45338, 'el Pla del Penedès', 'el Pla del Penedes', 'Pla de Panades,Pla de Panadés,Pla del Panades,Pla del Panadés,el Pla del Penedes,el Pla del Penedès', 41.4166700, 1.7166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45339, 'El Pla de Santa Maria', 'El Pla de Santa Maria', '', 41.3633600, 1.2915200, 'ES', '2011-12-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45340, 'Pizarral', 'Pizarral', 'Pizarral', 40.6145000, -5.6523800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45341, 'Pitillas', 'Pitillas', 'Pitilias,Pitillas', 42.4217200, -1.6201700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45342, 'Pitiegua', 'Pitiegua', 'Pitiegua', 41.0621000, -5.4664700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45343, 'Pitarque', 'Pitarque', 'Pitarque', 40.6485000, -0.5932400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45344, 'Piracés', 'Piraces', 'Piraces,Piracés', 42.0044800, -0.3176900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45345, 'Piqueras', 'Piqueras', 'Piqueras', 40.6636700, -1.7220200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45346, 'Pioz', 'Pioz', 'Pioz', 40.4615300, -3.1723400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45347, 'Piornal', 'Piornal', 'Piornal', 40.1173100, -5.8478700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45348, 'Pinto', 'Pinto', 'Pinto,Пинто', 40.2414700, -3.6999900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45349, 'Pinseque', 'Pinseque', 'Pinseque', 41.7365700, -1.1004100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45350, 'Piñor', 'Pinor', 'Pinor,Piñor', 42.5012000, -8.0015100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45351, 'Pinofranqueado', 'Pinofranqueado', 'Pinofrankeado,Pinofranqueado,Pinofranqueau,bynwfrankwyadw,pi nuo fu lan ke a duo,Пинофранкеадо,Пінофранкеадо,بينوفرانكويادو,皮诺夫兰克阿多', 40.3035100, -6.3318100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45352, 'Pino del Río', 'Pino del Rio', 'Pino del Rio,Pino del Río', 42.6450400, -4.8079500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45353, 'Pinillos', 'Pinillos', 'Pinillos', 42.1995100, -2.5970900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45354, 'Pinilla de Toro', 'Pinilla de Toro', 'Pinilla de Toro', 41.6278300, -5.3641400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45355, 'Pinilla de Molina', 'Pinilla de Molina', 'Pinilla de Molina', 40.6796900, -1.8803400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45356, 'Pinilla del Valle', 'Pinilla del Valle', 'Pinilla del Valle', 40.9244800, -3.8168800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45357, 'Pinilla de los Moros', 'Pinilla de los Moros', 'Pinilla de los Moros', 42.0681500, -3.3270600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45358, 'Pinilla de los Barruecos', 'Pinilla de los Barruecos', 'Pinilla de los Barruecos', 41.9179100, -3.3037100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45359, 'Pinilla del Campo', 'Pinilla del Campo', 'Pinilla del Campo', 41.7169100, -2.0835000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45360, 'Pinilla de Jadraque', 'Pinilla de Jadraque', 'Pinilla de Jadraque', 41.0198800, -2.9425400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45361, 'Piñel de Arriba', 'Pinel de Arriba', 'Pinel de Arriba,Piñel de Arriba', 41.6992300, -4.1280800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45362, 'Piñel de Abajo', 'Pinel de Abajo', 'Pinel de Abajo,Piñel de Abajo', 41.6745900, -4.1465500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45363, 'Pinedas', 'Pinedas', 'Pinedas', 40.4449300, -5.9602500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45364, 'Pineda de la Sierra', 'Pineda de la Sierra', 'Pineda de la Sierra', 42.2156000, -3.2969000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45365, 'Pineda de Gigüela', 'Pineda de Giguela', 'Pineda,Pineda de Giguela,Pineda de Gigüela', 40.0854600, -2.5436800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45366, 'Pineda de Mar', 'Pineda de Mar', 'Pineda,Pineda de Mar,Пинеда де Мар', 41.6276300, 2.6889000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45367, 'Pinarnegrillo', 'Pinarnegrillo', 'Pinarnegrillo', 41.1909800, -4.2096700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45368, 'Pinarejos', 'Pinarejos', 'Pinarejos', 41.2595000, -4.2936400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45369, 'Pina de Montalgrao', 'Pina de Montalgrao', 'Pina,Pina de Montalgrao,Pina de Montolgrao,Pina-de-Montal''grao,bayna dyl mwntaljraw,pi na de meng ta er ge lao,Пина-де-Монтальграо,Піна-де-Монтальграо,باينا ديل مونتالجراو,皮纳德蒙塔尔格劳', 40.0166700, -0.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45370, 'Piña de Esgueva', 'Pina de Esgueva', 'Pina,Pina de Esgueva,Piña,Piña de Esgueva', 41.7284300, -4.4282300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45371, 'Pina de Ebro', 'Pina de Ebro', 'Pina,Pina de Ebro', 41.4884600, -0.5312000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45372, 'Piña de Campos', 'Pina de Campos', 'Pina de Campos,Piña de Campos', 42.2132600, -4.4365700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45373, 'Piloña', 'Pilona', 'Pilona,Piloña', 43.3500000, -5.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45374, 'Piérnigas', 'Piernigas', 'Piernigas,Piérnigas', 42.5903000, -3.4133700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45375, 'Piera', 'Piera', 'Piera', 41.5223200, 1.7507600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45376, 'Piedratajada', 'Piedratajada', 'Piedratajada', 42.1212400, -0.8037300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45377, 'Piedramillera', 'Piedramillera', 'Piedramillera', 42.6320000, -2.2041600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45378, 'Piedralaves', 'Piedralaves', 'P''edralaves,Pedralaves,Piedralaves,bi de la la wei si,bydralafys,pydralabs,Пиедралавес,Пьедралавес,Пєдралавес,بيدرالافيس,پیدرالابس,彼德拉拉韦斯', 40.3172100, -4.7002500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45379, 'Piedrahita de Castro', 'Piedrahita de Castro', 'Piedrahita de Castro', 41.6808900, -5.7288600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45380, 'Pías', 'Pias', '', 42.0833300, -7.0000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45381, 'Pezuela de las Torres', 'Pezuela de las Torres', 'Pezuela de las Torres', 40.4161300, -3.1736300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45382, 'Petín', 'Petin', 'Petin,Petín', 42.3819100, -7.1289900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45383, 'Petilla de Aragón', 'Petilla de Aragon', 'Petiella dAragon,Petiella dAragón,Petil''ja-de-Aragon,Petilla,Petilla Aragoi,Petilla de Aragon,Petilla de Aragoni vald,Petilla de Aragón,Petilla de Aragóni vald,pei di li ya de a la gong,Петилья-де-Арагон,Петілья-де-Арагон,佩蒂利亚德阿拉贡', 42.4500000, -1.1166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45384, 'Pesquera', 'Pesquera', 'Pesquera,Pesquero', 43.0822300, -4.0793200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45385, 'Pesoz', 'Pesoz', 'Pesoz', 43.2500000, -6.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45386, 'Pertusa', 'Pertusa', 'Pertusa', 42.0021400, -0.1273200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45387, 'Perosillo', 'Perosillo', 'Perosillo', 41.3929400, -4.1411500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45388, 'Peromingo', 'Peromingo', 'Peromingo', 40.4638600, -5.7723800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45389, 'Perilla de Castro', 'Perilla de Castro', 'Perilla de Castro', 41.7254000, -5.8763600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45390, 'Pereruela', 'Pereruela', 'Pereruehla,Pereruela,pei lei lu ai la,Переруела,Переруэла,佩雷鲁埃拉', 41.4165000, -5.8781200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45391, 'El Perelló', 'El Perello', 'El Perello,El Perelló,Perello,Perelló', 40.8743100, 0.7112500, 'ES', '2013-11-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45392, 'Peralada', 'Peralada', 'Peralada', 42.3082300, 3.0091000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45393, 'Pereiro de Aguiar', 'Pereiro de Aguiar', 'Pereiro de Aguiar', 42.3452400, -7.8000800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45394, 'Perdiguera', 'Perdiguera', 'Perdiguera', 41.7545800, -0.6314800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45395, 'Peranzanes', 'Peranzanes', 'Peranzanes', 42.8772500, -6.6338300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45396, 'Peralveche', 'Peralveche', 'Peralveche', 40.6107800, -2.4495700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45397, 'Peraltilla', 'Peraltilla', 'Peraltilla', 42.0540700, -0.0184000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45398, 'Peralta', 'Peralta', 'Azkoien,Peral''ta,Peralta,Peralta - Azkoien,Peralta – Azkoien,pei la er ta,Перальта,佩拉尔塔', 42.3383400, -1.8003500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45399, 'Perales de Tajuña', 'Perales de Tajuna', 'Perales de Tajuna,Perales de Tajuña,Tajuna,Tajuña', 40.2313000, -3.3502100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45400, 'Perales del Puerto', 'Perales del Puerto', 'Perales del Puerto', 40.1559600, -6.6819200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45401, 'Perales del Alfambra', 'Perales del Alfambra', 'Perales,Perales de Alfambra,Perales del Alfambra', 40.6338300, -1.0018100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45402, 'Perales', 'Perales', '', 42.1939800, -4.5810500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45403, 'Peralejos de las Truchas', 'Peralejos de las Truchas', 'Peralejos de las Truchas', 40.5933600, -1.9095300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45404, 'Peralejos de Arriba', 'Peralejos de Arriba', 'Peralejos de Arriba', 41.0041000, -6.3336200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45405, 'Peralejos de Abajo', 'Peralejos de Abajo', 'Peralejos de Abajo', 41.0046900, -6.3623800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45406, 'Peralejos', 'Peralejos', 'Peralejos', 40.4843300, -1.0340800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45407, 'Peral de Arlanza', 'Peral de Arlanza', 'Peral de Arlanza', 42.0761200, -4.0773300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45408, 'Peracense', 'Peracense', 'Peracense', 40.6409900, -1.4707500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45409, 'Peque', 'Peque', 'Peque', 42.0729700, -6.2748900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45410, 'Peníscola', 'Peniscola', 'Penhiscola,Penhíscola,Peniscola,Peníscola,Peñíscola', 40.3574000, 0.4069200, 'ES', '2006-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45411, 'Penelles', 'Penelles', 'Penelles', 41.7500000, 0.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45412, 'Peñausende', 'Penausende', 'Pen''jausende,Penausade,Penausende,Peñausade,Peñausende,pei ni ao sen de,Пеньяусенде,佩尼奥森德', 41.2866200, -5.8675500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45413, 'Peñarandilla', 'Penarandilla', 'Penarandilla,Peñarandilla', 40.8834800, -5.3936000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45414, 'Peñaranda de Duero', 'Penaranda de Duero', 'Penaranda,Peñaranda', 41.6884900, -3.4786300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45415, 'Peñaranda de Bracamonte', 'Penaranda de Bracamonte', 'Pen''jaranda-de-Brakamonte,Penaranda de Bracamonte,Peñaranda de Bracamonte,pei ni ya lan da de fu la ka meng te,Пеньяранда-де-Бракамонте,ペニャランダ・デ・ブラカモンテ,佩尼亚兰达德夫拉卡蒙特', 40.9010800, -5.2002600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45416, 'Peñaparda', 'Penaparda', 'Penaparda,Peñaparda', 40.3209300, -6.6694800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45417, 'Peñalver', 'Penalver', 'Penalver,Peñalver', 40.5814000, -2.8889000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45418, 'Peñalén', 'Penalen', 'Penalen,Peñalén', 40.6656000, -2.0699900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45419, 'Peñalba de Ávila', 'Penalba de Avila', 'Penalba de Avila,Peñalba de Ávila', 40.7726600, -4.7459500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45420, 'Peñalba', 'Penalba', 'Penalba,Peñalba', 41.5008700, -0.0379800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45421, 'Penagos', 'Penagos', 'Penagos', 43.3521600, -3.8138200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45422, 'Peñaflor de Hornija', 'Penaflor de Hornija', 'Penaflor,Penaflor de Hornija,Peñaflor,Peñaflor de Hornija', 41.7115900, -4.9833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45423, 'Peñafiel', 'Penafiel', 'Penafiel,Peñafiel', 41.6016500, -4.1141800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45424, 'Peñacaballera', 'Penacaballera', '', 40.3435300, -5.8612100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45425, 'Peleas de Abajo', 'Peleas de Abajo', 'Peleas de Abajo', 41.3926000, -5.6896600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45426, 'Peleagonzalo', 'Peleagonzalo', 'Peleagonzalo', 41.4817500, -5.4830400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45427, 'Pelayos del Arroyo', 'Pelayos del Arroyo', 'Pelayos del Arroyo', 41.0508600, -3.9410400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45428, 'Pelayos de la Presa', 'Pelayos de la Presa', '', 40.3605100, -4.3346200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45429, 'Pelayos', 'Pelayos', 'Pelayos', 40.6498500, -5.5758000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45430, 'Pelarrodríguez', 'Pelarrodriguez', 'Pelarrodriguez,Pelarrodríguez', 40.8872300, -6.2127100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45431, 'Pelahustán', 'Pelahustan', '', 40.1759900, -4.5984200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45432, 'Pelabravo', 'Pelabravo', 'Pelabravo', 40.9365800, -5.5791600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45433, 'Peguerinos', 'Peguerinos', '', 40.6262000, -4.2315400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45434, 'Pedroso', 'Pedroso', 'Pedroso,pei de luo suo,Педросо,Պեդրոսո,佩德罗索', 42.2995900, -2.7188900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45435, 'Pedrosillo el Ralo', 'Pedrosillo el Ralo', 'Pedrosillo el Ralo', 41.0630500, -5.5479400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45436, 'Pedrosillo de los Aires', 'Pedrosillo de los Aires', 'Pedrosillo de los Aires', 40.7152400, -5.7051100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45437, 'Pedrosillo de Alba', 'Pedrosillo de Alba', 'Pedrosillo de Alba', 40.8227700, -5.3950600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45438, 'Pedrosa del Rey', 'Pedrosa del Rey', 'Pedrosa del Rey', 41.5561700, -5.2046600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45439, 'Pedrosa del Príncipe', 'Pedrosa del Principe', 'Pedrosa del Principe,Pedrosa del Príncipe', 42.2491800, -4.1984900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45440, 'Pedrosa del Páramo', 'Pedrosa del Paramo', '', 42.4420800, -3.9719000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45441, 'Pedrosa de la Vega', 'Pedrosa de la Vega', '', 42.4815900, -4.7467800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45442, 'Pedrosa de Duero', 'Pedrosa de Duero', 'Pedrosa de Duero', 41.7128900, -3.9880400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45443, 'Pedrola', 'Pedrola', 'Pedrola', 41.7910200, -1.2135700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45444, 'Pedro Bernardo', 'Pedro Bernardo', 'Pedro Bernardo,Pedro-Bernardo,bydrw byrnardw,pdrw brnardw,pei de luo wei er na er duo,Педро Бернардо,Педро-Бернардо,بيدرو بيرناردو,پدرو برناردو,佩德罗韦尔纳尔多', 40.2421400, -4.9096300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45445, 'Pedrezuela', 'Pedrezuela', 'Pedrezuela', 40.7427700, -3.5998000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45446, 'Pedraza de Campos', 'Pedraza de Campos', 'Pedraza de Campos', 41.9841900, -4.7352400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45447, 'Pedraza de Alba', 'Pedraza de Alba', 'Pedraza de Alba', 40.7550200, -5.3752400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45448, 'Pedraza', 'Pedraza', 'Pedraza,Pedraza de la Sierra', 41.1309200, -3.8111600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45449, 'Pedrajas de San Esteban', 'Pedrajas de San Esteban', 'Pedrajas de San Esteban', 41.3414500, -4.5822500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45450, 'Pazuengos', 'Pazuengos', 'Pazuengos', 42.3177600, -2.9253900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45451, 'Payo de Ojeda', 'Payo de Ojeda', 'Payo de Ojeda', 42.7185900, -4.4775200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45452, 'Pau', 'Pau', 'Pau', 42.3160700, 3.1162100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45453, 'Patones', 'Patones', 'Patones,Patones de Abajo', 40.8556300, -3.4849000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45454, 'Pastrana', 'Pastrana', 'Pastrana', 40.4190200, -2.9225600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45455, 'Pastores', 'Pastores', 'Pastores', 40.5150800, -6.5101800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45456, 'Pascualcobo', 'Pascualcobo', 'Pascualcobo', 40.6563700, -5.2773300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45457, 'Parrillas', 'Parrillas', 'Parrillas', 40.0622500, -5.0639000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45458, 'Parres', 'Parres', '', 43.3500000, -5.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45459, 'Parlavà', 'Parlava', 'Parlaba,Parlabá,Parlava,Parlavà', 42.0216300, 3.0319700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45460, 'Parla', 'Parla', 'Parla,barla,pa er la,Парла,بارلا,帕尔拉', 40.2360400, -3.7675200, 'ES', '2014-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45461, 'Parets del Vallès', 'Parets del Valles', 'Parets del Valles,Parets del Vallès,Sant Esteve de Parets', 41.5748100, 2.2330600, 'ES', '2011-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45462, 'Pareja', 'Pareja', 'Pareja', 40.5557800, -2.6488200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45463, 'Paredes de Sigüenza', 'Paredes de Siguenza', 'Paredes,Paredes de Siguenza,Paredes de Sigüenza', 41.2428300, -2.7337600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45464, 'Paredes de Nava', 'Paredes de Nava', 'Paredes,Paredes de Nava', 42.1536700, -4.6919300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45465, 'Paredes de Escalona', 'Paredes de Escalona', 'Paredes,Paredes de Escalona', 40.2047200, -4.4305000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45466, 'Paredes', 'Paredes', 'Paredes', 40.0657800, -2.8540000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45467, 'Pardos', 'Pardos', 'Pardos', 40.9481800, -1.9255500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45468, 'Pardilla', 'Pardilla', 'Pardilla,Pardillo', 41.5518300, -3.7108900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45469, 'Páramo del Sil', 'Paramo del Sil', 'Paramo,Paramo del Sil,Páramo,Páramo del Sil', 42.8205600, -6.4874700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45470, 'Páramo de Boedo', 'Paramo de Boedo', 'Paramo de Boedo,Páramo de Boedo', 42.5784200, -4.4004200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45471, 'O Páramo', 'O Paramo', '', 42.9500000, -7.3000000, 'ES', '2012-02-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45472, 'Paradinas de San Juan', 'Paradinas de San Juan', 'Paradinas de San Juan', 40.9832500, -5.1541800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45473, 'Paradela', 'Paradela', 'Paradela,San Miguel', 42.7666700, -7.5666700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45474, 'Parada de Rubiales', 'Parada de Rubiales', 'Parada de Rubiales', 41.1481800, -5.4363800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45475, 'Parada de Arriba', 'Parada de Arriba', 'Parada de Arriba', 40.9865500, -5.7933200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45476, 'Paracuellos de la Ribera', 'Paracuellos de la Ribera', 'Pacuellos,Paracuellos de la Ribera', 41.4227300, -1.5624500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45477, 'Paracuellos de Jiloca', 'Paracuellos de Jiloca', 'Paracuellos de Jiloca', 41.3137800, -1.6402900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45478, 'Paracuellos de Jarama', 'Paracuellos de Jarama', 'Paracuellos de Jarama', 40.5035300, -3.5277500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45479, 'Papatrigo', 'Papatrigo', 'Papatrigo', 40.8679000, -4.8339900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45480, 'Pantón', 'Panton', 'Panton,Pantón', 42.5166700, -7.6000000, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45481, 'Pantoja', 'Pantoja', 'Pantoja', 40.0433600, -3.8328000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45482, 'Paniza', 'Paniza', 'Paniza', 41.2840000, -1.2122400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45483, 'Pancrudo', 'Pancrudo', 'Pancrudo', 40.7622300, -1.0296700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45484, 'Pancorbo', 'Pancorbo', 'Pancorbo,Pancorvo', 42.6341800, -3.1118000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45485, 'Pamplona', 'Pamplona', 'Gorad Pamplona,Iruinea,Iruna,Irunea,Iruña,Iruñea,Lungsod ng Irunea,Lungsod ng Iruñea,PNA,Pampalona,Pampeluna,Pampelune,Pamplona,Pamplonae,Pamplono,Pompaelo,bnblwnt,iruniya,pam po lna,pampalona,pampeullona,pamplwna,pan pu luo na,panpurona,pmplwnh,Горад Памплона,Памплонæ,Памплона,Պամպլոնա,פמפלונה,بنبلونة,پامپلونا,पाम्पलोना,இருனியா,ปัมโปลนา,პამპლონა,パンプローナ,潘普洛納,팜플로나', 42.8168700, -1.6432300, 'ES', '2012-12-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45486, 'Pampliega', 'Pampliega', '', 42.2058200, -3.9866600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45487, 'Pals', 'Pals', 'Pais,Palls,Pals', 41.9710200, 3.1481400, 'ES', '2013-03-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45488, 'Palomero', 'Palomero', 'Palomero', 40.2468800, -6.2770600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45489, 'Palomeque', 'Palomeque', 'Palomeque', 40.1196600, -3.9640300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45490, 'Palomar de Arroyos', 'Palomar de Arroyos', 'Palomar de Arroyos', 40.7791100, -0.7505500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45491, 'Palol de Revardit', 'Palol de Revardit', 'Palol de Rebardit,Palol de Revardit', 42.0666700, 2.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45492, 'Palo', 'Palo', '', 42.3227000, 0.2437600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45493, 'Pálmaces de Jadraque', 'Palmaces de Jadraque', 'Palmaces de Jadraque,Pálmaces de Jadraque', 41.0561000, -2.9106000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45494, 'Pallejà', 'Palleja', 'Palleja,Pallejà', 41.4239400, 1.9950500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45495, 'els Pallaresos', 'els Pallaresos', 'Pallaresos,els Pallaresos', 41.1749100, 1.2709000, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45496, 'Palenzuela', 'Palenzuela', 'Palenzuela', 42.0951800, -4.1303900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45497, 'Palencia de Negrilla', 'Palencia de Negrilla', 'Palencia de Negrilla', 41.0943900, -5.6016800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45498, 'Palencia', 'Palencia', 'Gorad Palensija,Liste del villagies locata in Palencia,PCI,Palencia,Palencio,Palensija,Palentzia,Pallantia,Palència,Paléncia,Palência,balnthya,pa lun xi ya,pallensia,palnsya,parenshia,Горад Паленсія,Паленсия,Паленсија,Паленсія,بالنثيا,پالنسیا,パレンシア,帕伦西亚,팔렌시아', 42.0095500, -4.5240600, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45499, 'Palazuelos de Muñó', 'Palazuelos de Muno', '', 42.1969200, -3.9898400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45500, 'Palazuelos de la Sierra', 'Palazuelos de la Sierra', 'Palazuelos de la Sierra', 42.2116200, -3.4601400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45501, 'Palazuelos de Eresma', 'Palazuelos de Eresma', 'Palazuelos de Eresma', 40.9305500, -4.0607100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45502, 'Palazuelo de Vedija', 'Palazuelo de Vedija', 'Palazuelo de Vedija', 41.9296600, -5.1453400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45503, 'Palau-sator', 'Palau-sator', '', 41.9889700, 3.1101600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45504, 'Palanques', 'Palanques', 'Palanques', 40.7180000, -0.1794100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45505, 'Palamós', 'Palamos', 'Palamos,Palamós', 41.8484300, 3.1291200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45506, 'Palafrugell', 'Palafrugell', 'Palafrugell,Palafruzhel'',Палафружель', 41.9173800, 3.1631000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45507, 'Palafolls', 'Palafolls', 'Palafolls', 41.6666700, 2.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45508, 'Palaciosrubios', 'Palaciosrubios', 'Palaciosrubios', 41.0523800, -5.1950700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45509, 'Palacios de Sanabria', 'Palacios de Sanabria', 'Palacios de Sanabria', 42.0590100, -6.5236200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45510, 'Palacios del Sil', 'Palacios del Sil', 'Palacios,Palacios del Sil', 42.8760100, -6.4315000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45511, 'Palacios del Pan', 'Palacios del Pan', 'Palacios del Pan', 41.6024200, -5.8777300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45512, 'Palacios de la Valduerna', 'Palacios de la Valduerna', 'Palacios de la Valduerna', 42.3277300, -5.9383000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45513, 'Palacios de la Sierra', 'Palacios de la Sierra', 'Palacios de la Sierra', 41.9639200, -3.1278800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45514, 'Palacios del Arzobispo', 'Palacios del Arzobispo', 'Palacios del Arzobispo', 41.1665500, -5.8893300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45515, 'Palacios de Goda', 'Palacios de Goda', 'Palacios de Goda', 41.1179800, -4.7849600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45516, 'Pajares de los Oteros', 'Pajares de los Oteros', 'Pajares de los Oteros', 42.3301000, -5.4731300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45517, 'Pajares de la Lampreana', 'Pajares de la Lampreana', 'Pajares de la Lampreana', 41.7155100, -5.6935100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45518, 'Pajares de la Laguna', 'Pajares de la Laguna', 'Pajares de la Laguna', 41.0875400, -5.5088800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45519, 'Pajares de Adaja', 'Pajares de Adaja', 'Pajares de Adaja', 40.9239800, -4.6404800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45520, 'Pajarejos', 'Pajarejos', 'Pajarejos,Pajareros', 41.3899400, -3.5899700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45521, 'Padrones de Bureba', 'Padrones de Bureba', 'Padrones de Bureba', 42.7058200, -3.5329600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45522, 'Padrón', 'Padron', 'Padron,Padrón', 42.7387500, -8.6605700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45523, 'Padrenda', 'Padrenda', 'Padrenda,San Ciprian,San Ciprián', 42.1333300, -8.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45524, 'Padilla de Arriba', 'Padilla de Arriba', '', 42.4380300, -4.1909400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45525, 'Padilla de Abajo', 'Padilla de Abajo', '', 42.4077400, -4.1765200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45526, 'Padiernos', 'Padiernos', 'Pad''ernos,Padiernos,badyrnws,pa die er nuo si,padyrns,Падиернос,Падьернос,Падьєрнос,باديرنوس,پادیرنس,帕迭尔诺斯', 40.6216800, -4.8452300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45527, 'Paderne', 'Paderne', 'Paderne', 43.2856700, -8.1741500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45528, 'Oion / Oyón', 'Oyon', 'Oion,Oyon,Oyón', 42.5057100, -2.4363800, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45529, 'Oia', 'Oia', 'Ojja,Oya,ao ya,awya,oia,Ойя,أويا,オイア,奥亚', 42.0000000, -8.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45530, 'Oviedo', 'Oviedo', 'Gorad Aueda,OVD,Ov''edo,Ovedo,Ovetum,Oviedo,Oviedu,Ovieu,Ovijedo,Ovjedas,Ovjedo,Uvieu,Uviéu,abydw,ao wei ye duo,awfyydw,awwydw,obiedo,ovhiyedo,oviedo,oviyeto,xo beiy do,Горад Аўеда,Овиедо,Овиједо,Овьедо,Овєдо,אוביידו,أوفييدو,ابیدو,اوویدو,ओव्हियेदो,ஒவியேதோ,โอเบียโด,ოვიედო,オビエド,奥维耶多,오비에도', 43.3602900, -5.8447600, 'ES', '2012-12-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45531, 'Outes', 'Outes', 'Outes,awatys,awtys,ou te si,outesu,Оутес,أوتيس,اواتیس,オウテス,欧特斯', 42.8618900, -8.9018100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45532, 'Outeiro', 'Outeiro', '', 43.1445800, -7.2921200, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45533, 'Ourol', 'Ourol', 'Orol,Orol'',Ourol,Ourol'',San Julian,San Julián,ou luo er,ouroru,Ороль,Оуроль,オウロル,欧罗尔', 42.8701300, -7.6144700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45534, 'Outeiro de Rei', 'Outeiro de Rei', '', 43.1019800, -7.6149700, 'ES', '2016-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45535, 'Otero de Herreros', 'Otero de Herreros', 'Otero de Herreros', 40.8201600, -4.2099000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45536, 'Otero de Bodas', 'Otero de Bodas', 'Oter de Bodas,Otero,Otero de Bodas,Otero de Bodos', 41.9386800, -6.1502400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45537, 'Oteiza', 'Oteiza', 'Oteiza de la Solana', 42.6190500, -1.9538500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45538, 'Ossó de Sió', 'Osso de Sio', 'Osso de Sio,Ossó de Sió', 41.7548500, 1.1590000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45539, 'Osornillo', 'Osornillo', '', 42.3704700, -4.2915300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45540, 'Oseja de Sajambre', 'Oseja de Sajambre', 'Oseja de Sajambre', 43.1367100, -5.0378600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45541, 'Oseja', 'Oseja', 'Oseja', 41.5956400, -1.7002600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45542, 'Os de Balaguer', 'Os de Balaguer', 'Os,Os de Balaguer,Os de Ballaguer', 41.8731400, 0.7201700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45543, 'Ortuella', 'Urtuella', 'Ortuehl''ja,Ortuel''ja,Ortuella,ao er tu ai li ya,awrtwyla,Ортуелья,Ортуэлья,أورتويلا,奥尔图埃利亚', 43.3111300, -3.0561700, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45544, 'Ortigosa de Pestaño', 'Ortigosa de Pestano', 'Ortigos de Pestano,Ortigos de Pestaño,Ortigosa de Pestano,Ortigosa de Pestaño', 41.0874100, -4.3951600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45545, 'Ortigosa del Monte', 'Ortigosa del Monte', 'Ortigosa del Monte', 40.8418200, -4.1772400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45546, 'Ortigosa', 'Ortigosa', 'Ortigosa,Ortigosa de Cameros', 42.1756800, -2.7051300, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45547, 'Òrrius', 'Orrius', 'Orrius,Òrrius', 41.5500000, 2.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45548, 'Orrios', 'Orrios', 'Orrios', 40.5894500, -0.9861400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45549, 'Orpí', 'Orpi', 'Orpi,Orpí', 41.5187000, 1.5753600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45550, 'Oroso', 'Oroso', 'Oroso', 42.9833300, -8.4333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45551, 'Oropesa del Mar', 'Oropesa del Mar', 'Oropesa del Mar,Orpesa', 40.0913400, 0.1411500, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45552, 'Oronz', 'Oronz', '', 42.8687300, -1.0968300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45553, 'Ormaiztegi', 'Ormaiztegui', 'Ormaiztegi,Ormaiztegui,Ormáiztegui', 43.0433900, -2.2567300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45554, 'Oristà', 'Orista', '', 41.9333300, 2.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45555, 'Orísoain', 'Orisoain', 'Orisoain,Orísoain', 42.6012200, -1.6040300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45556, 'Orís', 'Oris', 'Caserio Oris,Caserío Oris,Oris,Orís', 42.0596700, 2.2206600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45557, 'Orio', 'Orio', 'Orio', 43.2787000, -2.1253700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45558, 'Orihuela del Tremedal', 'Orihuela del Tremedal', 'Orihuela del Tremedal', 40.5500000, -1.6500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45559, 'Oria', 'Oria', 'Oria', 43.2554100, -2.0187300, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45560, 'Orés', 'Ores', 'Ores,Orés', 42.2776500, -1.0015000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45561, 'Orera', 'Orera', 'Orera', 41.2984200, -1.4784900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45562, 'Ourense', 'Ourense', 'OUQ,Orance,Orense,Orenso,Ourense,ourense,Оренсе,オウレンセ', 42.3366900, -7.8640700, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45563, 'Orendain', 'Orendain', 'Orendain,Orendáin', 43.0789600, -2.1120100, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45564, 'Orexa', 'Oreja', 'Oreja,Orexa', 43.0938200, -2.0111900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45565, 'Orea', 'Orea', 'Orea', 40.5572500, -1.7273800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45566, 'Urduña / Orduña', 'Urduna', 'Orduna,Orduña,Urduna,Urduña', 42.9943500, -3.0097400, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45567, 'Ordis', 'Ordis', 'Ordis', 42.2183000, 2.9070500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45568, 'Ordes', 'Ordes', '', 43.0765400, -8.4090000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45569, 'Orkoien', 'Orkoien', 'Orcoyen,Orkoen,Orkoien,Orkojen,ao er ke yan,Оркойен,Оркоєн,奥尔科延', 42.8238000, -1.7048500, 'ES', '2012-12-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45570, 'Orcajo', 'Orcajo', '', 41.1097500, -1.4893300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45571, 'Orbita', 'Orbita', 'Orbita', 40.9984600, -4.6483300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45572, 'Orbara', 'Orbara', 'Orbara', 42.9672800, -1.2421300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45573, 'Oquillas', 'Oquillas', 'Oquillas', 41.8308500, -3.7056400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45574, 'Onzonilla', 'Onzonilla', 'Onsonil''ja,Onzonilla,onsonija,weng suo ni li ya,Онсонилья,Онсонілья,オンソニージャ,翁索尼利亚', 42.5243500, -5.5816000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45575, 'Ontiñena', 'Ontinena', '', 41.6766300, 0.0885800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45576, 'Ondarroa', 'Ondarroa', 'Ondarroa,Ondárroa', 43.3166700, -2.4166700, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45577, 'Oncala', 'Oncala', 'Oncala', 41.9702100, -2.3149300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45578, 'Oñati', 'Onate', 'Onate,Onati,Oñate,Oñati', 43.0326200, -2.4099700, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45579, 'Oña', 'Ona', 'On''ja,Ona,Onija,Oña,ao ni ya,awnya,Ония,Онья,أونيا,奥尼亚', 42.7340000, -3.4145900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45580, 'Oltza', 'Oltza', 'Oltza,Olza', 42.8500000, -1.7666700, 'ES', '2007-01-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45581, 'Olvés', 'Olves', 'Olves,Olvés', 41.2396500, -1.6464700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45582, 'Olvega', 'Olvega', 'Olvega', 41.7790100, -1.9839100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45583, 'Olot', 'Olot', 'Olot,ao luo te,awlwt,Олот,أولوت,奥洛特', 42.1809600, 2.4901200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45584, 'Olost', 'Olost', 'Olost', 41.9854000, 2.0945700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45585, 'Olóriz', 'Oloriz', '', 42.6352200, -1.6127600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45586, 'Olombrada', 'Olombrada', 'Olombrada', 41.4149200, -4.1607100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45587, 'Olocau del Rey', 'Olocau del Rey', 'Olocau del Rei,Olocau del Rey,Olokau-del''-Rej,ao luo kao de er lei,awlwkaw dyl ry,Олокау-дель-Рей,أولوكاو ديل ري,奥洛考德尔雷', 40.6377500, -0.3404100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45588, 'Olmos de Peñafiel', 'Olmos de Penafiel', 'Olmos de Penafiel,Olmos de Peñafiel', 41.5714200, -4.0431600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45589, 'Olmos de Ojeda', 'Olmos de Ojeda', 'Olmos de Ojeda', 42.7227400, -4.4244600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45590, 'Olmos de Esgueva', 'Olmos de Esgueva', 'Olmos de Esgueva', 41.6881500, -4.5225500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45591, 'Olmillos de Muñó', 'Olmillos de Muno', '', 42.2032200, -3.9391100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45592, 'Olmillos de Castro', 'Olmillos de Castro', 'Olmillos de Castro', 41.7317900, -5.9679100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45593, 'Olmedo de Camaces', 'Olmedo de Camaces', 'Olmedo de Camaces', 40.8796700, -6.6236000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45594, 'Olmedo', 'Olmedo', 'Olmedo', 41.2870600, -4.6887800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45595, 'Olmedillo de Roa', 'Olmedillo de Roa', 'Olmedillo de Roa', 41.7836200, -3.9341900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45596, 'Olmedilla de Eliz', 'Olmedilla de Eliz', 'Olmedilla de Eliz', 40.3023200, -2.4195200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45597, 'Olmeda de la Cuesta', 'Olmeda de la Cuesta', 'Olmeda de la Cuesta', 40.3108800, -2.4759200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45598, 'Olmeda de Cobeta', 'Olmeda de Cobeta', 'Olmeda de Cobeta', 40.8597100, -2.1828000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45599, 'Ollauri', 'Ollauri', 'Ollauri', 42.5425600, -2.8344800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45600, 'Olivella', 'Olivella', 'Olivella', 41.3166700, 1.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45601, 'Olivares de Duero', 'Olivares de Duero', 'Olivares de Duero', 41.6375500, -4.3654700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45602, 'Oliva de Plasencia', 'Oliva de Plasencia', 'Oliva,Oliva de Plasencia', 40.1122700, -6.0864800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45603, 'Olius', 'Olius', '', 42.0103500, 1.5646000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45604, 'Olite', 'Olite', 'Erriberri,Oligicus,Oligitum,Olit,Olite,ao li te,orite,Олите,Оліте,オリテ,奥利特', 42.4797100, -1.6519600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45605, 'Oliete', 'Oliete', '', 40.9979100, -0.6742900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45606, 'Oliana', 'Oliana', 'Oliana', 42.0689500, 1.3135300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45607, 'Olesa de Montserrat', 'Olesa de Montserrat', 'Olesa,Olesa de Montserrat', 41.5437200, 1.8940700, 'ES', '2014-12-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45608, 'Olesa de Bonesvalls', 'Olesa de Bonesvalls', 'Olesa de Bonesvall,Olesa de Bonesvalls', 41.3543500, 1.8490700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45609, 'Olejua', 'Olejua', 'Olejua', 42.6232900, -2.1420200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45610, 'Oleiros', 'Oleiros', 'Alejras,Oleiros,Olejros,Santa Maria,Santa María,ao lai luo si,awlyrws,awlyyrws,oreirosu,Алейрас,Олеирос,Олейрос,أوليروس,اولئیروس,اولیروس,オレイロス,奥莱罗斯', 43.3333300, -8.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45611, 'Olea de Boedo', 'Olea de Boedo', 'Olea de Boedo', 42.6099000, -4.4504000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45612, 'Olvan', 'Olvan', 'Olban,Olbán,Olvan', 42.0666700, 1.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45613, 'Olba', 'Olba', 'Olba', 40.1333300, -0.6166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45614, 'Olazagutía', 'Olazagutia', '', 42.8758400, -2.1953800, 'ES', '2010-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45615, 'Olaberria', 'Olaberria', 'Olaberria,Olaberría', 43.0272600, -2.2034900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45616, 'Ojos Negros', 'Ojos Negros', 'Ojos Negros', 40.7375000, -1.4987500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45617, 'Ojos-Albos', 'Ojos-Albos', 'Ojos-Albos', 40.7059600, -4.5163300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45618, 'Ojacastro', 'Ojacastro', 'Ojacastro,Okhakastro,Oxakastro,ao ha ka si te luo,Охакастро,Օխակաստրո,奥哈卡斯特罗', 42.3472000, -3.0049000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45619, 'Oitz', 'Oitz', 'Oitz,Oiz', 43.1166700, -1.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45620, 'Oimbra', 'Oimbra', '', 41.8855400, -7.4721600, 'ES', '2008-09-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45621, 'Oencia', 'Oencia', '', 42.5475800, -6.9685900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45622, 'Odón', 'Odon', 'Odon,Odón', 40.8841700, -1.5679200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45623, 'Òdena', 'Odena', 'Odena,Òdena', 41.6000000, 1.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45624, 'Ocón', 'Ocon', 'Econ,Ecón,Ocon,Ocón,Okon,ao kong,Окон,奥孔', 42.2989800, -2.2401900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45625, 'Oco', 'Oco', 'Oco', 42.6382800, -2.1647600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45626, 'Ochánduri', 'Ochanduri', 'Ochanduri,Ochánduri', 42.5252500, -3.0041500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45627, 'Otxandio', 'Otxandio', 'Ochandiano,Otxandio', 43.0333300, -2.6500000, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45628, 'Ocentejo', 'Ocentejo', 'Ocentejo', 40.7723400, -2.3976400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45629, 'Obón', 'Obon', 'Obon,Obón', 40.9045000, -0.7230000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45630, 'Obanos', 'Obanos', 'Obanos', 42.6807100, -1.7849300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45631, 'Nuñomoral', 'Nunomoral', 'Nun''jomoral'',Nun''omoral'',Nunomoral,Nuñomoral,nu ni ao mo la er,nwnywmawral,Нуньйомораль,Нуньомораль,نونيومأورال,努尼奥莫拉尔', 40.4069200, -6.2463600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45632, 'Nuño Gómez', 'Nuno Gomez', 'Nuno Gomez,Nuño Gómez', 40.1138300, -4.6197800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45633, 'Numancia de la Sagra', 'Numancia de la Sagra', 'Numancia de la Sagra', 40.0739500, -3.8511800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45634, 'Nuez de Ebro', 'Nuez de Ebro', 'Nuez de Ebro', 41.5895700, -0.6677400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45635, 'Nuevo Baztán', 'Nuevo Baztan', 'Nuehvo-Bastan,Nuevo Baztan,Nuevo Baztán,Nuevo-Bastan,nwfw baztan,xin ba si tan,Нуево-Бастан,Нуэво-Бастан,نوفو بازتان,新巴斯坦', 40.3673100, -3.2412500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45636, 'Nueva Villa de las Torres', 'Nueva Villa de las Torres', 'Nueva Villa de las Torres', 41.2676200, -5.0568500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45637, 'Nuévalos', 'Nuevalos', 'Nuevalos,Nuévalos', 41.2118500, -1.7895400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45638, 'Nueno', 'Nueno', 'Nueno', 42.2669700, -0.4390600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45639, 'Noia', 'Noia', '', 42.7858300, -8.8873400, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45640, 'Novillas', 'Novillas', 'Novillas', 41.9333400, -1.3941200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45641, 'Noviercas', 'Noviercas', 'Noviercas', 41.7119400, -2.0343300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45642, 'Novallas', 'Novallas', 'Novallas', 41.9500000, -1.7000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45643, 'Novales', 'Novales', 'Novales', 42.0320100, -0.2870000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45644, 'Noreña', 'Norena', 'Noren''ja,Norenija,nrnya,nuo lei ni ya,nwrynya,Норения,Норенья,نرنیا,نورينيا,诺雷尼亚', 43.3936400, -5.7066200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45645, 'Nonaspe', 'Nonaspe', 'Nonaspe', 41.2088100, 0.2477500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45646, 'Nombrevilla', 'Nombrevilla', '', 41.1073000, -1.3590400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45647, 'Nombela', 'Nombela', 'Nombela', 40.1553000, -4.5022300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45648, 'Nolay', 'Nolay', 'Nolaj,Nolay,Nolay i Spania,nuo lai,Нолай,诺莱', 41.5272100, -2.3506100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45649, 'Noja', 'Noja', 'Noja', 43.4891700, -3.5230600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45650, 'Nogueruelas', 'Nogueruelas', 'Nogueroles,Nogueruelas', 40.2362200, -0.6360600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45651, 'Nogueras', 'Nogueras', 'Nogueras', 41.1347500, -1.0670800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45652, 'Nogueira de Ramuín', 'Nogueira de Ramuin', 'Nogueira,Nogueira de Ramuin,Nogueira de Ramuín', 42.4171200, -7.7498200, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45653, 'Nogal de las Huertas', 'Nogal de las Huertas', 'Nogal de las Huertas', 42.3925500, -4.6415600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45654, 'Niharra', 'Niharra', 'Niharra', 40.5894500, -4.8389500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45655, 'Nigüella', 'Niguella', 'Niguella,Nigüella', 41.5362100, -1.5245000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45656, 'Nigrán', 'Nigran', 'Nigran,San Felix,San Félix,ni ge lan,niguran,nyghran,Нигран,Нігран,نيغران,ニグラン,尼格兰', 42.1415300, -8.8065600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45657, 'Nieva de Cameros', 'Nieva de Cameros', 'Nieva de Cameros', 42.2183500, -2.6670000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45658, 'Nieva', 'Nieva', 'Nieva', 41.0819100, -4.4250100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45659, 'Nestares', 'Nestares', 'Nestares', 42.2701400, -2.6199300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45660, 'Nepas', 'Nepas', 'Nepas', 41.5263900, -2.3986600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45661, 'Neila de San Miguel', 'Neila de San Miguel', 'Neila de San Miguel', 40.4237200, -5.6509000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45662, 'Neila', 'Neila', 'Neila,Nejla,nayla,nei la,Нейла,نايلا,内拉', 42.0601600, -2.9969100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45663, 'Negrilla de Palencia', 'Negrilla de Palencia', 'Negrilla de Palencia', 41.0918500, -5.5916500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45664, 'Negreira', 'Negreira', 'Negreira', 42.9040200, -8.7427300, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45665, 'Negredo', 'Negredo', 'Negredo', 41.0273700, -2.8587800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45666, 'Nebreda', 'Nebreda', 'Nebreda', 41.9688100, -3.6343000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45667, 'Nazar', 'Nazar', '', 42.6368600, -2.2796600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45668, 'Navianos de Valverde', 'Navianos de Valverde', 'Navianos de Valverde', 41.9531900, -5.8178100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45669, 'Navia de Suarna', 'Navia de Suarna', 'Navia de Suarna', 42.9666700, -7.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45670, 'Navia', 'Navia', 'Navia', 43.5354400, -6.7193500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45671, 'Navatejares', 'Navatejares', 'Navatejares', 40.3360200, -5.5322000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45672, 'Navatalgordo', 'Navatalgordo', 'Navatalgordo', 40.4152000, -4.8715500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45673, 'Navata', 'Navata', 'Navata', 42.2235300, 2.8611000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45674, 'Navasfrías', 'Navasfrias', 'Navasfrias,Navasfrías', 40.2967900, -6.8197500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45675, 'Navas de Oro', 'Navas de Oro', 'Navas de Oro', 41.1962700, -4.4375400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45676, 'Navas del Rey', 'Navas del Rey', 'Navas del Rey', 40.3861000, -4.2511700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45677, 'Navas de Bureba', 'Navas de Bureba', 'Navas de Bureba', 42.6809000, -3.3269800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45678, 'Navascués', 'Navascues', 'Navascues,Navascués', 42.7175800, -1.1174400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45679, 'Navàs', 'Navas', 'Navars,Navas,Navàs', 41.8999800, 1.8776300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45680, 'Navarrevisca', 'Navarrevisca', 'Navarrevisca', 40.3641700, -4.8935200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45681, 'Navarrete', 'Navarrete', '', 42.4306800, -2.5646600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45682, 'Navarredondilla', 'Navarredondilla', 'Navarredondilla', 40.4541600, -4.8219900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45683, 'Navarredonda de la Rinconada', 'Navarredonda de la Rinconada', 'Navarredonda de la Rinconada', 40.6065700, -6.0116900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45684, 'Navaridas', 'Navaridas', 'Nabaridas,Navaridas', 42.5456600, -2.6265000, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45685, 'Navares de las Cuevas', 'Navares de las Cuevas', 'Navares de las Cuevas', 41.4143100, -3.7507600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45686, 'Navares de Enmedio', 'Navares de Enmedio', 'Navares de Enmedio', 41.3809600, -3.7228300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45687, 'Navares de Ayuso', 'Navares de Ayuso', 'Navares de Ayuso', 41.3744700, -3.7074500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45688, 'Navardún', 'Navardun', 'Navardun,Navardún', 42.5125500, -1.1482200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45689, 'Navarcles', 'Navarcles', 'Navarcles', 41.7517100, 1.9035700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45690, 'Navaquesera', 'Navaquesera', 'Navaquesera', 40.4255800, -4.9110800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45691, 'Navamorcuende', 'Navamorcuende', 'Navamorcuende', 40.1565900, -4.7862500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45692, 'Navamorales', 'Navamorales', 'Navamorales', 40.4761800, -5.4789300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45693, 'Navaluenga', 'Navaluenga', 'Navaluenga', 40.4112300, -4.7089700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45694, 'Navalquejigo', 'Navalquejigo', 'Los Arroyos', 40.6070500, -4.0496600, 'ES', '2014-06-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45695, 'Navalperal de Tormes', 'Navalperal de Tormes', 'Navalperal de Tormes', 40.3528000, -5.3008400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45696, 'Navalperal de Pinares', 'Navalperal de Pinares', 'Navalperal,Navalperal de Pinares', 40.5939800, -4.4114900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45697, 'Navalosa', 'Navalosa', 'Navalesa,Navalosa,Navalosal', 40.4021200, -4.9299900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45698, 'Navalmoral de Béjar', 'Navalmoral de Bejar', 'Navalmoral de Bejar,Navalmoral de Béjar', 40.4226400, -5.7831000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45699, 'Navalmoral', 'Navalmoral', 'Naval''moral'',Navalmoral,na wa er mo la er,nabalmral,nafalmwral,Навалморал,Навальмораль,نابالمرال,نافالمورال,纳瓦尔莫拉尔', 40.4602800, -4.7685900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45700, 'Navalmanzano', 'Navalmanzano', 'Navalmanzano', 41.2159400, -4.2563100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45701, 'Navalilla', 'Navalilla', 'Navalilla', 41.3414600, -3.9321100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45702, 'Navales', 'Navales', 'Navales', 40.7885700, -5.4786300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45703, 'Navaleno', 'Navaleno', 'Navaleno,na wa lai nuo,nawalnw,Навалено,ناوالنو,纳瓦莱诺', 41.8383000, -3.0041800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45704, 'Navalcarnero', 'Navalcarnero', 'Naval''karnero,Navalcarnero,Navalkarnero,na wa er ka er nei luo,nabalkarnyrw,Навалькарнеро,نابالكارنيرو,纳瓦尔卡尔内罗', 40.2890800, -4.0119700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45705, 'Navalcán', 'Navalcan', 'Navalacan,Navalcan,Navalcán', 40.0666700, -5.0833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45706, 'Navalagamella', 'Navalagamella', 'Navalagamella', 40.4689400, -4.1233400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45707, 'Navalafuente', 'Navalafuente', 'Navalafuente', 40.8206300, -3.6726600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45708, 'Navalacruz', 'Navalacruz', 'Navalacruz', 40.4399300, -4.9312200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45709, 'Naval', 'Naval', 'Nabal,Naval', 42.1950300, 0.1518300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45710, 'Navajún', 'Navajun', '', 41.9666700, -2.1000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45711, 'Navahondilla', 'Navahondilla', 'Navahondilla', 40.3251000, -4.4966100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45712, 'Navafría', 'Navafria', 'Navafria,Navafría', 41.0551400, -3.8247800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45713, 'Navaescurial', 'Navaescurial', 'Navaescurial', 40.4716300, -5.2775600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45714, 'Navadijos', 'Navadijos', 'Navadijos', 40.4252400, -5.0828500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45715, 'Nava de Sotrobal', 'Nava de Sotrobal', 'Nava de Sotrobal', 40.8903900, -5.2856200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45716, 'Nava de Roa', 'Nava de Roa', 'Nava Cega,Nava de Roa', 41.6132600, -3.9644200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45717, 'Nava del Rey', 'Nava del Rey', 'Nava del Rey', 41.3303600, -5.0809500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45718, 'Nava del Barco', 'Nava del Barco', 'Nava del Barco', 40.2932100, -5.5402200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45719, 'Nava de la Asunción', 'Nava de la Asuncion', 'Nava de la Asuncion,Nava de la Asunción', 41.1558600, -4.4875100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45720, 'Nava de Francia', 'Nava de Francia', 'Nava de Francia', 40.5357200, -6.1162800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45721, 'Nava de Béjar', 'Nava de Bejar', 'Nava de Bejar,Nava de Béjar', 40.4751800, -5.6785600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45722, 'Nava de Arévalo', 'Nava de Arevalo', 'Nava de Arevalo,Nava de Arévalo', 40.9780300, -4.7757300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45723, 'Navaconcejo', 'Navaconcejo', 'Navaconcejo', 40.1771200, -5.8310800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45724, 'Navacerrada', 'Navacerrada', '', 40.7290500, -4.0169600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45725, 'Navacepedilla de Corneja', 'Navacepedilla de Corneja', 'Navacepedilla de Corneja', 40.4860200, -5.1838000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45726, 'Navacarros', 'Navacarros', 'Navacarros', 40.3977600, -5.7142500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45727, 'Nava', 'Nava', 'Nava', 43.3581000, -5.5106400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45728, 'Narros de Saldueña', 'Narros de Salduena', 'Narros de Salduena,Narros de Saldueña', 40.8726800, -4.8690900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45729, 'Narros de Matalayegua', 'Narros de Matalayegua', 'Narros de Matalayegua', 40.6988000, -5.9265800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45730, 'Narros del Puerto', 'Narros del Puerto', 'Narros del Puerto', 40.5413100, -4.9929100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45731, 'Narros del Castillo', 'Narros del Castillo', 'Narros del Castillo', 40.8586900, -5.0601000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45732, 'Narros', 'Narros', 'Narros', 41.8492300, -2.2947400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45733, 'Narrillos del Rebollar', 'Narrillos del Rebollar', 'Narrillos del Rebollar', 40.6648800, -4.9657700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45734, 'Narrillos del Álamo', 'Narrillos del Alamo', 'Narrillos del Alamo,Narrillos del Álamo', 40.5667300, -5.4658400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45735, 'Narón', 'Naron', 'Naron,Narón,San Julian,San Julian de Naron,Нарон', 43.5017500, -8.1908200, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45736, 'Nalec', 'Nalec', 'Nalec,Nalech', 41.5500000, 1.1166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45737, 'Nalda', 'Nalda', 'Nal''da,Nalda,na er da,Нальда,Նալդա,纳尔达', 42.3346700, -2.4871000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45738, 'Nájera', 'Najera', 'Nachera,Naiara,Naiera,Najera,Nakhera,Nájera,na he la,nahera,najrt,nʼhrh,Нáхера,Нахера,נאחרה,ناجرة,ナヘラ,纳赫拉', 42.4182200, -2.7286500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45739, 'Nafría de Ucero', 'Nafria de Ucero', 'Nafria de Ucero,Nafria-de-Usero,Nafrija-de-Usero,Nafriá de Ucero,Nafría de Ucero,na fu li ya de wu sai luo,Нафриа-де-Усеро,Нафрія-де-Усеро,纳夫里亚德乌塞罗', 41.7227300, -3.0949900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45740, 'Mutiloa', 'Mutiloa', 'Mutiloa', 43.0228800, -2.2725700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45741, 'Muruzábal', 'Muruzabal', '', 42.6905100, -1.7693100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45742, 'Muros de Nalón', 'Muros de Nalon', 'Muros,Muros de Nalon,Muros de Nalón,Santa Maria de Muros de Nalon,Santa María de Muros de Nalón', 43.5427700, -6.1034800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45743, 'Muros', 'Muros', 'Aebura,Ebora,Muros', 42.7761700, -9.0603200, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45744, 'Muro en Cameros', 'Muro en Cameros', 'Muro en Cameros', 42.2250900, -2.5303800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45745, 'Muro de Aguas', 'Muro de Aguas', 'Muro de Aguas,Muro de Ambas Aguas,Muro-de-Aguas,Muro-de-Agvas,mu luo de ya gua si,Муро-де-Агвас,Муро-де-Агуас,Մուրո դե Ագուաս,穆罗德亚瓜斯', 42.1336400, -2.1117500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45746, 'Murillo el Fruto', 'Murillo el Fruto', 'Murillo el Fruto', 42.3927200, -1.4603400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45747, 'Murillo de Río Leza', 'Murillo de Rio Leza', 'Muriello de Rio Leza,Muriello de Río Leza,Muril''jo-de-Rio-Lesa,Muril''o-de-Rio-Lesa,Murilio de Rio Lesa,Murillo,lai sa he pan mu li e,Мурильо-де-Рио-Леса,Мурільйо-де-Ріо-Леса,Մուրիլիո դե Ռիո Լեսա,莱萨河畔穆里略', 42.4009900, -2.3246400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45748, 'Murieta', 'Murieta', '', 42.6561800, -2.1545200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45749, 'Muriel Viejo', 'Muriel Viejo', 'Mur''el''-V''ekho,Murel''-Vekho,Muriel Viejo,mu lie er wei ye huo,Мурьель-Вьехо,Мурєль-Вєхо,穆列尔维耶霍', 41.7826100, -2.9152200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45750, 'Muriel de la Fuente', 'Muriel de la Fuente', 'Mur''el''-de-la-Fuehnte,Murel''-de-la-Fuente,Muriel de la Fuente,mu lie er de la feng te,Мурьель-де-ла-Фуэнте,Мурєль-де-ла-Фуенте,穆列尔德拉丰特', 41.7232000, -2.8600000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45751, 'Murias de Paredes', 'Murias de Paredes', 'Murias de Paredes,Murias-de-Paredes,mu li ya si de pa lei de si,Муриас-де-Паредес,Муріас-де-Паредес,穆里亚斯德帕雷德斯', 42.8502700, -6.1916400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45752, 'Murgia', 'Murguia', 'Murgia,Murguia,Murguia Zuya,Murguía,Murguía Zuya,Zuya', 42.9568600, -2.8194500, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45753, 'Murero', 'Murero', 'Murero', 41.1596700, -1.4827500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45754, 'Murchante', 'Murchante', 'Murchante', 42.0318500, -1.6558200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45755, 'Muras', 'Muras', 'Muras', 43.4668500, -7.7238300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45756, 'Mura', 'Mura', 'Mura', 41.6994300, 1.9761200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45757, 'Muñoveros', 'Munoveros', 'Munoveros,Muñoveros', 41.1723400, -3.9516100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45758, 'Muñotello', 'Munotello', 'Munotello,Muñotello', 40.5423600, -5.0418700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45759, 'Muñosancho', 'Munosancho', 'Munosancho,Muñosancho', 40.9209700, -5.0355900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45760, 'Muñopepe', 'Munopepe', 'Munopepe,Muñopepe', 40.6340800, -4.8187600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45761, 'Muñopedro', 'Munopedro', 'Munopedro,Muñopedro', 40.8880400, -4.4721300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45762, 'Muñomer del Peco', 'Munomer del Peco', 'Munomer del Peco,Muñomer del Peco', 40.8587800, -4.8799200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45763, 'Muñogrande', 'Munogrande', 'Munegrande,Munogrande,Muñogrande', 40.8218100, -4.9222300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45764, 'Muñogalindo', 'Munogalindo', 'Munogalindo,Muñogalindo', 40.6032400, -4.8989500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45765, 'Munilla', 'Munilla', 'Muniella,Munil''ja,Munilia,Munilla,mu ni li ya,Мунилья,Мунілья,Մունիլիա,穆尼利亚', 42.1890000, -2.2950600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45766, 'Muniesa', 'Muniesa', 'Muniesa', 41.0330800, -0.8114100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45767, 'Muñico', 'Munico', 'Munico,Muñico', 40.7067800, -5.0271700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45768, 'Mungia', 'Mungia', 'Mungia,Munguia,Munguía', 43.3546100, -2.8452400, 'ES', '2015-06-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45769, 'Munébrega', 'Munebrega', 'Munebrega,Munébrega', 41.2520300, -1.7055700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45770, 'Mundaka', 'Mundaka', 'Mundaca,Mundaka', 43.4080400, -2.6985200, 'ES', '2012-11-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45771, 'Muñana', 'Munana', 'Munana,Muñana', 40.5904200, -5.0144700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45772, 'Muiños', 'Muinos', '', 41.9560900, -7.9739600, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45773, 'Mugia', 'Mugia', 'Mugia,Mukhija,Muxia,Muxía,Мухия', 43.1041400, -9.2179100, 'ES', '2015-07-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45774, 'Mugardos', 'Mugardos', 'Mugardos,mu jia er duo si,mugarudosu,mwgardws,mwghradws,Мугардос,Մուգարդոս,موغرادوس,موگاردوس,ムガルドス,穆加尔多斯', 43.4604000, -8.2550700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45775, 'Muga de Sayago', 'Muga de Sayago', 'Muga de Sayago', 41.3877900, -6.1977700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45776, 'Muelas de los Caballeros', 'Muelas de los Caballeros', 'Muelas de los Caballeros', 42.1284300, -6.3371900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45777, 'Muel', 'Muel', 'Muehl'',Muel,Muel'',mu ai er,mwyl,Муель,Муэль,مويل,穆埃尔', 41.4663300, -1.0850300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45778, 'Muduex', 'Muduex', 'Muduex', 40.8293000, -2.9589900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45779, 'Mudá', 'Muda', 'Muda,Mudá', 42.8753000, -4.3942600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45780, 'Mucientes', 'Mucientes', 'Mucientes', 41.7427800, -4.7619100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45781, 'Mozota', 'Mozota', 'Mozota', 41.4841000, -1.0680700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45782, 'Mozoncillo', 'Mozoncillo', 'Mozoncillo', 41.1453900, -4.1875300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45783, 'Mozárbez', 'Mozarbez', 'Mozarbez,Mozarvez,Mozárbez,Mozárvez', 40.8565200, -5.6514400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45784, 'Moyuela', 'Moyuela', 'Moyoela,Moyuela', 41.1279200, -0.9222500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45785, 'Moià', 'Moia', '', 41.8111200, 2.0983900, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45786, 'Mutriku', 'Mutriku', 'Motrico,Mutriku', 43.3064300, -2.3851700, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45787, 'Mota del Marqués', 'Mota del Marques', 'Mota del Marques,Mota del Marqués', 41.6324700, -5.1768100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45788, 'Móstoles', 'Mostoles', 'Gorad Mostales,Monsteles,Mostoles,Mostolesas,Mostolo,mo si tuo lai si,moseutolleseu,mosutoresu,mwstwls,mwstwlys,Горад Мосталес,Мостолес,מוסטולס,موستولس,موستوليس,მოსტოლესი,モストレス,莫斯托莱斯,모스톨레스', 40.3223400, -3.8649600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45789, 'Mosqueruela', 'Mosqueruela', 'Mosqueroles,Mosqueruela,Mosqueruelas', 40.3613300, -0.4489000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45790, 'Moscardón', 'Moscardon', 'Moscardon,Moscardón', 40.3329500, -1.5368300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45791, 'Mos', 'Mos', 'Mos', 43.1566700, -7.5504700, 'ES', '2016-06-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45792, 'Moros', 'Moros', 'Moros', 41.3977500, -1.8283900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45793, 'Moronta', 'Moronta', 'Moronta', 40.9768800, -6.4310300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45794, 'Morón de Almazán', 'Moron de Almazan', 'Moron,Moron de Almazan,Moron-de-Al''masan,Morón de Almazán,mo long de ya er ma sang,Морон-де-Альмасан,莫龙德亚尔马桑', 41.4136100, -2.4131700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45795, 'Moriscos', 'Moriscos', 'Moriscos', 41.0081800, -5.5818400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45796, 'Morille', 'Morille', 'Morille', 40.8069300, -5.6983300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45797, 'Morés', 'Mores', 'Mores,Morés', 41.4732600, -1.5649100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45798, 'Moreruela de Tábara', 'Moreruela de Tabara', 'Moreruela de Tabara,Moreruela de Tábara', 41.7958800, -5.8684900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45799, 'Moreruela de los Infanzones', 'Moreruela de los Infanzones', 'Moreruela de los Infanzones', 41.6311800, -5.7061400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45800, 'Morentin', 'Morentin', '', 42.6128600, -2.0139300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45801, 'Morenilla', 'Morenilla', 'Morenilla', 40.7868700, -1.7071700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45802, 'Morella', 'Morella', 'Morella', 40.6196600, -0.0989200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45803, 'Moreda Araba / Moreda de Álava', 'Moreda de Alava', 'Moreda Araba,Moreda de Alava,Moreda de Álava,Moreta', 42.5257100, -2.4082800, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45804, 'Morcillo', 'Morcillo', 'Morcillo', 40.0188400, -6.3974600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45805, 'Moratinos', 'Moratinos', '', 42.3619100, -4.9283100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45806, 'Moratilla de los Meleros', 'Moratilla de los Meleros', 'Moratilla de los Meleros', 40.5018200, -2.9427600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45807, 'Moratalaz', 'Moratalaz', 'Barrio Moratalaz,Moratalaz distritu,Moratalazo,moratarasu,モラタラス', 40.4074200, -3.6493500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45808, 'Morata de Tajuña', 'Morata de Tajuna', 'Morata,Morata de Tajuna,Morata de Tajuña', 40.2268000, -3.4326900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45809, 'Morata de Jiloca', 'Morata de Jiloca', 'Morata de Jiloca', 41.2479700, -1.5866500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45810, 'Morata de Jalón', 'Morata de Jalon', 'Morata de Jalon,Morata de Jalón', 41.4734800, -1.4762800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45811, 'Morasverdes', 'Morasverdes', 'Morasverdes', 40.6001900, -6.2750300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45812, 'Moraña', 'Morana', 'Morana,Moraña,San Lorenzo', 42.5500000, -8.5833300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45813, 'Moralzarzal', 'Moralzarzal', '', 40.6781600, -3.9707000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45814, 'Moralina', 'Moralina', 'Moralina', 41.4900100, -6.1367000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45815, 'Morales de Valverde', 'Morales de Valverde', 'Morales de Valverde', 41.9364300, -5.8925500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45816, 'Morales de Toro', 'Morales de Toro', 'Morales de Toro', 41.5373700, -5.3064200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45817, 'Morales del Vino', 'Morales del Vino', 'Morales del Vino,Morales-del''-Vino,mo la lai si de er wei nuo,Моралес-дель-Вино,Моралес-дель-Віно,莫拉莱斯德尔维诺', 41.4473600, -5.7307000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45818, 'Morales de Campos', 'Morales de Campos', 'Morales de Campos', 41.8606800, -5.1725200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45819, 'Moraleja de Sayago', 'Moraleja de Sayago', 'Moraleja de Sayago', 41.1691600, -6.0036900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45820, 'Moraleja de Matacabras', 'Moraleja de Matacabras', 'Moraleja de Matacabras', 41.1073200, -4.9571700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45821, 'Moraleja del Vino', 'Moraleja del Vino', 'Moraleja del Vino', 41.4638500, -5.6563100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45822, 'Moraleja de las Panaderas', 'Moraleja de las Panaderas', 'Moraleja de las Panaderas', 41.2763600, -4.8252100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45823, 'Moraleja de Enmedio', 'Moraleja de Enmedio', '', 40.2612500, -3.8596300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45824, 'Moraleja', 'Moraleja', 'Moraleja', 40.0668200, -6.6598300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45825, 'Moral de Sayago', 'Moral de Sayago', 'Moral de Sayago', 41.4701900, -6.1006000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45826, 'Moral de la Reina', 'Moral de la Reina', 'Moral de la Paz,Moral de la Reina', 41.9861100, -5.0720800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45827, 'Moradillo de Roa', 'Moradillo de Roa', 'Moradillo de Roa', 41.5516400, -3.7911800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45828, 'Mora de Rubielos', 'Mora de Rubielos', 'Mora de Rubielos', 40.2502000, -0.7524900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45829, 'Monzón de Campos', 'Monzon de Campos', 'Monson-de-Kampos,Monzon,Monzon de Campos,Monzón,Monzón de Campos,meng song de kan bo si,Монсон-де-Кампос,蒙松德坎波斯', 42.1160400, -4.4928300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45830, 'Monzón', 'Monzon', 'Montso,Montsó,Monzon,Monzón', 41.9108400, 0.1940600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45831, 'Mont-roig del Camp', 'Mont-roig del Camp', 'Mont-roig del Camp,Montroig', 41.0867500, 0.9592500, 'ES', '2015-06-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45832, 'Mont-ral', 'Mont-ral', 'Mont-ral,Montreal', 41.2833300, 1.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45833, 'Montornès del Vallès', 'Montornes del Valles', 'Montornes del Valles,Montornès del Vallès', 41.5420600, 2.2674800, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45834, 'Montorio', 'Montorio', '', 42.5846900, -3.7772400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45835, 'Montón', 'Monton', '', 41.2066700, -1.5155000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45836, 'Montmeló', 'Montmelo', 'Montmelo,Montmeló', 41.5500200, 2.2419000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45837, 'Montferri', 'Montferri', 'Montferri', 41.2654500, 1.3651700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45838, 'Montesquiu', 'Montesquiu', 'Montesquiu,Montesquíu', 42.1166700, 2.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45839, 'Montesclaros', 'Montesclaros', 'Montesclaros', 40.1064600, -4.9384900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45840, 'Monterrubio de la Sierra', 'Monterrubio de la Sierra', 'Monterrubio de la Sierra', 40.7559200, -5.6932900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45841, 'Monterrubio de Armuña', 'Monterrubio de Armuna', 'Monterrubio de Armuna,Monterrubio de Armuña', 41.0265100, -5.6438900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45842, 'Monterrubio', 'Monterrubio', 'Monterrubio', 40.8491400, -4.3500100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45843, 'Monterroso', 'Monterroso', 'Monterroso,meng te luo suo,monteroso,Монтерросо,モンテローソ,蒙特罗索', 42.7925000, -7.8342500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45844, 'Monterde de Albarracín', 'Monterde de Albarracin', 'Monterde,Monterde de Albarracin,Monterde de Albarracín', 40.4970800, -1.4921600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45845, 'Monterde', 'Monterde', 'Monterde', 41.1743400, -1.7350500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45846, 'Montenegro de Cameros', 'Montenegro de Cameros', 'Montenegro,Montenegro de Cameras,Montenegro de Cameros', 42.0892400, -2.7540600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45847, 'Montemayor de Pililla', 'Montemayor de Pililla', 'Montemayor de Pililla', 41.5087400, -4.4574500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45848, 'Montemayor del Río', 'Montemayor del Rio', 'Montemayor,Montemayor del Rio,Montemayor del Río', 40.3483600, -5.8942700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45849, 'Montejo de Tiermes', 'Montejo de Tiermes', 'Montejo de Liceras,Montejo de Tiermes,Montekho-de-T''ermes,meng te huo de tie er mei si,Монтехо-де-Тьермес,Монтехо-де-Тьєрмес,蒙特霍德铁尔梅斯', 41.3683800, -3.2001600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45850, 'Montejo de la Vega de la Serrezuela', 'Montejo de la Vega de la Serrezuela', 'Montejo de la Vega,Montejo de la Vega de la Serrezuela', 41.5503200, -3.6540600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45851, 'Montejo de la Sierra', 'Montejo de la Sierra', 'Montejo de la Sierra', 41.0595500, -3.5299300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45852, 'Montejo de Arévalo', 'Montejo de Arevalo', 'Montejo de Arevalo,Montejo de Arévalo', 41.1402700, -4.6641400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45853, 'Montejo', 'Montejo', 'Montejo', 40.6324600, -5.6228700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45854, 'Montehermoso', 'Montehermoso', 'Monteermoso,Montehermosa,Montehermoso,Montelmosou,Montelmosu,meng te ai er mo suo,mnthrmsw,monteerumoso,mwntyhyrmwsw,Μοντελμόσου,Монтеермосо,منتهرمسو,مونتيهيرموسو,ሞንቴርሞሶ,モンテエルモーソ,蒙特埃尔莫索', 40.0879600, -6.3498400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45855, 'Montederramo', 'Montederramo', 'Montederramo', 42.2755400, -7.5013800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45856, 'Monteagudo del Castillo', 'Monteagudo del Castillo', 'Monteagudo del Castillo', 40.4565600, -0.8178100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45857, 'Monteagudo de las Vicarías', 'Monteagudo de las Vicarias', 'Monteagudo,Monteagudo de las Vicarias,Monteagudo de las Vicarías,Monteagudo-de-las-Vikarias,meng te ya gu duo de la si wei ka li ya si,Монтеагудо-де-лас-Викариас,Монтеагудо-де-лас-Вікаріас,蒙特亚古多德拉斯维卡里亚斯', 41.3648500, -2.1696000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45858, 'Monteagudo', 'Monteagudo', '', 41.9666700, -1.6833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45859, 'Montblanc', 'Montblanc', 'Monblan,Montblanc,Montblanch,Монблан', 41.3763600, 1.1616300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45860, 'Montarrón', 'Montarron', 'Montarron,Montarrón', 40.9067500, -3.1149500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45861, 'Muntanyola', 'Muntanyola', 'Muntanyola', 41.8833300, 2.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45862, 'Montanejos', 'Montanejos', 'Montanejos', 40.0666700, -0.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45863, 'Montán', 'Montan', 'Montan,Montant,Montán', 40.0333300, -0.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45864, 'Montamarta', 'Montamarta', 'Montamarta', 41.6472400, -5.8040200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45865, 'Montalbán', 'Montalban', 'Montalban,Montalbán', 40.8327800, -0.8017800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45866, 'Monsalupe', 'Monsalupe', 'Monsalupe', 40.7695300, -4.7813100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45867, 'Monsagro', 'Monsagro', 'Monsagro', 40.5034300, -6.2711000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45868, 'Monroyo', 'Monroyo', 'Monroyo', 40.7877500, -0.0355000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45869, 'Monreal del Campo', 'Monreal del Campo', 'Monreal del Campo', 40.7880000, -1.3554100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45870, 'Monreal de Ariza', 'Monreal de Ariza', 'Monreal de Ariza', 41.2916500, -2.1049300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45871, 'Monreal', 'Monreal', 'Elo,Monreal,Monreal'',Mont-reyal,meng lei ya er,Монреаль,蒙雷亚尔', 42.7042100, -1.5078500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45872, 'Monleras', 'Monleras', 'Monleras', 41.1870400, -6.2262200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45873, 'Monleón', 'Monleon', 'Monleon,Monleón', 40.5819200, -5.8431200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45874, 'Monistrol de Montserrat', 'Monistrol de Montserrat', 'Monistrol,Monistrol de Montserrat,Monistrol''-de-Monserrat,Монистроль-де-Монсеррат', 41.6166700, 1.8500000, 'ES', '2013-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45875, 'Montgat', 'Montgat', 'Montgat', 41.4685900, 2.2800100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45876, 'Monforte de Moyuela', 'Monforte de Moyuela', 'Monforte de Moyuela', 41.0551200, -1.0141100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45877, 'Monforte de Lemos', 'Monforte de Lemos', 'Monforte,Monforte de Lemos,Monforte-de-Lemos,meng fu er te de lai mo si,Монфорте-де-Лемос,モンフォルテ・デ・レモス,蒙福尔特德莱莫斯', 42.5216500, -7.5142200, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45878, 'Monforte de la Sierra', 'Monforte de la Sierra', 'Monforte de la Sierra', 40.4826400, -6.0567100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45879, 'Monfero', 'Monfero', 'Monfero,Monferro,San Felix,San Félix', 43.3333300, -8.0166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45880, 'Monfarracinos', 'Monfarracinos', 'Monfarracinos', 41.5546800, -5.7079500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45881, 'Moneva', 'Moneva', 'Moneva', 41.1281700, -0.8359100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45882, 'Monegrillo', 'Monegrillo', 'Monegrillo', 41.6385600, -0.4157000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45883, 'Arrasate / Mondragón', 'Arrasate / Mondragon', 'Arrasate,Mondragoe,Mondragon,Mondrague,Mondragón,Montdragon', 43.0644100, -2.4897700, 'ES', '2012-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45884, 'Mondoñedo', 'Mondonedo', 'Mondonedo,Mondoñedo,San Vicente', 43.4000000, -7.4000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45885, 'Mondéjar', 'Mondejar', 'Mondejar,Mondéjar', 40.3209500, -3.1068600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45886, 'Mondariz-Balneario', 'Mondariz-Balneario', '', 42.2268600, -8.4672800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45887, 'Mondariz', 'Mondariz', 'Mondariz', 42.2311000, -8.4583900, 'ES', '2013-08-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45888, 'Moncalvillo', 'Moncalvillo', 'Moncalvillo', 41.9541300, -3.1988600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45889, 'Montcada i Reixac', 'Montcada i Reixac', 'Moncada i Reixac,Montcada,Montcada i Reixac', 41.4833300, 2.1833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45890, 'Monasterio de Vega', 'Monasterio de Vega', 'Monasterio de Vega', 42.2301500, -5.1809500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45891, 'Monasterio de Rodilla', 'Monasterio de Rodilla', 'Monasterio,Monasterio de Rodilla', 42.4577500, -3.4696500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45892, 'Monasterio de la Sierra', 'Monasterio de la Sierra', 'Monasterio de la Sierra', 42.0518000, -3.1931400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45893, 'Monasterio', 'Monasterio', '', 40.9854700, -3.0971100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45894, 'Mombuey', 'Mombuey', 'Mombuey', 42.0228300, -6.3302700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45895, 'Momblona', 'Momblona', 'Momblona', 41.4442000, -2.3466000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45896, 'Mombeltrán', 'Mombeltran', 'Mombel''tran,Mombeltran,Mombeltrán,meng wei er te lan,mmbltran,mwmbyltran,Момбелтран,Момбельтран,ممبلتران,مومبيلتران,蒙韦尔特兰', 40.2598700, -5.0174900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45897, 'Mollet de Peralada', 'Mollet de Peralada', 'Mollet,Mollet de Peralada', 42.3595900, 3.0003400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45898, 'Mollet del Vallès', 'Mollet del Valles', 'Mollet del Valles,Mollet del Vallès,Mollet del Vallés', 41.5402600, 2.2130600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45899, 'Mollerussa', 'Mollerussa', 'Mollerusa,Mollerussa,Morellusa', 41.6333300, 0.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45900, 'Molledo', 'Molledo', 'Molledo', 43.1497400, -4.0423900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45901, 'Molins de Rei', 'Molins de Rei', 'Molins,Molins de Rei', 41.4166700, 2.0166700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45902, 'Molinos de Duero', 'Molinos de Duero', 'Molinos de Duero', 41.8860300, -2.7868200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45903, 'Molinos', 'Molinos', 'Molinos', 40.8210000, -0.4501700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45904, 'Molinillo', 'Molinillo', 'Molinillo', 40.4689800, -5.9449300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45905, 'Molinaseca', 'Molinaseca', 'Molinaseca,Molinaseka,mo li na sai ka,morinaseka,Молинасека,Молінасека,モリーナセカ,莫利纳塞卡', 42.5382900, -6.5199700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45906, 'Molina de Aragón', 'Molina de Aragon', 'Molina,Molina d''Aragon,Molina dAragon,Molina dAragón,Molina de Aragao,Molina de Aragon,Molina de Aragão,Molina de Aragón,Molina-de-Aragon,Molino de Aragon,Molino de Aragón,mo li na de ya la gong,Молина-де-Арагон,Моліна-де-Арагон,莫利纳德亚拉贡', 40.8435800, -1.8876200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45907, 'Molezuelas de la Carballeda', 'Molezuelas de la Carballeda', 'Molezuelas de la Carballeda', 42.0816600, -6.1872300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45908, 'Molacillos', 'Molacillos', 'Molacillos', 41.5826900, -5.6604600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45909, 'Mojados', 'Mojados', '', 41.4323700, -4.6649000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45910, 'Mohernando', 'Mohernando', 'Mohernando', 40.8012900, -3.1723400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45911, 'Mogarraz', 'Mogarraz', 'Mogarraz', 40.4926400, -6.0532700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45912, 'Moeche', 'Moeche', 'Moeche,San Juan', 43.5500000, -8.0166700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45913, 'Modúbar de la Emparedada', 'Modubar de la Emparedada', '', 42.2611800, -3.6596500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45914, 'Mochales', 'Mochales', 'Mochales', 41.0964700, -2.0156000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45915, 'Moaña', 'Moana', 'Moan''ja,Moana,Moanija,Moaña,San Martin,San Martín,mo a ni ya,moanya,mwanya  bwntyfydra,Моания,Моанья,موانيا، بونتيفيدرا,モアーニャ,莫阿尼亚', 42.2833300, -8.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45916, 'Mironcillo', 'Mironcillo', 'Mironcillo', 40.5543500, -4.8244900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45917, 'Miravet', 'Miravet', 'Miravet', 41.0393000, 0.5966500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45918, 'Miraveche', 'Miraveche', 'Mirabetxe,Miraveche', 42.6739600, -3.1994700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45919, 'Miranda del Castañar', 'Miranda del Castanar', 'Miranda del Castanar,Miranda del Castañar', 40.4844800, -5.9958100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45920, 'Miranda de Ebro', 'Miranda de Ebro', 'Miranda,Miranda Ebro,Miranda dEbro,Miranda de Ebro,Miranda del Ebro,Miranda-de-Ebro,Miranda-de-Ehbro,ai bu luo he pan mi lan da,milandadeebeulo,myranda dy aybrw,Миранда-де-Эбро,Міранда-де-Ебро,ميراندا دي إيبرو,ሚራንዳ ዴ ኤብሮ,ミランダ・デ・エブロ,埃布罗河畔米兰达,미란다데에브로', 42.6865000, -2.9469500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45921, 'Miranda de Azán', 'Miranda de Azan', 'Miranda de Azan,Miranda de Azán', 40.8875200, -5.6818200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45922, 'Miranda de Arga', 'Miranda de Arga', 'Miranda de Arga', 42.4833700, -1.8275900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45923, 'Mirambel', 'Mirambel', 'Mirambel,Mirambell', 40.5873300, -0.3426600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45924, 'Miralrío', 'Miralrio', 'Miralrio,Miralrío', 40.8890100, -2.9434000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45925, 'Miralcamp', 'Miralcamp', 'Miralcamp', 41.6051600, 0.8798700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45926, 'Mirafuentes', 'Mirafuentes', '', 42.6229700, -2.2796600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45927, 'Miraflores de la Sierra', 'Miraflores de la Sierra', '', 40.8155000, -3.7621300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45928, 'Mirabueno', 'Mirabueno', 'Mirabueno', 40.9447900, -2.7243800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45929, 'Miño de San Esteban', 'Mino de San Esteban', 'Mino de San Esteban,Miño de San Esteban', 41.5358400, -3.3457900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45930, 'Miño', 'Mino', 'Mino,Miño,Santa Maria,Santa María', 43.3500000, -8.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45931, 'Mingorría', 'Mingorria', 'Mingorria,Mingorría', 40.7519200, -4.6658300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45932, 'Milmarcos', 'Milmarcos', 'Milmarcos', 41.0862200, -1.8765200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45933, 'Milles de la Polvorosa', 'Milles de la Polvorosa', 'Milles de la Polvorosa', 41.9233900, -5.7330900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45934, 'Millana', 'Millana', 'Millana', 40.5071700, -2.5711600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45935, 'Milagros', 'Milagros', 'Milagros', 41.5750000, -3.6990700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45936, 'Milagro', 'Milagro', 'Milagro,Miraglo,mi la ge luo,Милагро,Мілагро,米拉格罗', 42.2416000, -1.7658800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45937, 'Mijares', 'Mijares', 'Mijares', 40.2965500, -4.8365100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45938, 'Migueláñez', 'Miguelanez', 'Miguelanez,Migueláñez', 41.1215500, -4.3641000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45939, 'Mieza', 'Mieza', 'M''esa,Mesa,Mieza,Mieza de la Ribera,mi ye sa,Мьеса,Мєса,米耶萨', 41.1642400, -6.6913700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45940, 'Mieres', 'Mieres', 'M''eres,Mieres,Мьерес', 43.2500000, -5.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45941, 'Mieres', 'Mieres', 'Mieras,Mieres', 42.1224700, 2.6385000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45942, 'Miengo', 'Miengo', 'Miengo', 43.4286100, -3.9986600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45943, 'Miedes de Atienza', 'Miedes de Atienza', 'Miedes,Miedes de Atienza,Miedes de Pela', 41.2667200, -2.9637500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45944, 'Micieces de Ojeda', 'Micieces de Ojeda', 'Micieces de Ojeda', 42.6907800, -4.4616600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45945, 'Micereces de Tera', 'Micereces de Tera', 'Micereces de Tera', 41.9888600, -5.8713300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45946, 'Mianos', 'Mianos', '', 42.5854400, -0.9547800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45947, 'Mezquita de Jarque', 'Mezquita de Jarque', 'Mezquita de Jarque', 40.7210000, -0.8670000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45948, 'Mezalocha', 'Mezalocha', 'Mezalocha', 41.4258100, -1.0827600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45949, 'Metauten', 'Metauten', '', 42.6771400, -2.1301500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45950, 'Mesones de Isuela', 'Mesones de Isuela', 'Mesones de Isuela', 41.5511900, -1.5385800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45951, 'Mesia', 'Mesia', 'Mesia,San Cristobal,San Cristóbal', 43.1000000, -8.2666700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45952, 'Mesegar de Corneja', 'Mesegar de Corneja', 'Mesegar de Corneja', 40.5020900, -5.3013100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45953, 'Mequinensa / Mequinenza', 'Mequinensa / Mequinenza', 'Mequinensa,Mequinensa / Maquinenza,Mequinenza', 41.3721100, 0.3016900, 'ES', '2010-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45954, 'Méntrida', 'Mentrida', 'Mentrida,Méntrida,men te li da,Ментрида,Ментріда,门特里达', 40.2389900, -4.1933700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45955, 'Mengamuñoz', 'Mengamunoz', 'Mengamunoz,Mengamuñoz', 40.5000600, -4.9998300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45956, 'Meneses de Campos', 'Meneses de Campos', 'Meneses de Campos', 41.9414200, -4.9192700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45957, 'Mendigorría', 'Mendigorria', 'Mendigorria,Mendigorría', 42.6282200, -1.8345000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45958, 'Mendavia', 'Mendavia', 'Mondaria', 42.4433500, -2.2008700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45959, 'Mendaro', 'Mendaro', 'Mendaro', 43.2532600, -2.3856800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45960, 'Membrillera', 'Membrillera', 'Membrillera', 40.9480700, -2.9796900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45961, 'Membribe de la Sierra', 'Membribe de la Sierra', 'Membribe,Membribe de la Sierra', 40.6912300, -5.8056800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45962, 'Membibre de la Hoz', 'Membibre de la Hoz', 'Membibre de la Hoz', 41.4495800, -4.0957100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45963, 'Melque de Cercos', 'Melque de Cercos', 'Melque', 41.0516600, -4.4694400, 'ES', '2015-12-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45964, 'Melón', 'Melon', 'Melon,Melón', 42.2601600, -8.2140000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45965, 'Melide', 'Melide', 'Mel''id,Melide,Mellid,mei li de,meride,mylydy  la krwnya,Мелиде,Мельид,Меліде,ميليدي، لا كرونيا,メリーデ,梅利德', 42.9138200, -8.0149600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45966, 'Mélida', 'Melida', 'Melida,Mélida', 42.3586900, -1.5488800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45967, 'Melgar de Yuso', 'Melgar de Yuso', '', 42.2538100, -4.2539400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45968, 'Melgar de Tera', 'Melgar de Tera', 'Melgar de Tera', 41.9661800, -6.0139000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45969, 'Melgar de Fernamental', 'Melgar de Fernamental', 'Mel''gar-de-Fernamental'',mei er jia er de fei er na men ta er,mylghar dy fyrnamyntal,Мельгар-де-Фернаменталь,ميلغار دي فيرنامينتال,梅尔加尔德费尔纳门塔尔', 42.4044500, -4.2448400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45970, 'Melgar de Arriba', 'Melgar de Arriba', 'Melgar de Arriba', 42.2680600, -5.0971200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45971, 'Melgar de Abajo', 'Melgar de Abajo', 'Melgar de Abajo', 42.2434400, -5.1421600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45972, 'Mejorada del Campo', 'Mejorada del Campo', 'Mejorada del Campo', 40.3928300, -3.4819400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45973, 'Mejorada', 'Mejorada', 'Mejorada', 40.0099100, -4.8850600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45974, 'Meis', 'Meis', 'Meis,San Martin,San Martín', 42.5000000, -8.7500000, 'ES', '2012-02-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45975, 'Meira', 'Meira', '', 43.2133700, -7.2937200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45976, 'Megina', 'Megina', 'Megina', 40.6391100, -1.8704100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45977, 'Megeces', 'Megeces', 'Megeces', 41.4082800, -4.5616600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45978, 'Medrano', 'Medrano', 'Medrano', 42.3836100, -2.5539400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45979, 'Medranda', 'Medranda', 'Medranda', 40.9833300, -2.9371900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45980, 'Mediona', 'Mediona', 'Mediona', 41.4779800, 1.6122200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45981, 'Medinilla', 'Medinilla', 'Medinilla', 40.4396700, -5.6177200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45982, 'Medina de Ríoseco', 'Medina de Rioseco', 'Medina de Rioseco,Medina de Ríoseco', 41.8832700, -5.0440500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45983, 'Medina de Pomar', 'Medina de Pomar', 'Medina de Pomar,Medina-de-Pomar,mei di na de bo ma er,mydayna dy bwmar,Медина-де-Помар,Медіна-де-Помар,ميداينا دي بومار,梅迪纳德波马尔', 42.9293800, -3.4880400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45984, 'Medina del Campo', 'Medina del Campo', 'Medina del Campo,Medina-del''-Kampo,mei di na de er kan bo,Медина-дель-Кампо,Медіна-дель-Кампо,メディナ・デル・カンポ,梅迪纳德尔坎波', 41.3123900, -4.9141300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45985, 'Medinaceli', 'Medinaceli', 'Medina,Medinaceli,Medinaseli,Occilis,mdynt salm,medinaseri,mei di na sai li,Мединасели,Медінаселі,مدينة سالم,メディナセリ,梅迪纳塞利', 41.1722400, -2.4347600, 'ES', '2014-09-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45986, 'Mediana de Voltoya', 'Mediana de Voltoya', 'Mediana,Mediana de Voltoya', 40.7010400, -4.5634100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45987, 'Meco', 'Meco', '', 40.5527400, -3.3289400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45988, 'Mecerreyes', 'Mecerreyes', 'Mecerreyes', 42.0953600, -3.5739300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45989, 'Meaño', 'Meano', 'Meano,Meaño,San Juan', 42.4466100, -8.7812200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45990, 'Mazuela', 'Mazuela', '', 42.2076700, -3.9192000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45991, 'Mazuecos de Valdeginate', 'Mazuecos de Valdeginate', 'Mazuecos de Valdeginate', 42.1681400, -4.8405900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45992, 'Mazuecos', 'Mazuecos', 'Mazuecos', 40.2602000, -3.0075500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45993, 'Mazariegos', 'Mazariegos', 'Mazariegos', 42.0269100, -4.7154200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45994, 'Mazaricos', 'Mazaricos', 'Mazaricos', 42.9403300, -8.9718700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45995, 'Mazarete', 'Mazarete', 'Mazarate,Mazare,Mazarete', 41.0008600, -2.1592100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45996, 'Mazaleón', 'Mazaleon', 'Mazaleon,Mazaleón', 41.0505600, 0.1029000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45997, 'Mayorga', 'Mayorga', 'Majorga,Mayorga,mai ao er jia,Майорга,Մայորգա,迈奥尔加', 42.1668700, -5.2630400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45998, 'Maials', 'Maials', 'Maials,Mayal,Mayals', 41.3666700, 0.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(45999, 'Mayalde', 'Mayalde', 'Mayalde', 41.2508000, -5.7976700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46000, 'Matute', 'Matute', 'Matute', 42.2988800, -2.7956400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46001, 'Matillas', 'Matillas', 'Matillas', 40.9441500, -2.8359000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46002, 'Matilla la Seca', 'Matilla la Seca', 'Matilla la Seca', 41.5793500, -5.5003000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46003, 'Matilla de los Caños del Río', 'Matilla de los Canos del Rio', 'Matilla de los Canos,Matilla de los Canos del Rio,Matilla de los Caños,Matilla de los Caños del Río', 40.8253900, -5.9427600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46004, 'Matilla de los Caños', 'Matilla de los Canos', 'Matilla de los Canos,Matilla de los Caños', 41.5481800, -4.9676100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46005, 'Matilla de Arzón', 'Matilla de Arzon', 'Matilla,Matilla de Arzon,Matilla de Arzón', 42.1049900, -5.6415600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46006, 'Matarrubia', 'Matarrubia', 'Matarrubia', 40.8646300, -3.2894400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46007, 'Mataró', 'Mataro', 'Iluro,Mataro,Mataró,ma ta luo,matalo,mataro,matarw  brshlwnt,Матаро,ماتارو، برشلونة,मातारो,マタロー,马塔罗,마타로', 41.5421100, 2.4445000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46008, 'Matapozuelos', 'Matapozuelos', 'Matapozuelos', 41.4142300, -4.7912200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46009, 'Mataporquera', 'Mataporquera', 'Mataporquera,Valdeolea', 42.8748600, -4.1627600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46010, 'Matamala de Almazán', 'Matamala de Almazan', 'Matamala,Matamala de Almazan,Matamala de Almazán,Matamala-de-Al''masan,ma ta ma la de ya er ma sang,Матамала-де-Альмасан,马塔马拉德亚尔马桑', 41.5056300, -2.6412200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46011, 'Matallana de Torío', 'Matallana de Torio', 'Matachana de Toriu,Matachana de Toríu,Matal''jana-de-Torio,Matallana de Torio,Matallana de Torío,ma ta li ya na de tuo li ao,Матальяна-де-Торио,Матальяна-де-Торіо,马塔利亚纳德托里奥', 42.8656000, -5.5203400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46012, 'Matalebreras', 'Matalebreras', 'Matalebreras,ma ta lai fu lei la si,Маталебрерас,马塔莱夫雷拉斯', 41.8411600, -2.0464400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46013, 'Matadepera', 'Matadepera', 'Matadepera', 41.5988600, 2.0264800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46014, 'Matadeón de los Oteros', 'Matadeon de los Oteros', 'Matadeon,Matadeon de los Oteros,Matadeón de los Oteros', 42.3377600, -5.3688700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46015, 'Mata de Cuéllar', 'Mata de Cuellar', 'Mata de Cuellar,Mata de Cuéllar', 41.3965500, -4.4716700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46016, 'Matabuena', 'Matabuena', 'Matabuena', 41.0959000, -3.7582700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46017, 'Masueco', 'Masueco', 'Masueco,Masuecu,Masuehko,Masueko,ma su ai ke,Масуеко,Масуэко,马苏埃科', 41.2035200, -6.5893800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46018, 'Maçanet de la Selva', 'Macanet de la Selva', 'Macanet de la Selva,Maçanet de la Selva', 41.7833300, 2.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46019, 'Maçanet de Cabrenys', 'Macanet de Cabrenys', 'Macanet de Cabrenys,Maçanet de Cabrenys', 42.3859700, 2.7480600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46020, 'Massanes', 'Massanes', 'Macanes,Massanes,Maçanes', 41.7653600, 2.6532400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46021, 'el Masroig', 'el Masroig', 'Masroig,el Masroig', 41.1333300, 0.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46022, 'Masquefa', 'Masquefa', 'Masquefa', 41.5035300, 1.8113600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46023, 'El Masnou', 'El Masnou', 'el Masnou', 41.4797800, 2.3188000, 'ES', '2010-12-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46024, 'Maside', 'Maside', 'Maside', 42.4103100, -8.0258200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46025, 'Masegoso de Tajuña', 'Masegoso de Tajuna', 'Masegoso de Tajuna,Masegoso de Tajuña', 40.8255200, -2.6953200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46026, 'Masegosa', 'Masegosa', 'Masegosa', 40.5468900, -2.0258800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46027, 'Masdenverge', 'Masdenverge', 'Masdenverge', 40.7160000, 0.5300900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46028, 'Mas de las Matas', 'Mas de las Matas', 'Mas de las Matas', 40.8340800, -0.2429200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46029, 'Mas de Barberans', 'Mas de Barberans', '', 40.7333300, 0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46030, 'Masarac', 'Masarac', 'Masarac', 42.3509000, 2.9729600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46031, 'Marzales', 'Marzales', 'Marzales', 41.5864400, -5.1345500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46032, 'Marugán', 'Marugan', 'Marugan,Marugán', 40.8994300, -4.3838300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46033, 'Martorell', 'Martorell', 'Martorel'',Martorell,Martorelle,Marturel'',ma er tuo lei li,martwrl,martwryl,Марторелле,Марторель,Мартурель,مارتورل,مارتوريل,马尔托雷利', 41.4740200, 1.9306200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46034, 'Martín Muñoz de las Posadas', 'Martin Munoz de las Posadas', 'Martin Munoz de las Posadas,Martín Muñoz de las Posadas', 40.9954600, -4.5967200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46035, 'Martín Muñoz de la Dehesa', 'Martin Munoz de la Dehesa', 'Martin Munoz de la Dehesa,Martín Muñoz de la Dehesa', 41.0665200, -4.6867600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46036, 'Martín Miguel', 'Martin Miguel', 'Martin Miguel,Martín Miguel', 40.9522000, -4.2716600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46037, 'Martínez', 'Martinez', 'Martinez,Martínez', 40.6304600, -5.3480100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46038, 'Martín de Yeltes', 'Martin de Yeltes', 'Martin de Yeltes,Martín de Yeltes', 40.7759400, -6.2916200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46039, 'Martín del Río', 'Martin del Rio', 'Martin del Rio,Martín del Río', 40.8445900, -0.8954900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46040, 'Martinamor', 'Martinamor', 'Martinamor', 40.8067600, -5.5991300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46041, 'Martiherrero', 'Martiherrero', 'Martiherrero', 40.6739200, -4.7815600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46042, 'Martiago', 'Martiago', 'Martiago', 40.4542000, -6.4901000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46043, 'Marracos', 'Marracos', '', 42.0882600, -0.7758700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46044, 'Markina-Xemein', 'Markina-Xemein', 'Markina,Markina-Khemejn,Markina-Shemejn,Markina-Xemein,Marquina-Jemein,Marquina-Jeméin,ma er ji na-ke sai men,markayna-kzymayn,Маркина-Хемейн,Маркіна-Шемейн,ماركاينا-كزيماين,马尔基纳-克塞门', 43.2666700, -2.5000000, 'ES', '2012-11-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46045, 'Marín', 'Marin', '', 42.3833300, -8.7000000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46046, 'Mariana', 'Mariana', 'Mariana', 40.1671700, -2.1460100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46047, 'María de Huerva', 'Maria de Huerva', 'Maria,Maria de Huerva,María de Huerva', 41.5388000, -0.9961500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46048, 'Margalef', 'Margalef', 'Margalef', 41.2849600, 0.7533100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46049, 'Marcilla de Campos', 'Marcilla de Campos', 'Marcilla de Campos', 42.3177000, -4.3967000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46050, 'Marcilla', 'Marcilla', 'Marcilla', 42.3279400, -1.7371400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46051, 'Marchamalo', 'Marchamalo', 'Marchamalo', 40.6667700, -3.1991400, 'ES', '2016-11-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46052, 'Marchagaz', 'Marchagaz', 'Marchagaz', 40.2676900, -6.2748500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46053, 'Marazuela', 'Marazuela', 'Marazuela', 40.9791200, -4.3650600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46054, 'Marazoleja', 'Marazoleja', 'Marazoleja', 40.9608600, -4.3388200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46055, 'Marañón', 'Maranon', 'Maran''jon,Maran''on,Maranon,Maranoni jogi,Maranyon,Maranyón,Marañon,Marañón,Marañóni jõgi,Rio Maranon,Rio Marañón,Río Marañón,ma la ni weng,mrnywn,Мараньйон,Мараньон,מרניון,马拉尼翁', 42.6294100, -2.4393100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46056, 'Meranges', 'Meranges', 'Maranges,Meranges', 42.4451800, 1.7877700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46057, 'Maranchón', 'Maranchon', 'Maranchon,Maranchón,ma lan qiong,Маранчон,马兰琼', 41.0475400, -2.2048200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46058, 'Maraña', 'Marana', 'Marana,Maraña', 43.0499100, -5.1772600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46059, 'Mara', 'Mara', 'Mara', 41.2895000, -1.5184200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46060, 'Maqueda', 'Maqueda', 'Maqueda', 40.0661400, -4.3706600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46061, 'Manzanillo', 'Manzanillo', 'Manzanillo', 41.5861700, -4.1882600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46062, 'Manzanera', 'Manzanera', 'Macanera,Manzanera,Maçanera', 40.0500000, -0.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46063, 'Manzaneda', 'Manzaneda', 'Mazaneda', 42.3096200, -7.2320900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46064, 'Manzanares el Real', 'Manzanares el Real', 'Mansanares-ehl''-Real'',Mansanares-el''-Real'',Manzanares el Real,man sa na lei sai er lei ya er,manzanarys sh ryal,Мансанарес-ель-Реаль,Мансанарес-эль-Реаль,مانزاناريس ش ريال,曼萨纳雷塞尔雷亚尔', 40.7262700, -3.8626500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46065, 'Manzanares de Rioja', 'Manzanares de Rioja', 'Manzanares de Rioja', 42.3961000, -2.8959000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46066, 'Manzanal de los Infantes', 'Manzanal de los Infantes', 'Manzanal de los Infantes', 42.0542800, -6.3828800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46067, 'Manzanal del Barco', 'Manzanal del Barco', 'Manzanal del Barco', 41.6350100, -5.9467100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46068, 'Manzanal de Arriba', 'Manzanal de Arriba', 'Manzanal de Arriba', 41.9921700, -6.4401200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46069, 'Mantinos', 'Mantinos', 'Mantinos', 42.7525900, -4.8421300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46070, 'Mantiel', 'Mantiel', 'Mantiel', 40.6189200, -2.6632400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46071, 'Mansilla Mayor', 'Mansilla Mayor', 'Mansilla Mayor', 42.5094300, -5.4427100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46072, 'Mansilla de las Mulas', 'Mansilla de las Mulas', 'Mansilla de las Mulas,Mansillas de las Mulas', 42.4988600, -5.4173800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46073, 'Manresa', 'Manresa', 'Manresa,Манреса', 41.7281500, 1.8239900, 'ES', '2015-10-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46074, 'Manquillos', 'Manquillos', 'Manquillos', 42.2051800, -4.5684100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46075, 'Mañón', 'Manon', 'Manon,Mañón,Santa Maria,Santa María', 43.6500000, -7.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46076, 'Manlleu', 'Manlleu', 'Manl''eu,Manlleu,man lie wu,manlyw,Манльеу,مانليو,曼列乌', 42.0022800, 2.2847600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46077, 'Manjarrés', 'Manjarres', 'Manjarres,Manjarrés', 42.3915200, -2.6751200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46078, 'Manjabálago', 'Manjabalago', 'Manjabalago,Manjabálago', 40.6644100, -5.0771900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46079, 'Manganeses de la Polvorosa', 'Manganeses de la Polvorosa', 'Manganeses de la Polvorosa', 42.0356300, -5.7469400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46080, 'Manganeses de la Lampreana', 'Manganeses de la Lampreana', 'Manganes de la Lampreana,Manganeses,Manganeses de la Lampreana', 41.7508500, -5.7104800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46081, 'Mañeru', 'Maneru', 'Maneru,Mañeru', 42.6700100, -1.8629700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46082, 'Mandayona', 'Mandayona', 'Mandayona', 40.9561000, -2.7502100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46083, 'Manciles', 'Manciles', '', 42.4572800, -3.9446100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46084, 'Manchones', 'Manchones', 'Manchones', 41.1500000, -1.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46085, 'Mancera de Arriba', 'Mancera de Arriba', 'Mancera de Arriba', 40.7913900, -5.1477200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46086, 'Mancera de Abajo', 'Mancera de Abajo', 'Mancera de Abajo', 40.8397400, -5.1993300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46087, 'Mañaria', 'Manaria', 'Manaria,Mañaria', 43.1381900, -2.6610400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46088, 'Mamolar', 'Mamolar', 'Mamolar', 41.9276200, -3.3622800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46089, 'Mambrillas de Lara', 'Mambrillas de Lara', 'Mambrillas de Lara', 42.0944600, -3.4619500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46090, 'Mambrilla de Castrejón', 'Mambrilla de Castrejon', 'Mambrilla de Castrejon,Mambrilla de Castrejón', 41.6663400, -3.9844800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46091, 'Mamblas', 'Mamblas', 'Mamblas', 41.0192500, -5.0087300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46092, 'Malva', 'Malva', 'Malva', 41.6546700, -5.4865700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46093, 'Maluenda', 'Maluenda', 'Maluenda', 41.2877200, -1.6160300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46094, 'Malpica', 'Malpica', 'Malpica de Bergantinos,Malpica de Bergantiños', 43.3228000, -8.8105200, 'ES', '2007-06-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46095, 'Malpartida de Corneja', 'Malpartida de Corneja', 'Malpartida de Corneja', 40.5220800, -5.3502600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46096, 'Malpartida', 'Malpartida', '', 40.7626900, -5.2314900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46097, 'Malón', 'Malon', 'Malon,Malón', 41.9523500, -1.6719900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46098, 'Mallén', 'Mallen', 'Mallen,Mallén', 41.9006400, -1.4199400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46099, 'Malgrat de Mar', 'Malgrat de Mar', 'Malgrat de Mar', 41.6466200, 2.7413500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46100, 'Maleján', 'Malejan', 'Malejan,Maleján', 41.8276200, -1.5490600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46101, 'Malanquilla', 'Malanquilla', 'Malanquilla', 41.5685600, -1.8748100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46102, 'Malaguilla', 'Malaguilla', 'Malaguilla', 40.8195600, -3.2545000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46103, 'Málaga del Fresno', 'Malaga del Fresno', 'Malaga del Fresno,Málaga del Fresno', 40.7874000, -3.2446500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46104, 'Maján', 'Majan', 'Majan,Maján', 41.4688800, -2.3026800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46105, 'Majaelrayo', 'Majaelrayo', 'Majaelrayo', 41.1126000, -3.3025700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46106, 'Majadahonda', 'Majadahonda', 'Majadahonda,Makhadaonda,Maxadahonda,ma ha da weng da,majadahwnda,Махадаонда,ماجاداهوندا,马哈达翁达', 40.4735300, -3.8718200, 'ES', '2015-06-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46107, 'Maire de Castroponce', 'Maire de Castroponce', 'Maire de Castroponce', 42.1128300, -5.7847500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46108, 'Mainar', 'Mainar', 'Mainar', 41.1927500, -1.3029200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46109, 'Maicas', 'Maicas', 'Maicas', 40.9670800, -0.8904100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46110, 'Mahide', 'Mahide', 'Mahide', 41.8691700, -6.3778400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46111, 'Mahamud', 'Mahamud', 'Mahamud', 42.1198100, -3.9406000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46112, 'Magaz de Cepeda', 'Magaz de Cepeda', 'Magaz de Cepeda', 42.5396700, -6.0717000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46113, 'Magaña', 'Magana', 'Magan''ja,Magana,Maganija,Magaña,ma jia ni ya,Магания,Маганья,马加尼亚', 41.9008900, -2.1626900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46114, 'Magallón', 'Magallon', 'Magallon,Magallón', 41.8324800, -1.4597900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46115, 'Maello', 'Maello', 'Maello', 40.8092900, -4.5118600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46116, 'Maella', 'Maella', 'Maella', 41.1225100, 0.1392600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46117, 'Madroñal', 'Madronal', '', 40.4640700, -6.0627100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46118, 'Madrigalejo del Monte', 'Madrigalejo del Monte', 'Madrigalejo del Monte', 42.1244200, -3.7250900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46119, 'Madrigal del Monte', 'Madrigal del Monte', 'Madrigal del Monte', 42.1446400, -3.6757100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46120, 'Madrigal de la Vera', 'Madrigal de la Vera', 'Madrigal de la Vera', 40.1476000, -5.3681800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46121, 'Madrigal de las Altas Torres', 'Madrigal de las Altas Torres', 'Madrigal,Madrigal de las Altas Torres,Madrigal de las Atlas Tores,Madrigal''-de-las-Al''tas-Torres,ma de li jia er de la sa er ta si tuo lei si,madrayghal dy las altas twrys,madrygal d las altas trs,Мадригал де лас Атлас Торес,Мадригаль-де-лас-Альтас-Торрес,Мадрігаль-де-лас-Альтас-Торрес,مادرايغال دي لاس ألتاس توريس,مادریگال د لاس آلتاس ترس,马德里加尔德拉萨尔塔斯托雷斯', 41.0896800, -4.9986300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46122, 'Madridanos', 'Madridanos', 'Madridanos', 41.4796700, -5.6045900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46123, 'Madrid', 'Madrid', 'Gorad Madryd,La Villa y Corte de Madrid,Los Madriles,Lungsod ng Madrid,MAD,Ma-daik-li,Ma-tet-li,Madrid,Madrid osh,Madridas,Madride,Madridi,Madrido,Madrids,Madril,Madrit,Madrite,Madryt,Madríd,Madrîd,Magerit,Maidrid,Mairil,Makelika,Matritum,Mâ-tet-lî,Mā-dáik-lī,Sanchinarro,ma de li,madarida,madeulideu,madorido,madorido shi,madri,madrid,madrida,madridi,madryd,matrit,mdryd,myadrida,mydrd,Μαδρίτη,Горад Мадрыд,Мaдрид,Мадрид,Мадрид ош,Мадрід,Մադրիդ,מאדריד,מדריד,مادرىد,مادرید,مدريد,میدرد,مەدرید,ܡܕܪܝܕ,मद्रिद,मद्रिद्,माद्रिद,माद्री,म्याड्रिड,মাদ্রিদ,ਮਾਦਰੀਦ,ମାଡ୍ରିଦ,மத்ரித்,ಮಡ್ರಿಡ್,മാഡ്രിഡ്,มาดริด,མ་ད་རིད།,မဒရစ်မြို့,მადრიდი,ማድሪድ,マドリード,マドリード市,馬德里,马德里,마드리드', 40.4165000, -3.7025600, 'ES', '2017-05-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46124, 'Madremanya', 'Madremanya', 'Madremana,Madremanya,Madremaña', 41.9833300, 2.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46125, 'Maderuelo', 'Maderuelo', 'Maderuelo', 41.4864400, -3.5221800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46126, 'Macotera', 'Macotera', 'Macotera,Makotera,ma ke te la,Макотера,马科特拉', 40.8310500, -5.2852600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46127, 'Machacón', 'Machacon', 'Machacon,Machacón', 40.9262300, -5.5243000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46128, 'Maceda', 'Maceda', '', 42.2697200, -7.6505200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46129, 'Luzón', 'Luzon', 'Luzon,Luzón', 41.0269100, -2.2769100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46130, 'Luzmela', 'Luzmela', 'Luzmela,Mazcuerras', 43.2968500, -4.2088400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46131, 'Luzaga', 'Luzaga', 'Luzaga', 40.9733700, -2.4449700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46132, 'Luyego', 'Luyego', 'Luyego', 42.3666700, -6.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46133, 'Lupiana', 'Lupiana', 'Lupiana', 40.6084600, -3.0511800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46134, 'Luna', 'Luna', 'Luna', 42.1676000, -0.9329200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46135, 'Lumpiaque', 'Lumpiaque', 'Lumpiaque', 41.6295300, -1.3015600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46136, 'Lumbreras', 'Lumbreras', 'Lumbreras,lun fu lei la si,Лумбрерас,Լումբրերաս,伦夫雷拉斯', 42.1047700, -2.6218900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46137, 'Lumbrales', 'Lumbrales', 'Llimiares,Lumbrales,lun fu la lai si,Лумбралес,伦夫拉莱斯', 40.9350100, -6.7194800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46138, 'Lumbier', 'Lumbier', 'Ilunberri,Lumbier', 42.6530300, -1.3066900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46139, 'Lugones', 'Lugones', 'Llugones,Lugones', 43.4027200, -5.8121500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46140, 'Lugo', 'Lugo', 'LUY,Lugo,lwghw,rugo,Луго,لوغو,ルーゴ', 43.0099200, -7.5560200, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46141, 'Luesma', 'Luesma', 'Luesma', 41.1658300, -1.1457500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46142, 'Luesia', 'Luesia', 'Luesia', 42.3697400, -1.0242100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46143, 'Luelmo', 'Luelmo', 'Luelmo', 41.4403000, -6.1333800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46144, 'Ludiente', 'Ludiente', 'Lludient,Ludiente', 40.0833300, -0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46145, 'Luceni', 'Luceni', 'Luceni', 41.8285700, -1.2388900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46146, 'Lucena del Cid', 'Lucena del Cid', 'Llucena,Lucena del Cid', 40.1333300, -0.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46147, 'Lucena de Jalón', 'Lucena de Jalon', 'Lucena de Jalon,Lucena de Jalón', 41.5530100, -1.3130500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46148, 'Lubián', 'Lubian', 'Lubian,Lubián', 42.0356900, -6.9054100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46149, 'Luanco', 'Luanco', 'Gozon,Lluancu,Luanco,Luanzo,Santa Maria de Luanco,Santa María de Luanco', 43.6151700, -5.7934400, 'ES', '2008-07-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46150, 'Lozoya', 'Lozoya', 'Lozoya', 40.9494900, -3.7908600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46151, 'Lobios', 'Lobios', 'San Miguel', 41.8749300, -8.0878300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46152, 'Lousame', 'Lousame', 'Lousame,Lusam,luo sa mei,lwzamy,rousame,Лоусаме,Лусам,لوزامي,ロウサーメ,洛萨梅', 42.7729900, -8.8444000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46153, 'Los Santos de la Humosa', 'Los Santos de la Humosa', 'Los Santos de la Humosa', 40.4996800, -3.2533200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46154, 'Los Molinos', 'Los Molinos', 'Los Molinos', 40.7157800, -4.0740200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46155, 'Loscos', 'Loscos', 'Loscos', 41.0810800, -1.0443300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46156, 'Los Corrales de Buelna', 'Los Corrales de Buelna', 'Corrales,Los Corrales,Los Corrales de Buelna,Los-Korrales-de-Buehl''na,Los-Korrales-de-Buel''na,luo si ke la lai si de wu ai er na,lws kwrals dy bwylna,Лос-Корралес-де-Буельна,Лос-Корралес-де-Буэльна,لوس كورالس دي بويلنا,洛斯科拉莱斯德武埃尔纳', 43.2635800, -4.0726200, 'ES', '2013-10-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46157, 'Loscorrales', 'Loscorrales', 'Loscorrales', 42.2545100, -0.6429600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46158, 'Losar de la Vera', 'Losar de la Vera', 'Losar de la Vera,Losar-de-la-Vera,luo sa er de la wei la,lwsar dy lafyra,Лосар-де-ла-Вера,لوسار دي لافيرا,洛萨尔德拉韦拉', 40.1215800, -5.6045400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46159, 'Los Arcos', 'Los Arcos', 'Los Arcos', 42.5707600, -2.1927500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46160, 'Losacio', 'Losacio', 'Losacio', 41.7109200, -6.0405900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46161, 'Losacino', 'Losacino', 'Losacino', 41.6808400, -6.0798600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46162, 'Loranca de Tajuña', 'Loranca de Tajuna', 'Loranca de Tajuna,Loranca de Tajuña', 40.4436800, -3.1108200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46163, 'Loporzano', 'Loporzano', '', 42.1613700, -0.3233700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46164, 'Longás', 'Longas', 'Longas,Longás', 42.4809200, -0.9342000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46165, 'Longares', 'Longares', 'Longares', 41.4030800, -1.1687600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46166, 'Lominchar', 'Lominchar', 'Lominchar', 40.0906100, -3.9671300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46167, 'Lomas', 'Lomas', 'Lomas,Lomas de Campos,lmas,luo ma si,Ломас,لماس,洛马斯', 42.2736200, -4.5509500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46168, 'Logroño', 'Logrono', 'Gorad Lagron''ja,Logron''jo,Logron''o,Logronh,Logronio,Logronjas,Logronjo,Logrono,Logronu,Logronyo,Logroño,Logroñu,Lucronium,RJL,lgrnyw,lo koryo,logeulonyo,logron''yo,logronyo,luo ge luo ni ao,lwghrwnyw,lwgrwnw,lwgrwnyw,roguronyo,Λογρόνιο,Горад Лагронья,Логроньйо,Логроньо,Логроњо,Լոգրոնյո,לוגרוניו,لوغرونيو,لوگرونو,لگرنیو,लोग्रोंयो,लोग्रोन्यो,โลโกรโญ,ログローニョ,洛格罗尼奥,로그로뇨', 42.4666700, -2.4500000, 'ES', '2015-04-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46169, 'Loeches', 'Loeches', 'Loeches', 40.3834300, -3.4146000, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46170, 'Lodosa', 'Lodosa', 'Lodosa', 42.4226900, -2.0774100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46171, 'Lobios', 'Lobios', '', 42.4074600, -7.5316400, 'ES', '2007-02-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46172, 'Lobera de Onsella', 'Lobera de Onsella', 'Lobera,Lobera de Onsella', 42.4784800, -1.0220800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46173, 'Loarre', 'Loarre', 'Loarre,Lobarre', 42.3143200, -0.6258800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46174, 'Lloret de Mar', 'Lloret de Mar', 'L''oret-de-Mar,Ljoret de Mar,Lloret de Mar,Љорет де Мар,Льорет-де-Мар', 41.6999300, 2.8456500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46175, 'Laudio / Llodio', 'Llodio', 'Laudio,Laudio-Llodio,Llodio,Plaza,Plaza de Gogenuri', 43.1432200, -2.9620400, 'ES', '2012-12-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46176, 'Llívia', 'Llivia', 'Llivia,Llívia', 42.4646200, 1.9807000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46177, 'Lliçà de Vall', 'Llica de Vall', 'Llica de Vall,Lliçà de Vall', 41.5905400, 2.2412100, 'ES', '2011-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46178, 'Lliçà d''Amunt', 'Llica d''Amunt', 'Llica d''Amunt,Llissa de Munt,Llissá de Munt,Lliçà d''Amunt', 41.6166700, 2.2333300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46179, 'Llinars del Vallès', 'Llinars del Valles', 'Llinars,Llinars del Valles,Llinars del Vallès,Llinas,Llinás', 41.6333300, 2.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46180, 'Llimiana', 'Llimiana', 'Llimiana', 42.0747600, 0.9162100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46181, 'Lles de Cerdanya', 'Lles de Cerdanya', 'Lles,Lles de Cerdanya,Llés', 42.3902500, 1.6869200, 'ES', '2017-01-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46182, 'Llers', 'Llers', 'Llers', 42.2957100, 2.9118300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46183, 'Lledó', 'Lledo', 'Lledo,Lledó', 40.9549800, 0.2774900, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46184, 'Llançà', 'Llanca', 'L''janssa,Llanca,Llançà,Льянсса', 42.3624100, 3.1521300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46185, 'Llano de Olmedo', 'Llano de Olmedo', 'Llano de Olmedo', 41.2672700, -4.6138600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46186, 'Llano de Bureba', 'Llano de Bureba', 'Llano de Bureba,Solas de Bureba', 42.6243500, -3.4589000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46187, 'Llanes', 'Llanes', 'L''janes,Llanes,li ya nei si,ryanesu,yans,yanys,Льянес,يانيس,یانس,リャネス,利亚内斯', 43.4198200, -4.7548500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46188, 'Llanera', 'Llanera', 'Llanera,Santa Cruz', 43.4618900, -5.9311000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46189, 'Llanera', 'Llanera', 'Llanera,San Cucufate', 43.4333300, -5.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46190, 'Llambilles', 'Llambilles', 'Llambillas,Llambilles', 41.9210600, 2.8507800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46191, 'Llamas de la Ribera', 'Llamas de la Ribera', 'Llamas,Llamas de la Ribera', 42.6350400, -5.8252400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46192, 'Llagostera', 'Llagostera', 'Llagostera', 41.8268800, 2.8936500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46193, 'Lladó', 'Llado', 'Llado,Lladó,Lledo,Lledó', 42.2476900, 2.8137300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46194, 'Lizoáin', 'Lizoain', '', 42.7986800, -1.4675300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46195, 'Lizartza', 'Lizarza', 'Lizartza,Lizarza', 43.1023600, -2.0348900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46196, 'Lituénigo', 'Lituenigo', 'Lituenigo,Lituénigo', 41.8353300, -1.7619600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46197, 'Litago', 'Litago', 'Litago', 41.8140700, -1.7527600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46198, 'Linyola', 'Linyola', 'Linola,Linyola,Liñola', 41.7000000, 0.9166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46199, 'Linares de Riofrío', 'Linares de Riofrio', 'Linares,Linares de Riofrio,Linares de Riofrío', 40.5833800, -5.9209100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46200, 'Linares de Mora', 'Linares de Mora', 'Linares,Linares de Mora,Llinars', 40.3215900, -0.5746800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46201, 'Limpias', 'Limpias', 'Limpias,Rucoba', 43.3640200, -3.4177800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46202, 'Liédena', 'Liedena', '', 42.6194300, -1.2757900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46203, 'Lidón', 'Lidon', 'Lidon,Lidón', 40.7172500, -1.1125000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46204, 'Liceras', 'Liceras', 'Liceras', 41.3793900, -3.2437100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46205, 'Libros', 'Libros', 'Libros', 40.1631100, -1.2336100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46206, 'Lezo', 'Lezo', 'Lezo', 43.3214200, -1.8973900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46207, 'Lezáun', 'Lezaun', '', 42.7773900, -1.9938500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46208, 'Lezama', 'Lezama', 'Lexama', 43.0279900, -2.9725700, 'ES', '2006-08-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46209, 'Leza de Río Leza', 'Leza de Rio Leza', 'Leza de Rio Leza,Leza de Río Leza', 42.3295200, -2.4060600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46210, 'Leza', 'Leza', 'Leza', 42.5655200, -2.6332400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46211, 'Letux', 'Letux', 'Letux', 41.2551200, -0.8026900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46212, 'Lesaka', 'Lesaka', 'Lesaca,Lesaka', 43.2500000, -1.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46213, 'Les', 'Les', 'Les', 42.8107600, 0.7105000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46214, 'Lerma', 'Lerma', 'Lerma,Lermo,lyrma,Лерма,ليرما', 42.0260900, -3.7597800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46215, 'Lerín', 'Lerin', 'Lerin,Lerín', 42.4831800, -1.9718400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46216, 'Lleida', 'Lleida', 'ILD,Ilerda,Ilerdo,Lerida,Lheida,Lhèida,Ljeida,Lleida,Lérida,lyydh,rerida,ryeida,Љеида,Лерида,ליידה,リェイダ,レリダ', 41.6167400, 0.6221800, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46217, 'Lerga', 'Lerga', 'Lerga', 42.5678100, -1.5011000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46218, 'Lekeitio', 'Lekeitio', 'Lekeitio,Lequeitio', 43.3641700, -2.5049200, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46219, 'León', 'Leon', 'Ciuda de Llion,Ciudá de Llión,LEN,Leon,Leono,León,Lleo,Lleon,Lleó,Lleón,lywn,reon,Леон,ليون,レオン', 42.6000300, -5.5703200, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46220, 'Leioa', 'Leioa', 'Leioa,Lejoa,Lejona,Lekhona,lai ao a,layaywa,reioa,Лейоа,Лехона,لايايوا,レイオア,莱奥阿', 43.3268600, -2.9888400, 'ES', '2015-06-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46221, 'Leitza', 'Leitza', 'Leitza,Leiza', 43.0833300, -1.9166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46222, 'Leiva', 'Leiva', 'Leiva', 42.5028100, -3.0470100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46223, 'Legorreta', 'Legorreta', 'Legorreta', 43.0846400, -2.1501700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46224, 'Legazpi', 'Legazpia', 'Legazpi,Legazpia', 43.0531900, -2.3368900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46225, 'Legaria', 'Legaria', '', 42.6492400, -2.1739200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46226, 'Legarda', 'Legarda', '', 42.7118300, -1.7684600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46227, 'Leganiel', 'Leganiel', 'Leganiel', 40.1656800, -2.9496600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46228, 'Leganés', 'Leganes', 'Gorad Leganes,Legamar,Leganes,Leganesas,Leganés,lai jia nei si,leganeseu,lyjanys,reganesu,Горад Леганес,Леганес,ليجانيس,レガネス,萊加內斯,레가네스', 40.3271800, -3.7635000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46229, 'Ledrada', 'Ledrada', 'Ledrada', 40.4687800, -5.7203800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46230, 'Ledigos', 'Ledigos', '', 42.3548000, -4.8648000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46231, 'Ledesma de la Cogolla', 'Ledesma de la Cogolla', 'Ledesma de la Cogolla', 42.3203200, -2.7190000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46232, 'Ledesma', 'Ledesma', 'Ledesma', 41.0882900, -6.0017800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46233, 'Ledanca', 'Ledanca', 'Ledanca', 40.8688100, -2.8434000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46234, 'Lekunberri', 'Lekunberri', 'Lecumberri,Lekunberri', 43.0005000, -1.8925700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46235, 'Leciñena', 'Lecinena', 'Lecinena,Leciñena', 41.7986800, -0.6117400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46236, 'Lechón', 'Lechon', 'Lechon,Lechón', 41.0863300, -1.2848300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46237, 'Lécera', 'Lecera', 'Lecera,Lécera', 41.2049100, -0.7113300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46238, 'Leache', 'Leache', '', 42.6071800, -1.4072800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46239, 'Leaburu', 'Leaburu', 'Leaburu,Leaburu-Txarama', 43.1218800, -2.0543000, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46240, 'Lazkao', 'Lazcano', 'Lazcano,Lazkao', 43.0323900, -2.1861600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46241, 'Lazagurría', 'Lazagurria', 'Lazagurria,Lazagurría', 42.4928600, -2.2401800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46242, 'Laza', 'Laza', 'Laza', 42.0613600, -7.4620000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46243, 'Layana', 'Layana', 'Layana', 42.2954600, -1.2448300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46244, 'La Torre de Esteban Hambrán', 'La Torre de Esteban Hambran', 'La Torre de Esteban Hambran,La Torre de Esteban Hambrán', 40.1693500, -4.2154900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46245, 'la Tallada d''Empordà', 'la Tallada d''Emporda', 'La Tallada,la Tallada,la Tallada d''Emporda,la Tallada d''Empordà', 42.0802000, 3.0558300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46246, 'Las Ventas de Retamosa', 'Las Ventas de Retamosa', 'Ventas de Retamosa', 40.1552600, -4.1145500, 'ES', '2008-10-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46247, 'Lastras del Pozo', 'Lastras del Pozo', 'Lastras del Pozo', 40.8792000, -4.3465800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46248, 'Lastras de Cuéllar', 'Lastras de Cuellar', 'Lastras de Cuellar,Lastras de Cuéllar', 41.2976200, -4.1067000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46249, 'Las Rozas de Madrid', 'Las Rozas de Madrid', 'Las Rozas,Las Rozas de Madrid,Las-Rosas-de-Madrid,Rozae Matritenses,Rozas de Madrid,la si luo sa si de ma de li de,las rwzas dy mdryd,Лас-Росас-де-Мадрид,Розас де Мадрид,لاس روزاس دي مدريد,拉斯罗萨斯德马德里德', 40.4929200, -3.8737100, 'ES', '2014-03-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46250, 'Laspuña', 'Laspuna', 'L''Espuna,Laspuna', 42.5037400, 0.1544100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46251, 'les Planes d''Hostoles', 'les Planes d''Hostoles', 'les Planes d''Hostoles', 42.0566900, 2.5409300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46252, 'Laspaúles', 'Laspaules', 'Laspaules,Laspaúles', 42.4713600, 0.5969800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46253, 'Las Navas del Marqués', 'Las Navas del Marques', 'Las Navas,Las Navas del Markez,Las Navas del Marques,Las Navas del Marqués,Las-Navas-del''-Markes,Navas del Marques,la si na wa si de er ma er ke si,las nabas dl marks,las nafas dyl markys,Лас Навас дел Маркез,Лас-Навас-дель-Маркес,لاس ناباس دل مارکس,لاس نافاس ديل ماركيس,拉斯纳瓦斯德尔马尔克斯', 40.6024400, -4.3344900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46254, 'Las Matas', 'Las Matas', 'Barrio Obrero Las Matas,La Mata,Las Matas', 40.5577900, -3.8917300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46255, 'les Llosses', 'les Llosses', 'Las Llosas,las Llosas,les Llosses', 42.1500000, 2.1166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46256, 'La Selva del Camp', 'La Selva del Camp', 'La Selva,La Selva del Camp,La Selva del Campo,Selva', 41.2148400, 1.1388300, 'ES', '2015-05-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46257, 'la Cellera de Ter', 'la Cellera de Ter', 'la Cellera,la Cellera de Ter', 41.9691900, 2.6240200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46258, 'La Secuita', 'La Secuita', 'La Secuita', 41.2046000, 1.2799600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46259, 'La Seca', 'La Seca', 'La Seca', 41.4136400, -4.9055200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46260, 'Lascuarre', 'Lascuarre', 'Lascuarra,Lascuarre,Lasquarri,Llascuarri', 42.1961100, 0.5201000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46261, 'Les Cases d''Alcanar', 'Les Cases d''Alcanar', 'Casas de Alcanar,Cases d''Alcanar', 40.5535900, 0.5302200, 'ES', '2016-10-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46262, 'Lasarte', 'Lasarte', 'Lasarte,Lasarte-Oria', 43.2677400, -2.0216900, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46263, 'La Sagrera', 'La Sagrera', 'Barrio La Sagrera', 41.4227100, 2.1858900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46264, 'A Rúa', 'A Rua', 'A Rua,A Rúa', 42.4004800, -7.1026800, 'ES', '2014-05-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46265, 'Larrodrigo', 'Larrodrigo', 'Larrodrigo', 40.7372200, -5.4489500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46266, 'Larraul', 'Larraul', 'Larraul', 43.1877300, -2.1020200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46267, 'Larraona', 'Larraona', 'Larraona', 42.7797000, -2.2568200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46268, 'Larraga', 'Larraga', 'Larraga', 42.5584100, -1.8495400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46269, 'La Roca del Vallès', 'La Roca del Valles', 'La Roca del Valles,La Roca del Vallès', 41.5833300, 2.3333300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46270, 'La Robla', 'La Robla', 'La Robla,La-Robla,la luo fu la,Ла-Робла,拉罗夫拉', 42.8030200, -5.6290400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46271, 'Sant Pere, Santa Caterina i La Ribera', 'Sant Pere, Santa Caterina i La Ribera', 'Barrio la Ribera,Born,borne,el Born,la Ribera', 41.3845000, 2.1815200, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46272, 'Laredo', 'Laredo', 'Laredo', 43.4098000, -3.4161300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46273, 'Lardero', 'Lardero', 'Lardero,la er de luo,Лардеро,Լարդերո,لارڈیرو,拉尔德罗', 42.4268600, -2.4615300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46274, 'Laracha', 'Laracha', 'A Laracha,Laracha', 43.2537500, -8.5853500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46275, 'Lapuebla de Labarca', 'Lapuebla de Labarca', '', 42.4945500, -2.5734100, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46276, 'La Pola de Gordón', 'La Pola de Gordon', 'La Pola de Gordon,La Pola de Gordón,La-Pola-de-Gordon,la bo la de ge er dong,Ла-Пола-де-Гордон,拉波拉德戈尔东', 42.8565800, -5.6676800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46277, 'la Pobla de Mafumet', 'la Pobla de Mafumet', 'La Pobla de Mafumet,Pobla de Mafumet,la Pobla de Mafumet', 41.1833300, 1.2166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46278, 'La Pobla de Claramunt', 'La Pobla de Claramunt', 'Claramunt,La Pobla de Claramunt,Pobla de Claramunt', 41.5542300, 1.6771200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46279, 'Lapoblación', 'Lapoblacion', 'La Poblacion,La Población,Lapoblas''jon,Lapoblas''on,la bo fu la xi weng,Лапобласьйон,Лапобласьон,拉波夫拉西翁', 42.6047800, -2.4600800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46280, 'La Plaza', 'La Plaza', 'La Plaza,Teberga,Teverga', 43.1639700, -6.0994300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46281, 'La Pineda', 'La Pineda', 'La Pineda,Ла Пинеда', 41.0762500, 1.1851500, 'ES', '2016-12-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46282, 'La Pesga', 'La Pesga', '', 40.3263000, -6.1760300, 'ES', '2012-10-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46283, 'Laperdiguera', 'Laperdiguera', 'Laperdiguera', 41.9905300, -0.0465700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46284, 'La Pedraja de Portillo', 'La Pedraja de Portillo', 'La Pedraja de Portillo', 41.4712400, -4.6463900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46285, 'Lanzuela', 'Lanzuela', 'Lanzuela', 41.0985000, -1.2061600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46286, 'Lantz', 'Lantz', 'Lantz,Lanz', 43.0000000, -1.6166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46287, 'Lantadilla', 'Lantadilla', '', 42.3407800, -4.2786600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46288, 'Languilla', 'Languilla', 'Languilla', 41.4492600, -3.4243800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46289, 'Langayo', 'Langayo', 'Langayo', 41.5698600, -4.1986600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46290, 'Langa del Castillo', 'Langa del Castillo', 'Langa,Langa del Castillo', 41.2120000, -1.3985000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46291, 'Langa de Duero', 'Langa de Duero', 'Langa,Langa de Duero,Langa-de-Duehro,Langa-de-Duero,Larga de Duero,lan jia de du ai luo,Ланга-де-Дуеро,Ланга-де-Дуэро,兰加德杜埃罗', 41.6098500, -3.4006100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46292, 'Langa', 'Langa', 'Langa', 41.0055000, -4.8594600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46293, 'Lanestosa', 'Lanestosa', 'Lanestosa', 43.2198600, -3.4392000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46294, 'Láncara', 'Lancara', '', 42.8642500, -7.3366700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46295, 'Lanaja', 'Lanaja', 'Lanaja', 41.7706300, -0.3309500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46296, 'la Morera de Montsant', 'la Morera de Montsant', 'la Morera,la Morera de Montsant', 41.2652900, 0.8415700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46297, 'Lama', 'Lama', 'Lama,San Salvador', 42.4000000, -8.4333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46298, 'Lalueza', 'Lalueza', 'Lalueza', 41.8396700, -0.2549300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46299, 'Laluenga', 'Laluenga', 'Laluenga', 42.0070300, -0.0471500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46300, 'La Llagosta', 'La Llagosta', 'La Llagosta', 41.5143500, 2.1929700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46301, 'Lalín', 'Lalin', 'Lalin,Lalín,Лалин', 42.6608500, -8.1128500, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46302, 'La Lastrilla', 'La Lastrilla', 'La Lastrilla', 40.9681700, -4.1046800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46303, 'la Jonquera', 'la Jonquera', 'la Jonquera', 42.4172800, 2.8736300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46304, 'La Iglesuela del Cid', 'La Iglesuela del Cid', 'Iglesuela del Cid,La Iglesuela', 40.4831200, -0.3193800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46305, 'Polanco', 'Polanco', '', 43.3852400, -4.0164200, 'ES', '2015-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46306, 'Lagunilla del Jubera', 'Lagunilla del Jubera', 'Lagunilla del Jubera', 42.3341400, -2.3211700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46307, 'Lagunilla', 'Lagunilla', 'Lagunilla', 40.3249100, -5.9713200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46308, 'Lagunaseca', 'Lagunaseca', 'Lagunaseca', 40.5310000, -2.0195600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46309, 'Laguna de Negrillos', 'Laguna de Negrillos', 'Laguna de Negrillos,Laguna-de-Negril''jos,Laguna-de-Negril''os,la gu na de nei ge li e si,Лагуна-де-Негрильос,Лагуна-де-Негрільйос,拉古纳德内格里略斯', 42.2388900, -5.6606600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46310, 'Laguna del Marquesado', 'Laguna del Marquesado', 'La Laguna del Marquesado,Laguna del Marquesado', 40.1774900, -1.6716700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46311, 'Laguna de Duero', 'Laguna de Duero', 'Laguna de Duero,Laguna-de-Duehro,Лагуна-де-Дуэро', 41.5815100, -4.7233200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46312, 'Laguna de Contreras', 'Laguna de Contreras', 'Laguna de Contreras', 41.4951300, -4.0287400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46313, 'Laguna de Cameros', 'Laguna de Cameros', 'Laguna de Cameros', 42.1745500, -2.5428200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46314, 'Laguna Dalga', 'Laguna Dalga', 'Laguna Dalga', 42.3319200, -5.7522000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46315, 'Lagueruela', 'Lagueruela', 'Lagueruela', 41.0425000, -1.1928300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46316, 'Laguardia', 'Laguardia', 'Biasteri,Guardia,La Gardia,Laguardia,Laguardija,Lagvardija,la gua er di ya,laghwardya,lagwardya,Ла Гардиа,Лагвардија,Лагуардія,لاغوارديا,لاگواردیا,拉瓜尔迪亚', 42.5546100, -2.5852800, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46317, 'A Guarda', 'A Guarda', 'A Guarda,La Guardia', 41.9013100, -8.8742300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46318, 'La Granada', 'La Granada', 'La Granada', 41.3781600, 1.7190200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46319, 'Lagrán', 'Lagran', 'Lagran,Lagrán', 42.6262500, -2.5838500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46320, 'La Ginebrosa', 'La Ginebrosa', 'La Ginebrosa,la Ginebrosa', 40.8699100, -0.1352500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46321, 'Laxe', 'Laxe', '', 43.2201900, -9.0063000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46322, 'Lagata', 'Lagata', 'Lagata', 41.2397000, -0.8048700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46323, 'Lagartos', 'Lagartos', '', 42.4057800, -4.9045400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46324, 'la Garriga', 'la Garriga', 'la Garriga', 41.6833300, 2.2833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46325, 'La Fuliola', 'La Fuliola', 'Fuliola,La Fuliola,la Fuliola', 41.7135800, 1.0174600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46326, 'La Fuente de San Esteban', 'La Fuente de San Esteban', 'Fuente San Esteban,Fuentes de San Esteban,La Fuente de San Esteban', 40.8016100, -6.2585200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46327, 'La Frontera', 'La Frontera', 'La Frontera', 40.4016100, -2.2169900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46328, 'A Estrada', 'A Estrada', 'La Estrada', 42.6891100, -8.4884200, 'ES', '2015-06-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46329, 'l''Escala', 'l''Escala', 'l''Escala', 42.1256200, 3.1326100, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46330, 'Ladrillar', 'Ladrillar', 'El Ladrillar', 40.4657600, -6.2242700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46331, 'Lakuntza', 'Lakuntza', 'Lacunza,Lakuntza', 42.9224900, -2.0233700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46332, 'La Cuesta', 'La Cuesta', 'Cuesta,La Cuesta,La Kosta,Ла Коста', 41.0828000, -3.9601700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46333, 'A Coruña', 'A Coruna', 'A Coruna,A Coruña,A Cruna,A Cruña,A Koruna,A-Korun''ja,Akoruna,Akoruņa,Caronium,Coruna,Corunako,Corunha,Corunya,Coruña,Coruñako,Corùna,In Coruna,In Coruña,Koruna,Korunjo,LCG,La Corogne,La Coronha,La Coruna,La Coruña,La Koruna,La Korunja,La Korunya,La-Karun''ja,La-Korun''ja,La-Korunya,The Groyne,la ke lu ni ya,la kwrwnya,lakolunya,lakrwnya,xa ko ruya,А Коруња,А-Корунья,Коруња,Ла Коруня,Ла-Карунья,Ла-Корунья,Լա Կորունա,א קורוניה,اے کرونا,لا كورونيا,لا کۆرونیا,لاکرونیا,อาโกรูญา,ლა-კორუნია,ア・コルーニャ,拉科魯尼亞,라코루냐', 43.3713500, -8.3960000, 'ES', '2015-04-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46334, 'La Carrera', 'La Carrera', 'La Carrera', 40.3477700, -5.5547400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46335, 'La Cabrera', 'La Cabrera', 'La Cabrera', 40.8638600, -3.6126500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46336, 'Labuerda', 'Labuerda', '', 42.4523400, 0.1356100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46337, 'La Bouza', 'La Bouza', '', 40.8362600, -6.7955100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46338, 'la Bisbal d''Empordà', 'la Bisbal d''Emporda', 'La Bisbal,La Bisbal d''Emporda,La Bisbal d''Empordà,La Bisbal del Ampurdan,La Bisbal del Ampurdán,la  Bisbal,la Bisbal,la Bisbal d''Emporda,la Bisbal d''Empordà', 41.9500000, 3.0500000, 'ES', '2012-11-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46339, 'Bastida / Labastida', 'Labastida', 'Bastida,Labastida', 42.5897400, -2.7956800, 'ES', '2012-11-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46340, 'La Bañeza', 'La Baneza', 'La Baneza,La Bañeza,La-Ban''esa,la wa nie sa,Ла-Баньеса,Ла-Баньєса,拉瓦涅萨', 42.3002600, -5.8977200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46341, 'Labajos', 'Labajos', 'Labajos,Labajoz', 40.8433500, -4.5200500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46342, 'L''Ampolla', 'L''Ampolla', 'Ampolla', 40.8123500, 0.7100800, 'ES', '2011-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46343, 'l''Ametlla de Mar', 'l''Ametlla de Mar', 'Ametlla de Mar,l''Ametlla,l''Ametlla de Mar', 40.9000000, 0.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46344, 'L''Ametlla del Vallès', 'L''Ametlla del Valles', 'L''Ametlla,L''Ametlla del Valles,L''Ametlla del Vallès', 41.6666700, 2.2666700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46345, 'La Almunia de Doña Godina', 'La Almunia de Dona Godina', 'Almunia de Dona Godina,Almunia de Doña Godina,La Almunia,La Almunia de Dona Godina,La Almunia de Doña Godina', 41.4767000, -1.3745100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46346, 'La Alberca', 'La Alberca', 'Alberca,La Alberca,Las Alberca', 40.4890800, -6.1110700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46347, 'La Alameda de la Sagra', 'La Alameda de la Sagra', 'Alameda de la Sagra,La Alameda de la Sagra', 40.0119900, -3.7925500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46348, 'La Adrada', 'La Adrada', 'La Adrada,La-Adrada,la adrada,la de la da,Ла Адрада,Ла-Адрада,لا آدرادا,لا أدرادا,拉德拉达', 40.2995300, -4.6358900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46349, 'Juzbado', 'Juzbado', 'Juzbado', 41.0779100, -5.8614000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46350, 'Juià', 'Juia', 'Juia,Juià,Juya,Juyá', 42.0166700, 2.9166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46351, 'Justel', 'Justel', '', 42.1486100, -6.2959400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46352, 'Juneda', 'Juneda', 'Juneda', 41.5484700, 0.8245100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46353, 'Juncosa', 'Juncosa', 'Juncosa', 41.3703300, 0.7765000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46354, 'Junciana', 'Junciana', 'Junciana', 40.4107600, -5.5569800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46355, 'Juarros de Voltoya', 'Juarros de Voltoya', 'Juarros de Voltoya', 41.0309700, -4.5192200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46356, 'Xove', 'Xove', '', 43.6865600, -7.5113000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46357, 'Josa', 'Josa', 'Josa', 40.9555000, -0.7668300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46358, 'Jorcas', 'Jorcas', 'Jorcas', 40.5427500, -0.7530800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46359, 'Jorba', 'Jorba', 'Jorba', 41.6019300, 1.5475000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46360, 'Joarilla de las Matas', 'Joarilla de las Matas', 'Joarilla de las Matas', 42.2875500, -5.1785500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46361, 'Jirueque', 'Jirueque', 'Jirueque', 40.9643100, -2.9028900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46362, 'Jerte', 'Jerte', 'Jerte', 40.2227100, -5.7501100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46363, 'Javier', 'Javier', '', 42.5911900, -1.2088400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46364, 'Jaulín', 'Jaulin', 'Jaulin,Jaulín', 41.4519800, -0.9925600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46365, 'Jatiel', 'Jatiel', 'Jatiel', 41.2200800, -0.3818300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46366, 'Jasa', 'Jasa', 'Chasa,Jasa', 42.6948000, -0.6660500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46367, 'Jarque de la Val', 'Jarque de la Val', 'Jarque de la Val', 40.7028300, -0.8008300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46368, 'Jarque', 'Jarque', 'Jarque', 41.5561300, -1.6756300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46369, 'Jarilla', 'Jarilla', 'Jarilla', 40.1715600, -6.0028100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46370, 'Jarandilla de la Vera', 'Jarandilla de la Vera', 'Jarandilla', 40.1291500, -5.6607900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46371, 'Jaramillo Quemado', 'Jaramillo Quemado', 'Jaramillo,Jaramillo Quemado', 42.0856800, -3.3586800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46372, 'Jaramillo de la Fuente', 'Jaramillo de la Fuente', 'Jaramillo de la Fuente', 42.1147200, -3.3123900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46373, 'Jaraíz de la Vera', 'Jaraiz de la Vera', 'Jaraiz,Jaraiz de la Vera,Jaraíz de la Vera', 40.0600500, -5.7542600, 'ES', '2015-03-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46374, 'Jaraba', 'Jaraba', 'Jaraba', 41.1908300, -1.8844000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46375, 'Jambrina', 'Jambrina', 'Jambrina', 41.3919600, -5.6641100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46376, 'Jalón de Cameros', 'Jalon de Cameros', 'Jalon de Cameros,Jalón de Cameros', 42.2180400, -2.4900400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46377, 'Jafre', 'Jafre', '', 42.0725400, 3.0106200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46378, 'Jadraque', 'Jadraque', 'Jadraque', 40.9245400, -2.9246800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46379, 'Jaca', 'Jaca', 'Chaca,Hako,Jaca,Jaka,Khaka,ha ka,haka,Ĥako,Хака,ハカ,哈卡,하카', 42.5689800, -0.5498700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46380, 'Jabaloyas', 'Jabaloyas', 'Jabaloyas', 40.2401000, -1.4088600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46381, 'Izurtza', 'Izurtza', 'Izurtza,Izurza,Izurza Eleizalde', 43.1500000, -2.6333300, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46382, 'Izagre', 'Izagre', 'Izagre', 42.2241000, -5.2572700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46383, 'Iturmendi', 'Iturmendi', '', 42.8899300, -2.1191600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46384, 'Ituren', 'Ituren', 'Ituren', 43.1323800, -1.7206300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46385, 'Ituero y Lama', 'Ituero y Lama', 'Ituero,Ituero y Lama', 40.8006600, -4.3791700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46386, 'Ituero de Azaba', 'Ituero de Azaba', 'Ituero de Azaba', 40.4848700, -6.6927200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46387, 'Itero del Castillo', 'Itero del Castillo', '', 42.2898800, -4.2444100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46388, 'Itero de la Vega', 'Itero de la Vega', '', 42.2880400, -4.2567700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46389, 'Isuerre', 'Isuerre', '', 42.4872900, -1.0540000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46390, 'Isòvol', 'Isovol', 'Isobol,Isovol,Isòvol,Isóbol', 42.3776300, 1.8180700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46391, 'Iscar', 'Iscar', 'Iscar', 41.3611700, -4.5334800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46392, 'Itsasondo', 'Isasondo', 'Isasondo,Itsasondo', 43.0690900, -2.1646400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46393, 'Isar', 'Isar', '', 42.3614000, -3.9304000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46394, 'Irurtzun', 'Irurtzun', 'Irurtzun,Irurzun', 42.9166700, -1.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46395, 'Irura', 'Irura', 'Irura', 43.1665100, -2.0674600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46396, 'Irun', 'Irun', 'Irun,Irun-Uranzu,Irún,Irún-Uranzu,yi lun,Ирун,伊倫', 43.3390400, -1.7893800, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46397, 'Irueste', 'Irueste', 'Irueste', 40.6120600, -2.8907200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46398, 'Iruelos', 'Iruelos', 'Iruelos', 41.1413500, -6.3280800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46399, 'Irixoa', 'Irixoa', 'San Lorenzo', 43.2847000, -8.0591600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46400, 'Irañeta', 'Iraneta', '', 42.9228700, -1.9459500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46401, 'Iniéstola', 'Iniestola', 'Iniestola,Iniéstola', 40.9940000, -2.3706300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46402, 'Incio', 'Incio', 'Incio,San Pedro', 42.6333300, -7.3500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46403, 'Illueca', 'Illueca', 'Illueca', 41.5381800, -1.6274700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46404, 'Illescas', 'Illescas', 'Il''eskas,Illescas,Ilyeskas,ayyskas,yi lie si ka si,Ільєскас,Ильескас,Իլյեսկաս,اییسکاس,伊列斯卡斯', 40.1221300, -3.8470400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46405, 'Illas', 'Illas', 'Illas,San Julian,San Julián', 43.4971600, -5.9749900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46406, 'Illano', 'Illano', 'Eilao,Il''jano,Illano,ayanw,ayyanw,yi li ya nuo,Ільяно,إيانو,اییانو,伊利亚诺', 43.3338500, -6.8656000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46407, 'Illana', 'Illana', 'Illana', 40.1844200, -2.9088900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46408, 'Ilche', 'Ilche', 'Ilche', 41.9570200, 0.0572800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46409, 'Igúzquiza', 'Iguzquiza', '', 42.6454500, -2.0855100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46410, 'Igüeña', 'Iguena', 'Iguena,Igüeña', 42.7285300, -6.2773800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46411, 'Igualada', 'Igualada', 'Igualada,Игуалада', 41.5809800, 1.6172000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46412, 'Igriés', 'Igries', 'Igries,Igriés', 42.2144300, -0.4320100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46413, 'Iglesias', 'Iglesias', '', 42.2980700, -3.9893200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46414, 'Iglesiarrubia', 'Iglesiarrubia', 'Iglesiarrubia', 41.9738300, -3.8470100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46415, 'Igea', 'Igea', 'Igea', 42.0677700, -2.0109400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46416, 'Idiazabal', 'Idiazabal', 'Idiazabal,Idiazábal', 43.0118900, -2.2335600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46417, 'Ikaztegieta', 'Icazteguieta', 'Icastiguia,Icazteguieta,Ikaztegieta', 43.0944400, -2.1237300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46418, 'Ibrillos', 'Ibrillos', 'Ibrillos', 42.4543100, -3.0823800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46419, 'Ivorra', 'Ivorra', 'Iborra,Ivorra', 41.7666700, 1.4000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46420, 'Ibieca', 'Ibieca', 'Ibieca', 42.1607900, -0.2085500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46421, 'Ibeas de Juarros', 'Ibeas de Juarros', '', 42.3308800, -3.5351900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46422, 'Ibdes', 'Ibdes', 'Ibdes', 41.2166700, -1.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46423, 'Ivars d''Urgell', 'Ivars d''Urgell', 'Ibars de Urgel,Ivars d''Urgell', 41.6833300, 1.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46424, 'Ibarrangelu', 'Ibarrangelu', 'Elejalde,Ibarrangelu,Ibarranguelua', 43.3902700, -2.6342300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46425, 'Ibarra', 'Ibarra', 'Campo Ibarra,Ibarra', 43.1312700, -2.0648700, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46426, 'Husillos', 'Husillos', 'Husillos', 42.0905400, -4.5270900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46427, 'Hurtumpascual', 'Hurtumpascual', 'Hurtumpascual', 40.6920000, -5.1137900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46428, 'Hurones', 'Hurones', '', 42.4057100, -3.6158800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46429, 'Humanes de Madrid', 'Humanes de Madrid', '', 40.2503800, -3.8306200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46430, 'Humanes', 'Humanes', 'Humanes', 40.8259800, -3.1525700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46431, 'Humada', 'Humada', 'Humada,Umada,hwmada,wu ma da,Умада,هومادا,乌马达', 42.6666700, -4.0833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46432, 'Hueva', 'Hueva', 'Hueva', 40.4622100, -2.9603900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46433, 'Huete', 'Huete', 'Huet,Huete,Uehte,Uete,hwyty  qwnkt,wei te,Уете,Уэте,هويتي، قونكة,韦特', 40.1452600, -2.6902600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46434, 'Huesca', 'Huesca', 'Gorad Uehska,Gueesca,Güesca,HSK,Huesca,Hueska,Osca,Oska,Uehska,Uesca,Ueska,hwyska,ueseuka,uesuka,wei si ka,wshqt,Òsca,ʼwʼsqh,Горад Уэска,Уеска,Уэска,אואסקה,هوئسکا,وشقة,ウエスカ,韦斯卡,우에스카', 42.1361500, -0.4087000, 'ES', '2011-05-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46435, 'Huesa del Común', 'Huesa del Comun', 'Huesa del Comun,Huesa del Común,Huesca del Comun,Huesca del Común', 41.0105300, -0.9188200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46436, 'Huerto', 'Huerto', 'Huerto', 41.9312800, -0.1668400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46437, 'Huertahernando', 'Huertahernando', 'Huertahernando', 40.8234800, -2.2869700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46438, 'Huerta del Rey', 'Huerta del Rey', 'Huerta del Rey,Puerta del Rey', 41.8391000, -3.3475500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46439, 'Huerta del Marquesado', 'Huerta del Marquesado', 'Huerta del Marquesado', 40.1500000, -1.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46440, 'Huerta de Arriba', 'Huerta de Arriba', 'Huerta de Arriba', 42.1167200, -3.0821100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46441, 'Huerta', 'Huerta', 'Huerta', 40.9684300, -5.4676900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46442, 'Huérmeces del Cerro', 'Huermeces del Cerro', 'Huermeces del Cerro,Huérmeces del Cerro', 41.0533200, -2.7971100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46443, 'Huérmeces', 'Huermeces', 'Huermeces,Huérmeces', 42.5225000, -3.7707200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46444, 'Huérguina', 'Huerguina', 'Huerguina,Huérguina', 40.0333300, -1.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46445, 'Huércanos', 'Huercanos', 'Huercanos,Huércanos,Owerkanos,Uehrkanos,Uerkanos,Уерканос,Уэрканос,Ուերկանոս', 42.4280000, -2.6958900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46446, 'Huelves', 'Huelves', 'Huelves', 40.0428200, -2.8844400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46447, 'Huélamo', 'Huelamo', 'Huelamo,Huelamos,Huélamo', 40.2765800, -1.8095700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46448, 'Huélaga', 'Huelaga', 'Huelaga,Huélaga', 40.0558200, -6.6156800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46449, 'Huecas', 'Huecas', 'Huecas', 40.0123000, -4.1954100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46450, 'Huarte-Uharte', 'Huarte-Uharte', 'Huarte,Uharte', 42.8303500, -1.5908700, 'ES', '2016-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46451, 'Hoz de Jaca', 'Hoz de Jaca', 'Hoz de Jaca,Oz de Chaca', 42.6904500, -0.3065000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46452, 'Hoyos de Miguel Muñoz', 'Hoyos de Miguel Munoz', 'Hoyos de Miguel Munoz,Hoyos de Miguel Muñoz', 40.3923700, -5.0671300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46453, 'Hoyos del Espino', 'Hoyos del Espino', 'Hoyos,Hoyos del Espino', 40.3562300, -5.1750500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46454, 'Hoyos del Collado', 'Hoyos del Collado', 'Hoyos del Collado', 40.3594500, -5.2002700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46455, 'Hoyos', 'Hoyos', 'Hoyos', 40.1715400, -6.7209200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46456, 'Hoyorredondo', 'Hoyorredondo', 'Hoyorredondo', 40.4627000, -5.4109700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46457, 'Hoyo de Manzanares', 'Hoyo de Manzanares', '', 40.6226500, -3.9073300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46458, 'Hoyocasero', 'Hoyocasero', 'Hoyocasero', 40.3989000, -4.9745500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46459, 'Hoyales de Roa', 'Hoyales de Roa', 'Hoyales de Roa', 41.6589300, -3.8620200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46460, 'Hostalric', 'Hostalric', 'Hostalric', 41.7500000, 2.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46461, 'L''Hospitalet de Llobregat', 'L''Hospitalet de Llobregat', 'Hospitalet de Llobregat,Ospitalet-de-L''obregat,l''Hospitalet,l''Hospitalet de Llobregat,Оспиталет-де-Льобрегат', 41.3596700, 2.1002800, 'ES', '2015-05-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46462, 'Hospital de Órbigo', 'Hospital de Orbigo', 'Hospital de Orbigo,Hospital de Órbigo', 42.4635400, -5.8863600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46463, 'Hortigüela', 'Hortiguela', 'Hortiguela,Hortigüela', 42.0684200, -3.4257800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46464, 'Hortaleza', 'Hortaleza', 'Hortaleza distritu,Hortalezo,orutaresa,オルタレサ', 40.4744400, -3.6411000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46465, 'Horta de Sant Joan', 'Horta de Sant Joan', 'Horta,Horta de San Juan,Horta de Sant Joan', 40.9500000, 0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46466, 'Horta', 'Horta', 'Horta', 41.4362800, 2.1572500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46467, 'Hornos de Moncalvillo', 'Hornos de Moncalvillo', 'Hornos de Moncalvillo', 42.3919800, -2.5855000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46468, 'Hornillos del Camino', 'Hornillos del Camino', '', 42.3386300, -3.9256000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46469, 'Hornillos de Cerrato', 'Hornillos de Cerrato', 'Hornillos de Cerrato', 41.9877200, -4.2720700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46470, 'Hornillos de Cameros', 'Hornillos de Cameros', 'Hornillos de Cameros', 42.2100100, -2.4196000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46471, 'Hormilleja', 'Hormilleja', 'Hormilleja', 42.4562800, -2.7315500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46472, 'Hormilla', 'Hormilla', 'Hormilla', 42.4382800, -2.7744700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46473, 'Hormigos', 'Hormigos', 'Hormigos', 40.0977800, -4.4447300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46474, 'Horche', 'Horche', 'Horche', 40.5639900, -3.0611000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46475, 'Horcajuelo de la Sierra', 'Horcajuelo de la Sierra', 'Horcajuelo de la Sierra', 41.0601900, -3.5464000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46476, 'Horcajo de Montemayor', 'Horcajo de Montemayor', 'Horcajo de Montemayor', 40.4226500, -5.8942700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46477, 'Horcajo de las Torres', 'Horcajo de las Torres', 'Horcajo de las Torres', 41.0649700, -5.0909200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46478, 'Horcajo de la Sierra', 'Horcajo de la Sierra', 'Horcajo de la Sierra', 41.0672300, -3.5853400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46479, 'Hontoria de Valdearados', 'Hontoria de Valdearados', 'Hontoria de Valdearados', 41.7448800, -3.5198300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46480, 'Hontoria del Pinar', 'Hontoria del Pinar', 'Hontoria del Pinar', 41.8483800, -3.1624500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46481, 'Hontoria de la Cantera', 'Hontoria de la Cantera', 'Hontoria de la Cantera', 42.1887900, -3.6425100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46482, 'Hontoria de Cerrato', 'Hontoria de Cerrato', 'Hontoria de Cerrato', 41.9106100, -4.4420900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46483, 'Hontoba', 'Hontoba', 'Hontoba', 40.4538500, -3.0385800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46484, 'Hontangas', 'Hontangas', 'Hontangas', 41.5821600, -3.7955000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46485, 'Hontanas', 'Hontanas', '', 42.3131200, -4.0452900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46486, 'Hontanares de Eresma', 'Hontanares de Eresma', 'Hontanares de Eresma', 40.9827300, -4.2043900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46487, 'Hontalbilla', 'Hontalbilla', 'Hontalbilla', 41.3455100, -4.1214900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46488, 'Honrubia de la Cuesta', 'Honrubia de la Cuesta', 'Honrubia de la Cuesta', 41.5099800, -3.7045300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46489, 'Hombrados', 'Hombrados', 'Hombrados', 40.8011800, -1.6855800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46490, 'Hita', 'Hita', 'Hita', 40.8214900, -3.0454000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46491, 'Hinojosa de San Vicente', 'Hinojosa de San Vicente', 'Hinojosa,Hinojosa de San Vicente', 40.1046300, -4.7226900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46492, 'Hinojosa del Campo', 'Hinojosa del Campo', 'Hinojosa de Campo,Hinojosa del Campo,Inokhosa-del''-Kampo,hynkhsa dl kampw,yi nuo huo sa de er kan bo,Інохоса-дель-Кампо,Инохоса-дель-Кампо,هینخسا دل کامپو,伊诺霍萨德尔坎波', 41.7384400, -2.0994600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46493, 'Hinojosa de Jarque', 'Hinojosa de Jarque', 'Hinojosa de Jarque', 40.6904900, -0.7854100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46494, 'Hinojosa de Duero', 'Hinojosa de Duero', 'Hinojosa de Duero', 40.9867400, -6.7952900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46495, 'Hijes', 'Hijes', 'Hijes', 41.2513900, -2.9998900, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46496, 'Híjar', 'Hijar', 'Hijar,Híjar', 41.1742900, -0.4511200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46497, 'Higuera de las Dueñas', 'Higuera de las Duenas', 'Higuera de las Duenas,Higuera de las Dueñas', 40.2390300, -4.6036100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46498, 'Hiendelaencina', 'Hiendelaencina', 'Endelaensina,Hiendelaencina,Iendelaehnsina,yan de lai en xi na,Єнделаенсіна,Иенделаэнсина,延德莱恩西纳', 41.0837300, -3.0033700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46499, 'Hervías', 'Hervias', 'Hervias,Hervías', 42.4478100, -2.8871400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46500, 'Hervás', 'Hervas', 'Ehrvas,Ervas,Ervás,Hervas,Hervás,ai er wa si,hyrfas,Ервас,Эрвас,هيرفاس,埃尔瓦斯', 40.2708100, -5.8672100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46501, 'Herrín de Campos', 'Herrin de Campos', 'Herrin de Campos,Herrín de Campos', 42.1247600, -4.9523900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46502, 'Herreros de Suso', 'Herreros de Suso', 'Herreros de Suso', 40.8036100, -5.0389200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46503, 'Herrería', 'Herreria', 'Herreria,Herrería', 40.8881500, -1.9601400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46504, 'Herrera de Valdecañas', 'Herrera de Valdecanas', 'Herrera de Valdecanas,Herrera de Valdecañas', 42.0482800, -4.2000400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46505, 'Herrera de Soria', 'Herrera de Soria', 'Ehrrera-de-Sorija,Errera-de-Sorija,Herrera de Soria,ai lei la de suo li ya,Еррера-де-Сорія,Эррера-де-Сория,埃雷拉德索里亚', 41.7626900, -3.0124300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46506, 'Herrera de Pisuerga', 'Herrera de Pisuerga', 'Ehrrera-de-Pisuehrga,Errera-de-Pisuerga,Herrera,Herrera de Pisuerga,ai lei la de pi su ai er jia,Еррера-де-Пісуерга,Эррера-де-Писуэрга,埃雷拉德皮苏埃尔加', 42.5949200, -4.3303400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46507, 'Herrera de los Navarros', 'Herrera de los Navarros', 'Herrera,Herrera de los Navarros', 41.2102400, -1.0827100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46508, 'Herramélluri', 'Herramelluri', 'Ehrramel''juri,Ehrramel''uri,Erramel''juri,Herramelluri,Herramélluri,ai la mei liu li,Еррамельюрі,Эррамельури,Эррамельюри,埃拉梅柳里', 42.5029500, -3.0195400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46509, 'Hernialde', 'Hernialde', 'Hernialde', 43.1544600, -2.0852100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46510, 'Hernansancho', 'Hernansancho', '', 40.8575300, -4.7304500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46511, 'Hernán-Pérez', 'Hernan-Perez', 'Ehrnan-Peres,Ernan-Peres,Hernan-Perez,Hernán-Pérez,ai er nan-pei lei si,hyrnan-byryz,Ернан-Перес,Эрнан-Перес,هيرنان-بيريز,埃尔南-佩雷斯', 40.2124600, -6.4647900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46512, 'Hernani', 'Hernani', 'Ehrnani,Ernani,Hernani,ai er na ni,arnany  asbanya,Ернани,Ернані,Эрнани,إرناني، إسبانيا,埃尔纳尼', 43.2661500, -1.9761500, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46513, 'Hermisende', 'Hermisende', 'Hermisende', 41.9689800, -6.8961600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46514, 'Hérmedes de Cerrato', 'Hermedes de Cerrato', 'Hermedes de Cerrato,Hérmedes de Cerrato', 41.8197200, -4.1736100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46515, 'Herguijuela del Campo', 'Herguijuela del Campo', 'Herguijuela del Campo', 40.6310200, -5.8639800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46516, 'Herguijuela de la Sierra', 'Herguijuela de la Sierra', 'Herguijuela de la Sierra', 40.4453500, -6.0744500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46517, 'Herguijuela de Ciudad Rodrigo', 'Herguijuela de Ciudad Rodrigo', 'Herguijuela de Ciudad Rodrigo', 40.4586000, -6.5207500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46518, 'Herce', 'Herce', 'Herce', 42.2142300, -2.1648800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46519, 'Herbés', 'Herbes', 'Herbers,Herbes,Herbés', 40.7210000, -0.0044100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46520, 'Henche', 'Henche', 'Henche', 40.7147400, -2.7074600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46521, 'Hazas de Cesto', 'Hazas de Cesto', 'Hazas de Cesto', 43.3965300, -3.5891600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46522, 'Haza', 'Haza', 'Asa,Haza,hasa,Аса,هاسا', 41.6166700, -3.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46523, 'Haro', 'Haro', 'Haro', 42.5763400, -2.8476000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46524, 'Hacinas', 'Hacinas', 'Hacinas', 41.9851400, -3.2870900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46525, 'Gutierre-Muñoz', 'Gutierre-Munoz', 'Gutierre-Muno,Gutierre-Munoz,Gutierre-Muño,Gutierre-Muñoz', 40.9829500, -4.6383900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46526, 'Gusendos de los Oteros', 'Gusendos de los Oteros', 'Gusendos de los Oteros', 42.3781800, -5.4308800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46527, 'Gurrea de Gállego', 'Gurrea de Gallego', 'Gurrea,Gurrea de Gallego,Gurrea de Gállego', 42.0154100, -0.7615000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46528, 'Guntín', 'Guntin', '', 42.8870200, -7.6925900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46529, 'Guitiriz', 'Guitiriz', 'Guitiriz', 43.1816900, -7.8965600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46530, 'Guisando', 'Guisando', 'Guisando', 40.2222500, -5.1395000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46531, 'Guirguillano', 'Guirguillano', '', 42.7172500, -1.8779800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46532, 'Guimerà', 'Guimera', 'Guimera,Guimerà', 41.5645000, 1.1852800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46533, 'Guils de Cerdanya', 'Guils de Cerdanya', 'Guils de Cerdana,Guils de Cerdanya,Guils de Cerdaña', 42.4474000, 1.8801200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46534, 'Guijuelo', 'Guijuelo', 'Gikhuehlo,Gikhuelo,Guijuelo,ji hu ai luo,Гихуэло,Гіхуело,吉胡埃洛', 40.5575700, -5.6706700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46535, 'Guijo de Santa Bárbara', 'Guijo de Santa Barbara', 'Guijo de Santa Barbara,Guijo de Santa Bárbara', 40.1541000, -5.6541400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46536, 'Guijo de Granadilla', 'Guijo de Granadilla', 'Guijo de Granadilla', 40.1935100, -6.1633900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46537, 'Guijo de Galisteo', 'Guijo de Galisteo', 'Guijo de Galisteo', 40.0938300, -6.4100700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46538, 'Guijo de Coria', 'Guijo de Coria', 'Guijo de Coria', 40.1009800, -6.4638300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46539, 'Guijo de Ávila', 'Guijo de Avila', 'Guijo de Avila,Guijo de Ávila', 40.5307800, -5.6397000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46540, 'Getaria', 'Getaria', 'Cetaria,Getaria,Getarija,Guetaria,getaria,ghytarya,he ta li ya,Гетария,Гетарія,غيتاريا,ゲタリア,赫塔里亚', 43.3032600, -2.2044400, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46541, 'Gernika-Lumo', 'Gernika-Lumo', 'Gernika,Gernika-Lumo,Guernica,Guernica y Luno', 43.3166700, -2.6833300, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46542, 'Güeñes', 'Guenes', 'Gueenes,Guehn''es,Guen''es,Guenes,Gueñes,Güeñes,ge nie si,ghynays,Гуеньєс,Гуэньес,غينايس,格涅斯', 43.2125200, -3.0949700, 'ES', '2012-12-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46543, 'Getxo', 'Getxo', 'Getxo,Guecho', 43.3568900, -3.0114600, 'ES', '2013-05-08', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46544, 'Gúdar', 'Gudar', 'Gudar,Gúdar', 40.4410700, -0.7204800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46545, 'Guaza de Campos', 'Guaza de Campos', 'Guaza,Guaza de Campos', 42.1336500, -4.9094900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46546, 'Guardo', 'Guardo', 'Cuardo,Guardo,Gvardo,gua er duo,Гвардо,Гуардо,瓜尔多', 42.7896600, -4.8482300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46547, 'Guardiola de Berguedà', 'Guardiola de Bergueda', 'Guardiola,Guardiola de Berga,Guardiola de Bergueda,Guardiola de Berguedà', 42.2349000, 1.8771600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46548, 'Sant Salvador de Guardiola', 'Sant Salvador de Guardiola', 'Guardiola,Sant Salvador de Guardiola', 41.6833300, 1.7666700, 'ES', '2015-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46549, 'Gualta', 'Gualta', '', 42.0295300, 3.1031200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46550, 'Guadramiro', 'Guadramiro', 'Guadramiro', 41.0170300, -6.4936900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46551, 'Guadarrama', 'Guadarrama', 'Guadarram', 40.6727000, -4.0894900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46552, 'Guadalix de la Sierra', 'Guadalix de la Sierra', '', 40.7849600, -3.6934700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46553, 'Guadalaviar', 'Guadalaviar', 'Guadalaviar', 40.3882400, -1.7180300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46554, 'Guadalajara', 'Guadalajara', 'GDU,Guadalajara,Gvadalaharo,Gvadalakhara,guadarahara,Гвадалахара,グアダラハラ', 40.6286200, -3.1618500, 'ES', '2013-07-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46555, 'O Grove', 'O Grove', 'El Grove,Jrobe,O-Grove,Ogrobe,Ogrove,a grbh,al ghrwfy,ao ge luo wei,О-Грове,إل غروفي,ا گربه,オ・グローベ,奥格罗韦', 42.4944400, -8.8650200, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46556, 'Grisén', 'Grisen', 'Grisen,Grisén', 41.7452400, -1.1626000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46557, 'Grisel', 'Grisel', 'Grisel', 41.8710900, -1.7279400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46558, 'Grisaleña', 'Grisalena', 'Grisalena,Grisaleña', 42.5912200, -3.2641600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46559, 'Griñón', 'Grinon', 'Grinon,Griñón', 40.2124900, -3.8548200, 'ES', '2014-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46560, 'Grijota', 'Grijota', 'Grijota', 42.0528900, -4.5830900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46561, 'Grijalba', 'Grijalba', 'Grijalba', 42.4300200, -4.1189600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46562, 'Griegos', 'Griegos', 'Griegos', 40.4272200, -1.7120100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46563, 'Grávalos', 'Gravalos', 'Bravalos,Gravalos,Grávalos', 42.1083600, -1.9987400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46564, 'Graus', 'Graus', 'Graus,ge lao si,Граус,格劳斯', 42.1888500, 0.3374900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46565, 'Granucillo', 'Granucillo', 'Granucillo', 42.0520900, -5.9277700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46566, 'Grañón', 'Granon', 'Gran''jon,Gran''on,Granion,Granon,Grañón,ge la ni weng,Граньйон,Граньон,Գրանիոն,格拉尼翁', 42.4499200, -3.0276700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46567, 'Granollers', 'Granollers', 'Granollers', 41.6079700, 2.2877300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46568, 'Granja de Moreruela', 'Granja de Moreruela', 'Granja de Moreruela', 41.8102600, -5.7389300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46569, 'la Granja d''Escarp', 'la Granja d''Escarp', 'Granja de Escarpe,la Granja d''Escarp', 41.4166700, 0.3666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46570, 'Granera', 'Granera', 'Granera', 41.7274100, 2.0592400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46571, 'Grañén', 'Granen', 'Granen,Grañén', 41.9410400, -0.3694100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46572, 'Grandas de Salime', 'Grandas de Salime', 'Crandas de Salime,Grandas,Grandas de Salime,Grandas-de-Salime,ge lan da si de sa li mei,ghrandas dy salymy,grandas d salymh,Грандас-де-Салиме,Грандас-де-Саліме,غرانداس دي ساليمي,گرانداس د سالیمه,格兰达斯德萨利梅', 43.2155400, -6.8757000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46573, 'la Granadella', 'la Granadella', 'Granadella,La Granadella,la Granadella', 41.3500000, 0.6666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46574, 'Grajera', 'Grajera', 'Grajera', 41.3731900, -3.6130400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46575, 'Grajal de Campos', 'Grajal de Campos', 'Grajal', 42.3207300, -5.0193800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46576, 'Grado', 'Grado', 'Grado,Grao,Grau,ge la duo,ghradw  astwryas,gradw,Градо,غرادو، أستورياس,گرادو,格拉多', 43.3880100, -6.0743300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46577, 'Gradefes', 'Gradefes', 'Gradefes', 42.6239600, -5.2269100, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46578, 'Gràcia', 'Gracia', 'Districte de Gracia,Districte de Gràcia,Distrikt Gracia,Distrikt Gràcia,Distrito de Gracia,Gracia,Gracia distritu,Gràcia,Gràcia distritu,Vila de Gracia,Vila de Gràcia,en dian qu,恩典区', 41.4023700, 2.1564100, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46579, 'Gotor', 'Gotor', 'Gotor', 41.5458300, -1.6491500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46580, 'Gotarrendura', 'Gotarrendura', 'Gotarrendura', 40.8265200, -4.7409000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46581, 'Gósol', 'Gosol', 'Gosol,Gósol', 42.2369700, 1.6601000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46582, 'Gormaz', 'Gormaz', 'Gormas,Gormaz,ge er ma si,Гормас,戈尔马斯', 41.4923200, -3.0050000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46583, 'Elexalde', 'Elexalde', 'Elexalde,Elexalde Gorliz,Gorliz,Górliz', 43.4149000, -2.9367800, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46584, 'Gordoncillo', 'Gordoncillo', 'Gordoncillo,Gordonsil''jo,Gordonsil''o,ge er dong xi e,gwrdwnsyyw,Гордонсильо,Гордонсільйо,گوردونسییو,戈尔东西略', 42.1355700, -5.4018100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46585, 'Gordaliza del Pino', 'Gordaliza del Pino', 'Gordaliza', 42.3435700, -5.1573100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46586, 'Goñi', 'Goni', 'Goni,Goñi', 42.8516700, -1.9035800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46587, 'Gondomar', 'Gondomar', 'Gondomar', 42.1115500, -8.7497100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46588, 'Gomecello', 'Gomecello', 'Gomecello', 41.0428000, -5.5358500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46589, 'Gómara', 'Gomara', 'Gomara,Gómara,ge ma la,Гомара,Գոմարա,戈马拉', 41.6234700, -2.2249300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46590, 'Golpejas', 'Golpejas', 'Golpejas', 40.9998100, -5.9068700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46591, 'Golmés', 'Golmes', 'Golmes,Golmés', 41.6335400, 0.9312500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46592, 'Golmayo', 'Golmayo', 'Gol''majo,Golmayo,ge er mai ao,Гольмайо,戈尔迈奥', 41.7662000, -2.5226700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46593, 'Goizueta', 'Goizueta', 'Boizueta,Coizueta,Goizueta,Gojsuehta,Gojsueta,ge yi su ai ta,Гойсуета,Гойсуэта,戈伊苏埃塔', 43.1718700, -1.8641100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46594, 'Godojos', 'Godojos', 'Godojos', 41.2683800, -1.8641000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46595, 'Gistaín', 'Gistain', 'Chisten,Chistén,Gistain,Gistaín', 42.5911000, 0.3347800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46596, 'Gironella', 'Gironella', 'Gironella', 42.0343300, 1.8801900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46597, 'Xinzo de Limia', 'Xinzo de Limia', 'Xinzo', 42.0635000, -7.7245900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46598, 'Ginestar', 'Ginestar', 'Ginestar', 41.0418400, 0.6329000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46599, 'Gimileo', 'Gimileo', '', 42.5499200, -2.8223700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46600, 'Gimialcón', 'Gimialcon', 'Gimialcon,Gimialcón', 40.8770500, -5.1230800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46601, 'Gijón', 'Gijon', 'Chichonas,Gigia,Gijon,Gijón,Gorad Khikhon,Hihono,Khikhon,Kixoi,QIJ,Xixon,Xixón,gyjwn,hihon,hyhwn,khi khxn,khikhoni,khykhn,khykhwn,kikon,xi hong,Ĥiĥono,Горад Хіхон,Хихон,Хіхон,חיחון,خيخون,خیخن,خیخۆن,گیجون,கிகோன்,คีคอน,ხიხონი,ヒホン,希洪,히혼', 43.5357300, -5.6615200, 'ES', '2012-12-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46602, 'Getafe', 'Getafe', 'Chetafe,Chetafė,Getafe,Gorad Khetafeh,Khetafe,Tituacia,Xetafe,he ta fei,hetafe,hetape,khe tafe,khytafy,Χετάφε,Горад Хетафэ,Хетафе,خيتافي,เคตาเฟ,ヘタフェ,赫塔费,헤타페', 40.3057100, -3.7329500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46603, 'Girona', 'Girona', 'GRO,Gerona,Gerone,Girona,Girono,Gérone,Kherona,Zherona,jirona,Ĝirono,Жерона,Херона,ジローナ', 41.9831100, 2.8249300, 'ES', '2014-05-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46604, 'Geria', 'Geria', 'Geria', 41.5786800, -4.8766300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46605, 'Ger', 'Ger', '', 42.4105900, 1.8453600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46606, 'Genevilla', 'Genevilla', '', 42.6452000, -2.3902100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46607, 'Gemuño', 'Gemuno', 'Gemuno,Gemuño', 40.5915900, -4.7817800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46608, 'Gema', 'Gema', 'Gema', 41.4185500, -5.6490600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46609, 'Gelsa', 'Gelsa', 'Gelsa', 41.4076600, -0.4615800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46610, 'Gelida', 'Gelida', '', 41.4333300, 1.8666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46611, 'Gejuelo del Barro', 'Gejuelo del Barro', 'Gejuelo del Barro', 41.0763300, -6.1233200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46612, 'Gea de Albarracín', 'Gea de Albarracin', 'Gea', 40.4111400, -1.3482300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46613, 'Gaztelu', 'Gaztelu', 'Gaztelu', 43.1162200, -2.0243900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46614, 'Gabiria', 'Gabiria', 'Gabiria,Gaviria', 43.0493400, -2.2796200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46615, 'Gavilanes', 'Gavilanes', 'Gavilanes', 40.2779100, -4.8532100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46616, 'Gavà', 'Gava', 'Gava,Gavà,Гава', 41.3060500, 2.0012300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46617, 'Gatón de Campos', 'Gaton de Campos', 'Gaton,Gaton de Campos,Gatón,Gatón de Campos', 42.0498400, -4.9807800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46618, 'Gatika', 'Gatika', 'Gatica,Gatika,Santa Maria de Gatica,Santa María de Gatica', 43.3631300, -2.8729400, 'ES', '2015-06-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46619, 'Gata', 'Gata', 'Gata', 40.2375800, -6.5968400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46620, 'Gascueña de Bornova', 'Gascuena de Bornova', 'Gascuena de Bornova,Gascueña de Bornova', 41.1424300, -3.0192400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46621, 'Gascueña', 'Gascuena', 'Gascuena,Gascueña', 40.2993700, -2.5185600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46622, 'Gascones', 'Gascones', 'Gascones', 41.0184300, -3.6421700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46623, 'Garriguella', 'Garriguella', 'Garriguella', 42.3439200, 3.0650600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46624, 'Garrigoles', 'Garrigoles', 'Garrigolas,Garrigoles', 42.1000000, 3.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46625, 'Garrigàs', 'Garrigas', 'Garrigas,Garrigàs', 42.1934300, 2.9543800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46626, 'Garray', 'Garray', 'Garraj,Гаррай', 41.8161700, -2.4459200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46627, 'Garralda', 'Garralda', 'Garralda', 42.9481800, -1.2862400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46628, 'Garrafe de Torío', 'Garrafe de Torio', 'Carrafe de Torio,Garrafe,Garrafe de Torio,Garrafe de Torío,Garrafe-de-Torio,jia la fei de tuo li ao,Гаррафе-де-Торио,Гаррафе-де-Торіо,加拉费德托里奥', 42.7328500, -5.5236000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46629, 'Garínoain', 'Garinoain', '', 42.6003600, -1.6443400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46630, 'Gargüera', 'Garguera', 'Garguera,Gargüera', 40.0613000, -5.9278100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46631, 'Gargantilla', 'Gargantilla', 'Gargantilla', 40.2483500, -5.9206800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46632, 'Garganta la Olla', 'Garganta la Olla', 'Garganta la Olla', 40.1104900, -5.7766500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46633, 'Garganta del Villar', 'Garganta del Villar', 'Garganta del Villar', 40.4496500, -5.1042000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46634, 'Garganta de los Montes', 'Garganta de los Montes', 'Garganta de los Montes', 40.9199200, -3.6837500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46635, 'Gargallo', 'Gargallo', 'Gargallo,Gargayo', 40.8358300, -0.5844200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46636, 'Garde', 'Garde', 'Garde', 42.7893700, -0.9258900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46637, 'Garcirrey', 'Garcirrey', 'Garcirrey', 40.9004900, -6.1312000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46638, 'Garcillán', 'Garcillan', 'Garcillan,Garcillán', 40.9777100, -4.2657700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46639, 'Garcihernández', 'Garcihernandez', 'Garcihernandez,Garcihernández', 40.8609600, -5.4356700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46640, 'Garcibuey', 'Garcibuey', 'Garcibuey', 40.5155200, -5.9943900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46641, 'Garcia', 'Garcia', 'Garcia,García', 41.1333300, 0.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46642, 'Garaioa', 'Garaioa', 'Garaioa,Garayoa', 42.9333300, -1.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46643, 'Gandesa', 'Gandesa', 'Gandesa,Grandesa', 41.0537500, 0.4385000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46644, 'Gamones', 'Gamones', 'Gamones', 41.4669000, -6.1762100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46645, 'Galve de Sorbe', 'Galve de Sorbe', 'Galve,Galve de Sorba,Galve de Sorbe', 41.2166700, -3.1833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46646, 'Galve', 'Galve', 'Galve', 40.6559100, -0.8821700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46647, 'Gallur', 'Gallur', 'Gallur', 41.8683000, -1.3157700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46648, 'Gallocanta', 'Gallocanta', '', 40.9962400, -1.5077400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46649, 'Gallipienzo', 'Gallipienzo', 'Gallipienzo', 42.5245000, -1.4111500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46650, 'Gallinero de Cameros', 'Gallinero de Cameros', 'Gallinero de Cameros', 42.1722900, -2.6179300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46651, 'Gallifa', 'Gallifa', 'Gallifa', 41.6924300, 2.1134600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46652, 'Gallegos de Sobrinos', 'Gallegos de Sobrinos', 'Gallegos de Sobrinos', 40.7169300, -5.1122400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46653, 'Gallegos del Río', 'Gallegos del Rio', 'Gallegos del Rio,Gallegos del Río', 41.7349700, -6.1743500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46654, 'Gallegos del Pan', 'Gallegos del Pan', 'Gallegos del Pan', 41.5998500, -5.5811700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46655, 'Gallegos de Hornija', 'Gallegos de Hornija', 'Gallegos de Hornija', 41.6098000, -5.0976800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46656, 'Gallegos de Argañán', 'Gallegos de Arganan', 'Gallegos de Arganan,Gallegos de Argañán', 40.6314600, -6.7024600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46657, 'Gallegos', 'Gallegos', '', 41.0750800, -3.7859100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46658, 'Galisancho', 'Galisancho', 'Galisancho', 40.7441800, -5.5547100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46659, 'Galinduste', 'Galinduste', 'Galinduste', 40.6626600, -5.5400300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46660, 'Galindo y Perahuy', 'Galindo y Perahuy', 'Galindo y Perahuy', 40.9439700, -5.8741000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46661, 'Galilea', 'Galilea', 'Galilea', 42.3470300, -2.2360500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46662, 'Galende', 'Galende', '', 42.1044000, -6.6625200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46663, 'Galdakao', 'Galdakao', 'Gal''dakano,Galdacan,Galdacano,Galdacon,Galdakao,Galdácano,Гальдакано', 43.2333300, -2.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46664, 'Galbárruli', 'Galbarruli', 'Gabalruli,Gabálruli,Galbarruli,Galbárruli', 42.6218100, -2.9608700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46665, 'Galbarros', 'Galbarros', 'Galbarros', 42.5272900, -3.4382700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46666, 'Galar', 'Galar', 'Cendea de Galar,Galar,Galar Zendea,jia la er,Галар,加拉尔', 42.7614700, -1.6988100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46667, 'Galápagos', 'Galapagos', 'Galapagos,Galápagos', 40.6934700, -3.3353700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46668, 'Galapagar', 'Galapagar', 'Galapagar,jalabajar,jia la pa jia er,Галапагар,جالاباجار,加拉帕加尔', 40.5783000, -4.0042600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46669, 'Gajates', 'Gajates', 'Gajates', 40.7825400, -5.3650600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46670, 'Gajanejos', 'Gajanejos', 'Gajanejos', 40.8414700, -2.8922900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46671, 'Gaintza', 'Gainza', 'Gaintza,Gainza,Gaínza', 43.0527100, -2.1329000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46672, 'Fustiñana', 'Fustinana', 'Fustinana,Fustiñana', 42.0208700, -1.4852600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46673, 'Funes', 'Funes', 'Funes', 42.3156200, -1.8001700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46674, 'Fulleda', 'Fulleda', 'Fulleda', 41.4633400, 1.0239500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46675, 'Fuertescusa', 'Fuertescusa', 'Fuerte-Escusa,Fuertescusa', 40.4755200, -2.1762000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46676, 'Fuentidueña de Tajo', 'Fuentiduena de Tajo', 'Fuentiduena de Tajo,Fuentidueña de Tajo', 40.1157400, -3.1571800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46677, 'Fuentidueña', 'Fuentiduena', 'Fuehntiduehn''ja,Fuentiduen''ja,Fuentiduena,Fuentidueña,feng di du ai ni ya,Фуентідуенья,Фуэнтидуэнья,丰蒂杜埃尼亚', 41.4422600, -3.9789900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46678, 'Fuentestrún', 'Fuentestrun', 'Fuentestrun,Fuentestrur,Fuentestrún,Fuentestrúr', 41.8746600, -2.0828300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46679, 'Fuentespreadas', 'Fuentespreadas', 'Fuentespreadas', 41.3262700, -5.6279800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46680, 'Fuentespina', 'Fuentespina', 'Fuentespina', 41.6307900, -3.6847500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46681, 'Fuentespalda', 'Fuentespalda', 'Fondespatla,Fontespala,Fuentespalda', 40.8066600, 0.0651700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46682, 'Fuentesoto', 'Fuentesoto', 'Fuentesoto', 41.4566400, -3.9183500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46683, 'Fuentesecas', 'Fuentesecas', 'Fuentesecas', 41.6307700, -5.4725200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46684, 'Fuentes de Valdepero', 'Fuentes de Valdepero', 'Fuentes de Valdepero', 42.0753200, -4.5005000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46685, 'Fuentes de Rubielos', 'Fuentes de Rubielos', 'Fonts de Rubiols,Fuentes de Rubielos', 40.1666700, -0.6166700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46686, 'Fuentes de Ropel', 'Fuentes de Ropel', 'Fuentes,Fuentes de Ropel', 42.0037700, -5.5453200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46687, 'Fuentes de Oñoro', 'Fuentes de Onoro', 'Fuentes de Onoro,Fuentes de Oñoro', 40.5910200, -6.8114400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46688, 'Fuentes de Nava', 'Fuentes de Nava', 'Fuentes de Nava', 42.0833300, -4.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46689, 'Fuentes de Magaña', 'Fuentes de Magana', 'Fuehntes-de-Maganija,Fuentes de Magana,Fuentes de Magaña,Fuentes-de-Magan''ja,feng te si de ma jia ni ya,Фуентес-де-Маганья,Фуэнтес-де-Магания,丰特斯德马加尼亚', 41.9352100, -2.1795000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46690, 'Fuentes de Jiloca', 'Fuentes de Jiloca', 'Fuentes de Jiloca', 41.2285900, -1.5361600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46691, 'Fuentes de Ebro', 'Fuentes de Ebro', 'Fuentes de Ebro', 41.5125000, -0.6315900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46692, 'Fuentes de Carbajal', 'Fuentes de Carbajal', 'Fuentes de Carbajal', 42.1777600, -5.4460600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46693, 'Fuentes de Béjar', 'Fuentes de Bejar', 'Fuehntes-de-Bekhar,Fuentes de Bejar,Fuentes de Béjar,Fuentes-de-Bekhar,feng te si de wei ha er,Фуентес-де-Бехар,Фуэнтес-де-Бехар,丰特斯德韦哈尔', 40.5081500, -5.6927000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46694, 'Fuentes de Ayódar', 'Fuentes de Ayodar', 'Fuentes de Ayodar,Fuentes de Ayódar', 40.0333300, -0.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46695, 'Fuentes de Año', 'Fuentes de Ano', 'Fuentes de Ano,Fuentes de Año', 41.0176900, -4.8990700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46696, 'Fuentes Claras', 'Fuentes Claras', 'Fuentes Claras', 40.8637500, -1.3226600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46697, 'Fuentes Calientes', 'Fuentes Calientes', 'Fuentes Calientes', 40.7000000, -0.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46698, 'Fuentesaúco de Fuentidueña', 'Fuentesauco de Fuentiduena', 'Fuentesauco de Fuentiduena,Fuentesaúco de Fuentidueña', 41.4244500, -4.0621500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46699, 'Fuentesaúco', 'Fuentesauco', 'Fuentesauco,Fuentesaúco', 41.2304300, -5.4972200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46700, 'Fuenterroble de Salvatierra', 'Fuenterroble de Salvatierra', 'Fuenterroble de Salvatierra', 40.5646600, -5.7337900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46701, 'Hondarribia', 'Fuenterrabia', 'Fontarabie,Fuenterrabia,Fuenterrabía,Hondarribi,Hondarribia', 43.3685900, -1.7962200, 'ES', '2013-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46702, 'Fuentepinilla', 'Fuentepinilla', 'Fuehntepinil''ja,Fuentepinil''ja,Fuentepinilla,feng te pi ni li ya,Фуентепінілья,Фуэнтепинилья,丰特皮尼利亚', 41.5668300, -2.7628800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46703, 'Fuentepiñel', 'Fuentepinel', 'Fuentepinel,Fuentepiñel', 41.3989200, -4.0429500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46704, 'Fuentepelayo', 'Fuentepelayo', 'Fuentepelayo', 41.2224900, -4.1757000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46705, 'Fuentenovilla', 'Fuentenovilla', 'Fuentenovilla', 40.3624800, -3.0910200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46706, 'Fuentenebro', 'Fuentenebro', 'Fuentenebro', 41.5287300, -3.7544900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46707, 'Fuentemolinos', 'Fuentemolinos', 'Fuentemolinos', 41.6047700, -3.8500500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46708, 'Fuentelviejo', 'Fuentelviejo', 'Fuentelviejo', 40.5263700, -2.9843000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46709, 'Fuentelsaz de Soria', 'Fuentelsaz de Soria', 'Fuehntel''sas-de-Sorija,Fuentel''sas-de-Sorija,Fuentelsaz de Soria,feng te er sa si de suo li ya,Фуентельсас-де-Сорія,Фуэнтельсас-де-Сория,丰特尔萨斯德索里亚', 41.8658600, -2.4152500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46710, 'Fuentelsaz', 'Fuentelsaz', 'Fuente el Saz,Fuentelsaz', 41.0735900, -1.8310800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46711, 'Fuentelisendo', 'Fuentelisendo', 'Fuentelisendo,Fuentelisendro', 41.6227400, -3.9012900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46712, 'Fuentelencina', 'Fuentelencina', 'Fuentelaencina,Fuentelencina', 40.5178100, -2.8822600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46713, 'Fuentelcésped', 'Fuentelcesped', 'Fuentelcesped,Fuentelcésped', 41.5916200, -3.6406400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46714, 'Fuente la Reina', 'Fuente la Reina', 'Fuente la Reina,La Font de la Reina', 40.0666700, -0.6000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46715, 'Fuentelapeña', 'Fuentelapena', 'Fuentelapena,Fuentelapeña', 41.2514400, -5.3832500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46716, 'Fuentelahiguera de Albatages', 'Fuentelahiguera de Albatages', 'Fuentelahiguera de Albatages', 40.7831200, -3.3049200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46717, 'Fuenteguinaldo', 'Fuenteguinaldo', 'Fuenteguinaldo', 40.4287600, -6.6752800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46718, 'Fuente Encalada', 'Fuente Encalada', 'Fuente Encalada', 42.1101100, -5.9962200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46719, 'Fuente el Sol', 'Fuente el Sol', 'Fuente el Sol', 41.1760300, -4.9343000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46720, 'Fuente el Saz', 'Fuente el Saz', '', 40.6321500, -3.5114600, 'ES', '2011-04-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46721, 'Fuente el Olmo de Fuentidueña', 'Fuente el Olmo de Fuentiduena', 'Fuente el Olmo,Fuente el Olmo de Fuentiduena,Fuente el Olmo de Fuentidueña', 41.3792900, -4.0008600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46722, 'Fuente de Santa Cruz', 'Fuente de Santa Cruz', 'Fuente de Santa Cruz', 41.2097200, -4.6353000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46723, 'Fuentecén', 'Fuentecen', 'Fuehntesen,Fuenecen,Fuenecén,Fuentecen,Fuentecén,Fuentesen,feng te sen,fwyntsn,fwyntysyn,Фуентесен,Фуэнтесен,فوئنتسن,فوينتيسين,丰特森', 41.6285200, -3.8686700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46724, 'Fuentecantos', 'Fuentecantos', 'Fuentecantos', 41.8492900, -2.4284600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46725, 'Fuentecambrón', 'Fuentecambron', 'Fuehntekambron,Fuentecambron,Fuentecambrón,Fuentekambron,feng te kan fu long,Фуентекамброн,Фуэнтекамброн,丰特坎夫龙', 41.5057900, -3.3287200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46726, 'Fuentebureba', 'Fuentebureba', 'Fuentebureba', 42.6340000, -3.2351000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46727, 'Fuentearmegil', 'Fuentearmegil', 'Fuehntearmekhil'',Fuentearmegil,Fuentearmekhil'',feng te ya er mei xi er,Фуентеармехіль,Фуэнтеармехиль,丰特亚尔梅希尔', 41.7149600, -3.1836200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46728, 'Fuensalida', 'Fuensalida', 'Fuensalida', 40.0528800, -4.2071800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46729, 'Fuensaldaña', 'Fuensaldana', 'Fuensaldana,Fuensaldaña', 41.7061700, -4.7654700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46730, 'Fuenmayor', 'Fuenmayor', 'Fuehnmajor,Fuenmajor,Fuenmayor,feng mai ao er,Фуенмайор,Фуэнмайор,Ֆուենմայոր,丰迈奥尔', 42.4672900, -2.5615300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46731, 'Fuenlabrada', 'Fuenlabrada', 'Fons Laborata,Fuehnlabrada,Fuenlabrada,Gorad Fuehnlabrada,feng la fu la da,fuenraburada,fwynlabrada,Горад Фуэнлабрада,Фуенлабрада,Фуэнлабрада,פואנלברדה,فوينلابرادا,フエンラブラダ,丰拉夫拉达', 40.2841900, -3.7941500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46732, 'Fuenferrada', 'Fuenferrada', 'Fuenferrada', 40.8692300, -1.0117900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46733, 'Fuendetodos', 'Fuendetodos', 'Fuendetodos', 41.3424500, -0.9598800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46734, 'Fuendejalón', 'Fuendejalon', 'Fuendejalon,Fuendejalón', 41.7605000, -1.4721300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46735, 'Fuencemillán', 'Fuencemillan', 'Fuencemillan,Fuencemillán', 40.9206300, -3.0981800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46736, 'Fuembellida', 'Fuembellida', 'Fuembellida', 40.7558900, -1.9986100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46737, 'Frumales', 'Frumales', 'Frumales', 41.3833300, -4.1863100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46738, 'Frómista', 'Fromista', 'Fromista,Frómista', 42.2666700, -4.4054600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46739, 'Friol', 'Friol', 'Frio', 43.0321300, -7.7951400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46740, 'Friera de Valverde', 'Friera de Valverde', 'Friera de Valverde', 41.9121400, -5.8415300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46741, 'Frías de Albarracín', 'Frias de Albarracin', 'Frias de Albarracin,Frías de Albarracín', 40.3375400, -1.6147000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46742, 'Frías', 'Frias', 'Frias,Frías,Trias', 42.7622500, -3.2939400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46743, 'Fresno El Viejo', 'Fresno El Viejo', 'Fresno El Viejo', 41.1975200, -5.1441300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46744, 'Fresno de Torote', 'Fresno de Torote', 'Fresno de Torote', 40.5904000, -3.4100300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46745, 'Fresno de Sayago', 'Fresno de Sayago', 'Fresno de Sayago', 41.3184800, -5.9712900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46746, 'Fresno de Rodilla', 'Fresno de Rodilla', '', 42.4205400, -3.4850700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46747, 'Fresno del Río', 'Fresno del Rio', 'Fresno del Rio,Fresno del Río', 42.6817600, -4.8173400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46748, 'Fresno de la Vega', 'Fresno de la Vega', 'Fresno de la Vega', 42.3454500, -5.5358700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46749, 'Fresno de la Ribera', 'Fresno de la Ribera', 'Fresno de la Ribera', 41.5292600, -5.5665800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46750, 'Fresno de la Polvorosa', 'Fresno de la Polvorosa', 'Fresno de la Polvorosa', 42.0831000, -5.7696900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46751, 'Fresno de la Fuente', 'Fresno de la Fuente', 'Fresno de la Fuente', 41.3924300, -3.6449100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46752, 'Fresno de Caracena', 'Fresno de Caracena', 'Fresno de Caracena', 41.4524700, -3.0912300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46753, 'Fresno de Cantespino', 'Fresno de Cantespino', 'Fresno de Cantespino', 41.3682000, -3.4995000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46754, 'Fresnillo de las Dueñas', 'Fresnillo de las Duenas', 'Fresnillo,Fresnillo de Duero,Fresnillo de las Duenas,Fresnillo de las Dueñas', 41.6470000, -3.6455800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46755, 'Fresneña', 'Fresnena', 'Fresnena,Fresneña', 42.4136600, -3.1345300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46756, 'Fresnedoso', 'Fresnedoso', 'Fresnedoso', 40.4361900, -5.7096900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46757, 'Fresnedillas', 'Fresnedillas', '', 40.4870400, -4.1714600, 'ES', '2008-10-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46758, 'Fresnedilla', 'Fresnedilla', 'Fresnedil''ja,Fresnedila,Fresnedilla,Fresnedillas,Fresnedilya,frsndyya,frysnydya,fu lei si nei di li ya,Фреснедила,Фреснедилья,Фреснеділья,Ֆրեսնեդիլյա,فرسندییا,فريسنيديا,夫雷斯内迪利亚', 40.2323300, -4.6220100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46759, 'Fresneda de la Sierra Tirón', 'Fresneda de la Sierra Tiron', 'Fresneda de la Sierra Tiron,Fresneda de la Sierra Tirón', 42.3153500, -3.1359600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46760, 'Fresneda de la Sierra', 'Fresneda de la Sierra', 'Fresneda de la Sierra', 40.3910100, -2.1423300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46761, 'Fresneda de Cuéllar', 'Fresneda de Cuellar', 'Fresneda de Cuellar,Fresneda de Cuéllar', 41.3190500, -4.4493800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46762, 'Fréscano', 'Frescano', 'Frescano,Fréscano', 41.8833300, -1.4500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46763, 'Frechilla de Almazán', 'Frechilla de Almazan', 'Frechilla,Frechilla de Almazan,Frechilla de Almazán', 41.4265600, -2.5144400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46764, 'Frechilla', 'Frechilla', 'Flechilla,Frechilla', 42.1376800, -4.8411200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46765, 'Frandovínez', 'Frandovinez', 'Frandevinez', 42.3103200, -3.8378300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46766, 'Fraga', 'Fraga', 'Fraga', 41.5229400, 0.3489400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46767, 'Frades de la Sierra', 'Frades de la Sierra', 'Frades de la Sierra', 40.6568700, -5.7822300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46768, 'Frades', 'Frades', 'Frades,San Martin,San Martín', 43.0501100, -8.2939100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46769, 'Foz-Calanda', 'Foz-Calanda', 'Foz de Calanda,Foz-Calanda', 40.9220800, -0.2648300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46770, 'Foz', 'Foz', 'Foz', 43.5692000, -7.2544100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46771, 'Forua', 'Forua', 'Forua', 43.3334300, -2.6750400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46772, 'Fortià', 'Fortia', 'Fortia,Fortià', 42.2432000, 3.0388100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46773, 'Fortanete', 'Fortanete', 'Fortanate,Fortanete', 40.5053300, -0.5228300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46774, 'Fórnoles', 'Fornoles', 'Fornoles,Fornols,Fornols del Tossal,Fórnoles,Fórnols,Fórnols del Tossal', 40.8935900, -0.0038300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46775, 'Fornelos de Montes', 'Fornelos de Montes', 'Fornelos de Montes,San Lorenzo', 42.3412600, -8.4529100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46776, 'Fornells de la Selva', 'Fornells de la Selva', '', 41.9315900, 2.8090700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46777, 'Formiche Alto', 'Formiche Alto', 'Formiche Alto', 40.3236700, -0.8924100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46778, 'Forfoleda', 'Forfoleda', 'Forfoleda', 41.0977900, -5.7497900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46779, 'Forès', 'Fores', 'Fores,Forès,Forés', 41.4833300, 1.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46780, 'Forcall', 'Forcall', 'Forcall,Forcallo,Forkal'',fu er ka li,fwrkal,Форкаль,فوركال,福尔卡利', 40.6454200, -0.1999200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46781, 'Fonzaleche', 'Fonzaleche', 'Fonzaleche', 42.5811400, -3.0121800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46782, 'Fonz', 'Fonz', 'Fons,Fonts,feng si,Фонс,丰斯', 42.0101500, 0.2587800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46783, 'Fontiveros', 'Fontiveros', 'Fontiveros,feng di wei luo si,fntybrs,fwntyfyrws,Фонтиверос,Фонтіверос,فنتیبرس,فونتيفيروس,丰蒂韦罗斯', 40.9299700, -4.9644500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46784, 'Fontioso', 'Fontioso', 'Fontioso', 41.9427300, -3.7387200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46785, 'Fontihoyuelo', 'Fontihoyuelo', 'Fontihoyuelo', 42.1619200, -5.0579100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46786, 'Fontellas', 'Fontellas', 'Fontellas', 42.0269400, -1.5764800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46787, 'Fontcoberta', 'Fontcoberta', 'Fontcoberta,Fontcuberta', 42.1333300, 2.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46788, 'Fontanilles', 'Fontanilles', 'Fontanillas,Fontanilles', 42.0111700, 3.1077600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46789, 'Fontanar', 'Fontanar', 'Fontanar', 40.7246600, -3.1730900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46790, 'Fonsagrada', 'Fonsagrada', '', 43.1239800, -7.0679000, 'ES', '2010-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46791, 'Fonollosa', 'Fonollosa', 'Fonollosa', 41.7630300, 1.6686700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46792, 'Fonfría', 'Fonfria', 'Fonfria,Fonfrija,Fonfría,feng fu li ya,Фонфрия,Фонфрія,丰夫里亚', 41.6349300, -6.1408100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46793, 'Fonfría', 'Fonfria', 'Fonfria,Fonfría', 40.9956600, -1.0847500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46794, 'Foncea', 'Foncea', 'Foncea', 42.6152900, -3.0389700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46795, 'Fompedraza', 'Fompedraza', 'Fompedraza', 41.5354100, -4.1448300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46796, 'Fombuena', 'Fombuena', 'Fombuena', 41.1444200, -1.1926600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46797, 'Fombellida', 'Fombellida', 'Fombellida', 41.7669300, -4.1840900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46798, 'Folgoso de la Ribera', 'Folgoso de la Ribera', 'Folgoso de la Ribera', 42.6469300, -6.3203500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46799, 'Foixà', 'Foixa', 'Foixa,Foixà', 42.0362600, 3.0002100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46800, 'Fogars de Montclús', 'Fogars de Montclus', 'Caserio Fogas de Montclus,Caserío Fogas de Montclús,Fogars de Montclus,Fogars de Montclús,Fogas de Monclus,Fogás de Monclús', 41.7333300, 2.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46801, 'Florida de Liébana', 'Florida de Liebana', 'Florida de Liebana,Florida de Liébana', 41.0236100, -5.7625200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46802, 'Flores de Ávila', 'Flores de Avila', 'Flores de Avila,Flores de Ávila', 40.9335800, -5.0791400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46803, 'Flix', 'Flix', 'Flix', 41.2307400, 0.5500800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46804, 'Flaçà', 'Flaca', 'Flaca,Flasa,Flassa,Flassá,Flaçà', 42.0666700, 2.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46805, 'Fitero', 'Fitero', 'Fitero', 42.0577000, -1.8575600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46806, 'Fiscal', 'Fiscal', '', 42.4956100, -0.1209400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46807, 'Fisterra', 'Fisterra', 'Finisterra,Fisterra,Фистерра', 42.9049200, -9.2628900, 'ES', '2011-02-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46808, 'Figueruelas', 'Figueruelas', 'Figueruelas', 41.7665100, -1.1747300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46809, 'Figueruela de Arriba', 'Figueruela de Arriba', 'Figeruehla-de-Arriba,Figeruela-de-Arriba,Figueruela de Arriba,shang fei ge lu ai la,Фигеруэла-де-Арриба,Фігеруела-де-Арріба,上菲格鲁埃拉', 41.8686700, -6.4445400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46810, 'Figueroles', 'Figueroles', 'Figueroles', 40.1166700, -0.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46811, 'Figueras', 'Figueras', 'Figejras,Figueras,Фигейрас', 43.5394300, -7.0255900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46812, 'Figueres', 'Figueres', 'Figeras,Figeres,Figueres,Фигерeс,Фигерас', 42.2664500, 2.9616300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46813, 'Ferreruela de Huerva', 'Ferreruela de Huerva', 'Ferreruela,Ferreruela de Huerva', 41.0632500, -1.2335000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46814, 'Ferreruela', 'Ferreruela', 'Ferreruela', 41.7667300, -6.0721500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46815, 'Ferreras de Arriba', 'Ferreras de Arriba', 'Ferreras de Arriba', 41.8987800, -6.1946100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46816, 'Ferreras de Abajo', 'Ferreras de Abajo', 'Ferreras de Abajo', 41.8965100, -6.0790400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46817, 'Fermoselle', 'Fermoselle', 'Fermosel''e,Fermoselle,fei er mo sai lie,Фермоселье,Фермосельє,费尔莫塞列', 41.3173800, -6.3958400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46818, 'Fene', 'Fene', 'Fene,San Salvador', 43.4500000, -8.1500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46819, 'Fayón', 'Fayon', 'Faio,Faio / Fayon,Faió,Faió / Fayón,Fayon,Fayón', 41.2385100, 0.3330200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46820, 'la Fatarella', 'la Fatarella', 'Fatarella,la Fatarella', 41.1666700, 0.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46821, 'Farrera', 'Farrera', 'Farrera', 42.4965400, 1.2721600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46822, 'Farlete', 'Farlete', 'Farlete', 41.6812200, -0.5067800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46823, 'Fariza', 'Fariza', 'Farisa,Fariza,Fariza de Sayago,fa li sa,Фариса,Фаріса,法里萨', 41.4166700, -6.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46824, 'Faramontanos de Tábara', 'Faramontanos de Tabara', 'Faramontanos de Tabara,Faramontanos de Tábara', 41.8346900, -5.8888300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46825, 'Fanzara', 'Fanzara', 'Fanzara', 40.0166700, -0.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46826, 'Falset', 'Falset', 'Falset', 41.1457600, 0.8197900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46827, 'Falces', 'Falces', 'Falces', 42.3896600, -1.7932100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46828, 'Fago', 'Fago', '', 42.7344000, -0.8813100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46829, 'Fabero', 'Fabero', 'Fabero', 42.7680300, -6.6265100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46830, 'Fabara', 'Fabara', 'Fabara,Favara de Matarranya', 41.1775000, 0.1690800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46831, 'Ezkurra', 'Ezkurra', 'Ezcurra,Ezkurra', 43.0833300, -1.8166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46832, 'Ezcaray', 'Ezcaray', 'Ehskaraj,Eskaraj,Eskaray,Ezcaray,Ezkarai,ai si ka lai,Ескарай,Эскарай,Էսկարայ,埃斯卡赖', 42.3253600, -3.0130900, 'ES', '2012-12-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46833, 'Eulate', 'Eulate', 'Eulace,Eulate', 42.7764100, -2.2063800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46834, 'Etayo', 'Etayo', 'Etayo', 42.6169500, -2.1544700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46835, 'Estriégana', 'Estriegana', 'Estriegana,Estriégana', 41.0582100, -2.5236300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46836, 'Estremera', 'Estremera', '', 40.1833300, -3.1000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46837, 'Estollo', 'Estollo', 'Estollo', 42.3295300, -2.8509200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46838, 'Estercuel', 'Estercuel', 'Estercuel', 40.8550000, -0.6320800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46839, 'Estépar', 'Estepar', '', 42.2773100, -3.8994600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46840, 'Estepa de San Juan', 'Estepa de San Juan', 'Estepa de San Juan', 41.9266100, -2.3332200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46841, 'Estella-Lizarra', 'Estella-Lizarra', 'Ehstel''ja,Estel''ja,Estela,Estella,Estella - Lizarra,Estella-Lizarra,Lizarra,Stella,ai si te li ya,esuterya,Естела,Естелья,Эстелья,エステーリャ,埃斯特利亚', 42.6718200, -2.0322600, 'ES', '2015-05-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46842, 'l''Estartit', 'l''Estartit', 'Estartit', 42.0534000, 3.1976700, 'ES', '2016-10-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46843, 'Estadilla', 'Estadilla', 'Estadella,Estadilla', 42.0565700, 0.2434300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46844, 'Estada', 'Estada', 'Estada', 42.0720100, 0.2321900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46845, 'Establés', 'Estables', 'Estables,Establés', 41.0076700, -2.0243800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46846, 'Esquivias', 'Esquivias', '', 40.1044000, -3.7667700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46847, 'Espronceda', 'Espronceda', '', 42.5970700, -2.3052400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46848, 'Espot', 'Espot', 'Espot', 42.5783800, 1.0866600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46849, 'Esponellà', 'Esponella', 'Esponella,Esponellà,Esponellá', 42.1666700, 2.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46850, 'Espolla', 'Espolla', 'Espolla', 42.3912000, 3.0006400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46851, 'Esplús', 'Esplus', 'Esplucs,Esplus,Esplús', 41.7987000, 0.2758600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46852, 'Esplugues de Llobregat', 'Esplugues de Llobregat', 'Esplugues de Llobregat', 41.3773200, 2.0880900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46853, 'Esplegares', 'Esplegares', 'Esplegares', 40.8565000, -2.3708400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46854, 'Espirdo', 'Espirdo', 'Espira Otero,Espirdo', 40.9976400, -4.0733100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46855, 'Espinosa de Villagonzalo', 'Espinosa de Villagonzalo', 'Espinosa de Villagonzalo', 42.4794900, -4.3721800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46856, 'Espinosa de los Monteros', 'Espinosa de los Monteros', 'Ehspinosa-de-los-Monteros,Espinosa-de-los-Monteros,ai si pi nuo sa de luo si meng te luo si,asbaynwza dy lws mwntyrws,Еспіноса-де-лос-Монтерос,Эспиноса-де-лос-Монтерос,إسباينوزا دي لوس مونتيروس,埃斯皮诺萨德洛斯蒙特罗斯', 43.0775400, -3.5536500, 'ES', '2008-07-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46857, 'Espinosa del Camino', 'Espinosa del Camino', 'Espinosa del Camino', 42.4059000, -3.2801900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46858, 'Espinosa de Henares', 'Espinosa de Henares', 'Espinosa de Henares', 40.9005300, -3.0695600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46859, 'Espinosa de Cervera', 'Espinosa de Cervera', 'Espinosa de Cervera', 41.8968300, -3.4685800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46860, 'Espinosa de Cerrato', 'Espinosa de Cerrato', 'Espinosa de Cerrato', 41.9667900, -3.9534600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46861, 'Espino de la Orbada', 'Espino de la Orbada', 'Espino de la Orbada', 41.1069300, -5.4251500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46862, 'Espejón', 'Espejon', 'Ehspekhon,Espejon,Espejón,Espekhon,ai si pei hong,Еспехон,Эспехон,埃斯佩洪', 41.8302300, -3.2593600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46863, 'Espeja de San Marcelino', 'Espeja de San Marcelino', 'Ehspekha-de-San-Marselino,Espeja,Espeja de San Marcelino,Espekha-de-San-Marselino,ai si pei ha de sheng ma er sai li nuo,Еспеха-де-Сан-Марселіно,Эспеха-де-Сан-Марселино,埃斯佩哈德圣马尔塞利诺', 41.8022700, -3.2223000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46864, 'Espeja', 'Espeja', 'Espeja', 40.5656500, -6.7158200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46865, 'Esparreguera', 'Esparreguera', 'Esparraguera,Esparreguera', 41.5380900, 1.8702500, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46866, 'Espadilla', 'Espadilla', 'Espadella,Espadilla', 40.0333300, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46867, 'Espadañedo', 'Espadanedo', 'Espadanedo,Espadañedo', 42.1161800, -6.3941900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46868, 'Espadaña', 'Espadana', 'Espadana,Espadaña', 41.0608500, -6.2845700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46869, 'Eslava', 'Eslava', '', 42.5645900, -1.4594700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46870, 'Esguevillas de Esgueva', 'Esguevillas de Esgueva', 'Esguevillas de Esgueva', 41.7501800, -4.3806200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46871, 'Esgos', 'Esgos', '', 42.3254900, -7.6969100, 'ES', '2007-02-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46872, 'Escurial de la Sierra', 'Escurial de la Sierra', 'Escurial,Escurial de la Sierra', 40.6173100, -5.9552000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46873, 'Escucha', 'Escucha', 'Escucha', 40.7946700, -0.8101200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46874, 'Escorihuela', 'Escorihuela', 'Escorihuela', 40.5440000, -0.9707800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46875, 'Eskoriatza', 'Eskoriatza', 'Ehskoriasa,Escoriaza,Eskoriatza,Эскориаса', 43.0182900, -2.5259800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46876, 'Escopete', 'Escopete', 'Escopete', 40.4132400, -3.0046000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46877, 'Escobosa de Almazán', 'Escobosa de Almazan', 'Escobosa,Escobosa de Almazan,Escobosa de Almazán', 41.4862600, -2.3714000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46878, 'Escobar de Polendos', 'Escobar de Polendos', 'Escobar,Escobar de Polendos', 41.0907900, -4.1311700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46879, 'Escobar de Campos', 'Escobar de Campos', 'Escobar', 42.3133700, -4.9657300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46880, 'Escatrón', 'Escatron', 'Escatron,Escatrón', 41.2914900, -0.3230800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46881, 'Escariche', 'Escariche', 'Escariche', 40.4055300, -3.0531000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46882, 'Escarabajosa de Cabezas', 'Escarabajosa de Cabezas', 'Escarabajosa de Cabezas', 41.1047000, -4.1941100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46883, 'Escamilla', 'Escamilla', 'Escamilla', 40.5497900, -2.5629200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46884, 'Escalona del Prado', 'Escalona del Prado', 'Escalona,Escalona del Prado', 41.1668200, -4.1227200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46885, 'Escalona', 'Escalona', 'Escalona,Escalona del Alberche', 40.1669000, -4.4048400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46886, 'Escalante', 'Escalante', 'Escalante', 43.4367800, -3.5134700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46887, 'Ermua', 'Ermua', 'Ehrmua,Ermua,ai er mu a,ayrmwa,Ермуа,Эрмуа,إيرموا,埃尔穆阿', 43.1872500, -2.5026100, 'ES', '2015-05-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46888, 'Erla', 'Erla', 'Erla', 42.1173200, -0.9501900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46889, 'Eratsun', 'Eratsun', 'Erasun,Eratsun', 43.0833300, -1.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46890, 'Erandio', 'Erandio', 'Ehrandio,Erandio,ai lan di ao,ayrandayw,erandio,Ерандіо,Эрандио,إيراندايو,エランディオ,埃兰迪奥', 43.3043800, -2.9735200, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46891, 'Épila', 'Epila', 'Ehpila,Epila,abyla,ai pi la,Épila,Епіла,Эпила,إبيلا,埃皮拉', 41.6004500, -1.2800700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46892, 'Entrimo', 'Entrimo', 'Entrimo,Santa Maria la Real,Santa María la Real', 41.9329700, -8.1172500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46893, 'Entrena', 'Entrena', 'Atiliana,Ehntrena,Entrena,antrna,en te lai na,en te lei na,enteulena,entorena,Ентрена,Энтрена,Էնտրենա,אנטרנה,إنترنا,انترنا,ኤንትረና,ᐫᑦᕂᓇ,エントレナ,恩特萊納,恩特雷纳,엔트레나', 42.3878200, -2.5306600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46894, 'Entrambasaguas', 'Entrambasaguas', 'Entrambasaguas', 43.3784600, -3.6807200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46895, 'Entrala', 'Entrala', 'Entrala', 41.4300600, -5.7555600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46896, 'Enériz', 'Eneriz', '', 42.6709500, -1.7279400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46897, 'Endrinal', 'Endrinal', 'Endrinal', 40.5910900, -5.8041100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46898, 'Enciso', 'Enciso', 'Ehnsiso,Enciso,Ensiso,en xi suo,Енсісо,Энсисо,Էնսիսո,恩西索', 42.1494600, -2.2695300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46899, 'Encío', 'Encio', 'Encio,Encío', 42.6711500, -3.0868000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46900, 'Encinillas', 'Encinillas', 'Encinilla,Encinillas', 41.0180900, -4.1578400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46901, 'Encinedo', 'Encinedo', 'Encinedo', 42.2704900, -6.5936800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46902, 'Encinasola de los Comendadores', 'Encinasola de los Comendadores', 'Encinasola de los Comendadores', 41.0308900, -6.5326100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46903, 'Encinas de Esgueva', 'Encinas de Esgueva', 'Encinas de Esgueva', 41.7565300, -4.1035700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46904, 'Encinas de Arriba', 'Encinas de Arriba', 'Encinas de Arriba', 40.7712000, -5.5566100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46905, 'Encinas de Abajo', 'Encinas de Abajo', 'Encinas de Abajo', 40.9349300, -5.4703700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46906, 'Encinas', 'Encinas', 'Encinas', 41.3751100, -3.6676200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46907, 'Encina de San Silvestre', 'Encina de San Silvestre', 'Encina de San Silvestre', 41.0144200, -6.0926800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46908, 'Encinacorba', 'Encinacorba', 'Encinacorba', 41.2851600, -1.2751600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46909, 'Embid de Ariza', 'Embid de Ariza', 'Embid de Ariza', 41.3783000, -1.9737300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46910, 'Embid', 'Embid', 'Embid', 40.9725600, -1.7120600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46911, 'El Viso de San Juan', 'El Viso de San Juan', 'El Viso de San Juan', 40.1415400, -3.9181700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46912, 'El Vellón', 'El Vellon', 'El Vellon,El Vellón', 40.7649500, -3.5796900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46913, 'El Tiemblo', 'El Tiemblo', 'Ehl''-T''emblo,El Tiembio,El''-T''emblo,ai er di en fu luo,al tymblw,Ел Тиембио,Ель-Тьємбло,Эль-Тьембло,إل تيمبلو,ال تیمبلو,埃尔蒂恩夫洛', 40.4153300, -4.5015600, 'ES', '2008-10-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46914, 'El Real de San Vicente', 'El Real de San Vicente', 'El Real de San Vicente,Real de San Vicente', 40.1356100, -4.6909500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46915, 'El Prat de Llobregat', 'El Prat de Llobregat', 'Al-Prat-da-Ljubragat,Ehl'' Prat,Ehl''-Prat-de-L''obregat,El Prat de Llobregat,Prat de LJobregat,Prat de Llobregat,Prat del Llobregat,ai er pu la te de e fu lei jia te,al bart dy ywbryghat,el Prat,el Prat de Llobregat,Ал-Прат-да-Любрагат,Прат де Љобрегат,Эль Прат,Эль-Прат-де-Льобрегат,إل بارت دي يوبريغات,アル・プラ・ダ・リョブレガート,埃尔普拉特德略夫雷加特', 41.3278400, 2.0947200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46916, 'El Pardo', 'El Pardo', 'Ehl''-Pardo,El Pardo,Эль-Пардо', 40.5145400, -3.7725300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46917, 'Elorz', 'Elorz', '', 42.7325800, -1.5615200, 'ES', '2008-07-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46918, 'Elorrio', 'Elorrio', 'Elorrio', 43.1292400, -2.5405600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46919, 'El Molar', 'El Molar', 'Ehl''-Molar,El Molar,El''-Molar,almwlar,Ель-Молар,Эль-Молар,Էլ Մոլար,ألمولار', 40.7321500, -3.5796900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46920, 'Éller', 'Eller', '', 42.4163600, 1.7922300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46921, 'Eljas', 'Eljas', 'As Ellas,Ehl''khas,El''khas,Elijas,Eljas,ai er ha si,alkhas,Ельхас,Эльхас,إلخاس,埃尔哈斯', 40.2164800, -6.8461600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46922, 'El Hoyo de Pinares', 'El Hoyo de Pinares', 'El Hoyo de Pinares,Hoyo de Pinares', 40.5008400, -4.4235700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46923, 'Gurb', 'Gurb', 'Gurb', 41.9541900, 2.2353700, 'ES', '2010-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46924, 'Elgeta', 'Elgeta', 'Elgeta,Elgueta', 43.1370300, -2.4886200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46925, 'Empuriabrava', 'Empuriabrava', 'Ehmpuriabrava,Empuriabrava,Эмпуриабрава', 42.2469100, 3.1205900, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46926, 'Elgorriaga', 'Elgorriaga', 'Elgorriaga', 43.1385800, -1.6865700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46927, 'Elgoibar', 'Elgoibar', 'Elgoibar,Elgóibar', 43.2160100, -2.4133400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46928, 'El Franco', 'El Franco', 'Ehl''-Franko,El Franco,El''-Franko,ai er fu lan ke,al frankw,Ель-Франко,Эль-Франко,إل فرانكو,ال فرانکو,埃尔夫兰科', 43.5552200, -6.8662000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46929, 'Figaró', 'Figaro', 'El Figaro,El Figaró,Figaro,Figaró,el Figuero,el Figueró', 41.7212200, 2.2729700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46930, 'Ferrol', 'Ferrol', 'El Ferrol,Ferrol', 43.4896100, -8.2194000, 'ES', '2017-05-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46931, 'El Escorial', 'El Escorial', 'Ehl''-Ehskorial'',El Eskorial,El''-Eskorial'',Escorial,Gorad Ehl''-Ehskaryjal'',L''Escurial,ai er ai si ke li ya er,al askwryal,alyskwryal,el-eseukolial,Ελ Εσκοριάλ,Горад Эль-Эскарыяль,Ель-Ескоріаль,Эль-Эскориаль,Էլ Էսկորիալ,إليسكوريال,ال اسکوریال,エル・エスコリアル,埃尔埃斯科里亚尔,엘에스코리알', 40.5825400, -4.1284600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46932, 'Elduain', 'Elduayen', 'Elduain,Elduayen', 43.1401700, -2.0010200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46933, 'Zalla', 'El Corrillo', 'El Corrillo,Sal''ja,Zalla,sa li ya,zala,Салья,زالا,萨利亚', 43.2333300, -3.1333300, 'ES', '2012-04-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46934, 'Elciego', 'Elciego', 'Elciego,Eltziego', 42.5156900, -2.6189700, 'ES', '2012-11-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46935, 'El Castellar', 'El Castellar', 'El Castellar', 40.3653100, -0.8173400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46936, 'El Casar de Escalona', 'El Casar de Escalona', 'El Casar de Escalona', 40.0464000, -4.5250700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46937, 'El Burgo de Osma', 'El Burgo de Osma', 'Burgo de Osma,El Burgo de Osma', 41.5861900, -3.0652200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46938, 'El Burgo de Ebro', 'El Burgo de Ebro', 'El Burgo de Ebro,El Burgos de Ebro', 41.5715700, -0.7412800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46939, 'O Barco de Valdeorras', 'O Barco de Valdeorras', 'O Barco,Valdeorras', 42.4164200, -6.9900500, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46940, 'El Barco de Ávila', 'El Barco de Avila', 'Barco de Avila,Ehl''-Barko-de-Avila,El Barco dAvila,El Barco de Avila,El Barco de Avile,El Barco de Ávila,El Barco de Ávile,El Barco dÁvila,El Brako de Avila,El''-Barko-de-Avila,ai er wa er ke de ya wei la,al barkw d abyla,al barkw dy afyla,Ел Брако де Авила,Ель-Барко-де-Авіла,Эль-Барко-де-Авила,إل باركو دي أفيلا,ال بارکو د آبیلا,埃尔瓦尔科德亚维拉', 40.3571000, -5.5236500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46941, 'El Astillero', 'El Astillero', 'Astillero,Ehl''-Astil''ero,El Astillero,El''-Astil''ero,ai la si di lie luo,al astyrylw,Ель-Астільєро,Эль-Астильеро,إل أستيريلو,埃拉斯蒂列罗', 43.4009400, -3.8205100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46942, 'el Raval', 'el Raval', 'Barrio el Raval,Raval,The Raval,el Raval', 41.3804200, 2.1686000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46943, 'Elantxobe', 'Elantxobe', 'Elanchove,Elantxobe', 43.4024300, -2.6391200, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46944, 'El Álamo', 'El Alamo', 'El Alamo,El Álamo', 40.2306600, -3.9944700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46945, 'Ejulve', 'Ejulve', 'Ejulve', 40.7763300, -0.5534400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46946, 'Ejeme', 'Ejeme', 'Ejeme', 40.7668500, -5.5382800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46947, 'Ejea de los Caballeros', 'Ejea de los Caballeros', 'Egea de los Caballeros,Ehkhea-de-los-Kabal''eros,Eixea,Ejea,Ejea de los Caballeros,Ekhea-de-los-Kabal''eros,Exea,Exeya dos Caballers,Exeya dos Cavallers,ai he ya de luo si ka wa lie luo si,aykhya dy lws kabayyrws,Ехеа-де-лос-Кабальєрос,Эхеа-де-лос-Кабальерос,إيخيا دي لوس كاباييروس,埃赫亚德洛斯卡瓦列罗斯', 42.1263200, -1.1371600, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46948, 'Eibar', 'Eibar', 'Ehibar,Ehjbar,Eibar,Eybar,Heivar,Heybar,Villanueva de San Andres,Villanueva de San Andres de Heybar,Villanueva de San Andrés,Villanueva de San Andrés de Heybar,Éibar,Эйбар', 43.1849300, -2.4715800, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46949, 'Echarri-Aranaz', 'Echarri-Aranaz', 'Echarri-Aranaz,Etxarri-Aranatz', 42.9079100, -2.0647400, 'ES', '2006-03-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46950, 'Echarri', 'Echarri', 'Echarri', 42.7801700, -1.8252500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46951, 'Etxalar', 'Etxalar', 'Echalar,Etxalar', 43.2337600, -1.6367100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46952, 'Ea', 'Ea', 'Ea', 43.3798500, -2.5855600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46953, 'Duruelo de la Sierra', 'Duruelo de la Sierra', 'Duruehlo-de-la-S''erra,Duruelo,Duruelo de la Sierra,Duruelo-de-la-S''erra,du lu ai luo de la xie la,Дуруело-де-ла-Сьєрра,Дуруэло-де-ла-Сьерра,杜鲁埃洛德拉谢拉', 41.9544800, -2.9308600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46954, 'Duruelo', 'Duruelo', 'Duruelo', 41.2362200, -3.6491400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46955, 'Durón', 'Duron', 'Duron,Durón', 40.6253000, -2.7266200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46956, 'Durango', 'Durango', 'Durango,Tavira,Дуранго', 43.1712400, -2.6338000, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46957, 'Dumbría', 'Dumbria', 'Dumbria,Dumbría,Santa Eulalia', 43.0083600, -9.1132800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46958, 'Dueñas', 'Duenas', 'Duehn''jas,Duen''jas,Duenias,du ai ni ya si,Дуеньяс,Дуэньяс,Դուենիաս,杜埃尼亚斯', 41.8771700, -4.5471400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46959, 'Driebes', 'Driebes', '', 40.2449800, -3.0416500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46960, 'Dozón', 'Dozon', 'Dozon,Dozón', 42.5833300, -8.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46961, 'Dosrius', 'Dosrius', 'Dosrius,Dosríus,dsryws,duo si liu si,dwsrayws,دسریوس,دوسرايوس,多斯留斯', 41.5833300, 2.4166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46962, 'Duesaigües', 'Duesaiguees', 'Dosaiguas,Dosaiqua,Duesaiguees,Duesaigües', 41.1500000, 0.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46963, 'Donvidas', 'Donvidas', 'Donvidas', 41.0895400, -4.8063400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46964, 'Donjimeno', 'Donjimeno', 'Donjimeno', 40.9597800, -4.8462700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46965, 'Doñinos de Salamanca', 'Doninos de Salamanca', 'Doninos de Salamanca,Doñinos de Salamanca', 40.9597800, -5.7434900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46966, 'Doñinos de Ledesma', 'Doninos de Ledesma', 'Doninos de Ledesma,Doñinos de Ledesma', 41.0125100, -6.0341200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46967, 'Donhierro', 'Donhierro', 'Donhierro', 41.1164200, -4.6967000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46968, 'Domingo García', 'Domingo Garcia', 'Domingo Garcia,Domingo García', 41.1152800, -4.3792700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46969, 'Dios le Guarde', 'Dios le Guarde', 'Dios le Guarde', 40.6428300, -6.3151100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46970, 'Dicastillo', 'Dicastillo', 'Dicastillo', 42.5964700, -2.0266600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46971, 'Deza', 'Deza', 'Desa,Deza,de sa,Деса,德萨', 41.4637300, -2.0204600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46972, 'Deba', 'Deba', 'Deba,Deva,de wa,dyfa  ghybwthkwa,Деба,Дева,ديفا، غيبوثكوا,德瓦', 43.2957100, -2.3521300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46973, 'Destriana', 'Destriana', 'Destriana', 42.3272900, -6.0957300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46974, 'Desojo', 'Desojo', 'Desojo', 42.5879000, -2.2743800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46975, 'Descargamaría', 'Descargamaria', 'Descargamaria,Descargamaría', 40.3044600, -6.4866600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46976, 'Derio', 'Derio', '', 43.3054400, -2.8811600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46977, 'Dehesa de Romanos', 'Dehesa de Romanos', 'Dehesa de Romanos', 42.6387600, -4.4351800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46978, 'Dehesa de Montejo', 'Dehesa de Montejo', '', 42.8193900, -4.5101900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46979, 'Degaña', 'Degana', 'Degan''ja,Degana,Deganija,Degaña,de jia ni ya,dganya,dyghanya,Дегания,Деганья,ديغانيا,دگانیا,德加尼亚', 42.9396900, -6.5693500, 'ES', '2013-08-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46980, 'Das', 'Das', '', 42.3614300, 1.8705100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46981, 'Daroca', 'Daroca', 'Daroca', 41.1147500, -1.4149200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46982, 'Darnius', 'Darnius', 'Darnius', 42.3666700, 2.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46983, 'Daganzo de Arriba', 'Daganzo de Arriba', 'Daganzo de Arriba', 40.5429300, -3.4545700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46984, 'Cuzcurrita de Río Tirón', 'Cuzcurrita de Rio Tiron', 'Cuzcurrita-Rio Tiron,Cuzcurrita-Río Tirón', 42.5415100, -2.9642100, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46985, 'Curtis', 'Curtis', 'Curtis,Santa Eulalia', 43.1166700, -8.0500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46986, 'Curtis', 'Curtis', 'Curtis,San Vicente', 43.0833300, -8.0666700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46987, 'Curiel de Duero', 'Curiel de Duero', 'Curiel,Curiel de Duero', 41.6432700, -4.1011000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46988, 'Cuntis', 'Cuntis', 'Bano,Baño', 42.6339600, -8.5625600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46989, 'Cunit', 'Cunit', 'Kunit,ku ni te,kwnyt,Кунит,Куніт,كونيت,库尼特', 41.1982900, 1.6364500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46990, 'Culleredo', 'Culleredo', 'Culleredo,Kul''eredo,Kuleredo,San Esteban,ku lie lei duo,kujeredo,kwlyrydw,Кулередо,Кульередо,Кульєредо,كوليريدو,クジェレード,库列雷多', 43.2878800, -8.3885800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46991, 'Culla', 'Culla', 'Cuellar,Culla,Cuéllar,Kul''ja,ku li ya,kwlla,Кулья,كوللا,库利亚', 40.3365000, -0.1656900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46992, 'Cuevas Labradas', 'Cuevas Labradas', 'Cuevas Labradas', 40.4535000, -1.0500800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46993, 'Cuevas de Vinromá', 'Cuevas de Vinroma', 'Cuevas de Vinroma,Cuevas de Vinromá,Les Coves de Vinroma', 40.3097600, 0.1208400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46994, 'Cuevas de San Clemente', 'Cuevas de San Clemente', 'Cuevas de San Clemente', 42.1300900, -3.5684000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46995, 'Cuevas de Provanco', 'Cuevas de Provanco', 'Cuevas de Provanco', 41.5420900, -3.9620300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46996, 'Cuevas del Valle', 'Cuevas del Valle', 'Cuevas del Valle', 40.2941800, -5.0093800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46997, 'Cuevas de Almudén', 'Cuevas de Almuden', 'Cuevas de Almuden,Cuevas de Almudén', 40.7134200, -0.8295800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46998, 'Cueva del Hierro', 'Cueva del Hierro', 'Cueva del Hierro', 40.5825800, -2.0361200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(46999, 'Cueva de Ágreda', 'Cueva de Agreda', 'Cueva de Agreda,Cueva de Ágreda', 41.7631000, -1.8881800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47000, 'Cuenca de Campos', 'Cuenca de Campos', 'Cuenca,Cuenca de Campos', 42.0592700, -5.0553900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47001, 'Cuenca', 'Cuenca', 'CEJ,Conca,Cuenca,Cuenca i Spania,Gorad Kuehnka,Kouen''ka,Kuehnka,Kuenka,Kvenko,ke wng ka,ku''ainaka,ku''ainka,kuengka,kuenka,kun ka,kwynka,qwnkt,Κουένκα,Горад Куэнка,Куенка,Куэнка,Կուենկա,קואנקה,قونكة,کوئنکا,کوینکا، ہسپانیہ,कुऐनका,ਕੁਐਂਕਾ,เกวงกา,კუენკა,クエンカ,昆卡,쿠엥카', 40.0666700, -2.1333300, 'ES', '2012-12-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47002, 'Cuéllar', 'Cuellar', 'Cuellar,Cuéllar,Kuehl''jar,Kuel''jar,ku ai li ya er,kueryaru,Куельяр,Куэльяр,クエリャル,库埃利亚尔', 41.4015500, -4.3147400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47003, 'Cuelgamures', 'Cuelgamures', 'Cuelgamures', 41.3073800, -5.6576900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47004, 'Cudillero', 'Cudillero', 'Cudillero,Cuideiru,Kudil''ero,ku di lie luo,kwdyyrw,Кудильеро,Кудільєро,كودييرو,کودییرو,库迪列罗', 43.5621700, -6.1458900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47005, 'Cucalón', 'Cucalon', 'Cucalon,Cucalón', 41.0860800, -1.2147500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47006, 'Cubo de la Solana', 'Cubo de la Solana', 'Cubo de la Solana,Kubo-de-la-Solana,ku wo de la suo la na,Кубо-де-ла-Солана,库沃德拉索拉纳', 41.6022400, -2.4217900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47007, 'Cubo de Bureba', 'Cubo de Bureba', 'Cubo,Cubo de Bureba', 42.6401100, -3.2062600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47008, 'Cubo de Benavente', 'Cubo de Benavente', 'Cubo de Benavente', 42.1249000, -6.1634200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47009, 'Cubla', 'Cubla', 'Cubla', 40.2097800, -1.0791700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47010, 'Cubillos del Sil', 'Cubillos del Sil', 'Cubillos del Sil', 42.6251900, -6.5636000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47011, 'Cubillos', 'Cubillos', 'Cubillos', 41.5743600, -5.7392000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47012, 'Cubillo del Campo', 'Cubillo del Campo', 'Cubillo del Campo', 42.1685400, -3.6102500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47013, 'Cubillo', 'Cubillo', 'Cubillo', 41.1213800, -3.9087800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47014, 'Cubillas de Santa Marta', 'Cubillas de Santa Marta', 'Cubillas de Santa Marta', 41.8335800, -4.6146300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47015, 'Cubillas de Rueda', 'Cubillas de Rueda', 'Cubillas de Rueda', 42.6562600, -5.1752800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47016, 'Cubillas de los Oteros', 'Cubillas de los Oteros', 'Cubillas de los Oteros', 42.3719900, -5.5087700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47017, 'Cubillas de Cerrato', 'Cubillas de Cerrato', 'Cubillas de Cerrato', 41.7984400, -4.4672000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47018, 'Cubilla', 'Cubilla', 'Cubilla', 41.7490500, -2.9371700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47019, 'Cubells', 'Cubells', 'Cubells', 41.8506200, 0.9590000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47020, 'Cubelles', 'Cubelles', 'Cubelles', 41.2077200, 1.6726700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47021, 'Cubel', 'Cubel', 'Cubel', 41.0960400, -1.6372900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47022, 'Cubas', 'Cubas', 'Cubas', 40.1890000, -3.8352600, 'ES', '2012-02-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47023, 'Cuarte de Huerva', 'Cuarte de Huerva', 'Cuarte de Huerva', 41.5946600, -0.9326800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47024, 'Cualedro', 'Cualedro', '', 41.9889700, -7.5946400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47025, 'Cuadros', 'Cuadros', 'Cuadros', 42.7116300, -5.6382800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47026, 'Cruïlles', 'Cruilles', '', 41.9500000, 3.0166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47027, 'Crivillén', 'Crivillen', 'Crivillen,Crivillén', 40.8832500, -0.5766600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47028, 'Cristóbal', 'Cristobal', '', 40.4692300, -5.8896700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47029, 'Crespos', 'Crespos', 'Crespos', 40.8712800, -4.9709400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47030, 'Crespià', 'Crespia', 'Crespia,Crespià,Crespiá', 42.1833300, 2.8000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47031, 'Crémenes', 'Cremenes', 'Cremenes,Crémenes', 42.9035700, -5.1437400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47032, 'Creixell', 'Creixell', 'Creixell', 41.1661800, 1.4403200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47033, 'Cozuelos de Fuentidueña', 'Cozuelos de Fuentiduena', 'Cozuelos,Cozuelos de Fuentiduena,Cozuelos de Fuentidueña', 41.3908600, -4.0956400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47034, 'Covelo', 'Covelo', '', 42.2333300, -8.3500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47035, 'Covarrubias', 'Covarrubias', 'Covarrubias', 42.0592700, -3.5195600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47036, 'Covaleda', 'Covaleda', 'Covaleda,Dovaleda,Kovaleda,ke wa lai da,Коваледа,科瓦莱达', 41.9349300, -2.8832500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47037, 'Cosuenda', 'Cosuenda', 'Cosuenda', 41.3655900, -1.2986700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47038, 'Costur', 'Costur', 'Costur', 40.1197100, -0.1738500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47039, 'Coslada', 'Coslada', 'Coslada,Coslata,Koslada,Koslado,ke si la da,kosurada,kwslada,Кослада,كوسلادا,コスラーダ,科斯拉达', 40.4237800, -3.5612900, 'ES', '2015-09-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47040, 'Coscurita', 'Coscurita', 'Coscurita,Koskurita,ke si ku li ta,Коскурита,Коскуріта,科斯库里塔', 41.4348300, -2.4757100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47041, 'Cosa', 'Cosa', 'Cosa', 40.8339200, -1.1365000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47042, 'Coruña del Conde', 'Coruna del Conde', 'Cluna,Clunia,Cluña,Coruna,Coruna del Conde,Coruña,Coruña del Conde,Cruna,Crunna,Crunnia,Cruña,Curuna,Curuña', 41.7656600, -3.3905900, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47043, 'Corullón', 'Corullon', 'Corullon,Corullón', 42.5789600, -6.8192500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47044, 'Kortezubi', 'Kortezubi', 'Cortezubi,Cortézubi,Kortezubi', 43.3333300, -2.6500000, 'ES', '2012-11-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47045, 'Cortes de Arenoso', 'Cortes de Arenoso', 'Cortes d''Arenos,Cortes de Arenoso', 40.1881200, -0.5419500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47046, 'Cortes de Aragón', 'Cortes de Aragon', 'Cortes de Aragon,Cortes de Aragón', 40.9736600, -0.8357500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47047, 'Cortes', 'Cortes', 'Cortes', 41.9226900, -1.4204500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47048, 'Cortegada', 'Cortegada', 'Cortegada', 42.2098300, -8.1682000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47049, 'Corçà', 'Corca', 'Corca,Corsa,Corsá,Corçà', 41.9833300, 3.0166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47050, 'Corrales de Duero', 'Corrales de Duero', 'Corrales de Duero', 41.6720500, -4.0481700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47051, 'Corrales', 'Corrales', 'Corrales', 41.3580000, -5.7247900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47052, 'Corral de Ayllón', 'Corral de Ayllon', 'Corral de Ayllon,Corral de Ayllón', 41.3908100, -3.4585600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47053, 'Corporales', 'Corporales', 'Corporales', 42.4320800, -2.9953500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47054, 'Corpa', 'Corpa', 'Corpa', 40.4232700, -3.2600300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47055, 'Cornellà del Terri', 'Cornella del Terri', 'Cornella de Terri', 42.0833300, 2.8166700, 'ES', '2011-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47056, 'Cornellà de Llobregat', 'Cornella de Llobregat', 'Cornella de Llobregat,Cornellà de Llobregat', 41.3500000, 2.0833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47057, 'Cornago', 'Cornago', 'Cornago,Kornago,ke er na ge,Корнаго,Կորնագո,科尔纳戈', 42.0644400, -2.0948600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47058, 'Coristanco', 'Coristanco', 'Coristanco,San Pelayo', 43.2000000, -8.7500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47059, 'Corgo', 'Corgo', 'Corgo', 42.9443400, -7.4314000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47060, 'Coreses', 'Coreses', 'Coreses', 41.5479400, -5.6225200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47061, 'Corera', 'Corera', 'Corera', 42.3434400, -2.2202300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47062, 'Corella', 'Corella', 'Corella,Corello,Korel''ja,ke lei li ya,Корелья,科雷利亚', 42.1150700, -1.7856300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47063, 'Corduente', 'Corduente', 'Corduente', 40.8430400, -1.9784100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47064, 'Cordovín', 'Cordovin', 'Cordovin,Cordovín', 42.3855700, -2.8150000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47065, 'Cordovilla la Real', 'Cordovilla la Real', 'Cordovilla la Real', 42.0796100, -4.2598800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47066, 'Cordovilla', 'Cordovilla', 'Cordovilla', 40.9509500, -5.4072500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47067, 'Corcubión', 'Corcubion', 'Corcubion,Corcubión', 42.9441400, -9.1926000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47068, 'Corcos', 'Corcos', '', 41.8094600, -4.6927000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47069, 'Corbins', 'Corbins', '', 41.6833300, 0.7000000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47070, 'Corbillos de los Oteros', 'Corbillos de los Oteros', 'Corbillos de los Oteros', 42.4076900, -5.4596300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47071, 'Corbera de Llobregat', 'Corbera de Llobregat', 'Corbera,Corbera Baja,Corbera de Llobregat,Corbera del Llobregat', 41.4170200, 1.9197000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47072, 'Corbalán', 'Corbalan', 'Corbalan,Corbalán', 40.4030800, -0.9852500, 'ES', '2015-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47073, 'Copernal', 'Copernal', 'Copernal', 40.8646300, -3.0539600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47074, 'Coomonte', 'Coomonte', 'Coomonte', 42.1154600, -5.8131600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47075, 'Contreras', 'Contreras', 'Contreras', 42.0200400, -3.4108400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47076, 'Contamina', 'Contamina', 'Contamina', 41.3053500, -1.9173100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47077, 'Constanzana', 'Constanzana', 'Constanzana', 40.9382100, -4.8751500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47078, 'Constantí', 'Constanti', 'Constanti,Constantí', 41.1539200, 1.2126200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47079, 'Congostrina', 'Congostrina', 'Congostrina', 41.0371900, -2.9856900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47080, 'Congosto de Valdavia', 'Congosto de Valdavia', 'Congosto de Valdavia', 42.7158400, -4.6336600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47081, 'Congosto', 'Congosto', 'Congosto', 42.6175500, -6.5204800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47082, 'Conesa', 'Conesa', 'Conesa', 41.5166700, 1.3000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47083, 'Condemios de Arriba', 'Condemios de Arriba', 'Condemios de Arriba', 41.2164400, -3.1254300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47084, 'Condemios de Abajo', 'Condemios de Abajo', 'Condemios de Abajo', 41.2166700, -3.1000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47085, 'Comillas', 'Comillas', 'Comillas,Komil''jas,Комильяс', 43.3860300, -4.2916200, 'ES', '2013-10-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47086, 'Combarro', 'Combarro', 'Kombarro,Комбарро', 42.4318800, -8.7064900, 'ES', '2009-12-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47087, 'Colungo', 'Colungo', 'Colungo', 42.1712500, 0.0681200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47088, 'Colunga', 'Colunga', 'Kolunga,ke lun jia,klwnga,kwlwngha,Колунга,كولونغا,کلونگا,科伦加', 43.4853100, -5.2700900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47089, 'Colomers', 'Colomers', 'Colomers,Colomes,Colomés', 42.0833300, 2.9833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47090, 'Colmenar Viejo', 'Colmenar Viejo', 'Kol''menar-V''ekho,Kol''menar-Vekho,Kolmenar Viexo,jiu ke er mei na er,kwlmnar wygw,kwlmynar fyjw,Кольменар-Вьехо,Кольменар-Вєхо,Կոլմենար Վիեխո,קולמנאר וייחו,كولمينار فيجو,کولمنار ویگو,旧科尔梅纳尔', 40.6590900, -3.7676200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47091, 'Colmenarejo', 'Colmenarejo', '', 40.5606300, -4.0171300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47092, 'Colmenar de Oreja', 'Colmenar de Oreja', 'Colmenar de Oreja', 40.1067500, -3.3854700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47093, 'Colmenar de Montemayor', 'Colmenar de Montemayor', 'Colmenar de Montemayor,Montegrande del Colmenar', 40.3995700, -5.9561800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47094, 'Colmenar del Arroyo', 'Colmenar del Arroyo', 'Colmenar del Arroyo', 40.4189700, -4.1984500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47095, 'Collsuspina', 'Collsuspina', 'Collsuspina', 41.8258000, 2.1754600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47096, 'Coll de Nargó', 'Coll de Nargo', 'Coll de Nargo,Coll de Nargó', 42.1747300, 1.3169400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47097, 'Colldejou', 'Colldejou', 'Colldejou', 41.0997000, 0.8871700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47098, 'Collbató', 'Collbato', 'Collbato,Collbató', 41.5700900, 1.8271200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47099, 'Collazos de Boedo', 'Collazos de Boedo', 'Collazos de Boedo', 42.6200900, -4.4829400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47100, 'Collado-Villalba', 'Collado-Villalba', 'Collado Villalba,Kol''jado-Vil''jal''ba,Кольядо-Вильяльба', 40.6350600, -4.0048600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47101, 'Collado Mediano', 'Collado Mediano', '', 40.6932600, -4.0228000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47102, 'Collado Hermoso', 'Collado Hermoso', 'Collado Hermoso', 41.0386900, -3.9185900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47103, 'Collado del Mirón', 'Collado del Miron', 'Collado del Miron,Collado del Mirón', 40.5530700, -5.3539800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47104, 'Collado de Contreras', 'Collado de Contreras', 'Collado de Contreras', 40.8874300, -4.9314000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47105, 'Collado', 'Collado', 'Collado', 40.0572900, -5.7205200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47106, 'Colindres', 'Colindres', 'Colindres,Kolindres,ke lin de lei si,kwlyndrys,Колиндрес,Коліндрес,كوليندريس,科林德雷斯', 43.3966700, -3.4536100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47107, 'Coles', 'Coles', 'Coles,San Juan', 42.4000000, -7.8333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47108, 'Colera', 'Colera', 'Colera', 42.4039400, 3.1515300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47109, 'Coirós', 'Coiros', 'Coiros,Coirós,San Julian,San Julián', 43.2500000, -8.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47110, 'el Cogul', 'el Cogul', 'Cogul,Cogull,Gogull,el Cogul', 41.4666700, 0.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47111, 'Cogolludo', 'Cogolludo', '', 40.9469100, -3.0893000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47112, 'Cogollos', 'Cogollos', 'Cogollos', 42.1998200, -3.7000500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47113, 'Cogollor', 'Cogollor', 'Cogollor', 40.8481800, -2.7442500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47114, 'Cogeces del Monte', 'Cogeces del Monte', 'Cogeces del Monte', 41.5103000, -4.3172100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47115, 'Codos', 'Codos', 'Codos', 41.2926600, -1.3742500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47116, 'Codorniz', 'Codorniz', 'Codorniz', 41.0674500, -4.6002100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47117, 'Coca de Alba', 'Coca de Alba', 'Coca de Alba', 40.8783300, -5.3653700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47118, 'Coca', 'Coca', 'Cauca,Coca,Koka,Kokao,ke ka,Кока,科卡', 41.2176700, -4.5214500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47119, 'Cobreros', 'Cobreros', 'Cobreros', 42.0732300, -6.7005300, 'ES', '2012-03-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47120, 'Cobos de Fuentidueña', 'Cobos de Fuentiduena', 'Cobos de Fuentiduena,Cobos de Fuentidueña', 41.3826500, -3.9272300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47121, 'Cobos de Cerrato', 'Cobos de Cerrato', 'Cobos de Cerrato', 42.0280800, -4.0025100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47122, 'Cobeta', 'Cobeta', 'Cobeta', 40.8656000, -2.1421100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47123, 'Cobeña', 'Cobena', 'Cobena,Cobeña', 40.5666700, -3.5000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47124, 'Cobeja', 'Cobeja', 'Cobeja', 40.0207600, -3.8559900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47125, 'Coaña', 'Coana', 'Coana,Coano,Coaña,Coaño,Cuana,Cuaña,Koan''ja,Koanija,ke a ni ya,kwanya,kyanya,Коания,Коанья,كوانيا,کئانیا,科阿尼亚', 43.5139200, -6.7552700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47126, 'el Clot', 'el Clot', 'Barrio El Clot,Clot,El Clot', 41.4098600, 2.1905300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47127, 'Clavijo', 'Clavijo', 'Clavijo,Clavillo,Klavikho,Klavixo,ke la wei huo,Клавихо,Клавіхо,Կլավիխո,克拉维霍', 42.3489700, -2.4266600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47128, 'Clarés de Ribota', 'Clares de Ribota', 'Clares de Ribota,Clarés de Ribota', 41.5295700, -1.8377300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47129, 'Zizurkil', 'Zizurkil', 'Cizurquil,Cizúrquil,Zizurkil', 43.1991700, -2.0742000, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47130, 'Cizur Mayor', 'Cizur Mayor', 'Cizur Mayor,Zizur Nagusia', 42.7879500, -1.6906500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47131, 'Ciutadilla', 'Ciutadilla', 'Ciutadilla', 41.5611300, 1.1393500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47132, 'Siurana', 'Siurana', 'Siurana', 42.2091600, 2.9939200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47133, 'Ciudad Rodrigo', 'Ciudad Rodrigo', 'Ciarrodrigu,Cidade Rodrigo,Ciudad Rodrigo,Ciudad-Rodrigo,S''judad-Rodrigo,Siudad-Rodrigo,luo de li ge cheng,Сьюдад-Родриго,Сьюдад-Родріго,シウダ・ロドリーゴ,罗德里戈城', 40.6000000, -6.5333300, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47134, 'Ciudad Lineal', 'Ciudad Lineal', 'Barrio Ciudad Lineal,Ciudad Lineal,Ciudad Lineal distritu,Linia Urbo,swydad lynyal,سويداد لينيال,シウダー・リネアル', 40.4450500, -3.6513200, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47135, 'Ciutadella', 'Ciutadella', 'Ciudadela,Ciutadella,QIU', 40.0011200, 3.8414400, 'ES', '2016-03-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47136, 'Cistierna', 'Cistierna', 'Cistierna,Sist''erna,thystyrna,xi si tie er na,Систьерна,Сістьєрна,ثيستيرنا,西斯铁尔纳', 42.8034400, -5.1266400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47137, 'Cistérniga', 'Cisterniga', 'Cisterniga,Cistérniga', 41.6129400, -4.6869700, 'ES', '2015-09-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47138, 'Cistella', 'Cistella', 'Cistella', 42.2687000, 2.8478000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47139, 'Cisneros', 'Cisneros', 'Cisneros,Sisneros,xi si nei luo si,Сиснерос,Сіснерос,西斯内罗斯', 42.2204600, -4.8580700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47140, 'Cisla', 'Cisla', 'Cisla', 40.9666200, -5.0140500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47141, 'Cirujales del Río', 'Cirujales del Rio', 'Chujales del Rio,Chujales del Río,Cirujales del Rio,Cirujales del Río', 41.8669100, -2.3254900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47142, 'Cirueña', 'Ciruena', 'Ciruena,Cirueña', 42.4121400, -2.8959300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47143, 'Ciruelos de Cervera', 'Ciruelos de Cervera', 'Ciruelos de Cervera', 41.9056200, -3.5301500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47144, 'Ciruelas', 'Ciruelas', 'Ciruelas', 40.7502100, -3.0858000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47145, 'Ciriza', 'Ciriza', 'Ciriza', 42.7901900, -1.8282200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47146, 'Ciria', 'Ciria', 'Ciria', 41.6183100, -1.9657800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47147, 'Cirauqui', 'Cirauqui', 'Cirauqui', 42.6759600, -1.8911500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47148, 'Cirat', 'Cirat', 'Cinat,Ciral,Cirat', 40.0500000, -0.4500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47149, 'Cipérez', 'Ciperez', 'Ciperez,Cipérez', 40.9621000, -6.2655200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47150, 'Ziordia', 'Ziordia', 'Ciordia,Ziordia', 42.8706800, -2.2295400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47151, 'Cintruénigo', 'Cintruenigo', 'Cintruenico,Cintruenigo,Cintruénico,Cintruénigo,Zentroniko', 42.0793700, -1.8045800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47152, 'Cinctorres', 'Cinctorres', 'Cinctorres', 40.5833300, -0.2166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47153, 'Cincovillas', 'Cincovillas', '', 41.2050100, -2.8183400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47154, 'Cinco Olivas', 'Cinco Olivas', 'Cinco Olivas', 41.3396600, -0.3711600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47155, 'Cimballa', 'Cimballa', 'Cimballa', 41.1011800, -1.7735200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47156, 'Cimanes del Tejar', 'Cimanes del Tejar', 'Cimanes del Tejar', 42.6178900, -5.8050600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47157, 'Cimanes de la Vega', 'Cimanes de la Vega', '', 42.1164600, -5.5985100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47158, 'Cilleruelo de San Mamés', 'Cilleruelo de San Mames', 'Cilleruelo de San Mames,Cilleruelo de San Mamés', 41.4322000, -3.5661400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47159, 'Cilleruelo de Arriba', 'Cilleruelo de Arriba', 'Cilleruelo,Cilleruelo de Arriba', 41.9048700, -3.6610200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47160, 'Cilleruelo de Abajo', 'Cilleruelo de Abajo', 'Cilleruelo de Abajo', 41.8840500, -3.7972300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47161, 'Cilleros de la Bastida', 'Cilleros de la Bastida', 'Cilleros de la Bastida', 40.5761400, -6.0609400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47162, 'Cilleros', 'Cilleros', 'Cilleros,Cillerus,Sil''eros,kaylyrws,xi lie luo si,Сильерос,Сільєрос,كايليروس,西列罗斯', 40.1148600, -6.7925600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47163, 'Cillán', 'Cillan', 'Cillan,Cillán', 40.7067500, -4.9813500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47164, 'Cihuri', 'Cihuri', 'Cihuri,Zihuri', 42.5649900, -2.9228700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47165, 'Cihuela', 'Cihuela', 'Cihuela', 41.4072100, -1.9998900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47166, 'Ciguñuela', 'Cigunuela', 'Cigunuela,Ciguñuela', 41.6406400, -4.8568800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47167, 'Cigudosa', 'Cigudosa', 'Cigudosa', 41.9333300, -2.0500000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47168, 'Cigales', 'Cigales', 'Cigales', 41.7578000, -4.6984800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47169, 'Cifuentes', 'Cifuentes', 'Cifuentes,Sifuehntes,Sifuentes,xi feng te si,Сифуэнтес,Сіфуентес,Սիֆուենտես,西丰特斯', 40.7862200, -2.6224500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47170, 'Zierbena', 'Zierbena', 'Ciervana,Ciervana-Abanto,Ciérvana,Ciérvana-Abanto,La Cuesta,La Cuesta-Ciervana,La Cuesta-Ciérvana,Zierbena', 43.3500000, -3.0833300, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47171, 'Ciempozuelos', 'Ciempozuelos', '', 40.1591300, -3.6210300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47172, 'Cidones', 'Cidones', 'Cidones,Sidones,xi duo nei si,Сидонес,Сідонес,西多内斯', 41.8144400, -2.6399100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47173, 'Cidamón', 'Cidamon', 'Cidamon,Cidamón', 42.4951800, -2.8783400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47174, 'Ciadoncha', 'Ciadoncha', 'Ciadoncha', 42.1581400, -3.9323500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47175, 'Chozas de Canales', 'Chozas de Canales', 'Chozas de Canales', 40.1001400, -4.0433300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47176, 'Chozas de Abajo', 'Chozas de Abajo', 'Chozas de Abajo', 42.5065700, -5.6865600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47177, 'Chodes', 'Chodes', 'Chodes', 41.4869600, -1.4801200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47178, 'Chiprana', 'Chiprana', 'Chiprana', 41.2631700, -0.1274100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47179, 'Chinchón', 'Chinchon', 'Chinchon,Chinchón,Cincono,qin qiong,tshyntshwn,Ĉinĉono,Чинчон,تشينتشون,钦琼', 40.1402000, -3.4226700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47180, 'Chimillas', 'Chimillas', 'Chimillas', 42.1703300, -0.4516800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47181, 'Chiloeches', 'Chiloeches', 'Chiloeches', 40.5703800, -3.1600300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47182, 'Chillarón del Rey', 'Chillaron del Rey', 'Chillaron del Rey,Chillarón del Rey', 40.5981800, -2.6912600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47183, 'Chillarón de Cuenca', 'Chillaron de Cuenca', 'Chillaron,Chillarón', 40.1053900, -2.2218100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47184, 'Chía', 'Chia', 'Chia,Chía,Gia', 42.5208000, 0.4656300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47185, 'Chert/Xert', 'Chert/Xert', 'Cheri,Chert,Xert', 40.5194400, 0.1583100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47186, 'Chequilla', 'Chequilla', 'Chequilla', 40.6060000, -1.8278700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47187, 'Checa', 'Checa', 'Checa', 40.5861400, -1.7905600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47188, 'Chapinería', 'Chapineria', 'Chapineria,Chapinería', 40.3789100, -4.2100900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47189, 'Chantada', 'Chantada', '', 42.6087600, -7.7711500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47190, 'Chañe', 'Chane', 'Chane,Chañe', 41.3383400, -4.4276400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47191, 'Chamartín', 'Chamartin', 'Chamartin,Chamartin de la Rosa,Chamartín,Chamartín de la Rosa,Distrito Chamartin,Distrito Chamartín', 40.4620600, -3.6766000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47192, 'Chamartín', 'Chamartin', 'Chamartin,Chamartin de la Sierra,Chamartín', 40.7026700, -4.9576900, 'ES', '2016-03-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47193, 'Chalamera', 'Chalamera', '', 41.6656700, 0.1629900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47194, 'Cevico Navero', 'Cevico Navero', 'Cevico Navero', 41.8611200, -4.1849800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47195, 'Cevico de la Torre', 'Cevico de la Torre', 'Cevico de la Torre', 41.8511300, -4.4097300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47196, 'Cetina', 'Cetina', 'Cetina', 41.2920800, -1.9628100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47197, 'Cesuras', 'Cesuras', 'Cesuras,Dordano,Dordaño,Sesuras,kyswras,sai su la si,sesurasu,syswras,Сесурас,سیسوراس,كيسوراس,セスーラス,塞苏拉斯', 43.1728200, -8.2006100, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47198, 'Zestoa', 'Cestona', 'Cestona,Zestoa', 43.2397300, -2.2579000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47199, 'Cervo', 'Cervo', 'Cervo', 43.6701900, -7.4101300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47200, 'Cervillego de la Cruz', 'Cervillego de la Cruz', 'Cervillego de la Cruz', 41.1878300, -4.9496600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47201, 'Cervià de Ter', 'Cervia de Ter', 'Cervia de Ter,Cervià de Ter', 42.0665000, 2.9074300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47202, 'Cerveruela', 'Cerveruela', 'Cerveruela', 41.2156700, -1.2152500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47203, 'Cervera de Pisuerga', 'Cervera de Pisuerga', 'Cervera,Cervera de Pisuerga,Servera-de-Pisuehrga,Servera-de-Pisuerga,sai er wei la de pi su ai er jia,Сервера-де-Писуэрга,Сервера-де-Пісуерга,塞尔韦拉德皮苏埃尔加', 42.8667600, -4.4979600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47204, 'Cervera del Río Alhama', 'Cervera del Rio Alhama', 'Cervera de Rio Alhama,Cervera del Rio Alhama,Cervera del Rio Alhambra,Cervera del Río Alhama,Cervera del Río Alhambra,Servera del Rio Alama,Servera-del''-Rio-Al''khama,Servera-del''-Rio-Alama,a er a ma he pan sai er wei la de er,Сервера-дель-Рио-Алама,Сервера-дель-Рио-Альхама,Сервера-дель-Ріо-Алама,Սերվերա դել Ռիո Ալամա,阿尔阿马河畔塞尔韦拉德尔', 42.0051700, -1.9553100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47205, 'Cervera de los Montes', 'Cervera de los Montes', 'Cervera,Cervera de los Montes', 40.0518200, -4.8107200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47206, 'Cervera del Maestre', 'Cervera del Maestre', 'Cervera,Cervera del Maestrat,Cervera del Maestre', 40.4536600, 0.2765900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47207, 'Cervera de la Cañada', 'Cervera de la Canada', 'Cervera de la Canada,Cervera de la Cañada', 41.4330100, -1.7356800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47208, 'Cervera de Buitrago', 'Cervera de Buitrago', 'Cervera de Buitrago', 40.9198800, -3.5270200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47209, 'Cervera', 'Cervera', '', 41.6700300, 1.2721000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47210, 'Cervelló', 'Cervello', '', 41.3958700, 1.9591700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47211, 'Cervatos de la Cueza', 'Cervatos de la Cueza', 'Cervatos,Cervatos de la Cueza', 42.2905400, -4.7694700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47212, 'Cerratón de Juarros', 'Cerraton de Juarros', 'Cerraton de Juarros,Cerratón de Juarros', 42.4222700, -3.3734700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47213, 'Cerralbo', 'Cerralbo', 'Cerralbo', 40.9734700, -6.5871000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47214, 'Cernadilla', 'Cernadilla', 'Cernadilla', 42.0208300, -6.4170100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47215, 'Cerezo de Río Tirón', 'Cerezo de Rio Tiron', 'Cerezo,Sereso-de-Rio-Tiron,sai lei suo de li ao di long,syryzw dy rayw tayrwn,Сересо-де-Рио-Тирон,Сересо-де-Ріо-Тірон,سيريزو دي رايو تايرون,塞雷索德里奥蒂龙', 42.4914000, -3.1360000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47216, 'Cerezo de Arriba', 'Cerezo de Arriba', 'Cerezo de Arriba', 41.2389000, -3.5584600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47217, 'Cerezo de Abajo', 'Cerezo de Abajo', 'Cerezo de Abajo', 41.2181700, -3.5912600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47218, 'Cerezo', 'Cerezo', 'Cerezo', 40.2367800, -6.2276400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47219, 'Cerezal de Peñahorcada', 'Cerezal de Penahorcada', 'Cerezal de Penahorcada,Cerezal de Peñahorcada', 41.1307100, -6.6535700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47220, 'Cerecinos del Carrizal', 'Cerecinos del Carrizal', 'Cerecinos,Cerecinos del Carrizal', 41.6838400, -5.6530300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47221, 'Cerecinos de Campos', 'Cerecinos de Campos', 'Cerecinos,Cerecinos de Campos', 41.9001700, -5.4860500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47222, 'Cereceda de la Sierra', 'Cereceda de la Sierra', 'Cereceda de la Sierra', 40.5662700, -6.0914000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47223, 'Cerdido', 'Cerdido', 'Cerdido,San Martin,San Martín', 43.6166700, -8.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47224, 'Cercedilla', 'Cercedilla', '', 40.7410100, -4.0564400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47225, 'Cerceda', 'Cerceda', 'Cerceda,San Martin,San Martín', 43.1833300, -8.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47226, 'Cerbón', 'Cerbon', 'Cerbon,Cerbón', 41.9293400, -2.1689500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47227, 'Zerain', 'Cerain', 'Cerain,Ceráin,Zerain', 43.0123700, -2.2726400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47228, 'Cepeda la Mora', 'Cepeda la Mora', 'Cepeda la Mora', 40.4578000, -5.0483300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47229, 'Cepeda', 'Cepeda', 'Cepeda,Sepeda,sai pei da,Сепеда,Սեպեդա,塞佩达', 40.4660000, -6.0410000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47230, 'Centenera de Andaluz', 'Centenera de Andaluz', 'Centenera de Andaluz,Sentenera-de-Andalus,sen te nei la de ya en da lu si,Сентенера-де-Андалус,森特内拉德亚恩达卢斯', 41.5067900, -2.7181300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47231, 'Centenera', 'Centenera', 'Centenera', 40.6506400, -3.0512000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47232, 'Centelles', 'Centelles', 'Centelles', 41.7974600, 2.2190200, 'ES', '2014-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47233, 'Cenlle', 'Cenlle', 'Cenlle', 42.3418300, -8.0898200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47234, 'Cenicientos', 'Cenicientos', 'Cenicientos', 40.2645900, -4.4668300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47235, 'Cenicero', 'Cenicero', 'Cenicero,Ceracero', 42.4813000, -2.6441200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47236, 'Cendejas de la Torre', 'Cendejas de la Torre', 'Cendejas de la Torre', 40.9791600, -2.8505300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47237, 'Celrà', 'Celra', 'Celra,Celrà,Celrá', 42.0333300, 2.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47238, 'Cellorigo', 'Cellorigo', 'Cellorigo', 42.6270300, -3.0001600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47239, 'Cella', 'Cella', 'Cella', 40.4532500, -1.2875000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47240, 'Celanova', 'Celanova', '', 42.1530300, -7.9551300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47241, 'Celada del Camino', 'Celada del Camino', '', 42.2635900, -3.9336200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47242, 'Ceinos de Campos', 'Ceinos de Campos', 'Ceinos,Ceinos de Campos', 42.0328400, -5.1500700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47243, 'Zegama', 'Cegama', 'Cegama,Zegama', 42.9755600, -2.2909100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47244, 'Cee', 'Cee', 'Cee,See,Seeh,sai ai,se,sy,sy galysya,Сее,Сеэ,سي,سی گالیسیا,セー,塞埃', 42.9546600, -9.1880000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47245, 'Cedrillas', 'Cedrillas', 'Cedrillas', 40.4370800, -0.8515000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47246, 'Cedillo del Condado', 'Cedillo del Condado', 'Cedillo del Condado', 40.1126000, -3.9212700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47247, 'Cedillo de la Torre', 'Cedillo de la Torre', 'Cedillo de la Torre', 41.4248200, -3.6057700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47248, 'Cedeira', 'Cedeira', 'Cedeira,Sedeira,Sedejra,sai de la,sedeira,sydyra,sydyrya,Седеира,Седейра,سيديريا,سیدیرا,セデイラ,塞德拉', 43.6604400, -8.0571900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47249, 'Cebrones del Río', 'Cebrones del Rio', 'Cebrones del Rio,Cebrones del Río', 42.2572600, -5.8262200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47250, 'Cebreros', 'Cebreros', 'Cebreros', 40.4583500, -4.4643300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47251, 'Cebrecos', 'Cebrecos', 'Cebrecos', 41.9840800, -3.5966100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47252, 'Cebanico', 'Cebanico', 'Cebanco,Cebanico', 42.7252600, -5.0256800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47253, 'Zeanuri', 'Zeanuri', 'Ceanuri,Ceanuri Alto,Ceánuri,Ceánuri Alto,Elexondo,Zeanuri', 43.1000000, -2.7500000, 'ES', '2012-11-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47254, 'Cea', 'Cea', 'Cea,San Cristobal,San Cristobal de Cea,San Cristóbal,San Cristóbal de Cea', 42.4749000, -7.9873900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47255, 'Cazurra', 'Cazurra', 'Cazurra', 41.4158300, -5.7045400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47256, 'Cazalegas', 'Cazalegas', 'Cazalegas', 40.0095800, -4.6760600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47257, 'Cayuela', 'Cayuela', '', 42.2722300, -3.8189500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47258, 'Catoira', 'Catoira', 'Catoira', 42.6674800, -8.7232300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47259, 'el Catllar', 'el Catllar', 'Catllar,el Catllar', 41.1666700, 1.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47260, 'Catí', 'Cati', '', 40.4715600, 0.0227500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47261, 'Castroverde de Cerrato', 'Castroverde de Cerrato', 'Castroverde de Cerrato', 41.7560900, -4.2215100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47262, 'Castroverde de Campos', 'Castroverde de Campos', 'Castroverde,Castroverde de Campos', 41.9704900, -5.3143400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47263, 'Castroverde', 'Castroverde', 'Castroverde', 43.0302000, -7.3242800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47264, 'Castro-Urdiales', 'Castro-Urdiales', 'Castro Urdiales,Castro-Urdiales,Urdialaitz', 43.3828500, -3.2204300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47265, 'Castroserracín', 'Castroserracin', 'Castroserracin,Castroserracín', 41.3932900, -3.8019600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47266, 'Castroserna de Abajo', 'Castroserna de Abajo', 'Castroserna de Abajo', 41.2083500, -3.7338700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47267, 'Castroponce', 'Castroponce', 'Castroponce', 42.1264600, -5.1824500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47268, 'Castropol', 'Castropol', 'Kastropol'',ka si te luo bo er,kastrpl,kastrwbwl,Кастрополь,كاستروبول,کاسترپل,卡斯特罗波尔', 43.5277700, -7.0304800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47269, 'Castropodame', 'Castropodame', 'Castropodame', 42.5794300, -6.4683700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47270, 'Castronuño', 'Castronuno', 'Castronuno,Castronuño', 41.3891800, -5.2640800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47271, 'Castronuevo de Esgueva', 'Castronuevo de Esgueva', 'Castronuevo de Esgueva', 41.6818000, -4.5886600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47272, 'Castronuevo', 'Castronuevo', 'Castronuevo', 41.7204600, -5.5431500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47273, 'Castromonte', 'Castromonte', 'Castromonte', 41.7735500, -5.0390900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47274, 'Castromocho', 'Castromocho', 'Castromocho', 42.0310400, -4.8240400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47275, 'Castromembibre', 'Castromembibre', 'Castromembibre,Castromembribe', 41.6724600, -5.3047300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47276, 'Castrojimeno', 'Castrojimeno', 'Castrojimeno', 41.3965900, -3.8472600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47277, 'Castrogonzalo', 'Castrogonzalo', 'Castrogonzalo', 41.9909900, -5.6030100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47278, 'Castrodeza', 'Castrodeza', 'Castrodeza', 41.6492100, -4.9588800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47279, 'Castro de Rei', 'Castro de Rei', '', 43.2086600, -7.4002600, 'ES', '2013-08-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47280, 'Castro de Fuentidueña', 'Castro de Fuentiduena', 'Castro de Fuentiduena,Castro de Fuentidueña', 41.4204400, -3.8552800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47281, 'Castrocontrigo', 'Castrocontrigo', 'Castrocontigo,Castrocontrigo', 42.1836300, -6.1902200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47282, 'Castro Caldelas', 'Castro Caldelas', 'Castro Caldelas', 42.3736600, -7.4257800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47283, 'Castrocalbón', 'Castrocalbon', 'Castrocalbon,Castrocalbón', 42.1970600, -5.9822600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47284, 'Castrobol', 'Castrobol', 'Castrobol', 42.1371700, -5.3142300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47285, 'Castro', 'Castro', '', 42.7666700, -7.5833300, 'ES', '2006-01-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47286, 'Castrillo-Tejeriego', 'Castrillo-Tejeriego', 'Castrillo-Tejeriego', 41.7034000, -4.3714200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47287, 'Castrillo de Villavega', 'Castrillo de Villavega', 'Castrillo de Villavega', 42.4546300, -4.4806900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47288, 'Castrillo de Onielo', 'Castrillo de Onielo', 'Castrillo de Onielo', 41.8582000, -4.3012500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47289, 'Castrillo del Val', 'Castrillo del Val', 'Castrillo del Val,Kastril''jo-del''-Val'',Kastril''o-del''-Val'',ka si te li e de er wa er,kastylrylw dyl fal,Кастрильо-дель-Валь,Кастрільйо-дель-Валь,كاستيلريلو ديل فال,卡斯特里略德尔瓦尔', 42.3140100, -3.5850100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47290, 'Castrillo de la Vega', 'Castrillo de la Vega', 'Castrillo de la Vega', 41.6516600, -3.7808900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47291, 'Castrillo de la Valduerna', 'Castrillo de la Valduerna', 'Castrillo de la Valduerna', 42.3239300, -6.1345500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47292, 'Castrillo de la Reina', 'Castrillo de la Reina', 'Castrillo de la Reina', 41.9871400, -3.2356000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47293, 'Castrillo de la Guareña', 'Castrillo de la Guarena', 'Castrillo de la Guarena,Castrillo de la Guareña', 41.2304300, -5.3255000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47294, 'Castrillo de Duero', 'Castrillo de Duero', 'Castrillo de Duero', 41.5749400, -4.0154700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47295, 'Castrillo de Don Juan', 'Castrillo de Don Juan', 'Castrillo de Don Juan', 41.7908600, -4.0703100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47296, 'Castrillo de Cabrera', 'Castrillo de Cabrera', 'Castrillo de Cabrera', 42.3403600, -6.5445100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47297, 'Castrelo de Miño', 'Castrelo de Mino', 'Santa Maria,Santa María', 42.2979800, -8.0669700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47298, 'Castrejón de la Peña', 'Castrejon de la Pena', 'Castrejon de la Pena,Castrejón de la Peña', 42.8079500, -4.5990100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47299, 'Castraz', 'Castraz', 'Castraz', 40.7051700, -6.3338300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47300, 'Castilruiz', 'Castilruiz', 'Castilruiz,Kastil''ruis,Kastil''rujs,ka si di er lu yi si,Кастильруйс,Кастільруїс,卡斯蒂尔鲁伊斯', 41.8767800, -2.0593000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47301, 'Castilnuevo', 'Castilnuevo', 'Castilnuevo', 40.8143100, -1.8578200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47302, 'Castillonuevo', 'Castillonuevo', 'Castillonuevo', 42.6827000, -1.0312100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47303, 'Castillo de Villamalefa', 'Castillo de Villamalefa', 'Castillo de Villamalefa,Castillo de Villamaleja,Castillo de Villamaleta,Castillon de Villamatefa,el Castell de Vilamalefa', 40.1333300, -0.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47304, 'Castillo de Bayuela', 'Castillo de Bayuela', 'Castillo de Bayuela', 40.1003200, -4.6856200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47305, 'Castell-Platja d''Aro', 'Castell-Platja d''Aro', 'Castell-Platja d''Aro,Castillo de Aro,Kastel''-Pladzha-de-Aro,Кастель-Пладжа-де-Аро', 41.8175100, 3.0674200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47306, 'Castillo-Albaráñez', 'Castillo-Albaranez', 'Castillo de Albaranez,Castillo de Albarañez,Castillo-Albaranez,Castillo-Albaráñez', 40.2986900, -2.3927700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47307, 'Castillejo-Sierra', 'Castillejo-Sierra', 'Castillejo-Sierra', 40.3747700, -2.1404000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47308, 'Castillejo de Robledo', 'Castillejo de Robledo', 'Castillejo de Robledo', 41.5586700, -3.4968900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47309, 'Castillejo de Mesleón', 'Castillejo de Mesleon', 'Castillejo de Mesleon,Castillejo de Mesleón', 41.2810000, -3.6013700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47310, 'Castillejo de Martín Viejo', 'Castillejo de Martin Viejo', 'Castillejo de Martin Viejo,Castillejo de Martín Viejo', 40.6972800, -6.6376300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47311, 'Castillazuelo', 'Castillazuelo', 'Castillazuelo', 42.0677400, 0.0649100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47312, 'Castiliscar', 'Castiliscar', 'Castiliscar', 42.3766200, -1.2732600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47313, 'Castilfrío de la Sierra', 'Castilfrio de la Sierra', 'Caltilfrio de la Sierra,Caltilfrío de la Sierra,Castilfrio de la Sierra,Castilfrío de la Sierra,Kastil''frio-de-la-S''erra,ka si di er fu li ao de la xie la,Кастильфрио-де-ла-Сьерра,Кастільфріо-де-ла-Сьєрра,卡斯蒂尔夫里奥德拉谢拉', 41.9192900, -2.3049700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47314, 'Castilforte', 'Castilforte', 'Castilforte', 40.5573500, -2.4322600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47315, 'Castilfalé', 'Castilfale', 'Castilfale,Castilfalé', 42.2199100, -5.4212200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47316, 'Castil de Vela', 'Castil de Vela', 'Castil de Vela', 41.9846100, -4.9592000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47317, 'Castil de Peones', 'Castil de Peones', 'Castil de Peones', 42.4834700, -3.3846100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47318, 'Castildelgado', 'Castildelgado', 'Castildelgado,Villaipun,Villaipún', 42.4375600, -3.0838900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47319, 'Castigaleu', 'Castigaleu', 'Castigaleu', 42.2037400, 0.5794400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47320, 'Castiello de Jaca', 'Castiello de Jaca', 'Castiello de Jaca', 42.6296400, -0.5502000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47321, 'Castielfabib', 'Castielfabib', 'Castellfabib,Castielfabib', 40.1307600, -1.3039600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47322, 'Castelserás', 'Castelseras', 'Castelseras,Castelserás', 40.9813300, -0.1466600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47323, 'Castelnou', 'Castelnou', 'Castelnou', 41.2289200, -0.3643400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47324, 'Castellví de Rosanes', 'Castellvi de Rosanes', 'Castellvi de Rosanes,Castellví de Rosanes,Castellví de Rosanés', 41.4500000, 1.9000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47325, 'Castellterçol', 'Castelltercol', 'Castelltercol,Castelltersol,Castellterçol', 41.7500000, 2.1166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47326, 'Castellserà', 'Castellsera', 'Castellsera,Castellserà', 41.7500000, 1.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47327, 'Castellote', 'Castellote', 'Castellot,Castellote,Kastel''jote,Kastel''ote,ka si te e te,Кастельйоте,Кастельоте,卡斯特略特', 40.8000000, -0.3197500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47328, 'Castellolí', 'Castelloli', 'Castelloli,Castellolí', 41.5982900, 1.7005700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47329, 'Castelló de Farfanya', 'Castello de Farfanya', 'Castello de Farfanya,Castelló de Farfanya', 41.8166700, 0.7333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47330, 'Castelló d''Empúries', 'Castello d''Empuries', 'Castello d''Empuries,Castelló d''Empúries', 42.2567300, 3.0744600, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47331, 'Castellnou de Seana', 'Castellnou de Seana', 'Castellnou de Seana', 41.6480200, 0.9709300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47332, 'Castellfollit de Riubregós', 'Castellfollit de Riubregos', 'Castellfollit de Riubregos,Castellfollit de Riubregós,Castellfullit de Riubregos,Castellfullit de Riubregós', 41.7666700, 1.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47333, 'Castellfollit del Boix', 'Castellfollit del Boix', 'Castellfollit de Boix,Castellfollit del Boix', 41.6666700, 1.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47334, 'Castellfort', 'Castellfort', 'Castellfort', 40.5020800, -0.1913300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47335, 'Castellet', 'Castellet', '', 41.2628100, 1.6336900, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47336, 'Castelldefels', 'Castelldefels', 'Castelldefels', 41.2779400, 1.9703300, 'ES', '2013-03-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47337, 'Castell de Cabres', 'Castell de Cabres', 'Castell de Cabres', 40.6605800, 0.0421700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47338, 'Castellcir', 'Castellcir', 'Castellcir', 41.7607400, 2.1612800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47339, 'Castellbisbal', 'Castellbisbal', 'Castelbisbal,Kastel''bisbal,Kastelbisbal,bi si wa er bao,kastybysbal,kastylbaysbal,Кастельбісбал,Կաստելբիսբալ,كاستيلبايسبال,کاستیبیسبال,比斯瓦尔堡', 41.4753400, 1.9817400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47340, 'Castellar de la Muela', 'Castellar de la Muela', 'Castellar,Castellar de la Muela', 40.8190200, -1.7593200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47341, 'Castellar del Vallès', 'Castellar del Valles', '', 41.6166700, 2.0833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47342, 'Castellanos de Zapardiel', 'Castellanos de Zapardiel', 'Castellanos de Zapardiel', 41.0845000, -4.9098400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47343, 'Castellanos de Villiquera', 'Castellanos de Villiquera', 'Castellanos de Villiquera', 41.0513900, -5.6947700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47344, 'Castellanos de Moriscos', 'Castellanos de Moriscos', 'Castellanos de Moriscos', 41.0191700, -5.5906500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47345, 'Castellanos de Castro', 'Castellanos de Castro', '', 42.3280600, -4.0341700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47346, 'Castelflorite', 'Castelflorite', 'Castelflorite', 41.8027300, -0.0216900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47347, 'Castel de Cabra', 'Castel de Cabra', 'Castel de Cabra', 40.8025500, -0.6960000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47348, 'Castejón de Valdejasa', 'Castejon de Valdejasa', 'Castejon,Castejon de Valdejasa,Castejon de Valdejosa,Castejón de Valdejasa', 41.9820400, -0.9939300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47349, 'Castejón de Tornos', 'Castejon de Tornos', '', 40.9972600, -1.4280500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47350, 'Castejón de Sos', 'Castejon de Sos', 'Castejon de Sos,Castejón de Sos,Castillo de Sos,Castilló de Sos', 42.5123500, 0.4924100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47351, 'Castejón de Monegros', 'Castejon de Monegros', 'Castejon de Monegros,Castejón de Monegros', 41.6180200, -0.2401300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47352, 'Castejón del Puente', 'Castejon del Puente', '', 41.9617900, 0.1588300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47353, 'Castejón de las Armas', 'Castejon de las Armas', 'Castejon de las Armas,Castejón de las Armas', 41.3097600, -1.8108400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47354, 'Castejón de Henares', 'Castejon de Henares', 'Castejon de Henares,Castejón de Henares', 40.9376200, -2.7866500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47355, 'Castejón de Alarba', 'Castejon de Alarba', 'Castejon de Alarba,Castejón de Alarba', 41.1836500, -1.6361200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47356, 'Castejón', 'Castejon', 'Castejon,Castejón', 42.1691200, -1.6895100, 'ES', '2014-05-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47357, 'Castandiello', 'Castandiello', 'Castandiella,Castandiello,Morcin', 43.2796200, -5.8920100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47358, 'Castañares de Rioja', 'Castanares de Rioja', 'Castanares,Castanares de Rioja,Castañares,Castañares de Rioja', 42.5124800, -2.9314800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47359, 'Cassà de la Selva', 'Cassa de la Selva', 'Cassa de la Selva,Cassà de la Selva', 41.8878400, 2.8752400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47360, 'Caspueñas', 'Caspuenas', 'Caspuenas,Caspueñas', 40.6949700, -2.9794100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47361, 'Caspe', 'Caspe', 'Casp,Caspe,Kaspe,ka si pei,kasby,Каспе,كاسبي,卡斯佩', 41.2340200, -0.0394500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47362, 'Casla', 'Casla', 'Casla', 41.1660200, -3.6564300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47363, 'Casillas de Flores', 'Casillas de Flores', 'Casilla de Flores,Casillas de Flores', 40.3810800, -6.7560200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47364, 'Casillas', 'Casillas', 'Casillas', 40.3261000, -4.5718200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47365, 'Caseres', 'Caseres', 'Caseras,Caseres', 41.0333300, 0.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47366, 'Cáseda', 'Caseda', 'Caseda,Cáseda', 42.5225500, -1.3663600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47367, 'Cascante del Río', 'Cascante del Rio', 'Carrasconte,Cascante,Cascante del Rio,Cascante del Río', 40.1965200, -1.1141400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47368, 'Cascante', 'Cascante', 'Cascante,Cascanto', 41.9976900, -1.6809800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47369, 'Cascajares de la Sierra', 'Cascajares de la Sierra', 'Cascajares de la Sierra', 42.0617700, -3.3993600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47370, 'Cascajares de Bureba', 'Cascajares de Bureba', 'Cascajares de Bureba', 42.6788400, -3.2376800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47371, 'Casbas de Huesca', 'Casbas de Huesca', 'Casbas de Huesca', 42.1555000, -0.1399000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47372, 'Casavieja', 'Casavieja', 'Casavieja', 40.2832500, -4.7667000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47373, 'Casasola de Arión', 'Casasola de Arion', 'Casasola de Arion,Casasola de Arión', 41.5782500, -5.2407600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47374, 'Casaseca de las Chanas', 'Casaseca de las Chanas', 'Casaseca de las Chanas', 41.4387000, -5.6754700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47375, 'Casaseca de Campeán', 'Casaseca de Campean', 'Casaseca de Campean,Casaseca de Campeán', 41.3742900, -5.7464800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47376, 'Casas de San Galindo', 'Casas de San Galindo', 'Casas de Galindo,Casas de San Galindo', 40.8723400, -2.9575000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47377, 'Casas del Monte', 'Casas del Monte', 'Casas del Monte', 40.2032000, -5.9615200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47378, 'Casas del Castañar', 'Casas del Castanar', 'Casas del Castanar,Casas del Castañar', 40.1078500, -5.9050900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47379, 'Casas de Don Gómez', 'Casas de Don Gomez', 'Casas de Don Gomez,Casas de Don Gómez', 40.0093200, -6.6007300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47380, 'Casas Bajas', 'Casas Bajas', 'Casas Bajas', 40.0166700, -1.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47381, 'Casas Altas', 'Casas Altas', 'Casas Altas', 40.0333300, -1.2666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47382, 'Casarrubuelos', 'Casarrubuelos', '', 40.1714600, -3.8310500, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47383, 'Casarrubios del Monte', 'Casarrubios del Monte', 'Casarrubios del Monte', 40.1869700, -4.0364400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47384, 'Casares de las Hurdes', 'Casares de las Hurdes', 'Casares de las Hurdes', 40.4333300, -6.2833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47385, 'Casarejos', 'Casarejos', 'Casarejos', 41.7965100, -3.0325100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47386, 'Casar de Palomero', 'Casar de Palomero', 'Casar,Casar de Palomero', 40.2948300, -6.2569800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47387, 'Casalarreina', 'Casalarreina', 'Casalareina,Casalarreina,Kasalareyna,Kasalarrejna,Nafarruri,ka sa la lei na,Касаларрейна,Կասալառեյնա,卡萨拉雷纳', 42.5491100, -2.9099400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47388, 'Casafranca', 'Casafranca', 'Casafranca', 40.5926700, -5.7603900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47389, 'Casa de Uceda', 'Casa de Uceda', 'Casa de Uceda', 40.8411500, -3.3684900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47390, 'Carucedo', 'Carucedo', 'Carucedo', 42.4902900, -6.7656500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47391, 'Cartes', 'Cartes', 'Cartes,Kartes,ka er te si,kartys,Картес,كارتيس,卡尔特斯', 43.3259600, -4.0689300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47392, 'Cartelle', 'Cartelle', 'Cartelle', 42.2510900, -8.0706200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47393, 'Carrocera', 'Carrocera', 'Carrocera', 42.7960500, -5.7437400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47394, 'Carrizo de la Ribera', 'Carrizo de la Ribera', 'Carrizo,Carrizo de la Ribera', 42.5839500, -5.8288100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47395, 'Carrión de los Condes', 'Carrion de los Condes', 'Carrion de los Condes,Carrión de los Condes,Karrion-de-los-Kondes,Lacobriga,ka li weng de luo si kong de si,Каррион-де-лос-Кондес,Карріон-де-лос-Кондес,卡里翁德洛斯孔德斯', 42.3413000, -4.6007100, 'ES', '2012-10-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47396, 'Carrias', 'Carrias', 'Carrias', 42.4814100, -3.2831900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47397, 'Carreña', 'Carrena', 'Cabrales,Carrena de Cabrales,Carrena de Cabreles,Carrena-Cabrales,Carreña de Cabrales,Carreña de Cabreles,Carreña-Cabrales', 43.3173700, -4.8460900, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47398, 'Carrascosa de la Sierra', 'Carrascosa de la Sierra', 'Carrascosa de la Sierra', 41.8953500, -2.2800300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47399, 'Carrascosa de Abajo', 'Carrascosa de Abajo', 'Carrascosa de Abajo', 41.4233800, -3.0895500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47400, 'Carrascosa', 'Carrascosa', 'Carrascosa,Carrascosa-Sierra', 40.5909200, -2.1630500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47401, 'Carrascal del Río', 'Carrascal del Rio', 'Carrascal del Rio,Carrascal del Río', 41.3680100, -3.8981900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47402, 'Carrascal del Obispo', 'Carrascal del Obispo', 'Carrascal,Carrascal del Obispo', 40.7637600, -5.9991300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47403, 'Carrascal de Barregas', 'Carrascal de Barregas', 'Carrascal de Barregas', 40.9786800, -5.7622700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47404, 'Carranque', 'Carranque', '', 40.1697600, -3.9009200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47405, 'Carral', 'Carral', 'Carral', 43.2286000, -8.3554500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47406, 'Carracedelo', 'Carracedelo', 'Carracedelo', 42.5560200, -6.7331700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47407, 'Carpio de Azaba', 'Carpio de Azaba', 'Carpio de Azaba', 40.5960200, -6.6468000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47408, 'Carpio', 'Carpio', 'Carpio,Corpie', 41.2132900, -5.1090700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47409, 'Carnota', 'Carnota', '', 42.8233000, -9.0891300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47410, 'Cármenes', 'Carmenes', 'Carmenes,Cármenes', 42.9586300, -5.5734600, 'ES', '2013-07-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47411, 'Cariño', 'Carino', 'Carino,Cariño', 43.7413400, -7.8671500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47412, 'Cariñena', 'Carinena', 'Carinena,Cariñena', 41.3373300, -1.2244400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47413, 'Carenas', 'Carenas', 'Carenas', 41.2775500, -1.7975400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47414, 'Cardona', 'Cardona', 'Cardona', 41.9137100, 1.6785500, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47415, 'Cardiel de los Montes', 'Cardiel de los Montes', 'Cardiel de los Montes', 40.0634800, -4.6548800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47416, 'Cardeñosa de Volpejera', 'Cardenosa de Volpejera', 'Cardenosa de Volpejera,Cardeñosa de Volpejera', 42.2321400, -4.7019700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47417, 'Cardeñosa', 'Cardenosa', 'Cardenosa,Cardeñosa', 40.7424000, -4.7457900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47418, 'Cárdenas', 'Cardenas', 'Cardenas,Cárdenas', 42.3746400, -2.7672600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47419, 'Cardeñajimeno', 'Cardenajimeno', '', 42.3303800, -3.6210300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47420, 'Cardeñadijo', 'Cardenadijo', 'Cardenadijo,Cardeñadijo', 42.3021700, -3.6677900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47421, 'Cardedeu', 'Cardedeu', 'Cardedeu', 41.6397600, 2.3573900, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47422, 'Carcedo de Burgos', 'Carcedo de Burgos', '', 42.2869600, -3.6227400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47423, 'Carcedo de Bureba', 'Carcedo de Bureba', 'Carcedo de Bureba', 42.5781800, -3.4983100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47424, 'Carcastillo', 'Carcastillo', 'Carcastillo', 42.3790800, -1.4437600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47425, 'Cárcar', 'Carcar', 'Carcar,Cárcar', 42.3931400, -1.9790400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47426, 'Carcaboso', 'Carcaboso', 'Carcaboso', 40.0496800, -6.2137500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47427, 'Carbonero el Mayor', 'Carbonero el Mayor', 'Carbonero,Carbonero el Mavor,Carbonero el Mayor', 41.1225700, -4.2647800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47428, 'Carbellino', 'Carbellino', 'Carbellino,Carbellinu,Karbel''ino,ka er wei li nuo,Карбельино,Карбельїно,卡尔韦利诺', 41.2297500, -6.1490100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47429, 'Carballo', 'Carballo', 'Carballo,Karbal''o,Карбальо', 43.2130000, -8.6910400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47430, 'O Carballiño', 'O Carballino', '', 42.4316300, -8.0789900, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47431, 'Carballedo', 'Carballedo', '', 42.5219100, -7.8284000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47432, 'Carballeda de Avia', 'Carballeda de Avia', '', 42.3214000, -8.1645600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47433, 'Carbajosa de la Sagrada', 'Carbajosa de la Sagrada', 'Carbajosa de la Sagrada', 40.9330500, -5.6502600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47434, 'Carbajales de Alba', 'Carbajales de Alba', 'Carbajales,Carbajales de Alba', 41.6534700, -5.9970600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47435, 'Carazo', 'Carazo', 'Carazo', 41.9683200, -3.3531000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47436, 'Caracena', 'Caracena', 'Caracena', 41.3832100, -3.0914600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47437, 'Carabantes', 'Carabantes', 'Carabantes', 41.5521100, -1.9981000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47438, 'Carabaña', 'Carabana', 'Carabana,Carabaña', 40.2542400, -3.2357200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47439, 'Capmany', 'Capmany', 'Campmany,Capmany', 42.3735100, 2.9202600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47440, 'Capillas', 'Capillas', 'Capillas', 42.0136200, -4.8905100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47441, 'Capellades', 'Capellades', 'Capellades', 41.5300500, 1.6865100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47442, 'Capella', 'Capella', 'Capella', 42.1963500, 0.3963700, 'ES', '2016-02-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47443, 'Capdesaso', 'Capdesaso', 'Capdesaso', 41.8428700, -0.1831600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47444, 'Caparroso', 'Caparroso', 'Caparroso', 42.3412900, -1.6496200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47445, 'Capafonts', 'Capafonts', 'Capafons,Capafonts', 41.3000000, 1.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47446, 'Cantiveros', 'Cantiveros', 'Cantiveros', 40.9521500, -4.9545500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47447, 'Cantimpalos', 'Cantimpalos', 'Cantimpalos', 41.0740600, -4.1598800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47448, 'Cantavieja', 'Cantavieja', 'Cantavieja', 40.5264200, -0.4055800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47449, 'Cantaracillo', 'Cantaracillo', 'Cantaracillo', 40.9037600, -5.1629100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47450, 'Cantalpino', 'Cantalpino', 'Cantalpino', 41.0534100, -5.3304500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47451, 'Cantalojas', 'Cantalojas', 'Cantalojas', 41.2347200, -3.2462900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47452, 'Cantallops', 'Cantallops', 'Cantallops', 42.4221600, 2.9252400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47453, 'Cantalejo', 'Cantalejo', 'Cantalejo,Cantalojos,Kantalekho,kan ta lai huo,Канталехо,坎塔莱霍', 41.2576000, -3.9279100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47454, 'Cantalapiedra', 'Cantalapiedra', 'Cantalapiedra', 41.1263000, -5.1835100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47455, 'Cantagallo', 'Cantagallo', 'Cantagallo', 40.3723900, -5.8189000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47456, 'Cantabrana', 'Cantabrana', 'Cantabrana', 42.7342200, -3.4670400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47457, 'Canredondo', 'Canredondo', 'Canredondo', 40.8125700, -2.4937700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47458, 'Cànoves i Samalús', 'Canoves i Samalus', 'Canoves,Canoves i Samalus,Cànoves,Cànoves i Samalús', 41.6833300, 2.3500000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47459, 'Canovelles', 'Canovelles', 'Canovellas,Canovelles', 41.6166700, 2.2833300, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47460, 'Cañizo', 'Canizo', 'Canizo,Cañizo', 41.7695500, -5.5019900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47461, 'Cañizares', 'Canizares', 'Canizares,Cañizares', 40.5187000, -2.1920100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47462, 'Cañizar del Olivar', 'Canizar del Olivar', 'Canizar del Olivar,Cañizar del Olivar', 40.8162200, -0.6456700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47463, 'Cañizar', 'Canizar', 'Canizar,Cañizar', 40.7676300, -3.0639900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47464, 'Cañizal', 'Canizal', 'Canizal,Cañizal', 41.1665400, -5.3682800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47465, 'Canillas de Río Tuerto', 'Canillas de Rio Tuerto', '', 42.3995000, -2.8409100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47466, 'Canillas de Esgueva', 'Canillas de Esgueva', 'Canillas de Esgueva', 41.7546400, -4.1250200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47467, 'Canillas de Abajo', 'Canillas de Abajo', 'Canillas de Abajo', 40.9226600, -5.9290500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47468, 'Canicosa de la Sierra', 'Canicosa de la Sierra', 'Canicosa,Canicosa de la Sierra,Kanikosa-de-la-S''erra,ka ni ke sa de la xie la,kwnayshwsa dy la sayra,Каникоса-де-ла-Сьерра,Канікоса-де-ла-Сьєрра,كونايشوسا دي لا سايرا,卡尼科萨德拉谢拉', 41.9367300, -3.0408900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47469, 'Cangas de Onís', 'Cangas de Onis', 'Cangas de Onis,Cangas de Onís,Cangues d''Onis,Cangues d''Onís,Cangues dOnis,Cangues dOnís,Kangas-de-Onis,kan jia si de ao ni si,kangas d anys,kanghas dy awnys,Кангас-де-Онис,Кангас-де-Оніс,كانغاس دي أونيس,کانگاس د انیس,カンガス・デ・オニス,坎加斯德奥尼斯', 43.3514000, -5.1291600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47470, 'Cangas del Narcea', 'Cangas del Narcea', 'Cangas,Cangas de Tineo,Kangas-del''-Narsea,kan jia si de er na er sai ya,kangas dl narkya,kanghas dyl narthya,Кангас-дель-Нарсеа,كانغاس ديل نارثيا,کانگاس دل نارکئا,坎加斯德尔纳尔塞亚', 43.1833300, -6.5500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47471, 'Cangas do Morrazo', 'Cangas do Morrazo', 'Cangas,Cangas do Morrazo', 42.2641300, -8.7846300, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47472, 'Canfranc', 'Canfranc', 'Campfranc,Canfran,Canfranc,Canfrán,Kanfrank,kan fu lan ke,Канфранк,坎夫兰克', 42.7162800, -0.5256300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47473, 'Canet lo Roig', 'Canet lo Roig', 'Canet lo Roig,Carnet lo Roig', 40.5514200, 0.2430800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47474, 'Cañete', 'Canete', 'Canete,Cañete', 40.0500000, -1.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47475, 'Canet de Mar', 'Canet de Mar', 'Canet de Mar', 41.5905400, 2.5811600, 'ES', '2016-10-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47476, 'Canencia', 'Canencia', 'Canencia', 40.9072800, -3.7352300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47477, 'Candín', 'Candin', 'Candin,Candín', 42.8169500, -6.7284800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47478, 'Candilichera', 'Candilichera', 'Candilechera,Candilichera,Kandilichera,kan di li qie la,Кандиличера,Канділічера,坎迪利切拉', 41.7043400, -2.3012300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47479, 'Candeleda', 'Candeleda', 'Candaleda,Candeleda,Kandeleda,kan de lai da,kandlda,kandlyda,Канделеда,كاندليدا,کاندلدا,坎德莱达', 40.1552100, -5.2404500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47480, 'Candelario', 'Candelario', '', 40.3680600, -5.7449900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47481, 'Candasnos', 'Candasnos', 'Candasnos', 41.5021300, 0.0642500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47482, 'Cañaveruelas', 'Canaveruelas', 'Canaveruelas,Cañaveruelas', 40.4002400, -2.6371900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47483, 'Cañaveras', 'Canaveras', 'Canaveras,Cañaveras', 40.3599400, -2.3961100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47484, 'Cañas', 'Canas', '', 42.3924000, -2.8464900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47485, 'Cañamares', 'Canamares', 'Canamares,Cañamares', 40.4520300, -2.2398300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47486, 'Cañamaque', 'Canamaque', 'Canamaque,Cañamaque', 41.4445300, -2.2379200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47487, 'Canales de la Sierra', 'Canales de la Sierra', 'Canales,Canales de la Sierra', 42.1423300, -3.0245800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47488, 'Canales', 'Canales', 'Canales', 41.0033100, -4.9016300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47489, 'Canalejas de Peñafiel', 'Canalejas de Penafiel', 'Canalejas de Penafiel,Canalejas de Peñafiel', 41.5251300, -4.1154600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47490, 'Canalejas del Arroyo', 'Canalejas del Arroyo', 'Canalejas,Canalejas del Arroyo', 40.3685000, -2.4940800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47491, 'Cañada Vellida', 'Canada Vellida', 'Canada Vellida,Cañada Vellida', 40.7081100, -0.9148900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47492, 'Cañada de Benatanduz', 'Canada de Benatanduz', 'Canada de Benatanduz,Cañada de Benatanduz', 40.5793400, -0.5368200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47493, 'Camproviín', 'Camproviin', 'Camproviin,Camproviín', 42.3538700, -2.7229400, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47494, 'Camprodon', 'Camprodon', 'Camprodon,Camprodón', 42.3118500, 2.3650600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47495, 'Camporrells', 'Camporrells', 'Camporrells', 41.9585600, 0.5213600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47496, 'Camporredondo', 'Camporredondo', 'Camporredondo', 41.4733300, -4.5050300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47497, 'Campo Real', 'Campo Real', 'Campo Real,Camporreal', 40.3333300, -3.3833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47498, 'Camponaraya', 'Camponaraya', 'Camponaraya', 42.5779900, -6.6670900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47499, 'Campolara', 'Campolara', 'Campolara', 42.1195300, -3.4274000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47500, 'Campo de Villavidel', 'Campo de Villavidel', 'Campo de Villavidel', 42.4390600, -5.5280800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47501, 'Campo de San Pedro', 'Campo de San Pedro', 'Campo de San Pedro', 41.4299200, -3.5459900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47502, 'Campo de Caso', 'Campo de Caso', 'Campo de Caso,Caso,Casu,San Juan el Real', 43.1831000, -5.3447600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47503, 'Campo', 'Campo', 'Campo,Pole', 42.4095600, 0.3961500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47504, 'Campisábalos', 'Campisabalos', 'Campisabalos,Campisábalos', 41.2666700, -3.1333300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47505, 'Campins', 'Campins', '', 41.7166700, 2.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47506, 'Campillos-Sierra', 'Campillos-Sierra', 'Campillo-Sierra,Campillos-Sierra', 40.1000000, -1.7000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47507, 'Campillo de Ranas', 'Campillo de Ranas', 'Campillo de Ranas,Kampil''jo-de-Ranas,Kampil''o-de-Ranas,kan pi e de la na si,Кампильо-де-Ранас,Кампільйо-де-Ранас,坎皮略德拉纳斯', 41.0860100, -3.3143100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47508, 'Campillo de Dueñas', 'Campillo de Duenas', 'Campillo de Duenas,Campillo de Dueñas', 40.8837600, -1.6850500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47509, 'Campillo de Azaba', 'Campillo de Azaba', 'Campillo de Azaba', 40.5095100, -6.6870500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47510, 'Campillo de Aranda', 'Campillo de Aranda', 'Campillo de Aranda', 41.6101500, -3.7301700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47511, 'Campillo de Aragón', 'Campillo de Aragon', 'Campillo,Campillo de Aragon,Campillo de Aragón', 41.1264800, -1.8439300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47512, 'Campdevànol', 'Campdevanol', 'Campdevanol,Campdevànol', 42.2244500, 2.1686000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47513, 'Campazas', 'Campazas', 'Campazas', 42.1421900, -5.4934900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47514, 'Campaspero', 'Campaspero', 'Campaspero,Kampaspero,kampasprw,kan pa si pei luo,Кампасперо,Կամպասպերո,کامپاسپرو,坎帕斯佩罗', 41.4920800, -4.1960800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47515, 'Landa', 'Landa', 'Campa,La Campa,Landa,Urduliz,Urdúliz', 43.3833300, -2.9500000, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47516, 'Camós', 'Camos', 'Camos,Camós', 42.0877600, 2.7628800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47517, 'Caminreal', 'Caminreal', 'Camin Reyal,Caminreal,Camín Reyal,Kaminreal'',ka ming lei ya er,Каминреаль,Камінреаль,卡明雷亚尔', 40.8388300, -1.3241600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47518, 'Caminomorisco', 'Caminomorisco', 'Caminomorisco,Caminomoriscu,Kaminomorisko,ka mi nuo mo li si ke,kamaynwmwrayskw,Каминомориско,Каміноморіско,كاماينومورايسكو,卡米诺莫里斯科', 40.3271900, -6.2892300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47519, 'Cambrils', 'Cambrils', 'Cambrils,Kambril''s,Kambrils,kan fu li er si,kanburisu,kmbrylz,Камбрилс,Камбрильс,Камбрілс,کمبریلز,カンブリス,坎夫里尔斯', 41.0699700, 1.0594900, 'ES', '2015-08-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47520, 'Cambre', 'Cambre', 'Cambre', 43.2943800, -8.3473600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47521, 'Cambados', 'Cambados', 'Cambados', 42.5122200, -8.8131000, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47522, 'Camarzana de Tera', 'Camarzana de Tera', 'Camarzana de Tera', 41.9947100, -6.0265700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47523, 'Camarma de Esteruelas', 'Camarma de Esteruelas', 'Camarma de Esteruelas', 40.5503200, -3.3729500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47524, 'Camariñas', 'Camarinas', 'Camarinas,Camarines,Camariñas,Kamarin''jas,Kamarinas,ka ma li ni ya si,kamarinyasu,kamarynas,kamarynyas,Камариньяс,Камарињас,Камаріньяс,كامارينياس,کاماریناس,カマリーニャス,卡马里尼亚斯', 43.1311500, -9.1817200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47525, 'Camarillas', 'Camarillas', 'Camarillas,Camarillos', 40.6124200, -0.7541600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47526, 'Camargo', 'Camargo', 'Camargo,Kamargo,Камарго', 43.4074400, -3.8849800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47527, 'Camarenilla', 'Camarenilla', 'Camarenilla', 40.0167200, -4.0762400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47528, 'Camarena de la Sierra', 'Camarena de la Sierra', 'Camarena,Camarena de la Sierra', 40.1500000, -1.0333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47529, 'Camarena', 'Camarena', 'Camarena', 40.0931100, -4.1192700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47530, 'Camarasa', 'Camarasa', 'Camarasa,Camarassa', 41.8748600, 0.8781400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47531, 'Camañas', 'Camanas', 'Camanas,Camañas', 40.6430800, -1.1375200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47532, 'Camaleño', 'Camaleno', 'Camaleno,Camaleño,Kamalen''jo,Kamalen''o,ka ma lai ni ao,kamalynyw,Камаленьйо,Камаленьо,كامالينيو,卡马莱尼奥', 43.1507800, -4.6937600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47533, 'Calzadilla de Tera', 'Calzadilla de Tera', 'Calzadilla de Tera', 41.9789900, -6.0824300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47534, 'Calzadilla', 'Calzadilla', 'Calzadilla', 40.0601400, -6.5332800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47535, 'Calzada de Valdunciel', 'Calzada de Valdunciel', 'Calzada de Valdunciel', 41.0866300, -5.7021900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47536, 'Calzada de los Molinos', 'Calzada de los Molinos', 'Calzada de los Molinos', 42.3272400, -4.6529300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47537, 'Calzada del Coto', 'Calzada del Coto', '', 42.3861300, -5.0780900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47538, 'Calzada de Don Diego', 'Calzada de Don Diego', 'Calzada de Don Diego', 40.9050000, -5.9027900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47539, 'Calvos', 'Calvos', 'Calvos,Calvos de Randin', 41.9479000, -7.8960400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47540, 'Calvarrasa de Arriba', 'Calvarrasa de Arriba', 'Calvarrasa de Arriba', 40.9067200, -5.5919900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47541, 'Calvarrasa de Abajo', 'Calvarrasa de Abajo', 'Calvarrasa de Abajo', 40.9463800, -5.5525800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47542, 'Caltojar', 'Caltojar', 'Caltojar,Kal''tokhar,ka er tuo ha er,Кальтохар,卡尔托哈尔', 41.4022600, -2.7643600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47543, 'Calonge', 'Calonge', '', 41.8586900, 3.0792600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47544, 'Calomarde', 'Calomarde', 'Calomarde', 40.3726400, -1.5743500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47545, 'Calmarza', 'Calmarza', 'Calmarza', 41.1581000, -1.9119600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47546, 'Càlig', 'Calig', '', 40.4626200, 0.3552100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47547, 'Caleruega', 'Caleruega', 'Calaroga,Caleruega,Kaleruega,Kaleruehga,ka lai lu ai jia,kalrwyga,kalyrwygha,Калеруега,Калеруэга,كاليرويغا,کالروئگا,卡莱鲁埃加', 41.8254800, -3.4859300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47548, 'Calella', 'Calella', 'Calella,Callella', 41.6138100, 2.6542300, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47549, 'Caldas de Reis', 'Caldas de Reis', 'Caldas de Reves', 42.6000000, -8.6333300, 'ES', '2015-09-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47550, 'Caldes de Montbui', 'Caldes de Montbui', 'Caldes de Montbui,Caldes de Montbuy', 41.6333300, 2.1666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47551, 'Caldes de Malavella', 'Caldes de Malavella', 'Caldas de Malavella,Caldes de Malavella,Kal''das-de-Malavel''ja,Кальдас-де-Малавелья', 41.8333300, 2.8166700, 'ES', '2014-11-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47552, 'Caldes d''Estrac', 'Caldes d''Estrac', 'Caldas de Estrach,Caldes d''Estrac', 41.5666700, 2.5333300, 'ES', '2012-10-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47553, 'Calcena', 'Calcena', 'Calcena', 41.6551500, -1.7176400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47554, 'Calatorao', 'Calatorao', 'Calatorao', 41.5222800, -1.3470200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47555, 'Calatayud', 'Calatayud', 'Calataiud,Calatayu,Calatayud,Calatayú,Kalatajud,ka la tai wu de,kalataywd,karatayu,Калатаюд,قلعة أيوب,کالاتایود,カラタユー,卡拉泰乌德', 41.3535300, -1.6431800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47556, 'Calatañazor', 'Calatanazor', 'Calatanazor,Calatañazor', 41.6987900, -2.8183700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47557, 'Calanda', 'Calanda', '', 40.9415300, -0.2324300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47558, 'Calamocha', 'Calamocha', 'Calamocha,Kalamocha,ka la mo cha,Каламоча,卡拉莫查', 40.9193300, -1.2975000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47559, 'Calahorra de Boedo', 'Calahorra de Boedo', 'Calahorra,Calahorra de Boedo', 42.5740900, -4.3848500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47560, 'Calahorra', 'Calahorra', 'Calagorra,Calagurris,Calahorra,Kalagorria,Kalaora,Kalaorra,ka la ao la,karaora,qlhrt,Калаорра,Կալաոռա,قلهرة,カラオラ,卡拉奥拉', 42.3050600, -1.9652100, 'ES', '2015-06-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47561, 'Calafell', 'Calafell', 'Calafell', 41.1999700, 1.5683000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47562, 'Calaf', 'Calaf', '', 41.7328900, 1.5137500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47563, 'Calaceite', 'Calaceite', 'Calaceit,Calaceite', 41.0162500, 0.1887600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47564, 'Cadrete', 'Cadrete', 'Cadrete', 41.5557500, -0.9601300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47565, 'Cadreita', 'Cadreita', 'Cadreita', 42.2166700, -1.6833300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47566, 'Cadaqués', 'Cadaques', 'Cadaques,Cadaqués,Kadakes,Кадакес', 42.2885600, 3.2770600, 'ES', '2012-03-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47567, 'Cadalso de los Vidrios', 'Cadalso de los Vidrios', 'Cadalso,Cadalso de los Vidrios', 40.3006700, -4.4334800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47568, 'Cadalso', 'Cadalso', 'Cadalso', 40.2374300, -6.5408300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47569, 'Cacabelos', 'Cacabelos', 'Cacabelos', 42.6002100, -6.7237300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47570, 'Cabrils', 'Cabrils', 'Cabrils', 41.5276000, 2.3699600, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47571, 'Cabrillas', 'Cabrillas', 'Cabrillas', 40.7397700, -6.1787300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47572, 'Cabrillanes', 'Cabrillanes', 'Cabrillanes', 42.9534300, -6.1484900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47573, 'Cabreros del Río', 'Cabreros del Rio', 'Cabreros del Rio,Cabreros del Río', 42.4020500, -5.5415400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47574, 'Cabreros del Monte', 'Cabreros del Monte', 'Cabreros del Monte', 41.8490600, -5.2701600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47575, 'Cabrero', 'Cabrero', 'Cabrero', 40.1132400, -5.8929300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47576, 'Cabrerizos', 'Cabrerizos', 'Cabrerizos', 40.9780800, -5.6090700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47577, 'Cabrera de Mar', 'Cabrera de Mar', 'Cabrera de Mar', 41.5166700, 2.4000000, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47578, 'Cabrejas del Pinar', 'Cabrejas del Pinar', 'Cabrejas del Pinar', 41.7959600, -2.8494500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47579, 'Cabrejas del Campo', 'Cabrejas del Campo', 'Cabrejas del Campo,Kabrekhas-del''-Kampo,ka fu lei ha si de er kan bo,Кабрехас-дель-Кампо,卡夫雷哈斯德尔坎波', 41.6809600, -2.2696400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47580, 'Cabredo', 'Cabredo', '', 42.6296600, -2.4113300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47581, 'Cabra de Mora', 'Cabra de Mora', 'Cabra de Mora', 40.3169600, -0.8067800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47582, 'Cabra del Camp', 'Cabra del Camp', 'Cabra del Camp,Cabra del Campo', 41.4000000, 1.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47583, 'Cabolafuente', 'Cabolafuente', 'Cabolafuente', 41.2105300, -2.0413300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47584, 'Cabizuela', 'Cabizuela', 'Cabizuela', 40.9009000, -4.8021200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47585, 'Cabezuela del Valle', 'Cabezuela del Valle', 'Cabezuela,Cabezuela del Valle', 40.1936400, -5.8065000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47586, 'Cabezuela', 'Cabezuela', 'Cabezuela', 41.2359000, -3.9317300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47587, 'Cabezón de Valderaduey', 'Cabezon de Valderaduey', 'Cabezon de Valderaduey,Cabezón de Valderaduey', 42.1679300, -5.1589200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47588, 'Cabezón de Liébana', 'Cabezon de Liebana', 'Cabezon de Liebana,Cabezón de Liébana,Kabeson-de-L''ebana,ka wei song de lie wa na,kabyzwn dy ybana,Кабесон-де-Льебана,Кабесон-де-Льєбана,كابيزون دي يبانا,卡韦松德列瓦纳', 43.1343700, -4.5763000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47589, 'Cabezón de la Sierra', 'Cabezon de la Sierra', 'Cabezon de la Sierra,Cabezón de la Sierra,Kabeson de la Siera,Kabeson-de-la-S''erra,ka wei song de la xie la,kabsn d la syra,kabyzwn dy la sayra,Кабесон-де-ла-Сьерра,Кабесон-де-ла-Сьєрра,Կաբեսոն դե լա Սիեռա,كابيزون دي لا سايرا,کابسن د لا سیرا,卡韦松德拉谢拉', 41.9343400, -3.2415300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47590, 'Cabezón de la Sal', 'Cabezon de la Sal', 'Cabezon de la Sal,Cabezón de la Sal,Kabeson-de-la-Sal'',ka wei song de la sa er,kabyzwn dy la sal,Кабесон-де-ла-Саль,كابيزون دي لا سال,卡韦松德拉萨尔', 43.3082400, -4.2357100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47591, 'Cabezón de Cameros', 'Cabezon de Cameros', 'Cabezon de Cameros,Cabezón de Cameros', 42.1971600, -2.5198900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47592, 'Cabezón', 'Cabezon', '', 41.7336900, -4.6451000, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47593, 'Cabezas del Villar', 'Cabezas del Villar', 'Cabezas del Villar', 40.7155700, -5.2095600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47594, 'Cabezas del Pozo', 'Cabezas del Pozo', 'Cabezas del Pozo', 41.0013900, -4.9545300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47595, 'Cabezas de Alambre', 'Cabezas de Alambre', 'Cabezas de Alambre', 40.9421800, -4.8418400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47596, 'Cabeza del Caballo', 'Cabeza del Caballo', 'Cabeza del Caballo', 41.1298200, -6.5574200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47597, 'Cabezabellosa de la Calzada', 'Cabezabellosa de la Calzada', 'Cabezabellosa de la Calzada,Cabezavellosa de la Calzada', 41.0439500, -5.4886600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47598, 'Cabezabellosa', 'Cabezabellosa', 'Cabezabellosa', 40.1376300, -6.0008600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47599, 'Cabanillas del Campo', 'Cabanillas del Campo', 'Cabanillas del Campo,Kabanil''jas-del''-Kampo,ka wa ni li ya si de er kan bo,Кабанильяс-дель-Кампо,Кабанільяс-дель-Кампо,卡瓦尼利亚斯德尔坎波', 40.6337600, -3.2293700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47600, 'Cabanillas de la Sierra', 'Cabanillas de la Sierra', 'Cabanillas de la Sierra', 40.8200900, -3.6243800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47601, 'Cabanillas', 'Cabanillas', 'Cabanillas', 42.0324900, -1.5259100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47602, 'Cabañes de Esgueva', 'Cabanes de Esgueva', 'Cabanes de Esgueva,Cabañes de Esgueva', 41.8302300, -3.7882400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47603, 'Cabanes', 'Cabanes', 'Cabanes', 40.1560000, 0.0432500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47604, 'Cabanelles', 'Cabanelles', 'Cabanelles', 42.2306800, 2.8199700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47605, 'Cabañas de Sayago', 'Cabanas de Sayago', 'Cabanas de Sayago,Cabañas de Sayago', 41.3333300, -5.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47606, 'Cabañas de Polendos', 'Cabanas de Polendos', 'Cabanas de Polendos,Cabañas de Polendos', 41.0666700, -4.1101000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47607, 'Cabañas de la Sagra', 'Cabanas de la Sagra', 'Cabanas de la Sagra,Cabañas de la Sagra', 40.0061000, -3.9456000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47608, 'Cabañas de Ebro', 'Cabanas de Ebro', 'Cabanas de Ebro,Cabañas de Ebro', 41.8000000, -1.2000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47609, 'Caballar', 'Caballar', 'Caballar', 41.1215900, -3.9642000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47610, 'Busto de Bureba', 'Busto de Bureba', 'Busto de Bureba', 42.6591000, -3.2651200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47611, 'Bustillo del Páramo de Carrión', 'Bustillo del Paramo de Carrion', 'Bustillo,Bustillo del Paramo de Carrion,Bustillo del Páramo de Carrión', 42.3550900, -4.7398000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47612, 'Bustillo del Páramo', 'Bustillo del Paramo', '', 42.4412600, -5.7928000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47613, 'Bustillo del Oro', 'Bustillo del Oro', 'Bustillo del Oro', 41.6746000, -5.4615800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47614, 'Bustillo de la Vega', 'Bustillo de la Vega', 'Bustillo de la Vega', 42.4560500, -4.7411500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47615, 'Bustillo de Chaves', 'Bustillo de Chaves', 'Bustillo de Chaves', 42.1311400, -5.0916900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47616, 'Bustarviejo', 'Bustarviejo', 'Bustarv''ekho,Bustarvekho,Bustarviejo,bu si ta er wei ye huo,bwstarfyjw,Бустарвьехо,Бустарвєхо,بوستارفيجو,布斯塔尔维耶霍', 40.8572000, -3.7076600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47617, 'Bustares', 'Bustares', 'Bustares', 41.1333300, -3.0666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47618, 'Burón', 'Buron', 'Buron,Burón', 43.0248600, -5.0511900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47619, 'Burlata', 'Burlata', 'Burlada,Burlata', 42.8256200, -1.6167100, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47620, 'Burgos', 'Burgos', 'Bourgos,Burgi,Burgos,Burgosa,Burgosas,Burgoso,Burgus,Burqos,Gorad Burgas,RGS,brghsh,brgws,bu er ge si,buleugoseu,bur kos,burgosa,burugosu,bwrgws,Μπούργος,Бургос,Горад Бургас,Բուրգոս,בורגוס,برغش,برگوس,بورگوس,बुर्गोस,บูร์โกส,ブルゴス,布尔戈斯,부르고스', 42.3410600, -3.7018400, 'ES', '2016-03-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47621, 'Burgohondo', 'Burgohondo', 'Burgohondo,Burgokhondo,Burgoondo,bu er ge weng duo,bwrghwhwndw,bwrgwhwndw,Бургоондо,Бургохондо,بورغوهوندو,بورگوهوندو,布尔戈翁多', 40.4141600, -4.7850900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47622, 'Burganes de Valverde', 'Burganes de Valverde', 'Burganes de Valverde', 41.9213000, -5.7824400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47623, 'Bureta', 'Bureta', 'Bureta', 41.8157200, -1.4881900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47624, 'Burela de Cabo', 'Burela de Cabo', 'Burela,Burela de Cabo', 43.6500000, -7.4000000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47625, 'Burbáguena', 'Burbaguena', 'Burbaguena,Burbáguena', 41.0178300, -1.3382500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47626, 'Buñuel', 'Bunuel', 'Bunuel,Buñuel', 41.9800900, -1.4450300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47627, 'Buniel', 'Buniel', '', 42.3119700, -3.8223000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47628, 'Bulbuente', 'Bulbuente', 'Bulbuente', 41.8197000, -1.6023800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47629, 'Bujaraloz', 'Bujaraloz', 'Bujaraloz', 41.4980600, -0.1529000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47630, 'Bujalaro', 'Bujalaro', 'Bujalaro', 40.9368700, -2.8833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47631, 'Buitrago del Lozoya', 'Buitrago del Lozoya', 'Buitrago,Buitrago de Lozoya,Buitrago del Lozoya,Buitrago del Lozoyo,Buitrago-del''-Losoja,Bujtrago-del''-Losojja,bu yi te la ge de e suo ya,bwytrajw dyl wzwya,Буйтраго-дель-Лосойя,Буїтраго-дель-Лосоя,بويتراجو ديل وزويا,布伊特拉戈德略索亚', 40.9909000, -3.6336500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47632, 'Buitrago', 'Buitrago', 'Buitrago,Bujtrago,bu yi te la ge,Буйтраго,Буїтраго,布伊特拉戈', 41.8473500, -2.4085800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47633, 'Bugedo', 'Bugedo', 'Bugedo,Bujedo', 42.6491200, -3.0178600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47634, 'Bueu', 'Bueu', 'Buen,Bueu', 42.3245800, -8.7849700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47635, 'Buendía', 'Buendia', 'Buehndia,Buendija,ben di ya,bwyndya,Буендія,Буэндиа,بوينديا,本迪亚', 40.3664300, -2.7564500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47636, 'Buenavista de Valdavia', 'Buenavista de Valdavia', 'Buenavista de Valdavia', 42.6378800, -4.6144600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47637, 'Buenavista', 'Buenavista', 'Buenavista', 40.7676300, -5.6113900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47638, 'Buenaventura', 'Buenaventura', 'Buenaventura', 40.1770500, -4.8500300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47639, 'Buenamadre', 'Buenamadre', 'Buenamadre', 40.8570500, -6.2498700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47640, 'Bueña', 'Buena', 'Buena,Bueña', 40.7088100, -1.2674200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47641, 'Budia', 'Budia', 'Budia', 40.6273400, -2.7584600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47642, 'Buciegas', 'Buciegas', 'Buciegas', 40.3362200, -2.4625000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47643, 'Bubierca', 'Bubierca', 'Bubierca', 41.3148200, -1.8538600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47644, 'Buberos', 'Buberos', 'Buberos', 41.6469200, -2.1940600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47645, 'Brunyola', 'Brunyola', 'Brunola,Brunyola,Bruñola', 41.9000000, 2.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47646, 'Brunete', 'Brunete', 'Brunete', 40.4053200, -3.9985000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47647, 'Broto', 'Broto', '', 42.6043400, -0.1235100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47648, 'Bronchales', 'Bronchales', '', 40.5117100, -1.5882100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47649, 'Briviesca', 'Briviesca', 'Bribiesca,Briv''eska,Briveska,Briviesca,brayfayska,bu li wei ye si ka,Бривьеска,Брівєска,برايفايسكا,布里维耶斯卡', 42.5499300, -3.3231500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47650, 'Briones', 'Briones', 'Briones,bu li ao nei si,Брионес,Бріонес,Բրիոնես,布里奥内斯', 42.5439700, -2.7857200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47651, 'Brincones', 'Brincones', 'Brincones', 41.1133900, -6.3486500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47652, 'Briñas', 'Brinas', 'Brinas,Briñas', 42.6010600, -2.8319200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47653, 'Brime de Urz', 'Brime de Urz', 'Brime de Urz,San Esteban', 42.0379400, -5.8732600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47654, 'Brime de Sog', 'Brime de Sog', 'Brime de Sog', 42.0616200, -6.0479100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47655, 'Brihuega', 'Brihuega', 'Brihuega,Briuega,Briuehga,Бриуэга,Бріуега', 40.7604900, -2.8696600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47656, 'Brieva de Cameros', 'Brieva de Cameros', 'Brieva de Cameros', 42.1646200, -2.7945000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47657, 'Brieva', 'Brieva', 'Brieva', 41.0348300, -4.0536400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47658, 'Bretocino', 'Bretocino', 'Bretocino', 41.8843000, -5.7547300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47659, 'Bretó', 'Breto', 'Breto,Bretó', 41.8791700, -5.7390200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47660, 'Breda', 'Breda', '', 41.7483300, 2.5596400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47661, 'Brea de Tajo', 'Brea de Tajo', 'Brea,Brea de Tajo', 40.2333300, -3.1000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47662, 'Brea de Aragón', 'Brea de Aragon', 'Brea,Brea de Aragon,Brea de Aragón', 41.5238700, -1.6026100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47663, 'Brazuelo', 'Brazuelo', 'Brazuelo', 42.4970200, -6.1573400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47664, 'Brazacorta', 'Brazacorta', 'Brazacorta', 41.7173700, -3.3671100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47665, 'Braojos', 'Braojos', 'Braojos', 41.0404000, -3.6432900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47666, 'Brañosera', 'Branosera', 'Bran''josera,Bran''osera,Branosera,Brañosera,bu la ni ao sai la,Браньйосера,Браньосера,布拉尼奥塞拉', 42.9362000, -4.3083300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47667, 'Brabos', 'Brabos', 'Brabos,brabs,brabws,bu la wo si,Брабос,Բրաբոս,برابس,برابوس,布拉沃斯', 40.7784600, -4.9393400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47668, 'Bóveda del Río Almar', 'Boveda del Rio Almar', 'Boveda del Rio Almar,Bóveda del Río Almar', 40.8571900, -5.2103000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47669, 'Bóveda', 'Boveda', '', 42.6246000, -7.4767000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47670, 'Botorrita', 'Botorrita', 'Botorrita', 41.5070600, -1.0310400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47671, 'Botarell', 'Botarell', 'Botarell', 41.1362700, 0.9891900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47672, 'Bot', 'Bot', 'Bot', 41.0091600, 0.3839200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47673, 'Borriol', 'Borriol', 'Borriol', 40.0424900, -0.0702500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47674, 'Borrenes', 'Borrenes', 'Borrenes', 42.4901900, -6.7233800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47675, 'Borredà', 'Borreda', 'Borreda,Borredà', 42.1356400, 1.9942800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47676, 'Borrassà', 'Borrassa', 'Borrassa,Borrassà', 42.2231600, 2.9261000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47677, 'Borox', 'Borox', 'Borox', 40.0679500, -3.7380400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47678, 'Borobia', 'Borobia', 'Borobia,Borobija,bo luo wei ya,Боробиа,Боробія,博罗维亚', 41.6648100, -1.8961500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47679, 'les Borges del Camp', 'les Borges del Camp', 'Borjas del Campo,Les Borges del Camp,les Borges del Camp', 41.1666700, 1.0166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47680, 'Borjabad', 'Borjabad', 'Borjabad', 41.5524500, -2.3662500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47681, 'Borja', 'Borja', 'Borja', 41.8341200, -1.5327100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47682, 'Bordón', 'Bordon', 'Bordon,Bordón', 40.6865000, -0.3221600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47683, 'Bordils', 'Bordils', 'Bordils', 42.0433600, 2.9108800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47684, 'Bordalba', 'Bordalba', 'Bordalba', 41.4166700, -2.0666700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47685, 'Borau', 'Borau', '', 42.6585800, -0.5884600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47686, 'Boquiñeni', 'Boquineni', 'Boquineni,Boquiñeni', 41.8480400, -1.2524600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47687, 'Bonilla de la Sierra', 'Bonilla de la Sierra', 'Bonilla,Bonilla de la Sierra', 40.5306300, -5.2645200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47688, 'Bonastre', 'Bonastre', 'Bonastre', 41.2203100, 1.4393600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47689, 'Boñar', 'Bonar', 'Bonar,Boñar', 42.8668000, -5.3238600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47690, 'Bonansa', 'Bonansa', 'Bonansa', 42.4269100, 0.6669200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47691, 'Bolvir', 'Bolvir', '', 42.4177500, 1.8798600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47692, 'Boltaña', 'Boltana', 'Bol''tan''ja,Bol''tanija,Boltanya,bo er ta ni ya,borutanya,bwltanya,Больтания,Больтанья,بولتانيا,ボルターニャ,博尔塔尼亚', 42.4455000, 0.0680200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47693, 'Bolaños de Campos', 'Bolanos de Campos', 'Bolanos de Campos,Bolaños de Campos', 42.0068000, -5.2842800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47694, 'Boiro', 'Boiro', 'Boiro', 42.6472500, -8.8845900, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47695, 'Boimorto', 'Boimorto', 'Boimorto,Santiago', 43.0000000, -8.1333300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47696, 'Bohoyo', 'Bohoyo', 'Bohoyo', 40.3158400, -5.4429400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47697, 'Bogajo', 'Bogajo', 'Bogajo', 40.9071000, -6.5306500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47698, 'Boecillo', 'Boecillo', '', 41.5409000, -4.6994000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47699, 'Bocos de Duero', 'Bocos de Duero', '', 41.6233900, -4.0704800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47700, 'Bocigas', 'Bocigas', 'Bocigas', 41.2307000, -4.6812800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47701, 'Boceguillas', 'Boceguillas', 'Boceguillas,Bosegil''jas,bo sai ji li ya si,Босегильяс,Босегільяс,博塞吉利亚斯', 41.3364100, -3.6382800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47702, 'Boca de Huérgano', 'Boca de Huergano', 'Boca de Huergano,Boca de Huérgano', 42.9728700, -4.9241900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47703, 'Boborás', 'Boboras', 'Boboras,Boborás', 42.4333200, -8.1443100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47704, 'Bovera', 'Bovera', 'Bobera,Bovera', 41.3166700, 0.6500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47705, 'Bobadilla del Campo', 'Bobadilla del Campo', 'Bobadilla del Campo', 41.2043200, -5.0229400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47706, 'Bobadilla', 'Bobadilla', 'Bobadilla', 42.3187300, -2.7599200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47707, 'Boalo', 'Boalo', 'Boalo', 40.7160300, -3.9165600, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47708, 'Boal', 'Boal', 'Boal,Boal'',Bual,bo a er,bwal,byal,Боаль,بئال,بوال,博阿尔', 43.4320000, -6.8151300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47709, 'Boadilla del Monte', 'Boadilla del Monte', 'Boadil''ja-del''-Monte,bo a di li ya de er meng te,bwadyla dyl mwnty,Боадилья-дель-Монте,Боаділья-дель-Монте,בואדייה דל מונטה,بواديلا ديل مونتي,博阿迪利亚德尔蒙特', 40.4050000, -3.8783500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47710, 'Boadilla del Camino', 'Boadilla del Camino', 'Boadilla del Camino', 42.2593400, -4.3452500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47711, 'Boada de Campos', 'Boada de Campos', 'Boada de Campos', 41.9895700, -4.8773000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47712, 'Boada', 'Boada', 'Boada,bo a da,Боада,博阿达', 40.8156900, -6.3061100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47713, 'Bliecos', 'Bliecos', 'Bliecos', 41.5279000, -2.2713500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47714, 'Blesa', 'Blesa', 'Blesa', 41.0515000, -0.8850000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47715, 'Blascosancho', 'Blascosancho', '', 40.8774400, -4.6374300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47716, 'Blascomillán', 'Blascomillan', 'Blascomillan,Blascomillán', 40.8014600, -5.0870300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47717, 'Blanes', 'Blanes', 'Blanes,Бланес', 41.6741900, 2.7903600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47718, 'Blancos', 'Blancos', 'Blancos', 41.9965200, -7.7517500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47719, 'Blancas', 'Blancas', 'Blancas', 40.8139200, -1.4820800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47720, 'Blacos', 'Blacos', 'Blacos', 41.6809000, -2.8582600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47721, 'Bisimbre', 'Bisimbre', 'Bisimbre', 41.8560700, -1.4426800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47722, 'Biscarrués', 'Biscarrues', 'Biscarrues,Biscarrués', 42.2286700, -0.7496700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47723, 'la Bisbal del Penedès', 'la Bisbal del Penedes', 'Bisbal del Panades,Bisbal del Panadés,la Bisbal del Penedes,la Bisbal del Penedès', 41.2833300, 1.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47724, 'Bisaurri', 'Bisaurri', 'Bisagorri,Bisaurri,Bissauerri,Bissaürri', 42.4967700, 0.5064700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47725, 'Biota', 'Biota', 'Biota,bi ao ta,bywta,Биота,Біота,Բիոտա,بيوتا,比奥塔', 42.2621400, -1.1873500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47726, 'Binéfar', 'Binefar', 'Binefar,Binèfar,Binéfar', 41.8514100, 0.2943300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47727, 'Binaced', 'Binaced', 'Binaced,Binazed', 41.8256400, 0.2008400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47728, 'Bimenes', 'Bimenes', 'Bimenes,San Emeterio,bi mei nei si,bymns,bymyns,Бименес,Біменес,بيمينس,بیمنس,比梅内斯', 43.3166700, -5.5500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47729, 'Bilbao', 'Bilbao', 'BIO,Bil''bao,Bilbao,Bilbau,Bilbaum,Bilbaw,Bilbo,Bilbo / Bilbao,Bilmpao,El Bocho,Gorad Bil''baa,bi er ba e,bil ba xo,bilba''o,bilbao,birubao,blbaw,bylbaw,bylbayw,Μπιλμπάο,Билбао,Бильбао,Більбао,Горад Більбаа,Բիլբաո,בילבאו,بلباو,بیلبائو,بیلباو,बिल्बाओ,บิลบาโอ,ბილბაო,ビルバオ,毕尔巴鄂,빌바오', 43.2627100, -2.9252800, 'ES', '2011-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47730, 'Bijuesca', 'Bijuesca', 'Bijuesca', 41.5408300, -1.9203900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47731, 'Bigues i Riells', 'Bigues i Riells', 'Bigues,Bigues i Riells', 41.6833300, 2.2333300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47732, 'Biescas', 'Biescas', 'B''eskas,Beskas,Biescas,bi si ka si,bieseukaseu,Бьескас,Бєскас,毕斯卡斯,비에스카스', 42.6289700, -0.3213500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47733, 'Bierge', 'Bierge', 'Biarche,Bierge', 42.1621600, -0.0832600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47734, 'Bielsa', 'Bielsa', 'Bielsa', 42.6334700, 0.2185800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47735, 'Biel', 'Biel', 'B''el'',Bel'',Biel,bie er,byyl,Бьель,Бєль,بييل,别尔', 42.3876300, -0.9415400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47736, 'Bezas', 'Bezas', 'Bezas', 40.3307600, -1.3251100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47737, 'Bezares', 'Bezares', 'Bezares', 42.3703600, -2.6707600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47738, 'Beuda', 'Beuda', '', 42.2372200, 2.7094200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47739, 'Beteta', 'Beteta', 'Beteta', 40.5719100, -2.0758800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47740, 'Betelu', 'Betelu', '', 43.0255500, -1.9802900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47741, 'Betanzos', 'Betanzos', 'Betanzos', 43.2804200, -8.2146700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47742, 'Bescanó', 'Bescano', 'Bescano,Bescanó', 41.9660300, 2.7392200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47743, 'Besalú', 'Besalu', 'Besalu,Besalú', 42.1989300, 2.6995300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47744, 'Berzosilla', 'Berzosilla', 'Berzosilla', 42.7805300, -4.0375300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47745, 'Berzosa del Lozoya', 'Berzosa del Lozoya', 'Berzosa del Lozoya', 40.9732000, -3.5200900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47746, 'Berzosa de Bureba', 'Berzosa de Bureba', 'Berzosa de Bureba', 42.6267800, -3.2665200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47747, 'Berrueces', 'Berrueces', 'Berrueces', 41.9460600, -5.0969300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47748, 'Berrocalejo de Aragona', 'Berrocalejo de Aragona', 'Berrocalejo de Aragona', 40.6943600, -4.5947400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47749, 'Berrocal de Salvatierra', 'Berrocal de Salvatierra', 'Berrocal de Salvatierra', 40.6333100, -5.6900500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47750, 'Berrocal de Huebra', 'Berrocal de Huebra', 'Berrocal de Huebra', 40.7186400, -6.0005400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47751, 'Berrobi', 'Berrobi', 'Berrobi', 43.1451800, -2.0262300, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47752, 'Berriz', 'Berriz', 'Berriz,Bérriz', 43.1666700, -2.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47753, 'Berriozar', 'Berriozar', 'Berriozar', 42.8306700, -1.6664800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47754, 'Berriobeiti', 'Berriobeiti', 'Berriobeiti,Berrioplano', 42.8500000, -1.7000000, 'ES', '2007-01-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47755, 'Berriatua', 'Berriatua', 'Berriatua,Berriatúa', 43.3166700, -2.4666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47756, 'Berninches', 'Berninches', 'Berninches', 40.5710600, -2.8012100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47757, 'Bernardos', 'Bernardos', 'Bernardos', 41.1278700, -4.3511900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47758, 'Bermillo de Sayago', 'Bermillo de Sayago', 'Bermiellu de Seyagu,Bermil''jo-de-Sajago,Bermil''o-de-Sajjago,Bermillo de Sayago,bei er mi e de sai a ge,Бермильо-де-Сайяго,Бермільйо-де-Саяго,贝尔米略德赛阿戈', 41.3664800, -6.1122300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47759, 'Bermeo', 'Bermeo', 'Bermeo,Bermeu,Bermeum,Bermio,bei er mei ao,berumeo,byrmyw,Бермео,بيرميو,ベルメオ,贝尔梅奥', 43.4208800, -2.7215200, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47760, 'Bermellar', 'Bermellar', 'Bermellar', 40.9991800, -6.6701400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47761, 'Berlangas de Roa', 'Berlangas de Roa', 'Berlangas de Roa', 41.6891300, -3.8728400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47762, 'Berlanga del Bierzo', 'Berlanga del Bierzo', 'Berlanga del Bierzo', 42.7310400, -6.6056500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47763, 'Berlanga de Duero', 'Berlanga de Duero', 'Berlanga,Berlanga de Duero,Berlanga del Duero,Berlanga-de-Duehro,Berlanga-de-Duero,bei er lan jia de du ai luo,Берланга-де-Дуеро,Берланга-де-Дуэро,贝尔兰加德杜埃罗', 41.4656000, -2.8614700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47764, 'Beriáin', 'Beriain', 'Beriain,Beriáin', 42.7334700, -1.6444800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47765, 'Bergondo', 'Bergondo', 'Bergondo,San Salvador', 43.3166700, -8.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47766, 'Berge', 'Berge', 'Berge', 40.8579100, -0.4270900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47767, 'Bergasillas Bajera', 'Bergasillas Bajera', 'Bergasilla Bajera,Bergasillas Bajera', 42.2446200, -2.1583000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47768, 'Bergasa', 'Bergasa', 'Bergasa', 42.2528500, -2.1322100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47769, 'Berga', 'Berga', 'Berga', 42.1042900, 1.8462800, 'ES', '2013-09-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47770, 'Berdejo', 'Berdejo', 'Berdejo', 41.5613300, -1.9443100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47771, 'Bercimuel', 'Bercimuel', '', 41.3992500, -3.5705100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47772, 'Bercianos del Real Camino', 'Bercianos del Real Camino', 'Bercianos del Real Camino', 42.3873200, -5.1446200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47773, 'Bercianos del Páramo', 'Bercianos del Paramo', 'Bercianos', 42.3801700, -5.7083400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47774, 'Bercial de Zapardiel', 'Bercial de Zapardiel', 'Bercial de Zapardiel', 41.0467500, -4.9691000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47775, 'Bercial', 'Bercial', 'Bercial', 40.9071100, -4.4363800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47776, 'Berceruelo', 'Berceruelo', 'Berceruelo', 41.5803300, -5.0326700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47777, 'Bercero', 'Bercero', 'Bercero', 41.5639700, -5.0558000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47778, 'Berceo', 'Berceo', 'Berceo', 42.3390600, -2.8523900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47779, 'Berbinzana', 'Berbinzana', 'Berbinzana', 42.5277900, -1.8341900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47780, 'Berberana', 'Berberana', 'Berberana', 42.9178400, -3.0606300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47781, 'Berbegal', 'Berbegal', 'Barbegal,Berbedel,Berbegal', 41.9595900, -0.0032600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47782, 'Beratón', 'Beraton', 'Beraton,Beratón,bei la tong,Бератон,贝拉通', 41.7174900, -1.8109200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47783, 'Berastegi', 'Berastegui', 'Berastegi,Berastegui,Berástegui', 43.1242300, -1.9801900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47784, 'Berantevilla', 'Berantevilla', 'Berantevilla,Beranturi', 42.6825400, -2.8583200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47785, 'Berango', 'Berango', 'Berango', 43.3650000, -2.9960100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47786, 'Benuza', 'Benuza', 'Benuza', 42.3994100, -6.7096900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47787, 'Benlloch', 'Benlloch', 'Bell-lloc del Pla,Benlloch,Benltoch,Bennloch', 40.2107500, 0.0271700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47788, 'Benifallet', 'Benifallet', 'Benifallet', 40.9742200, 0.5176700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47789, 'Benicàssim', 'Benicassim', 'Benicasim,Benicassim,Benicàssim,Benicásim,bnw qasm,بنو قاسم', 40.0500000, 0.0666700, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47790, 'Benicarló', 'Benicarlo', 'Benicarlo,Benicarló,Benikarlo,Беникарло', 40.4165000, 0.4270900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47791, 'Benegiles', 'Benegiles', 'Benegiles', 41.6270000, -5.6347900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47792, 'Benavides', 'Benavides', 'Benavides,Benavides de Orbigo', 42.5044200, -5.8944200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47793, 'Benavente', 'Benavente', 'Benavente', 42.0024900, -5.6782600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47794, 'Benasque', 'Benasque', 'Benas,Benasc,Benaske,Benasque,Benasque-Benas,Benasque-Benás,Benás,Venasque,bei na si ke,Бенаске,贝纳斯克', 42.6052800, 0.5230500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47795, 'Benassal', 'Benassal', 'Benasal,Benassal', 40.3769000, -0.1397000, 'ES', '2016-12-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47796, 'Benafigos', 'Benafigos', 'Benafigos', 40.2764100, -0.2077200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47797, 'Benafarces', 'Benafarces', 'Benafarces', 41.6213300, -5.2928500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47798, 'Benavarri / Benabarre', 'Benavarri / Benabarre', 'Benabarre,Benabarri,Benavarri,Benavarri / Benabarre', 42.1058600, 0.4821100, 'ES', '2007-02-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47799, 'Bembibre', 'Bembibre', 'Bembibire,Bembibre,Bembibro,Bembribe,ben wei fu lei,benbibure,Бембибре,Бембібре,ベンビブレ,本维夫雷', 42.6177100, -6.4154500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47800, 'Belver de los Montes', 'Belver de los Montes', 'Belver de los Montes', 41.7228400, -5.4518200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47801, 'Belver', 'Belver', 'Bellver de Cinca', 41.6927200, 0.1782700, 'ES', '2007-02-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47802, 'Belorado', 'Belorado', 'Belfuratus,Belorado,Bilforato,bei luo la duo,bylwradw,Белорадо,بيلورادو,贝洛拉多', 42.4204800, -3.1913300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47803, 'Belmonte de Tajo', 'Belmonte de Tajo', 'Belmonte de Tajo', 40.1316200, -3.3358000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47804, 'Belmonte de Campos', 'Belmonte de Campos', 'Belmonte de Campos', 41.9425500, -4.9865900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47805, 'Belmonte', 'Belmonte', 'Miranda', 43.2824500, -6.2181800, 'ES', '2008-01-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47806, 'Bellvís', 'Bellvis', 'Bellvis,Bellvís', 41.6726900, 0.8176800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47807, 'Bellver de Cerdanya', 'Bellver de Cerdanya', '', 42.3666700, 1.7833300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47808, 'Bellpuig', 'Bellpuig', 'Bellpuig,Belpuig', 41.6259500, 1.0114400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47809, 'Bellprat', 'Bellprat', 'Bellprat', 41.5169500, 1.4333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47810, 'Bello', 'Bello', 'Bello', 40.9226600, -1.4985000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47811, 'Bellcaire d''Urgell', 'Bellcaire d''Urgell', 'Bellcaire d''Urgell', 41.7500000, 0.9166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47812, 'Belinchón', 'Belinchon', 'Belinchon,Belinchón', 40.0460300, -3.0551700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47813, 'Beleña', 'Belena', 'Belena,Beleña', 40.7506700, -5.6271300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47814, 'Belchite', 'Belchite', 'Bel''chite,Belchit,Belchite,Belgit,bei er qi te,byltshyty,Бельчите,بيلتشيتي,贝尔奇特', 41.3032500, -0.7505000, 'ES', '2017-05-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47815, 'Belbimbre', 'Belbimbre', 'Belbimbre', 42.1687300, -4.0128000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47816, 'Belauntza', 'Belaunza', 'Belauntza,Belaunza', 43.1358600, -2.0515600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47817, 'Belascoáin', 'Belascoain', 'Belascoain,Belascoáin', 42.7561900, -1.8322700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47818, 'Béjar', 'Bejar', 'Bejar,Bekhar,Bexa,Béjar,bei ha er,Бехар,贝哈尔', 40.3864100, -5.7634100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47819, 'Beizama', 'Beizama', 'Beizama', 43.1338500, -2.2000100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47820, 'Beire', 'Beire', 'Beire', 42.4541500, -1.6210100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47821, 'Begonte', 'Begonte', 'Begonte,San Pedro', 43.1512100, -7.6864300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47822, 'Begues', 'Begues', 'Begas,Begues', 41.3333300, 1.9333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47823, 'Becilla de Valderaduey', 'Becilla de Valderaduey', 'Becilla de Valderaduey', 42.0990500, -5.2180500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47824, 'Becerril de la Sierra', 'Becerril de la Sierra', 'Becerril de la Sierra', 40.7169900, -3.9885800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47825, 'Becerril de Campos', 'Becerril de Campos', 'Becerril,Becerril de Campos,Beseril de Kampos,Beserril''-de-Kampos,bei sai li er de kan bo si,bsryl d kamps,Бесерриль-де-Кампос,Бесерріль-де-Кампос,Բեսեռիլ դե Կամպոս,بسریل د کامپس,贝塞里尔德坎波斯', 42.1084100, -4.6415200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47826, 'Becerreá', 'Becerrea', 'Becerrea,Becerreá', 42.8561000, -7.1636000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47827, 'Becedillas', 'Becedillas', 'Becedillas', 40.5382100, -5.3256100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47828, 'Becedas', 'Becedas', 'Becedas', 40.4036900, -5.6357700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47829, 'Beasain', 'Beasain', 'Beasain,Beasáin', 43.0501700, -2.2008700, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47830, 'Beamud', 'Beamud', 'Beamud', 40.1864500, -1.8288000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47831, 'Beade', 'Beade', '', 42.3307400, -8.1295000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47832, 'Bea', 'Bea', 'Bea', 41.0363300, -1.1472500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47833, 'Bayubas de Arriba', 'Bayubas de Arriba', 'Bajubas-de-Arriba,Bayubas de Arriba,bai wu wa si de ya li wa,Баюбас-де-Арриба,Баюбас-де-Арріба,拜乌瓦斯德亚里瓦', 41.5575000, -2.8873100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47834, 'Bayubas de Abajo', 'Bayubas de Abajo', 'Bajubas-de-Abakho,Bayubas de Abajo,bai wu wa si de ya wa huo,Баюбас-де-Абахо,拜乌瓦斯德亚瓦霍', 41.5274700, -2.8958600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47835, 'Baiona', 'Baiona', 'Baiona', 42.1166700, -8.8500000, 'ES', '2015-08-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47836, 'Batres', 'Batres', 'Batres', 40.2098100, -3.9233100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47837, 'Batea', 'Batea', 'Batea', 41.0943400, 0.3110000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47838, 'Bascuñana de San Pedro', 'Bascunana de San Pedro', 'Bascunana,Bascunana de San Pedro,Bascuñana,Bascuñana de San Pedro', 40.2132200, -2.2281200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47839, 'Bascuñana', 'Bascunana', 'Bascunana,Bascuñana', 42.4254800, -3.0823100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47840, 'Báscones de Ojeda', 'Bascones de Ojeda', 'Bascones de Ojeda,Báscones de Ojeda', 42.6706400, -4.5269300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47841, 'Basconcillos del Tozo', 'Basconcillos del Tozo', 'Basconcillos,Basconcillos del Tozo,Baskonsil''jos-del''-Toso,Baskonsil''os-del''-Toso,ba si kong xi e si de er tuo suo,baskwnsaylws dyl twzw,Басконсильос-дель-Тосо,Басконсільйос-дель-Тосо,باسكونسايلوس ديل توزو,巴斯孔西略斯德尔托索', 42.7023600, -3.9893700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47842, 'Bàscara', 'Bascara', 'Bascara,Bàscara,Báscara', 42.1599800, 2.9102800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47843, 'Basardilla', 'Basardilla', 'Basardilla', 41.0273700, -4.0259800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47844, 'Sant Esteve d''en Bas', 'Sant Esteve d''en Bas', 'Bas,Sant Esteve d''en Bas', 42.1180900, 2.4568200, 'ES', '2017-07-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47845, 'Bárzana', 'Barzana', 'Barzana,Bárzana,Quiros,Quirós', 43.1574200, -5.9734500, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47846, 'Barruelo de Santullán', 'Barruelo de Santullan', 'Barruehlo-de-Santul''jan,Barruelo,Barruelo de Santullan,Barruelo de Santullán,Barruelo-de-Santul''jan,ba lu ai luo de sang tu liang,Барруело-де-Сантульян,Барруэло-де-Сантульян,巴鲁埃洛德桑图良', 42.9064100, -4.2859300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47847, 'Barruecopardo', 'Barruecopardo', 'Barruecopardo,Barruecupardu,Barruehkopardo,Barruekopardo,ba lu ai ke pa er duo,Барруекопардо,Барруэкопардо,巴鲁埃科帕尔多', 41.0721500, -6.6642300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47848, 'Barromán', 'Barroman', 'Barroman,Barromán', 41.0653600, -4.9306600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47849, 'Barro', 'Barro', '', 42.5553400, -8.6223100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47850, 'Barrios de Colina', 'Barrios de Colina', '', 42.3959500, -3.4600100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47851, 'Barriopedro', 'Barriopedro', 'Barriopedro', 40.7902600, -2.7524600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47852, 'Barrio de Muñó', 'Barrio de Muno', 'Barrio de Muno,Barrio de Muñó', 42.1758400, -4.0071500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47853, 'Barrado', 'Barrado', 'Barrado', 40.0847700, -5.8806800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47854, 'Barraco', 'Barraco', '', 40.4764700, -4.6434600, 'ES', '2011-10-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47855, 'Barrachina', 'Barrachina', 'Barrachina', 40.8968800, -1.1385800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47856, 'Barracas', 'Barracas', 'Barracas,Barraques', 40.0166700, -0.6833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47857, 'Barjas', 'Barjas', 'Barjas', 42.6118200, -6.9797900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47858, 'Barillas', 'Barillas', 'Barillas', 41.9666700, -1.6333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47859, 'Bargota', 'Bargota', 'Bargota', 42.5598200, -2.3106700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47860, 'Bareyo', 'Bareyo', 'Bareyo', 43.4668600, -3.6008300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47861, 'Bardallur', 'Bardallur', 'Bardallur', 41.6842300, -1.2118300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47862, 'Barcones', 'Barcones', 'Barcones', 41.2914600, -2.8163000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47863, 'Barcial del Barco', 'Barcial del Barco', 'Barcial del Barco', 41.9335300, -5.6626800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47864, 'Barcial de la Loma', 'Barcial de la Loma', 'Barcial de la Loma', 41.9513900, -5.2835300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47865, 'Barceo', 'Barceo', 'Barceo', 41.0610800, -6.4517500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47866, 'Bárcena de Pie de Concha', 'Barcena de Pie de Concha', 'Barcena de Pie de Concha,Barcena de Pla de Concha,Barsena-de-P''e-de-Koncha,Barsena-de-Pe-de-Koncha,Bárcena de Pie de Concha,ba er sai na de bi de kong cha,barsyna dy by dy kwntsha,Барсена-де-Пье-де-Конча,Барсена-де-Пє-де-Конча,بارسينا دي بي دي كونتشا,巴尔塞纳德彼德孔查', 43.1258000, -4.0566200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47867, 'Bárcena de Cicero', 'Barcena de Cicero', 'Barcena,Barcena de Cicero,Barsena-de-Sisero,Bárcena,Bárcena de Cicero,ba er sai na de xi sai luo,barsyna dy saysyrw,Барсена-де-Сисеро,Барсена-де-Сісеро,بارسينا دي سايسيرو,巴尔塞纳德西塞罗', 43.4216000, -3.5103000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47868, 'Bárcena de Campos', 'Barcena de Campos', 'Barcena de Campos,Bárcena de Campos', 42.4842800, -4.4987500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47869, 'la Barceloneta', 'la Barceloneta', 'Barceloneta,Barrio la Barceloneta,la Barceloneta', 41.3799000, 2.1897100, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47870, 'Barcelona', 'Barcelona', 'BCN,Barcellona,Barcellonn-a,Barcelona,Barcelone,Barcelono,Barceluna,Barcelůna,Barcełona,Barcillona,Barcino,Barkelone,Barseloana,Barselon,Barselona,Barselonae,Barselono,Barseluna,Barseluona,Barselóna,Barslon-a,Barsélona,Bartzellona,Bartzelona,Barzelona,Barçellonn-a,Barċellona,Gorad Barselona,Lungsod ng Barcelona,ba sa long na,ba sai luo na,baleusellona,balsaleana,bar se lon a,barasilona,barselona,barsilona,barslwn,barslwna,barsylwna,barsێlۆna,baruserona,brshlwnt,brshlwnہ,brzlwnh,la Ciudad Condal,parcelona,Βαρκελώνη,Барселон,Барселонæ,Барселона,Барселоно,Горад Барселона,Բարսելոնա,בארצעלאנע,ברצלונה,بارسلون,بارسلونا,بارسیلونا,بارسێلۆنا,برشلونة,برشلونہ,बार्सिलोना,बार्सेलोना,বার্সেলোনা,ਬਾਰਸੀਲੋਨਾ,பார்செலோனா,ബാഴ്സലോണ,บาร์เซโลนา,ບາກເຊໂລນ,བྷར་སེ་ལོ་ནཱ།,ဘာစီလိုနာမြို့,ბარსელონა,ባርሴሎና,バルセロナ,巴塞罗那,巴薩隆拿,바르셀로나', 41.3887900, 2.1589900, 'ES', '2017-05-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47871, 'Bárcabo', 'Barcabo', 'Barcabo,Bárcabo', 42.2421900, 0.0693400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47872, 'Barca', 'Barca', 'Barca,Barka,ba er ka,baleuka,Барка,巴尔卡,바르카', 41.4549000, -2.6221700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47873, 'Barbuñales', 'Barbunales', 'Barbunales,Barbuñales', 42.0256300, -0.0865900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47874, 'Barbués', 'Barbues', 'Barbues,Barbués', 41.9808500, -0.4194900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47875, 'Barbolla', 'Barbolla', 'Barbolla,Barboya', 41.3256700, -3.6736100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47876, 'Bárboles', 'Barboles', 'Barboles,Bárboles', 41.7089800, -1.1859400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47877, 'Barbastro', 'Barbastro', 'Balbastro,Barbastras,Barbastre,Barbastro,ba er wa si te luo,barubasutoro,brbshtr,Барбастро,بربشتر,バルバストロ,巴尔瓦斯特罗', 42.0356500, 0.1268600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47878, 'Barbalos', 'Barbalos', 'Barbalos', 40.6767800, -5.9425800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47879, 'Barbadillo del Pez', 'Barbadillo del Pez', 'Barbadillo del Pez', 42.1187900, -3.2280300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47880, 'Barbadillo del Mercado', 'Barbadillo del Mercado', 'Barbadillo del Mercado', 42.0385800, -3.3566900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47881, 'Barbadillo de Herreros', 'Barbadillo de Herreros', 'Barbadillo,Barbadillo de Herreros', 42.1497400, -3.1770200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47882, 'Barásoain', 'Barasoain', 'Barasoain,Barasoajn,ba la suo a yin,Барасоайн,Բարասոաին,巴拉索阿因', 42.6033900, -1.6465800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47883, 'Barañáin', 'Baranain', 'Baran''jajn,Baranain,Barañáin,Бараньяйн', 42.8056700, -1.6773100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47884, 'Baralla', 'Baralla', 'Baralla,Neira de Jusa,Neira de Xusa,Neira de Xusá', 42.8920700, -7.2549200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47885, 'Barajas de Melo', 'Barajas de Melo', 'Barajas de Melo', 40.1234000, -2.9167500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47886, 'Barajas de Madrid', 'Barajas de Madrid', 'Barajas,Barajas Madrid,MAD', 40.4736600, -3.5777700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47887, 'Baquerín de Campos', 'Baquerin de Campos', 'Baquerin de Campos,Baquerín de Campos', 42.0160000, -4.7818500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47888, 'Bañuelos de Bureba', 'Banuelos de Bureba', 'Banuelos de Bureba,Bañuelos de Bureba', 42.5025800, -3.2795700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47889, 'Bañuelos', 'Banuelos', 'Banuelos,Bañuelos', 41.2860100, -2.9147700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47890, 'Baños de Valdearados', 'Banos de Valdearados', 'Banos de Valdearados,Baños de Valdearados', 41.7701000, -3.5558900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47891, 'Baños de Tajo', 'Banos de Tajo', 'Banos de Tajo,Baños de Tajo', 40.7166700, -1.9666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47892, 'Baños de Río Tobía', 'Banos de Rio Tobia', 'Banos de Rio Tobia,Baños de Río Tobía', 42.3353300, -2.7609900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47893, 'Baños de Rioja', 'Banos de Rioja', 'Ban''jos-de-Riokha,Ban''os-de-Riokha,Banios de Rioxa,Banos de Rioja,Baños de Rioja,ba ni ao si de li ao ha,Баньйос-де-Ріоха,Баньос-де-Риоха,Բանիոս դե Ռիոխա,巴尼奥斯德里奥哈', 42.5123000, -2.9463500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47894, 'Baños de Montemayor', 'Banos de Montemayor', '', 40.3167100, -5.8600900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47895, 'Baños de Molgas', 'Banos de Molgas', '', 42.2414800, -7.6722300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47896, 'Bañón', 'Banon', 'Banon,Bañón', 40.8382500, -1.1909100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47897, 'Banyoles', 'Banyoles', 'Banolas,Banyoles,Bañolas', 42.1166700, 2.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47898, 'Bañobárez', 'Banobarez', 'Banobarez,Bañobárez', 40.8482500, -6.6131100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47899, 'Bande', 'Bande', 'Bande', 42.0312000, -7.9748900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47900, 'Banastás', 'Banastas', 'Banastas,Banastás', 42.1808900, -0.4519100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47901, 'Bañares', 'Banares', 'Ban''jares,Banares,Baniares,Bañares,ba ni ya lei si,Баньярес,Բանիարես,巴尼亚雷斯', 42.4683800, -2.9101000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47902, 'Baltar', 'Baltar', 'Baltar', 41.9520000, -7.7158100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47903, 'Baltanás', 'Baltanas', 'Baltanas,Baltanás', 41.9377500, -4.2465600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47904, 'Balsareny', 'Balsareny', 'Balsareny', 41.8631100, 1.8735600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47905, 'Ballobar', 'Ballobar', 'Argavieso,Ballobar', 41.6210600, 0.1920000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47906, 'Baliarrain', 'Baliarrain', 'Baliarrain,Baliarráin', 43.0692800, -2.1278100, 'ES', '2012-11-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47907, 'Balconchán', 'Balconchan', 'Valconchan,Valconchán', 41.0873700, -1.4599800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47908, 'Balboa', 'Balboa', 'Balboa', 42.7060800, -6.9222200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47909, 'Balaguer', 'Balaguer', 'Balaguer', 41.7911700, 0.8109400, 'ES', '2016-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47910, 'Bailo', 'Bailo', 'Bajlo,bai luo,Байло,拜洛', 42.5090600, -0.8113600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47911, 'Baides', 'Baides', 'Baides', 41.0068500, -2.7762000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47912, 'Bahabón de Esgueva', 'Bahabon de Esgueva', 'Bahabon de Esgueva,Bahabón de Esgueva', 41.8616200, -3.7298000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47913, 'Bahabón', 'Bahabon', 'Bahabon,Bahabón', 41.4814100, -4.2794100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47914, 'Begur', 'Begur', 'Bagur,Begur', 41.9500000, 3.2166700, 'ES', '2013-06-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47915, 'Bagüés', 'Bagues', '', 42.5493500, -0.9457700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47916, 'Báguena', 'Baguena', '', 41.0418100, -1.3576700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47917, 'Bagà', 'Baga', 'Baga,Bagà,Bagá,Бага', 42.2528900, 1.8609800, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47918, 'Baells', 'Baells', 'Baells', 41.9532500, 0.4595600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47919, 'Badules', 'Badules', 'Badules', 41.1390100, -1.2536600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47920, 'Bádenas', 'Badenas', 'Badenas,Bádenas', 41.0921600, -1.1224100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47921, 'Badarán', 'Badaran', 'Badaran,Badarán', 42.3679400, -2.8107900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47922, 'Badalona', 'Badalona', 'Badalona,Gorad Badalona,ba da lon a,ba da luo na,badallona,badalona,badalwna,badarona,Μπαδαλόνα,Бадалона,Горад Бадалона,Բադալոնա,بادالونا,बाडालोना,บาดาโลนา,ბადალონა,バダロナ,巴达洛纳,바달로나', 41.4500400, 2.2474100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47923, 'Bakaiku', 'Bakaiku', 'Bacaicoa,Bacáicoa,Bakaiku', 42.8924400, -2.1025100, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47924, 'Babilafuente', 'Babilafuente', 'Babilafuente', 40.9770400, -5.4255400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47925, 'Azuqueca de Henares', 'Azuqueca de Henares', 'Asukeka-de-Ehnares,Asukeka-de-Enares,Azuqueca,Azuqueca de Henares,a su ke ka de ai na lei si,Асукека-де-Енарес,Асукека-де-Энарес,阿苏克卡德埃纳雷斯', 40.5656600, -3.2675300, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47926, 'Azuelo', 'Azuelo', '', 42.6084400, -2.3498700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47927, 'Azuara', 'Azuara', 'Azuara', 41.2582200, -0.8707800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47928, 'Azpeitia', 'Azpeitia', 'Aspejtia,Aspejtija,Azpeitia,a si pei di ya,asupeitia,athbytya,Аспейтиа,Аспейтія,أثبيتيا,アスペイティア,阿斯佩蒂亚', 43.1824600, -2.2669300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47929, 'Azofra', 'Azofra', 'Asofra,Azofra,a suo fu la,Асофра,Ասոֆրա,阿索夫拉', 42.4240000, -2.8008600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47930, 'Azlor', 'Azlor', 'Aflor,Azlor', 42.0942700, -0.0459400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47931, 'Azkoitia', 'Azkoitia', 'Azcoitia,Azkoitia', 43.1774400, -2.3112900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47932, 'Azara', 'Azara', 'Azara', 42.0703300, -0.0292100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47933, 'Azagra', 'Azagra', 'Azagra', 42.3000000, -1.9000000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47934, 'Ayuela', 'Ayuela', 'Ayuela', 42.6261800, -4.6597900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47935, 'Aitona', 'Aitona', 'Aitona,Aytona', 41.4833300, 0.4666700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47936, 'Ayoó de Vidriales', 'Ayoo de Vidriales', 'Ayoo de Vidriales,Ayoó de Vidriales', 42.1304200, -6.0655000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47937, 'Ayllón', 'Ayllon', 'Ayllon,Ayllón', 41.4189900, -3.3753700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47938, 'Aiguafreda', 'Aiguafreda', 'Aiguafreda', 41.7680700, 2.2505100, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47939, 'Ayerbe', 'Ayerbe', 'Aerbe,Ayerbe,a ye wei,ai~erube,ayeleube,Аербе,Аєрбе,アイェルベ,阿耶韦,아예르베', 42.2726700, -0.6884400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47940, 'Ayegui', 'Ayegui', '', 42.6565600, -2.0393400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47941, 'Aia', 'Aya', 'Aia,Aya', 43.2372100, -2.1483300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47942, 'Axpe-San Bartolome', 'Busturi-Axpe', 'Axpe de Busturia,Axpe-San Bartolome,Busturi-Axpe', 43.3833300, -2.7000000, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47943, 'Avión', 'Avion', 'Avion,Avión,San Justo,Santos Justo y Pastor', 42.3833300, -8.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47944, 'Avinyonet del Penedès', 'Avinyonet del Penedes', 'Avinyonet,Avinyonet del Penedes,Avinyonet del Penedès', 41.3500000, 1.7833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47945, 'Avinyó', 'Avinyo', 'Avinyo,Avinyó', 41.8636700, 1.9709500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47946, 'Avinyonet de Puigventós', 'Avinyonet de Puigventos', 'Avinyonet de Puigventos,Avinyonet de Puigventós', 42.2498400, 2.9150900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47947, 'Avilés', 'Aviles', 'Aviles,Avilesas,Avileso,Avilés,a wei lai si,abilleseu,abiresu,abyls,afylys,awyls,Авилес,Авілес,آبیلس,أفيليس,اویلس,アビレス,阿维莱斯,아빌레스', 43.5547300, -5.9248300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47948, 'Ávila', 'Avila', 'AVJ,Abela,Abila,Abula,Aebura,Albicella,Avela,Avila,Avila de los Caballeros,Avila de los Leales,Avila de los Santos,Avila del Rey,Avilo,Obila,abira,Àvila,Ávila,Ávila de los Caballeros,Ávila de los Leales,Ávila de los Santos,Ávila del Rey,Авила,アビラ', 40.6572400, -4.6995100, 'ES', '2014-06-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47949, 'Avià', 'Avia', 'Avia,Avià,Aviá', 42.0666700, 1.8500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47950, 'Avellanosa de Muñó', 'Avellanosa de Muno', 'Avellanosa de Muno,Avellanosa de Muñó', 41.9834900, -3.8255300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47951, 'Avellaneda', 'Urrestieta', 'Avellaneda,Avellaneda-Sopuerta,Urrestieta', 43.2294200, -3.1617200, 'ES', '2012-11-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47952, 'Avellaneda', 'Avellaneda', 'Avellaneda', 40.3890900, -5.3881100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47953, 'Aveinte', 'Aveinte', 'Aveinte', 40.7822700, -4.8364900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47954, 'Autol', 'Autol', 'Autol', 42.2166100, -2.0052500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47955, 'Autillo de Campos', 'Autillo de Campos', 'Autillo de Campos', 42.0872500, -4.8337600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47956, 'Autilla del Pino', 'Autilla del Pino', 'Autilla del Pino', 41.9920700, -4.6339300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47957, 'Ausejo de la Sierra', 'Ausejo de la Sierra', 'Ausejo de la Sierra', 41.8946200, -2.3739400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47958, 'Ausejo', 'Ausejo', 'Ausejo,Ausekho,Ausexo,ao sai huo,Аусехо,Աուսեխո,奥塞霍', 42.3421000, -2.1671000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47959, 'Auñón', 'Aunon', 'Aunon,Auñón', 40.5175200, -2.7925000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47960, 'Aulesti', 'Aulesti', 'Aulesti,Aulestia', 43.3000000, -2.5666700, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47961, 'Atienza', 'Atienza', 'At''ensa,Atientha,a di en sa,atyntha,Ατιένθα,Атьенса,Атьєнса,أتينثا,阿蒂恩萨', 41.1972200, -2.8712900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47962, 'Ateca', 'Ateca', 'Ateca', 41.3309200, -1.7935300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47963, 'Atea', 'Atea', 'Atea', 41.1605900, -1.5553300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47964, 'Ataun', 'Ataun', 'Ataun,Atáun', 43.0061200, -2.1766300, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47965, 'Ataquines', 'Ataquines', 'Ataquines', 41.1824700, -4.8031900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47966, 'Atapuerca', 'Atapuerca', '', 42.3775700, -3.5079000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47967, 'Asturianos', 'Asturianos', 'Asturianos', 42.0520100, -6.4894000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47968, 'Astudillo', 'Astudillo', '', 42.1933000, -4.2939400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47969, 'Astorga', 'Astorga', 'Astorga,Asturica Augusta,Асторга', 42.4587900, -6.0560100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47970, 'Astigarraga', 'Astigarraga', 'Astigarraga', 43.2817400, -1.9463400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47971, 'Asteasu', 'Asteasu', 'Asteasu', 43.1943600, -2.0981800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47972, 'Aspariegos', 'Aspariegos', 'Aspariegos', 41.6745800, -5.5995500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47973, 'Aspa', 'Aspa', 'Aspa', 41.4947200, 0.6727700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47974, 'Ascó', 'Asco', 'Asco,Ascó', 41.1833300, 0.5666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47975, 'Arzúa', 'Arzua', 'Arzua,Arzúa', 42.9333300, -8.1500000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47976, 'Artieda', 'Artieda', '', 42.5853800, -0.9842200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47977, 'Artesa de Segre', 'Artesa de Segre', 'Artesa de Segre', 41.8946700, 1.0462500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47978, 'Artés', 'Artes', 'Artes,Artés', 41.7980000, 1.9542800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47979, 'Arteixo', 'Arteixo', '', 43.3048200, -8.5074900, 'ES', '2016-12-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47980, 'Artazu', 'Artazu', 'Artazu', 42.6922800, -1.8395400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47981, 'Artajona', 'Artajona', 'Artajona,Artaxoa', 42.5886700, -1.7650400, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47982, 'Arrúbal', 'Arrubal', 'Arrubal,Arrúbal', 42.4348500, -2.2514300, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47983, 'Arruazu', 'Arruazu', '', 42.9218600, -2.0015700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47984, 'Arroyomolinos de la Vera', 'Arroyomolinos de la Vera', 'Arabo,Arroyomolinos de la Vera', 40.0527700, -5.8511100, 'ES', '2017-02-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47985, 'Arroyomolinos', 'Arroyomolinos', 'Aorroyomolinos,Aroyomolinos,Arrojomolinos,aloyomollinoseu,Арройомолинос,Арройомолінос,Առոյոմոլինոս,아로요몰리노스', 40.2695100, -3.9194600, 'ES', '2017-05-03', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47986, 'Arroyo de las Fraguas', 'Arroyo de las Fraguas', 'Arroyo de las Fraguas', 41.1024600, -3.1300500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47987, 'Arroyo', 'Arroyo', '', 41.6095600, -4.7969200, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47988, 'Arróniz', 'Arroniz', 'Arroitz,Arroniz,Arróniz', 42.5882300, -2.0923700, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47989, 'Arrigorriaga', 'Arrigorriaga', 'Arrigorriaga,Arrigunaga,a li ge li ya jia,arayghwrygha,Арригорриага,Аррігорріага,أرايغوريغا,阿里戈里亚加', 43.2100600, -2.8856200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47990, 'Arriba', 'Arriba', 'Arriba', 43.5161500, -5.5351100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47991, 'Arredondo', 'Arredondo', 'Arredondo', 43.2732500, -3.6003100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47992, 'Arraya de Oca', 'Arraya de Oca', 'Arraya de Oca', 42.4148800, -3.3978100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47993, 'Arrancacepas', 'Arrancacepas', 'Arrancacepas', 40.3032000, -2.3589900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47994, 'Arrabalde', 'Arrabalde', 'Arrabalde,Arrabalde de Vidriales', 42.1076000, -5.8944100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47995, 'Arquillinos', 'Arquillinos', 'Arquillinos', 41.7099000, -5.6570800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47996, 'Arnuero', 'Arnuero', 'Arnuehro,Arnuero,a er nu ai luo,arnyrw,Арнуеро,Арнуэро,أرنيرو,阿尔努埃罗', 43.4775600, -3.5695900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47997, 'Arnedo', 'Arnedo', 'Arnedo,a er nei duo,aleunedo,arnydw,arunedo,Арнедо,Արնեդո,أرنيدو,アルネド,阿尔内多,아르네도', 42.2280000, -2.1008300, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47998, 'Arnedillo', 'Arnedillo', 'Arnediello,Arnedil''jo,Arnedil''o,Arnedilio,a er nei di e,Арнедильо,Арнедільйо,Արնեդիլիո,阿尔内迪略', 42.2122100, -2.2360200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(47999, 'Armuña de Tajuña', 'Armuna de Tajuna', 'Armuna de Tajuna,Armuña de Tajuña', 40.5288400, -3.0281900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48000, 'Armuña', 'Armuna', 'Armuna,Armuña', 41.0771500, -4.3194900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48001, 'Armiñón', 'Arminon', 'Araminon,Aramiñon,Arminon,Armiñón', 42.7231300, -2.8717200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48002, 'Armenteros', 'Armenteros', 'Armenteros', 40.5932000, -5.4480600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48003, 'Armañanzas', 'Armananzas', 'Armanantzas,Armananzas,Armañantzas,Armañanzas', 42.5596300, -2.2847600, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48004, 'Armallones', 'Armallones', 'Armallones', 40.7358000, -2.3025700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48005, 'Arlanzón', 'Arlanzon', 'Arlanson,Arlanzon,Arlanzón,arlansn,arlanzwn,Арлансон,Արլանսոն,آرلانسن,أرلانزون', 42.3226700, -3.4578400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48006, 'Ariza', 'Ariza', 'Ariza', 41.3144200, -2.0533200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48007, 'Aribe', 'Aribe', 'Aribe,Arive', 42.9500000, -1.2500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48008, 'Ariño', 'Arino', '', 41.0301900, -0.5920600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48009, 'Arija', 'Arija', 'Arija', 42.9935000, -3.9449700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48010, 'Aria', 'Aria', 'Aria', 42.9528300, -1.2658400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48011, 'Argujillo', 'Argujillo', 'Argujillo', 41.3115600, -5.5876300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48012, 'Arguis', 'Arguis', 'Arguis', 42.3147600, -0.4396700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48013, 'Arguedas', 'Arguedas', 'Argedas,Arguedas,Arketas,a er ge da si,Аргедас,阿尔格达斯', 42.1775900, -1.5971900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48014, 'Argoños', 'Argonos', 'Argon''jos,Argon''os,Argonos,Argoños,a er ge ni ao si,arghwnyws,Аргоньйос,Аргоньос,أرغونيوس,阿尔戈尼奥斯', 43.4574000, -3.4901300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48015, 'Argentona', 'Argentona', 'Argentona', 41.5533600, 2.4011400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48016, 'Argente', 'Argente', 'Argente', 40.6884100, -1.1621700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48017, 'Argelita', 'Argelita', 'Argeleta,Argelita', 40.0500000, -0.3500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48018, 'Argelaguer', 'Argelaguer', '', 42.2156300, 2.6419300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48019, 'Argecilla', 'Argecilla', 'Argecilla', 40.8815100, -2.8218100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48020, 'Argavieso', 'Argavieso', 'Argavieso', 42.0527500, -0.2783400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48021, 'Arganza', 'Arganza', 'Arganza', 42.6407700, -6.6862700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48022, 'Argañín', 'Arganin', 'Arganin,Argañín', 41.4394800, -6.2082700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48023, 'Arganda', 'Arganda', 'Arganda,Arganda del Rey,Арганда', 40.3007600, -3.4372200, 'ES', '2016-07-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48024, 'Arévalo de la Sierra', 'Arevalo de la Sierra', 'Arevalo de la Sierra,Arevalo-de-la-S''erra,Arévalo de la Sierra,a lei wa luo de la xie la,Аревало-де-ла-Сьерра,Аревало-де-ла-Сьєрра,阿雷瓦洛德拉谢拉', 41.9472300, -2.4003300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48025, 'Arévalo', 'Arevalo', 'Arevalo,Arévalo,a lei wa luo,arbalw,arebaro,aryfalw,Аревало,آربالو,أريفالو,アレバロ,阿雷瓦洛', 41.0625500, -4.7204200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48026, 'Arevalillo de Cega', 'Arevalillo de Cega', 'Arevalillo de Cega', 41.1617400, -3.8891100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48027, 'Areso', 'Areso', 'Areso', 43.0820900, -1.9519800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48028, 'Ares del Maestre', 'Ares del Maestre', 'Ares del Maestrat,Ares del Maestre', 40.4567500, -0.1326700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48029, 'Ares', 'Ares', '', 43.4299500, -8.2425400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48030, 'Arenzana de Arriba', 'Arenzana de Arriba', 'Arenzana de Arriba', 42.3874500, -2.6949400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48031, 'Arenzana de Abajo', 'Arenzana de Abajo', 'Arenzana de Abajo', 42.3859900, -2.7194000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48032, 'Arenys de Munt', 'Arenys de Munt', 'Arenys de Munt', 41.6142400, 2.5397200, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48033, 'Arenys de Mar', 'Arenys de Mar', 'Aren''s-de-Mar,Aren''sh-da-Mar,Arenis de Mar,Arenys de Mar,aleniseudemaleu,arnys d mar,arynys dy mar,bin hai a lei ni si,Ареньс-де-Мар,Ареньш-да-Мар,Արենիս դե Մար,آرنیس د مار,أرينيس دي مار,滨海阿雷尼斯,아레니스데마르', 41.5819000, 2.5493600, 'ES', '2016-10-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48034, 'Arenys de Lledó / Arens de Lledó', 'Arenys de Lledo / Arens de Lledo', 'Arens de Lledo,Arens de Lledó,Arenys de Lledo,Arenys de Lledó', 40.9924400, 0.2709200, 'ES', '2012-03-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48035, 'Arenillas', 'Arenillas', 'Arenillas', 41.3470600, -2.8461800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48036, 'Arenas de San Pedro', 'Arenas de San Pedro', 'Arenas de San Pedro,Arenas-de-San-Pedro,a lei na si de sheng pei de luo,arnas d san pdrw,arynas dy san bydrw,Аренас де Сан Педро,Аренас-де-Сан-Педро,آرناس د سان پدرو,أريناس دي سان بيدرو,阿雷纳斯德圣佩德罗', 40.2104100, -5.0869400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48037, 'Arenas de Iguña', 'Arenas de Iguna', 'Arenas de Iguna,Arenas de Iguña,Arenas-de-Igun''ja,Arenas-de-Igunija,Las Arenas,a lei na si de gu ni ya,arynas dy aghwynya,Аренас-де-Ігунья,Аренас-де-Игуния,أريناس دي أغوينيا,阿雷纳斯德古尼亚', 43.1829300, -4.0472900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48038, 'Arellano', 'Arellano', 'Arellano', 42.6059800, -2.0465300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48039, 'Aretxabaleta', 'Aretxabaleta', 'Arechavaleta,Aretxabaleta', 43.0341400, -2.5045600, 'ES', '2012-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48040, 'Ardón', 'Ardon', 'Ardon,Ardón', 42.4362900, -5.5604800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48041, 'Arcos de la Sierra', 'Arcos de la Sierra', 'Arcos de la Sierra', 40.3466400, -2.1131000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48042, 'Arcos de la Polvorosa', 'Arcos de la Polvorosa', 'Arcos de la Polvorosa', 41.9438900, -5.6973100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48043, 'Arcos de Jalón', 'Arcos de Jalon', 'Arcos,Arcos de Jalon,Arcos de Jalón,Arcos de Xalon,Arcos de Xalón,Arkos-de-Khalon,a er ke si de ha long,Аркос-де-Халон,阿尔科斯德哈隆', 41.2159200, -2.2747000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48044, 'Arcos', 'Arcos', 'Arcos de la Llana,Arkos,Arkos-de-la-L''jana,arks,arksh,Аркос,Аркос-де-ла-Льяна,آرکس,أركش', 42.2666400, -3.7545800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48045, 'Arcones', 'Arcones', 'Arcones', 41.1181700, -3.7238400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48046, 'Arconada', 'Arconada', 'Arconada', 42.3277400, -4.4961700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48047, 'Arcicóllar', 'Arcicollar', 'Arcicollar,Arcicóllar', 40.0551700, -4.1163800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48048, 'Arcenillas', 'Arcenillas', 'Arcenillas', 41.4564100, -5.6851200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48049, 'Arcediano', 'Arcediano', 'Arcediano', 41.0937900, -5.5605500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48050, 'Arbúcies', 'Arbucies', 'Arbucies,Arbúcies', 41.8166700, 2.5166700, 'ES', '2015-06-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48051, 'Arbo', 'Arbo', 'Arbo,Santa Maria,Santa María,a er wo,arbw,arubo,Арбо,آربو,أربو,アルボ,阿尔沃', 42.1166700, -8.3166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48052, 'Arbizu', 'Arbizu', 'Arbizu', 42.9154500, -2.0391700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48053, 'Arbeteta', 'Arbeteta', 'Arbeteta', 40.6699900, -2.4023600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48054, 'Arbeca', 'Arbeca', 'Arbeca', 41.5415300, 0.9245700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48055, 'Arbancón', 'Arbancon', '', 40.9643400, -3.1150500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48056, 'Araia', 'Araya', 'Araia,Araya,Asparren,Asparrena,Aspárrena', 42.8934500, -2.3131400, 'ES', '2012-11-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48057, 'Arauzo de Torre', 'Arauzo de Torre', 'Arauzo de Torre', 41.7981800, -3.4231400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48058, 'Arauzo de Salce', 'Arauzo de Salce', 'Arauzo de Salce', 41.8191900, -3.4119100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48059, 'Arauzo de Miel', 'Arauzo de Miel', 'Arauzo de Miel', 41.8587800, -3.3877300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48060, 'Aras', 'Aras', 'Aras,Tres Aras', 42.5617200, -2.3560000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48061, 'Arapiles', 'Arapiles', 'Arapiles', 40.8936600, -5.6449400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48062, 'Aranzueque', 'Aranzueque', 'Aranzueque', 40.4909400, -3.0744800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48063, 'Arañuel', 'Aranuel', 'Aranuel,Aranyel,Arañuel', 40.0666700, -0.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48064, 'Arano', 'Arano', 'Arano', 43.1995600, -1.8956900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48065, 'Aranjuez', 'Aranjuez', 'Aranchuesas,Aranguesia,Aranjuez,Arankhuehs,Arankhues,Arankhuez,a lan hu ai si,alanhueseu,aranfuesu,arnkhwyth,Аранхуез,Аранхуес,Аранхуэс,ארנחואס,آرنخويث,アランフエス,阿兰胡埃斯,아란후에스', 40.0310800, -3.6024600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48066, 'Aranga', 'Aranga', 'Aranga,San Pelayo', 43.2346900, -8.0170500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48067, 'Arandilla del Arroyo', 'Arandilla del Arroyo', 'Arandilla,Arandilla del Arroyo', 40.5105600, -2.3835500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48068, 'Arandilla', 'Arandilla', 'Arandilla', 41.7377800, -3.4291400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48069, 'Arándiga', 'Arandiga', 'Arandiga,Arándiga', 41.5087200, -1.5007400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48070, 'Aranda de Moncayo', 'Aranda de Moncayo', 'Aranda de Moncayo', 41.5774900, -1.7917100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48071, 'Aranda de Duero', 'Aranda de Duero', 'Aranda,Aranda de Duero,Aranda-de-Duehro,Aranda-de-Duero,aranda dy dwyrw,du luo he pan a lan da,Аранда-де-Дуеро,Аранда-де-Дуэро,أراندا دي دويرو,アランダ・デ・ドゥエロ,杜罗河畔阿兰达', 41.6704100, -3.6892000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48072, 'Arancón', 'Arancon', 'Arancon,Aranconi vald,Arancón,Arancóni vald,Arankon,Arankona,Arankonas,a lan kong,arankon,arankwn,Аранкон,آرانکون,アランコン,阿兰孔', 41.8001700, -2.2814100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48073, 'Arantza', 'Arantza', 'Aranatz,Aranaz,Arantza', 43.1962300, -1.7249400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48074, 'Aranarache', 'Aranarache', 'Aranarache,Aranaratxe', 42.7797900, -2.2292400, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48075, 'Arama', 'Arama', 'Arama', 43.0633500, -2.1654000, 'ES', '2012-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48076, 'Arahuetes', 'Arahuetes', 'Arahuetes', 41.1376200, -3.8566400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48077, 'Aragüés del Puerto', 'Aragues del Puerto', '', 42.7064100, -0.6699900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48078, 'Elexalde', 'Elexalde', 'Aracaldo,Arakaldo', 43.1500000, -2.9333300, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48079, 'Aoiz', 'Aoiz', '', 42.7863300, -1.3725200, 'ES', '2008-07-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48080, 'Antzuola', 'Anzuola', 'Antzuola,Anzuola', 43.0972500, -2.3799800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48081, 'Antillón', 'Antillon', 'Antillon,Antillón', 42.0363900, -0.1623900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48082, 'Antigüedad', 'Antiguedad', 'Antiguedad,Antigüedad', 41.9468100, -4.1205800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48083, 'Ansó', 'Anso', 'Anso,Ansó,Berari,an suo,Ансо,安索', 42.7578500, -0.8294700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48084, 'Anquela del Pedregal', 'Anquela del Pedregal', 'Anquela del Pedregal', 40.7433600, -1.7369700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48085, 'Anquela del Ducado', 'Anquela del Ducado', 'Anquela del Ducado', 40.9708400, -2.1306600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48086, 'Añover de Tormes', 'Anover de Tormes', 'Anover de Tormes,Añover de Tormes', 41.1365800, -5.9158500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48087, 'Añorbe', 'Anorbe', '', 42.6573200, -1.7149000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48088, 'Anoeta', 'Anoeta', 'Anoeta', 43.1624100, -2.0710700, 'ES', '2012-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48089, 'Anguix', 'Anguix', 'Anguix', 41.7533100, -3.9312500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48090, 'Anguita', 'Anguita', 'Anguita', 41.0265900, -2.3684900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48091, 'Anguiano', 'Anguiano', 'Angiano,Anguiano,an ji ya nuo,Ангиано,Ангіано,Անգիանո,安吉亚诺', 42.2638100, -2.7646300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48092, 'Angüés', 'Angues', 'Angues,Angüés', 42.1110900, -0.1529800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48093, 'Anguciana', 'Anguciana', 'Anguciana', 42.5742100, -2.9012400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48094, 'Anglesola', 'Anglesola', 'Anglesola', 41.6564900, 1.0828600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48095, 'Anglès', 'Angles', 'Angles,Anglès', 41.9561700, 2.6360300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48096, 'Anento', 'Anento', 'Anento', 41.0695800, -1.3337500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48097, 'Añe', 'Ane', 'Ane,Añe', 41.0370200, -4.2946200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48098, 'Andosilla', 'Andosilla', 'Andosilla', 42.3814400, -1.6730500, 'ES', '2014-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48099, 'Andorra', 'Andorra', 'Andorra', 40.9765500, -0.4472100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48100, 'Andoain', 'Andoain', 'Andoain,Andoaín,Andoáin', 43.2165800, -2.0253000, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48101, 'Ancín', 'Ancin', 'Antzin', 42.6604700, -2.1888500, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48102, 'Anchuelo', 'Anchuelo', 'Anchuelo', 40.4652700, -3.2683800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48103, 'Anaya de Alba', 'Anaya de Alba', 'Anaya de Alba', 40.7282800, -5.4926600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48104, 'Anaya', 'Anaya', 'Anaya', 40.9918400, -4.3095000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48105, 'Anadón', 'Anadon', 'Anadon,Anadón', 40.9822500, -0.9836700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48106, 'Amusquillo', 'Amusquillo', 'Amusquillo', 41.7485300, -4.3011700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48107, 'Amusco', 'Amusco', 'Amusco', 42.1730600, -4.4701800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48108, 'Amurrio', 'Amurrio', 'Amurio,Amurrio,a mu li ao,amwryw,Амурио,Амуррио,Амурріо,آموریو,أموريو,阿穆里奥', 43.0500000, -3.0000000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48109, 'Ampuero', 'Ampuero', 'Ampuehro,Ampuero,ambyrw,ampwyrw,an pu ai luo,Ампуеро,Ампуэро,أمبيرو,امپوئرو,安普埃罗', 43.3426800, -3.4166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48110, 'Ampudia', 'Ampudia', 'Ampudia', 41.9160800, -4.7803300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48111, 'Amposta', 'Amposta', 'Amposta', 40.7099500, 0.5785600, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48112, 'Amoroto', 'Amoroto', 'Amoroto', 43.3263400, -2.5134900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48113, 'Amorebieta', 'Amorebieta', 'Amorebieta,Amorebieta-Echano,Amorebieta-Etxano,Zornotza', 43.2166700, -2.7333300, 'ES', '2012-12-01', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48114, 'Amoeiro', 'Amoeiro', 'Amoeiro', 42.4166700, -7.9500000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48115, 'Amieva', 'Amieva', 'Am''eva,Ameva,Amieva,a mi ye wa,amyba,amyfa,Амьева,Амєва,آمیبا,أميفا,阿米耶瓦', 43.2440300, -5.0746000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48116, 'Amezketa', 'Amezqueta', 'Amezketa,Amezqueta,Amézqueta', 43.0481300, -2.0854100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48117, 'Ameyugo', 'Ameyugo', 'Ameyugo', 42.6561700, -3.0617000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48118, 'Amés', 'Ames', 'Ehjmsa,Santo Tomas,Santo Tomás,Эймса', 42.9042600, -8.6555100, 'ES', '2015-06-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48119, 'Ambite', 'Ambite', 'Ambite', 40.3319000, -3.1803400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48120, 'Ambía', 'Ambia', 'Ambia,Ambía,San Esteban', 42.2057800, -7.7370700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48121, 'Ambel', 'Ambel', 'Ambel', 41.7947200, -1.6152000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48122, 'Amayuelas de Arriba', 'Amayuelas de Arriba', 'Amayuelas de Arriba', 42.2110800, -4.4888000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48123, 'Amavida', 'Amavida', 'Amavida', 40.5737100, -5.0654100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48124, 'Altzaga', 'Alzaga', 'Altzaga,Alzaga', 43.0646800, -2.1540000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48125, 'Alustante', 'Alustante', 'Alustante', 40.6144200, -1.6591000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48126, 'Altafulla', 'Altafulla', '', 41.1428600, 1.3726900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48127, 'Altable', 'Altable', 'Altable', 42.6027600, -3.0771900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48128, 'Altsasu', 'Altsasu', 'Al''casu,Al''sasua,Alsasua,Alsasua – Altsasu,Altsasu,Altsasu/Alsasua,a er te sa su,Альсасуа,Альцасу,阿尔特萨苏', 42.8999900, -2.1651600, 'ES', '2011-01-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48129, 'Alkiza', 'Alquiza', 'Alkiza,Alquiza', 43.1726300, -2.1092300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48130, 'Alquézar', 'Alquezar', 'Alquezar,Alquezra', 42.1726800, 0.0258600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48131, 'Alpicat', 'Alpicat', 'Alpicat', 41.6657000, 0.5556400, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48132, 'Alpens', 'Alpens', '', 42.1193000, 2.1013500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48133, 'Alpeñés', 'Alpenes', 'Alpenes,Alpeñés', 40.7995800, -1.0662500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48134, 'Alpedrete', 'Alpedrete', '', 40.6588900, -4.0251200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48135, 'Alpartir', 'Alpartir', 'Alpartir', 41.4225300, -1.3806100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48136, 'Alpanseque', 'Alpanseque', 'Alpanseque', 41.2650500, -2.6706400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48137, 'Alp', 'Alp', '', 42.3725600, 1.8869900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48138, 'Alovera', 'Alovera', 'Alovera', 40.5936800, -3.2452900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48139, 'Alonsotegi', 'Alonsotegi', 'Alonsotegi,Alonsotegui,Alonsótegui', 43.2448300, -2.9875900, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48140, 'Alocén', 'Alocen', 'Alocen,Alocén', 40.5745500, -2.7499300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48141, 'Alobras', 'Alobras', 'Alobras', 40.1816900, -1.3873100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48142, 'Almuniente', 'Almuniente', 'Almuniente', 41.9494900, -0.4117300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48143, 'Almudébar', 'Almudebar', 'Almudebar,Almudevar,Almudébar', 42.0425500, -0.5814100, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48144, 'Almoster', 'Almoster', 'Almoster', 41.1975800, 1.1116700, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48145, 'Almorox', 'Almorox', 'Almora,Almorox', 40.2342300, -4.3904400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48146, 'Almonacid de Zorita', 'Almonacid de Zorita', 'Almonacid de Zorita', 40.3293200, -2.8504000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48147, 'Almonacid de la Sierra', 'Almonacid de la Sierra', '', 41.3975400, -1.3239400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48148, 'Almonacid de la Cuba', 'Almonacid de la Cuba', 'Almonacid de la Cuba', 41.2806700, -0.7926600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48149, 'Almohaja', 'Almohaja', 'Almohaja', 40.6048900, -1.4380000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48150, 'Almoguera', 'Almoguera', 'Almoguera', 40.2971300, -2.9824000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48151, 'Almochuel', 'Almochuel', 'Almochuel', 41.2799200, -0.5506700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48152, 'Almendral de la Cañada', 'Almendral de la Canada', 'Almendral de la Canada,Almendral de la Cañada', 40.1845600, -4.7417300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48153, 'Almendra', 'Almendra', 'Almendra', 41.2292200, -6.3406800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48154, 'Almenar de Soria', 'Almenar de Soria', 'Al''menar-de-Sorija,Almenar de Soria,a er mei na er de suo li ya,Альменар-де-Сория,Альменар-де-Сорія,阿尔梅纳尔德索里亚', 41.6823000, -2.2008200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48155, 'Almenara de Tormes', 'Almenara de Tormes', 'Almenara de Tormes', 41.0639000, -5.8235000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48156, 'Almenara de Adaja', 'Almenara de Adaja', 'Almenara de Adaja', 41.2140600, -4.6782400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48157, 'Almenar', 'Almenar', 'Almenar', 41.7960400, 0.5683400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48158, 'Almazul', 'Almazul', 'Al''masul'',Almazul,a er ma su er,Альмасуль,阿尔马苏尔', 41.5740000, -2.1462000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48159, 'Almazán', 'Almazan', 'Adnamantia,Al''masan,Al''mazan,Almasan,Almasana,Almasanas,Almasans,Almathan,Almazan,Almazani vald,Almazán,Almazáni vald,Gorad Al''masan,a lei ma sang,ai er ma shan zhen,ai er ma zhan zhen,almaZAN,almajana,almajhana,almasan,almasani,almazan,almazyn,arumasan,xal ma san,Αλμαθάν,Алмазан,Алмасан,Альмазан,Альмасан,Горад Альмасан,אלמסאן,آلمازان,آلماسان,المازين,ܐܠܡܐܙܢ,अल्माजान,आल्माझान,അൽമസാൻ,අල්මසාන්,อัลมาซัน,ალმასანი,አልማዛን,アルマサン,愛爾瑪詹鎮,艾爾瑪善鎮,阿嘞玛桑,', 41.4864800, -2.5308800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48160, 'Almarza de Cameros', 'Almarza de Cameros', 'Almarza de Cameros', 42.2165000, -2.5987300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48161, 'Almarza', 'Almarza', 'Al''marsa,Almarsa,Almarza,a er ma sa,almaleusa,almarza,arumarusa,Альмарса,آلمارزا,アルマルサ,阿尔马萨,알마르사', 41.9467800, -2.4690000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48162, 'Almaraz de Duero', 'Almaraz de Duero', 'Almaraz de Duero', 41.4750500, -5.9165400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48163, 'Almanza', 'Almanza', 'Al''mansa,Almanza,a er man sa,Альманса,阿尔曼萨', 42.6582500, -5.0362000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48164, 'Almaluez', 'Almaluez', 'Almaluez', 41.2893200, -2.2687100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48165, 'Almajano', 'Almajano', 'Almajano', 41.8509500, -2.3383000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48166, 'Almadrones', 'Almadrones', 'Almadrones', 40.9009600, -2.7740600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48167, 'Almacelles', 'Almacelles', 'Almacelles', 41.7321600, 0.4372200, 'ES', '2015-11-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48168, 'Allueva', 'Allueva', 'Allueva', 40.9853300, -1.0425800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48169, 'Alloza', 'Alloza', 'Alloza', 40.9694200, -0.5294100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48170, 'Allo', 'Allo', 'Allo', 42.5673800, -2.0205200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48171, 'Allepuz', 'Allepuz', 'Allepuz', 40.4929500, -0.7247800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48172, 'Allariz', 'Allariz', 'Allariz', 42.1904400, -7.8017500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48173, 'Aliud', 'Aliud', 'Aliud', 41.6541200, -2.2531400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48174, 'Alique', 'Alique', 'Alique', 40.5867100, -2.6444100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48175, 'Alió', 'Alio', 'Alio,Alió', 41.2942200, 1.3058500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48176, 'Aliaga', 'Aliaga', 'Aliaga', 40.6741100, -0.7033300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48177, 'Alhóndiga', 'Alhondiga', 'Alhondiga,Alhóndiga', 40.5266900, -2.8243800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48178, 'Alhama de Aragón', 'Alhama de Aragon', 'Alhama,Alhama de Aragon,Alhama de Aragón', 41.2965700, -1.8935800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48179, 'Alguaire', 'Alguaire', 'Alguaire', 41.7370300, 0.5845000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48180, 'Algorta', 'Algorta', 'Algorta', 43.3492700, -3.0094000, 'ES', '2007-11-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48181, 'Algora', 'Algora', 'Algora', 40.9632400, -2.6668800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48182, 'Algodre', 'Algodre', 'Algodre', 41.5663100, -5.6040600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48183, 'Algete', 'Algete', 'Algete', 40.5971100, -3.4974300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48184, 'Algerri', 'Algerri', 'Algerri', 41.8148200, 0.6363300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48185, 'Algar de Mesa', 'Algar de Mesa', 'Algar de Mesa', 41.1349400, -1.9596400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48186, 'Algadefe', 'Algadefe', 'Algadefe', 42.2193100, -5.5841900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48187, 'Alforque', 'Alforque', 'Alforque', 41.3294200, -0.3852500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48188, 'Alforja', 'Alforja', 'Alforja', 41.2110800, 0.9754200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48189, 'Alfés', 'Alfes', 'Alfes,Alfés', 41.5214300, 0.6205000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48190, 'Alfarràs', 'Alfarras', 'Alfarras,Alfarràs', 41.8166700, 0.5833300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48191, 'Alfaro', 'Alfaro', 'Alfaro', 42.1803200, -1.7501600, 'ES', '2012-10-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48192, 'Alfántega', 'Alfantega', '', 41.8283200, 0.1482300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48193, 'Alfamén', 'Alfamen', 'Alfamen,Alfamén', 41.4391900, -1.2445800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48194, 'Alfambra', 'Alfambra', 'Alfambra', 40.5463800, -1.0331400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48195, 'Alfajarín', 'Alfajarin', 'Alfajarin,Alfajarín', 41.6140000, -0.7037000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48196, 'Alesón', 'Aleson', 'Aleson,Alesón', 42.4055400, -2.6893800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48197, 'Alesanco', 'Alesanco', 'Alesanco', 42.4140900, -2.8166600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48198, 'Alerre', 'Alerre', 'Alerre', 42.1646800, -0.4636900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48199, 'Alentisque', 'Alentisque', 'Alentisque', 41.4205900, -2.3318900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48200, 'Alella', 'Alella', 'Alella', 41.4937900, 2.2945100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48201, 'Alegia', 'Alegria de Oria', 'Alegia,Alegria de Oria,Alegría de Oria', 43.1009700, -2.0963700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48202, 'Aldeonte', 'Aldeonte', 'Aldeonte', 41.3509200, -3.6784700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48203, 'Aldehuela de Yeltes', 'Aldehuela de Yeltes', 'Al''deuehla-de-El''tes,Al''deuela-de-El''tes,Aldehuela de Yeltes,a er de wei la de ai er te si,Альдеуела-де-Єльтес,Альдеуэла-де-Ельтес,阿尔德韦拉德埃尔特斯', 40.6625400, -6.2433200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48204, 'Aldehuela de Liestos', 'Aldehuela de Liestos', 'Aldehuela de Liestos', 41.0641000, -1.7010700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48205, 'Aldehuela del Codonal', 'Aldehuela del Codonal', 'Aldehuela del Codonal', 41.0550400, -4.5386300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48206, 'Aldehuela de la Bóveda', 'Aldehuela de la Boveda', 'Aldehuela de Boveda,Aldehuela de Bóveda,Aldehuela de la Boveda,Aldehuela de la Bóveda', 40.8507700, -6.0526000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48207, 'Aldeavieja de Tormes', 'Aldeavieja de Tormes', 'Aldeavieja de Tormes', 40.5830700, -5.6170500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48208, 'Aldeatejada', 'Aldeatejada', 'Aldeatejada', 40.9216800, -5.6927300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48209, 'Aldeasoña', 'Aldeasona', 'Aldeasona,Aldeasoña', 41.4728500, -4.0571100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48210, 'Aldeaseca de la Frontera', 'Aldeaseca de la Frontera', 'Aldeaseca de la Frontera', 40.9416100, -5.2071900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48211, 'Aldeaseca de Alba', 'Aldeaseca de Alba', 'Aldeaseca de Alba', 40.8190900, -5.4469900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48212, 'Aldeaseca', 'Aldeaseca', 'Aldeaseca', 41.0491200, -4.8170700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48213, 'Aldearrubia', 'Aldearrubia', 'Aldearrubia', 41.0080700, -5.4982900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48214, 'Aldearrodrigo', 'Aldearrodrigo', 'Aldearrodrigo', 41.1096600, -5.8072600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48215, 'Aldea Real', 'Aldea Real', 'Aldea Real', 41.1855300, -4.1655900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48216, 'Aldeanueva de Santa Cruz', 'Aldeanueva de Santa Cruz', 'Aldeanueva de Santa Cruz', 40.3818900, -5.4214200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48217, 'Aldeanueva del Codonal', 'Aldeanueva del Codonal', 'Aldeanueva del Codonal', 41.0823600, -4.5436900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48218, 'Aldeanueva del Camino', 'Aldeanueva del Camino', 'Aldeanueva del Camino', 40.2598000, -5.9288600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48219, 'Aldeanueva de la Vera', 'Aldeanueva de la Vera', 'Aldeanueva de la Vera', 40.1271000, -5.7015000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48220, 'Aldeanueva de la Sierra', 'Aldeanueva de la Sierra', 'Aldeanueva de la Sierra', 40.6162000, -6.1002300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48221, 'Aldeanueva de Guadalajara', 'Aldeanueva de Guadalajara', 'Aldeanueva de Guadalajara', 40.6798800, -3.0443800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48222, 'Aldeanueva de Figueroa', 'Aldeanueva de Figueroa', 'Aldeanueva de Figueroa', 41.1480900, -5.5240400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48223, 'Aldeanueva de Ebro', 'Aldeanueva de Ebro', 'Aldeanueva de Ebro', 42.2291100, -1.8873500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48224, 'Aldeamayor de San Martín', 'Aldeamayor de San Martin', 'Aldeamayor de San Martin,Aldeamayor de San Martín', 41.5125600, -4.6395500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48225, 'Aldealseñor', 'Aldealsenor', 'Aldealsenor,Aldealseñor', 41.8789000, -2.3156500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48226, 'Aldealpozo', 'Aldealpozo', 'Al''deal''poso,Aldealposo,Aldealpozo,a er de ya er bo suo,arudearuposo,Альдеальпосо,アルデアルポソ,阿尔德亚尔波索', 41.7825800, -2.2041600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48227, 'Aldealengua de Santa María', 'Aldealengua de Santa Maria', 'Aldealengua de Santa Maria,Aldealengua de Santa María', 41.4619600, -3.4672300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48228, 'Aldealengua', 'Aldealengua', 'Aldealengua', 40.9809000, -5.5492200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48229, 'Aldealcorvo', 'Aldealcorvo', 'Aldealcorvo', 41.2444300, -3.7913600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48230, 'Aldealafuente', 'Aldealafuente', 'Al''dealafuehnte,Al''dealafuente,Aldealafuente,a er de ya la feng te,arudearafuente,Альдеалафуенте,Альдеалафуэнте,アルデアラフエンテ,阿尔德亚拉丰特', 41.6719400, -2.3252200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48231, 'Aldea de San Miguel', 'Aldea de San Miguel', 'Aldea de San Miguel', 41.4609800, -4.6158000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48232, 'Aldea del Obispo', 'Aldea del Obispo', 'Aldea del Obispo', 40.7067700, -6.7925300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48233, 'Aldea del Fresno', 'Aldea del Fresno', '', 40.3236000, -4.2031900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48234, 'Aldeadávila de la Ribera', 'Aldeadavila de la Ribera', 'Al''deadavila-de-la-Ribera,Aldeadavila de la Ribera,Aldeadávila de la Ribera,Aldeiadavila da Ribera,Aldeiadávila da Ribera,Alveavila de la Ribera,a er de ya da wei la de la li wei la,Альдеадавила-де-ла-Рибера,Альдеадавіла-де-ла-Рібера,阿尔德亚达维拉德拉里韦拉', 41.2176900, -6.6178600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48235, 'Aldeacipreste', 'Aldeacipreste', 'Aldeacipreste', 40.3809000, -5.8975400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48236, 'Alcubilla de Nogales', 'Alcubilla de Nogales', 'Alcubilla,Alcubilla de Nogales', 42.1278700, -5.9218400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48237, 'Alcubilla de las Peñas', 'Alcubilla de las Penas', 'Al''kubil''ja-de-las-Pen''jas,Alcubilla de las Penas,Alcubilla de las Peñas,Alkuvilja de las Penjasa,a er ku wei li ya de la si pei ni ya si,alkwbyla dw las pnas,Алькубилья-де-лас-Пеньяс,Алькубілья-де-лас-Пеньяс,آلکوبیلا دو لاس پناس,阿尔库维利亚德拉斯佩尼亚斯', 41.2512900, -2.5268400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48238, 'Alcubilla de Avellaneda', 'Alcubilla de Avellaneda', 'Al''kubil''ja-de-Avel''janeda,Alcubilla de Avellaneda,a er ku wei li ya de ya wei li ya nei da,Алькубилья-де-Авельянеда,Алькубілья-де-Авельянеда,アルクビージャ・デ・アベジャネーダ,阿尔库维利亚德亚韦利亚内达', 41.7259300, -3.3047100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48239, 'Alcubierre', 'Alcubierre', 'Alcubierre', 41.8075700, -0.4529100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48240, 'Alcover', 'Alcover', 'Alcober,Alcover', 41.2626700, 1.1701000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48241, 'Alcoroches', 'Alcoroches', 'Alcoroches', 40.6266900, -1.7462900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48242, 'Alcorisa', 'Alcorisa', 'Alcoriza', 40.8921000, -0.3814300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48243, 'Alcorcón', 'Alcorcon', 'Al''korkon,Alcorcon,Alcorconum,Alcorcón,Alkorkon,Alkorkonas,Alkorkono,Gorad Al''karkon,a er ke er kong,alkoleukon,alkwrkwn,arukorukon,Алкоркон,Алькоркон,Горад Алькаркон,ألكوركون,アルコルコン,阿尔科尔孔,알코르콘', 40.3458200, -3.8248700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48244, 'l''Alcora', 'l''Alcora', 'Alcora,L''Alcora', 40.0666700, -0.2000000, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48245, 'Alconchel de Ariza', 'Alconchel de Ariza', 'Alconchel de Ariza', 41.2042800, -2.1219100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48246, 'Alconada de Maderuelo', 'Alconada de Maderuelo', 'Alconada de Maderuelo', 41.4501500, -3.4855400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48247, 'Alconada', 'Alconada', 'Alconada', 40.9109200, -5.3630500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48248, 'Alconaba', 'Alconaba', 'Al''konaba,Alconaba,Alkonaba,Alkonava,a er ke na wa,alkwnaba,Альконаба,آلکونابا,阿尔科纳瓦', 41.7236000, -2.3848300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48249, 'Alcoletge', 'Alcoletge', 'Alcoletge', 41.6476200, 0.6938300, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48250, 'Alcolea del Pinar', 'Alcolea del Pinar', 'Alcolea,Alcolea del Pinar', 41.0356900, -2.4664500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48251, 'Alcolea de las Peñas', 'Alcolea de las Penas', 'Alcolea de las Penas,Alcolea de las Peñas', 41.2096000, -2.7848300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48252, 'Alcolea de Cinca', 'Alcolea de Cinca', '', 41.7194400, 0.1171600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48253, 'Alcohujate', 'Alcohujate', 'Alcohujate', 40.4176300, -2.6149000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48254, 'Alcocero de Mola', 'Alcocero de Mola', 'Alcocero,Alcocero de Mola', 42.4722200, -3.3579000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48255, 'Alcocer', 'Alcocer', 'Alcocer', 40.4697200, -2.6094000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48256, 'Alcocéber', 'Alcoceber', 'Alcoceber,Alcocebre,Alcocéber,Alcossebre,Aleosebre', 40.2514200, 0.2843300, 'ES', '2013-11-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48257, 'Alcobendas', 'Alcobendas', 'Al''kobendas,Alcobendas,Alcovendae,Alkobendas,Alkobendasas,a er ke wen da si,alkobendaseu,alkwbyndas,arukobendasu,Алкобендас,Алькобендас,ألكوبينداس,アルコベンダス,阿尔科文达斯,알코벤다스', 40.5474600, -3.6419700, 'ES', '2013-08-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48258, 'Alcazarén', 'Alcazaren', 'Alcazaren,Alcazarén', 41.3706100, -4.6726200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48259, 'Alcázar del Rey', 'Alcazar del Rey', 'Alcazar del Rey,Alcázar del Rey', 40.0628900, -2.8078200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48260, 'Alcarràs', 'Alcarras', 'Alcarras,Alcarraz,Alcarràs,Alcarrás', 41.5666700, 0.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48261, 'Alcantud', 'Alcantud', 'Alcantud', 40.5481800, -2.3325800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48262, 'Alcanó', 'Alcano', 'Alcano,Alcanó', 41.4806400, 0.6165900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48263, 'Alcañiz', 'Alcaniz', 'Al''kan''is,Alcaniz,Alcanyis,Alcanyiz,Alcanyís,Alcañiz,a er ka ni yi si,arukanisu,Альканьис,Альканьїс,アルカニス,阿尔卡尼伊斯', 41.0500000, -0.1333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48264, 'Alcañices', 'Alcanices', 'Al''kan''ises,Alcanices,Alcanizes,Alcañices,a er ka ni yi sai si,Альканьисес,Альканьїсес,阿尔卡尼伊塞斯', 41.6994000, -6.3464700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48265, 'Alcanar', 'Alcanar', '', 40.5431600, 0.4808200, 'ES', '2010-04-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48266, 'Alcanadre', 'Alcanadre', 'Al''kanadre,Alcanadre,Alcanadro,Alcandre,Alecanadre,Alkanadre,a er ka na de lei,alkandr,Альканадре,Ալկանադրե,الکاندر,阿尔卡纳德雷', 42.4049200, -2.1207300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48267, 'Alcalá de Moncayo', 'Alcala de Moncayo', 'Alcala de Moncayo,Alcalá de Moncayo', 41.7861000, -1.6954400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48268, 'Alcalá del Obispo', 'Alcala del Obispo', 'Alcala del Obispo,Alcalá del Obispo', 42.0773000, -0.2912000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48269, 'Alcalá de la Vega', 'Alcala de la Vega', 'Alcala de la Vega,Alcalá de la Vega', 40.0333300, -1.5166700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48270, 'Alcalá de la Selva', 'Alcala de la Selva', 'Alcala de la Selva,Alcalá de la Selva', 40.3718300, -0.7201500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48271, 'Alcalá de Henares', 'Alcala de Henares', 'Al''kala-de-Ehnares,Al''kala-de-Enares,Alcala de Henares,Alcalá de Henares,Alcála de Henares,Alkala de Enares,Alkala de Henaresas,Alkala nte Enares,Compluto,Complutum,Cómpluto,Gorad Al''kala-deh-Ehnarehs,ai na lei si bao,alkala dy aynarys,alkalladeenaleseu,arukara・de・enaresu,xal ka lade xe na res,Αλκαλά ντε Ενάρες,Алкала де Енарес,Алькала-де-Енарес,Алькала-де-Энарес,Горад Алькала-дэ-Энарэс,אלקלה דה אנארס,ألكالا دي إيناريس,الكالا دى ايناريس,อัลกาลาเดเอนาเรส,ალკალა-დე-ენარესი,アルカラ・デ・エナーレス,埃纳雷斯堡,알칼라데에나레스', 40.4820500, -3.3599600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48272, 'Alcalá de Gurrea', 'Alcala de Gurrea', '', 42.0665300, -0.6853400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48273, 'Alcalá de Ebro', 'Alcala de Ebro', 'Alcala de Ebro,Alcalá de Ebro', 41.8149500, -1.1942900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48274, 'Alcalà de Xivert', 'Alcala de Xivert', 'Alcala,Alcala de Chisvert,Alcala de Chivert,Alcala de Xivert,Alcalá de Chisvert', 40.3000000, 0.2333300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48275, 'Alcaine', 'Alcaine', 'Alcaine', 40.9534100, -0.7058300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48276, 'Albornos', 'Albornos', 'Albornos', 40.8379500, -4.8812900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48277, 'Alborge', 'Alborge', 'Alborge', 41.3336700, -0.3567500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48278, 'Albons', 'Albons', '', 42.1038900, 3.0843300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48279, 'Albocàsser', 'Albocasser', 'Al''bokaser,Albocacer,Albocasser,Albocazar,Albocácer,Albocázar,Albokaser,Albokaseris,a er wo ka sai er,albwkasyr,Албокасер,Альбокасер,البوكاسير,阿尔沃卡塞尔', 40.3500000, 0.0333300, 'ES', '2006-10-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48280, 'Albiztur', 'Albiztur', 'Albistur,Albiztur,Albístur', 43.1293300, -2.1364900, 'ES', '2012-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48281, 'Albinyana', 'Albinyana', 'Albinana,Albinyana,Albiñana', 41.2500000, 1.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48282, 'Albillos', 'Albillos', '', 42.2768000, -3.7890800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48283, 'Albeta', 'Albeta', 'Albeta', 41.8263600, -1.4993600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48284, 'Albesa', 'Albesa', 'Albesa', 41.7528200, 0.6593600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48285, 'Alberuela de Tubo', 'Alberuela de Tubo', 'Alberuela de Tubo', 41.9084600, -0.2141800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48286, 'Albero Bajo', 'Albero Bajo', 'Albero Bajo', 42.0238000, -0.3801800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48287, 'Albero Alto', 'Albero Alto', 'Albero Alto', 42.0503100, -0.3371000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48288, 'Alberite de San Juan', 'Alberite de San Juan', 'Alberite de San Juan', 41.8200900, -1.4706300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48289, 'Alberite', 'Alberite', 'Al''berite,Alberit,Alberite,a er wei li te,albryt,Альберите,Альберіте,Ալբերիտե,البریت,阿尔韦里特', 42.4070400, -2.4389400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48290, 'Albendiego', 'Albendiego', 'Albendiego', 41.2274200, -3.0517100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48291, 'Albendea', 'Albendea', 'Albendea', 40.4875100, -2.4174700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48292, 'Albelda de Iregua', 'Albelda de Iregua', 'Al''bel''da-de-Iregua,Al''bel''da-de-Iregva,Albelda de Iregua,a er wei er da de lei gua,Альбельда-де-Ірегуа,Альбельда-де-Ирегва,Альбельда-де-Ирегуа,Ալբելդա դե Իրեգուա,البيضاء,阿尔韦尔达德雷瓜', 42.3583700, -2.4727800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48293, 'Albelda', 'Albelda', 'Albelda', 41.8654200, 0.4599900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48294, 'Albarracín', 'Albarracin', 'Al''barrasin,Albarasinas,Albarracin,Albarracín,Albarrasi,Albarrasí,Albarrazin,Albarrazín,a er wa la xin,arubarashin,bny alrzyn,Альбаррасин,Альбаррасін,بني الرزين,アルバラシン,阿尔瓦拉辛', 40.4081800, -1.4437500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48295, 'Albares', 'Albares', 'Albares', 40.3069000, -3.0089700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48296, 'Albalatillo', 'Albalatillo', 'Albalatillo', 41.7352700, -0.1511500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48297, 'Albalate de Zorita', 'Albalate de Zorita', 'Albalate de Zorita', 40.3081200, -2.8426700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48298, 'Albalate de las Nogueras', 'Albalate de las Nogueras', 'Albalate,Albalate de las Nogueras', 40.3661400, -2.2771800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48299, 'Albalate del Arzobispo', 'Albalate del Arzobispo', 'Albalate del Arzobispo', 41.1217300, -0.5114200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48300, 'Albalate de Cinca', 'Albalate de Cinca', 'Albalat de Cinca', 41.7252100, 0.1524400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48301, 'Alba de Yeltes', 'Alba de Yeltes', 'Alba de Yeltes', 40.6718000, -6.3166000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48302, 'Alba de Tormes', 'Alba de Tormes', 'Alba de Tormes', 40.8266400, -5.5123700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48303, 'Alba de Cerrato', 'Alba de Cerrato', 'Alba de Cerrato', 41.8127600, -4.3647000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48304, 'Alba', 'Alba', 'Alba', 40.6182500, -1.3465800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48305, 'Alàs i Cerc', 'Alas i Cerc', '', 42.3500000, 1.5166700, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48306, 'Alarilla', 'Alarilla', 'Alarilla', 40.8471100, -3.1031000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48307, 'Alar del Rey', 'Alar del Rey', 'Alar del Rey,Alar-del''-Rej,a la er de er lei,Алар-дель-Рей,阿拉尔德尔雷', 42.6603700, -4.3127100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48308, 'Alarba', 'Alarba', 'Alarba', 41.2048200, -1.6133500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48309, 'Alaraz', 'Alaraz', 'Alaraz', 40.7488600, -5.2878100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48310, 'Alaminos', 'Alaminos', 'Alaminos', 40.8630300, -2.7257300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48311, 'Alameda del Valle', 'Alameda del Valle', 'Alameda del Valle', 40.9187000, -3.8424300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48312, 'Alagón', 'Alagon', 'Alago,Alagon,Alagó,Alagón,a la gong,alaghwn,alagwn  zaragwza,Алагон,ألاغون,الاگون، زاراگوزا,阿拉贡', 41.7696400, -1.1190600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48313, 'Alaejos', 'Alaejos', 'Alaejos', 41.3073200, -5.2156700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48314, 'Aladrén', 'Aladren', 'Aladren,Aladrén', 41.2491700, -1.1559100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48315, 'Alacón', 'Alacon', 'Alacon,Alacón', 41.0257500, -0.6978200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48316, 'Ajamil', 'Ajamil', 'Ajamil,Ajamil de Cameros,Akhamil'',Akhamil''-de-Kameros,Axamil,a ha mi er de ka mei luo si,ajamyl,Ахамиль,Ахаміль-де-Камерос,Ախամիլ,اجامیل,阿哈米尔德卡梅罗斯', 42.1670500, -2.4875200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48317, 'Ajalvir', 'Ajalvir', 'Ajalvir', 40.5320500, -3.4784100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48318, 'Aizarnazabal', 'Aizarnazabal', 'Aizarnazabal,Aizarnazábal', 43.2559100, -2.2360700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48319, 'Ainzón', 'Ainzon', 'Ainzon,Ainzón', 41.8164400, -1.5199500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48320, 'Aínsa', 'Ainsa', 'Ainsa,L''Ainsa', 42.4154700, 0.1400800, 'ES', '2007-03-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48321, 'Aiguaviva', 'Aiguaviva', 'Aiguaviva', 41.9384000, 2.7621700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48322, 'Ahigal de Villarino', 'Ahigal de Villarino', 'Ahigal de Villarino', 41.1581900, -6.3803700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48323, 'Ahigal de los Aceiteros', 'Ahigal de los Aceiteros', 'Ahigal de los Aceiteros', 40.8723100, -6.7470200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48324, 'Ahigal', 'Ahigal', 'Ahigal', 40.1895400, -6.1881500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48325, 'Agullana', 'Agullana', 'Agullana', 42.3940800, 2.8466600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48326, 'Aguilón', 'Aguilon', 'Aguilon,Aguilón', 41.2946700, -1.0463400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48327, 'Aguilar de Segarra', 'Aguilar de Segarra', 'Aguilar de Boixadors,Aguilar de Segarra', 41.7482200, 1.6291900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48328, 'Aguilar del Río Alhama', 'Aguilar del Rio Alhama', 'Agilar del Rio Alama,Agilar-del''-Rio-Al''khama,Agilar-del''-Rio-Alama,Aguilar,Aguilar de Rio Alhama,Aguilar del Rio Alhama,Aguilar del Río Alhama,a ji la er de er li ao a er a ma,agwlar dl ryw alhama,Агилар-дель-Рио-Алама,Агилар-дель-Рио-Альхама,Агілар-дель-Ріо-Алама,Ագիլար դել Ռիո Ալամա,اگولار دل ریو الهاما,اگویلار دیل ریو الہاما,阿吉拉尔德尔里奥阿尔阿马', 41.9621200, -1.9934000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48329, 'Aguilar del Alfambra', 'Aguilar del Alfambra', 'Aguilar,Aguilar de Alfambra,Aguilar del Alfambra', 40.5902700, -0.7958900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48330, 'Aguilar de Codés', 'Aguilar de Codes', 'Aguilar Kodes,Aguilar de Codes,Aguilar de Codés', 42.6124900, -2.3898700, 'ES', '2012-11-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48581, 'Ziway', 'Ziway', 'Ziway,Zwai,Zway', 7.9333300, 38.7166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48582, 'Yirga ‘Alem', 'Yirga `Alem', 'Abosto,Agraria,Dalle,Irgalem,Yirga `Alem,Yirga ‘Alem,Yirgalem,Ābosto', 6.7500000, 38.4166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48583, 'Yabēlo', 'Yabelo', 'Iavello,Yabalo,Yabelo,Yabēlo,Yavello,Yavelo,Yeabelo,Yebelo,Yābalo', 4.8833300, 38.0833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48584, 'Werota', 'Werota', 'Wereta,Wereta (2),Werota,Worota,Worrota', 11.9166700, 37.7000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48585, 'Were Īlu', 'Were Ilu', 'Uorra Ilu,Uorre Ilu,Wara Haylu,Wara Hāylu,Warayelu,Ware Ilu,Warra Hailu,Were Ilu,Were Īlu,Wereyilu,Woreyilu', 10.5896400, 39.4376700, 'ET', '2013-08-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48586, 'Wenjī', 'Wenji', 'Uongi,Wenji,Wenjī,Wonji', 8.4500000, 39.2833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48587, 'Wendo', 'Wendo', 'Uondo,Wando,Wendo,Wondo', 6.6000000, 38.4166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48588, 'Turmi', 'Turmi', 'Turmi,Турми', 4.9666700, 36.4833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48589, 'Tulu Bolo', 'Tulu Bolo', 'Masno Gabado,Tulu Bolo', 8.6666700, 38.2166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48590, 'Tippi', 'Tippi', 'TIE,Tepi,Tippi,Tēpī', 7.2000000, 35.4500000, 'ET', '2016-03-31', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48591, 'Sirre', 'Sirre', 'Sere,Seri,Serē,Sire,Sire (2),Siri,Sirie,Siriè,Sirre,Sīrē,Sīrē (2)', 8.3166700, 39.4833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48592, 'Shashemenē', 'Shashemene', 'Sciasciamanna,Sciasciamanne,Shashamana,Shashamane,Shashamani,Shashamanna,Shashamanni,Shashamané,Shashemene,Shashemenē,Shāshamani,ሻሸመኔ', 7.2000000, 38.6000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48593, 'Shambu', 'Shambu', 'Sciambo,Shambo,Shambu,Shembo,Shembu', 9.5666700, 37.1000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48594, 'Shakīso', 'Shakiso', 'Shakiso,Shakīso', 5.7500000, 38.9166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48595, 'Sendafa', 'Sendafa', 'Sandafe,Sendafa,Sendefa,Sendefà', 9.1520300, 39.0233500, 'ET', '2013-09-08', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48596, 'Sebeta', 'Sebeta', 'Sebeta', 8.9166700, 38.6166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48597, 'Robīt', 'Robit', '', 12.0166700, 39.6333300, 'ET', '2006-01-27', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48598, 'Nejo', 'Nejo', 'NEJ,Najo,Nedjo,Neggio,Nego,Nejo,Neju', 9.5000000, 35.5000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48599, 'Nazrēt', 'Nazret', 'Adama,Hadama,Nazareth,Nazret,Nazreth,Nazrēt', 8.5500000, 39.2666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48600, 'Mojo', 'Mojo', 'Maggio,Moccia,Modjo,Moggio,Mojjio,Mojjo,Mojo', 8.5867900, 39.1211100, 'ET', '2014-11-16', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48601, 'Mīzan Teferī', 'Mizan Teferi', 'Mesan,Mizan,Mizan Tafari,Mizan Teferi,Mizon Teferi,Mīzan Teferī', 6.9986500, 35.5887900, 'ET', '2017-06-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48602, 'Metu', 'Metu', 'Mattu,Mettu,Metu', 8.3000000, 35.5833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48603, 'Metahāra', 'Metahara', 'Matahara,Matahārā,Metahara,Metahāra,Metehara', 8.9000000, 39.9166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48604, 'Mendī', 'Mendi', 'Mandi,Mendi,Mendī,Менди', 9.8000000, 35.1000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48605, 'Mek''ele', 'Mek''ele', 'MQX,Macalle,Macallè,Makale,Makalle,Maqale,Maqalle,Maqalē,Mehkehle,Mek''ele,Mekele,Mekelie,Mekelle,Mek’ele,me khele,mo ke lai,mqlh,Мекеле,Мэкэле,מקלה,میکیلے,เมเคเล,መቀሌ,默克萊', 13.4966700, 39.4752800, 'ET', '2016-10-12', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48606, 'Mēga', 'Mega', 'Mega,Megga,Mēga', 4.0500000, 38.3000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48607, 'Maych’ew', 'Maych''ew', 'Mai Ceu,Mai Chio,Mai Cio,Mai Ciò,Mai Keu,Maichew,Maitchew,Maych''awu,Maych''ew,Maych’awu,Maych’ew', 12.7875000, 39.5422200, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48608, 'Lobuni', 'Lobuni', 'Lobuni,Omorate,Оморате', 4.8333300, 36.1000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48609, 'Leku', 'Leku', 'Leku,Locu', 6.8730900, 38.4442500, 'ET', '2013-05-18', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48610, 'Lalībela', 'Lalibela', 'Klippekirkerne i Lalibela,LLI,Labibela,Lalibala,Lalibela,Lalībela,Lālibalā,la li bei la,Лалибела,ላሊበላ,拉利貝拉', 12.0321900, 39.0475600, 'ET', '2016-02-06', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48611, 'Korem', 'Korem', 'Koram,Korem,Kworam,Quaram,Quoram,Quoram Vecchia,Quorem', 12.5058300, 39.5227800, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48612, 'Konso', 'Konso', 'Konso,Консо', 5.2500000, 37.4833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48613, 'K’olīto', 'K''olito', 'Alaba,Alaba K''ulito,Alaba Kolito,Colito,Golito,Goluto,K''olito,K’olīto,Ālaba K’ulīto', 7.3166700, 38.0833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48614, 'Kofelē', 'Kofele', 'Cofole,Kefole,Kofale,Kofele,Kofelē', 7.0666700, 38.7833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48615, 'Kibre Mengist', 'Kibre Mengist', 'Adola,Angedi,Kibre Mengist', 5.8833300, 38.9833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48616, 'Kemisē', 'Kemise', 'Cascim,Kassebie,Kemise,Kemissie,Kemisē,Kemse,Kemsē', 10.7166800, 39.8699700, 'ET', '2013-10-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48617, 'Kombolcha', 'Kombolcha', 'Cambolcia,Combolcha,Combolcia,Kambolcha,Kambolchā,Kembolcha,Kombol''cha,Kombolcah,Kombolcha,Комбольча', 11.0815500, 39.7433900, 'ET', '2011-10-28', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48618, 'Jinka', 'Jinka', 'Jinka', 5.6500000, 36.6500000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48619, 'Jimma', 'Jimma', 'Djimma,Gima,Gimma,JIM,Jima,Jimma,Jīma', 7.6734400, 36.8344100, 'ET', '2016-10-22', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48620, 'Jijiga', 'Jijiga', 'Djidjiga,Djigdjiga,Dschidschiga,Dzhidzhiga,Dzidziga,Dżidżiga,Džidžiga,Giggiga,Giggigga,Gigiga,JIJ,Jigjiga,Jigjigga,Jijiga,gygygh,ji ji jia,jijiga,jyjyga,Ĝiĝiga,Джиджига,גיגיגה,جیجیگا,ጅጅጋ,吉吉加,지지가', 9.3500000, 42.8000000, 'ET', '2014-08-20', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48621, 'Inda Silasē', 'Inda Silase', 'Enda Salassie,Enda Selase,Enda Selassie,Enda Selassye,Enda Sellassie,Endā Selāsē,Inda Selassie,Inda Silase,Inda Silasē,Shire Inda Silase,Shirē Inda Silasē,Ynda Syllase', 14.1030700, 38.2828900, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48622, 'Huruta', 'Huruta', 'Hurruta,Huruta,Huruta (1),Uruta Mariam', 8.1500000, 39.3500000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48623, 'Hīrna', 'Hirna', 'Hirna,Hīrna', 9.2166700, 41.1000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48624, 'Harar', 'Harar', 'Charar,Gorad Kharehr,Harar,Harar Jugol,Hararas,Harer,Harrar,Hārar,Hārer,Kharar,Kharehr,Kharer,ha lei er,halaleu,harara,harari,hararu,hrr,Χαράρ,Горад Харэр,Харар,Харер,Харэр,הרר,هرر,ہرار,हरार,ਹਾਰਰ,ჰარარი,ሐረር,ハラール,哈勒尔,하라르', 9.3138700, 42.1181500, 'ET', '2013-07-06', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48625, 'Hāgere Selam', 'Hagere Selam', 'Agere Selam,Agheresalam,Hagere Selam,Hula,Hāgere Selam', 6.4833300, 38.5166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48626, 'Hāgere Hiywet', 'Hagere Hiywet', 'Agere Hiywet,Ambo,Hagere Hiwot,Hagere Hiywet,Hagere Hiywot,Hagere-Hiywer,Hāgere Hiywet,Āmbo', 8.9833300, 37.8500000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48627, 'Guder', 'Guder', '', 8.9666700, 37.7666700, 'ET', '2006-01-17', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48628, 'Gorē', 'Gore', 'GOR,Gannat,Genud,Gore,Gorei,Gorē,Gwore', 8.1500000, 35.5333300, 'ET', '2013-03-30', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48629, 'Gondar', 'Gondar', 'GDQ,Gondar,Gondehr,Gonder,Gonderas,Gondero,Gwender,Gwonder,Nkontair,gondaleu,gondaru,gong de er,gwndr,Γκόνταιρ,Гондар,Гондэр,גונדר,ጎንደር ከተማ,ゴンダール,貢德爾,곤다르', 12.6000000, 37.4666700, 'ET', '2014-05-28', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48630, 'Goba', 'Goba', 'GOB,Goba,Gobba,Gobbà,Гоба', 7.0166700, 39.9833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48631, 'Waliso', 'Waliso', 'Chitu,Ghion,Gion,Giyon,Guyon,Ualiso,Uoliso,Uolisò,Waliso,Walliso,Walso,Weliso,Welso,Welīso,Woliso,Wolisso,Wolliso', 8.5341700, 37.9651500, 'ET', '2014-11-16', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48632, 'Ginir', 'Ginir', 'GNN,Ghigner,Ghiignir,Ghimir,Ghinner,Ghinnir,Ginir,Ginnir,Ginnīr,Gīnīr', 7.1395200, 40.7108300, 'ET', '2013-05-08', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48633, 'Gimbi', 'Gimbi', 'GHD,Gembi,Ghimbi,Gimbi,Gīmbī', 9.1703100, 35.8349100, 'ET', '2013-06-23', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48634, 'Gīdolē', 'Gidole', 'Ghidole,Ghidolie,Gidole,Gīdolē', 5.6500000, 37.3666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48635, 'Gewanē', 'Gewane', 'Gauani,Gawani,Gawāni,Gewane,Gewani,Gewanē,Gewanī,Gouani', 10.1665800, 40.6468900, 'ET', '2013-09-08', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48636, 'Genet', 'Genet', 'Genet,Gennet,Holata,Holeta,Holetta,Hollatta,Holota,Holotā,Oletta,Zhenja,Женя', 9.0666700, 38.5000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48637, 'Gelemso', 'Gelemso', 'Galamso,Gelemso,Ghelemso,Ghelemsò', 8.8166700, 40.5166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48638, 'Gēdo', 'Gedo', 'Gedo,Ghedo,Gēdo', 9.0166700, 37.4500000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48639, 'Gebre Guracha', 'Gebre Guracha', 'Cuyu,Gabra Guracha,Gabre Guracha,Gebre Guracha,Kuyu', 9.8000000, 38.4000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48640, 'Gambēla', 'Gambela', 'GMB,Gambeila,Gambela,Gambela Post,Gambele,Gambella,Gambēla,Гамбеле', 8.2500000, 34.5833300, 'ET', '2013-03-30', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48641, 'Finote Selam', 'Finote Selam', 'Fenote Selam,Finote Selam', 10.7000000, 37.2666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48642, 'Fichē', 'Fiche', 'Feche,Fechē,Ficce,Fice,Fiche,Fichē,Fitche', 9.8000000, 38.7333300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48643, 'Felege Neway', 'Felege Neway', 'Felege Neway,Felege Niway,Sawla Felege Neway', 6.3000000, 36.8833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48644, 'Dubti', 'Dubti', 'Dubti,Dubtī,Dufti,Dufty,Duftī', 11.7329200, 41.0820000, 'ET', '2013-12-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48645, 'Dodola', 'Dodola', 'Dodola,Dodolla,Dodolo,Додола', 6.9833300, 39.1833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48646, 'Dire Dawa', 'Dire Dawa', 'D''ire Daua,DIR,Daredawa,Dirdabo,Dirdabò,Dire Daba,Dire Daua,Dire Dawa,Dire Dewa,Dire-Daoua,Direaoua,Diredavy,Dirediua,Diré-Daoua,Dirē Dawa,D’ire Daua,dile dawa,dyrt dawa,Диредавы,דירה דאווה,ديرة داوا,ድሬዳዋ,디레 다와', 9.5930600, 41.8661100, 'ET', '2015-09-05', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48647, 'Dīla', 'Dila', 'Dila,Dilla,Dīla,Дила', 6.4166700, 38.3166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48648, 'Desē', 'Dese', 'Dase,Dasē,Dese,Desje,Dessa,Dessi,Dessie,Dessye,Desē,Desė', 11.1333300, 39.6333300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48649, 'Dembī Dolo', 'Dembi Dolo', 'DEM,Dambidollo,Dambidolo,Dembi Doilo,Dembi Dolo,Dembidollo,Dembilollo,Dembī Dolo,Saio', 8.5333300, 34.8000000, 'ET', '2017-06-27', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48650, 'Dejen', 'Dejen', 'Degen,Dejen,Dingab', 10.1666700, 38.1333300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48651, 'Deder', 'Deder', 'Dadar,Deder', 9.3116800, 41.4430100, 'ET', '2013-08-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48652, 'Bishoftu', 'Bishoftu', 'Biscioftu,Biscioftù,Bishoftu,Debra Zeit,Debre Zeit,Debre Zeyit,Debre Zeyt', 8.7522500, 38.9784600, 'ET', '2014-11-30', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48653, 'Debre Werk’', 'Debre Werk''', 'Dabra Wark'',Dabra Wark’,Dabra-Warq,Debra Uerch,Debra Uorc,Debra Uorch,Debra Uork,Debra Wark,Debra Werk,Debra Work,Debre Werk'',Debre Werk’', 10.6666700, 38.1666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48654, 'Debre Tabor', 'Debre Tabor', 'DBT,Dabra-Tabor,Dabra-Tābor,Debra Tabor,Debre Tabor,Samara', 11.8500000, 38.0166700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48655, 'Debre Sīna', 'Debre Sina', 'Debra Sina,Debre Sina,Debre Sīna', 9.8475200, 39.7602700, 'ET', '2013-07-06', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48656, 'Debre Mark’os', 'Debre Mark''os', 'DBM,Dabra Marko''s,Dabra Mārko’s,Dabra-7arqos,Dabra-7ārqos,Debra Marcos,Debra Markos,Debre Marcos,Debre Mark''os,Debre Mark’os,Moncorer,Monkorer', 10.3500000, 37.7333300, 'ET', '2017-06-27', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48657, 'Debre Birhan', 'Debre Birhan', 'Dabra Berham,Dabra-Berhan,Dabra-Berhān,Debra Berham,Debra Berhan,Debra Birhan,Debra Brehan,Debre Berhan,Debre Birhan', 9.6795400, 39.5326200, 'ET', '2013-07-06', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48658, 'Debark’', 'Debark''', 'Dabark'',Dabarq,Dabārk’,Dabārq,Davark,Debarec,Debarech,Debarek,Debark'',Debark’,Devark,Dibark', 13.1561100, 37.8980600, 'ET', '2013-03-02', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48659, 'Dabat', 'Dabat', 'Dabat,Dabat (2),Dahat', 12.9841700, 37.7650000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48660, 'Butajīra', 'Butajira', 'Butajera,Butajira,Butajīra,Butlagira,Buttagira', 8.1166700, 38.3666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48661, 'Burē', 'Bure', 'Bure,Burie,Burja,Burye,Burē,Буря', 10.7000000, 37.0666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48662, 'Bonga', 'Bonga', 'Bonga,Bonga (1),Бонга', 7.2833300, 36.2333300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48663, 'Bodītī', 'Boditi', 'Boditi,Boditti,Boditu,Bodity,Bodītī', 6.9666700, 37.8666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48664, 'Bichena', 'Bichena', 'Bechana,Bechanā,Biccena,Bichana,Bichena', 10.4500000, 38.2000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48665, 'Bedēsa', 'Bedesa', 'Bedesa,Bedessa,Bedēsa', 8.9000000, 40.7833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48666, 'Bedelē', 'Bedele', 'Beddele,Bedele,Bedelle,Bedelli,Bedelē', 8.4560000, 36.3530200, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48667, 'Batī', 'Bati', 'Bati,Batia,Batie,Batī', 11.1915200, 40.0167500, 'ET', '2012-10-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48668, 'Bako', 'Bako', 'Bachio,Baco,Baka,Bako,Бако', 5.7833300, 36.5666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48669, 'Bahir Dar', 'Bahir Dar', 'BJR,Babardur Georgis,Bachr-Ntar,Bahar,Bahar Dar,Bahar Dar Ghiorghis,Baher Dar,Baherdar-Giyorgis,Bahir Dar,Bahr Dar,Bahrdar Giyergio,Bahrdar Giyorgis,Bahyr Dar,Bakhir Dar,Bakhr-Dar,Bāherdār-Giyorgis,ba he da er,bahileudaleu,bahr-dari,bhr dar,bhr dr,Μπαχρ-Νταρ,Бахир Дар,Бахр-Дар,בהר דר,بحر دار,ბაჰრ-დარი,ባሕር-ዳር,巴赫達爾,바히르다르', 11.5936400, 37.3907700, 'ET', '2013-04-21', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48670, 'Āwash', 'Awash', 'Auasc,Awash,Āwash', 8.9833300, 40.1666700, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48671, 'Hawassa', 'Hawassa', 'AWA,Avase,Awasa,Awassa,Hawassa,Āwasa,ʼwwsh,Авасе,אווסה', 7.0620500, 38.4763500, 'ET', '2013-05-18', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48672, 'Āsosa', 'Asosa', 'ASO,Asosa,Āsosa', 10.0666700, 34.5333300, 'ET', '2017-07-18', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48673, 'Āsbe Teferī', 'Asbe Teferi', 'Asba Littorio,Asbar Tafari,Asbatafari,Asbe Taferi,Asbe Tefen,Asbe Teferi,Asebe Tafari,Asebe Teferi,Āsbe Teferī,Āsebe Teferī', 9.0856900, 40.8670800, 'ET', '2013-08-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48674, 'Asaita', 'Asaita', 'Aisaita,Asaita,Asajita,Asayita,Asayta,Assayita,Aysa''ita,Āsayita,Āysa’īta,Асайита', 11.5683800, 41.4386900, 'ET', '2012-10-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48675, 'Āsasa', 'Asasa', 'Asasa,Āsasa', 7.1000000, 39.2000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48676, 'Āreka', 'Areka', 'Ancheto,Areka,Areka Ancheto,Āreka', 7.0666700, 37.7000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48677, 'Arba Minch', 'Arba Minch', 'AMH,Arba Mench,Arba Minch,Arba Mintch,Arba-Mynch,Gantar,Minghi,Арба-Мынч,አርባ ምንጭ', 6.0333300, 37.5500000, 'ET', '2016-11-21', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48678, 'Axum', 'Axum', 'AXU,Akesum,Aksoum,Aksum,Aksumo,Axum,akswm,Āksum,Аксум,أكسوم,አክሱም', 14.1210900, 38.7233700, 'ET', '2015-11-22', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48679, 'Hagere Maryam', 'Hagere Maryam', 'Agere Mariam,Agere Maryam,Aghere Mariam,Alga,Alge,Alghe,Algheremariam,Algā,Hagere Mariam,Āgere Maryam', 5.6341800, 38.2360300, 'ET', '2012-06-05', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48680, 'Āgaro', 'Agaro', 'Agaro,Aggaro,Aggarò,Āgaro', 7.8500000, 36.6500000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48681, 'Ādīs Zemen', 'Adis Zemen', 'Addis Zaman,Addis Zemen,Adis Zemen,Ādīs Zemen', 12.1166700, 37.7833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48682, 'Ādīs ‘Alem', 'Adis `Alem', 'Addis Alem,Addis-Alam,Addis-Ālam,Adis `Alem,Ādīs ‘Alem', 9.0333300, 38.4000000, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48683, 'Addis Ababa', 'Addis Ababa', 'ADD,Addis Ababa,Addis Abbaba,Addis Abeba,Addis-Abeba,Addis-Abebae,Addisz-Abeba,Adis Abeba,Adis-Abebo,Adisabeba,Adís Abeba,Antis Ampempa,Neanthopolis,a di si a bei ba,adisa ababa,adiseuababa,adisuabeba,adys ababa,Ādīs Ābeba,Αντίς Αμπέμπα,Аддис-Абебæ,Аддис-Абеба,Адис Абеба,Ադիս Աբեբա,אדיס אבבה,آدیس آبابا,أديس أبابا,ئەددىس -ئەبىبە,अदिस अबाबा,አዲስ አበባ,アディスアベバ,阿迪斯阿貝巴,아디스아바바', 9.0249700, 38.7468900, 'ET', '2015-05-13', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48684, 'Ādīgrat', 'Adigrat', '', 14.2770000, 39.4620000, 'ET', '2013-03-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48685, 'Addiet Canna', 'Addiet Canna', 'Addiet,Addiet Canna,Adet,Ādēt', 11.2666700, 37.4833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48686, 'Abomsa', 'Abomsa', 'Abomsa,Abonsa', 9.9833300, 39.9833300, 'ET', '2012-01-19', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48687, 'Semera', 'Semera', 'SZE,Semera,semera,სემერა,ሰመራ', 11.7934200, 41.0057800, 'ET', '2013-12-07', 71);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48688, 'Ypäjä', 'Ypaejae', '', 60.8000000, 23.2833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48689, 'Ylöjärvi', 'Yloejaervi', 'Ylajarvi,Yloejaervi,Yläjarvi,Ylöjärvi', 61.5563200, 23.5960600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48690, 'Ylivieska', 'Ylivieska', 'Ilivieska,YLI,Ylivieska,Иливиеска', 64.0833300, 24.5500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48691, 'Ylitornio', 'Ylitornio', 'Badje-Duortnus,Julitornio,OEvertornea,Ylitornio,Ylitornio vald,shang tuo er ni ao,ylytwrnw,Övertorneå,Юлиторнио,یلیتورنو,上托爾尼奧', 66.3089300, 23.6773400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48692, 'Ylistaro', 'Ylistaro', 'Ylistaro', 62.9395800, 22.5130600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48693, 'Ylikiiminki', 'Ylikiiminki', 'Ilikiminki,OEverkiminge,Ylikiiminki,Överkiminge,Иликиминки', 65.0833300, 26.2500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48694, 'Yli-Ii', 'Yli-Ii', 'Ili-I,OEverijo,Yli-Ii,Överijo,Или-И', 65.3718100, 25.8458000, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48695, 'Ylihärmä', 'Ylihaermae', 'OEvre Haermae,Övre Härmä', 63.1500000, 22.7833300, 'FI', '2017-05-06', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48696, 'Yläne', 'Ylaene', 'Yulyane', 60.8833300, 22.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48697, 'Ylämaa', 'Ylaemaa', 'Juljamaa,Ylaemaa,Ylämaa,Юлямаа', 60.8000000, 28.0000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48698, 'Vuolijoki', 'Vuolijoki', 'Vuolijo,Vuolijoki,Вуолийо', 64.1853800, 26.9954700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48699, 'Vuokatti', 'Vuokatti', 'Vuokatti,XVM,Вуокатти', 64.1446600, 28.2819600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48700, 'Vörå', 'Voera', 'Voera,Voeyri,Vora,Vörå,Vöyri', 63.1360700, 22.2522300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48701, 'Virtasalmi', 'Virtasalmi', 'Virtasalmi,Виртасалми', 62.1269500, 27.4627600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48702, 'Virrat', 'Virrat', 'Virats,Virdois,Virrat,Virrati linn,Virtois,Wirrat,wei la te,wrat,Виррат,Віррат,ورات,維拉特', 62.2475900, 23.7800400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48703, 'Virolahti', 'Virolahti', 'Vederlax kyrkby,Virolahden Kirkonkyla,Virolahden Kirkonkylae,Virolahden Kirkonkylä,Virolahti,Virolakhti,Виролахти', 60.5166700, 27.6830600, 'FI', '2014-12-10', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48704, 'Virojoki', 'Virojoki', 'Virojoki,Виройоки', 60.5794000, 27.7035400, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48705, 'Vinkkilä', 'Vinkkilae', '', 60.6833300, 21.7166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48706, 'Vimpeli', 'Vimpeli', 'Vimpeli,Wimpeli', 63.1618700, 23.8192200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48707, 'Vilppula', 'Vilppula', 'Val''ppu,Vil''ppula,Vilppula,Вильппула', 62.0212100, 24.5048300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48708, 'Viljakkala', 'Viljakkala', 'Viliakkala,Viljakkala,Wiljakkala', 61.7060100, 23.2668800, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48709, 'Viitasaari', 'Viitasaari', 'Viitasaari,Vijtasaari,wei ta sa li,wytasary,Вийтасаари,Війтасаарі,ویتاساری,維塔薩里', 63.0666700, 25.8666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48710, 'Viiala', 'Viiala', '', 61.2102300, 23.7673800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48711, 'Vihti', 'Vihti', 'Vichtis,Vihti,Vihti vald,Vikhti,fyhty,wei he di,Вихти,فيهتي,維赫蒂', 60.4169900, 24.3196500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48712, 'Vihanti', 'Vihanti', 'Vihanti,Vikhanti,Wihanti,Виханти', 64.4847200, 24.9915700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48713, 'Vieremä', 'Vieremae', 'Vierema,Vieremae,Vieremja,Vieremä,Виеремя', 63.7500000, 27.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48714, 'Veteli', 'Veteli', 'Veteli,Vetil', 63.4783900, 23.7828500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48715, 'Vesilahti', 'Vesilahti', 'Vesilahti', 61.3166700, 23.6166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48716, 'Vesanto', 'Vesanto', 'Vesanto,Wesanto,Весанто', 62.9333300, 26.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48717, 'Velkua', 'Velkua', 'Velkua', 60.4666700, 21.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48718, 'Vehmersalmi', 'Vehmersalmi', 'Vehmersalmi,Vekhmersalmi,Вехмерсалми', 62.7610100, 28.0285300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48719, 'Vehmaa', 'Vehmaa', 'Vehmo,Vemo', 60.6833300, 21.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48720, 'Västanfjärd', 'Vaestanfjaerd', 'Vestanfjard,Vestanfjärd', 60.0500000, 22.6833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48721, 'Varpaisjärvi', 'Varpaisjaervi', 'Varpaisjaervi,Varpaisjarvi,Varpaisjärvi,Varpajs"jarvi,Варпайсъярви', 63.3593200, 27.7550600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48722, 'Varkaus', 'Varkaus', 'VRK,Varghuz,Varkaus,farkaws,vu~arukausu,wa er kao si,wrkaws,wrkws,Варкаус,فاركاوس,ورکاؤس,ورکوس,ヴァルカウス,瓦爾考斯', 62.3153300, 27.8730000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48723, 'Vantaa', 'Vantaa', 'Gorad Vantaa,Vanda,Vanta,Vantaa,Vantania,Vantā,banta,fanta,vhanta,vu~anta,wan ta,wanta,wnth,Βάνταα,Ванта,Вантаа,Горад Вантаа,ונטה,فانتا,وانتا,व्हंटा,ვანტაა,ヴァンター,万塔,반타', 60.2941400, 25.0409900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48724, 'Vampula', 'Vampula', 'Vambula', 61.0166700, 22.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48725, 'Vammala', 'Vammala', 'Vamala,Vammala,Vammala linn,famla,wa ma la,wamala,Вамала,Ваммала,فاملا,وامالا,瓦马拉', 61.3333300, 22.9000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48726, 'Valtimo', 'Valtimo', 'Valtimo,Valtimojarvi,Valtimojärvi,Waltimo,Валтимо', 63.6666700, 28.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48727, 'Valkeakoski', 'Valkeakoski', 'QVK,Valkeakoski,Valkeakoski linn,Valkeakoskis,falkyakwsky,wa er kai a ke si ji,walkyakwsky,Валкеакоски,Валкеакоскі,فالكياكوسكي,والکیاکوسکی,瓦爾凱阿科斯基', 61.2642100, 24.0312200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48728, 'Vahto', 'Vahto', '', 60.6000000, 22.3000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48729, 'Vähäkyrö', 'Vaehaekyroe', 'Lillkyro,Vaehaekyroe,Vaehaeykyroe,Vähäkyrö,Vähäykyrö', 63.0563500, 22.1058400, 'FI', '2015-01-10', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48730, 'Vaasa', 'Vaasa', 'Gorad Vasa,Nikolainkaupunki,Nikolaistad,VAA,Vaasa,Vas,Vasa,Wasa,basa,fasa,vu~asa,wa sa,wasa,Βάασα,Вааса,Васа,Горад Васа,ואסה,فآسا,وآسا,วาซา,ヴァーサ,瓦萨,바사', 63.0960000, 21.6157700, 'FI', '2015-04-21', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48731, 'Vaala', 'Vaala', 'Vaala,Vala,Вала', 64.5666700, 26.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48732, 'Uusikaupunki', 'Uusikaupunki', 'Gorad Usikaupunki,Neostadium,Nystad,Nyustad,Usikaupunki,Usikavpunki,Uusikaupunki,Uusikaupunki linn,awsy kawpnky,awsykawbwnky,ushikaupunki,usikaupungki,uusikaupunki,xin kao peng ji,Ūsikaupunki,Горад Усікаўпункі,Усикавпунки,Усикаупунки,Уусикаупунки,Уусікаупункі,أوسيكاوبونكي,اوسی کاؤپنکی,ウーシカウプンキ,新考蓬基,우시카우풍키', 60.8004300, 21.4084100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48733, 'Uurainen', 'Uurainen', 'Urajnen,Uurainen,Урайнен', 62.5000000, 25.4500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48734, 'Utsjoki', 'Utsjoki', 'Ohcejohka,Utsjok,Utsjoki,Utsjoki vald,Utsyoki,wu ci yue ji,Утсйоки,烏茨約基', 69.9086400, 27.0284300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48735, 'Utajärvi', 'Utajaervi', 'Utajaervi,Utajarvi,Utajärvi,Utayarvi,Утаярви', 64.7500000, 26.3833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48736, 'Urjala', 'Urjala', 'Urdiala,Urjala', 61.0833300, 23.5333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48737, 'Ulvila', 'Ulvila', 'Ulfsby,Ulfsbyu,Ulvila,Ulvsby,alwyla,wu er wei la,Улвила,Улвіла,الویلا,烏爾維拉', 61.4284400, 21.8710300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48738, 'Ullava', 'Ullava', '', 63.6000000, 24.0833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48739, 'Tyrnävä', 'Tyrnaevae', '', 64.7646900, 25.6523000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48740, 'Tuusula', 'Tuusula', 'Thusby,Tusby,Tusula,Tuusula,Tuusula vald,to~usura,tu su la,tusulla,twswla,Тусула,Туусула,توسولا,トゥースラ,图苏拉,투술라', 60.4036800, 25.0263800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48741, 'Tuusniemi', 'Tuusniemi', 'Tusniemi,Tuusniemi,Тусниеми', 62.8166700, 28.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48742, 'Tuupovaara', 'Tuupovaara', 'Tupovara,Tuupovaara,Туповара', 62.4837200, 30.6273100, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48743, 'Tuulos', 'Tuulos', 'Tulos,Tuulos,Тулос', 61.1500000, 24.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48744, 'Turku', 'Turku', 'Abo,Aboa,Gorad Turku,TKU,Tourkou,Turcu,Turku,Turkù,Turu,Túrcú,to~uruku,trkw,tu er ku,tu rku,tuleuku,turku,twrkw,twrqw,Åbo,Τούρκου,Горад Турку,Турку,Տուրկու,טורקו,ترکو,توركو,تورکو,तुर्कू,টুর্কু,ตุรกุ,တားကူးမြို့,ტურკუ,ቱርኩ,トゥルク,图尔库,圖爾庫,투르쿠', 60.4514800, 22.2686900, 'FI', '2016-07-23', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48745, 'Turenki', 'Turenki', 'Turengi,Turenki,Туренки', 60.9166700, 24.6333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48746, 'Töysä', 'Toeysae', '', 62.6280300, 23.8182800, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48747, 'Tornio', 'Tornio', 'Duortnus,Tornea,Torneå,Tornia,Tornijas,Tornijes,Tornijės,Tornio,Tornio linn,toleunio,torunio,tuo er ni ao,twrnyw,Торнио,Торніо,تورنيو,تورنیو,トルニオ,托尔尼奥,토르니오', 65.8481100, 24.1466200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48748, 'Toivakka', 'Toivakka', 'Toivakka,Tojvakka,Тойвакка', 62.1000000, 26.0833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48749, 'Akaa', 'Akaa', 'Ackas,Akaa', 61.1666700, 23.8666700, 'FI', '2017-05-15', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48750, 'Toholampi', 'Toholampi', 'Toholampi,Tokholampi,Тохолампи', 63.7666700, 24.2500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48751, 'Tohmajärvi', 'Tohmajaervi', 'Tohmajaervi,Tohmajaervi vald,Tohmajärvi,Tohmajärvi vald,Tokhmajarvi,tuo he ma ye er wei,twhmayarfy,Тохмаярви,توهمايارفي,托赫馬耶爾維', 62.1833300, 30.3833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48752, 'Teuva', 'Teuva', 'OEstermark,Teuva,Östermark', 62.4819000, 21.7415600, 'FI', '2015-03-01', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48753, 'Tervola', 'Tervola', 'Tervola,Тервола', 66.0833300, 24.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48754, 'Tervo', 'Tervo', 'Tervo,Терво', 62.9500000, 26.7500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48755, 'Tervakoski', 'Tervakoski', 'QVS,Tervakoski,Тервакоски', 60.8141200, 24.6259400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48756, 'Tarvasjoki', 'Tarvasjoki', 'Tarvasjoki', 60.5833300, 22.7333300, 'FI', '2015-01-02', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48757, 'Tampere', 'Tampere', 'Gorad Tampereh,TMP,Tammerfors,Tammerforsia,Tampere,Tampereh,Tamperė,amabere,tambyry,tampele,tampere,tamprh,tan pei lei,tanpere,tmprh,Τάμπερε,Горад Тамперэ,Тампере,Տամպերե,טמפרה,تامبيري,تامپره,تامپیرے,ٹیمپیر,तांपेरे,আমবেরে,ตัมเปเร,ტამპერე,タンペレ,坦佩雷,탐페레', 61.4991100, 23.7871200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48758, 'Tammela', 'Tammela', '', 60.8103500, 23.7682300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48759, 'Taivassalo', 'Taivassalo', 'Taivassalo,Tefsala,Toefsala,Toevsala,Töfsala,Tövsala', 60.5608500, 21.6163900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48760, 'Taivalkoski', 'Taivalkoski', 'Taivalkoski,Tajvalkoski,Тайвалкоски', 65.5666700, 28.2500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48761, 'Taipalsaari', 'Taipalsaari', 'Taipalsaari,Tajpalsaari,Тайпалсаари', 61.1500000, 28.0500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48762, 'Taavetti', 'Taavetti', 'Davidsstad,Taavetti,Tavetti,Таветти', 60.9166700, 27.5666700, 'FI', '2015-07-06', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48763, 'Sysmä', 'Sysmae', 'Sysmae,Sysmä', 61.5000000, 25.6833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48764, 'Suonenjoki', 'Suonenjoki', 'Suonenjoki,Суоненйоки', 62.6166700, 27.1333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48765, 'Suomussalmi', 'Suomussalmi', 'Suomusal''mi,Suomussahni,Suomussalmi,Suomussalmi vald,su ao mu si sa er mi,suomusalmi,suomussarumi,Суомуссалми,Суомуссалмі,スオムッサルミ,苏奥穆斯萨尔米,수오무살미', 64.8868500, 28.9077800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48766, 'Suomusjärvi', 'Suomusjaervi', '', 60.3500000, 23.6500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48767, 'Suolahti', 'Suolahti', 'Suolahti,Suolakhti,Суолахти', 62.5642100, 25.8536300, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48768, 'Suodenniemi', 'Suodenniemi', 'Suodenniemi', 61.5581000, 22.7852600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48769, 'Sumiainen', 'Sumiainen', 'Sumiainen,Sumiajnen,Сумиайнен', 62.6573600, 26.0464200, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48770, 'Sulkava', 'Sulkava', 'Sulkava,Сулкава', 61.7869100, 28.3729900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48771, 'Sotkamo', 'Sotkamo', 'Sotkamo,Sotkamo vald,XQS,sotokamo,suo te ka mo,swtkamw,Соткамо,سوتکامو,ソトカモ,索特卡莫', 64.1333300, 28.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48772, 'Sonkajärvi', 'Sonkajaervi', 'Sonkajaervi,Sonkajarvi,Sonkajärvi,Сонкаярви', 63.6666700, 27.5166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48773, 'Somero', 'Somero', 'Somero,Somero linn,suo mei luo,Сомеро,索梅羅', 60.6166700, 23.5333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48774, 'Soini', 'Soini', 'Soini,Sojni,Сойни', 62.8666700, 24.2166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48775, 'Sodankylä', 'Sodankylae', 'SOT,Soadegilli,Soađegilli,Sodankjulja,Sodankyla,Sodankylae,Sodankylae vald,Sodankylä,Sodankylä vald,Sodankyulya,sodankwille,sodankyura,suo dan qu lai,Соданкюля,ソダンキュラ,索丹屈莱,소단퀼레', 67.4166700, 26.6000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48776, 'Smedsby', 'Smedsby', 'Sepankyla,Sepänkylä,Smedsby', 63.1166700, 21.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48777, 'Siuntio', 'Siuntio', 'Shundeo,Siunlia,Siuntio,Sjundea,Sjundeå,Шундео', 60.1386200, 24.2271500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48778, 'Simpele', 'Simpele', 'Simpele,Симпеле', 61.4333300, 29.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48779, 'Simo', 'Simo', 'Simo,Симо', 65.6666700, 25.0500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48780, 'Broby', 'Broby', 'Broby,Siltakyla,Siltakylä,Stor Kuppis', 60.5000000, 26.7166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48781, 'Siilinjärvi', 'Siilinjaervi', 'Siilinjaervi,Siilinjärvi,Sijlinujarvi,Silin"jarvi,Silinjervi,sylnyarfy,sylynyarwy,xi lin ye er wei,Сийлинъярви,Силинъярви,Силинјерви,سيلنيارفي,سیلینیاروی,錫林耶爾維', 63.0833300, 27.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48782, 'Siikajoki', 'Siikajoki', 'Siikajoki,Sikaioki,Sikajoki,Сикайоки', 64.8145500, 24.7592400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48783, 'Siikainen', 'Siikainen', 'Siikais', 61.8770300, 21.8194500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48784, 'Sievi', 'Sievi', 'Sievi,Сиеви', 63.9000000, 24.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48785, 'Sibbo', 'Sibbo', 'Sibba,Sibbo,Sibbå,Sipoo', 60.3775200, 25.2690600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48786, 'Seinäjoki', 'Seinaejoki', 'OEstermyra,SJY,Seinaejoki,Seinaejoki linn,Seinejokis,Seinjogi,Seinäjoki,Seinäjoki linn,Sejnejoki,Sejnjajoki,sai yi nai yue ji,seinayoki,seineyoki,synajwky,synaywky,syynaywky,syynywqy,Östermyra,Сейняйоки,Сейняйокі,Сейняёки,Сејнејоки,סייניוקי,سينايوكي,سیئنایوکی,سیناجوکی,セイナヨキ,塞伊奈约基,세이네요키', 62.7944600, 22.8282200, 'FI', '2015-08-24', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48787, 'Säynätsalo', 'Saeynaetsalo', 'Saeynaetsalo,Sjajnjatsalo,Säynätsalo,Сяйнятсало', 62.1402500, 25.7694800, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48788, 'Savukoski', 'Savukoski', 'Saukoski,Savukoski,Sayukoski,Suovvaguoika,Савукоски', 67.2925000, 28.1580600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48789, 'Savonranta', 'Savonranta', 'Savonranta,Савонранта', 62.1833300, 29.2000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48790, 'Savonlinna', 'Savonlinna', 'Nyslott,SVL,Savonlina,Savonlinna,sa weng lin na,sabonlinna,safwnlyna,savu~onrin''na,Савонлина,Савонлинна,Савонлінна,سافونلينا,サヴォンリンナ,萨翁林纳,사본린나', 61.8699000, 28.8799900, 'FI', '2015-03-12', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48791, 'Savitaipale', 'Savitaipale', 'Savitaipale,Savitajpale,Savitaypole,Савитайпале', 61.2000000, 27.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48792, 'Sauvo', 'Sauvo', 'Sagu,Sauvo', 60.3430600, 22.6964200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48793, 'Saukkola', 'Saukkola', '', 60.3833300, 23.9833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48794, 'Särkisalo', 'Saerkisalo', 'Finby,Saerkisalo,Sjarkisalo,Särkisalo,Сяркисало', 60.1138900, 22.9500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48795, 'Sammatti', 'Sammatti', 'Sammatti', 60.3199100, 23.8208500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48796, 'Salo', 'Salo', 'Sala,Salo,Salo Kapell,Salo linn,sa luo,sallo,salw,saro,Сало,سالو,سالو، فن لینڈ,サロ,萨洛,살로', 60.3833300, 23.1333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48797, 'Salla', 'Salla', 'Salla,Salla vald,Sal·la,sa la,Салла,薩拉', 66.8333300, 28.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48798, 'Säkylä', 'Saekylae', '', 61.0333300, 22.3333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48799, 'Sahalahti', 'Sahalahti', 'Sahalahti,Sakalakhti,Сакалахти', 61.4746000, 24.3265200, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48800, 'Saarijärvi', 'Saarijaervi', 'Saaijarvi,Saaijärvi,Saarijaervi,Saarijaervi linn,Saarijarvi,Saarijärvi,Saarijärvi linn,Sariyarvi,sa li ye er wei,saryjrwy,Саариярви,Сааріярві,ساریجروی,薩里耶爾維', 62.7048600, 25.2539600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48801, 'Saari', 'Saari', 'Saari,Sari,Сари', 61.6500000, 29.7500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48802, 'Rymättylä', 'Rymaettylae', 'Rimito,Rymaettylae,Rymättylä', 60.3765800, 21.9418400, 'FI', '2015-06-18', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48803, 'Ruukki', 'Ruukki', 'Rukki,Ruukki,Рукки', 64.6666700, 25.1000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48804, 'Rusko', 'Rusko', '', 60.5333300, 22.2166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48805, 'Ruovesi', 'Ruovesi', 'Ruovesi,Руовеси', 61.9857500, 24.0571400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48806, 'Ruotsinpyhtää', 'Ruotsinpyhtaeae', 'Pyhtaa,Pyhtää,Ruotsinpyhtaa,Ruotsinpyhtaeae,Ruotsinpyhtää,Stroemfors,Strömfors', 60.5268000, 26.4620300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48807, 'Ruokolahti', 'Ruokolahti', 'Ruokolahti,Ruokolakhti,Руоколахти', 61.2833300, 28.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48808, 'Rovaniemi', 'Rovaniemi', 'RVN,Roavvenjarga,Roavvenjárga,Robaniemi,Ronianemi,Rovanem,Rovaniehmi,Rovaniemi,Rovaniemi linn,Rovaniemis,Rovanieni,Rovanijemi,lobaniemi,luo wa nie mi,rovu~aniemi,rwbnyymy,rwfanyymy,rwwanymy,Ροβανιέμι,Рованиеми,Рованиэми,Рованијеми,Рованіемі,רובניימי,روفانييمي,رووا نی اے می,رووانیمی,ロヴァニエミ,罗瓦涅米,로바니에미', 66.5000000, 25.7166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48809, 'Ristijärvi', 'Ristijaervi', 'Ristijaervi,Ristijarvi,Ristijärvi,Ристиярви', 64.5000000, 28.2166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48810, 'Ristiina', 'Ristiina', 'Kristina,Ristiina,Ristina,Ристина', 61.5057900, 27.2464300, 'FI', '2015-07-06', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48811, 'Riihimäki', 'Riihimaeki', 'Regimaegi,Regimägi,Riihimaeki,Riihimäki,Rijgimjaki,Rijkhimjaki,Rikhimeki,li xi mai ji,lihimaeki,rihimaki,ryhy maky,ryhymaky,Рийхимяки,Рихимеки,Рійгімякі,ريهيماكي,ریحی ماکی,リーヒマキ,里希邁基,리히매키', 60.7376900, 24.7772600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48812, 'Replot', 'Replot', 'Raippaluoto,Replot,Replotoe,Replotö', 63.2288200, 21.4169100, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48813, 'Renko', 'Renko', 'Renko,Ренко', 60.8956300, 24.2878500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48814, 'Reisjärvi', 'Reisjaervi', 'Reisjaervi,Reisjarvi,Reisjärvi,Rejs"jarvi,Рейсъярви', 63.6166700, 24.9000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48815, 'Rautjärvi', 'Rautjaervi', 'Rautjaervi,Rautjärvi,Rautujarvi,Раутъярви', 61.4333300, 29.3500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48816, 'Rautavaara', 'Rautavaara', 'Rautavaara,Rautavara,Раутавара', 63.4833300, 28.3000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48817, 'Rautalampi', 'Rautalampi', 'Rautalampi,Рауталампи', 62.6333300, 26.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48818, 'Rauma', 'Rauma', 'Gorad Rauma,QZU,Raum,Rauma,Rauma linn,Raumo,Ravma,Raŭmo,lao ma,lauma,rauma,rawma,Горад Раўма,Равма,Раума,رؤمہ,راوما,ラウマ,劳马,라우마', 61.1272400, 21.5112700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48819, 'Ranua', 'Ranua', 'Ranua,Ranua vald,la nu a,Рануа,拉努阿', 65.9166700, 26.5333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48820, 'Rantsila', 'Rantsila', 'Rantsila,Рантсила', 64.5061300, 25.6644900, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48821, 'Rantasalmi', 'Rantasalmi', 'Rantasalimi,Rantasalmi,lan ta sa er mi,Рантасалми,蘭塔薩爾米', 62.0666700, 28.3000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48822, 'Raisio', 'Raisio', 'Raisio,Rajsio,Reso,la yi xi ao,laisio,raishio,raysyw,rayysyw,Райсио,Райсіо,Рајсио,رائیسیو,رايسيو,ライシオ,拉伊西奧,라이시오', 60.4859200, 22.1689500, 'FI', '2015-06-18', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48823, 'Rääkkylä', 'Raeaekkylae', 'Braekylae,Bräkylä,Raeaekkylae,Rääkkylä', 62.3166700, 29.6166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48824, 'Raahe', 'Raahe', 'Brahestad,Raache,Raage,Raahe,Raahe linn,Raakhe,Rahe,Rahė,Rakhe,la he,rahy,Ράαχε,Рааге,Раахе,Рахе,رآهي,راہے,拉赫', 64.6833300, 24.4833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48825, 'Pylkönmäki', 'Pylkoenmaeki', 'Pylkoenmaeki,Pylkönmäki', 62.6666700, 24.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48826, 'Pyhtää', 'Pyhtaeae', 'Pjukhtjaa,Pyhtaeae,Pyhtaeae vald,Pyhtää,Pyhtää vald,Pyttis,pi he tai,Пюхтяа,皮赫泰', 60.4934900, 26.5434600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48827, 'Pyhäselkä', 'Pyhaeselkae', 'Pyhaeselkae,Pyhäselkä', 62.4333300, 29.9666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48828, 'Pyhäsalmi', 'Pyhaesalmi', 'Pjukhjasalmi,Pyhaesalmi,Pyhasalmi,Pyhäsalmi,Пюхясалми', 63.6833300, 25.9833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48829, 'Pyhäranta', 'Pyhaeranta', 'Pitharanta,Pithäranta', 60.9500000, 21.4500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48830, 'Pyhäntä', 'Pyhaentae', 'Pyhanta,Pyhäntä', 64.1000000, 26.3166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48831, 'Pyhäjoki', 'Pyhaejoki', 'Kyhajoki,Pyhajoki,Pyhäjoki,Pyukha', 64.4666700, 24.2333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48832, 'Pyhäjärvi', 'Pyhaejaervi', 'Pjukhjajarvi,Pyhaejaervi,Pyhajarvi,Pyhäjärvi,Пюхяярви', 67.0701000, 27.2176300, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48833, 'Pyhäjärvi', 'Pyhaejaervi', 'Pjugjajarvi,Pjukhjajarvi,Pychagiarvi,Pyhaejaervi,Pyhaejaervi linn,Pyhäjärvi,Pyhäjärvi linn,pi hai ye er wei,Πυχαγιάρβι,Пюгяярві,Пюхяярви,پوہا یاروی,皮海耶爾維', 63.6666700, 25.9000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48834, 'Puumala', 'Puumala', 'Pumala,Puuinala,Puumala,Пумала', 61.5272800, 28.1749500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48835, 'Puolanka', 'Puolanka', 'Puolango,Puolanka,Пуоланка', 64.8666700, 27.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48836, 'Punkalaidun', 'Punkalaidun', '', 61.1166700, 23.1000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48837, 'Punkaharju', 'Punkaharju', '', 61.7588300, 29.3884300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48838, 'Pulkkila', 'Pulkkila', 'Pulkilla,Pulkkila,Пулкилла', 64.2666700, 25.8666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48839, 'Pukkila', 'Pukkila', 'Pukkila,Пуккила', 60.6500000, 25.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48840, 'Pudasjärvi', 'Pudasjaervi', 'Pountasgiarvi,Pudasjaervi,Pudasjaervi linn,Pudasjarvi,Pudasjärvi,Pudasjärvi linn,Pudasujarvi,pu da si ye er wei,pudasuyaruvu~i,Πουντασγιάρβι,Пудасъярви,Пудасярві,پڈاس یاروی,プダスヤルヴィ,普達斯耶爾維', 65.3833300, 26.9166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48841, 'Pöytyä', 'Poeytyae', '', 60.7666700, 22.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48842, 'Posio', 'Posio', 'Posio,Posio vald,bo xi ao,Посио,波西奧', 66.1085600, 28.1718600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48843, 'Pornainen', 'Pornainen', 'Borgnaes,Borgnäs,Pornainen,Pornajnen,Порнайнен', 60.4758100, 25.3749000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48844, 'Pori', 'Pori', 'Arctopolis,Berneborg,Bjoerneborg,Björneborg,Bërneborg,Gorad Pory,POR,Pori,Poris,bo li,bwry,poli,pori,pwry,Πόρι,Горад Поры,Пори,Порі,Պոռի,פורי,بوري,پوری,ポリ,波里,포리', 61.4833300, 21.7833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48845, 'Pomarkku', 'Pomarkku', 'Pamark,Pomarkku,Påmark', 61.6934800, 22.0086200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48846, 'Polvijärvi', 'Polvijaervi', 'Polvijaervi,Polvijarvi,Polvijärvi,Полвиярви', 62.8500000, 29.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48847, 'Pohja', 'Pohja', 'Pohja,Pojo', 60.0962600, 23.5275700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48848, 'Pirkkala', 'Pirkkala', 'Birkala,Pirkkala,TMP', 61.4612500, 23.6322800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48849, 'Piippola', 'Piippola', 'Piippola,Pippola,Пиппола', 64.1666700, 25.9666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48850, 'Piikkiö', 'Piikkioe', 'Piikkioe,Piikkis,Piikkiö,Pikis', 60.4248100, 22.5160100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48851, 'Pihtipudas', 'Pihtipudas', 'Pihtipudas,Pihtipuoas,Pikhtipudas,Пихтипудас', 63.3833300, 25.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48852, 'Pielavesi', 'Pielavesi', 'Pielavesi,Пиелавеси', 63.2333300, 26.7500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48853, 'Pieksämäki', 'Pieksaemaeki', 'Pieksaemaeki,Pieksaemaeki linn,Pieksama,Pieksjamjaki,Pieksyamyaki,Pieksämä,Pieksämäki,Pieksämäki linn,Pijeksemeki,pi ye ke sai mai ji,py ayksa maky,Пиексямяки,Пијексемеки,Пієксямякі,پی ایکسا ماکی,皮耶克赛迈基', 62.3000000, 27.1333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48854, 'Petäjävesi', 'Petaejaevesi', 'Petaejaevesi,Petaejaevesi vald,Petjajavesi,Petjajjavesi,Petäjävesi,Petäjävesi vald,pei tai ye wei xi,Петяйявеси,Петяявеси,佩泰耶韋西', 62.2500000, 25.2000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48855, 'Pertunmaa', 'Pertunmaa', 'Pertunma,Pertunmaa,Пертунма', 61.5000000, 26.4833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48856, 'Pertteli', 'Pertteli', 'Pertteli,S:t Bertils', 60.4333300, 23.2666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48857, 'Perniö', 'Pernioe', 'Bjaerna,Bjernaa,Bjerno,Bjärnå,Pernioe,Perniö', 60.2000000, 23.1333300, 'FI', '2016-08-07', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48858, 'Pernå', 'Perna', 'Perna,Pernaja,Perno,Pernå,Pernö', 60.4486900, 26.0318700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48859, 'Perho', 'Perho', 'Perho,Perkho,Перхо', 63.2166700, 24.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48860, 'Pello', 'Pello', 'Pello', 66.7736400, 23.9625500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48861, 'Pelkosenniemi', 'Pelkosenniemi', 'Pelkoseniemi,Pelkosenniemi,Pelkosenniemi vald,pei er ke sen nie mi,Пелкосениеми,Пелкосенниеми,佩尔科森涅米', 67.1108300, 27.5105600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48862, 'Pedersöre', 'Pedersoere', 'Pedersoere,Pedersoere vald,Pedersoeren kunta,Pedersore,Pedersöre,Pedersöre vald,Pedersören kunta,Pietarsaaren Pitaejae,Pietarsaaren Pitäjä,Pietarsaari,pei dai er se lei,佩代爾瑟雷', 63.6500000, 22.6833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48863, 'Parola', 'Parola', '', 61.0462400, 24.3546300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48864, 'Parkano', 'Parkano', 'Parkano,Parkano linn,pa er ka nuo,parkanw,Паркано,پارکانو,帕爾卡諾', 62.0166700, 23.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48865, 'Parikkala', 'Parikkala', 'Parikkala,Париккала', 61.5500000, 29.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48866, 'Pargas', 'Pargas', 'Parainen,Pargas,Паргас', 60.3067200, 22.3009700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48867, 'Paltamo', 'Paltamo', 'Paltamo,Палтамо', 64.4166700, 27.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48868, 'Pälkäne', 'Paelkaene', 'Paelkaene vald,Pjal''kjane,Pälkäne vald,pai er kai nei,Пялькяне,派爾凱內', 61.3342400, 24.2719700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48869, 'Paimio', 'Paimio', 'Paimio,Pajmio,Pemar,pa yi mi ao,payymyw,Паймио,Пайміо,پائیمیو,帕伊米奧', 60.4567100, 22.6869400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48870, 'Padasjoki', 'Padasjoki', 'Padasjoki,Падасйоки', 61.3500000, 25.2833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48871, 'Outokumpu', 'Outokumpu', 'Outakumpy,Outokumpu,ou tuo kun pu,Оутокумпу,اوتوکمپو، فن لینڈ,歐托昆普', 62.7268500, 29.0159200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48872, 'Oulunsalo', 'Oulunsalo', 'Olulunsalo,Oulunsalo,Uleasalo,Uleasaloe,Uleåsalo,Uleåsalö,Олулунсало', 64.9345600, 25.4112100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48873, 'Oulu', 'Oulu', 'Gorad Oulu,OUL,Ooulou,Oulo,Oulu,Oulu linn,Ovlu,Oŭlo,Uleaborg,Uleoborg,Uleåborg,Uloa,ao lu,awlu,awlw,awlw  fnland,awwlw,oullu,ouru,xow lu,Όουλου,Горад Оўлу,Овлу,Оулу,אואולו,أولو,اوؤلو,اولو، فنلاند,اولُو,โอวลุ,オウル,奥卢,奧盧,오울루', 65.0123600, 25.4681600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48874, 'Oulainen', 'Oulainen', 'Oulainen,Oulais,Oulajnen,Оулайнен', 64.2666700, 24.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48875, 'Otaniemi', 'Otaniemi', 'Otaniemi,Otnaes,Otnäs', 60.1839500, 24.8278600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48876, 'Orivesi', 'Orivesi', 'Orihvesi,Orivesi,Orivesi linn,ao li wei xi,awrywysy,Оривеси,Орівесі,اوریویسی,奧里韋西', 61.6776600, 24.3572000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48877, 'Oripää', 'Oripaeae', 'Oripaeae,Oripää', 60.8500000, 22.6833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48878, 'Orimattila', 'Orimattila', 'Orimattila,Orimattila linn,ao li ma di la,awry mtyla,Ориматтила,Оріматтіла,اوری متیلا,奧里馬蒂拉', 60.8048700, 25.7296400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48879, 'Oravais', 'Oravais', 'Oravainen,Oravais', 63.3013500, 22.3782100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48880, 'Oitti', 'Oitti', 'Oitti,Ojtti,Ойтти', 60.7833300, 25.0333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48881, 'Nykarleby', 'Nykarleby', 'Carolina Nova,Njukarlebju,Nykarleby,Nyukarlebyu,Usikarlepyu,Uusikaarlepjuu,Uusikaarlepyy,Uusikarlepuu,xin ka lei bi,Нюкарлебю,Уусикаарлепюу,Уусикарлепӱӱ,نو کارلے بو,新卡勒比', 63.5227700, 22.5307300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48882, 'Nurmo', 'Nurmo', 'Nurmo', 62.8287000, 22.9099000, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48883, 'Nurmijärvi', 'Nurmijaervi', 'Nurmijaervi,Nurmijaervi vald,Nurmijarvi,Nurmijervi,Nurmijärvi,Nurmijärvi vald,nu er mi ye er wei,nuleumiyaeleubi,nurumiyaruvu~i,nwrmyarfy,nwrmyawy,Нурмиярви,Нурмијерви,نورميارفي,نورمیاوی,ヌルミヤルヴィ,努爾米耶爾維,누르미얘르비', 60.4640700, 24.8073000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48884, 'Nurmes', 'Nurmes', 'Nurmes,nrms,nu er mei si,Нурмес,نرمس,努爾梅斯', 63.5420500, 29.1396500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48885, 'Nuijamaa', 'Nuijamaa', 'Nuijamaa,Nujjamaa,Нуйямаа', 60.9601100, 28.5510400, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48886, 'Nousiainen', 'Nousiainen', 'Nousiainen,Nousis', 60.6041600, 22.0792600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48887, 'Noormarkku', 'Noormarkku', 'Noormarkku,Norrmark', 61.5927400, 21.8684600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48888, 'Nokia', 'Nokia', 'Nokia,Nokia by,Nokia stad,Nokija,nokia,nuo ji ya,nwkya,nwkya  fnland,nwqyh,Нокиа,Нокија,Нокіа,נוקיה,نوكيا,نوکیا، فن لینڈ,نوکیا، فنلاند,නොකියා නගරය,ノキア,諾基亞,诺基亚,노키아', 61.4666700, 23.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48889, 'Nivala', 'Nivala', 'Nivala,Нивала', 63.9166700, 24.9666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48890, 'Nilsiä', 'Nilsiae', 'Nil''sija,Nilsiae,Nilsiä,Нильсия', 63.2074600, 28.0822200, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48891, 'Nickby', 'Nickby', 'Nickby,Nickbygard,Nickbygård,Nikkila,Nikkilä', 60.3833300, 25.2833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48892, 'Nastola', 'Nastola', 'Nastola,Настола', 60.9500000, 25.9333300, 'FI', '2016-02-03', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48893, 'Närpes', 'Naerpes', 'Naerpes,Naerpesi linn,Naerpioe,Narpio,Nerpes,Nerpesos,Njarpes,Närpes,Närpesi linn,Närpiö,nai er po si,narps,Нерпес,Нярпес,Нӓрпиӧ,نارپس,奈爾珀斯', 62.4728300, 21.3370700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48894, 'Nakkila', 'Nakkila', 'Nackeby,Nakkila', 61.3666700, 22.0000000, 'FI', '2015-04-12', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48895, 'Nagu', 'Nagu', 'Nagu,Nauvo', 60.1937500, 21.9097200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48896, 'Naantali', 'Naantali', 'Naantali,Nadendal,Nantali,Nodendal'',Nådendal,Vallis Gratiae,Наантали', 60.4674400, 22.0242800, 'FI', '2015-05-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48897, 'Myrskylä', 'Myrskylae', 'Moerskom,Myrskyla,Myrskylae,Myrskylä,Mörskom', 60.6696500, 25.8475000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48898, 'Mynämäki', 'Mynaemaeki', 'Virmo', 60.6791500, 21.9927400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48899, 'Muurla', 'Muurla', '', 60.3500000, 23.2833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48900, 'Muurame', 'Muurame', 'Muurame,Муураме', 62.1333300, 25.6666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48901, 'Muonio', 'Muonio', 'Muona,Muonio,Muonio vald,Muonioniska,Muoná,ma wni xo,mu ao ni ao,Муонио,มาวนีโอ,穆奥尼奥', 67.9500000, 23.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48902, 'Multia', 'Multia', 'Muldia,Multia,Мултиа', 62.4166700, 24.7833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48903, 'Muhos', 'Muhos', 'Mukhos,Мухос', 64.8079800, 25.9931400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48904, 'Muhos', 'Muhos', 'Muhos,Muhospera,Mukhos,Мухос', 64.7666700, 26.1000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48905, 'Mouhijärvi', 'Mouhijaervi', '', 61.5000000, 23.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48906, 'Mikkeli', 'Mikkeli', 'MIK,Mikkeli,S:t Michel,Sankt Michel,St. Michel,mi kai li,mikkeri,Миккели,ミッケリ,米凱利', 61.6885700, 27.2722700, 'FI', '2015-05-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48907, 'Mietoinen', 'Mietoinen', 'Mietois', 60.6333300, 21.9333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48908, 'Miehikkälä', 'Miehikkaelae', 'Michikkala,Miehikkaelae,Miehikkala,Miehikkälä,Miekhikkjalja,Миехиккяля', 60.6666700, 27.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48909, 'Merimasku', 'Merimasku', 'Merimasko', 60.4833300, 21.8666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48910, 'Merikarvia', 'Merikarvia', 'Merikarvia,Sastmola', 61.8583900, 21.5003500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48911, 'Merijärvi', 'Merijaervi', 'Merijaervi,Merijarvi,Merijärvi,Мериярви', 64.3000000, 24.4500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48912, 'Mellilä', 'Mellilae', '', 60.7666700, 22.9500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48913, 'Masku', 'Masku', 'Masko,Masku', 60.5708200, 22.0988300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48914, 'Marttila', 'Marttila', 'Marttila,S:t Martens,S:t Mårtens,Sankt Martens,Sankt Mårtens,T Martens,T Mårtens,Марттила', 60.5833300, 22.9000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48915, 'Mäntyharju', 'Maentyharju', 'Mantyharja,Mäntyharja', 61.4166700, 26.8833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48916, 'Mänttä', 'Maenttae', '', 62.0301400, 24.6279100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48917, 'Mäntsälä', 'Maentsaelae', 'Maentsaelae,Maentsaelae vald,Mentsele,Mjantsjalja,Mäntsälä,Mäntsälä vald,man cai lai,mantsala,mantsla,Ментселе,Мянтсяля,مانتسالا,مانتسلا,曼采萊', 60.6333300, 25.3166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48918, 'Malax', 'Malax', 'Maahlahti,Maalahti,Maalalahti,Malaks,Malax,Mallax', 62.9422500, 21.5731100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48919, 'Maaninka', 'Maaninka', 'Maaninka,Maninka,Манинка', 63.1552300, 27.2993900, 'FI', '2015-01-02', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48920, 'Luvia', 'Luvia', '', 61.3637500, 21.6255600, 'FI', '2017-01-04', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48921, 'Luumäki', 'Luumaeki', 'Lumjaki,Luumaeki,Luumäki,Лумяки', 60.9261800, 27.5813500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48922, 'Luopioinen', 'Luopioinen', 'Luopioinen,Luopiojnen,Луопиойнен', 61.3629300, 24.6678100, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48923, 'Lumijoki', 'Lumijoki', 'Lumijoki,Lymelki,Лумийоки', 64.8374400, 25.1860700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48924, 'Luhanka', 'Luhanka', 'Luhanka,Lukhanka,Луханка', 61.7968200, 25.7045700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48925, 'Lovisa', 'Lovisa', 'Loviisa,Loviisa linn,Lovijsa,Lovisa,Loviza,Svartkhol''m,Ловийса,Свартхольм', 60.4565900, 26.2250500, 'FI', '2015-04-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48926, 'Loppi', 'Loppi', 'Loppi,Лоппи', 60.7166700, 24.4500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48927, 'Loimaa', 'Loimaa', 'Loimaa,Loimaa linn,Loimijoki,Lojma,Lojmaa,QZJ,luo yi ma,lwyyma,Лойма,Лоймаа,لوئیما,洛伊馬', 60.8497200, 23.0561000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48928, 'Lohtaja', 'Lohtaja', 'Lochtea,Lochteå,Lohtaja,Lokhteo', 64.0247200, 23.5048200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48929, 'Lohja', 'Lohja', 'Logja,Lohja,Lohja linn,Lojo,Lokh''ja,Lokhja,loheuya,luo he ya,lwhya,rohoya,Логя,Лохья,Лохја,لوهيا,لوہ یا,ロホヤ,洛赫亞,로흐야', 60.2485900, 24.0653400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48930, 'Liperi', 'Liperi', 'Libelits,Liperi,Liperi vald,li pei li,Липери,利佩里', 62.5333300, 29.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48931, 'Liminka', 'Liminka', 'Limingo,Liminka,Лиминка', 64.8098500, 25.4154500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48932, 'Liljendal', 'Liljendal', 'Lil''endal'',Liljendal,Liljentaali,Лильендаль', 60.5734600, 26.0525700, 'FI', '2015-06-26', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48933, 'Lieto', 'Lieto', 'Lieto,Lundo', 60.5103200, 22.4617600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48934, 'Lieksa', 'Lieksa', 'Lieksa,Lieksa linn,lie ke sa,ly ayska,riekusa,Лиекса,Ліекса,لی ایسکا,リエクサ,列克薩', 63.3166700, 30.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48935, 'Lestijärvi', 'Lestijaervi', 'Lestijaervi,Lestijarvi,Lestijärvi,Лестиярви', 63.5333300, 24.6500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48936, 'Leppävirta', 'Leppaevirta', 'Leppaevirta,Leppjavirta,Leppävirta,Леппявирта', 62.4900900, 27.7826200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48937, 'Lemu', 'Lemu', 'Lemo,Lemu', 60.5666700, 21.9666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48938, 'Lempäälä', 'Lempaeaelae', 'Lembois,Lempaeaelae,Lempaeaelae vald,Lempjaalja,Lempäälä,Lempäälä vald,lmbala,lun pai lai,Лемпяаля,لمبالا,倫派萊', 61.3166700, 23.7500000, 'FI', '2015-11-09', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48939, 'Lemi', 'Lemi', 'Lemi,Леми', 61.0624400, 27.8057100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48940, 'Leivonmäki', 'Leivonmaeki', 'Leivonmaeki,Leivonmaki,Leivonmäki,Lejvonmjaki,Лейвонмяки', 61.9119800, 26.1279600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48941, 'Lehtimäki', 'Lehtimaeki', '', 62.7833300, 23.9166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48942, 'Lavia', 'Lavia', 'Lavia', 61.6000000, 22.6000000, 'FI', '2015-01-02', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48943, 'Laukaa', 'Laukaa', 'Lauka,Laukaa,Laukaa vald,Laukas,lao ka,lawka,Лаука,Лаукаа,لاوکا,勞卡', 62.4140700, 25.9519400, 'FI', '2015-03-01', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48944, 'Larsmo', 'Larsmo', 'Larsmo,Luoto', 63.7538800, 22.7472800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48945, 'Lapua', 'Lapua', 'Lappo,Lapua,la pu a,lapwa,Лапуа,لاپوا,拉普阿', 62.9692700, 23.0088000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48946, 'Lappi', 'Lappi', 'Lapinkyla,Lapinkylä,Lappi,Лаппи', 61.1000000, 21.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48947, 'Lappeenranta', 'Lappeenranta', 'Gorad Lapeehnranta,LPP,Lapeenranta,Lapenrand,Lapenranta,Lappeehnranta,Lappeenranta,Lappeenranta linn,Lappenranta,Lapēnranta,Villmanstrand,la peng lan ta,la pu lan da,labynrnta,lapenlanta,laprnta,lapynranta,lpyn rnta,rappenranta,Λαπεενράντα,Горад Лапеэнранта,Лапенранта,Лаппеенранта,Лаппенранта,Лаппеэнранта,לאפנראנטה,لابينرنتا,لاپرنتا,لاپینرانتا,لپین رنتا,ლაპეენრანტა,ラッペーンランタ,拉彭兰塔,拉普兰大,라펜란타', 61.0587100, 28.1887100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48948, 'Lappajärvi', 'Lappajaervi', '', 63.2000000, 23.6333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48949, 'Lapinlahti', 'Lapinlahti', 'Lapinlahti,Lapinlakhti,Лапинлахти', 63.3666700, 27.4000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48950, 'Lapinjärvi', 'Lapinjaervi', 'Lapin"jarvi,Lapinjaervi,Lapinjärvi,Lapptraesk,Lappträsk,Лапинъярви', 60.6244300, 26.1972000, 'FI', '2016-08-28', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48951, 'Längelmäki', 'Laengelmaeki', '', 61.6500000, 22.1000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48952, 'Lammi', 'Lammi', 'Lammi,Ламми', 61.0833300, 25.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48953, 'Laitila', 'Laitila', 'Laitila,Letala', 60.8757500, 21.6976500, 'FI', '2016-08-21', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48954, 'Laihia', 'Laihia', 'Laihela,Laihia', 62.9760900, 22.0114300, 'FI', '2015-04-21', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48955, 'Lahti', 'Lahti', 'Gorad Lakhty,Lachti,Laht,Lahti,Lahtis,Lakhti,Laxti,QLF,la he di,lah ti,lahty,lakhty,lati,rahati,Λάχτι,Горад Лахты,Лахти,Лахті,לאהטי,لاختی,لاهتي,لاہتی,ลาห์ตี,ラハティ,拉赫蒂,라티', 60.9826700, 25.6615100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48956, 'Kyyjärvi', 'Kyyjaervi', 'Kjujarvi,Kyyjaervi,Kyyjärvi,Кюярви', 63.0333300, 24.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48957, 'Kyrö', 'Kyroe', 'Kyro,Kyrö', 60.7000000, 22.7500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48958, 'Kirkkonummi', 'Kirkkonummi', 'Kirkkonummi,Kirkkonummi vald,Kirkonumi,Kyrkslaett,Kyrkslatt,Kyrkslätt,ji er ke nu mi,kileukonummi,kirukkonunmi,kyrkwnwmy,Киркконумми,Кирконуми,كيركونومي,کیرکونومی,キルッコヌンミ,基爾科努米,키르코눔미', 60.1238100, 24.4385300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48959, 'Kylmäkoski', 'Kylmaekoski', '', 61.1540000, 23.6885800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48960, 'Kuusjoki', 'Kuusjoki', 'Kuusjoki', 60.5166700, 23.2000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48961, 'Kuusamo', 'Kuusamo', 'Guossan,Guossán,KAO,Kouousamo,Kusamo,Kuusamo,Kuusamo linn,ku sa mo,kusamo,kwsamw,kwwsamw,Κούουσαμο,Кусамо,Куусамо,קוסאמו,کوسامو,کووسامو,クーサモ,庫薩莫', 65.9666700, 29.1833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48962, 'Kustavi', 'Kustavi', 'Gustaf,Gustavs', 60.5452900, 21.3588000, 'FI', '2015-05-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48963, 'Kuru', 'Kuru', '', 61.8755800, 23.7194800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48964, 'Kurikka', 'Kurikka', 'Kurikka,Курикка', 62.6166700, 22.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48965, 'Kuortane', 'Kuortane', 'Kuortane', 62.8000000, 23.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48966, 'Kuopio', 'Kuopio', 'KUO,Kouopio,Kuopijas,Kuopio,Kuopio linn,ko peiyw,ku ao pi ao,kuopio,kwwbyw,kwwpyw,qwpyw,Κουόπιο,Куопио,Куопіо,קופיו,كووبيو,کؤوپیو,کووپیو,โกเปียว,კუოპიო,クオピオ,庫奧皮奧,쿠오피오', 62.8923800, 27.6770300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48967, 'Kullaa', 'Kullaa', 'Kullaa', 61.4699800, 22.1614500, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48968, 'Kuivaniemi', 'Kuivaniemi', 'Kuivaniemi,Kujvaniemi,Куйваниеми', 65.5784700, 25.1881400, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48969, 'Kuhmoinen', 'Kuhmoinen', 'Kuhmoinen,Kukhmojnen,Кухмойнен', 61.5666700, 25.1833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48970, 'Kuhmo', 'Kuhmo', 'Kugmo,Kuhmo,Kuhmo linn,Kuhmoniemi,Kukhmo,ku he mo,kufumo,Кугмо,Кухмо,کوہمو,クフモ,庫赫莫', 64.1333300, 29.5166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48971, 'Kuhmalahti', 'Kuhmalahti', 'Kuhmalahti,Kukhmalakhti,Кухмалахти', 61.5000000, 24.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48972, 'Kronoby', 'Kronoby', 'KOK,Kronoby,Kronobyu,Kruununkyla,Kruununkylä,Kruunupjuu,Kruunupyy,ke luo nuo bi,Круунупюу,克羅諾比', 63.7285900, 23.0338700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48973, 'Kristinestad', 'Kristinestad', 'Kristiina,Kristiinankaupunki,Kristijnankaupunki,Kristinestad,ke li si di na cheng,kurisuchinesutaddo,Кристиинанкаупунки,Кристийнанкаупунки,Крістінестад,کریسٹین سٹڈ,クリスチーネスタッド,克里斯蒂娜城', 62.2742900, 21.3759600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48974, 'Köyliö', 'Koeylioe', 'Kjulo,Koeylioe,Köyliö', 61.1191000, 22.3097600, 'FI', '2016-02-03', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48975, 'Kouvola', 'Kouvola', 'Kouvol,Kouvola,Kouvola linn,Kovvola,ke wo la,koubolla,kouvu~ora,kwfwla,kwwla,kwwwwla,Коввола,Коувола,كوفولا,کوؤوولا,کوولا,コウヴォラ,科沃拉,코우볼라', 60.8666700, 26.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48976, 'Kotka', 'Kotka', 'Gorad Kotka,Kotk,Kotka,Kotka linn,Kotko,Kòtka,Ruotsinsalmi,Svensksund,ke te ka,koska,kotoka,kwtka,qwtqh,Κότκα,Горад Котка,Котка,קוטקה,كوتكا,کوتکا,コトカ,科特卡,콧카', 60.4664000, 26.9458200, 'FI', '2017-03-21', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48977, 'Hämeenkoski', 'Haemeenkoski', 'Koski,Коски', 61.0222200, 25.1541700, 'FI', '2016-02-03', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48978, 'Koski Tl', 'Koski Tl', 'Koski,Koski Tl', 60.6500000, 23.1500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48979, 'Kortesjärvi', 'Kortesjaervi', '', 63.3000000, 23.1666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48980, 'Korsnäs', 'Korsnaes', 'Korsnaes,Korsnes,Korsnäs,Ristitaipale', 62.7833300, 21.2000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48981, 'Korsholm', 'Korsholm', 'Korsholm,Mustasaari', 63.1141800, 21.6821600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48331, 'Aguilar de Campos', 'Aguilar de Campos', 'Aguilar de Campos', 41.9837500, -5.1811700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48332, 'Aguilar de Campóo', 'Aguilar de Campoo', 'Aguilar de Compoa', 42.7945200, -4.2589200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48333, 'Aguilar de Bureba', 'Aguilar de Bureba', 'Aguilar de Bureba', 42.5897400, -3.3291300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48334, 'Aguilafuente', 'Aguilafuente', 'Aguilafuente', 41.2266700, -4.1118500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48335, 'Aguaviva', 'Aguaviva', 'Aguaviva,Aiguaviva de Bergantes', 40.8221100, -0.1953200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48336, 'Aguatón', 'Aguaton', 'Aguaton,Aguatón', 40.6715800, -1.2347500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48337, 'Aguasal', 'Aguasal', 'Aguasal', 41.2749500, -4.6529000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48338, 'Aguarón', 'Aguaron', 'Aguaron,Aguarón', 41.3390100, -1.2705500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48339, 'Ágreda', 'Agreda', 'Agreda,a ge lei da,ageuleda,agrda,agureda,Агреда,Аґреда,آگردا,アグレダ,阿格雷达,아그레다', 41.8558800, -1.9224400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48340, 'Agramunt', 'Agramunt', 'Agramunt', 41.7868600, 1.0968300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48341, 'Agoncillo', 'Agoncillo', 'Agoncillo', 42.4466700, -2.2898000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48342, 'Agón', 'Agon', 'Agon,Agón', 41.8557400, -1.4523300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48343, 'Àger', 'Ager', 'Ager,Àger', 42.0000000, 0.7666700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48344, 'Agallas', 'Agallas', 'Agallas', 40.4486700, -6.4417600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48345, 'Adzaneta', 'Adzaneta', 'Adzaneta,Atzaneta del Maestrat', 40.2161600, -0.1702800, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48346, 'Aduna', 'Aduna', 'Aduna', 43.2037500, -2.0503300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48347, 'Adrados', 'Adrados', 'Adrados', 41.3681600, -4.1118600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48348, 'Adradas', 'Adradas', 'Adradas,Adradasa,a de la da si,adeuladaseu,adoradasu,adradas,Адрадас,آدراداس,アドラーダス,阿德拉达斯,아드라다스', 41.3509800, -2.4737300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48349, 'Adrada de Pirón', 'Adrada de Piron', 'Adrada de Piron,Adrada de Pirón', 41.0525700, -4.0510700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48350, 'Adrada de Haza', 'Adrada de Haza', 'Adrada de Haza', 41.5945400, -3.8232700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48351, 'Adobes', 'Adobes', 'Adobes', 40.6758400, -1.6791600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48352, 'Adiós', 'Adios', 'Ad''os,Adios,Adiós,a di ao si,Адьос,Адіос,阿迪奥斯', 42.6863500, -1.7353200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48353, 'Ademuz', 'Ademuz', 'Ademus,Ademuz,Ademús,Aldemuz,a de mu si,admwz,adymwz,Адемус,أديموز,ادموز,阿德穆斯', 40.0613900, -1.2867700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48354, 'Adanero', 'Adanero', 'Adanero,a da nei luo,adanrw,adanyrw,Аданеро,آدانرو,أدانيرو,阿达内罗', 40.9448700, -4.6056100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48355, 'Adalia', 'Adalia', 'Adalia', 41.6489400, -5.1210700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48356, 'Adahuesca', 'Adahuesca', 'Adahuesca', 42.1461000, -0.0080400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48357, 'Aceituna', 'Aceituna', 'Aceituna', 40.1500800, -6.3329200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48358, 'Acebo', 'Acebo', 'Acebo', 40.2010500, -6.7168900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48359, 'Acebedo', 'Acebedo', 'Acebedo', 43.0396900, -5.1160000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48360, 'Abusejo', 'Abusejo', 'Abusejo', 40.7090000, -6.1407400, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48361, 'Abrera', 'Abrera', 'Abrera', 41.5168200, 1.9010000, 'ES', '2012-01-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48362, 'Ablitas', 'Ablitas', 'Ablitas', 41.9745000, -1.6405300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48363, 'Ablanque', 'Ablanque', 'Ablanque', 40.8981800, -2.2252300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48364, 'Abizanda', 'Abizanda', 'Abizanda', 42.2423600, 0.1971700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48365, 'Abiego', 'Abiego', 'Abiego', 42.1209400, -0.0687300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48366, 'Abia de las Torres', 'Abia de las Torres', '', 42.4201600, -4.4213100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48367, 'Abezames', 'Abezames', 'Abezames', 41.6264200, -5.4257700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48368, 'Abejar', 'Abejar', 'Abehara,Abejar,Abekhar,a wei ha er,abehaleu,abeharu,abkhar,Абехар,آبخار,アベハール,阿韋哈爾,아베하르', 41.8075500, -2.7840700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48369, 'Abegondo', 'Abegondo', 'Abegondo,Santa Eulalia', 43.2166700, -8.2833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48370, 'Abanto', 'Abanto', 'Abanto', 41.1375100, -1.6981800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48371, 'Abánades', 'Abanades', 'Abanades,Abánades', 40.8926100, -2.4852600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48372, 'Ábalos', 'Abalos', 'Abalos,Ábalos', 42.5715400, -2.7095600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48373, 'Abaltzisketa', 'Abalcisqueta', 'Abalcisqueta,Abaltzisketa', 43.0474400, -2.1053200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48374, 'Abajas', 'Abajas', '', 42.6231000, -3.5808600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48375, 'Abáigar', 'Abaigar', 'Abaigar,Abáigar', 42.6482300, -2.1418200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48376, 'Abadín', 'Abadin', 'Abadin,Abadín,Santa Maria,Santa María', 43.3666700, -7.4833300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48377, 'Abadiño', 'Abadino', 'Abadiano,Abadiano Celayeta,Abadino,Abadino-Zelaieta,Abadiño,Abadiño-Zelaieta,Abandiano Celayeta', 43.1511000, -2.6094200, 'ES', '2012-11-09', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48378, 'Abadía', 'Abadia', '', 40.2592200, -5.9782800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48379, 'Abades', 'Abades', 'Abades', 40.9164600, -4.2693700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48380, 'Ababuj', 'Ababuj', 'Ababuj', 40.5490800, -0.8075800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48381, 'Nou Barris', 'Nou Barris', 'Distrikt Nou Barris,Distrito Nou Barris,Distrito de Nou Barris,Nou Barris,Nou Barris distritu', 41.4416300, 2.1772700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48382, 'Yerri', 'Yerri', '', 42.7016100, -1.9380600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48383, 'Blancafort', 'Blancafort', '', 41.4374000, 1.1598300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48384, 'Pinar de Chamartín', 'Pinar de Chamartin', '', 40.4790300, -3.6683600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48385, 'Las Tablas', 'Las Tablas', 'Las Tablas', 40.5064900, -3.6723500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48386, 'Santa Ponsa', 'Santa Ponsa', 'Santa Ponca,Santa Ponsa,Santa Ponça,Santa-Ponsa,Санта-Понса', 39.5086800, 2.4766000, 'ES', '2016-09-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48387, 'Valdelacalzada', 'Valdelacalzada', '', 38.8894300, -6.7002900, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48388, 'Areny de Noguera / Arén', 'Areny de Noguera / Aren', 'AAren,AArén,Areny de Noguera,Areny de Noguera / Aren,Areny de Noguera / Arén', 42.2581700, 0.7214100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48389, 'Sopeira', 'Sopeira', '', 42.3161500, 0.7463200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48390, 'el Torricó / Altorricon', 'el Torrico / Altorricon', 'Altorricon,Altorricón,el Torrico,el Torrico / Altorricon,el Torricó,el Torricó / Altorricon', 41.8028000, 0.4139000, 'ES', '2007-02-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48391, 'Playa del Ingles', 'Playa del Ingles', 'Plaja del'' Ingles,Playa del Ingles,Playa del Inglés,Плая дель Инглес', 27.7567000, -15.5787000, 'ES', '2008-11-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48392, 'Puerto Rico', 'Puerto Rico', '', 27.7894300, -15.7104500, 'ES', '2015-04-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48393, 'Cala d''Or', 'Cala d''Or', '', 39.3781000, 3.2347900, 'ES', '2015-08-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48394, 'Puerto del Carmen', 'Puerto del Carmen', 'Puehrto-del''-Karmen,Puerto del Carmen,Пуэрто-дель-Кармен', 28.9231300, -13.6657900, 'ES', '2015-06-10', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48395, 'Magaluf', 'Magaluf', 'Magalluf,Magaluf', 39.5111000, 2.5353000, 'ES', '2008-04-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48396, 'Peguera', 'Peguera', 'Paguera,Peguera', 39.5375100, 2.4480600, 'ES', '2016-09-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48397, 'Camp de Mar', 'Camp de Mar', 'Kamp-de-Mar,el Camp de Mar,es Camp de Mar,Камп-де-Мар', 39.5382700, 2.4238600, 'ES', '2013-11-16', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48398, 'La Manga del Mar Menor', 'La Manga del Mar Menor', 'La Manga,La Manga del Mar Menor,La-Manga-del''-Mar-Menor,Ла-Манга-дель-Мар-Менор', 37.6412900, -0.7165100, 'ES', '2012-04-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48399, 'Playa de las Américas', 'Playa de las Americas', 'las americas', 28.0640300, -16.7301200, 'ES', '2015-03-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48400, 'Las Rosas', 'Las Rosas', '', 28.0153900, -16.6537300, 'ES', '2007-03-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48401, 'Ceuta', 'Ceuta', 'Ceuta,JCU,Seuta,Сеута', 35.8893300, -5.3197900, 'ES', '2016-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48402, 'Sopuerta', 'Sopuerta', '', 43.2623900, -3.1550500, 'ES', '2010-04-05', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48403, 'Riu de Cerdanya', 'Riu de Cerdanya', '', 42.3454100, 1.8263100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48404, 'Urús', 'Urus', '', 42.3513100, 1.8534300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48405, 'el Pont de Bar', 'el Pont de Bar', '', 42.3711000, 1.6053800, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48406, 'Cabanes', 'Cabanes', 'Cabanes', 42.3080500, 2.9776600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48407, 'Sant Cristòfol de les Fonts', 'Sant Cristofol de les Fonts', '', 42.1696400, 2.4994300, 'ES', '2010-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48408, 'Alquerías del Niño Perdido', 'Alquerias del Nino Perdido', '', 39.8946600, -0.1294300, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48409, 'Port d''Alcúdia', 'Port d''Alcudia', 'Port d''Alcudia,Port d''Alcúdia', 39.8418200, 3.1329100, 'ES', '2008-04-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48410, 'Moncloa-Aravaca', 'Moncloa-Aravaca', 'Moncloa,Moncloa-Aravaca,Moncloa-Aravaca distritu,Monkloo-Aravako,monkuroa=arabaka,モンクロア＝アラバカ', 40.4354700, -3.7317000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48411, 'Eixample', 'Eixample', 'Ashjampla,Districte de lEixample,Distrikt Ensanche,Distrito Eixample,Distrito del Ensanche,Ehshample,Eixample,Eixample de Barcelona,Eixample distritu,EixampleBCN-projecteRovira.jpg|250px|miniatyr|hoeger|''''''Antonio Rovira i Trias stadsplan''''''.,EixampleBCN-projecteRovira.jpg|250px|miniatyr|höger|''''''Antonio Rovira i Trias stadsplan''''''.,Esample,L''Eixample,ashanpura,kuo zhan qu,Εσάμπλε,Ашямпла,Эшампле,אישמפלה,アシャンプラ,扩展区', 41.3889600, 2.1617900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48412, 'Les Corts', 'Les Corts', 'Distrito Les Corts,Les Corts', 41.3871200, 2.1300700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48413, 'Sarrià-Sant Gervasi', 'Sarria-Sant Gervasi', 'Distrito Sarria-Sant Gervasi,Distrito Sarrià-Sant Gervasi,Sarria,Sarria-Sant Gervasi,Sarrià,Sarrià-Sant Gervasi,sant gervasi', 41.4010400, 2.1394000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48414, 'Horta-Guinardó', 'Horta-Guinardo', 'Distrikt Horta-Guinardo,Distrikt Horta-Guinardó,Distrito Horta-Guinardo,Distrito Horta-Guinardó,Distrito de Horta-Guinardo,Distrito de Horta-Guinardó,Horta-Guinardo,Horta-Guinardo distritu,Horta-Guinardó,Horta-Guinardó distritu', 41.4184900, 2.1677000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48415, 'Sants-Montjuïc', 'Sants-Montjuic', 'District de Sants-Montjuic,District de Sants-Montjuïc,Distrikt Sants-Montjuic,Distrikt Sants-Montjuïc,Distrito Sants-Montjuic,Distrito Sants-Montjuïc,Distrito de Sants-Montjuic,Distrito de Sants-Montjuïc,Sants-Montjuic,Sants-Montjuic distritu,Sants-Montjuïc,Sants-Montjuïc distritu,Sants-Montjuїc,sheng tu-meng te hui qi,サンツ・ムンジュイック,圣徒-蒙特惠奇', 41.3726300, 2.1546000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48416, 'Sant Martí', 'Sant Marti', 'Districte de Sant Marti,Districte de Sant Martí,Distrikt Sant Marti,Distrikt Sant Martí,Distrito de Sant Marti,Distrito de Sant Martí,Sant Marti,Sant Marti distritu,Sant Martí,Sant Martí distritu', 41.4181400, 2.1993300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48417, 'Ciutat Vella', 'Ciutat Vella', 'Ciutat Vella,Ciutat Vella de Barcelona,Distrikt Ciutat Vella,Distrito Ciutat Vella,Distrito de Ciutat Vella,Staryj gorod,Vieille ville de Barcelone,jiu cheng qu,Старый город,シウタ・ベリャ,旧城区', 41.3802200, 2.1731900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48418, 'La Pineda', 'La Pineda', '', 41.0719000, 1.1782000, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48419, 'Retamar', 'Retamar', 'El Retamar', 36.8332000, -2.3159700, 'ES', '2014-03-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48420, 'S''Agaró', 'S''Agaro', 'S''agaro,Sagaro,Sagaró', 41.7936800, 3.0536400, 'ES', '2016-10-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48421, 'Benalup-Casas Viejas', 'Benalup-Casas Viejas', '', 36.3437500, -5.8128000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48422, 'Ballesteros de Calatrava', 'Ballesteros de Calatrava', '', 38.8346000, -3.9447000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48423, 'Arganzuela', 'Arganzuela', 'Argansuela,Arganzuela distritu,Arganzuelo,Distrito Arganzuela,a er gan su ai la,arugansuera,Արգանսուելա,アルガンスエラ,阿尔甘苏埃拉', 40.4002100, -3.6961800, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48424, 'San Blas-Canillejas', 'San Blas-Canillejas', 'Distrito San Blas,Distrito San Blas-Canillejas,San Blas-Canillejas', 40.4389300, -3.6153700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48425, 'Latina', 'Latina', 'Distrito Latina,Latina,Latina distritu,latyna,ratina,Լատինա,لاتینا,ラティーナ', 40.3889700, -3.7456900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48426, 'Usera', 'Usera', 'Distrito Usera', 40.3886600, -3.7003500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48427, 'Salamanca', 'Salamanca', 'Distrito Salamanca,Salamanka,Salamanko,saramanka,Саламанка,Սալամանկա,サラマンカ', 40.4297200, -3.6797500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48428, 'Chamberí', 'Chamberi', 'Camberio,Chamberi distritu,Chamberí distritu,Distrito Chamberi,Distrito Chamberí,chanberi,Ĉamberio,Չամբերի,チャンベリ', 40.4340400, -3.7037900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48429, 'Carabanchel', 'Carabanchel', 'Carabanchel distritu,Distrito Carabanchel,Karabancelo,Karabanĉelo,karabancheru,karabantshyl,كارابانتشيل,カラバンチェル', 40.3909400, -3.7242000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48430, 'City Center', 'City Center', 'Madrid Centro,Madrid City Center', 40.4183100, -3.7027500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48431, 'Retiro', 'Retiro', 'Districte de Retiro,Distrito Retiro,Retiro,Retiro distritu,retiro,Ռետիրո,レティーロ', 40.4131700, -3.6830700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48432, 'Barri Gòtic', 'Barri Gotic', 'Barri Gotic,Barri Gòtic,Barrio Gotico,Barrio Gotico de Barcelona,Barrio Gótico,Barrio Gótico de Barcelona,El Gotic,El Gòtic,Gothic Quarter,Gotic,Goticheskij kvartal,Gotichnij kvartal,Gotico,Gòtic,Gótico,Quartier gothique,ge te qu,goshikku,gothische Viertel,gwtyk kwartr barslwn,quartier gothique,Готический квартал,Готичний квартал,הרובע הגותי,گوتیک کوآرتر بارسلون,ゴシック,哥特区', 41.3836400, 2.1762800, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48433, 'Forcarei', 'Forcarei', '', 42.5923300, -8.3509000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48434, 'Poble Sec', 'Poble Sec', '', 41.3745200, 2.1632600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48435, 'Hostafrancs', 'Hostafrancs', '', 41.3769400, 2.1430600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48436, 'La Bordeta', 'La Bordeta', '', 41.3739700, 2.1437700, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48437, 'La Bonanova', 'La Bonanova', 'Bonanova', 41.4058500, 2.1324300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48438, 'Las Tres Torres', 'Las Tres Torres', '', 41.3998900, 2.1293100, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48439, 'Pedralbes', 'Pedralbes', '', 41.3904600, 2.1101900, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48440, 'el Coll', 'el Coll', 'Coll', 41.4172100, 2.1472300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48441, 'el Poblenou', 'el Poblenou', '', 41.4039200, 2.2041300, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48442, 'El Carmel', 'El Carmel', 'El Carmelo', 41.4175800, 2.1591400, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48443, 'Pego', 'Pego', 'Pego,byghw,pei ge,pgw,Пего,بيغو,پگو,佩戈', 38.8430500, -0.1170700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48444, 'l''Alfàs del Pi', 'l''Alfas del Pi', 'Alfas Del Pi,Alfaz,Alfaz del Pi,L''Alfas Del Pi', 38.5805500, -0.1032100, 'ES', '2016-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48445, 'Deltebre', 'Deltebre', '', 40.7194400, 0.7083500, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48446, 'Sedella', 'Sedella', '', 36.8623200, -4.0331400, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48447, 'Las Gabias', 'Las Gabias', '', 37.1354800, -3.6702900, 'ES', '2015-06-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48448, 'San José del Valle', 'San Jose del Valle', '', 36.6055400, -5.7989500, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48449, 'Camarles', 'Camarles', '', 40.7816900, 0.6550900, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48450, 'Vall de Gallinera', 'Vall de Gallinera', '', 38.8231300, -0.2417000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48451, 'Delicias', 'Delicias', '', 41.6492800, -0.9075700, 'ES', '2011-09-02', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48452, 'Almozara', 'Almozara', 'Al''mozara,La Quimica,La Química,Альмозара', 41.6612400, -0.9016900, 'ES', '2010-01-29', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48453, 'Montecanal', 'Montecanal', '', 41.6296500, -0.9387300, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48454, 'Oliver-Valdefierro', 'Oliver-Valdefierro', '', 41.6445400, -0.9334900, 'ES', '2015-05-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48455, 'Santutxu', 'Santutxu', '', 43.2534700, -2.9161000, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48456, 'Fort Pienc', 'Fort Pienc', '', 41.3945800, 2.1794600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48457, 'Dreta de l''Eixample', 'Dreta de l''Eixample', '', 41.3960600, 2.1668800, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48458, 'Vallcarca', 'Vallcarca', 'Vallcarca,Vallcarca i els Penitents', 41.4120900, 2.1439400, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48459, 'Sagrada Família', 'Sagrada Familia', '', 41.4040800, 2.1733200, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48460, 'Diagonal Mar', 'Diagonal Mar', '', 41.4089700, 2.2161500, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48461, 'Sant Martí de Provençals', 'Sant Marti de Provencals', 'Provencals,Provençals', 41.4202000, 2.1963200, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48462, 'Sondika', 'Sondika', '', 43.3002000, -2.9244200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48463, 'El Cotillo', 'El Cotillo', 'Ehl''-Kotil''o,El Cotillo,Эль-Котильо', 28.6826400, -14.0063700, 'ES', '2016-09-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48464, 'Los Gigantes', 'Los Gigantes', 'Acantilado de los Gigantes', 28.2436100, -16.8415300, 'ES', '2015-11-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48465, 'Los Realejos', 'Los Realejos', 'Los-Realekhos,luo si lei ya lai huo si,lws ryalykhws,Лос-Реалехос,لوس رياليخوس,洛斯雷亚莱霍斯', 28.3848700, -16.5827500, 'ES', '2015-06-14', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48466, 'Sant Guim de Freixenet', 'Sant Guim de Freixenet', 'Sant Guim de l''Estacio,Sant Guim de l''Estació', 41.6557300, 1.4202400, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48467, 'Sant Joan de Mediona', 'Sant Joan de Mediona', '', 41.4786200, 1.6116400, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48468, 'Pasaia', 'Pasaia', 'Pasaja,Pasajes,Pasakhes,Passatge,basakhys,pa sai a,pasaia,Пасахес,Пасая,باساخيس,帕赛阿,파사이아', 43.3253000, -1.9270700, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48469, 'El entrego', 'El entrego', 'L''Entregu', 43.2875200, -5.6380000, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48470, 'El Toro', 'El Toro', '', 39.4847700, 2.4822200, 'ES', '2016-09-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48471, 'Navas de San Juan', 'Navas de San Juan', '', 38.1838200, -3.3159800, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48472, 'Basauri', 'Basauri', 'Basauri,ba shao li,basauri,basawry,Басаури,Басаурі,باساوري,バサウリ,巴绍里', 43.2397000, -2.8858000, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48473, 'Castrillón', 'Castrillon', 'Kastril''jon,Kastril''on,ka si te li li weng,kastrywn,kastryyn,Кастрильон,Кастрільйон,كاستريون,کاستریین,卡斯特里利翁', 43.5479300, -5.9938100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48474, 'Novés', 'Noves', '', 40.0474600, -4.2747100, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48475, 'Sahún', 'Sahun', '', 42.5759000, 0.4654600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48476, 'Taberno', 'Taberno', '', 37.4688000, -2.0773600, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48477, 'Llefià', 'Llefia', '', 41.4380600, 2.2195000, 'ES', '2011-09-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48478, 'Corvera de Asturias', 'Corvera de Asturias', 'Corvera,Korvera-de-Asturias,ke er wei la de a si tu li ya si,krbra d astwryas,kwrfyra dy astwryas,Корвера-де-Астуриас,Корвера-де-Астуріас,كورفيرا دي أستورياس,کربرا د آستوریاس,科尔韦拉德阿斯图里亚斯', 43.5355400, -5.8889300, 'ES', '2015-09-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48479, 'San Isidro', 'San Isidro', 'Paraje San Isidro,San Isidro de Albatera', 38.1724900, -0.8387400, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48480, 'Vega del Codorno', 'Vega del Codorno', '', 40.4245700, -1.9131200, 'ES', '2011-07-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48481, 'Barreiros', 'Barreiros', '', 43.5332100, -7.2334200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48482, 'els Poblets', 'els Poblets', '', 38.8538100, 0.0210300, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48483, 'Navarredonda de Gredos', 'Navarredonda de Gredos', 'Gredos,Navaredonda de Gredos,Navarredonda de Gredos,Navarredonda-de-Gredos,na wa lei dong da de ge lei duo si,nabardnda d grds,nafarydwnda dy ghrydws,Наваредонда де Гредос,Наварредонда-де-Гредос,ناباردندا د گردس,نافاريدوندا دي غريدوس,纳瓦雷东达德格雷多斯', 40.3613600, -5.1326800, 'ES', '2016-01-11', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48484, 'Tres Cantos', 'Tres Cantos', 'Tres Cantos,Tres-Kantos,Três Cantos,te lei si kan tuo si,trys santws,Трес-Кантос,تريس سانتوس,特雷斯坎托斯', 40.6009200, -3.7080600, 'ES', '2015-06-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48485, 'Castellar del Riu', 'Castellar del Riu', '', 42.1229900, 1.7737800, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48486, 'Senterada', 'Senterada', '', 42.3254900, 0.9364100, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48487, 'Mendexa', 'Mendexa', 'Mendeja,Mendexa', 43.3459000, -2.4842000, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48488, 'Capolat', 'Capolat', '', 42.0772000, 1.7535200, 'ES', '2010-11-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48489, 'Totalán', 'Totalan', '', 36.7652600, -4.2970700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48490, 'Sanlúcar de Barrameda', 'Sanlucar de Barrameda', 'San Lucar de Barrameda,Sanlukar de Barameda,Sanlukar-de-Barrameda,sang lu ka er de wa la mei da,sanlukaleudebalameda,shlwqt,Санлукар де Барамеда,Санлукар-де-Баррамеда,شلوقة,სანლუკარ-დე-ბარამედა,サンルーカル・デ・バラメーダ,桑卢卡尔德瓦拉梅达,산루카르데바라메다', 36.7788900, -6.3538900, 'ES', '2011-04-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48491, 'Jete', 'Jete', '', 36.7969100, -3.6672000, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48492, 'Atanzón', 'Atanzon', '', 40.6669700, -2.9968600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48493, 'Etxebarria', 'Etxebarria', '', 43.2541400, -2.4777600, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48494, 'Bakio', 'Bakio', '', 43.4291700, -2.8088100, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48495, 'Iturrama', 'Iturrama', '', 42.8084700, -1.6582500, 'ES', '2011-10-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48496, 'Ermitagaña', 'Ermitagana', '', 42.8108400, -1.6640900, 'ES', '2011-10-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48497, 'Primer Ensanche', 'Primer Ensanche', '', 42.8148300, -1.6489800, 'ES', '2011-10-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48498, 'Segundo Ensanche', 'Segundo Ensanche', '', 42.8139000, -1.6429500, 'ES', '2011-10-17', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48499, 'Pueblonuevo de Miramontes', 'Pueblonuevo de Miramontes', '', 40.0606000, -5.3783200, 'ES', '2016-12-21', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48500, 'Les Franqueses del Vallès', 'Les Franqueses del Valles', '', 41.6192900, 2.2982900, 'ES', '2012-02-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48501, 'San Tirso de Abres', 'San Tirso de Abres', '', 43.4087300, -7.1431700, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48502, 'Santiago de Alcántara', 'Santiago de Alcantara', '', 39.6066100, -7.2440200, 'ES', '2012-03-04', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48503, 'Fuencarral-El Pardo', 'Fuencarral-El Pardo', '', 40.4984000, -3.7314000, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48504, 'Villa de Vallecas', 'Villa de Vallecas', 'Valjeko,Villa de Vallecas distritu,ビリャ・デ・バリェカス', 40.3669500, -3.6014600, 'ES', '2017-05-26', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48505, 'Moriles', 'Moriles', '', 37.4367000, -4.6076100, 'ES', '2013-03-13', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48506, 'Natahoyo', 'Natahoyo', '', 43.5403500, -5.6823300, 'ES', '2013-10-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48507, 'Castroviejo', 'Castroviejo', '', 42.3293800, -2.6612200, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48508, 'Daroca de Rioja', 'Daroca de Rioja', '', 42.3711500, -2.5818700, 'ES', '2014-01-07', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48509, 'Son Ferrer', 'Son Ferrer', '', 39.4966600, 2.5010200, 'ES', '2016-09-25', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48510, 'Liendo', 'Liendo', 'L''endo,Liendo,lian duo,yyndw,Льендо,Льєндо,Լիենդո,ييندو,连多', 43.4008000, -3.3702900, 'ES', '2014-12-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48511, 'Villanova', 'Villanova', '', 42.5470200, 0.4618300, 'ES', '2014-12-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48512, 'Gordexola', 'Gordexola', '', 43.1786000, -3.0760000, 'ES', '2014-12-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48513, 'Liérganes', 'Lierganes', '', 43.3461400, -3.7466800, 'ES', '2014-12-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48514, 'Sant Julià de Ramis', 'Sant Julia de Ramis', '', 42.0293200, 2.8533800, 'ES', '2014-12-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48515, 'Olivenza', 'Olivenza', 'Olivenca,Olivensa,Olivenza,Olivenza - Olivenca,Olivenza - Olivença,Olivença,alybnsa,ao li wen sa,awlayfynza,ollibensa,oribensa,Оливенза,Оливенса,Олівенса,أولايفينزا,الیبنسا,オリベンサ,奥利文萨,올리벤사', 38.6826900, -7.1004600, 'ES', '2014-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48516, 'Andosilla', 'Andosilla', '', 42.3772900, -1.9426700, 'ES', '2014-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48517, 'Muxika', 'Muxika', '', 43.2890500, -2.6893700, 'ES', '2014-12-23', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48518, 'Costacabana', 'Costacabana', '', 36.8380700, -2.3811100, 'ES', '2015-09-28', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48519, 'Castellnou de Bages', 'Castellnou de Bages', '', 41.8344400, 1.8372100, 'ES', '2015-10-30', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48520, 'La Pobla de Farnals', 'La Pobla de Farnals', '', 39.5657100, -0.2842500, 'ES', '2016-10-12', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48521, 'Callús', 'Callus', '', 41.7814600, 1.7840100, 'ES', '2016-02-15', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48522, 'Ubide', 'Ubide', '', 43.0239600, -2.6875900, 'ES', '2016-02-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48523, 'Valdezorras', 'Valdezorras', '', 37.4293900, -5.9262900, 'ES', '2016-03-31', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48524, 'La Gangosa Vistasol', 'La Gangosa Vistasol', 'Gangosa Vitasol,La Gangosa', 36.8058100, -2.6217400, 'ES', '2016-06-06', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48525, 'Balanegra', 'Balanegra', '', 36.7488600, -2.9097000, 'ES', '2016-12-19', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48526, 'Tiétar', 'Tietar', '', 40.0294500, -5.4819200, 'ES', '2016-12-20', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48527, 'Montbau', 'Montbau', '', 41.4352900, 2.1378100, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48528, 'Sant Genís dels Agudells', 'Sant Genis dels Agudells', '', 41.4254100, 2.1301900, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48529, 'Vallvidrera, el Tibidabo i les Planes', 'Vallvidrera, el Tibidabo i les Planes', '', 41.4197000, 2.0891100, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48530, 'la Marina del Prat Vermell', 'la Marina del Prat Vermell', '', 41.3393700, 2.1426200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48531, 'Sarrià', 'Sarria', '', 41.4026900, 2.1162000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48532, 'l''Antiga Esquerra de l''Eixample', 'l''Antiga Esquerra de l''Eixample', '', 41.3893900, 2.1551700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48533, 'el Baix Guinardó', 'el Baix Guinardo', '', 41.4117500, 2.1678400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48534, 'el Parc i la Llacuna del Poblenou', 'el Parc i la Llacuna del Poblenou', '', 41.3986000, 2.1903000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48535, 'la Prosperitat', 'la Prosperitat', '', 41.4426900, 2.1820000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48536, 'el Putxet i el Farró', 'el Putxet i el Farro', '', 41.4069300, 2.1439200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48537, 'Provenals del Poblenou', 'Provenals del Poblenou', '', 41.4110900, 2.2026000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48538, 'Sant Antoni', 'Sant Antoni', '', 41.3785700, 2.1593700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48539, 'Can Baró', 'Can Baro', '', 41.4167700, 2.1624200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48540, 'Baró de Viver', 'Baro de Viver', '', 41.4458400, 2.1990200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48541, 'Vallbona', 'Vallbona', '', 41.4634100, 2.1841700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48542, 'la Vila de Gràcia', 'la Vila de Gracia', '', 41.4031500, 2.1568700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48543, 'la Nova Esquerra de l''Eixample', 'la Nova Esquerra de l''Eixample', '', 41.3830900, 2.1490000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48544, 'Porta', 'Porta', '', 41.4349000, 2.1788300, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48545, 'la Font de la Guatlla', 'la Font de la Guatlla', '', 41.3697800, 2.1448600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48546, 'Sants - Badal', 'Sants - Badal', '', 41.3747100, 2.1277500, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48547, 'la Maternitat i Sant Ramon', 'la Maternitat i Sant Ramon', '', 41.3812500, 2.1174400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48548, 'Sant Gervasi - Galvany', 'Sant Gervasi - Galvany', '', 41.3975000, 2.1430100, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48549, 'Verdun', 'Verdun', '', 41.4427300, 2.1756400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48550, 'el Camp d''en Grassot i Gràcia Nova', 'el Camp d''en Grassot i Gracia Nova', '', 41.4063400, 2.1650300, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48551, 'Can Peguera', 'Can Peguera', '', 41.4348700, 2.1664600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48552, 'la Marina de Port', 'la Marina de Port', '', 41.3600000, 2.1398600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48553, 'Vilapicina i la Torre Llobeta', 'Vilapicina i la Torre Llobeta', '', 41.4286100, 2.1741000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48554, 'el Camp de l''Arpa del Clot', 'el Camp de l''Arpa del Clot', '', 41.4120400, 2.1824700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48555, 'el Bon Pastor', 'el Bon Pastor', '', 41.4370000, 2.2018200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48556, 'Canyelles', 'Canyelles', '', 41.4450900, 2.1634600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48557, 'la Salut', 'la Salut', '', 41.4124300, 2.1543700, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48558, 'la Font d''en Fargues', 'la Font d''en Fargues', '', 41.4246100, 2.1652600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48559, 'el Congrés i els Indians', 'el Congres i els Indians', '', 41.4246000, 2.1808600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48560, 'la Teixonera', 'la Teixonera', '', 41.4230700, 2.1465400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48561, 'la Vall d''Hebron', 'la Vall d''Hebron', '', 41.4303800, 2.1483000, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48562, 'la Trinitat Nova', 'la Trinitat Nova', '', 41.4505100, 2.1848100, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48563, 'Navas', 'Navas', '', 41.4180300, 2.1859600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48564, 'la Guineueta', 'la Guineueta', '', 41.4388400, 2.1689300, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48565, 'les Roquetes', 'les Roquetes', '', 41.4480900, 2.1751900, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48566, 'Ciutat Meridiana', 'Ciutat Meridiana', '', 41.4611900, 2.1749400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48567, 'la Trinitat Vella', 'la Trinitat Vella', '', 41.4516600, 2.1928900, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48568, 'la Vila Olímpica del Poblenou', 'la Vila Olimpica del Poblenou', '', 41.3907400, 2.1967900, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48569, 'la Verneda i la Pau', 'la Verneda i la Pau', '', 41.4239900, 2.2030400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48570, 'Sant Andreu', 'Sant Andreu', '', 41.4369300, 2.1902200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48571, 'el Turó de la Peira', 'el Turo de la Peira', '', 41.4323200, 2.1689500, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48572, 'el Besòs i el Maresme', 'el Besos i el Maresme', '', 41.4130900, 2.2173600, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48573, 'el Guinardó', 'el Guinardo', '', 41.4188500, 2.1736400, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48574, 'Torre Baró', 'Torre Baro', '', 41.4549000, 2.1741800, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48575, 'Barri de Sant Andreu', 'Barri de Sant Andreu', '', 41.4369300, 2.1902200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48576, 'Barri de les Corts', 'Barri de les Corts', '', 41.3869700, 2.1347200, 'ES', '2017-05-24', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48577, 'Barrio de San José Obrero', 'Barrio de San Jose Obrero', '', 38.0280500, -1.0491900, 'ES', '2017-06-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48578, 'Cabecicos', 'Cabecicos', '', 38.0241300, -1.0682100, 'ES', '2017-06-18', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48579, 'Sarriguren', 'Sarriguren', '', 42.8129200, -1.5981500, 'ES', '2017-06-22', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48580, 'Rayaces', 'Rayaces', '', 41.9213700, -4.7140100, 'ES', '2017-06-27', 209);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49149, 'Stanley', 'Stanley', 'Gorad Stehnli,PSY,Port Stanley,Port Stenli,Port Stenlis,Port-Stehnli,Port-Stenli,Porto Arxentino/Stanley,Puerto Archentinas/Stenlis,Puerto Argentino,Puerto Stanley,Stanlef,Stanlejo,Stanley,Stanley Harbour,Stenli,Stenlis,astnly  jzayr falklnd,asٹynlے  jzayr faklynڈ,icutanli,porta stenli,seutaenli,si tan li,si tan li gang,stanly,stnly,sutanre,sutanri,Στάνλεϋ,Горад Стэнлі,Порт Стенли,Порт-Стенлі,Порт-Стэнли,Стенли,Պորտ Սթենլի,סטאנלי,סטנלי,استنلی، جزایر فالکلند,اسٹینلے، جزائر فاکلینڈ,ستانلي,سٹینلے,पोर्ट स्टॅन्ली,இசுடான்லி,സ്റ്റാൻലി,สแตนลีย์,スタンリー,スタンレー,斯坦利,斯坦利港,스탠리', -51.7000000, -57.8500000, 'FK', '2017-01-08', 72);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49202, 'Vestmanna', 'Vestmanna', 'Vestmanhavn,Vestmanshavn,Vestnanhavn', 62.1535400, -7.1729100, 'FO', '2017-07-20', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49203, 'Vágur', 'Vagur', 'Gorad Vagur,Vaag,Vag,Vagur,Vaguras,Voavur,Våg,Вагур,Воавур,Горад Вагур', 61.4732400, -6.8118500, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49204, 'Tvøroyri', 'Tvoroyri', 'Tvaera,Tvaeraa,Tvaora,Tvera,Tveraa,Tverå,Tvioroiris,Tvjorojri,Tvorovri,Tværaa,Tværå,Tvörovri,Твёройри', 61.5555700, -6.8110900, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49205, 'Tórshavn', 'Torshavn', 'Gorad Torskhaun,Havn,THorshoefn,THunreshaefen,Thori Portus,Thorshavn,Torschavn,Torsgavn,Torshamn,Torshaunas,Torshavn,Torshgavn,Torshkhavn,Torskhavn,Tourshavna,Touršhavna,Tórshavn,lei shen gang,thosa''una,thxrs hea n,toleuseuhaun,tosuhaun,tuo er si gang,twshhafn,twshhawn,tۆrshawn,Þunreshæfen,Þórshöfn,Τόρσχαβν,Горад Торсхаўн,Торсгавн,Торсхавн,Торшгавн,Торшхавн,Տորսհավն,טורסהאבן,تورشھاون,توشهافن,توشهاون,تۆرشاون,ਥੋਸ਼ਾਊਨ,ทอร์สเฮาน์,ტორსჰავნი,トースハウン,托爾斯港,雷神港,토르스하운', 62.0097300, -6.7716400, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49206, 'Sørvágur', 'Sorvagur', 'Siorvaguras,Sjorvoavur,Soervaag,Sorvaag,Sorvag,Sorvagur,Sörvag,Sørvaag,Sørvágur,Sørvåg,Сёрвоавур', 62.0972600, -7.3577000, 'FO', '2014-07-21', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49207, 'Sandur', 'Sandur', 'Sand,Sandur,Sanduras,Сандур,סאנדור', 61.8425000, -6.8077800, 'FO', '2009-07-20', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49208, 'Miðvágur', 'Midvagur', 'Midvaag,Midvag,Midvaguras,Midvåg,Mivoavur,Мивоавур', 62.0511100, -7.1938900, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49209, 'Kunoy', 'Kunoy', 'Kounoi,Kuno,Kuno Bygd,Kunoj,Kunoy,Kunoyarbygd,Kunö,Kunö Bygd,Vostrau Kunoj,kun dao,kunoi dao,qwnwy,Κούνοϊ,Востраў Куной,Куной,קונוי,クノイ島,昆岛', 62.3038800, -6.6475400, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49210, 'Kollafjørður', 'Kollafjordhur', 'Kollafjordhur,Kollafjørður,Kollefiord Church,Kollefjord,Kollefjord Kirke', 62.1116700, -6.9106700, 'FO', '2012-01-17', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49211, 'Klaksvík', 'Klaksvik', 'Gorad Klaksvujk,Klakksvik,Klakksvík,Klaksvig,Klaksvik,Klaksvikas,Klaksvujk,Klaksvík,ke la ke si wei ke,klaksvyk,klakswyk,kurakusuvu~iku,Горад Клаксвуйк,Клаксвик,Клаксвуйк,Клаксвік,Քլակսվուիկ,קלאקסוויק,كلاكسويك,كلاكسڤيك,კლაქსვიკი,クラクスヴィーク,克拉克斯维克', 62.2265500, -6.5890100, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49212, 'Hoyvík', 'Hoyvik', 'Gojvik,Gorad Khojvik,Hojvig,Hojvikas,Hoyvig,Hoyvik,Hoyvík,Höjvig,Khojvujk,Гойвік,Горад Хойвік,Хойвуйк,ჰოივიკი', 62.0340700, -6.7812700, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49213, 'Fuglafjørður', 'Fuglafjordur', 'Fuglaf''jorur,Fuglaf''ordur,Fuglafjoerdur,Fuglafjordur,Fuglafjorduras,Fuglafjörður,Fuglafjørður,Fuglefiord,Fuglefjord,Vjoska Fuglafijordur,Вёска Фуглафіёрдур,Фуглафьордур,Фуглафьёрур', 62.2439800, -6.8139500, 'FO', '2009-07-20', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49214, 'Eiði', 'Eidi', 'Aji,Eide,Eidhi,Eidis,Eiði,Ejde,Айи', 62.2993000, -7.0924500, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49215, 'Argir', 'Argir', 'Ardzhir,Arge,Argir,Argiras,Арджир', 61.9959500, -6.7715400, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49216, 'Eystur', 'Eystur', '', 62.2090700, -6.7524700, 'FO', '2017-02-01', 73);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49142, 'Suva', 'Suva', 'Gorad Suva,SUV,Souba,Souva,Sufa,Suv,Suva,Suva City,Suvae,Suvo,Suwa,cuva,su wa,suba,subha,suva,suwa,swbh,swfa,swwa,Σούβα,Горад Сува,Сувæ,Сува,Սուվա,סובה,سوفا,سووا,सुवा,সুভা,ਸੂਵਾ,சுவா,ซูวา,སུ་ཝ།,სუვა,ሱቫ,スバ,蘇瓦,수바', -18.1416100, 178.4414900, 'FJ', '2010-05-30', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49143, 'Nadi', 'Nadi', 'NAN,Nadi,Nadis,Nandi,Nanti Fitzi,nadi,nady,nan di,nandi,nanti,Νάντι Φίτζι,Нанди,نادي,நண்டி,ナンディ,楠迪,나디', -17.8030900, 177.4161700, 'FJ', '2016-04-10', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49144, 'Levuka', 'Levuka', '', -18.0666700, 179.3166700, 'FJ', '2013-08-16', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49145, 'Lautoka', 'Lautoka', 'Lautok,Lautoka,lao tuo ka,lautoka,lawtwka,lutokka,lwtwqh,rautoka,Лаутока,לוטוקה,لاوتوكا,لاوتوکا,लौतोका,லூடோக்கா,ラウトカ,劳托卡,라우토카', -17.6168600, 177.4504900, 'FJ', '2016-07-17', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49146, 'Labasa', 'Labasa', 'LBS,Labasa,Lambasa,Lambasa Mill,Lambase,Lambassa', -16.4332000, 179.3645100, 'FJ', '2016-04-17', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49147, 'Ahau', 'Ahau', '', -12.5000000, 177.0500000, 'FJ', '2013-06-27', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49148, 'Ba', 'Ba', 'Ba,Mba,ba,impa,Μπα,Мба,با,இம்பா,バ,바', -17.5343000, 177.6740700, 'FJ', '2016-11-18', 74);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48982, 'Korpilahti', 'Korpilahti', 'Korpilahti,Korpilakhti,Корпилахти', 62.0166700, 25.5500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48983, 'Kontiolahti', 'Kontiolahti', 'Kontiolagti,Kontiolahti,Kontiolahti vald,Kontiolakhti,Kontiolax,kong di ao la he di,Контиолахти,Контіолагті,孔蒂奧拉赫蒂', 62.7602300, 29.8471100, 'FI', '2015-03-12', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48984, 'Konnevesi', 'Konnevesi', 'Konnevesi,Конневеси', 62.6166700, 26.3166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48985, 'Kolari', 'Kolari', 'Kolari', 67.3304700, 23.7778500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48986, 'Kokkola', 'Kokkola', 'Carolina Vetus,Gamla-Kargabyu,Gamla-Karlabyu,Gamla-Kergabyu,Gamlakarleby,KOK,Karleby,Kokkol,Kokkola,Kokkola linn,Kokola,ke ke la,kokkora,kokolla,kwkwla,qwqwlh,Коккола,Кокола,Կոկկոլա,קוקולה,كوكولا,کوکولا,コッコラ,科科拉,코콜라', 63.8384700, 23.1306600, 'FI', '2014-12-29', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48987, 'Kokemäki', 'Kokemaeki', 'Gorad Kokemjaki,Kokemaeki,Kokemaeki linn,Kokemaki,Kokemjaki,Kokemäki,Kokemäki linn,Kumo,ke kai mai ji,Горад Кокемякі,Кокемяки,Кокемякі,Кокемӓки,کوکے ماکی,科凱邁基', 61.2564700, 22.3564300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48988, 'Kivijärvi', 'Kivijaervi', 'Kivijaervi,Kivijarvi,Kivijärvi,Кивиярви', 63.1198400, 25.0783500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48989, 'Kiuruvesi', 'Kiuruvesi', 'Kiuruvesi,Киурувеси', 63.6500000, 26.6166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48990, 'Kiukainen', 'Kiukainen', 'Kiukainen,Kiukais', 61.2166700, 22.0833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48991, 'Kittilä', 'Kittilae', 'Gihttel,KTT,Kittila,Kittilae,Kittilae vald,Kittilja,Kittilä,Kittilä vald,ji di lai,kitillae,Киттиля,基蒂莱,키틸래', 67.6647400, 24.8935600, 'FI', '2016-10-23', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48992, 'Kitee', 'Kitee', 'KTQ,Kides,Kite,Kitee,Kiteeh,Kiteh,ji tai,Κίτεε,Ките,Китее,Китеэ,Китэ,Кітее,Կիտեե,کیتے,კიტეე,基泰', 62.1000000, 30.1500000, 'FI', '2015-03-01', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48993, 'Kisko', 'Kisko', '', 60.2333300, 23.4833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48994, 'Kinnula', 'Kinnula', 'Kinnula,Киннула', 63.3833300, 24.9500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48995, 'Kinnula', 'Kinnula', '', 63.3666700, 24.9666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48996, 'Kimito', 'Kimito', 'Kemioe,Kemiö,Kimito', 60.1604700, 22.7290000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48997, 'Kiiminki', 'Kiiminki', 'Kiiminki,Kiminki,Киминки', 65.1313900, 25.7974400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48998, 'Kiikoinen', 'Kiikoinen', 'Kiikoinen,Kikois', 61.4538500, 22.5769900, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(48999, 'Kiikala', 'Kiikala', '', 60.4666700, 23.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49000, 'Kiihtelysvaara', 'Kiihtelysvaara', 'Kiihtelysvaara,Kikhteljusvara,Кихтелюсвара', 62.4952500, 30.2508100, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49001, 'Kihniö', 'Kihnioe', '', 62.2000000, 23.1833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49002, 'Keuruu', 'Keuruu', 'Keuru,Keuruu,Keuruu linn,kai wu lu,keuru,kywrw,Кеуруу,کیورو,ケウルー,凱烏魯', 62.2666700, 24.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49003, 'Kestilä', 'Kestilae', 'Kestila,Kestilja,Kestilä,Кестиля', 64.3500200, 26.2792100, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49004, 'Kesälahti', 'Kesaelahti', 'Kesaelahti,Kesjalakhti,Kesälahti,Кесялахти', 61.8975200, 29.8349400, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49005, 'Kerimäki', 'Kerimaeki', 'Kerimaeki,Kerimjaki,Kerimäki,Керимяки', 61.9106900, 29.2822800, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49006, 'Kerava', 'Kerava', 'Kerava,Kervo,kai la wa,kelaba,keravu~a,krawa,kyrafa,kyrawa,Керава,كيرافا,کراوا,کیراوا,ケラヴァ,凱拉瓦,케라바', 60.4033800, 25.1050000, 'FI', '2016-04-10', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49007, 'Kempele', 'Kempele', 'Kempele,Kempelen,Кемпеле', 64.9131400, 25.5033900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49008, 'Kemijärvi', 'Kemijaervi', 'Giemajavri,Giemajávri,Kemijaervi,Kemijaervi linn,Kemijarvi,Kemijärvi,Kemijärvi linn,kai mi ye er wei,kymy yarwy,Кемиярви,Кеміярві,کیمی یاروی,凱米耶爾維', 66.6666700, 27.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49009, 'Keminmaa', 'Keminmaa', 'Kemi,Keminmaa', 65.8015800, 24.5448300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49010, 'Kemi', 'Kemi', 'Giepma,Gorad Kemi,KEM,Kemi,Kemis,ji mi,kai mi,kemi,kymy,Горад Кемі,Кеми,Кемі,كيمي,کیمی,ケミ,凯米,基米,케미', 65.7364100, 24.5637100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49011, 'Kellokoski', 'Kellokoski', 'Kellokoski,Mariefors,Келлокоски', 60.5327100, 25.1091700, 'FI', '2016-05-02', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49012, 'Keitele', 'Keitele', 'Keitele', 63.1833300, 26.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49013, 'Kaustinen', 'Kaustinen', 'Kaustby,Kaustinen', 63.5487800, 23.6884500, 'FI', '2015-01-10', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49014, 'Kauniainen', 'Kauniainen', 'Grankulla,Kauniainen,Kauniainenas,Kauniajnen,kao ni ai ning,kauniainen,kawny ayynn,Гранкулла,Кауниайнен,Кауніайнен,کاؤنی آئینن,კაუნიაინენი,考尼艾寧,카우니아이넨', 60.2120900, 24.7275600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49015, 'Kauhava', 'Kauhava', 'KAU,Kaugava,Kauhava,Kauhava linn,Kaukhava,kao ha wa,Каугава,Каухава,کاوہاوا,考哈瓦', 63.1029900, 23.0712900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49016, 'Kauhajoki', 'Kauhajoki', 'KHJ,Kaugajoki,Kauhajoki,Kauhajokis,Kaukha-Yoki,Kaukhajoki,kao ha yue ji,kauhayoki,Каугайокі,Каухайоки,کاوہایوکی,カウハヨキ,考哈约基,카우하요키', 62.4333300, 22.1833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49017, 'Kaskinen', 'Kaskinen', 'Kaske,Kaskinen,Kaskinena,Kaskoe,Kaskë,Kaskö,ka si ke,kaskynn,Каскинен,Каскінен,کاسکینن,卡斯克', 62.3844400, 21.2233100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49018, 'Karvia', 'Karvia', '', 62.2000000, 22.6500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49019, 'Karvia', 'Karvia', 'Karvia', 62.1333300, 22.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49020, 'Karttula', 'Karttula', 'Karttula,Karttulankyla,Karttulankylä,Vapaakirkko,Карттула', 62.8963000, 26.9704500, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49021, 'Karstula', 'Karstula', 'Karstula,Карстула', 62.8666700, 24.7833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49022, 'Kärsämäki', 'Kaersaemaeki', 'Kaersaemaeki,Kjarsjamjaki,Kärsämäki,Кярсямяки', 63.9666700, 25.7666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49023, 'Kärkölä', 'Kaerkoelae', 'Kaerkoelae,Kjarkela,Kärkölä,Кяркела', 60.9166700, 25.2500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49024, 'Kärkölä', 'Kaerkoelae', 'Karkala,Karkola,Kjarkela,Kärkälä,Kärkölä,Кяркела', 60.6129200, 23.9419600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49025, 'Karkkila', 'Karkkila', 'Hoegfors,Högfors,Karkkila,Karkkila linn,QVF,ka er ji la,kaleukilla,karkyla,Карккила,Карккіла,کارکیلا,卡爾基拉,카르킬라', 60.5341800, 24.2097700, 'FI', '2015-05-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49026, 'Karjalohja', 'Karjalohja', 'Karislojo,Karjalohja', 60.2401500, 23.7178900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49027, 'Karis', 'Karis', 'Kar''jaa,Karis,Karja,Karjaa,ka li si,karys,Карьяа,کاریس,卡里斯', 60.0717800, 23.6616300, 'FI', '2016-10-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49028, 'Karinainen', 'Karinainen', 'Karinainen,Karinais', 60.6666700, 22.7666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49029, 'Karijoki', 'Karijoki', 'Boetom,Bötom', 62.3085100, 21.7085600, 'FI', '2016-11-13', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49030, 'Karhula', 'Karhula', 'Karhula,Karkhula,Кархула', 60.5215600, 26.9312500, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49031, 'Kannus', 'Kannus', 'Kannus,Каннус', 63.9000000, 23.9000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49032, 'Kannonkoski', 'Kannonkoski', 'Kannonkoski,Каннонкоски', 62.9666700, 25.2500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49033, 'Kankaanpää', 'Kankaanpaeae', 'Kankaanpaa,Kankaanpjaa,kan kang pei,knkan pa,Канкаанпяа,Канкаанпӓӓ,کنکان پا,坎康佩', 61.8000000, 22.4166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49034, 'Kangasniemi', 'Kangasniemi', 'Kangasniemi,Кангасниеми', 61.9935700, 26.6478500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49035, 'Kangaslampi', 'Kangaslampi', '', 62.2956300, 28.2528900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49036, 'Kangasala', 'Kangasala', 'Kangasala,Kangasala vald,kan jia sa la,knasala,Кангасала,كناسألا,坎加薩拉', 61.4638300, 24.0760200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49037, 'Kalvola', 'Kalvola', 'Kalvola', 61.1008100, 24.1217700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49038, 'Kälviä', 'Kaelviae', 'Kaelviae,Kelvia,Kelviå,Kyal''viya,Kälviä', 63.8606700, 23.4528900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49039, 'Kalajoki', 'Kalajoki', 'Kalagioki,Kalajoki,Kalajoki linn,ka la yue ji,kalaywky,karayoki,Καλαγιόκι,Калайоки,Калайокі,کالایوکی,カラヨキ,卡拉約基', 64.2500000, 23.9500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49040, 'Kajaani', 'Kajaani', 'Caianeburgum,KAJ,Kajaani,Kajaani linn,Kajana,Kajani,Kajanis,Kajauni,Kayani,Kjana,Knyaaani,Knyaani,ka ya ni,kajany,kayani,kayany,Каяани,Каяані,Каяни,Кајани,קאיאני,كايآني,کاجآنی,کایانی,カヤーニ,卡亚尼,카야니', 64.2272800, 27.7284600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49041, 'Kaavi', 'Kaavi', 'Kaavi,Kaavi vald,Kavi,kavu~i,Каави,Кави,カーヴィ', 62.9833300, 28.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49042, 'Kaarina', 'Kaarina', 'Kaarina,S:t Karins,Saint Karin,Sankt Karins,St Karins,Каарина', 60.4072400, 22.3690400, 'FI', '2015-05-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49043, 'Jyväskylä', 'Jyvaeskylae', 'Gorad Juvjaskjulja,Granivicus,Gyvaskyla,JYV,Jiveskile,Jjuvjaskjulja,Juevaeskuelae,Juvaskula,Juveskiule,Juveskiulė,Juvjaskjulja,Jyvaeskylae,Jyvaeskylae linn,Jyvaskyla,Jyväskylä,Jyväskylä linn,Jüväskülä,iwibeseukwille,jywaskyla,yu wei si qu lai,yuvu~asukyura,ywaskwla,ywfaskwla,yybsqylh,yywaskyla,Γυβάσκυλα,Јивескиле,Горад Ювяскюля,Йювяскюля,Йӱвӓскӱлӓ,Ювяскюля,ייבסקילה,جیواسکیلا,يوفاسكولا,یواسکولا,ییواسکیلا,ยูแวสกูแล,ユヴァスキュラ,于韦斯屈莱,이위베스퀼레', 62.2414700, 25.7208800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49044, 'Juva', 'Juva', 'Jockas,Juva,Yuva,you wa,yuvu~a,Юва,Յուվա,ユヴァ,尤瓦', 61.9000000, 27.8500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49045, 'Juupajoki', 'Juupajoki', '', 61.7990100, 24.3693900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49046, 'Juuka', 'Juuka', 'Juga,Juka,Juuka,Юка', 63.2333300, 29.2500000, 'FI', '2015-03-01', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49047, 'Jurva', 'Jurva', '', 62.6833300, 21.9833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49048, 'Juankoski', 'Juankoski', 'Juankoski,Juankoski linn,Stroemsdal,Strömsdal,you an ke si ji,ywankwsky,ywn kho ski,Юанкоски,Юанкоскі,یوانکوسکی,ยวนโคสกี,尤安科斯基', 63.0666700, 28.3500000, 'FI', '2017-01-04', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49049, 'Joutseno', 'Joutseno', 'Joutseno,Йоутсено', 61.1179600, 28.5076300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49050, 'Joutsa', 'Joutsa', 'Joutsa,Joutsa vald,jwtsa,yue cha,Йоутса,جوتسا,約察', 61.7333300, 26.1166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49051, 'Joroinen', 'Joroinen', 'Joroinen,Jorois,Jorojnen,Йоройнен', 62.1782300, 27.8316500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49052, 'Jokioinen', 'Jokioinen', 'Jockis,Jokioinen', 60.8016200, 23.4800400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49053, 'Joensuu', 'Joensuu', 'JOE,Joehnsu,Joehnsu osh,Joehnsuu,Joensu,Joensuu,Joensuu linn,Joensū,Jogensu,Jovensuu,Ostia Carelorum,Yoensu,jwynsw,yoensu,yue en su,ywynsw,Ёэнсу,Јоенсу,Йоенсуу,Йоэнсу ош,Йоэнсуу,יואנסואו,جوئنسو,يوينسو,یوئنسو,ヨエンスー,约恩苏,요엔수', 62.6011800, 29.7631600, 'FI', '2016-11-23', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49054, 'Järvenpää', 'Jaervenpaeae', 'Gorad Jarvenpjaa,Jaervenpaeae,Jarvenpaa,Jarvenpjaa,Jarvenpjaja,Jervenpe,Järvenpää,Traeskaenda,Träskända,jarwynpaa,yaleubenpa,yarfnba,yaruvu~enpa,ye er wen pei,Горад Ярвенпяа,Йӓрвенпӓӓ,Ярвенпяа,Ярвенпяя,جاروینپاا,يارفنبا,ヤルヴェンパー,耶爾文佩,야르벤파', 60.4736900, 25.0899200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49055, 'Järvelä', 'Jaervelae', 'Jaervelae,Jarvela,Jarvelja,Järvelä,Ярвеля', 60.8666700, 25.2833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49056, 'Jäppilä', 'Jaeppilae', 'Jaeppilae,Jappilja,Jäppilä,Яппиля', 62.3789900, 27.4337200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49057, 'Janakkala', 'Janakkala', 'Janakkala,Janakkala vald,jnakkala,ya wei ka la,Янаккала,جناککالا,亞維卡拉', 60.9000000, 24.6000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49058, 'Jämsänkoski', 'Jaemsaenkoski', 'Jaemsaenkoski,Jjamsjankoski,Jämsänkoski,Йямсянкоски', 61.9190000, 25.1701100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49059, 'Jämsä', 'Jaemsae', 'Gorad Jamsja,Jaemsae,Jamsa,Jamsja,Jemse,Jjamsja,Jämsä,KEV,Yamsya,jamsa,yamsa,yamusa,ye mu sai,Јемсе,Горад Ямся,Йямся,Йӓмсӓ,Ямся,جامسا,يامسا,ヤムサ,耶姆賽', 61.8642000, 25.1900200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49060, 'Jämijärvi', 'Jaemijaervi', '', 61.8166700, 22.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49061, 'Jalasjärvi', 'Jalasjaervi', 'Yalas''yarvi', 62.5000000, 22.7500000, 'FI', '2016-02-03', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49062, 'Jakobstad', 'Jakobstad', 'Jakobstad,Jakobstadas,Pietarsaari,Pietarsari,Pietasaari,Yakobstad,jkwbstad,ya ge bu si ta de,yakobseutadeu,yakobusutado,Јакобстад,Пиетарсаари,Якобстад,جکوبستاد,ヤコブスタード,雅各布斯塔德,야콥스타드', 63.6748600, 22.7025600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49063, 'Jaala', 'Jaala', 'Jaala,Яала', 61.0525100, 26.4811700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49064, 'Ivalo', 'Ivalo', 'Avveel,Avvil,IVL,Ivalo,Kyro,Kyrö,iballo,ivu~aro,Аввил,Ивало,イヴァロ,이발로', 68.6598600, 27.5389100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49065, 'Isokyrö', 'Isokyroe', 'Isokyroe,Isokyrö,Storkyro', 63.0117200, 22.3333200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49066, 'Isojoki', 'Isojoki', 'Isojoki,Stora,Storå', 62.1131900, 21.9588400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49067, 'Iniö', 'Inioe', '', 60.4000000, 21.4000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49068, 'Ingå', 'Inga', 'Inga,Inga vald,Ingo,Ingå,Ingå vald,Inkoo,yin jia,Инґо,因加', 60.0458700, 24.0045900, 'FI', '2016-06-05', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49069, 'Inari', 'Inari', 'Aanaar,Anar,Anár,Enare,Inari,Ânar,Инари', 68.9059600, 27.0288100, 'FI', '2016-12-13', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49070, 'Imatra', 'Imatra', 'Gorad Imatra,Imatra,Imatra linn,aymatra,imateula,imatora,imatra,yi ma te la,Іматра,Горад Іматра,Иматра,إيماترا,ایماترا,イマトラ,伊馬特拉,이마트라', 61.1718500, 28.7524200, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49071, 'Ilomantsi', 'Ilomantsi', 'Ilomants,Ilomantsi,Ilomantsi vald,yi luo man qi,Иломантси,伊洛曼齊', 62.6716200, 30.9327600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49072, 'Ilmajoki', 'Ilmajoki', 'Ilmajoki,Ilmola,SJY', 62.7333300, 22.5666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49073, 'Ikaalinen', 'Ikaalinen', 'Ikaalinen,Ikaalineni linn,Ikalis,aykalynn,yi ka li ning,Ікаалінен,Икаалинен,ایکالینن,伊卡利寧', 61.7695100, 23.0658000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49074, 'Iitti', 'Iitti', '', 60.8948800, 26.3386900, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49075, 'Iisalmi', 'Iisalmi', 'Idensalmi,Iisalmi,Iisalmi linn,Iisalmo,Ijsalmi,Isal''mi,Isalmi,ay salmy,ayslmy,isalmi,yi sa er mi,Ίισαλμι,Ійсалмі,Ийсалми,Исалми,إيسلمي,ای سالمی,伊薩爾米,이살미', 63.5591500, 27.1906700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49076, 'Ii', 'Ii', 'Ii,Ii vald,Iio,Ij,Ijo,i,yi zhen,Ίι,Ий,イー,伊鎮,이', 65.3173500, 25.3731000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49077, 'Hyvinge', 'Hyvinge', 'Hyvinge,Hyvinkaa,Hyvinkaeae,Hyvinkää,Khjuvinkjaja,Хювинкяя', 60.6333300, 24.8666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49078, 'Hyrynsalmi', 'Hyrynsalmi', 'Hyrynsaimi,Hyrynsalmi,Khjurjunsalmi,Khyuryunsalmi,Хюрюнсалми', 64.6666700, 28.5333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49079, 'Humppila', 'Humppila', 'Humppila', 60.9333300, 23.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49080, 'Huittinen', 'Huittinen', 'Gujttinen,Huittinen,Huittineni linn,Vittis,hu yi di ning,hwytynn,Гуйттинен,Гуйттінен,هویتینن,ہوئیتینن,胡伊蒂寧', 61.1833300, 22.7000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49081, 'Houtskär', 'Houtskaer', 'Houtskaer,Houtskari,Houtskär', 60.2228400, 21.3721800, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49082, 'Honkajoki', 'Honkajoki', 'Hongonjoki,Honkajoki', 61.9833300, 22.2666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49083, 'Hollola', 'Hollola', 'Hollola,Khollola,Холлола', 61.0500000, 25.4333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49084, 'Hollola', 'Hollola', 'Hollola', 61.0000000, 25.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49085, 'Hirvensalmi', 'Hirvensalmi', 'Hirvensalmi,Khirvensalmi,Хирвенсалми', 61.6333300, 26.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49086, 'Himanka', 'Himanka', 'Himango,Himanka', 64.0621800, 23.6544700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49087, 'Helsinki', 'Helsinki', 'Elsin''ki,Elsinki,Elzinki,Gel''sinki,Gorad Khel''sinki,HEL,Heilsinci,Heilsincí,Hel''sinki,Helsenkis,Helsingfors,Helsingi,Helsingia,Helsinki,Helsinkis,Helsinkium,Helsinko,Helsinky,Helsinqui,Helsinquia,Helsset,Helsínquia,Helsînkî,Helsėnkis,Hèlsinki,Khel''sinki,Khel''sinki osh,Khelsinki,Khelzinki,Lungsod ng Helsinki,Stadi,Xelsinki,Xélsinki,elcinki,hailasiki,he er xin ji,helasinki,helsingki,helsinki,herushinki,hlsnky,hlsnqy,hlsynky,hlsynqy,hylsynky,Èlzinki,Ħelsinki,Ελσίνκι,Гельсінкі,Горад Хельсінкі,Хелзинки,Хелсинки,Хельсинки,Хельсинки ош,Ҳелсинкӣ,Һel''sinki,Һельсинки,Հելսինկի,הלסינקי,העלסינקי,هلسنكي,هلسنڪي,هلسینکی,هيلسينكى,هیلسینکی,ھێلسینکی,ہلسنکی,ہیلسنکی,ܗܠܣܢܩܝ,हेलसिंकी,हेल्सिन्की,হেলসিঙ্কি,ਹੈਲਸਿੰਕੀ,எல்சிங்கி,ಹೆಲ್ಸಿಂಕಿ,ഹെൽസിങ്കി,เฮลซิงกิ,ཧེལ་སིན་ཀི།,ဟယ်လ်ဆင်ကီမြို့,ჰელსინკი,ሄልሲንኪ,Ḥélsinki,ヘルシンキ,赫尔辛基,赫爾辛基,헬싱키', 60.1695200, 24.9354500, 'FI', '2017-06-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49088, 'Heinola', 'Heinola', 'Heinola,Khejnola,Kheynola,QVV,Хейнола', 61.2056400, 26.0381100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49089, 'Heinävesi', 'Heinaevesi', 'Heinaevesi,Heinaevesi vald,Heinavesi,Heinnvesi,Heinävesi,Heinävesi vald,Khejnjavesi,hei nai wei xi,Хейнявеси,黑奈韋西', 62.4333300, 28.6000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49090, 'Hausjärvi', 'Hausjaervi', '', 60.7833300, 24.9333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49091, 'Haukivuori', 'Haukivuori', 'Haukivuori,Khaukivuori,Хаукивуори', 62.0175300, 27.2190600, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49092, 'Haukipudas', 'Haukipudas', 'Chaoukipountas,Haukipudas,Khaukipudas,hao ji pu da si,haywkypwdas,Χάουκιπουντας,Хаукипудас,هائوکیپوداس,ہاوکیپوداس,豪基普達斯', 65.1765400, 25.3523300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49093, 'Hauho', 'Hauho', 'Hauho,Khaukho,Хаухо', 61.1725500, 24.5630300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49094, 'Hartola', 'Hartola', 'Gustav Adolfs,Hartola,Khartola,Хартола', 61.5833300, 26.0166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49095, 'Harjavalta', 'Harjavalta', '', 61.3166700, 22.1333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49096, 'Hankasalmi', 'Hankasalmi', 'Hankasalmi,Hankasalmi vald,Khalkasalmi,Khankasalmi,han ka sa er mi,Халкасалми,Ханкасалми,漢卡薩爾米', 62.3833300, 26.4333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49097, 'Hanko', 'Hanko', 'Ganko,Hango,Hangoe,Hangonkyla,Hangonkylä,Hangö,Hanko,Khanko,han ke,hangko,hanko,Ганко,Ханко,האנקו,ہانکو,ハンコ,汉科,항코', 59.8333300, 22.9500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49098, 'Hamina', 'Hamina', 'Fredericia,Fredrikshamn,Gamina,Hamina,Khamina,ha mi na,hamina,hamyna,Гаміна,Хамина,هامينا,ہامینا,哈米納,하미나', 60.5697400, 27.1979400, 'FI', '2015-11-23', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49099, 'Hämeenlinna', 'Haemeenlinna', 'Gjameenlinna,Haemeenlinna,Haemenlidn,Hemenlina,Hämeenlinna,Hämenlidn,Khameehnlinna,Khamenlinna,Khemenlina,Khjameehnlinna,Khjamenlinna,Tavastehus,Tavastum,hai men lin na,hamenrin''na,hamynlyna,hemenlinna,hmnlynh,Гямеенлінна,Хеменлина,Хяменлинна,Хямеэнлинна,Хӓмеэнлинна,המנלינה,هامينلينا,ہمین لننا,ہیمینلنا,ハメーンリンナ,海门林纳,헤멘린나', 60.9959600, 24.4643400, 'FI', '2017-01-26', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49100, 'Hämeenkyrö', 'Haemeenkyroe', 'Haemeenkyroe,Haemeenkyroe vald,Hämeenkyrö,Hämeenkyrö vald,Khjameehnkjurjo,Tavastkyro,Tavastkyroe,Tavastkyrö,hai men qu lei,Хямеэнкюрё,海門屈勒', 61.6391300, 23.1953100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49101, 'Halsua', 'Halsua', 'Halsua,Khalsua,Халсуа', 63.4666700, 24.1666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49102, 'Halikko', 'Halikko', '', 60.4000000, 23.0833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49103, 'Hailuoto', 'Hailuoto', 'Ailuoto,Chailouoto,Hailuotas,Hailuoto,Karlo,Karloe,Karlö,Khajluoto,hai lu ao tuo dao,hairuoto dao,Χάιλουοτο,Хайлуото,ハイルオト島,海盧奧托島', 65.0090000, 24.7138500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49104, 'Haapavesi', 'Haapavesi', 'Chaapavesi,Gaapavesi,Haapavesi,Haapavesi linn,Khaapavesi,Khapavesi,ha pa wei xi,Χάαπαβεσι,Гаапавесі,Хаапавеси,Хапавеси,ہاپاویسی,哈帕韋西', 64.1333300, 25.3666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49105, 'Haapajärvi', 'Haapajaervi', 'Aspsjoe,Aspsjö,Haapajaervi,Haapajärvi,Haapavesi,Khapajarvi,Khapayarvi,Хапаярви', 63.7500000, 25.3333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49106, 'Forssa', 'Forssa', 'Forsa,Forss,Forssa,QVE,fu er sa,fwrsa,Форса,Форсса,فورسا,福爾薩', 60.8146200, 23.6214600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49107, 'Evijärvi', 'Evijaervi', '', 63.3666700, 23.4833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49108, 'Eurajoki', 'Eurajoki', 'Euraaminne,Eurajoki,Euraåminne', 61.2000000, 21.7333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49109, 'Eura', 'Eura', '', 61.1333300, 22.1333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49110, 'Espoo', 'Espoo', 'Ehspoo,Esbo,Espo,Espoo,ai si bo,esupo,Έσποο,Еспо,Еспоо,Эспоо,ესპოო,エスポー,埃斯波', 60.2052000, 24.6522000, 'FI', '2016-06-11', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49111, 'Enontekiö', 'Enontekioe', 'ENF,Eanodat,Ehnontekijo,Enodak,Enontekioe,Enontekioe vald,Enontekis,Enontekiö,Enontekiö vald,Heahtta,Hetta,Heähtta,ai nong tai ji e,Энонтекиё,埃農泰基厄', 68.3857300, 23.6321500, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49112, 'Enonkoski', 'Enonkoski', 'Ehnonkoski,Enonkoski,Энонкоски', 62.0833300, 28.9333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49113, 'Eno', 'Eno', 'Eno', 62.8051100, 30.1542200, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49114, 'Elimäki', 'Elimaeki', 'Ehlimjaki,Elima,Elimae,Elimaeki,Elimä,Elimäki,Элимяки', 60.7166700, 26.4666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49115, 'Ekenäs', 'Ekenaes', 'Ehkenes,Ekenaes,Ekenas,Ekenäs,Tammisaari,Tammisari,Э́кенес', 59.9735900, 23.4338900, 'FI', '2016-06-05', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49116, 'Dragsfjärd', 'Dragsfjaerd', 'Dragsf''jard,Dragsfjaerdi vald,Dragsfjärdi vald,Драгсфьярд', 60.0666700, 22.4833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49117, 'Porvoo', 'Porvoo', 'Borga,Borgo,Borgoa,Borgå,Gorad Porva,Porvas,Porvo,Porvoo,Porvō,QXJ,bo er wo,bwrfw,poleubo,poruvu~o,pwrww,Горад Порва,Порво,Порвоо,Պորվոո,بورفو,پوروو,ポルヴォー,波爾沃,포르보', 60.3923300, 25.6650700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49118, 'Bennäs', 'Bennaes', 'Baennaes,Bennaes,Bennäs,Pannainen,Pännäinen', 63.6000000, 22.8000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49119, 'Auttoinen', 'Auttoinen', 'Auttoinen,Auttojnen,Ауттойнен', 61.2990100, 25.0888700, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49120, 'Aura', 'Aura', 'Aura', 60.6471000, 22.5875500, 'FI', '2014-09-26', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49121, 'Askola', 'Askola', 'Askola,Askola vald,Gmina Askola,a si ke la,Аскола,阿斯科拉', 60.5333300, 25.6000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49122, 'Askainen', 'Askainen', 'Askas', 60.5666700, 21.8666700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49123, 'Asikkala', 'Asikkala', 'Asikkala,Асиккала', 61.2166700, 25.5000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49124, 'Artjärvi', 'Artjaervi', 'Artsjoe,Artsjö', 60.7454400, 26.0708400, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49125, 'Anjala', 'Anjala', 'Anjala,Anujala,Анъяла', 60.6833300, 26.8333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49126, 'Alavus', 'Alavus', 'Alavo,Alavus,Алавус', 62.5833300, 23.6166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49127, 'Alavieska', 'Alavieska', 'Alavieska,Алавиеска', 64.1666700, 24.3000000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49128, 'Alastaro', 'Alastaro', '', 60.9500000, 22.8500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49129, 'Alajärvi', 'Alajaervi', 'Alajaervi,Alajaervi linn,Alajarvi,Alajärvi,Alajärvi linn,Alayarvi,a la ye er wei,alajarwy,alayarwy,Алайӓрви,Алаярви,Алаярві,الاجاروی,الایاروی,阿拉耶爾維', 63.0000000, 23.8166700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49130, 'Alahärmä', 'Alahaermae', 'Alahaermae,Alahärmä', 63.2333300, 22.8500000, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49131, 'Ähtäri', 'AEhtaeri', 'AEhtaeri,AEhtaeri linn,Atsari,Egtjari,Ehkhtjari,Eteyari,Etseri,ai he tai li,Ähtäri,Ähtäri linn,Ätsari,Егтярі,Эхтяри,آہتاری,艾赫泰里', 62.5540300, 24.0618600, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49132, 'Äänekoski', 'AEaenekoski', 'AEaenekoski,AEaenekoski linn,Eenekoski,Ehehnekoski,Enekoski,ai nei ke si ji,anakoski,anykwsky,Äänekoski,Äänekoski linn,Еенекоскі,Енекоски,Ээнекоски,آنيكوسكي,آنیکوسکی,आनाकोस्की,艾內科斯基', 62.6000000, 25.7333300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49133, 'Äetsä', 'AEetsae', 'Aetsa,Äetsä', 61.2833300, 22.6833300, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49134, 'Kilo', 'Kilo', '', 60.2174600, 24.7815100, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49135, 'Teekkarikylä', 'Teekkarikylae', 'Helsinki University of Technology student village,Teknologbyn', 60.1895900, 24.8350200, 'FI', '2016-08-26', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49136, 'Koukkuniemi', 'Koukkuniemi', 'Koukkuniemi,Krokudden', 60.1526100, 24.7646700, 'FI', '2015-02-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49137, 'Ristinummi', 'Ristinummi', '', 63.0919200, 21.7229700, 'FI', '2014-09-25', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49138, 'Teeriniemi', 'Teeriniemi', 'Orrnaes,Orrnäs,Teeriniemi', 63.0970500, 21.6959000, 'FI', '2015-01-17', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49139, 'Toijala', 'Toijala', '', 61.1678000, 23.8381900, 'FI', '2015-02-14', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49140, 'Länsi-Turunmaa', 'Laensi-Turunmaa', 'Laensi-Turunmaa,Länsi-Turunmaa,Parainen,Pargas,Vaestaboland,Väståboland', 60.2997200, 22.3004000, 'FI', '2015-11-23', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49141, 'Älajärvi', 'AElajaervi', '', 63.0002700, 23.8158600, 'FI', '2017-06-22', 75);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49217, 'Peyrat-le-Château', 'Peyrat-le-Chateau', 'Pairac,Pairac dAimostier,Pejra-le-Shato,Peyrat,Peyrat-le-Chateau,Peyrat-le-Château,pei la lei sha tuo,Пейра-ле-Шато,佩拉勒沙托', 45.8157800, 1.7723300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49218, 'Blaye', 'Blaye', 'Blaia,Blaj,Blavia,Blaya,Blaye-et-Sainte-Luce,Ble,blay,bu lai,burai,Блай,Бле,בלאי,بلای,ブライ,布莱', 45.1333300, -0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49219, 'Zuydcoote', 'Zuydcoote', 'Zjujdkoot,Zuidcoote,Zuidkote,Zuudkote,Zuydcoote,ju yi de ke te,Зюйдкоот,聚伊德科特', 51.0609600, 2.4933800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49220, 'Zutkerque', 'Zutkerque', 'Zjutkerk,Zutkerque,ju kai er ke,zwtkyrkyw,Зюткерк,زوتكيركيو,聚凯尔克', 50.8530300, 2.0681800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49221, 'Zonza', 'Zonza', 'Conca,Dzondza,Zonza,Дзондза,Цонца', 41.7481300, 9.1710200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49222, 'Zimmersheim', 'Zimmersheim', 'Zimmersheim', 47.7202100, 7.3881900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49223, 'Zillisheim', 'Zillisheim', 'Zillisajm,Zillisheim,Зиллисайм,Зіллісайм', 47.6956200, 7.2951600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49224, 'Zegerscappel', 'Zegerscappel', '', 50.8833300, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49225, 'Yzeures-sur-Creuse', 'Yzeures-sur-Creuse', 'Izer sir Krez,Izer-sjur-Krez,Yzeures,Yzeures-sur-Creuse,ke lei si he pan yi ze lei,Ізер-сюр-Крез,Изер сир Крез,یزیرس-سر-کراسے,克勒斯河畔伊泽雷', 46.7860900, 0.8716600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49226, 'Yzeure', 'Yzeure', 'Isodrus,Izer,Izjor,Yzeure,yi ze er,Ізер,Изер,Изёр,یزیرے,伊泽尔', 46.5643800, 3.3549500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49227, 'Yzernay', 'Yzernay', 'Yzernay', 47.0222900, -0.7029500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49228, 'Yvré-le-Pôlin', 'Yvre-le-Polin', 'Ivre-le-Polen,Yvre,Yvre-le-Polin,Yvré,Yvré-le-Pôlin,Івре-ле-Полен,یوری-لے -پولین', 47.8223500, 0.1558100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49229, 'Yvrac', 'Yvrac', 'Yvrac', 44.8778600, -0.4587000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49230, 'Yvignac-la-Tour', 'Yvignac-la-Tour', 'Ivin''jak-la-Tur,Ivinieg,yi wei ni ya ke la tu,Івіньяк-ла-Тур,Ивиньяк-ла-Тур,伊维尼亚克拉图', 48.3500000, -2.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49231, 'Yvetot', 'Yvetot', 'Iveto,Yvetot,Yvetot-la-Montagne,ywtwt,Івето,Ивето,یوتوت', 49.6174400, 0.7581400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49232, 'Yves', 'Yves', 'Yves', 46.0192200, -1.0483300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49233, 'Ytrac', 'Ytrac', 'Ytrac', 44.9134300, 2.3629500, 'FR', '2017-07-06', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49234, 'Yssingeaux', 'Yssingeaux', 'Issenzho,Issingeaux,Sinjau,Yssingeaux,aysynzhw,issanjo,yi sang ruo,Іссенжо,Иссенжо,ایسینژو,صنگے ش,イッサンジョー,伊桑若', 45.1333300, 4.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49235, 'Yport', 'Yport', 'Ipor,Yport,Іпор,Ипор,یپورٹ', 49.7371600, 0.3153700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49236, 'Youx', 'Youx', 'Youx', 46.1444100, 2.8000400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49237, 'Ymare', 'Ymare', 'Ymare', 49.3506000, 1.1793800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49238, 'Ygos-Saint-Saturnin', 'Ygos-Saint-Saturnin', 'Ygos', 43.9765100, -0.7378000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49239, 'Yffiniac', 'Yffiniac', 'Iffin''jak,Ilfinieg,Yffiniac,yffnak,yi fei ni a ke,Іффіньяк,Иффиньяк,یففناک,伊菲尼阿克', 48.4842800, -2.6764700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49240, 'Yèvres', 'Yevres', 'Aebura,Evr,Evra,Yevres,Yèvres,yi ai fu lei,yywrs,Євр,ییورس,伊埃夫雷', 48.2107800, 1.1871700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49241, 'Yerville', 'Yerville', 'Yerville', 49.6672000, 0.8959400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49242, 'Yerres', 'Yerres', 'Jer,Yerres,Йер', 48.7178500, 2.4933800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49243, 'Yenne', 'Yenne', 'Enn,Epauna,Jenn,Єнн,Йенн,یننے', 45.7042000, 5.7579500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49244, 'Yébleron', 'Yebleron', 'Yebleron,Yébleron', 49.6333300, 0.5374600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49245, 'Ydes', 'Ydes', 'Eidas,Hisde,Id,Ydes,yds,yi dai,Ід,Ид,یدس,伊代', 45.3333300, 2.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49246, 'Ychoux', 'Ychoux', 'Ychoux', 44.3286900, -0.9517900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49247, 'Yainville', 'Yainville', 'Envil'',Yainville,yynwyl,Єнвіль,Енвиль,یینویل', 49.4537100, 0.8292000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49248, 'Xonrupt-Longemer', 'Xonrupt-Longemer', 'Ksonrju-Lonzhmer,Xonrupt,Xonrupt-Longemer,ke song lu pu long re mo,Ксонрю-Лонжмер,克松吕普隆热默', 48.0822300, 6.9294400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49249, 'Xertigny', 'Xertigny', 'Ksertin''i,Xertigny,ke sai er di ni,Ксертиньи,Ксертіньї,克塞尔蒂尼', 48.0439400, 6.4083600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49250, 'Woustviller', 'Woustviller', 'Woustviller', 49.0763600, 7.0048700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49251, 'Wormhout', 'Wormhout', 'Vormu,Wormhoudt,Wormhout,Wormout,wo er mu,Ворму,沃尔穆', 50.8812900, 2.4690100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49252, 'Wolfisheim', 'Wolfisheim', '', 48.5872300, 7.6670800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49253, 'Wolfgantzen', 'Wolfgantzen', '', 48.0280500, 7.5004000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49254, 'Woippy', 'Woippy', 'Vuappi,Woippy,wa pi,Вуаппи,Вуаппі,瓦皮', 49.1494600, 6.1490900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49255, 'Woincourt', 'Woincourt', 'Woincourt,Wornicourt', 50.0663000, 1.5367600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49256, 'Wizernes', 'Wizernes', 'Vizern,Wizernes,wei ze ne,wyzyrnys,Визерн,Візерн,ويزيرنيس,维泽讷', 50.7117000, 2.2431600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49257, 'Wittisheim', 'Wittisheim', 'Vittisajm,Wittisheim,Wittse,Wíttse,wei di sang,wytyshaym,wytysym,Виттисайм,Віттісайм,ويتيسيم,ویتیسهایم,维蒂桑', 48.2634100, 7.5870300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49258, 'Wittenheim', 'Wittenheim', 'Vittenajm,Wittenheim,Виттенайм,Віттенайм', 47.8078000, 7.3370200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49259, 'Wittelsheim', 'Wittelsheim', '', 47.8094700, 7.2415400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49260, 'Witry-lès-Reims', 'Witry-les-Reims', 'Witry,Witry-les-Reims,Witry-lez-Reims,Witry-lès-Reims', 49.2916200, 4.1192100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49261, 'Wissous', 'Wissous', 'Wissous', 48.7335200, 2.3233800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49262, 'Wissembourg', 'Wissembourg', 'Visambur,Vissembur,Waissebursch,Waißebursch,Weissenburg,Weißenburg,Wissemborg,Wissembourg,bai bao,vu~isanburu,wei sang bao,wysmbwr,wysymbwrgh,Висамбур,Виссембур,Віссембур,ויסמבור,ويسيمبورغ,ヴィサンブール,白堡,维桑堡', 49.0370800, 7.9454800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49263, 'Wissant', 'Wissant', 'Vissan,Wichin,Wissant,Witzand,wei sang,wysant,Виссан,Віссан,ويسانت,维桑', 50.8853000, 1.6626300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49264, 'Wisches', 'Wisches', 'Vish,wei si xie,wyshs,wystshys,Виш,Віш,ويستشيس,ویشس,维斯谢', 48.5088100, 7.2681400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49265, 'Wintzenheim', 'Wintzenheim', 'Vencenajm,Wintzenheim,Winzenheim,Венценайм', 48.0726900, 7.2907200, 'FR', '2017-07-06', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49266, 'Winnezeele', 'Winnezeele', 'Winnezeele', 50.8410000, 2.5511800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49267, 'Wingles', 'Wingles', 'Wingles', 50.4938200, 2.8550000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49268, 'Wingersheim', 'Wingersheim', 'Vengersajm,Wingersche,Wíngersche,wan re er sang,wynghyrshym,wyngrshaym,Венгерсайм,وينغيرشيم,وینگرسهایم,万热尔桑', 48.7214900, 7.6346400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49269, 'Wimmenau', 'Wimmenau', 'Vimmeno,Wimmenau,wei mo nuo,wymnaw,wymynaw,Виммено,Віммено,ويميناو,ویمناو,维默诺', 48.9115500, 7.4209300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49270, 'Wimille', 'Wimille', 'Vimij,Vimil'',Wimil,Wimille,wei mi ye,wymyly,Вимий,Вимиль,Вімій,ويميلي,维米耶', 50.7641800, 1.6313700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49271, 'Wimereux', 'Wimereux', 'Vimere,Vimrjo,Wimereux,Wimraw,wei mu lei,wymyrywks,Вимере,Вимрё,Вімере,ويميريوكس,维姆勒', 50.7696300, 1.6113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49272, 'Willerwald', 'Willerwald', 'Villerwaldt,Willerwald', 49.0248100, 7.0372600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49273, 'Willems', 'Willems', 'Willems', 50.6320600, 3.2384000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49274, 'Wihr-au-Val', 'Wihr-au-Val', 'Vir-o-Val'',Weier im Thal,Wihr,Wihr-au-Val,Вир-о-Валь,Вір-о-Валь', 48.0531200, 7.2048900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49275, 'Wignehies', 'Wignehies', 'Vin''ei,Wignehies,wei nie,Виньеи,Віньєї,维涅', 50.0155000, 4.0091300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49276, 'Wiesviller', 'Wiesviller', 'Wiesviller', 49.0791600, 7.1646600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49277, 'Widensolen', 'Widensolen', 'Widensohlen,Widensolen', 48.0628900, 7.4805700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49278, 'Weyersheim', 'Weyersheim', 'Weyersheim', 48.7153700, 7.8009700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49279, 'Wettolsheim', 'Wettolsheim', 'Vettol''sajm,Веттольсайм', 48.0575500, 7.2984400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49280, 'Westhoffen', 'Westhoffen', 'Vestoffen,Weschthoffe,wei si tuo fang,wsthwfn,wysthwfyn,Вестоффен,وستهوفن,ويسثوفين,韦斯托方', 48.6035200, 7.4428900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49281, 'Wervicq-Sud', 'Wervicq-Sud', 'Vervik-Sjud,Wervicq-Sud,Wervik-Zuud,Zuid-Wervik,nan wei er wei ke,Вервик-Сюд,Вервік-Сюд,南韦尔维克', 50.7745000, 3.0420700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49282, 'Weitbruch', 'Weitbruch', 'Vetbruk,Widbrueech,Widbrüech,wei te bu lu ke,wytbrwtsh,Ветбрук,ويتبروتش,韦特布吕克', 48.7545500, 7.7793500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49283, 'Waziers', 'Waziers', 'Vaz''e,Waziers,wa qi ye,Вазье,Вазьє,瓦齐耶', 50.3871700, 3.1149000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49284, 'Wavrin', 'Wavrin', 'Vavren,Wavrin,wa fu lan,Ваврен,瓦夫兰', 50.5738600, 2.9363000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49285, 'Wavrechain-sous-Denain', 'Wavrechain-sous-Denain', 'Wavrechain,Wavrechain-sous-Denain', 50.3322400, 3.4125200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49286, 'Wavignies', 'Wavignies', 'Vavini,Wavignie,Wavignies,wa wei nie,Вавіні,瓦维涅', 49.5474800, 2.3603200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49287, 'Wattwiller', 'Wattwiller', 'Vattviller,Wattweiler,Ваттвиллер,Ваттвіллер', 47.8364900, 7.1778500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49288, 'Wattrelos', 'Wattrelos', 'Vatrelo,Vatrlo,Vattrelo,Wattrelos,wa te lei luo,wateulello,wattoruro,wtrwlw,Ватрело,Ватрло,Ваттрело,وترولو,ワットルロー,瓦特勒洛,와트렐로', 50.7011800, 3.2181200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49289, 'Wattignies', 'Wattignies', 'Vattin''i,Vattini,Wattignies,wa di ni,Ваттини,Ваттиньи,Ваттіні,瓦蒂尼', 50.5863900, 3.0439400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49290, 'Watten', 'Watten', 'Watten', 50.8368500, 2.2134600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49291, 'Wassy', 'Wassy', 'Vassi,Vassy,Wassy,wa xi,Вассі,瓦西', 48.4981100, 4.9477500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49292, 'Wassigny', 'Wassigny', 'Wassigny', 50.0133400, 3.5998800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49293, 'Wasselonne', 'Wasselonne', 'Vasselonn,Wasselnheim,Wasselonne,Wassle,Wàssle,wa se long,wasylwn,Васселонн,واسيلون,瓦瑟隆', 48.6372300, 7.4473100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49294, 'Wasquehal', 'Wasquehal', 'Vaskeal,Vaskeal'',Wasquehal,wa si kai lei,Васкеал,Васкеаль,瓦斯凯勒', 50.6704300, 3.1338200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49295, 'Warmeriville', 'Warmeriville', 'Warmeriville', 49.3522700, 4.2188200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49296, 'Warluis', 'Warluis', 'Varljui,Warluis,wa er lu yi,Варлюї,瓦尔吕伊', 49.3887400, 2.1422000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49297, 'Warhem', 'Warhem', 'Warhem', 50.9759200, 2.4930300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49298, 'Wargnies-le-Grand', 'Wargnies-le-Grand', 'Varni-le-Gran,Wargnies-le-Grand,da wa er nie,Варни-ле-Гран,Варні-ле-Гран,大瓦尔涅', 50.3075100, 3.6603800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49299, 'Wardrecques', 'Wardrecques', 'Vardrek,Wardrecques,Werdrecque,Wérdrecque,wa er de lei ke,wardryskyws,Вардрек,واردريسكيوس,瓦尔德雷克', 50.7110800, 2.3448300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49300, 'Warcq', 'Warcq', 'Warcq', 49.7751700, 4.6817500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49301, 'Wangenbourg-Engenthal', 'Wangenbourg-Engenthal', '', 48.6280500, 7.3047100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49302, 'Wandignies-Hamage', 'Wandignies-Hamage', 'Vandini-Amazh,Wandignies-Hamage,wang di ni a ma re,Вандини-Амаж,Вандіні-Амаж,旺迪尼阿马热', 50.3960900, 3.3145000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49303, 'Wambrechies', 'Wambrechies', 'Vambreshi,Wambrechies,wa bu lei xi,Вамбреши,Вамбреші,瓦布勒希', 50.6827600, 3.0478400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49304, 'Walscheid', 'Walscheid', 'Val''shed,Walscheid,wa er si xie,Вальшед,瓦尔斯谢', 48.6524500, 7.1485600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49305, 'Wallers', 'Wallers', 'Wallers', 50.3743200, 3.3918800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49306, 'Waldighofen', 'Waldighofen', 'Val''digofen,Waldighofen,Waldighoffen,Вальдигофен,Вальдігофен', 47.5512600, 7.3174300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49307, 'Walbourg', 'Walbourg', 'Walburg', 48.8862800, 7.7882800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49308, 'Wailly', 'Wailly', '', 50.5228700, 2.0679200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49309, 'Wahagnies', 'Wahagnies', 'Wahagnies', 50.4866500, 3.0344800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49310, 'Vulaines-sur-Seine', 'Vulaines-sur-Seine', 'Vulaines,Vulaines-sur-Seine', 48.4318600, 2.7647600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49311, 'Vue', 'Vue', 'Gwagenez,Ile-Tortue,Vue', 47.1995300, -1.8775000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49312, 'Vrigne-aux-Bois', 'Vrigne-aux-Bois', 'Vrigne,Vrigne-aux-Bois', 49.7371600, 4.8556700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49313, 'Vred', 'Vred', 'Vre,Vred,fu lei de,Вре,弗雷德', 50.3945500, 3.2302900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49314, 'Voves', 'Voves', 'Vov,Voves,wo wei,Вов,沃韦', 48.2713800, 1.6258300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49315, 'Vouzon', 'Vouzon', 'Vouzon,Vuzon,wu zong,Вузон,武宗', 47.6451500, 2.0560900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49316, 'Vouziers', 'Vouziers', 'Vuz''e,vujie,wu ji ye,Вузье,Вузьє,ヴージエ,武济耶', 49.4000000, 4.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49317, 'Vouvray', 'Vouvray', 'Vouvray', 47.4108700, 0.7989200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49318, 'Voutezac', 'Voutezac', 'Vautezac,Voutezac', 45.2924600, 1.4371400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49319, 'Vourles', 'Vourles', 'Vourles,Vourles-le-Courageux,Vurl'',Вурль', 45.6567400, 4.7715700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49320, 'Vourey', 'Vourey', 'Vourey', 45.3195800, 5.5202800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49321, 'Vouneuil-sur-Vienne', 'Vouneuil-sur-Vienne', 'Vouneuil,Vouneuil-sur-Vienne,Vunej-sjur-Venn,wei ai na he pan wu na yi,Вуней-сюр-Вєнн,维埃纳河畔武纳伊', 46.7179300, 0.5393600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49322, 'Vouneuil-sous-Biard', 'Vouneuil-sous-Biard', 'Vouneuil,Vouneuil-sous-Biard,Vunej-su-Biar,wu na yi su bi a er,Вуней-су-Біар,武纳伊苏比阿尔', 46.5738700, 0.2698800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49323, 'Voulx', 'Voulx', 'Voulx', 48.2820400, 2.9674700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49324, 'Voulangis', 'Voulangis', '', 48.8525200, 2.8955800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49325, 'Voujeaucourt', 'Voujeaucourt', 'Voujaucourt,Voujeaucourt', 47.4751300, 6.7743100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49326, 'Vouillé', 'Vouille', 'Vouille,Vouillé', 46.6401100, 0.1677800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49327, 'Vouillé', 'Vouille', 'Vouille,Vouillé', 46.3155000, -0.3684500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49328, 'Vougy', 'Vougy', 'Vougy', 46.1018000, 4.1197300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49329, 'Vougy', 'Vougy', 'Vougy', 46.0667600, 6.4941900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49330, 'Vorey', 'Vorey', 'Vorey,Vorey sur Arzon', 45.1835700, 3.9099200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49331, 'Voreppe', 'Voreppe', 'Vorep,Vorepp,Voreppe,wo lei pu,Вореп,Ворепп,沃雷普', 45.2947600, 5.6332400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49332, 'Vonnas', 'Vonnas', 'Vonas,Vonna,Vonnas,Vonâs,fwnna,wo na si,Вонна,Վոննա,فوننا,沃纳斯', 46.2186700, 4.9916100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49333, 'Volx', 'Volx', 'Vol''ks,Volx,Vous,Vòus,wo er,Волькс,沃尔', 43.8738300, 5.8413000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49334, 'Volvic', 'Volvic', 'Vol''vik,Volvic,bolbig,vu~oruvu~ikku,wo er wei ke,Вольвік,ヴォルヴィック,沃尔维克,볼빅', 45.8719600, 3.0383200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49335, 'Volstroff', 'Volstroff', 'Volstroff', 49.3115600, 6.2600800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49336, 'Volonne', 'Volonne', 'Volon,Volona,Volonn,wo long,Волон,Волонн,沃隆', 44.1103900, 6.0142400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49337, 'Volmerange-les-Mines', 'Volmerange-les-Mines', 'Volmerange,Volmerange-les-Mines', 49.4434200, 6.0819000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49338, 'Voisins-le-Bretonneux', 'Voisins-le-Bretonneux', 'Voisins,Voisins-le-Bretonneux,Vuazen-le-Bretonne,Вуазен-ле-Бретонне', 48.7579300, 2.0513700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49339, 'Voisenon', 'Voisenon', 'Voisenon', 48.5717000, 2.6648000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49340, 'Voiron', 'Voiron', 'Voiron,Vuaron,bualong,fwarwn,vu~owaron,wa long,wwarwn,Вуарон,فوارون,ووآرون,ヴォワロン,瓦龙,부아롱', 45.3639500, 5.5920900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49341, 'Voglans', 'Voglans', 'Voglans', 45.6339000, 5.9022700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49342, 'Vœuil-et-Giget', 'Voeuil-et-Giget', 'Vej-e-Zhizhe,Vjoj-eh-Zhizhe,Voeuil,wo e yi he ji re,Вей-е-Жиже,Вёй-э-Жиже,沃厄伊和吉热', 45.5833300, 0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49343, 'Vizille', 'Vizille', 'Vizij,wei qi er,Визий,Візій,维齐尔', 45.0781900, 5.7707400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49344, 'Vix', 'Vix', 'Vix', 46.3645600, -0.8607200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49345, 'Vivy', 'Vivy', 'Vivy', 47.3264800, -0.0553100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49346, 'Vivonne', 'Vivonne', 'Vivona,Vivonn,Vivonne,wei wo na,Вівонн,维沃纳', 46.4295300, 0.2644300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49347, 'Viviez', 'Viviez', 'Viviez', 44.5567800, 2.2164900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49348, 'Viviers-lès-Montagnes', 'Viviers-les-Montagnes', 'Viviers,Viviers-la-Montagne,Viviers-les-Montagnes,Viviers-lès-Montagnes', 43.5547400, 2.1767200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49349, 'Viviers', 'Viviers', 'Viviers,Viviers-sur-Rhone', 44.4851500, 4.6872100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49350, 'Vivier-au-Court', 'Vivier-au-Court', 'Vivier,Vivier-au-Court', 49.7332600, 4.8293900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49351, 'Viuz-la-Chiésaz', 'Viuz-la-Chiesaz', 'Vicus ad Ecclesiam,Viuz-la-Chiesaz,Viuz-la-Chiésaz,Vju-la-Shez,Вю-ла-Шєз', 45.8108400, 6.0620700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49352, 'Viuz-en-Sallaz', 'Viuz-en-Sallaz', 'Vicus Sallatius,Viux-en-Sallaz,Viuz,Viuz-en-Sallaz,Vju-an-Salla,Вю-ан-Салла', 46.1455600, 6.4098600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49353, 'Vittel', 'Vittel', 'Mouzon-Meuse,VTL,Vittel,Vittel'',vu~itteru,wei te,Виттель,Віттель,ヴィッテル,维特', 48.2008500, 5.9484300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49354, 'Vitteaux', 'Vitteaux', 'Vitteaux,Vitto,wei tuo,Витто,Вітто,维托', 47.3973200, 4.5419000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49355, 'Vitry-sur-Seine', 'Vitry-sur-Seine', 'Port-de-Marat,Vitri sir Sen,Vitri sjur Sen,Vitri-sjur-Sen,Vitry,Vitry-sur-Seine,biteuliswileusen,fytry swr syn,sai na he pan wei ti,vu~itori=shuru=senu,wytry swr sn,wytry-swr-sn,Витри сир Сен,Витри сюр Сен,Витри-сюр-Сен,Вітрі-сюр-Сен,فيتري سور سين,ویتری سور سن,ویتری-سور-سن,ヴィトリー＝シュル＝セーヌ,塞纳河畔维提,비트리쉬르센', 48.7871600, 2.4033200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49356, 'Vitry-sur-Orne', 'Vitry-sur-Orne', 'Vitri-sjur-Orn,Vitry,Vitry-sur-Orne,ao er en he pan wei te li,wytry-swr-arn,Витри-сюр-Орн,Вітрі-сюр-Орн,ویتری-سور-ارن,奥尔恩河畔维特里', 49.2655400, 6.1111300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49357, 'Vitry-le-François', 'Vitry-le-Francois', 'Vitri-le-Fransua,Vitry-le-Francois,Vitry-le-François,Vitry-sur-Marne,wei te li lei fu lang suo wa,Витри-ле-Франсуа,Вітрі-ле-Франсуа,维特里勒弗朗索瓦', 48.7333300, 4.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49358, 'Vitry-en-Artois', 'Vitry-en-Artois', 'Vitri-an-Artua,Vitry,Vitry-en-Artois,Vitry-in-Artoe,Vitry-in-Artoé,fytry an artwyz,wei te li ang na tu wa,wytry-an-artwa,Витри-ан-Артуа,Вітрі-ан-Артуа,فيتري إن أرتويز,ویتری-آن-آرتوا,维特里昂纳图瓦', 50.3266000, 2.9799900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49359, 'Vitry-aux-Loges', 'Vitry-aux-Loges', 'Vitri-o-Lozh,Vitry,Vitry-aux-Loges,wei te li ao luo re,Вітрі-о-Лож,维特里奥洛热', 47.9333300, 2.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49360, 'Vitrolles', 'Vitrolles', 'Vitrol'',Vitrolles,Витроль', 43.4600000, 5.2486100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49361, 'Vitré', 'Vitre', 'Bitre,Gwitreg,Vitre,Vitreh,Vitré,fytry,vu~itore,wei te lei,Βιτρέ,Витрэ,فيتري,ヴィトレ,维特雷', 48.1177600, -1.2057700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49362, 'Visan', 'Visan', 'Visan,Vizan,wei sang,Визан,Візан,维桑', 44.3141000, 4.9520200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49363, 'Viry-Noureuil', 'Viry-Noureuil', 'Viry,Viry-Noureuil', 49.6321400, 3.2432200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49364, 'Viry-Châtillon', 'Viry-Chatillon', 'Viri Shatijon,Viri-Shatijon,Viri-Shatillon,Viry,Viry-Chatillon,Viry-Châtillon,bilisyatiyong,vu~iri=shatiyon,wei li sha di long,wyry shtywn,Вири Шатијон,Вири-Шатийон,Вири-Шатиллон,Вірі-Шатійон,ویری شتیون,ヴィリー＝シャティヨン,维里沙蒂隆,비리샤티용', 48.6721100, 2.3931800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49365, 'Viry', 'Viry', 'Viry', 46.1171700, 6.0371700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49366, 'Viroflay', 'Viroflay', 'Viroflay,Virofle,vu~irofure,Вирофле,Вірофле,ヴィロフレー', 48.8007800, 2.1618100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49367, 'Viriville', 'Viriville', 'Viriville', 45.3173700, 5.2037300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49368, 'Virieu-le-Grand', 'Virieu-le-Grand', 'Virieu,Virieu-le-Grand', 45.8485100, 5.6497900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49369, 'Virieu', 'Virieu', 'Virieu', 45.4839900, 5.4750100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49370, 'Viriat', 'Viriat', 'Veriat,Vir''ja,Viriat,Virja,Virya,fyrya,wei li ya,Вирья,Віря,Վիրյա,فيريا,维里亚', 46.2548400, 5.2156700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49371, 'Virey-le-Grand', 'Virey-le-Grand', 'Virey', 46.8333300, 4.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49372, 'Vireux-Wallerand', 'Vireux-Wallerand', 'Vireux,Vireux-Wallerand', 50.0819600, 4.7301700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49373, 'Vireux-Molhain', 'Vireux-Molhain', 'Vire-Molen,Vireu-Molen,Vireu-Molén,Vireux,Vireux-Molhain,Virjo-Molen,Вирё-Молен,Віре-Молен', 50.0787400, 4.7242600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49374, 'Vire', 'Vire', 'Vir,vu~iru,wei er,Βιρ,Вир,Вір,ヴィール,维尔', 48.8333300, -0.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49375, 'Virazeil', 'Virazeil', 'Virazeil', 44.5070500, 0.2217700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49376, 'Vion', 'Vion', 'Vion', 47.8192300, -0.2391600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49377, 'Violès', 'Violes', 'V''oles,Viaules,Viaulés,Violes,Violès,Vjole,wei ao lai,Вйоле,Вьолес,维奥莱', 44.1614600, 4.9532900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49378, 'Violay', 'Violay', 'Violay,Vjole,wei ao lai,Вйоле,维奥莱', 45.8528300, 4.3572400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49379, 'Violaines', 'Violaines', 'Violaines,Vjolen,fywlaynys,wei yue lai ne,Вйолен,فيولاينيس,维约莱讷', 50.5416000, 2.7886000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49380, 'Vinsobres', 'Vinsobres', 'Vensobr,Vinsobres,Vinsobri,Vinsòbri,vu~ansoburu,wan suo bu lei,Венсобр,ヴァンソブル,万索布雷', 44.3331500, 5.0620800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49381, 'Vinon-sur-Verdon', 'Vinon-sur-Verdon', 'Vinon,Vinon de Verdon,Vinon-sjur-Verdon,Vinon-sur-Verdon,fu er dong he pan wei nong,Винон-сюр-Вердон,Вінон-сюр-Вердон,弗尔东河畔维农', 43.7245100, 5.8108100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49382, 'Vinneuf', 'Vinneuf', 'Vinneuf', 48.3479500, 3.1401300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49383, 'Vineuil-Saint-Firmin', 'Vineuil-Saint-Firmin', 'Les Sans-Culottes-sur-Nonette,Vinej-Sen-Firmen,Vineuil,Vineuil-Saint-Firmin,wei na yi sheng fei er man,Віней-Сен-Фірмен,维纳伊圣菲尔曼', 49.2002400, 2.4956700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49384, 'Vineuil', 'Vineuil', 'Vineuil', 47.5838000, 1.3760100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49385, 'Vineuil', 'Vineuil', 'Vineuil', 46.9003800, 1.6354300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49386, 'Vincey', 'Vincey', 'Vense,Vincey,wan sai,Венсе,万塞', 48.3374900, 6.3313400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49387, 'Vincennes', 'Vincennes', 'Vensen,Vensenas,Vensenn,Vilcenia,Vincennes,baengsen,fansan,vu~ansen''nu,wan sai ne,wnsn,wsn,Венсен,Венсенн,فانسان,وسن,ونسن,ヴァンセンヌ,万塞讷,뱅센', 48.8486000, 2.4376900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49388, 'Vinça', 'Vinca', 'Vinca,Vinça,Vinçà', 42.6448600, 2.5283000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49389, 'Vinay', 'Vinay', 'Vinay', 45.2107500, 5.4080600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49390, 'Vinassan', 'Vinassan', 'Vinassan,wei na sang,Винассан,Вінассан,维纳桑', 43.2044300, 3.0746300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49391, 'Vimy', 'Vimy', 'Vermy,Vimi,Vimy,fymy,wei mi,Вими,Вімі,فيمي,维米', 50.3724300, 2.8103400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49392, 'Vimoutiers', 'Vimoutiers', 'Vimoutiers,Vimut''e,wei mu di ye er,Вимутье,Вімутьє,维穆蒂耶尔', 48.9277200, 0.1983500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49393, 'Vimory', 'Vimory', 'Vimori,Vimory,wei mo li,Віморі,维莫里', 47.9478600, 2.6870100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49394, 'Vimines', 'Vimines', 'Vimin,Vimines,Вімін', 45.5474100, 5.8649300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49395, 'Villiers-sur-Orge', 'Villiers-sur-Orge', 'Vil''e-sjur-Orzh,Villiers,Villiers-sur-Orge,ao er ri he pan wei li ye er,Вилье-сюр-Орж,Вільє-сюр-Орж,奥尔日河畔维利耶尔', 48.6595300, 2.3000200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49396, 'Villiers-sur-Morin', 'Villiers-sur-Morin', 'Vil''e-sjur-Moren,Villiers,Вилье-сюр-Морен,Вільє-сюр-Морен', 48.8609900, 2.8777300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49397, 'Villiers-sur-Marne', 'Villiers-sur-Marne', 'Vil''e-sjur-Marn,Vilije sir Marn,Villiers,Villiers-sur-Marne,billieswileumaleun,ma en he pan wei li ye er,vu~irie=shuru=marunu,wyh swr mrn,wylyh-swr-mrn,Вилије сир Марн,Вилье-сюр-Марн,Вільє-сюр-Марн,ویلیه-سور-مرن,ویه سور مرن,ヴィリエ＝シュル＝マルヌ,马恩河畔维利耶尔,빌리에쉬르마른', 48.8310000, 2.5484400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49398, 'Villiers-sur-Loir', 'Villiers-sur-Loir', 'Vil''e-sjur-Luar,Villiers,Villiers-sur-Loir,lu wa he pan wei li ye er,Вільє-сюр-Луар,卢瓦河畔维利耶尔', 47.8050700, 0.9977400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49399, 'Villiers-Saint-Georges', 'Villiers-Saint-Georges', 'Villiers-Saint-Georges', 48.6499800, 3.4075400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49400, 'Villiers-Saint-Fréderic', 'Villiers-Saint-Frederic', 'Villiers,Villiers-le-Voltaire', 48.8166700, 1.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49401, 'Villiers-le-Morhier', 'Villiers-le-Morhier', 'Villiers,Villiers-le-Morhier,Villiers-le-Mornier', 48.6201800, 1.5634900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49402, 'Villiers-le-Bel', 'Villiers-le-Bel', 'Vil''e-le-Bel'',Vilije le Bel,Villiers,Villiers-le-Bel,billieleubel,vu~irie=ru=beru,wei li ye er lei bo,wyr lw bl,Вилије ле Бел,Вилье-ле-Бель,Вільє-ле-Бель,ویر لو بل,ヴィリエ＝ル＝ベル,维利耶尔勒伯,빌리에르벨', 49.0087500, 2.3981900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49403, 'Villiers-le-Bâcle', 'Villiers-le-Bacle', 'Vil''e-le-Bakl'',Villiers,Villiers-le-Bacle,Villiers-le-Bâcle,wei li ye er lei ba ke er,Вилье-ле-Бакль,Вільє-ле-Бакль,维利耶尔勒巴克尔', 48.7281900, 2.1192500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49404, 'Villiers-en-Plaine', 'Villiers-en-Plaine', 'Villiers,Villiers-en-Plaine', 46.4089500, -0.5375600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49405, 'Villiers-en-Lieu', 'Villiers-en-Lieu', 'Villiers,Villiers-en-Lieu', 48.6678500, 4.8975500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49406, 'Villié-Morgon', 'Villie-Morgon', 'Villie,Villie-Morgon,Villié,Villié-Morgon', 46.1622900, 4.6805600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49407, 'Villey-Saint-Étienne', 'Villey-Saint-Etienne', 'Villey,Villey-Saint-Etienne,Villey-Saint-Étienne,Villey-sur-Moselle', 48.7313600, 5.9784100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49408, 'Villevocance', 'Villevocance', 'La Vila de Vaucanca,La Vila de Vaucança,Vil''vokans,Villevocance,wei lei wo kang ke,Вильвоканс,Вільвоканс,维勒沃康克', 45.2265900, 4.5910300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49409, 'Villevieille', 'Villevieille', 'Ville Vielle,Villevieille', 43.7879500, 4.0975600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49410, 'Villeveyrac', 'Villeveyrac', 'Vil''verak,Vilamanda,Villeveyrac,wei lei wei la ke,Вильверак,Вільверак,维勒韦拉克', 43.5009500, 3.6072300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49411, 'Villevêque', 'Villeveque', 'Port-du-Loir,Vil''vek,wei lai wei qu ai,Вільвек,维莱韦屈埃', 47.5609500, -0.4238300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49412, 'Villevaudé', 'Villevaude', 'Villevaude,Villevaudé', 48.9175100, 2.6522800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49413, 'Villeurbanne', 'Villeurbanne', 'Gorad Vijorban,Vijjorban,Vilerban,Vilerbana,Vilerbanas,Vilerbāna,Viljurban,Villerbann,Villeurbanne,billoeleuban,fylwrban,vilerbani,vu~iruruban''nu,wei lei ban,wei lei he peng na,wywrbn,Вийёрбан,Вилербан,Вилюрбан,Віллербанн,Горад Віёрбан,וילרבאן,فيلوربان,ولےاربین,ویوربن,ვილერბანი,ヴィルールバンヌ,维勒班,维嘞合朋纳,빌뢰르반', 45.7666700, 4.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49414, 'Villette-de-Vienne', 'Villette-de-Vienne', 'Villette,Villette-de-Vienne', 45.5890800, 4.9139800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49415, 'Villetelle', 'Villetelle', 'Villetelle', 43.7310500, 4.1365800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49416, 'Villetaneuse', 'Villetaneuse', 'Vil''tanez,wei er ta na si,Вильтанез,Вільтанез,维尔塔纳斯', 48.9583300, 2.3416700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49417, 'Villes-sur-Auzon', 'Villes-sur-Auzon', 'Vielas dAuson,Vil''-sjur-Ozon,Villes,Villes-sur-Auzon,ao zong he pan wei lei,Виль-сюр-Озон,Віль-сюр-Озон,奥宗河畔维勒', 44.0566900, 5.2343000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49418, 'Ville-sous-la-Ferté', 'Ville-sous-la-Ferte', 'Ville,Ville-sous-la-Ferte,Ville-sous-la-Ferté', 48.1206000, 4.7895700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49419, 'Ville-sous-Anjou', 'Ville-sous-Anjou', 'Ville,Ville-sous-Anjou', 45.3719400, 4.8510600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49420, 'Villerupt', 'Villerupt', 'Vil''rju,Villerupt,wei lei lu pu,Вильрю,Вільрю,维勒吕普', 49.4673700, 5.9328500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49421, 'Villers-sur-Mer', 'Villers-sur-Mer', 'Ville-sjur-Mer,Viller-sjur-Mer,Villers,Villers-sur-Mer,bin hai wei lai er,Вилле-сюр-Мер,Виллер-сюр-Мер,Вілле-сюр-Мер,滨海维莱尔', 49.3226400, 0.0002700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49422, 'Villers-sur-Coudun', 'Villers-sur-Coudun', 'Villers,Villers-sur-Coudun', 49.4830800, 2.8045700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49423, 'Villers-sous-Saint-Leu', 'Villers-sous-Saint-Leu', 'Viller-su-Sen-Le,Villers,Villers-sous-Saint-Leu,Villers-sur-Oise,wei lai er su sheng lei,Віллер-су-Сен-Ле,维莱尔苏圣勒', 49.2123500, 2.3948500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49424, 'Villers-Semeuse', 'Villers-Semeuse', 'Viller-Semez,Viller-Semjoz,Villers,Villers-Semeuse,Villers-devant Mezieres,Villers-devant Mézières,Виллер-Семёз,Віллер-Семез', 49.7420100, 4.7469700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49425, 'Villers-Saint-Paul', 'Villers-Saint-Paul', 'Viller-Sen-Pol'',Villers,Villers-Saint-Paul,wei lai er sheng bo,Виллер-Сен-Поль,Віллер-Сен-Поль,维莱尔圣波', 49.2888500, 2.4896800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49426, 'Villers-Pol', 'Villers-Pol', 'Ville-Pol'',Villers-Pol,wei lai bo lei,Вилле-Поль,Вілле-Поль,维莱波勒', 50.2846000, 3.6144900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49427, 'Villers-Outréaux', 'Villers-Outreaux', 'Ville-Utreo,Villers-Outreaux,Villers-Outréaux,wei lai wu te lei ou,Вилле-Утрео,Вілле-Утрео,维莱乌特雷欧', 50.0359000, 3.2994700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49428, 'Villers-lès-Nancy', 'Villers-les-Nancy', 'Ville-le-Nansi,Viller-le-Nansi,Villers,Villers-les-Nancy,Villers-lès-Nancy,wei lai er lai nan xi,Вилле-ле-Нанси,Виллер-ле-Нанси,Вілле-ле-Нансі,维莱尔莱南西', 48.6710300, 6.1508300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49429, 'Villers-le-Lac', 'Villers-le-Lac', 'Lac-ou-Villers,Le Lac ou Villers,Ville-le-Lak,Villers,Villers-le-Lac,wei lai er lai la ke,Вілле-ле-Лак,维莱尔莱拉克', 47.0631900, 6.6669900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49430, 'Villers-la-Montagne', 'Villers-la-Montagne', 'Villers,Villers-la-Montagne', 49.4710800, 5.8241200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49431, 'Villersexel', 'Villersexel', 'Villerseksel'',Villersexel,Villeseksel'',Виллерсексель,Віллесексель', 47.5507000, 6.4327300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49432, 'Villers-en-Cauchies', 'Villers-en-Cauchies', 'Villers,Villers-en-Cauchies', 50.2257400, 3.4036200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49433, 'Villers-Écalles', 'Villers-Ecalles', 'Villers,Villers-Ecalles,Villers-sous-Barentin,Villers-Écalles', 49.5413600, 0.9194200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49434, 'Villers-Cotterêts', 'Villers-Cotterets', 'Vijer Kotre,Villare ad Collum Retiae,Viller-Kotre,Villers-Cotterets,Villers-Cotterêts,wei lai ke te lei,Вийер Котре,Виллер-Котре,Віллер-Котре,维莱科特雷', 49.2531100, 3.0900300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49435, 'Villers-Bretonneux', 'Villers-Bretonneux', 'Viler-Bretonneux,Viller-Bretonne,Viller-Bretonnjo,Villers-Bretonneux,Vilèr-Bretonneux,wei lai bu lei tuo ne,Виллер-Бретоннё,Віллер-Бретонне,维莱布勒托讷', 49.8684400, 2.5168800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49436, 'Villers-Bocage', 'Villers-Bocage', 'Villers,Villers-Bocage', 49.9981000, 2.3168300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49437, 'Villers-Bocage', 'Villers-Bocage', 'Villers,Villers-Bocage', 49.0796000, -0.6541200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49438, 'Villereversure', 'Villereversure', 'Villereversure', 46.1850900, 5.3826900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49439, 'Villerest', 'Villerest', 'Vil''re,Villeret,Villerêt,wei lei lei si,Вільре,维勒雷斯', 46.0000000, 4.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49440, 'Villeréal', 'Villereal', 'Vil''real'',Vila-real,Vilareal,Villereal,Villeréal,wei lai lei a,Вильреаль,Вільреаль,维莱雷阿', 44.6363100, 0.7432600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49441, 'Villepreux', 'Villepreux', 'Vil''pre,Villepreux,Вильпре,Вільпре', 48.8281500, 1.9976000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49442, 'Villepinte', 'Villepinte', 'Villepinte', 48.9620300, 2.5325300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49443, 'Villepinte', 'Villepinte', 'Villepinte', 43.2821300, 2.0876000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49444, 'Villeparisis', 'Villeparisis', 'Vil''parizi,Villeparisis,Вильпаризи', 48.9420800, 2.6146300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49445, 'Villenoy', 'Villenoy', 'Vil''nua,Villenoy,Вильнуа,Вільнуа', 48.9411200, 2.8602000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49446, 'Villenouvelle', 'Villenouvelle', 'Villenouvelle', 43.4358100, 1.6627900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49447, 'Villennes-sur-Seine', 'Villennes-sur-Seine', 'Villenn-sjur-Sen,Villennes,Villennes-sur-Seine,Вилленн-сюр-Сен,Вілленн-сюр-Сен', 48.9413700, 1.9913700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49448, 'Villeneuve-Tolosane', 'Villeneuve-Tolosane', 'Vil''nev-Tolozan,Vil''njov-Tolozan,Vilanava Tolosana,Vilanava de Tolosa,Vilanova Tolosana,Vilanòva Tolosana,Villeneuve,Villeneuve-les Cugnax,tuo luo sang xin cheng,Вильнёв-Толозан,Вільнев-Толозан,托洛桑新城', 43.5231600, 1.3410200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49449, 'Villeneuve-sur-Yonne', 'Villeneuve-sur-Yonne', 'Vil''nev-sjur-Ionn,Villeneuve,Villeneuve-sur-Yonne,yue ne he pan wei er na wo,Вильнев-сюр-Ионн,Вільнев-сюр-Іонн,约讷河畔维尔纳沃', 48.0824700, 3.2968800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49450, 'Villeneuve-sur-Lot', 'Villeneuve-sur-Lot', 'Vil''nev-sjur-Lo,Vil''nev-sjur-Lot,Vil''njov-sjur-Lo,Vilanueva dAgen,Vilanueva dOlt,Vilanuèva dAgen,Vilanuèva dÒlt,Villanova ad Oltem,Villeneuve,Villeneuve-sur-Lot,Vilnev sir Lot,bilnoebeuswileuloteu,luo te he pan xin cheng,vu~irunuvu=shuru=rotto,wilneifw-sur-lxt,wy nw swrlw,Вилнев сир Лот,Вильнев-сюр-Ло,Вильнев-сюр-Лот,Вильнёв-сюр-Ло,Вільнев-сюр-Лот,وی نو سورلو,วีลเนิฟว์-ซูร์-ล็อต,ヴィルヌーヴ＝シュル＝ロット,洛特河畔新城,빌뇌브쉬르로트', 44.4085400, 0.7041500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49451, 'Villeneuve-sur-Bellot', 'Villeneuve-sur-Bellot', 'Bellot-la-Montagne,Villeneuve,Villeneuve-sur-Bellot', 48.8620300, 3.3414300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49452, 'Villeneuve-Saint-Germain', 'Villeneuve-Saint-Germain', 'Villeneuve-Saint-Germain', 49.3797600, 3.3595200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49453, 'Villeneuve-Saint-Georges', 'Villeneuve-Saint-Georges', 'Vil''nev-Sen-Zhorzh,Vil''njov-Sen-Zhorzh,Villeneuve,Villeneuve-Saint-Georges,Villeneuve-la-Montagne,Vilnev Sen Zhorzh,bilnoebeusaengjoleuju,vu~irunuvu=san=joruju,wylnww-sn-zhrzh,wynw sn zhwrzh,xin cheng sheng qiao zhi,Вилнев Сен Жорж,Вильнев-Сен-Жорж,Вильнёв-Сен-Жорж,Вільнев-Сен-Жорж,ویلنوو-سن-ژرژ,وینو سن ژورژ,ヴィルヌーヴ＝サン＝ジョルジュ,新城圣乔治,빌뇌브생조르주', 48.7321900, 2.4492500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49454, 'Villeneuve-Loubet', 'Villeneuve-Loubet', 'Vil''nev-Lube,Vil''njov-Lube,Vilanova de Mar,Vilanòva de Mar,Villeneuve,Villeneuve-Loubet,fylynywf lwbyt,lu bei xin cheng,vu~irunuvu=rube,Вильнёв-Лубе,Вільнев-Лубе,فيلينيوف لوبيت,ヴィルヌーヴ＝ルベ,卢贝新城', 43.6666300, 7.1204000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49455, 'Villeneuve-les-Sablons', 'Villeneuve-les-Sablons', 'Villeneuve,Villeneuve-les-Sablons', 49.2375300, 2.0778200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49456, 'Villeneuve-lès-Maguelone', 'Villeneuve-les-Maguelone', 'Vil''nev-le-Magelon,Vilanova de Magalona,Vilanòva de Magalona,Villeneuve,ma gai long xin cheng,vu~irunuvu=re=maguronu,wylnb-lh-mglwn,Вильнев-ле-Магелон,Вільнев-ле-Магелон,וילנב-לה-מגלון,ヴィルヌーヴ＝レ＝マグローヌ,马盖隆新城', 43.5333300, 3.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49457, 'Villeneuve-lès-Bouloc', 'Villeneuve-les-Bouloc', 'Villeneuve,Villeneuve-les-Bouloc,Villeneuve-lès-Bouloc', 43.7676900, 1.4227800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49458, 'Villeneuve-lès-Béziers', 'Villeneuve-les-Beziers', 'Villeneuve,Villeneuve les beziers,Villeneuve-les-Beziers,Villeneuve-lès-Béziers', 43.3151700, 3.2805900, 'FR', '2017-07-06', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49459, 'Villeneuve-lès-Avignon', 'Villeneuve-les-Avignon', 'Vil''nev-lez-Avin''jon,Vil''njov-lez-Avin''on,Vilanova dAvinhon,Vilanòva dAvinhon,Villanova ad Avenionem,Villeneuve,Villeneuve-les-Avignon,Villeneuve-lez-Avignon,Villeneuve-lès-Avignon,a wei ni weng xin cheng,vu~irunuvu=rezavu~inyon,Вильнев-лез-Авиньйон,Вильнёв-лез-Авиньон,Вільнев-лез-Авіньйон,ヴィルヌーヴ＝レザヴィニョン,阿维尼翁新城', 43.9684000, 4.7963000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49460, 'Villeneuve-le-Roi', 'Villeneuve-le-Roi', 'Vil''nev-le-Rua,Villeneuve,Villeneuve-le-Roi,Villeneuve-sur-Seine,vu~irunuvu=ru=rowa,xin cheng lei lu wa,Вильнев-ле-Руа,Вільнев-ле-Руа,ヴィルヌーヴ＝ル＝ロワ,新城勒鲁瓦', 48.7368400, 2.4008100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49461, 'Villeneuve-le-Comte', 'Villeneuve-le-Comte', 'Villeneuve,Villeneuve-le-Comte,Villeneuve-le-Peuple,Villeneuve-les-Bordes', 48.8141300, 2.8295300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49462, 'Villeneuve-la-Rivière', 'Villeneuve-la-Riviere', 'Vilanova,Villeneuve,Villeneuve-de-la-Riviere,Villeneuve-de-la-Rivière,Villeneuve-la-Riviere,Villeneuve-la-Rivière', 42.6936600, 2.8029400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49463, 'Villeneuve-la-Guyard', 'Villeneuve-la-Guyard', 'Vil''nev-la-Gviar,Villeneuve,Villeneuve-la-Guerre,Villeneuve-la-Guyard,wei er na wo la ju yi a er,Вильнев-ла-Гвиар,Вільнев-ла-Гвіар,维尔纳沃拉居伊阿尔', 48.3409300, 3.0617600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49464, 'Villeneuve-la-Garenne', 'Villeneuve-la-Garenne', 'Vil''nev-la-Garenn,Villeneuve,Villeneuve-la-Garenne,Vilnev la Garan,bilnoebeulagalen,vu~irunuvu=ra=garen''nu,wynyw lgrn,xin cheng-la jia lun,Вилнев ла Гаран,Вильнев-ла-Гаренн,Вільнев-ла-Гаренн,وینیو لگرن,ヴィルヌーヴ＝ラ＝ガレンヌ,新城-拉加伦,빌뇌브라가렌', 48.9393500, 2.3147800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49465, 'Villeneuve-la-Comptal', 'Villeneuve-la-Comptal', 'Villeneuve,Villeneuve-la-Comptal', 43.2883300, 1.9177300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49466, 'Villeneuve-de-Rivière', 'Villeneuve-de-Riviere', 'Villeneuve,Villeneuve-de-Riviere,Villeneuve-de-Rivière', 43.1282900, 0.6635100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49467, 'Villeneuve-de-Marsan', 'Villeneuve-de-Marsan', 'Vil''nev-de-Marsan,Vilanava de Marcan,Vilanava de Marsan,Vilanava de Marçan,Villeneuve,Villeneuve-de-Marsan,ma er sang xin cheng,Вильнев-де-Марсан,Вільнев-де-Марсан,马尔桑新城', 43.8890600, -0.3092600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49468, 'Villeneuve-de-la-Raho', 'Villeneuve-de-la-Raho', 'Villeneuve,Villeneuve-de-la-Raho', 42.6359600, 2.9165100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49469, 'Villeneuve-de-Berg', 'Villeneuve-de-Berg', 'Vil''nev-de-Ber,Vil''njov-de-Ber,Vilanova de Berg,Vilanòva de Berg,Villeneuve,Villeneuve-de-Berg,bei er xin cheng,Вильнёв-де-Бер,Вільнев-де-Бер,贝尔新城', 44.5573200, 4.5026500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49470, 'Villeneuve', 'Villeneuve', 'Villeneuve-d''Aveyron', 44.4333300, 2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49471, 'Villeneuve', 'Villeneuve', 'Villeneuve', 46.0214100, 4.8361100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49472, 'Villeneuve', 'Villeneuve', '', 44.9448800, 6.5654500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49473, 'Villeneuve', 'Villeneuve', 'Villeneuve', 43.8943100, 5.8618400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49474, 'Villenave-d’Ornon', 'Villenave-d''Ornon', 'Vilanava,Villenave,Villenave-d''Ornon,Villenave-d’Ornon', 44.7732700, -0.5442000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49475, 'Villenauxe-la-Grande', 'Villenauxe-la-Grande', 'Vil''noks-la-Grand,Villenauxe-la-Grande,da wei lei nuo,Вильнокс-ла-Гранд,Вільнокс-ла-Гранд,大维勒诺', 48.5833300, 3.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49476, 'Villemur-sur-Tarn', 'Villemur-sur-Tarn', 'Vil''mjur-sjur-Tarn,Vilamur de Tarn,Villemur,Villemur-sur-Tarn,ta er en he pan wei lai mi,Вильмюр-сюр-Тарн,Вільмюр-сюр-Тарн,塔尔恩河畔维莱米', 43.8670800, 1.5028100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49477, 'Villemoustaussou', 'Villemoustaussou', 'Villemoustaussou', 43.2518600, 2.3655200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49478, 'Villemomble', 'Villemomble', 'Vil''mombl'',Vilemombl,Villemomble,Villemonble,bilmongbeul,vu~irumonburu,wei lei meng bu lei,wyamwmb,wylmwmbl,Вилемомбл,Вильмомбль,Вільмомбль,וילמומבל,ویامومب,ヴィルモンブル,维勒蒙布勒,빌몽블', 48.8833300, 2.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49479, 'Villemolaque', 'Villemolaque', 'Vilamulaca,Villemolaque', 42.5881500, 2.8389000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49480, 'Villemoisson-sur-Orge', 'Villemoisson-sur-Orge', 'Vil''muasson-sjur-Orzh,Villemoisson,Villemoisson-sur-Orge,ao er ri he pan wei lai mu wa song,Вильмуассон-сюр-Орж,Вільмуассон-сюр-Орж,奥尔日河畔维莱穆瓦松', 48.6663200, 2.3365700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49481, 'Villemoirieu', 'Villemoirieu', 'Villemoirieu', 45.7161700, 5.2277100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49482, 'Villemeux-sur-Eure', 'Villemeux-sur-Eure', 'Villemeux,Villemeux-sur-Eure', 48.6725900, 1.4647000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49483, 'Villemandeur', 'Villemandeur', 'Vil''mander,Villemandeur,wei lai mang de,Вільмандер,维莱芒德', 47.9870100, 2.7180200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49484, 'Vilallonga dels Monts', 'Vilallonga dels Monts', 'Vilallonga,Vilallonga dels Monts,Villelongue-dels-Monts', 42.5255700, 2.9043400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49485, 'Villelongue-de-la-Salanque', 'Villelongue-de-la-Salanque', 'Vil''long-de-la-Salank,Vilallonga de la Salanca,Villelongue,Villelongue-de-la-Salanque,wei lai long gai de la-sa lang qu ai,Вильлонг-де-ла-Саланк,Вільлонг-де-ла-Саланк,维莱隆盖德拉-萨朗屈埃', 42.7263700, 2.9824000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49486, 'Villelaure', 'Villelaure', 'Vil''lor,Vilalaura,Villelaure,wei lai luo lei,Вильлор,Вільлор,维莱洛勒', 43.7131900, 5.4307200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49487, 'Ville-la-Grand', 'Ville-la-Grand', 'Vil''-la-Gran,Ville la Grand,Віль-ла-Гран', 46.2030000, 6.2501000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49488, 'Villejust', 'Villejust', 'Vil''zhust,Villejust,wei er rui si,Вильжуст,Вільжуст,维尔瑞斯', 48.6830400, 2.2361000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49489, 'Villejuif', 'Villejuif', 'Vil''zhjuif,Vil''zhuif,Villejuif,Vilzhif,Vilzhuif,biljwipeu,fyljwyf,vu~irujuifu,wylzhwyyf,wywzhwyyf,you tai cheng,Вилжиф,Вилжуиф,Вильжуиф,Вильжюиф,Вільжуїф,فيلجويف,ویلژوئیف,ویوژوئیف,ヴィルジュイフ,犹太城,빌쥐프', 48.7939000, 2.3599200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49490, 'Villegouge', 'Villegouge', 'Villegouge', 44.9666700, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49491, 'Villegailhenc', 'Villegailhenc', 'Villegailhenc', 43.2686700, 2.3546900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49492, 'Villefranque', 'Villefranque', 'Milafranga,Tricolor,Villefranque', 43.4363100, -1.4532400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49493, 'Villefranche-sur-Saône', 'Villefranche-sur-Saone', 'Commune-Franche,Velafranche,Vil''fransh-sjur-Son,Vilfransh sir Saon,Ville-Libre-sur-Saone,Ville-Libre-sur-Saône,Villefranche,Villefranche sobre Saona,Villefranche-sur-Saone,Villefranche-sur-Saône,bilpeulangsyuswileuson,vu~irufuranshu=shuru=sonu,wyywfransh swr sywn,Вилфранш сир Саон,Вильфранш-сюр-Сон,Вільфранш-сюр-Сон,وییوفرانش سور سئون,ヴィルフランシュ＝シュル＝ソーヌ,빌프랑슈쉬르손', 45.9833300, 4.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49494, 'Villefranche-sur-Mer', 'Villefranche-sur-Mer', 'Vil''fransh-sjur-Mer,Vilafranca de Mar,Villa Franca Niciensium,Villafranca,Villefranche,Villefranche-sur-Mer,bilpeulangsyuswileumeleu,bin hai zi you cheng,fylfransh swr myr,vu~irufuranshu=shuru=meru,Вильфранш-сюр-Мер,Вільфранш-сюр-Мер,فيلفرانش سور مير,ヴィルフランシュ＝シュル＝メール,滨海自由城,빌프랑슈쉬르메르', 43.7039200, 7.3108800, 'FR', '2017-05-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49495, 'Villefranche-de-Rouergue', 'Villefranche-de-Rouergue', 'Franciopolis,Vil''fransh-de-Ruehrg,Vil''fransh-de-Ruerg,Vilafranca de Roergue,Villefranche,Villefranche-de-Rouergue,lu ai ge zi you cheng,vu~irufuranshu=do=ruerugu,Вильфранш-де-Руэрг,Вільфранш-де-Руерг,ヴィルフランシュ＝ド＝ルエルグ,鲁埃格自由城', 44.3516600, 2.0370200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49496, 'Villefranche-de-Lauragais', 'Villefranche-de-Lauragais', 'Vil''fransh-de-Lorage,Vilafranca de Lauragues,Vilafranca de Lauragués,Villefranche,Villefranche de Lauragais,Villefranche-de-Lauragais,luo la gai zi you cheng,Вильфранш-де-Лораге,Вільфранш-де-Лораге,洛拉盖自由城', 43.4000000, 1.7169400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49497, 'Villefranche-sur-Cher', 'Villefranche-sur-Cher', 'Vil''fransh-sjur-Sher,xie he pan zi you cheng,Вільфранш-сюр-Шер,谢河畔自由城', 47.3000000, 1.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49498, 'Villefontaine', 'Villefontaine', 'Vil''fonten,Villefontaine,fylfwntyn,wei lai feng tan,Вильфонтен,Вільфонтен,فيلفونتين,维莱丰坦', 45.6125000, 5.1455800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49499, 'Villefagnan', 'Villefagnan', 'Vil''fan''jan,Villefagnan,wei lai fa ni ang,Вильфаньян,Вільфаньян,维莱法尼昂', 46.0114000, 0.0793600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49500, 'Villedômer', 'Villedomer', 'Villedomer,Villedômer', 47.5465100, 0.8877500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49150, 'Weno', 'Weno', 'Moen,TKK,Veno,Weno,u~eno,we no,wei nuo,weno,Вено,เวโน,ウェノ,維諾,웨노', 7.4464800, 151.8413500, 'FM', '2016-09-24', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49151, 'Tofol', 'Tofol', '', 5.3247900, 163.0078100, 'FM', '2013-08-11', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49152, 'Palikir - National Government Center', 'Palikir - National Government Center', 'Palakir,Palikir,Palikyras,Palirik,Pallikir,pa li ji er,pa liki r,pallikileu,parikiru,plyqyr,Παλιρίκ,Паликир,Պալիկիր,פליקיר,ปาลีกีร์,ፓሊኪር,パリキール,帕利基尔,팔리키르', 6.9247700, 158.1610900, 'FM', '2015-06-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49153, 'Kolonia Town', 'Kolonia Town', 'Colony Koronia,Kolonie,Koroni,Koronia,Koronie,Mesenieng,Mesieng,Ponape,Ponape Town', 6.9640000, 158.2060000, 'FM', '2011-02-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49154, 'Rumung', 'Rumung', 'Fal,Faru,Fuaru,Fwaru', 9.6220000, 138.1540000, 'FM', '2011-02-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49155, 'Kolonia', 'Kolonia', 'Colonia,Colony,Colony Koronia,Colony Town,Kolonia,Kolonie,Koroni,Koronie,Koronii,Mesieng,Ponape,Ponape Town', 6.9640000, 158.2062000, 'FM', '2014-08-18', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49156, 'Kapingamarangi', 'Kapingamarangi', '', 1.0786100, 154.8075200, 'FM', '2010-12-21', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49157, 'Nukuoro', 'Nukuoro', '', 3.8361900, 154.9714300, 'FM', '2010-12-21', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49158, 'Ngatik', 'Ngatik', '', 5.7885000, 157.1594200, 'FM', '2010-12-22', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49159, 'Pingelap', 'Pingelap', '', 6.2058900, 160.7032700, 'FM', '2010-12-23', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49160, 'Namoluk', 'Namoluk', '', 5.9150000, 153.1400000, 'FM', '2011-01-09', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49161, 'Houk', 'Houk', '', 6.6894000, 149.2990800, 'FM', '2010-12-31', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49162, 'Polowat', 'Polowat', '', 7.3566100, 149.1990800, 'FM', '2011-01-02', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49163, 'Pulap', 'Pulap', '', 7.6366000, 149.4287800, 'FM', '2011-01-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49164, 'Tamatam', 'Tamatam', '', 7.5386800, 149.4142800, 'FM', '2011-01-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49165, 'Onoun', 'Onoun', '', 8.5750000, 149.6870000, 'FM', '2011-01-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49166, 'Pisaras', 'Pisaras', '', 8.5690000, 150.4195000, 'FM', '2011-01-06', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49167, 'Onou', 'Onou', '', 8.7990000, 150.2915000, 'FM', '2011-01-04', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49168, 'Unanu', 'Unanu', '', 8.7500000, 150.3410000, 'FM', '2011-01-04', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49169, 'Makur', 'Makur', '', 8.9850000, 150.1275000, 'FM', '2011-01-04', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49170, 'Mokil', 'Mokil', '', 6.6928100, 159.7628300, 'FM', '2011-01-05', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49171, 'Nomwin', 'Nomwin', '', 8.4300000, 151.7480000, 'FM', '2011-01-07', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49172, 'Fananu', 'Fananu', '', 8.5581100, 151.9092200, 'FM', '2011-01-07', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49173, 'Murilo', 'Murilo', '', 8.6920000, 152.3435000, 'FM', '2011-01-08', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49174, 'Ruo', 'Ruo', '', 8.6090000, 152.2455000, 'FM', '2011-01-08', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49175, 'Nema', 'Nema', 'Nama', 6.9930000, 152.5750000, 'FM', '2011-01-08', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49176, 'Losap', 'Losap', '', 6.8940000, 152.7400000, 'FM', '2011-01-08', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49177, 'Piis', 'Piis', '', 6.8340000, 152.7010000, 'FM', '2011-01-08', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49178, 'Ettal', 'Ettal', '', 5.5920000, 153.5640000, 'FM', '2011-01-09', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49179, 'Lukunor', 'Lukunor', 'Lekinioch', 5.5070000, 153.8205000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49180, 'Oneop', 'Oneop', '', 5.5066000, 153.7105000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49181, 'Moch', 'Moch', '', 5.4918000, 153.5400000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49182, 'Kuttu', 'Kuttu', '', 5.4530000, 153.4575000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49183, 'Ta', 'Ta', '', 5.2842000, 153.6480000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49184, 'Satowan', 'Satowan', '', 5.3340000, 153.7380000, 'FM', '2011-01-10', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49185, 'Satawal', 'Satawal', '', 7.3820000, 147.0322000, 'FM', '2011-01-17', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49186, 'Lamotrek', 'Lamotrek', '', 7.4910000, 146.3050000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49187, 'Elato', 'Elato', '', 7.5020000, 146.1660000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49188, 'Faraulep', 'Faraulep', '', 8.5880000, 144.5080000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49189, 'Ifalik', 'Ifalik', '', 7.2500000, 144.4445000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49190, 'Eauripik', 'Eauripik', '', 6.6870000, 143.0375000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49191, 'Sorol', 'Sorol', '', 8.1435000, 140.3940000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49192, 'Fais', 'Fais', '', 9.7660000, 140.5200000, 'FM', '2011-01-13', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49193, 'Ngulu', 'Ngulu', '', 8.4500000, 137.4840000, 'FM', '2011-01-12', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49194, 'Colonia', 'Colonia', 'Colonia', 9.5163800, 138.1216700, 'FM', '2014-08-19', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49195, 'Lelu', 'Lelu', '', 5.3335900, 163.0224800, 'FM', '2011-01-31', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49196, 'Tafunsak', 'Tafunsak', '', 5.3671000, 162.9853200, 'FM', '2011-02-03', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49197, 'Malem', 'Malem', '', 5.2859900, 163.0260900, 'FM', '2011-02-02', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49198, 'Utwe', 'Utwe', '', 5.2748600, 162.9765600, 'FM', '2011-02-02', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49199, 'Madolenihm Municipality Government', 'Madolenihm Municipality Government', '', 6.8349300, 158.2987000, 'FM', '2011-02-11', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49200, 'Tonoas Municipal Building', 'Tonoas Municipal Building', '', 7.3759700, 151.8843300, 'FM', '2011-02-18', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49201, 'Weno Municipal Offices', 'Weno Municipal Offices', '', 7.4442800, 151.8410300, 'FM', '2011-02-18', 145);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49501, 'Villedieu-sur-Indre', 'Villedieu-sur-Indre', 'Verite,Vil''d''e-sjur-Ehndr,Vil''d''e-sjur-Endr,Villedieu,Villedieu-sur-Indre,Vérité,an de er he pan wei lai di e,Вильдье-сюр-Эндр,Вільдьє-сюр-Ендр,安德尔河畔维莱迪厄', 46.8459800, 1.5397500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49502, 'Villedieu-les-Poêles', 'Villedieu-les-Poeles', 'Vil''d''e-le-Poel'',Villedieu,wei lai di e lai bo ai lai,Вильдье-ле-Поель,Вільдьє-ле-Поель,维莱迪厄莱波埃莱', 48.8333300, -1.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49503, 'Villedieu-la-Blouère', 'Villedieu-la-Blouere', 'Vil''d''e-la-Bluer,Villedieu,Villedieu-la-Blouere,Villedieu-la-Blouère,vu~irude~yu=ra=burueru,wei lai di e la bu lu ai er,Вільдьє-ла-Блуер,ヴィルデュー＝ラ＝ブルエール,维莱迪厄拉布卢埃尔', 47.1473800, -1.0628600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49504, 'Ville-d’Avray', 'Ville-d''Avray', 'Ville-d''Avray,Ville-d’Avray', 48.8235800, 2.1931100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49505, 'Villecroze', 'Villecroze', 'Vil''kroz,Vilacrosa,Vilacròsa,Villecroze,wei lai ke luo ze,Вилькроз,Вількроз,维莱克罗泽', 43.5818100, 6.2754200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49506, 'Villecresnes', 'Villecresnes', 'Vil''kren,Villecresnes,wei lai ke lei na,Вилькрен,Вількрен,维莱克雷纳', 48.7200200, 2.5394000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49507, 'Villebret', 'Villebret', 'Villebret', 46.2668500, 2.6382700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49508, 'Villebon-sur-Yvette', 'Villebon-sur-Yvette', 'Vil''bon-sjur-Ivett,Villebon,Villebon-sur-Yvette,yi fu te he pan wei lei bang,Вильбон-сюр-Иветт,Вільбон-сюр-Іветт,伊夫特河畔维勒邦', 48.7059400, 2.2401900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49509, 'Villebois', 'Villebois', 'Villebois', 45.8494700, 5.4322600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49510, 'Villeblevin', 'Villeblevin', 'Vilbleven,Villeblevin,Вилблевен', 48.3244600, 3.0803800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49511, 'Villebernier', 'Villebernier', 'Vil''bern''e,Villebernier,wei lei bei er nie,Вільберньє,维勒贝尔涅', 47.2537400, -0.0322900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49512, 'Villebarou', 'Villebarou', 'Commune-Barou,Villebarou', 47.6234400, 1.3225200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49513, 'Villé', 'Ville', 'Ville,Villé,Weiler,Willer,fyly,wei lai,Вилле,Вілле,فيلي,维莱', 48.3426600, 7.3057400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49514, 'Villaz', 'Villaz', 'Villa,Villaz,Вілла', 45.9506900, 6.1871700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49515, 'Villaudric', 'Villaudric', 'Villaudric', 43.8304400, 1.4316600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49516, 'Villars-les-Dombes', 'Villars-les-Dombes', 'Villars,Villars-les-Dombes', 46.0022700, 5.0290500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49517, 'Villar-Saint-Pancrace', 'Villar-Saint-Pancrace', 'Lo Vilar de Sant Pancraci,Vilard Sant Pancraci,Villar,Villar-Sen-Pankras,Villard-Saint-Pancrace,wei la sheng pang ke la ke,Виллар-Сен-Панкрас,Віллар-Сен-Панкрас,维拉圣庞克拉克', 44.8731800, 6.6266900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49518, 'Villars', 'Villars', 'Villars', 45.4711800, 4.3544700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49519, 'Villargondran', 'Villargondran', 'Villargondran', 45.2711300, 6.3695000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49520, 'Villard-de-Lans', 'Villard-de-Lans', 'Lo Vilar de Lans,Villar-de-Lan,Villar-de-Lans,Villard,Villard-de-Lans,wei la er de lang,Виллар-де-Ланс,Віллар-де-Лан,维拉尔德朗', 45.0707000, 5.5528100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49521, 'Villard-Bonnot', 'Villard-Bonnot', 'Villar-Bonno,Villard,Villard-Bonnot,wei la er bang ao,Виллар-Бонно,Віллар-Бонно,维拉尔邦奥', 45.2400000, 5.8901500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49522, 'Villandry', 'Villandry', 'Villandri,vu~irandori,wei lang de li,Вілландрі,ヴィランドリー,维朗德里', 47.3401900, 0.5105000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49523, 'Villaines-la-Juhel', 'Villaines-la-Juhel', 'Villaines,Villaines-la-Juhel,Villen-la-Zhuel'',wei lai nei la rui ai,Віллен-ла-Жуель,维莱内拉瑞埃', 48.3441600, -0.2773400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49524, 'Village-Neuf', 'Village-Neuf', 'Neudorf,Viljage-Nef,Village-Neuf,Виляге-Неф,Віляге-Неф', 47.5901600, 7.5701900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49525, 'Villabé', 'Villabe', 'Villabe,Villabé,wei la bei,Виллабе,Віллабе,维拉贝', 48.5894900, 2.4509600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49526, 'Vihiers', 'Vihiers', 'Vie,Vierium,Vihiers,wei ye er,Віє,维耶尔', 47.1463100, -0.5323800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49527, 'Vigy', 'Vigy', 'Vigy,Vizhi,wei ji,Вижи,Віжі,维吉', 49.2035600, 6.2988300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49528, 'Vigny', 'Vigny', 'Vigny', 49.0790200, 1.9280600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49529, 'Vignoux-sur-Barangeon', 'Vignoux-sur-Barangeon', 'Vignoux,Vignoux-sur-Barangeon', 47.2006800, 2.1725800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49530, 'Vignot', 'Vignot', '', 48.7741800, 5.6090400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49531, 'Vignoc', 'Vignoc', 'Gwinieg,Vignoc,Vin''ok,wei ni ao ke,Виньок,Віньок,维尼奥克', 48.2484200, -1.7816900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49532, 'Vigneux-sur-Seine', 'Vigneux-sur-Seine', 'Vigneux,Vigneux-sur-Seine,Vin''e-sjur-Sen,Vine sir Sen,binoeswileusen,sai na he pan wei ni e,vu~inyu=shuru=senu,wynywswrsn,Винье-сюр-Сен,Виње сир Сен,Віньє-сюр-Сен,وینیوسورسن,ヴィニュー＝シュル＝セーヌ,塞纳河畔维尼厄,비뇌쉬르센', 48.7029100, 2.4135700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49533, 'Vigneux-de-Bretagne', 'Vigneux-de-Bretagne', 'Gwinieg-Breizh,Vigneux,Vigneux-de-Bretagne,Vin''e-de-Bretan'',wei gai yu de bu lei ta ni,Віньє-де-Бретань,维盖于德布雷塔尼', 47.3254700, -1.7367800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49534, 'Vigneulles-lès-Hattonchâtel', 'Vigneulles-les-Hattonchatel', 'Vigneulles,Vigneulles-les-Hattonchatel,Vigneulles-lès-Hattonchâtel', 48.9815200, 5.7046400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49535, 'Vignale', 'Vignale', 'Vignale', 42.4704500, 9.3259800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49536, 'Vignacourt', 'Vignacourt', 'Vignacourt,Vin''jakur,Vinacourt,wei ni ya ku er,Віньякур,维尼亚库尔', 50.0123600, 2.1974300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49537, 'Vigeois', 'Vigeois', 'Vigeois', 45.3801400, 1.5163500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49538, 'Vif', 'Vif', 'Vif', 45.0543600, 5.6775700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49539, 'Vieux-Thann', 'Vieux-Thann', 'Alt-Tann Mulhausen,Alt-Thann,V''e-Tann,Ve-Tann,Vieux-Thann,Вье-Танн,Вє-Танн', 47.8034700, 7.1206800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49540, 'Le Vieux-Marché', 'Le Vieux-Marche', 'Ar C''houerc''had,Le Vieux-Marche,Le Vieux-Marché', 48.6000000, -3.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49541, 'Vieux-Condé', 'Vieux-Conde', 'V''e-Konde,V''jo-Konde,Ve-Konde,Vieux-Conde,Vieux-Condé,Vieux-Nord-Libre,jiu kong dai,Вье-Конде,Вьё-Конде,Вє-Конде,旧孔代', 50.4594400, 3.5673800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49542, 'Vieux-Charmont', 'Vieux-Charmont', 'Vieux-Charmont', 47.5219000, 6.8373800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49543, 'Vieux-Boucau-les-Bains', 'Vieux-Boucau-les-Bains', 'Vieux-Boucau,Vieux-Boucau-les-Bains', 43.7894700, -1.3995700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49544, 'Vieux-Berquin', 'Vieux-Berquin', 'Vieux-Berquin', 50.6948900, 2.6444400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49545, 'Viesly', 'Viesly', 'Viesly', 50.1534500, 3.4623600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49546, 'Vierzon', 'Vierzon', 'V''erzon,Verzon,Vierzon,Vierzon-Ville,Vjerzon,XVZ,bieleujong,vu~ieruzon,wei ye er zong,wyrzwn,Вьерзон,Вєрзон,Вјерзон,ویرزون,ヴィエルゾン,维耶尔宗,비에르종', 47.2166700, 2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49547, 'Vienne-en-Val', 'Vienne-en-Val', 'Venn-an-Val'',Vienne-en-Val,wa de qu wei an,Вєнн-ан-Валь,瓦地区维安', 47.8003600, 2.1346000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49548, 'Vienne', 'Vienne', 'V''enn,Viana,Viena,Viena del Delfinat,Vienne,Vienne-la-Patriote,Vièna,XVI,Вьенн', 45.5166700, 4.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49549, 'Viennay', 'Viennay', 'Viennay', 46.6871100, -0.2464100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49550, 'Vielmur-sur-Agout', 'Vielmur-sur-Agout', 'V''el''mjur-sjur-Agu,Vel''mjur-sjur-Agu,Vielhmur,Vièlhmur,a gu he pan wei ye er mi,Вьельмюр-сюр-Агу,Вєльмюр-сюр-Агу,阿古河畔维耶尔米', 43.6166700, 2.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49551, 'Vielle-Saint-Girons', 'Vielle-Saint-Girons', 'Vielle-Saint-Girons', 43.9500000, -1.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49552, 'Vieillevigne', 'Vieillevigne', 'Henwinieg,Vieillevigne', 46.9721400, -1.4340500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49553, 'Vieille-Toulouse', 'Vieille-Toulouse', '', 43.5236600, 1.4423000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49554, 'Vieille-Église', 'Vieille-Eglise', 'L''Indivisible,V''ej-Egliz,Vej-Egliz,Vieille-Eglise,Vieille-Église,fyyly ajlys,jiu ai ge li si,Вьей-Еглиз,Вєй-Егліз,فييلي إجليس,旧埃格利斯', 50.9282300, 2.0767100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49555, 'Vieille-Brioude', 'Vieille-Brioude', 'Vieille-Brioude', 45.2664800, 3.4027200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49556, 'Vidauban', 'Vidauban', 'Vidauban,Vidoban,wei duo bang,Видобан,Відобан,维多邦', 43.4278000, 6.4329000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49557, 'Vic-sur-Seille', 'Vic-sur-Seille', 'Vic,Vic-sur-Seille,Vik-sjur-Sej,sai er he pan wei ke,Вик-сюр-Сей,Вік-сюр-Сей,塞尔河畔维克', 48.7820400, 6.5308100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49558, 'Vic-sur-Cère', 'Vic-sur-Cere', 'Vic,Vic de Cera,Vic-sur-Cere,Vic-sur-Cère,Vik-sjur-Ser,sai er he pan wei ke,vu~ikku=shuru=seru,Вик-сюр-Сер,Вік-сюр-Сер,ヴィック＝シュル＝セール,塞尔河畔维克', 44.9792900, 2.6248500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49559, 'Vic-sur-Aisne', 'Vic-sur-Aisne', 'Vic,Vic-sur-Aisne,Vik-sjur-Ehn,Vik-sjur-En,ai na he pan wei ke,Вик-сюр-Эн,Вік-сюр-Ен,埃纳河畔维克', 49.4060900, 3.1122300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49560, 'Vicq-sur-Breuilh', 'Vicq-sur-Breuilh', 'Vicq,Vicq-sur-Breuilh', 45.6466100, 1.3817900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49561, 'Vicq', 'Vicq', 'Vicq', 50.4073800, 3.6034800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49562, 'Vic-le-Comte', 'Vic-le-Comte', 'Vic,Vic la Comte,Vic la Còmte,Vic-le-Comte,Vic-sur-Allier,Vik-le-Kont,vu~ikku=ru=konto,wei ke lai kong te,Вік-ле-Конт,ヴィック＝ル＝コント,维克莱孔特', 45.6431700, 3.2463800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49563, 'Vic-la-Gardiole', 'Vic-la-Gardiole', 'Vic,Vic de la Gardiola,Vic de la Gardiòla,Vic-la-Gardiole,Vik-la-Gard''jol'',wei ke la jia er di ao er,Вик-ла-Гардьйоль,Вік-ла-Гардьйоль,维克拉加尔迪奥尔', 43.4908000, 3.7975000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49564, 'Vichy', 'Vichy', 'Gorad Vishy,VHY,Vichei,Vichèi,Vippiacum,Vishi,Visi,Visy,Viši,Višī,bisi,fyshy,vishi,vu~ishi,wei qi,wshy,wwysy,wyshy,wysy,Βισύ,Виши,Віші,Горад Вішы,ווישי,וישי,فيشي,وشی,ویشی,ཝི་ཆི།,ვიში,ヴィシー,维琪,비시', 46.1166700, 3.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49565, 'Vic-Fezensac', 'Vic-Fezensac', 'Vic de Fesensac,Vic en Fesensac,Vic-Fezensac,Vic-sur-l''Osse,Vik-Fezansak,vu~ikku=fezansakku,wei ke fei cang sa ke,Вик-Фезансак,Вік-Фезансак,ヴィック＝フェザンサック,维克费藏萨克', 43.7718300, 0.3136800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49566, 'Vic-en-Bigorre', 'Vic-en-Bigorre', 'Vic,Vic-de Bigorre,Vic-en-Bigorre', 43.3868200, 0.0547100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49567, 'Vibraye', 'Vibraye', 'Vibraye', 48.0560700, 0.7417100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49568, 'Vias', 'Vias', 'Vias', 43.3115600, 3.4177400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49569, 'Viarmes', 'Viarmes', 'V''jarm,Viarm,Viarmes,wei a er mo,Виарм,Вьярм,Віарм,维阿尔默', 49.1308200, 2.3707400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49570, 'Vianne', 'Vianne', 'V''jann,Viana,Vianne,Vjann,wei ang,Вьянн,Вянн,维昂', 44.1965800, 0.3210400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49571, 'Vezins', 'Vezins', 'Chalain,Vezins', 47.1201500, -0.7097100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49572, 'Vezin-le-Coquet', 'Vezin-le-Coquet', 'Gwezin,Vezin,Vezin-le-Coquet', 48.1185700, -1.7546600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49573, 'Vézénobres', 'Vezenobres', 'Vezenobres,Vézénobres', 44.0513000, 4.1377500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49574, 'Vézelise', 'Vezelise', 'Vezelise,Vezeliz,Vezliz,Vézelise,wei ze li si,Везелиз,Везеліз,Везлиз,韦泽利斯', 48.4868200, 6.0889400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49575, 'Veyrier-du-Lac', 'Veyrier-du-Lac', 'Vejre-dju-Lak,Ver''e-dju-Lak,Verier,Veyrier,Veyrier-du-Lac,Vêriér,Вейрє-дю-Лак,Верье-дю-Лак', 45.8799000, 6.1775100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49576, 'Veyre-Monton', 'Veyre-Monton', 'Veira e Monton,Vejr-Monton,Veyre,Veyre-Monton,Vèira e Monton,vu~eiru=monton,wei er meng tong,Вейр-Монтон,ヴェイル＝モントン,韦尔蒙通', 45.6686600, 3.1714400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49577, 'Veyras', 'Veyras', 'Veyras', 44.7351800, 4.5625400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49578, 'Veyrac', 'Veyrac', 'Veyrac', 45.8952100, 1.1050000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49579, 'Veynes', 'Veynes', 'Veina,Veinet,Vejn,Ven,Veynes,Vèina,wei nei,Вейн,Вен,韦内', 44.5333300, 5.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49580, 'Veurey-Voroize', 'Veurey-Voroize', 'Veurey,Veurey-Voroize', 45.2730700, 5.6131900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49581, 'Vétraz-Monthoux', 'Vetraz-Monthoux', 'Vetra-Montu,Vitriacum-Montanum,Ветра-Монту', 46.1743000, 6.2585200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49582, 'Vestric-et-Candiac', 'Vestric-et-Candiac', 'Vestric,Vestric-et-Candiac', 43.7406100, 4.2591400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49583, 'Vesseaux', 'Vesseaux', 'Vesseaux', 44.6513600, 4.4425900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49584, 'Vesoul', 'Vesoul', 'Vesoul,Vesulum,Vezul,Vezul'',XVO,beujul,vuzuru,wo su lei,Везул,Везуль,ヴズール,沃苏勒,브줄', 47.6333300, 6.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49585, 'Vescovato', 'Vescovato', 'Vescovato', 42.4927800, 9.4391600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49586, 'Verzy', 'Verzy', 'Verzy', 49.1457600, 4.1640900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49587, 'Verzenay', 'Verzenay', 'Verzenay,Verzene,wei er ze nai,Верзене,韦尔泽奈', 49.1591800, 4.1454300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49588, 'Vervins', 'Vervins', 'Verven,vu~eruvu~an,wei er wan,Вервен,ヴェルヴァン,韦尔万', 49.8333300, 3.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49589, 'Vertus', 'Vertus', 'Vertju,Vertus,wei er di,Вертю,韋爾蒂', 48.9060900, 4.0021600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49590, 'Vert-Saint-Denis', 'Vert-Saint-Denis', 'Ver-Sen-Deni,Vert-Saint-Denis,Вер-Сен-Дени,Вер-Сен-Дені', 48.5681800, 2.6200700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49591, 'Vertou', 'Vertou', 'Gwerzhav,Vertou,Vertu,beleutu,vu~eruto~u,wei er tu,wrtw,Верту,ورتو,ヴェルトゥ,韦尔图,베르투', 47.1686900, -1.4692900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49592, 'Verton', 'Verton', 'Verton,fyrtwn,wei er tong,Вертон,فيرتون,韦尔通', 50.4023400, 1.6476600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49593, 'Vert-le-Petit', 'Vert-le-Petit', 'Ver-le-Peti,Vert-le-Petit,xiao wei er,Вер-ле-Пети,Вер-ле-Петі,小韦尔', 48.5516300, 2.3652600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49594, 'Vert-le-Grand', 'Vert-le-Grand', 'Ver-le-Gran,Vert-le-Grand,da wei er,Вер-ле-Гран,大韦尔', 48.5717200, 2.3577700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49595, 'Vertheuil', 'Vertheuil', 'Vertheuil-en-Medoc,Vertheuil-en-Médoc', 45.2500000, -0.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49596, 'Vert-en-Drouais', 'Vert-en-Drouais', 'Ver-an-Drue,Vert,Vert-en-Drouais,de lu ai de qu wei er,Вер-ан-Друе,德鲁艾地区韦尔', 48.7602900, 1.2946000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49597, 'Vertaizon', 'Vertaizon', 'Vertaizon', 45.7713600, 3.2888400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49598, 'Ver-sur-Mer', 'Ver-sur-Mer', 'Ver,Ver-sjur-Mer,Ver-sur-Mer,bin hai wei,wyr swr mrsy,Вер-сюр-Мер,وئر سور مرسی,滨海韦', 49.3298700, -0.5311800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49599, 'Ver-sur-Launette', 'Ver-sur-Launette', 'Ver,Ver sur Launette,Ver-sjur-Lonett,Ver-sur-Launette,Vern,luo nei te he pan wei,wyr swr lwnt,Вер-сюр-Лонетт,وئر سور لونت,洛内特河畔韦', 49.1049500, 2.6840900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49600, 'Versonnex', 'Versonnex', 'Versonnex', 45.9275300, 5.9258500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49601, 'Verson', 'Verson', 'Verson,wei er song,Версон,韦尔松', 49.1543200, -0.4562800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49602, 'Versailles', 'Versailles', 'Berceau-de-la-Liberte,Berceau-de-la-Liberté,Bersallies,Versailles,Versaj,Versajlo,Versal'',Versalhes,Versalia,Versaliae,Versalis,Versalles,Wersal,XVE,beleusayu,vu~erusaiyu,Βερσαλλίες,Версай,Версаль,ורסאי,ヴェルサイユ,베르사유', 48.8000000, 2.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49603, 'Verrières-le-Buisson', 'Verrieres-le-Buisson', 'Verr''er-le-Bjuisson,Verrer-le-Bjuisson,Verrieres,Verrieres-le-Buisson,Verrières,Verrières-le-Buisson,fu er li ai lei bi yi song,Веррьер-ле-Бюиссон,Веррєр-ле-Бюїссон,弗尔里埃勒比伊松', 48.7456500, 2.2679600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49604, 'Verrières', 'Verrieres', 'Verrieres,Verrières', 48.2333400, 4.1489300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49605, 'Verquin', 'Verquin', 'Verquin', 50.5024000, 2.6388800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49606, 'Véron', 'Veron', 'Veron,Véron', 48.1285300, 3.3077300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49607, 'Verny', 'Verny', 'Verny', 49.0072800, 6.2052800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49608, 'Vern-sur-Seiche', 'Vern-sur-Seiche', 'Gwern-ar-Sec''h,Gwern-ar-Sech,Vern,Vern-sjur-Sesh,Vern-sur-Seiche,Vernum,sai ke he pan wei er en,wrn swr sych,Верн-сюр-Сеш,ورن سور سیچ,塞克河畔韦尔恩', 48.0451400, -1.6005700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49609, 'Vernoux-en-Vivarais', 'Vernoux-en-Vivarais', 'Vernoux,Vernoux-d''Ardeche,Vernoux-d’Ardèche,Vernoux-en-Vivarais', 44.8956300, 4.6464300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49610, 'Vernou-la-Celle-sur-Seine', 'Vernou-la-Celle-sur-Seine', 'Vernou,Vernu-la-Sel''-sjur-Sen,Верну-ла-Сель-сюр-Сен', 48.3878900, 2.8471800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49611, 'Vernou-sur-Brenne', 'Vernou-sur-Brenne', 'Vernou,Vernou-sur-Brenne', 47.4193600, 0.8475700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49612, 'Vernouillet', 'Vernouillet', 'Vernouillet', 48.9714600, 1.9808200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49613, 'Vernouillet', 'Vernouillet', 'Vernouillet', 48.7209000, 1.3695100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49614, 'Vernosc-lès-Annonay', 'Vernosc-les-Annonay', 'Vernosc,Vernosc les Annonay,Vernosc lès Annonay,Vernosc-les-Annonay,Vernosc-lès-Annonay,Vernosk-lez-Annone,Vernòsc,wei er nuo si ke lai a nuo nai,Верноск-лез-Анноне,韦尔诺斯克莱阿诺奈', 45.2167600, 4.7125200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49615, 'Vernon', 'Vernon', 'Vernon', 49.0929200, 1.4633200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49616, 'Vernoil-le-Fourrier', 'Vernoil-le-Fourrier', 'Vernoil,Vernual''-le-Furre,wei er nu wa lai fu er li ye,wrnyl lh fwryr,Вернуаль-ле-Фуррє,ورنیل له فوریر,韦尔努瓦莱富尔里耶', 47.3833300, 0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49617, 'Vernioz', 'Vernioz', 'Vernioz', 45.4268200, 4.8818800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49618, 'Verniolle', 'Verniolle', 'Verniolle', 43.0816200, 1.6490400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49619, 'Verneuil-sur-Vienne', 'Verneuil-sur-Vienne', 'Verneuil,Verneuil-sur-Vienne', 45.8552400, 1.1013300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49620, 'Verneuil-sur-Seine', 'Verneuil-sur-Seine', 'Vernej-sjur-Sen,Verneuil,wrnwyl swr syn,Верней-сюр-Сен,ورنویل سور سین', 48.9738800, 1.9648000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49621, 'Verneuil-sur-Avre', 'Verneuil-sur-Avre', 'Verneig-syr-Avr,Vernej-sjur-Avr,Verneuil,Verneuil-sur-Avre,Vernjoj-sjur-Avr,Vernolium in Pertico,a fu er he pan wei er ne yi,wrnwyl swr awr,Βερνέιγ-συρ-Αβρ,Верней-сюр-Авр,Вернёй-сюр-Авр,ورنویل سور آور,阿夫尔河畔韦尔讷伊', 48.7394900, 0.9273100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49622, 'Verneuil-en-Halatte', 'Verneuil-en-Halatte', 'Vernej-an-Alatt,Verneuil,Verneuil-en-Halatte,Verneuil-sur-Oise,Vernjoj-an-Alatt,a la te de qu wei er na yi,wrnwyl an halath,Верней-ан-Алатт,Вернёй-ан-Алатт,ورنویل ان حالاته,阿拉特地区韦尔纳伊', 49.2791400, 2.5241000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49623, 'Vernet-les-Bains', 'Vernet-les-Bains', 'Verne-le-Ben,Vernet,Vernet-les-Bains,vu~erune=re=ban,wei er nei lai ban,wrnt las byns,Верне-ле-Бен,ورنت لاس بینس,ヴェルネ＝レ＝バン,韦尔内莱班', 42.5483400, 2.3871700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49624, 'Vernègues', 'Vernegues', 'Lo Vernegue,Verneg,Vernegues,Vernègues,wei er nei gai,Вернег,韦尔内盖', 43.6857500, 5.1715600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49625, 'Vernantes', 'Vernantes', 'Vernantes', 47.3932000, 0.0530400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49626, 'Vernaison', 'Vernaison', 'Vernaison,Vernezon,fan he nai cong,wrnysn,Вернезон,ورنیسن,凡合乃从', 45.6469300, 4.8124900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49627, 'Vermenton', 'Vermenton', 'Vermenton', 47.6645900, 3.7350100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49628, 'Vermelles', 'Vermelles', 'Vermel'',Vermelles,fyrmylys,wei er mei lei,wrmlz,Вермель,فيرميليس,ورملز,韦尔梅勒', 50.4894900, 2.7473900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49629, 'Vermand', 'Vermand', 'Verman,Vermand,wei er mang,wrmnd,Верман,Վերման,ورمند,韦尔芒', 49.8755000, 3.1495900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49630, 'Verlinghem', 'Verlinghem', 'Verlengem,Verlinghem,wei er lan gai mu,wrlynqm,Верленгем,ورلینقم,韦尔兰盖姆', 50.6829100, 2.9990700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49631, 'Vérines', 'Verines', 'Verines,Vérines', 46.1937200, -0.9668300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49632, 'Vergt', 'Vergt', 'Lo Vern de Salon,Ver,Vergt,Vern,wei er ge,wrgt,Вер,ورگت,韦尔格', 45.0269500, 0.7182000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49633, 'Vergongheon', 'Vergongheon', 'Vergongeon,Vergongheon,Vergonjon,wei er gong rong,wrgnqywn,Вергонгеон,ورگنقئون,韦尔贡容', 45.3705800, 3.3191500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49634, 'Vergigny', 'Vergigny', 'Vergigny', 47.9705900, 3.7186100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49635, 'Vergèze', 'Vergeze', 'Vergeze,Vergèze', 43.7440400, 4.2210900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49636, 'Verfeil', 'Verfeil', 'Verfeil', 43.6578100, 1.6634000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49637, 'Véretz', 'Veretz', 'Veretz,Véretz', 47.3570600, 0.8057500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49638, 'Verdun', 'Verdun', 'Ferdun,Gorad Verdehn,Verdan,Verden,Verdena,Verdenas,Verdjun,Verdun,Verdun-sur-Meuse,Verduno,Verdún,Virodunum,beleudoeng,fan er deng,frdan,verdeni,vu~erudan,wrdn,wrdwn,Вердан,Верден,Вердюн,Горад Вердэн,Վերդեն,ורדן,فردان,وردون,ვერდენი,ヴェルダン,凡尔登,베르됭', 49.1666700, 5.3833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49639, 'Verdun-sur-le-Doubs', 'Verdun-sur-le-Doubs', 'Verdun', 46.8969200, 5.0212700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49640, 'Verdun-sur-Garonne', 'Verdun-sur-Garonne', 'Verden-sjur-Garonn,Verdun,Verdun de Garona,Verdun-sur-Garonne,jia luo na he pan fu er dan,wrdn swr garwn,Верден-сюр-Гаронн,وردن سور گارون,加罗纳河畔弗尔丹', 43.8544600, 1.2342500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49641, 'Vercel-Villedieu-le-Camp', 'Vercel-Villedieu-le-Camp', 'Campdu Vercel,Vercel,Vercel-Villedieu-le-Camp', 47.1831800, 6.4008200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49642, 'Verberie', 'Verberie', 'Verberi,Verberie,wei er bo li ye,wrbry,Вербери,Вербері,وربری,韦尔伯里耶', 49.3111500, 2.7321000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49643, 'Ventiseri', 'Ventiseri', 'Ventiseri,Ventizeri,Vintisari,Vintìsari,wntysry,Вентизери,Вентізері,ونتیسری', 41.9416900, 9.3317300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49644, 'Ventabren', 'Ventabren', 'Vantabran,Ventabren,wang ta bu lang,wntbrn,Вантабран,ونتبرن,旺塔布朗', 43.5384700, 5.2954100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49645, 'Venoy', 'Venoy', 'Venoy', 47.8051800, 3.6369500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49646, 'Vennecy', 'Vennecy', 'Vennecy,Vennesi,wei nei xi,wnky,Веннесі,ونکی,韦内西', 47.9546500, 2.0545900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49647, 'Venizel', 'Venizel', 'Venizel', 49.3658300, 3.3932100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49648, 'Vénissieux', 'Venissieux', 'Venis''e,Venis''jo,Venisje,Venissieux,Venissioex,Vènissiœx,Vénissieux,benisioe,vu~enishu,wei ni xi e,wnysyw,Венисье,Венисьё,Венисје,Венісьє,ونیسیو,ヴェニシュー,維尼西厄,베니시외', 45.7025400, 4.8714700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49649, 'Veneux-les-Sablons', 'Veneux-les-Sablons', 'Vene-le-Sablon,Veneux,Veneux-Les Sablons,wnwks las sblns,Вене-ле-Саблон,ونوکس لاس سبلنس', 48.3787200, 2.7949900, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49650, 'Venette', 'Venette', 'Venett,Venette,wei nei te,Венетт,韦内特', 49.4170500, 2.8031700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49651, 'Venerque', 'Venerque', 'Benerca,Benèrca,Venerca,Venerk,Venerque,Venèrca,wei nei er qu ai,wnrqw,Венерк,ونرقو,韦内尔屈埃', 43.4345700, 1.4458800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49652, 'Venelles', 'Venelles', 'Venel'',Venela,Venelles,Venèla,wei nei lai,wnls,Венель,ونلس,韦内莱', 43.5983900, 5.4852900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49653, 'Vénéjan', 'Venejan', 'Venejan,Vénéjan', 44.1972900, 4.6542200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49654, 'Vendres', 'Vendres', 'Vendres', 43.2697700, 3.2234100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49655, 'Vendrennes', 'Vendrennes', 'Vandrenn,Vendrennes,wang de lei na,wndrns,Вандренн,وندرنس,旺德雷纳', 46.8252300, -1.1235700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49656, 'Vendôme', 'Vendome', 'Gorad Vandom,Vandom,Vantom,Vendome,Vendome-Regenere,Vendôme,Vendôme-Regénéré,Vindocinum,vu~andomu,wang duo mu,wndm,Βαντόμ,Вандом,Горад Вандом,وندم,ヴァンドーム,旺多姆', 47.8000000, 1.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49657, 'Vendœuvres', 'Vendoeuvres', 'Vandevr,Vandjovr,Vendoeuvres,wang duo e fu lei,wndwwrs,Вандевр,Вандёвр,وندوورس,旺多厄夫雷', 46.8000000, 1.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49658, 'Vendin-le-Vieil', 'Vendin-le-Vieil', 'Vanden-le-V''ej,Vanden-le-Vej,Vendin,Vendin Le Veil,Vendin-le-Vieil,Vindin-lVieil,fyndyn ly fyyl,jiu wang dan,wndyn lh wyyl,Ванден-ле-Вьей,Ванден-ле-Вєй,فيندين لي فييل,وندین له وییل,旧旺丹', 50.4738500, 2.8667400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49659, 'Vendin-lès-Béthune', 'Vendin-les-Bethune', 'Vanden-le-Betjun,Vendin,Vendin-les-Bethune,Vendin-lès-Béthune,Vindin-les-Betheune,Vindin-lès-Betheune,fyndyn lyh bythwn,wang dan lai bei di ne,wndyn las bthwn,Ванден-ле-Бетюн,فيندين ليه بيثون,وندین لاس بتهون,旺丹莱贝蒂讷', 50.5401200, 2.6004300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49660, 'Vendeville', 'Vendeville', 'Vendeville', 50.5769300, 3.0787000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49661, 'Vendeuvre-sur-Barse', 'Vendeuvre-sur-Barse', 'Vandevr-sjur-Bars,Vandjovr-sjur-Bars,Vandopera,Vendeuvre,Vendeuvre-sur-Barse,ba er si he pan wang de fu er,wndwwr swr brs,Вандевр-сюр-Барс,Вандёвр-сюр-Барс,وندوور سور برس,巴尔斯河畔旺德夫尔', 48.2378600, 4.4690500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49662, 'Vendeuvre-du-Poitou', 'Vendeuvre-du-Poitou', 'Vandevr-dju-Puatu,Vendeuvre,Vendeuvre-du-Poitou,wang de fu lei di pu wa tu,wndwwr dwd pytw,Вандевр-дю-Пуату,وندوور دود پیتو,旺德夫勒迪普瓦图', 46.7357900, 0.3099600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49663, 'Vendenheim', 'Vendenheim', 'Vangene,Vendenajm,Vendenheim,fyndynhym,wang de nan,wndnhym,Венденайм,فيندينهيم,وندنهیم,旺德南', 48.6694800, 7.7098300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49664, 'Vendegies-sur-Écaillon', 'Vendegies-sur-Ecaillon', 'Vandezhi-sjur-Ekajon,Vendegies,Vendegies-sur-Ecaillon,Vendegies-sur-Écaillon,ai ka yong he pan wang de ji,wndgys swr akyln,Вандежи-сюр-Екайон,Вандежі-сюр-Екайон,وندگیس سور اکیلن,埃卡永河畔旺德吉', 50.2622400, 3.5125600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49665, 'Vendat', 'Vendat', 'Vanda,Vendat,Vindac,wang da,wndt,Ванда,وندت,旺达', 46.1601500, 3.3545100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49666, 'Vendargues', 'Vendargues', 'Vandarg,Vendargues,wang da er gai,wndrgws,Вандарг,وندرگوس,旺达尔盖', 43.6583300, 3.9700000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49667, 'Vence', 'Vence', 'Vans,Venca,Vence,Vensa,Vença,Vintium,fyns,vu~ansu,wang ke,wans,Ванс,فينس,وانس,ヴァンス,旺克', 43.7225400, 7.1118300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49668, 'Venasque', 'Venasque', 'Venasca,Venask,Venasque,Vindasca,fu na si qu e,wnsqw,Венаск,ونسقو,弗纳斯屈厄', 43.9921400, 5.1489500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49669, 'Venarey-les-Laumes', 'Venarey-les-Laumes', 'Venare-Le-Lom,Venare-le-Lom,Venarey,Venarey-les-Laumes,wei na lei lai luo mei,Венаре-Ле-Лом,Венаре-ле-Лом,وناری‌له‌لوم,韦纳雷莱洛梅', 47.5420200, 4.4602200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49670, 'Venansault', 'Venansault', 'Venansault', 46.6851600, -1.5141500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49671, 'Vémars', 'Vemars', 'Vemar,Vemars,Vémars,fu ma er,Вемар,弗马尔', 49.0694200, 2.5664300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49672, 'Velleron', 'Velleron', 'Veleron,Velleron,fu lai long,wlrn,Веллерон,ولرن,弗莱龙', 43.9575900, 5.0287900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49673, 'Vélizy-Villacoublay', 'Velizy-Villacoublay', 'Velizi Vilakuble,Velizi-Villakuble,Velizy,Velizy-Villacoublay,Villacoublay,Vélizy,Vélizy-Villacoublay,bellijibillakubeulle,vu~eriji=vu~irakubure,wlyzy wyykwblh,Велизи Вилакубле,Велизи-Виллакубле,Велізі-Віллакубле,ولیزی ویئکوبله,ヴェリジー＝ヴィラクブレー,벨리지빌라쿠블레', 48.7819800, 2.1939500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49674, 'Vélines', 'Velines', 'Velines,Vélines', 44.8500000, 0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49675, 'Velaux', 'Velaux', 'Velaurs,Velaux,Velo,wei luo,Вело,韦洛', 43.5283900, 5.2566100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49676, 'Velars-sur-Ouche', 'Velars-sur-Ouche', 'Velars,Velars-sur-Ouche', 47.3196000, 4.9059400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49677, 'Velaines', 'Velaines', 'Velaines', 48.6988000, 5.3048300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49678, 'Velaine-en-Haye', 'Velaine-en-Haye', 'Velaine,Velaine-en-Haye,Velen-an-E,Velen-an-Eh,ai ai de qu wei lan,wlyn an hay,Велен-ан-Е,Велен-ан-Э,ولین ان های,艾埃地区韦兰', 48.7038300, 6.0212200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49679, 'Veigy-Foncenex', 'Veigy-Foncenex', 'Veigy,Veigy-Foncenex,Vezhi-Fonsneks,wygy fnknks,Вежі-Фонснекс,ویگی فنکنکس', 46.2704400, 6.2541900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49680, 'Veigné', 'Veigne', 'Veigne,Veigné,Ven''e,wei nie,Веньє,韦涅', 47.2855600, 0.7407900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49681, 'Vedène', 'Vedene', 'Veden,Vedena,Vedene,Vedenes,Vedène,Vedènes,fu dai na,wdn,Веден,ودن,弗代纳', 43.9774400, 4.9042800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49682, 'Vecoux', 'Vecoux', 'Vecoux,Veku,fu ku,wkwks,Веку,وکوکس,弗库', 47.9779700, 6.6365100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49683, 'Veauche', 'Veauche', 'Veauche,Vosh,wo ke,wywch,Вош,ویوچ,沃克', 45.5629400, 4.2903100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49684, 'Vayres', 'Vayres', 'Vayres', 44.9000000, -0.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49685, 'Vayrac', 'Vayrac', 'Vairac,Vayrac,Verak,wyrk,Верак,ویرک', 44.9533700, 1.7035800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49686, 'Vay', 'Vay', 'Gwez,Vay', 47.5546600, -1.7009500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49687, 'Vaux-sur-Seine', 'Vaux-sur-Seine', 'Vaux,Vaux-sur-Seine,Vo-sjur-Sen,wawks swr syn,Во-сюр-Сен,واوکس سور سین', 49.0127100, 1.9694200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49688, 'Vaux-sur-Mer', 'Vaux-sur-Mer', 'Vaux,Vaux-sur-Mer,Vo syur Mer,Vo-sjur-Mer,bin hai wo,wawks swr mrsy,Во-сюр-Мер,Վո սյուր Մեր,واوکس سور مرسی,滨海沃', 45.6460600, -1.0584100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49689, 'Vaux-le-Pénil', 'Vaux-le-Penil', 'Vaux,Vaux-le-Penil,Vaux-le-Pénil,Vo-le-Penij,wawks lh pnyl,Во-ле-Пений,Во-ле-Пеній,واوکس له پنیل', 48.5280300, 2.6916500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49690, 'Vaux-en-Bugey', 'Vaux-en-Bugey', 'Vaux,Vaux-en-Bugey,Vo an Byuze,Vo-an-Bjuzhe,bi re de qu wo,fwks-awn-bwghyy,wawks an bwgy,Во-ан-Бюже,Վո ան Բյուժե,فوكس-أون-بوغيي,واوکس ان بوگی,比热地区沃', 45.9271100, 5.3533600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49691, 'Vauvert', 'Vauvert', 'Vauvert', 43.6952900, 4.2770500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49692, 'Vauréal', 'Vaureal', 'Lieux,Vaureal,Vauréal,Voreal'',wo lei a,Вореаль,沃雷阿', 49.0333300, 2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49693, 'Vaumoise', 'Vaumoise', 'Vomuaz,wawmys,wo mu wa si,Вомуаз,واومیس,沃穆瓦斯', 49.2352500, 2.9807700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49694, 'Vaulx-Vraucourt', 'Vaulx-Vraucourt', 'Vaulx,Vaulx-Vraucourt', 50.1491000, 2.9083000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49695, 'Vaulx-Milieu', 'Vaulx-Milieu', 'Vaulx-Milieu', 45.6122600, 5.1810000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49696, 'Vaulx-en-Velin', 'Vaulx-en-Velin', 'Vaulx,Vaulx-en-Velin,Vo-an-Velen,Vol an Velen,boangbellaeng,vu~o=an=vuran,ww an wwln,Во-ан-Велен,Вол ан Велен,وو آن وولن,ヴォー＝アン＝ヴラン,보앙벨랭', 45.7818000, 4.9208500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49697, 'Vaulnaveys-le-Haut', 'Vaulnaveys-le-Haut', 'Vaulnaveys,Vaulnaveys-le-Haut,Vol''navej-le-O,Vonave-le-O,wawlnwys lh hwt,wo er na wei lai ao,Вольнавей-ле-О,Вонаве-ле-О,واولنویس له هوت,沃尔纳韦莱奥', 45.1169600, 5.8125700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49698, 'Vaulnaveys-le-Bas', 'Vaulnaveys-le-Bas', 'Vaulnaveys,Vaulnaveys-le-Bas', 45.1002000, 5.8253200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49699, 'Vaujours', 'Vaujours', 'Vaujours', 48.9302200, 2.5711000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49700, 'Vauhallan', 'Vauhallan', 'Vauhallan,Voallan,wawhln,wo a lang,Воаллан,واوهلن,沃阿朗', 48.7335400, 2.2027700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49701, 'Vaugrigneuse', 'Vaugrigneuse', 'Vaugrigneuse,Vogrin''ez,wawgrygnws,wo ge li ni e si,Вогриньез,Вогриньєз,واوگریگنوس,沃格里尼厄斯', 48.6026300, 2.1221800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49702, 'Vaugneray', 'Vaugneray', 'Vaugneray', 45.7371700, 4.6587300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49703, 'Vaudry', 'Vaudry', 'Vaudry,Vodri,wo de li,Водри,Водрі,沃德里', 48.8413000, -0.8530900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49704, 'Vaudelnay', 'Vaudelnay', 'Vaudelenay,Vaudelnay', 47.1381300, -0.2067700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49705, 'Vaucresson', 'Vaucresson', 'Vallis Crisonis,Vaucresson,Vokresson,vu~okureson,wawkrsn,wo ke lei song,Вокрессон,واوکرسن,ヴォークレソン,沃克雷松', 48.8407800, 2.1565200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49706, 'Vaucouleurs', 'Vaucouleurs', 'Vaucouleurs', 48.6031300, 5.6665900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49707, 'Vauchrétien', 'Vauchretien', 'Vauchretien,Vauchrétien', 47.3323400, -0.4767800, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49708, 'Vatan', 'Vatan', 'Vastan,Vasten,Vatan,Watan', 47.0744700, 1.8101000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49709, 'Vassy', 'Vassy', 'Vassy', 48.8538100, -0.6748500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49710, 'Vasselay', 'Vasselay', 'Vasselay', 47.1568600, 2.3896300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49711, 'Vasles', 'Vasles', 'Val'',Vasles,wsls,Валь,وسلس', 46.5761800, -0.0263800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49712, 'Varzy', 'Varzy', 'Varzy', 47.3581000, 3.3861900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49713, 'Vars', 'Vars', 'Vars', 45.7625600, 0.1247800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49714, 'Varreddes', 'Varreddes', 'Varreddes', 49.0030500, 2.9278800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49715, 'Varrains', 'Varrains', 'Varrains,Varren,wa er lan,wryns,Варрен,ورینس,瓦尔兰', 47.2230500, -0.0603300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49716, 'Varois-et-Chaignot', 'Varois-et-Chaignot', 'Varois,Varois-et-Chaignot', 47.3505900, 5.1283800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49717, 'Varilhes', 'Varilhes', 'Varilhes', 43.0451400, 1.6280500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49718, 'Varetz', 'Varetz', 'Varets,Varetz', 45.1939000, 1.4512100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49719, 'Varennes-sur-Seine', 'Varennes-sur-Seine', 'Varennes,Varennes-sur-Seine', 48.3730400, 2.9257100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49720, 'Varennes-sur-Loire', 'Varennes-sur-Loire', 'Varenn-sjur-Luar,Varennes,Varennes-sur-Loire,lu wa er he pan wa lei nei,wrns swr lyr,Варенн-сюр-Луар,ورنس سور لیر,卢瓦尔河畔瓦雷内', 47.2376700, 0.0535000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49721, 'Varennes-sur-Allier', 'Varennes-sur-Allier', 'Varen-sjur-Al''e,Varenas,Varenn-sjur-Al''e,Varennae super Elaverim,Varennes,Varennes-sur-Allier,a li ye he pan wa lei nei,Варен-сюр-Алье,Варенн-сюр-Алье,Варенн-сюр-Альє,ورنس سور علیر,阿利耶河畔瓦雷内', 46.3147200, 3.3984600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49722, 'Varennes-Saint-Sauveur', 'Varennes-Saint-Sauveur', 'Varenn-Sen-Sover,Varenne-Saint-Sauveur,Varennes,Varennes-Saint-Sauveur,Varennes-sur-Sevron,wa lei ne sheng suo wo er,Варенн-Сен-Совер,وارن‌سن‌سوور,瓦雷訥聖索沃爾', 46.4822600, 5.2434900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49723, 'Varennes-le-Grand', 'Varennes-le-Grand', 'Varennes,Varennes-le-Grand', 46.7186800, 4.8687200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49724, 'Varennes-Jarcy', 'Varennes-Jarcy', 'Varen-Zharsi,Varenn-Zharsi,Varennes-Jarcy,wa lei na ya er xi,wrns jrky,Варен-Жарси,Варенн-Жарси,Варенн-Жарсі,ورنس جرکی,瓦雷纳雅尔西', 48.6791400, 2.5615200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49725, 'Varengeville-sur-Mer', 'Varengeville-sur-Mer', 'Varanzhvil''-sjur-Mer,Varengeville,Varengeville-sur-Mer,wrngwyl swr mrsy,Варанжвиль-сюр-Мер,Варанжвіль-сюр-Мер,ورنگویل سور مرسی', 49.9047500, 0.9947900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49726, 'Varangéville', 'Varangeville', 'Varangeville,Varangéville,Varanzhevil'',wa lang re wei er,wrngwyl,Варанжевиль,Варанжевіль,ورنگویل,瓦朗热维尔', 48.6360500, 6.3211200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49727, 'Varades', 'Varades', 'Gwared,Varades', 47.3845800, -1.0284200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49728, 'Vanves', 'Vanves', 'Vanv,Vanve,Vanves,vu~an''vu,wang fu,wanw,Ванв,Ванве,وانو,ヴァンヴ,旺夫', 48.8234500, 2.2902500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49729, 'Vannes', 'Vannes', 'Dariorigum,Gwened,VNE,Van,Vanas,Vann,Vannes,Venetens,ban,fan,vani,vu~an''nu,wa ne,wns,Ван,Ванн,באניס,ואן,فان,ونس,ვანი,ヴァンヌ,瓦讷,반', 47.6666700, -2.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49730, 'Vandœuvre-lès-Nancy', 'Vandoeuvre-les-Nancy', 'Vandevr le Nansi,Vandevr-le-Nansi,Vandjovr-le-Nansi,Vandoeuvre,Vandoeuvre-les-Nancy,Vandoeuvre-lès-Nancy,bangdoebeuleuleunangsi,vu~ando~uvuru=re=nanshi,wandwr lnansy,wang duo e fu er lai nan xi,Вандевр ле Нанси,Вандевр-ле-Нанси,Вандевр-ле-Нансі,Вандёвр-ле-Нанси,واندور لنانسی,ヴァンドゥーヴル＝レ＝ナンシー,旺多厄夫尔莱南西,방되브르르낭시', 48.6500000, 6.1833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49731, 'Vals-près-le-Puy', 'Vals-pres-le-Puy', 'Vals,Vals-pres-le-Puy,Vals-près-le-Puy', 45.0315500, 3.8778700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49732, 'Vals-les-Bains', 'Vals-les-Bains', 'Val''-le-Ben,Val''s-le-Ben,Vals,Vals daus Banhs,Vals-les-Bains,fals lyh byns,wa er lai ban,Валь-ле-Бен,Вальс-ле-Бен,فالس ليه بينس,瓦尔莱班', 44.6638700, 4.3686100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49733, 'Valros', 'Valros', 'Valros', 43.4195600, 3.3650600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49734, 'Valréas', 'Valreas', 'Val''reas,Valreas,Valréas,Vaurias,Vauriàs,falrys,vu~arureasu,wa er lei a,Вальреас,فالريس,ヴァルレアス,瓦尔雷阿', 44.3836600, 4.9908400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49735, 'Valras-Plage', 'Valras-Plage', 'Valras,Valras-Plage', 43.2480800, 3.2903200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49736, 'Valognes', 'Valognes', 'Valognes,Valon'',Valoni,falwghns,wa luo gai,Βαλόνι,Валонь,فالوغنس,瓦洛盖', 49.5088100, -1.4704700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49737, 'Valmont', 'Valmont', 'Valmont', 49.0838300, 6.6994200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49738, 'Valmondois', 'Valmondois', 'Val''mondua,Valmondois,falmndwys,wa er meng du wa,Вальмондуа,فالمندويس,瓦尔蒙杜瓦', 49.0973000, 2.1899600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49739, 'Vallon-en-Sully', 'Vallon-en-Sully', 'Vallon,Vallon-en-Sully', 46.5367600, 2.6082800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49740, 'Valloire', 'Valloire', 'Valloire,Valluar,Varouere,Vârouère,XVR,falwyr,Валлуар,فالوير', 45.1656500, 6.4299400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49741, 'Valliquerville', 'Valliquerville', 'Valliquerville', 49.6138500, 0.6870300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49742, 'Vallières', 'Vallieres', 'Vallieres,Vallières', 45.9026200, 5.9381100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49743, 'Vallet', 'Vallet', 'Gwaled,Vallet', 47.1622700, -1.2660700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49744, 'Valleroy', 'Valleroy', 'Valleroy', 49.2090500, 5.9383000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49745, 'Valleraugue', 'Valleraugue', 'Val''rog,Valerauga,Valleraugue,Vallerog,wa lei luo gai,Валлерог,Вальрог,瓦勒罗盖', 44.0813000, 3.6415400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49746, 'Valleiry', 'Valleiry', 'Valleiry', 46.1111700, 5.9726700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49747, 'Vallauris', 'Vallauris', 'Valauria,Vallauris,Valloris,Valori,Valàuria,balloli,falwrys,vu~arorisu,wa luo li,wlwry,Валлорис,Валлоріс,Валори,فالوريس,ولوری,ヴァロリス,瓦洛里,발로리', 43.5780300, 7.0545100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49748, 'Vallabrègues', 'Vallabregues', 'Vallabregues,Vallabrègues', 43.8530700, 4.6266200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49749, 'Valframbert', 'Valframbert', 'Valframbert', 48.4646500, 0.1082800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49750, 'Valfin-lès-Saint-Claude', 'Valfin-les-Saint-Claude', 'Condat-Montagne,Valfin,Valfin-les-Saint-Claude,Valfin-lès-Saint-Claude', 46.4375800, 5.8551300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49751, 'Valff', 'Valff', 'Falaba,Val''ff,Valf,Valff,Walf,falf,wa er,walf,Вальфф,فالف,والف,瓦尔', 48.4204500, 7.5195400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49752, 'Valergues', 'Valergues', 'Valergues', 43.6682400, 4.0612400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49753, 'Valenton', 'Valenton', 'Valanton,Valenton,wa lang tong,Валантон,瓦朗通', 48.7452700, 2.4646700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49754, 'Valentigney', 'Valentigney', 'Valentigney', 47.4638800, 6.8316800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49755, 'Valensole', 'Valensole', 'Valansol,Valansol'',Valencola,Valensole,Valençòla,Valesole,wa lang suo er,Валансол,Валансоль,瓦朗索尔', 43.8379900, 5.9832300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49756, 'Valencin', 'Valencin', 'Valencin', 45.6128500, 5.0156500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49757, 'Valenciennes', 'Valenciennes', 'Gorad Valans''en,Valans''en,Valans''enn,Valansien,Valansjen,Valansjenas,Valencenae,Valencianas,Valenciennes,Valincyinne,XVS,ballangsien,falnsyan,vu~aranshien''nu,wa lang xie ne,wal xng seiyn,walnsyn,wlansyn,Βαλανσιέν,Валансиен,Валансьен,Валансьенн,Валансьєнн,Валансјен,Горад Валансьен,ואלנסיין,فالنسيان,والنسین,ولانسین,วาล็องเซียน,ヴァランシエンヌ,瓦朗謝訥,발랑시엔', 50.3500000, 3.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49758, 'Valence-sur-Baïse', 'Valence-sur-Baise', 'Valence,Valence-sur-Baise,Valence-sur-Baïse', 43.8827000, 0.3811100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49759, 'Valence', 'Valence', 'VAF,Valenca,Valence,Valencia,Valença,valansa,vu~aransu,वलांस,ヴァランス', 44.9333300, 4.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49760, 'Valence', 'Valence', 'Valence,Valence-d''Agen', 44.1082300, 0.8910100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49761, 'Valençay', 'Valencay', 'Valanse,Valencay,Valençay,vu~aranse,wa lang sai,Валансе,ヴァランセ,瓦朗赛', 47.1620700, 1.5685200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49762, 'Valdoie', 'Valdoie', 'Val''dua,Valdoie,vu~arudowa,wa er du wa,Вальдуа,ヴァルドワ,瓦尔杜瓦', 47.6679900, 6.8444600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49763, 'Val-d’Isère', 'Val-d''Isere', 'Laval,Val d Isere,Val d''Isere,Val d''Isère,Val''d''Izer,Val-d''Isere,Val-d''Isère,Val-d’Isère,Валь д''Изер', 45.4497200, 6.9781000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49764, 'Valbonne', 'Valbonne', 'QVI,Val''bonn,Vaubona,falbwny,wa er bang,Вальбонн,فالبوني,瓦尔邦', 43.6329200, 6.9991100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49765, 'Valady', 'Valady', 'Valady', 44.4563300, 2.4274600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49766, 'Vaivre-et-Montoille', 'Vaivre-et-Montoille', 'Vaivre,Vaivre-et-Montoille,Vevr-e-Montual'',Vevr-eh-Montoj,Вевр-е-Монтуаль,Вевр-э-Монтой', 47.6302100, 6.1036200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49767, 'Vaison-la-Romaine', 'Vaison-la-Romaine', 'Vaison,Vaison-la-Romaine,Vasio,Vezon-la-Romen,vu~ezon=ra=romenu,wei song la luo mai na,Везон-ла-Ромен,ཝེ་ཟོང་ལ་རོ་མེ་ནེ།,ヴェゾン＝ラ＝ロメーヌ,韦松拉罗迈纳', 44.2389600, 5.0746100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49768, 'Vaires-sur-Marne', 'Vaires-sur-Marne', 'Vaires,Vaires-sur-Marne,Ver-sjur-Marn,Вер-сюр-Марн', 48.8764900, 2.6398200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49769, 'Vairé', 'Vaire', 'Vaire,Vairé,Varie,Varié', 46.6010400, -1.7553800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49770, 'Vailly-sur-Aisne', 'Vailly-sur-Aisne', 'Vai-sjur-En,Vailly,Vailly-sur-Aisne,Vaji-sjur-Ehn,ai na he pan wa yi,Вайи-сюр-Эн,Ваї-сюр-Ен,埃纳河畔瓦伊', 49.4083400, 3.5163100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49771, 'Vailhauquès', 'Vailhauques', 'Vailhauques,Vailhauquès', 43.6715900, 3.7204200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49772, 'Vaiges', 'Vaiges', 'Vaiges', 48.0402500, -0.4751300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49773, 'Vagney', 'Vagney', 'Vagney,Van''e,wa gai yi,Ванье,Ваньє,瓦盖伊', 48.0062900, 6.7174000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49774, 'Vacquiers', 'Vacquiers', 'Vacquiers', 43.7766700, 1.4812700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49775, 'Vacqueyras', 'Vacqueyras', 'Vacquevras,Vacqueyras', 44.1373500, 4.9828100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49776, 'Vacon', 'Vacon', 'Vacon', 48.6686500, 5.6002400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49777, 'Vaas', 'Vaas', 'Vaas', 47.6689000, 0.3167700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49778, 'Uzès', 'Uzes', 'Firmin-les-Uzes,Firmin-les-Uzés,Juzes,Ucetia,Uses,Usès,Uzes,Uzes-la-Montagne,Uzès,Uzès-la-Montagne,yu ze,yuzesu,Юзес,ユゼス,于泽', 44.0136200, 4.4152900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49779, 'Uzerche', 'Uzerche', 'Faubourg-Egalite,Faubourg-Egalité,Juzersh,Userca,Usercha,Usèrcha,Uzerche,yu ze er ke,yuzerushu,Юзерш,ユゼルシュ,于泽尔克', 45.4212000, 1.5639500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49780, 'Uzemain', 'Uzemain', 'Juzmen,Uzemain,yu ze man,Юзмен,于泽曼', 48.0857200, 6.3444300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49781, 'Uzein', 'Uzein', 'Juzen,Usenh,Uzein,yu zan,Юзен,于赞', 43.4000000, -0.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49782, 'Uxem', 'Uxem', 'Uxem', 51.0217000, 2.4837600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49783, 'Uxegney', 'Uxegney', 'Iksene,Juksen''e,Uxegney,Uxegny,yu ke sai gai yi,Иксење,Юксенье,Юксеньє,于克塞盖伊', 48.1965200, 6.3697100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49784, 'Ustaritz', 'Ustaritz', 'Justaris,Justarits,Marat-sur-Nive,Ustarits,Ustaritz,Ustariz,Ustàrits,Ustáriz,Uztaritze,yu si ta li ci,Юстарис,Юстаритс,于斯塔里茨', 43.3965000, -1.4560300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49785, 'Usson-en-Forez', 'Usson-en-Forez', 'Jusson-an-Fore,Ucon,Usson,Usson-en-Forez,Uçon,fu lei de qu yu song,Юссон-ан-Форе,福雷地区于松', 45.3879700, 3.9377200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49786, 'Usson-du-Poitou', 'Usson-du-Poitou', 'Jusson-dju-Puatu,Usson,Usson-du-Poitou,yu song di pu wa tu,Юссон-дю-Пуату,于松迪普瓦图', 46.2778200, 0.5281600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49787, 'Ussel', 'Ussel', '', 45.5500000, 2.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49788, 'Ussac', 'Ussac', '', 45.1938900, 1.5133700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49789, 'Us', 'Us', 'Us', 49.1000000, 1.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49790, 'Urzy', 'Urzy', 'Urzy', 47.0487700, 3.2029500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49791, 'Urville-Nacqueville', 'Urville-Nacqueville', 'Jurvil''-Nakevil'',Urville,Urville-Hague,Urville-Nacqueville,yu er wei er na qu ai wei er,Юрвиль-Накевиль,Юрвіль-Накевіль,于尔维尔纳屈埃维尔', 49.6744400, -1.7366400, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49792, 'Urt', 'Urt', 'Ahurti,Jurt,Liberte,Liberté,Urt,yu er,Юрт,于尔', 43.4900900, -1.2974400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49793, 'Urrugne', 'Urrugne', 'Jurrjun'',Urrugne,Urruna,Urrunha,Urruña,awrwny,yu er lu ni,Юррюнь,أوروني,于尔吕尼', 43.3636100, -1.6992100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49794, 'Urmatt', 'Urmatt', '', 48.5275200, 7.3256500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49795, 'Uriménil', 'Urimenil', 'Jurimenij,Urimenil,Uriménil,yu li mo ni,Юримений,Юрименій,于里默尼', 48.1007900, 6.4004600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49796, 'Urcuit', 'Urcuit', 'Jurkjui,Jurkjuit,Le Laurier,Urcueit,Urcuit,Urketa,yu er qu yi,Юркюи,Юркюит,Юркюї,于尔屈伊', 43.4859400, -1.3366800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49797, 'Upie', 'Upie', 'Upie', 44.8035900, 4.9777800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49798, 'Unverre', 'Unverre', 'Enverr,Unverre,an wei er,Енверр,安韦尔', 48.1982900, 1.0920700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49799, 'Unieux', 'Unieux', 'Jun''e,Unieux,Unieux-Firminy,yu ni e,Юньє,于尼厄', 45.4004000, 4.2781200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49800, 'Ungersheim', 'Ungersheim', '', 47.8784800, 7.3079700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49801, 'Ully-Saint-Georges', 'Ully-Saint-Georges', 'Julli-Sen-Zhorzh,Ully,Ully-Saint-Georges,yu li sheng ruo er re,Юллі-Сен-Жорж,于利圣若尔热', 49.2791400, 2.2809400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49802, 'Ugine', 'Ugine', 'Juzhin,Ugena,Ugine,Ugines,Южин', 45.7508400, 6.4161100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49803, 'Uffholtz', 'Uffholtz', 'Juffol''c,Uffholz,Юффольц', 47.8208200, 7.1778500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49804, 'Uckange', 'Uckange', 'Jukanzh,UEckingen,Uckange,akynj,yu kang ge,ywkng,Ückingen,Юканж,اکینج,یوکنگ,于康格', 49.3030400, 6.1492000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49805, 'Uchaux', 'Uchaux', 'Jusho,Uchau,Uchaux,achaks,yu shao,yusho,ywchwks,Юшо,اچاکس,یوچوکس,ユショー,于绍', 44.2166700, 4.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49806, 'Uchaud', 'Uchaud', 'Uchaud', 43.7585700, 4.2684300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49807, 'Uberach', 'Uberach', 'Uberach,Ueberach', 48.8491900, 7.6293800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49808, 'Turretot', 'Turretot', 'Turretot', 49.6092300, 0.2342200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49809, 'Turckheim', 'Turckheim', 'Tjurkajm,Tjurkem,Tuerkheim,Turckheim,Türkheim,te~yurukuaimu,twrqhyym,Тюркайм,Тюркем,טורקהיים,テュルクアイム', 48.0874800, 7.2770700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49810, 'Tullins', 'Tullins', 'Tjullen,Tullins,di lan,Тюллен,蒂兰', 45.2986100, 5.4860900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49811, 'Tulle', 'Tulle', 'Byen Tulle,Til,Tjul'',Tula,Tulle,Tutela,Tyll,XTU,churu,di lei,twil,Тил,Тюль,チュール,蒂勒,튈', 45.2666700, 1.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49812, 'Tulette', 'Tulette', 'Tjulett,Tuleta,Tulette,di lai te,Тюлетт,蒂莱特', 44.2852700, 4.9296000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49813, 'Tuffé', 'Tuffe', 'Tuffe,Tuffé', 48.1131900, 0.5155100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49814, 'Tucquegnieux', 'Tucquegnieux', 'Tjuken''e,Tjuken''jo,Tucquegnieux,di qu ai ni e,Тюкенье,Тюкеньё,Тюкеньє,蒂屈埃尼厄', 49.3014000, 5.8824700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49815, 'Truyes', 'Truyes', 'Truyes', 47.2729900, 0.8517900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49816, 'Trun', 'Trun', 'Trun', 48.8426800, 0.0326800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49817, 'Truchtersheim', 'Truchtersheim', '', 48.6631300, 7.6075200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49818, 'Troyes', 'Troyes', 'QYR,Trecae,Troa,Troias,Troua,Troyes,Trua,Tròias,te lu wa,teulua,thraw,torowa,trwa,trwa  fransh,Τρουά,Троа,Труа,טרואה,تروئے,تروا,تروا، فرانسه,ทรัว,トロワ,特鲁瓦,트루아', 48.3000000, 4.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49819, 'Trouy', 'Trouy', 'Trouy', 47.0115300, 2.3601800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49820, 'Trouville-sur-Mer', 'Trouville-sur-Mer', 'Deauville-Trouville,Trouville,Trouville-sur-Mer,Truvil''-Sjur-Mer,Truvil''-sjur-Mer,bin hai te lu wei er,toruvu~iru=shuru=meru,trwbyl,Трувиль-Сюр-Мер,Трувиль-сюр-Мер,Трувіль-сюр-Мер,טרוביל,トルヴィル＝シュル＝メール,滨海特鲁维尔', 49.3657000, 0.0804100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49821, 'Trouillas', 'Trouillas', 'Trouillas', 42.6108900, 2.8082100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49822, 'Trosly-Breuil', 'Trosly-Breuil', 'Trosli-Brej,Trosly,Trosly-Breuil,te luo si li bu lei yi,Трослі-Брей,特罗斯利布勒伊', 49.4000000, 2.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49823, 'Tronville-en-Barrois', 'Tronville-en-Barrois', 'Tronville,Tronville-en-Barrois', 48.7197700, 5.2780800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49824, 'Troissereux', 'Troissereux', 'Troissereux,Truassere,te lu wa se lei,Труассере,特鲁瓦瑟勒', 49.4799800, 2.0448500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49825, 'Troarn', 'Troarn', 'Troarn,te luo a er en,Троарн,特罗阿尔恩', 49.1783500, -0.1816900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49826, 'Trizay', 'Trizay', 'Trizay,Trize,te li ze,Тризе,特里泽', 45.8827600, -0.8969700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49827, 'Trith-Saint-Léger', 'Trith-Saint-Leger', 'Tri-Sen-Lezhe,Trit-Sen-Lezhe,Trith,Trith-Saint-Leger,Trith-Saint-Léger,te li sheng lai re,Три-Сен-Леже,Трит-Сен-Леже,特里圣莱热', 50.3166700, 3.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49828, 'Trilport', 'Trilport', 'Trijpor,Trilport,Трийпор,Трійпор', 48.9568500, 2.9507600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49829, 'Triguères', 'Trigueres', 'Trigueres,Triguères', 47.9397500, 2.9857000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49830, 'Trignac', 'Trignac', 'Trignac,Trin''jak,Trinieg,te li ni ya ke,Триньяк,特里尼亚克', 47.3180900, -2.1889500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49831, 'Trieux', 'Trieux', 'Trieux', 49.3244600, 5.9364400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49832, 'Triel-sur-Seine', 'Triel-sur-Seine', 'Triel,Triel''-sjur-Sen,Triel-sur-Seine,toriru=shuru=senu,Триель-сюр-Сен,Трієль-сюр-Сен,トリール＝シュル＝セーヌ', 48.9781800, 2.0074300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49833, 'Trie-Château', 'Trie-Chateau', 'Trie-Chateau,Trie-Château,Trij-Shato,Trye-sur-Troesne,te li ye sha tuo,Трій-Шато,特里耶沙托', 49.2854000, 1.8212900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49834, 'Trie-sur-Baïse', 'Trie-sur-Baise', 'Trie', 43.3333300, 0.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49835, 'Tricot', 'Tricot', 'Tricot', 49.5608000, 2.5878900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49836, 'Triaize', 'Triaize', 'Triez,te li ai ze,Тріез,特里艾泽', 46.3926500, -1.1978500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49837, 'Trévoux', 'Trevoux', 'Trevoux,Trevu,Trivurtium,Trévoux,te lai wu,trwwks,tryfw,Треву,Տրևու,ترووکس,تريفو,特莱武', 45.9411100, 4.7672700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49838, 'Trévou-Tréguignec', 'Trevou-Treguignec', 'An Trevou,An Trevoù,Trevou-Treguignec,Trevu-Tregin''ek,Trévou-Tréguignec,te lei wu te lei ji gai ke,trww trgwygnk,Треву-Трегиньек,Треву-Трегіньєк,تروو ترگویگنک,特雷武特雷吉盖克', 48.8186900, -3.3413200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49839, 'Trévol', 'Trevol', 'Trevol,Trévol', 46.6288600, 3.3045700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49840, 'Trévé', 'Treve', 'Treve,Trévé', 48.2114700, -2.7931700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49841, 'Trets', 'Trets', 'Tre,Trec,Trets,Tretz,te lei,Тре,Трец,特雷', 43.4481800, 5.6832800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49842, 'Tressin', 'Tressin', 'Tressin', 50.6175000, 3.1935400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49843, 'Tresses', 'Tresses', 'Trecas,Tress,Tresses,Treças,te lei sai,Тресс,特雷塞', 44.8478100, -0.4629600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49844, 'Tresserve', 'Tresserve', 'Tresserv,Tresserve,Tresserves,Трессерв', 45.6778500, 5.9015300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49845, 'Tressange', 'Tressange', 'Tressange', 49.4053800, 5.9813800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49846, 'Tresques', 'Tresques', 'Tresques', 44.1068900, 4.5873900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49847, 'Tresbœuf', 'Tresboeuf', 'Tresboeuf,Trevo', 47.8833300, -1.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49848, 'Trept', 'Trept', 'Tre,Trep,Trept,te lei pu,Тре,Треп,特雷普', 45.6856100, 5.3161700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49849, 'Tréon', 'Treon', 'Treon,Tréon,te lei weng,trywn,Треон,ترئون,特雷翁', 48.6770900, 1.3266800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49850, 'Trémuson', 'Tremuson', 'Tremjuzon,Tremuson,Tremuzon,Trémuson,te lei mi song,trmwswn,Тремюзон,ترموسون,特雷米松', 48.5232500, -2.8483300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49851, 'Tréméven', 'Tremeven', 'Tremeven,Tremeven-Kemperle,Tréméven', 47.9000000, -3.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49852, 'Trémery', 'Tremery', 'Tremery,Trémery', 49.2445900, 6.2235700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49853, 'Trémentines', 'Trementines', 'Tremantin,Trementines,Trémentines,te lei mang di nei,trmntyans,Тремантін,ترمنتیانس,特雷芒蒂内', 47.1235700, -0.7850000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49854, 'Tremblay-en-France', 'Tremblay-en-France', 'Tramble an Frans,Tramble-an-Frans,Tremblay-sans-Culottes,fu lang si de qu te lang bu lai,teulangbeulleangpeulangseu,toranbure=an=furansu,tramblh anfrans,Трамбле ан Франс,Трамбле-ан-Франс,ترامبله آنفرانس,トランブレ＝アン＝フランス,弗朗斯地区特朗布莱,트랑블레앙프랑스', 48.9495600, 2.5684000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49855, 'Tremblay', 'Tremblay', 'Kreneg,Tremblay', 48.4221600, -1.4755500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49856, 'Trélon', 'Trelon', 'Trelon,Trélon,te lei long,trlwn,Трелон,ترلون,特雷隆', 50.0580500, 4.1020000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49857, 'Trélivan', 'Trelivan', 'Trelivan,Trélivan', 48.4319800, -2.1174800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49858, 'Trélissac', 'Trelissac', 'Trelhissac,Trelissac,Trelissak,Trélissac,te lei li sa ke,trlyask,Трелиссак,Треліссак,ترلیاسک,特雷利萨克', 45.1976600, 0.7861500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49859, 'Trélévern', 'Trelevern', 'Trelevern,Trelêvern,Trélévern', 48.8107100, -3.3714100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49860, 'Trélazé', 'Trelaze', 'Trelaze,Trélazé,te lei la ze,trlaz,Трелазе,ترلاز,特雷拉泽', 47.4456500, -0.4654000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49861, 'Treize-Septiers', 'Treize-Septiers', 'Treize-Septiers,Trez-Set''e,te lei ze sai pu di ye er,Трез-Сетьє,特雷泽塞普蒂耶尔', 46.9852400, -1.2292100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49862, 'Treillières', 'Treillieres', 'Treillieres,Treillières,Trejer,Trelier,Treliera,te lei li ai,Трейєр,特雷利埃', 47.3306000, -1.6191800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49863, 'Treignac', 'Treignac', 'Trainhac,Treignac,Treignac-la-Montagne,Tren''jak,Trenhac,te lei ni ya ke,Треньяк,特雷尼亚克', 45.5355800, 1.7962100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49864, 'Trégunc', 'Tregunc', 'Tregenk,Tregon,Tregunc,Trégunc,te lei gan ke,toregan,trgwnk,Трегенк,ترگونک,トレガン,特雷甘克', 47.8500000, -3.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49865, 'Tréguier', 'Treguier', 'Landreger,Trecorium,Treg''e,Tregie,Treguier,Tréguier,te lei ji ye,toregie,trgwyyr,Трегие,Трегье,Трегіє,ترگویئر,トレギエ,特雷吉耶', 48.7833300, -3.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49866, 'Trégastel', 'Tregastel', 'Tregastel,Tregastel-Bourg,Trégastel', 48.8166700, -3.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49867, 'Treffléan', 'Trefflean', 'Trefflean,Treffléan,Trevlean,te lei fu lai ang,Треффлеан,特雷夫莱昂', 47.6816300, -2.6128700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49868, 'Treffiagat', 'Treffiagat', 'Treff''jaga,Treffjaga,Triagad,te lei fei a jia,Треффьяга,Треффяга,特雷菲阿加', 47.8166700, -4.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49869, 'Trédarzec', 'Tredarzec', 'Tredarzec,Tredarzeg,Trédarzec', 48.7858300, -3.2010000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49870, 'Trébeurden', 'Trebeurden', 'Treberdan,Trebeurden,Trebjorden,Trébeurden,te lei bo er dang,Требердан,Требёрден,特雷伯尔当', 48.7666700, -3.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49871, 'Trèbes', 'Trebes', 'Treb,Trebes,Trèbes,te lei bei,trbs,Треб,تربس,特雷贝', 43.2106400, 2.4416500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49872, 'Trappes', 'Trappes', 'Trap,Trapp,Trappes,te la pu,teulapeu,tkhp,torappu,trp,Трап,Трапп,تخپ,ترپ,トラップ,特拉普,트라프', 48.7741300, 2.0178100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49873, 'Trans-en-Provence', 'Trans-en-Provence', 'Tran-an-Provans,Tranc,Trans,Trans-en-Provence,Tranç,pu luo wang si de qu te lang,Тран-ан-Прованс,普罗旺斯地区特朗', 43.5050000, 6.4857100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49874, 'Trangé', 'Trange', 'Trange,Trangé', 48.0270600, 0.1105400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49875, 'Tramoyes', 'Tramoyes', 'Tramoyes,Tramua,sramwy  ayn,te la shao yue,Трамуа,Տրամուա,سراموي، أين,特拉绍约', 45.8762700, 4.9656800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49876, 'Traînou', 'Trainou', 'Trainou,Traînou,Trenu,te lai nu,Трену,特赖努', 47.9735300, 2.1039900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49877, 'Tracy-le-Mont', 'Tracy-le-Mont', 'Tracy,Tracy-le-Mont,Trasi-le-Mon,te la xi lai meng,Трасі-ле-Мон,特拉西莱蒙', 49.4722500, 3.0093900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49878, 'Touvre', 'Touvre', 'Touvre,Tuvr,tu fu er,Тувр,图夫尔', 45.6666700, 0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49879, 'Touvois', 'Touvois', 'Tolveia,Tolvez,Touvois,Tuvua,to~uvu~owa,tu wa,Тувуа,トゥーヴォワ,图瓦', 46.9020800, -1.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49880, 'Toutlemonde', 'Toutlemonde', 'Toutlemonde,Tutlemond,tu te lai meng de,Тутлемонд,图特莱蒙德', 47.0548800, -0.7654800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49881, 'Toutainville', 'Toutainville', 'Toutainville', 49.3647400, 0.4653800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49882, 'Toussieu', 'Toussieu', 'Toussieu', 45.6537100, 4.9861800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49883, 'Toury', 'Toury', 'Toury', 48.1939700, 1.9348400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49884, 'Tourville-sur-Odon', 'Tourville-sur-Odon', 'Tourville,Tourville-sur-Odon', 49.1415400, -0.5012800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49885, 'Tourville-sur-Arques', 'Tourville-sur-Arques', 'Tourville,Tourville-sur-Arques', 49.8592600, 1.1023800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49886, 'Tourville-la-Rivière', 'Tourville-la-Riviere', 'Tourville,Tourville-la-Riviere,Tourville-la-Rivière,Turvil''-la-Riv''er,Turvil''-la-River,Турвиль-ла-Ривьер,Турвіль-ла-Ривєр', 49.3278200, 1.1055100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49887, 'Tourves', 'Tourves', 'Torvas,Tourves,Turv,tu er wo,Турв,图尔沃', 43.4077600, 5.9241500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49888, 'Tours-sur-Marne', 'Tours-sur-Marne', 'Tours,Tours-sur-Marne', 49.0487300, 4.1206000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49889, 'Tours', 'Tours', 'Augusta-Turonum,Gorad Tur,La Reunion-du-Nord,La Réunion-du-Nord,TUF,Teurgn,Tors,Tour,Tours,Tur,Tura,Turas,Turones,Tūra,Tūras,to~uru,tu er,tuleu,tura,twr,Τουρ,Горад Тур,Тур,Տուր,טור,تور,ٹورز,टुर,तुर,ტური,トゥール,图尔,투르', 47.3833300, 0.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49890, 'Tourrette-Levens', 'Tourrette-Levens', 'Sa Torreta,Torreta de Levens,Tourrette,Tourrette-Levens,Turret-Levans,Turrett-Levans,Turricula Leventiorum,tu er lei te lei wang,twryt lyfyns,Туррет-Леванс,Турретт-Леванс,توريت ليفينس,图尔雷特勒旺', 43.7874600, 7.2736400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49891, 'Tourouvre', 'Tourouvre', 'Tourouvre', 48.5895100, 0.6525300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49892, 'Tournus', 'Tournus', 'Tinortium,Tournus,Tournus-Lacrost,Turniu,Turnju,to~urunyu,Турню,トゥールニュ', 46.5675800, 4.9057400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49893, 'Tournon-Saint-Martin', 'Tournon-Saint-Martin', 'Tournon,Tournon-Saint-Martin,Turnon-Sen-Marten,tu er nong sheng ma er tan,Турнон-Сен-Мартен,图尔农圣马尔坦', 46.7342300, 0.9551400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49894, 'Tournon-sur-Rhône', 'Tournon-sur-Rhone', 'Tornon,Tournon-sur-Rhone,Tournon-sur-Rhône,Turnon-sjur-Ron,Turnonium,luo ne he pan tu er nong,to~urunon=shuru=ronu,Турнон-сюр-Рон,トゥルノン＝シュル＝ローヌ,罗讷河畔图尔农', 45.0666700, 4.8333300, 'FR', '2017-03-14', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49895, 'Tournes', 'Tournes', 'Tournes', 49.7970000, 4.6385600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49896, 'Tournehem-sur-la-Hem', 'Tournehem-sur-la-Hem', 'Tournan-su-la-Hem,Turneem-sjur-la-Am,ai mu he pan tu er ne mu,twrnyhym sw la hym,Турнеем-сюр-ла-Ам,تورنيهيم سو لا هيم,埃姆河畔图尔讷姆', 50.8000000, 2.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49897, 'Tournefeuille', 'Tournefeuille', 'Brumaire,Frimaire,Fructidor,Germinal,Messidor,Nivose,Nivôse,Prairial,Tornafuelha,Tornafuèlha,Tournefeuille,Turnefej,Turnefjoj,Turnfej,Vendemiaire,Vendémiaire,Ventose,Ventôse,to~urunufuiyu,tu er nei fu yi er,tuleunpoeyu,twrnfwy,Турнефей,Турнефёй,Турнфеј,تورنفوی,トゥルヌフイユ,图尔内弗伊尔,투른푀유', 43.5887200, 1.3192200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49898, 'Tournay', 'Tournay', 'Tournay', 43.1843800, 0.2445400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49899, 'Tournan-en-Brie', 'Tournan-en-Brie', 'Tournan,Tournan-en-Brie,Tournan-l''Union,Turnan-an-Bri,Турнан-ан-Бри,Турнан-ан-Брі', 48.7414600, 2.7720000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49900, 'Tourlaville', 'Tourlaville', 'Tourlaville,Turlavil'',tu er la wei er,Турлавиль,Турлавіль,图尔拉维尔', 49.6382900, -1.5663900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49901, 'Tourrettes-sur-Loup', 'Tourrettes-sur-Loup', 'Torretas,Torretas de Lop,Tourette,Turret-sjur-Lu,Turrett-sjur-Lu,lu he pan tu er lei tai,twryts swr lwb,Туррет-сюр-Лу,Турретт-сюр-Лу,توريتس سور لوب,卢河畔图尔雷泰', 43.7166700, 7.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49902, 'Tourcoing', 'Tourcoing', 'Terkoeje,Toerkonje,Tourco,Tourcoing,Turcundium,Turkoan,Turkuehn,Turkuen,XTN,to~urukowan,tu er kuan,tuleukuaeng,turk wng,twrkwan,twrkwyngh,Туркоан,Туркуен,Туркуэн,توركوينغ,تورکوآن,ٹورکونگ,ตูร์กวง,トゥールコワン,图尔宽,투르쿠앵', 50.7239100, 3.1611700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49903, 'Tourbes', 'Tourbes', 'Tourbes', 43.4461500, 3.3785200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49904, 'Touquin', 'Touquin', 'Touquin', 48.7349800, 3.0122200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49905, 'Touques', 'Touques', 'Touques', 49.3444300, 0.1021800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49906, 'Toulouse', 'Toulouse', 'Gorad Tuluza,Lapangan Terbang Blagnac,TLS,Tolosa,Tolosa Okzitania,Tolosa de Francia,Tolosa de Llenguadoc,Toloxa,Toloza,Toulouse,Toulouz,Tołoxa,Tuluz,Tuluza,Tuluzae,Tuluzo,Tulūza,Tólóza,to~uruzu,tu lu zi,tu lus,tullujeu,tulujha,tulus,tuluza,twlwz,Τουλούζ,Горад Тулуза,Тулузæ,Тулуза,Тулузо,Թուլուզ,טולוז,تولوز,तुलूज़,तुलूझ,ਟੁਲੂਜ਼,துலூஸ்,ടൂളൂസ്,ตูลูซ,ཊོའུ་ལོའུ་སེ།,ტულუზა,ቱሉዝ,トゥールーズ,圖盧茲,圖魯茲,툴루즈', 43.6042600, 1.4436700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49907, 'Toulouges', 'Toulouges', 'Toluges,Toulouges,Tuluzh,tu lu re,Тулуж,图卢热', 42.6696100, 2.8300800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49908, 'Toulon-sur-Arroux', 'Toulon-sur-Arroux', 'Bel-Air-sur-Arroux,Toulon,Toulon-sur-Arroux,Tulon-sjur-Arru,Тулон-сюр-Арру', 46.6934500, 4.1386900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49909, 'Toulon-sur-Allier', 'Toulon-sur-Allier', 'Mont-la-Loi,Tolonium,Toulon,Tulon-sjur-Al''e,a li ye he pan tu long,Тулон-сюр-Алье,Тулон-сюр-Альє,阿利耶河畔图隆', 46.5184500, 3.3598900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49910, 'Toulon', 'Toulon', 'Gorad Tulon,Port-la-Montagne,TLN,Telo Martius,Tolo,Tolon,Tolone,Toló,Tolón,Toulon,Toulon-sur-Mer,Tulon,Tulona,Tulonas,Tuluni,to~uron,tu lng,tu lun,tulam,tullong,tulom,tulon,twlwn,Τουλόν,Горад Тулон,Тулон,Տուլոն,טולון,تولون,طولون,तुलाँ,तुलों,துலோன்,ടൂളാൻ,ตูลง,ტულონი,トゥーロン,土伦,土倫,툴롱', 43.1244200, 5.9283600, 'FR', '2017-05-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49911, 'Toulenne', 'Toulenne', 'Toulenne', 44.5566500, -0.2632800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49912, 'Toulaud', 'Toulaud', 'Toulaud', 44.9000900, 4.8172100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49913, 'Toul', 'Toul', 'La Moselle,La Paix,Toul,Tul,Tul'',Tulis,Tullum,to~uru,tu lei,tul,twl,twl  frans,twl  fransh,Тул,Туль,تول,تول، فرانس,تول، فرانسه,ቱል,トゥール,图勒,툴', 48.6833300, 5.9000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49914, 'Toufflers', 'Toufflers', 'Toufflers,Tuffle,tu fu lai,Туффле,图夫莱', 50.6603900, 3.2335800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49915, 'Toucy', 'Toucy', 'Toucy,Tusi,Tutiacum,tu xi,Туси,Тусі,图西', 47.7360200, 3.2950200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49916, 'Tôtes', 'Totes', 'Totes,Tôtes', 49.6809100, 1.0464900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49917, 'Tossiat', 'Tossiat', 'Tossiat', 46.1398900, 5.3113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49918, 'Tosse', 'Tosse', 'Tosse', 43.6891600, -1.3326200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49919, 'Torreilles', 'Torreilles', 'Torreilles', 42.7543300, 2.9929200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49920, 'Torigni-sur-Vire', 'Torigni-sur-Vire', 'Torigneium,Torigni,Torigni-sur-Vire,Torigny,Torigny-sur-Vire,Torin''i-sjur-Vir,wei er he pan tuo li ni,Ториньи-сюр-Вир,Ториньї-сюр-Вір,维尔河畔托里尼', 49.0370200, -0.9821400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49921, 'Torfou', 'Torfou', 'Torfou', 47.0368200, -1.1163500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49922, 'Torcy', 'Torcy', '', 48.8500000, 2.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49923, 'Torcy', 'Torcy', 'Torcy', 46.7685700, 4.4533300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49924, 'Torcé', 'Torce', 'Torce,Torcé,Tourc''heg', 48.0612000, -1.2670800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49925, 'Tonquédec', 'Tonquedec', 'Tonkedeg,Tonkedek,Tonquedec,Tonquédec,tong qu ai dai ke,Тонкедек,通屈埃代克', 48.6688600, -3.3971200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49926, 'Tonnerre', 'Tonnerre', 'Tonnerre', 47.8562800, 3.9736900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49927, 'Tonneins', 'Tonneins', 'Tonens,Tonneins,Tonneins-la-Montagne,Tonnen,tonneng,tuo nan,Тоннен,托南,톤넹', 44.3920600, 0.3124100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49928, 'Tonnay-Charente', 'Tonnay-Charente', 'Tonnay Charenta,Tonnay-Charente,Tonne-Sharant,tuo nai sha lang te,Тонне-Шарант,托奈沙朗特', 45.9490000, -0.8935000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49929, 'Tonnay-Boutonne', 'Tonnay-Boutonne', 'Tonnay-Boutonne,Tonne-Buton,Tonne-Butonn,tuo nai bu tong,Тонне-Бутон,Тонне-Бутонн,托奈布通', 45.9681500, -0.7084700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49930, 'Tomblaine', 'Tomblaine', 'Tomblaine,Tomblen,tong bu lan,Томблен,通布兰', 48.6833300, 6.2131200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49931, 'Tollevast', 'Tollevast', 'Tollevast', 49.5743700, -1.6274600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49932, 'Tocane-Saint-Apre', 'Tocane-Saint-Apre', 'Barra-sur-Dronne,Sent Abre,Tocane,Tocane-Saint-Apre,Tocane-Saint-Âpre,Tocuno,Tokan-Sent-Apr,Tooane-Saint-Abre,tuo kang sheng a pu er,Токан-Сент-Апр,托康圣阿普尔', 45.2540400, 0.4968200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49933, 'Tinténiac', 'Tinteniac', 'Tenten''jak,Tinteniac,Tinteniacum,Tintenieg,Tinténiac,tan tai ni a ke,Тентеньяк,坦泰尼阿克', 48.3286000, -1.8363000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49934, 'Tinqueux', 'Tinqueux', 'Tenke,Tinqueux,tan qu e,Тенке,坦屈厄', 49.2500000, 3.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49935, 'Tinchebray', 'Tinchebray', 'Tenercebrai,Tenerchebraium,Tenshebre,Tinchebray,tan xie bu lai,Теншебре,坦谢布赖', 48.7643700, -0.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49936, 'Tilques', 'Tilques', 'Til''k,Tilques,di yi ke,tylkyws,Тильк,Тільк,تيلكيوس,蒂伊克', 50.7771200, 2.1994800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49937, 'Tilly-sur-Seulles', 'Tilly-sur-Seulles', 'Tii-sjur-Sel'',Tiji-sjur-Sjol'',Tilly,Tilly-sur-Seulles,se lai he pan di li,Тии-сюр-Сель,Тийи-сюр-Сёль,Тії-сюр-Сель,瑟莱河畔蒂利', 49.1759800, -0.6260500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49938, 'Tilloy-lès-Mofflaines', 'Tilloy-les-Mofflaines', 'Tilloy,Tilloy-anx-Fosses', 50.2751900, 2.8145600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49939, 'Tillières-sur-Avre', 'Tillieres-sur-Avre', 'Tillieres,Tillieres-sur-Avre,Tillières,Tillières-sur-Avre', 48.7558500, 1.0538800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49940, 'Tillières', 'Tillieres', 'Tillieres,Tilliers,Tillières', 47.1439700, -1.1633400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49941, 'Tillé', 'Tille', 'Tille,Tillé', 49.4641500, 2.1103800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49942, 'Tigy', 'Tigy', 'Tigy,Tizhi,di ji,Тіжі,蒂吉', 47.7936500, 2.1976700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49943, 'Tignieu-Jameyzieu', 'Tignieu-Jameyzieu', 'Tignieu,Tignieu-Jameyzieu', 45.7356400, 5.1804600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49944, 'Tignes', 'Tignes', 'TGF,Tignes,Tignes-sur-Boisses,Tin'',Tiniae,tyn,Тинь,Тінь,טין', 45.4960400, 6.9246300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49945, 'Tigery', 'Tigery', 'Tigery,Tizheri,di re li,Тижери,Тіжері,蒂热里', 48.6425700, 2.5077900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49946, 'Tiffauges', 'Tiffauges', 'Tifauges,Tiffauges,Tiffozh,di fu re,Тіффож,蒂福热', 47.0108000, -1.1099900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49947, 'Tiercé', 'Tierce', 'Tierce,Tiercé', 47.6158700, -0.4660900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49948, 'Thyez', 'Thyez', '', 46.0824900, 6.5377700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49949, 'Thury-Harcourt', 'Thury-Harcourt', 'Thury,Thury-Harcourt,Tjuri-Arkur,di li a er ku er,Тюри-Аркур,Тюрі-Аркур,蒂里阿尔库尔', 48.9843400, -0.4751900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49950, 'Thurins', 'Thurins', 'Thurins,Thurins-le-Francais,Thurins-le-Français', 45.6809300, 4.6396800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49951, 'Thuré', 'Thure', 'Thure,Thuré', 46.8322100, 0.4579700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49952, 'Thun-Saint-Amand', 'Thun-Saint-Amand', 'Thun,Thun-Saint-Amand', 50.4727600, 3.4511500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49953, 'Thumeries', 'Thumeries', 'Thumeries', 50.4766200, 3.0550000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49954, 'Thuir', 'Thuir', 'Thuir,Tjuir,Tuir,Tuïr,di yi,Тюир,Тюїр,蒂伊', 42.6329000, 2.7547100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49955, 'Thueyts', 'Thueyts', 'Thueyts', 44.6782800, 4.2191600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49956, 'Thuellin', 'Thuellin', 'Thuellin', 45.6396400, 5.5084000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49957, 'Thourotte', 'Thourotte', 'Thourotte,Turott,tu luo te,Туротт,图罗特', 49.4759100, 2.8821000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49958, 'Thouars', 'Thouars', 'Thouars,Toarcium,Tuar,tu a er,Туар,圖阿爾', 46.9760200, -0.2150700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49959, 'Thouaré-sur-Loire', 'Thouare-sur-Loire', 'Tarvieg,Tauriacus,Thouare,Thouare-sur-Loire,Thouaré,Thouaré-sur-Loire,Tuare-sjur-Luar,lu wa er he pan tu a lei,Туаре-сюр-Луар,卢瓦尔河畔图阿雷', 47.2689300, -1.4383400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49960, 'Thouarcé', 'Thouarce', 'Thouarce,Thouarcé,Tuarse,tu a er sai,Туарсе,图阿尔塞', 47.2673400, -0.5018600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49961, 'Thorigny-sur-Oreuse', 'Thorigny-sur-Oreuse', 'Thorigny,Thorigny-sur-Oreuse,Torin''i-sjur-Orez,ao lei si he pan tuo li ni,Ториньи-сюр-Орез,Ториньї-сюр-Орез,奥勒斯河畔托里尼', 48.2929700, 3.4012800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49962, 'Thorigny-sur-Marne', 'Thorigny-sur-Marne', 'Thorigny,Thorigny-sur-Marne', 48.8868900, 2.7180600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49963, 'Thorigné-sur-Dué', 'Thorigne-sur-Due', 'Thorigne,Thorigne-sur-Due,Thorigné,Thorigné-sur-Dué', 48.0392000, 0.5355400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49964, 'Thorigné', 'Thorigne', 'Thorigne,Thorigné', 46.2914900, -0.2512200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49965, 'Thorens-Glières', 'Thorens-Glieres', 'Thorens,Thorens-Glieres,Thorens-Glières,Toran-Gl''er,Торан-Гльєр', 45.9947500, 6.2458100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49966, 'Thonon-les-Bains', 'Thonon-les-Bains', 'Thonon,Thonon-les-Bains,Thononum,Tonon,Tonon Le Ben,Tonon le Benas,Tonon-le-Bain,Tonon-le-Ben,XTS,tonon=re=ban,tononglebaeng,twnwn lbn,Τονόν-λε-Μπαιν,Тонон Ле Бен,Тонон-ле-Бен,تونون لبن,トノン＝レ＝バン,토농레뱅', 46.3666700, 6.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49967, 'Thônes', 'Thones', 'Thonesia,Ton,Тон', 45.8812300, 6.3257200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49968, 'Thomery', 'Thomery', 'Thomery,Tomeri,Томери,Томері', 48.4072300, 2.7885200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49969, 'Thoissey', 'Thoissey', 'Thoissey,Tuase,Tuasse,tu wa sai,twasy,Туассе,Տուասե,تواسي,图瓦塞', 46.1740500, 4.8033100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49970, 'Thoiry', 'Thoiry', 'Thoiry', 48.8671500, 1.7976000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49971, 'Thoiry', 'Thoiry', 'Thoiry', 46.2376200, 5.9811100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49972, 'Thizy-les-Bourgs', 'Thizy-les-Bourgs', 'Thizy', 46.0299500, 4.3129900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49973, 'Thiviers', 'Thiviers', 'Thiviers,Tiv''e,Tive,Tivier,di wei ye er,Тивье,Тівє,蒂维耶尔', 45.4154200, 0.9196300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49974, 'Thiverval-Grignon', 'Thiverval-Grignon', 'Thivernal-Grignon,Thiverval,Thiverval-Grignon,Tiverval''-Grin''on,Тиверваль-Гриньон,Тіверваль-Гриньон', 48.8496400, 1.9172900, 'FR', '2016-11-26', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49975, 'Thiverny', 'Thiverny', 'Thiverny,Tiverni,di wei er ni,Тіверні,蒂韦尔尼', 49.2518000, 2.4360900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49976, 'Thise', 'Thise', 'Thise', 47.2848600, 6.0812700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49977, 'Thiron Gardais', 'Thiron Gardais', 'Thiron', 48.3166700, 0.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49978, 'Thionville', 'Thionville', 'Diddenuewen,Diedenhofen,T''jonvil'',T''onvil'',Theudonevilla,Thionville,Tionvil,di yong wei er,tion''vu~iru,tiongbil,tywn wyl,tywn‌wyl,Тионвил,Тьйонвиль,Тьйонвіль,Тьонвиль,تیون ویل,تیون‌ویل,ティオンヴィル,蒂永维尔,티옹빌', 49.3666700, 6.1666700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49979, 'Thilouze', 'Thilouze', 'Thilouze', 47.2241500, 0.5796300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49980, 'Thilay', 'Thilay', 'Thilay', 49.8734500, 4.8077200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49981, 'Thil', 'Thil', 'Thil', 49.4746400, 5.9078900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49982, 'Thil', 'Thil', 'Thil', 45.8141600, 5.0219000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49983, 'Thierville-sur-Meuse', 'Thierville-sur-Meuse', 'T''ervil''-sjur-Mez,Thierville,Thierville-sur-Meuse,mo si he pan di ye er wei er,Тьервиль-сюр-Мез,Тьєрвіль-сюр-Мез,默斯河畔蒂耶尔维尔', 49.1705000, 5.3526600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49984, 'Thiers-sur-Thève', 'Thiers-sur-Theve', 'T''er-sjur-Tev,Thiers,Thiers-sur-Theve,Thiers-sur-Thève,tai fu he pan di ye er,Тьєр-сюр-Тев,泰夫河畔蒂耶尔', 49.1525200, 2.5705100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49985, 'Thiers', 'Thiers', 'Thiers,Tiern,Tièrn', 45.8500000, 3.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49986, 'Thiberville', 'Thiberville', 'Thiberville', 49.1376800, 0.4550200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49987, 'Thiant', 'Thiant', 'T''jan,Thiant,di ang,Тьян,蒂昂', 50.3048000, 3.4479600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49988, 'Thiais', 'Thiais', 'T''e,Thiais,Tje,di ai,tie,tyh,tyh  fransh,Тье,Тьє,Тје,تیه,تیه، فرانسه,ティエ,蒂艾,티에', 48.7649600, 2.3961000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49989, 'Thézan-lès-Béziers', 'Thezan-les-Beziers', 'Thezan,Thézan', 43.4166700, 3.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49990, 'Théza', 'Theza', 'Tesa,Tesà,Theza,Thèza,Théza', 42.6379700, 2.9510800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49991, 'Theys', 'Theys', 'Theys', 45.3013600, 5.9953400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49992, 'Thésée', 'Thesee', 'Thesee,Thezee,Thésée,Thézée', 47.3234500, 1.3088200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49993, 'Thérouanne', 'Therouanne', 'Teruan,Teruann,Terwoan,Therouanne,Therwane,Thérouanne,tai lu a ne,thyrwan,Теруан,Теруанн,ثيروان,泰鲁阿讷', 50.6369500, 2.2583800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49994, 'Théoule-sur-Mer', 'Theoule-sur-Mer', 'Teul''-sjur-Mer,Teula de Mar,Theoule,Théoule,bin hai tai wu er,thywl swr myr,Теуль-сюр-Мер,ثيول سور مير,滨海泰乌尔', 43.5078000, 6.9408000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49995, 'Thenon', 'Thenon', 'Tenon,Thenon,tang weng,Тенон,唐翁', 45.1389700, 1.0721100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49996, 'Thénezay', 'Thenezay', 'Thenezay,Thénezay', 46.7187900, -0.0288300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49997, 'Thénac', 'Thenac', 'Thenac,Thénac', 45.6670500, -0.6534500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49998, 'Thélus', 'Thelus', 'Telju,Thelus,Thélus,tai lu,thylws,Телю,ثيلوس,泰吕', 50.3544100, 2.8014600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(49999, 'Theizé', 'Theize', 'Teze,Theize,Theizé,Тезе', 45.9402800, 4.6163400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50000, 'Theix', 'Theix', 'Te,Teiz,Theix,tai zhen,Те,泰镇', 47.6291600, -2.6518600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50001, 'Theillay', 'Theillay', 'Theillay', 47.3142900, 2.0402800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50002, 'Théding', 'Theding', 'Theding,Théding', 49.1294100, 6.8931500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50003, 'Thaon-les-Vosges', 'Thaon-les-Vosges', 'Taon-le-Vozh,Thaon,Thaon-les-Vosges,tang lai wo si re,Таон-ле-Вож,唐莱沃斯热', 48.2500000, 6.4166700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50004, 'Thaon', 'Thaon', 'Thaon', 49.2579600, -0.4560500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50005, 'Thann', 'Thann', 'Thann', 47.8166700, 7.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50006, 'Thairé', 'Thaire', 'Thaire,Thaire-d''Aunis,Thairé,Thairé-d’Aunis', 46.0734100, -1.0023000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50007, 'Teyran', 'Teyran', 'Teiran,Tejran,Teyran,tai lang,Тейран,泰朗', 43.6852800, 3.9288900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50008, 'Teting-sur-Nied', 'Teting-sur-Nied', 'Teting,Téting', 49.0500000, 6.6666700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50009, 'Téteghem', 'Teteghem', 'Teteghem,Téteghem', 51.0185900, 2.4445400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50010, 'Tessy-sur-Vire', 'Tessy-sur-Vire', 'Tessi-sjur-Vir,Tessy,Tessy-sur-Vire,Tessy-sur-ville,wei er he pan tai xi,Тесси-сюр-Вир,Тессі-сюр-Вір,维尔河畔泰西', 48.9738100, -1.0608700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50011, 'Tessé-la-Madeleine', 'Tesse-la-Madeleine', 'Tesse,Tessé', 48.5496300, -0.4252100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50012, 'Terville', 'Terville', 'Terville', 49.3471400, 6.1380200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50013, 'Terrasson-Lavilledieu', 'Terrasson-Lavilledieu', 'Terrasson,Terrasson e La Vila Dieu,Terrasson-Lavil''d''e,tai er la song la wei lai di e,Террассон-Лавильдье,Террассон-Лавільдьє,泰尔拉松拉维莱迪厄', 45.1301100, 1.3013600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50014, 'Ternay', 'Ternay', 'Ternay', 45.6083500, 4.8102400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50015, 'Tergnier', 'Tergnier', 'Tergnier,Tern''e,tai er ni ye,Тернье,Терньє,泰尔尼耶', 49.6560700, 3.3010700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50016, 'Tercis-les-Bains', 'Tercis-les-Bains', 'Tercis,Tercis-les-Bains', 43.6704800, -1.1073800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50017, 'Tercé', 'Terce', 'Terce,Tercé', 46.5166700, 0.5638600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50018, 'Tenteling', 'Tenteling', 'Tantelen,Tenteling,Tentelingen,tang tai lan,tntlyng,Тантелен,تنتلینگ,唐泰兰', 49.1242500, 6.9369200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50019, 'Tennie', 'Tennie', 'Tennie', 48.1076900, -0.0762600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50020, 'Tende', 'Tende', 'Tenda,Tende', 44.0857100, 7.5934000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50021, 'Tencin', 'Tencin', 'Tencin', 45.3095300, 5.9581800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50022, 'Tence', 'Tence', 'Tans,Tenca,Tence,Tença,tang ke,Танс,唐克', 45.1150300, 4.2916600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50023, 'Tenay', 'Tenay', 'Tenay,Tene,te nai,tynay,Тене,Տենե,تيناي,特奈', 45.9190000, 5.5104100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50024, 'Templeuve', 'Templeuve', 'Templeuve,Templeuve-en Pevele,Templeuve-en Pévele', 50.5233600, 3.1780900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50025, 'Templemars', 'Templemars', 'Tamplemar,Templemars,tang pu lei ma er,Тамплемар,唐普勒马尔', 50.5738700, 3.0543700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50026, 'Teloché', 'Teloche', 'Teloche,Teloché,Teloshe,Телоше', 47.8881900, 0.2708600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50027, 'Telgruc-sur-Mer', 'Telgruc-sur-Mer', 'Telgruc,Telgruc-sur-Mer,Terrug', 48.2333300, -4.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50028, 'Teillé', 'Teille', 'Teille,Teillé,Tilhieg', 47.4617000, -1.2781000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50029, 'Tavers', 'Tavers', 'Tave,Tavers,ta wei er,Таве,塔韦尔', 47.7592100, 1.6126700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50030, 'Taverny', 'Taverny', 'Taverni,Taverny,ta fu er ni,tabeleuni,tavu~eruni,twrny,Таверни,Таверні,تورنی,タヴェルニー,塔夫尔尼,타베르니', 49.0254200, 2.2169100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50031, 'Tavel', 'Tavel', 'Tavel', 44.0127000, 4.6983500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50032, 'Tavaux', 'Tavaux', 'Tavaux,Tavo,ta wo,Таво,塔沃', 47.0337600, 5.4050000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50033, 'Tauxigny', 'Tauxigny', 'Tauxigny', 47.2133700, 0.8347900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50034, 'Tauriac', 'Tauriac', '', 45.0491500, -0.5004800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50035, 'Taupont', 'Taupont', 'Talbont,Taupont', 47.9596100, -2.4393300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50036, 'Taulignan', 'Taulignan', 'Taulignan,Taulinhan,Tolin''jan,tuo li ni ang,Толіньян,托利尼昂', 44.4442500, 4.9797100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50037, 'Taulé', 'Taule', 'Taole,Taule,Taulé,Tole,tore,tuo lai,Толе,トレ,托莱', 48.6000000, -3.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50038, 'Tatinghem', 'Tatinghem', 'Tatinghem,Tatinghen', 50.7431700, 2.2072400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50039, 'Tassin-la-Demi-Lune', 'Tassin-la-Demi-Lune', 'Tassen-la-Demi-Ljun,Tassin,Tassin la Demi Lena,Tassin-la-Demi-Lune,Tassin-la-Lune,Tassin-la-Lûne,Тассен-ла-Демі-Люн', 45.7549900, 4.7881200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50040, 'Tartas', 'Tartas', 'Tartas,Tartàs,ta er ta,Тартас,塔尔塔', 43.8324800, -0.8089500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50041, 'Tarnos', 'Tarnos', 'Tarnos,Tarnose,Tarnòs,ta er nuo,Тарнос,塔尔诺', 43.5417000, -1.4628100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50042, 'Targon', 'Targon', 'Targon,ta er gong,Таргон,塔尔贡', 44.7349500, -0.2635100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50043, 'Tarbes', 'Tarbes', 'Tarb,Tarba,Tarbas,Tarbe,Tarbes,XTB,ta bu,taleubeu,tarb,tarubu,Ταρμπ,Тарб,تارب,ཊར་བེ།,タルブ,塔布,타르브', 43.2333300, 0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50044, 'Tarascon-sur-Ariège', 'Tarascon-sur-Ariege', 'Tarascon,Tarascon dArieja,Tarascon dArièja,Tarascon-Ussat,Tarascon-sur-Ariege,Tarascon-sur-Ariège,Taraskon-sjur-Ar''ezh,Taraskon-sjur-Arezh,a li ye ge he pan ta la si kong,Тараскон-сюр-Арьеж,Тараскон-сюр-Арєж,阿里耶格河畔塔拉斯孔', 42.8454500, 1.6033200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50045, 'Tarascon', 'Tarascon', 'Barra,Marat,Tarasco,Tarascon,Tarascona,Tarascuni,Tarascó,Tarascón,Taraskon,ta la si kong,tarasukon,Тараскон,タラスコン,塔拉斯孔', 43.8058300, 4.6602800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50046, 'Tarare', 'Tarare', 'Tarare', 45.8976100, 4.4327200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50047, 'Taradeau', 'Taradeau', 'Taradeau', 43.4542800, 6.4277600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50048, 'Taponnat-Fleurignac', 'Taponnat-Fleurignac', 'Taponac e Florinhac,Taponna-Flerin''jak,Taponna-Fljorin''jak,Taponnat,Taponnat-Fleurignac,ta bo na fu lei li ni ya ke,Тапонна-Флериньяк,Тапонна-Флёриньяк,塔波纳弗勒里尼亚克', 45.7786800, 0.4093200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50049, 'Tanneron', 'Tanneron', 'Tanneron', 43.5908300, 6.8749500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50050, 'Tanlay', 'Tanlay', 'Tanlay', 47.8448800, 4.0850400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50051, 'Taninges', 'Taninges', '', 46.1088300, 6.5923100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50052, 'Tancarville', 'Tancarville', 'Tancarville', 49.4855000, 0.4576500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50053, 'Taluyers', 'Taluyers', 'Taluyers', 45.6399100, 4.7219400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50054, 'Talmas', 'Talmas', 'Talmas', 50.0304900, 2.3255400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50055, 'Talloires', 'Talloires', 'Talloires,Talluar,Таллуар', 45.8403600, 6.2141600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50056, 'Tallende', 'Tallende', 'Tallende', 45.6712600, 3.1279900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50057, 'Tallard', 'Tallard', 'Talard,Talarn,Tallar,Tallard,ta la er,Таллар,塔拉尔', 44.4612800, 6.0550400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50058, 'Talensac', 'Talensac', 'Talansak,Talensac,Talenseg,ta lang sa ke,Талансак,塔朗萨克', 48.1084700, -1.9282900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50059, 'Talence', 'Talence', 'Talans,Talenca,Talence,Talença,ta lang si,tallangseu,taransu,tlans,Таланс,تلانس,タランス,塔朗斯,탈랑스', 44.8047700, -0.5954300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50060, 'Talant', 'Talant', 'Talan,Talant,ta lang,Талан,塔朗', 47.3369300, 5.0088800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50061, 'Talange', 'Talange', 'Talange,Talanzh,ta lang ge,talanzh,Таланж,تالانژ,塔朗格', 49.2366900, 6.1728200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50062, 'Taissy', 'Taissy', 'Tessi,tai xi,Тессі,泰西', 49.2150900, 4.0940600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50063, 'Taintrux', 'Taintrux', 'Taintrux,Tentrju,tan te lu,Тентрю,坦特吕', 48.2494400, 6.8996300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50064, 'Tain-l’Hermitage', 'Tain-l''Hermitage', 'Tain,Tain-l''Hermitage,Tain-l’Hermitage', 45.0721700, 4.8370800, 'FR', '2017-03-14', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50065, 'Taillecourt', 'Taillecourt', 'Taillecourt', 47.4952100, 6.8544200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50066, 'Taillades', 'Taillades', 'Lei Talhadas,Taillades,Tajad,tai la dai,Тайад,Таяд,泰拉代', 43.8359200, 5.0921600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50067, 'Taden', 'Taden', 'Taden', 48.4753000, -2.0194600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50068, 'Tacoignières', 'Tacoignieres', 'Tacoignieres,Tacoignières,Takuan''er,Такуаньер,Такуаньєр', 48.8361900, 1.6750100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50069, 'Tabanac', 'Tabanac', 'Coteau-Libre,Tabanac,Tabanak,Tavanac,ta ba na ke,Табанак,塔巴纳克', 44.7205900, -0.4051300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50070, 'Suze-la-Rousse', 'Suze-la-Rousse', 'Sjuz-la-Russ,Susa de Bolena,Susa la Rossa,Suze,Suze-la-Rousse,xu ci la lu si,Сюз-ла-Русс,叙兹拉鲁斯', 44.2878800, 4.8434600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50071, 'Sussargues', 'Sussargues', 'Sussargues', 43.7125000, 4.0031000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50072, 'Surzur', 'Surzur', 'Sjurzjur,Surzhur,Surzur,xu er ju,Сюрзюр,叙尔聚', 47.5785000, -2.6289200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50073, 'Sury-le-Comtal', 'Sury-le-Comtal', 'Sjuri-le-Kontal'',Sury,Sury-la-Chaux,Sury-le-Comtal,xu li lai kong ta,Сюрі-ле-Конталь,叙里莱孔塔', 45.5342000, 4.1864200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50074, 'Survilliers', 'Survilliers', 'Sjurvil''e,Survilliers,xu er wei li ye er,Сюрвилье,Сюрвільє,叙尔维利耶尔', 49.0971200, 2.5444900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50075, 'Surtainville', 'Surtainville', 'Surtainville', 49.4597700, -1.8129800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50076, 'Surgères', 'Surgeres', 'Sjurzher,Surgeres,Surgères,xu er re lei,Сюржер,叙尔热雷', 46.1082000, -0.7514800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50077, 'Suresnes', 'Suresnes', 'Siren,Sjuren,Suresnes,Surisna,shuren''nu,swilen,swrzn,syrn,xu lei ne,Сирен,Сюрен,סירן,سورزن,ซูว์แรน,シュレンヌ,敘雷訥,쉬렌', 48.8714300, 2.2292900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50078, 'Surbourg', 'Surbourg', 'Sjurbur,Suerburi,Surburg,Sürburi,ashtwrbwrg,swrbwrgh,xu er bu er,Сюрбур,اشتوربورگ,سوربورغ,叙尔布尔', 48.9100900, 7.8471600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50079, 'Sundhouse', 'Sundhouse', 'Sjunduz,Sundhausen,Sundhouse,Sundhuese,Sundhüse,sang du si,swndhws,zwndhaws,Сюндуз,زوندهاوس,سوندهوس,桑杜斯', 48.2514800, 7.6035900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50080, 'Sundhoffen', 'Sundhoffen', '', 48.0426300, 7.4132000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50081, 'Sumène', 'Sumene', 'Sjumen,Sumena,Sumene,Sumèna,Sumène,xu mei en,Сюмен,叙梅恩', 43.9805700, 3.7157500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50082, 'Sulniac', 'Sulniac', 'Sulniac,Sulnieg', 47.6737500, -2.5713600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50083, 'Sully-sur-Loire', 'Sully-sur-Loire', 'Sjulli-sjur-Luar,Soliacum,Sully,Sully-sur-Loire,luo ya er he pan xu li,shuri=shuru=rowaru,Сюлли-сюр-Луар,Сюллі-сюр-Луар,シュリー＝シュル＝ロワール,羅亞爾河畔敘利', 47.7637200, 2.3723800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50084, 'Suippes', 'Suippes', 'Sjuipp,Suippes,xu yi pei,Сюїпп,叙伊佩', 49.1288600, 4.5344600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50085, 'Suèvres', 'Suevres', 'Sjuevr,Suevres,Suèvres,xu ai fu lei,Сюевр,叙埃夫雷', 47.6665500, 1.4615300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50086, 'Sucy-en-Brie', 'Sucy-en-Brie', 'Sisi an Bri,Sjusi-an-Bri,Sucy,Sucy-en-Brie,bu li de qu xu xi,shushi=an=buri,swisiangbeuli,swsyan bry,Сиси ан Бри,Сюси-ан-Бри,Сюсі-ан-Брі,سوسیان بری,シュシー＝アン＝ブリ,布里地区叙西,쉬시앙브리', 48.7687200, 2.5347400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50087, 'Sucé-sur-Erdre', 'Suce-sur-Erdre', 'Sjuse-sjur-Erdr,Sucerum,Sulieg,ai er de er he pan xu sai,Сюсе-сюр-Ердр,埃尔德尔河畔叙塞', 47.3333300, -1.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50088, 'Strasbourg', 'Strasbourg', 'Argentoratum,Estrasborg,Estrasbou,Estrasburg,Estrasburgo,Estrasburgu,Gorad Strasbur,Lungsod ng Strasbourg,SXB,Sjtraasburg,Straasburch,Straasbuurich,Straatsburg,Strasborg,Strasborgh,Strasbourg,Strasbourgo,Strasbura,Strasburas,Strasburg,Strasburgo,Strasburgu,Strasburk,Strasburq,Strasbwrg,Strasbôrg,Strasbūra,Strasbūras,Strassborg,Strassbourg,Strassburg,Straszburg,Strazbur,Strazburg,Strazburgu,Straßborg,Straßburg,Strażburgu,Stroatsburg,Stroosburi,Stroossbuerg,Strossburg,Strǣtburg,astrasbwrg,s thra sbur,satarasabaraga,seuteulaseubuleu,si te la si bao,stiraspurk,strasabarga,strasaborga,strasaburga,strasbwrg,strasbwrgh,strsbwrg,sutorasuburu,Štrasburg,Štrasburk,Στρασβούργο,Горад Страсбур,Стразбур,Страсбург,Ստրասբուրգ,שטראסבורג,שטרסבורג,استراسبورگ,ستراسبورغ,ستراسبورگ,شٹراسبرگ,स्ट्रासबर्ग,स्त्रासबुर्ग,ਸਟਰਾਸਬਰਗ,સ્ટ્રાસબોર્ગ,ஸ்திராஸ்பூர்க்,സ്ട്രാസ്ബർഗ്,สทราซบูร์,སི་ཐི་རཱ་སི་བུར།,სტრასბური,ስትራዝቡርግ,ストラスブール,斯特拉斯堡,스트라스부르', 48.5839200, 7.7455300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50089, 'Stotzheim', 'Stotzheim', 'Stotzheim', 48.3782600, 7.4899700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50090, 'Stosswihr', 'Stosswihr', 'Stossvir,Stossweier,Stosswihr,Стоссвир,Стоссвір', 48.0510800, 7.1100100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50091, 'Stiring-Wendel', 'Stiring-Wendel', 'Steringen-Wendel,Stieringen-Wendel,Stiren-Vandel'',Stiren-Vendel'',Stiring-Wendel,Strying,Styring,Wendel,s teiy ring-wen del,si di lan wang dai,Стирен-Вандель,Стирен-Вендель,Стірен-Вендель,สเตียริง-เวนเดล,斯蒂兰旺代', 49.2000000, 6.9333300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50092, 'Still', 'Still', 'Still', 48.5498200, 7.4044400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50093, 'Stenay', 'Stenay', 'Stenay,Stene,si te nai,Стене,斯特奈', 49.4948900, 5.1860600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50094, 'Steinbourg', 'Steinbourg', 'Staiweri,Steinburg,Stenbur,ashtaynbwrg,si tan bu er,stynbwrgh,Стенбур,اشتاینبورگ,ستينبورغ,斯坦布尔', 48.7702800, 7.4135400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50095, 'Steinbach', 'Steinbach', '', 47.8214000, 7.1527900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50096, 'Steenwerck', 'Steenwerck', 'Steenverk,Steenwerck,Steenwerk,Stenverk,si teng wei ke,Стеенверк,Стенверк,斯滕韦克', 50.7019900, 2.7782900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50097, 'Steenvoorde', 'Steenvoorde', 'Steenvoord,Steenvoorde,Stenvord,Stêenvôorde,astnwwrdh,si teng fu de,Стеенвоорд,Стенворд,استنوورده,ستنووردے,斯滕福德', 50.8104600, 2.5824400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50098, 'Steene', 'Steene', 'Steen,Steene,Stene,si tai ne,Стеен,斯泰讷', 50.9522800, 2.3681300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50099, 'Steenbecque', 'Steenbecque', 'Steenbecque,Steenbek,Steenbeke,si tai bei ke,Стеенбек,斯泰贝克', 50.6742100, 2.4844200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50100, 'Stains', 'Stains', 'Stains,Sten,astn  fransh,seutaeng,si tan,sutan,Стен,استن، فرانسه,スタン,斯坦,스탱', 48.9500000, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50101, 'Staffelfelden', 'Staffelfelden', '', 47.8264700, 7.2523500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50102, 'Spycker', 'Spycker', 'Spycker', 50.9691500, 2.3218400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50103, 'Spicheren', 'Spicheren', 'Speicheren,Spicheren,Spieherer Burg', 49.1926600, 6.9672700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50104, 'Spézet', 'Spezet', 'Speied,Speze,Spezet,Spézet,si pei ze,supeze,Спезе,スペゼ,斯佩泽', 48.2000000, -3.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50105, 'Spéracèdes', 'Speracedes', 'Speracedes,Spéracèdes', 43.6436400, 6.8527900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50106, 'Spay', 'Spay', 'Spay', 47.9238400, 0.1525800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50107, 'Soyons', 'Soyons', 'Soyons', 44.8861300, 4.8505900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50108, 'Soyaux', 'Soyaux', 'Soyaux,Suajo,su wa ao,Суайо,苏瓦奥', 45.6500000, 0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50109, 'Souvigny', 'Souvigny', 'Souvigny,Suvin''i,su wei ni,Сувиньи,Сувіньї,苏维尼', 46.5335200, 3.1924700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50110, 'Soustons', 'Soustons', 'Soston,Soustons,Suston,su si tong,Сустон,苏斯通', 43.7532800, -1.3278000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50111, 'Soussans', 'Soussans', 'Soussans', 45.0561900, -0.6991600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50112, 'Sourzac', 'Sourzac', 'Sorzac,Sourzac,Surzak,su er zha ke,Сурзак,苏尔扎克', 45.0497800, 0.3959800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50113, 'Sours', 'Sours', 'Sours,Sur,su er,Сур,苏尔', 48.4104300, 1.5988900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50114, 'Sourdun', 'Sourdun', 'Sourdun', 48.5368800, 3.3520000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50115, 'Sourdeval', 'Sourdeval', 'Sourdeval,Surdeval'',su er de wa,Сурдеваль,苏尔德瓦', 48.7231200, -0.9222300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50116, 'Sourcieux-les-Mines', 'Sourcieux-les-Mines', 'Sourcieux,Sourcieux-les-Mines', 45.8056600, 4.6235800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50117, 'Souraïde', 'Souraide', 'Mendialte,Souraide,Souraïde,Suraid,Zuraide,su lai de,Сураид,Сураїд,苏赖德', 43.3415400, -1.4755900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50118, 'Souprosse', 'Souprosse', 'Souprosse', 43.7886900, -0.7103500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50119, 'Souppes-sur-Loing', 'Souppes-sur-Loing', 'Souppes,Souppes-sur-Loing,Supp-sjur-Luen,Супп-сюр-Луен', 48.1829700, 2.7352100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50120, 'Soumoulou', 'Soumoulou', 'Somolon,Sumulu,su mu lu,Сумулу,苏穆卢', 43.2666700, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50121, 'Soultz-sous-Forêts', 'Soultz-sous-Forets', 'Soultz,Soultz-sous-Forets,Soultz-sous-Forêts,Sul''c-su-Fore,Sulz unterm Wald,su er te su fu lei te,swltz sws fwryts,Сульц-су-Форе,سولتز سوس فوريتس,苏尔特苏福雷特', 48.9358600, 7.8830700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50122, 'Soultzmatt', 'Soultzmatt', 'Suizmatt,Sul''cmat,Sulzmatt,Сульцмат', 47.9618800, 7.2375900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50123, 'Soultz-Haut-Rhin', 'Soultz-Haut-Rhin', 'Soultz,Soultz-Haut-Rhin,Sul''c-O-Ren,Sulz,Сульц-О-Рен', 47.8874000, 7.2304200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50124, 'Soultzeren', 'Soultzeren', 'Soultzeren,Soultzern', 48.0621300, 7.1021400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50125, 'Soullans', 'Soullans', '', 46.7962400, -1.9010600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50126, 'Souligné-sous-Ballon', 'Souligne-sous-Ballon', 'Souligne,Souligne-sous-Ballon,Souligné,Souligné-sous-Ballon,Sulin''e-su-Ballon,Суліньє-су-Баллон', 48.1375800, 0.2357200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50127, 'Soulgé-sur-Ouette', 'Soulge-sur-Ouette', 'Soulge,Soulge-le-Bruant,Soulgé,Soulgé-le-Bruant,Sul''zhe-sjur-Uett,wu ai te he pan su er re,Сульже-сюр-Уетт,乌埃特河畔苏尔热', 48.0666700, -0.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50128, 'Soulaire-et-Bourg', 'Soulaire-et-Bourg', 'Soulaire,Soulaire-et-Bourg,Suler-e-Bur,su lai er he bu er,Сулер-е-Бур,苏莱尔和布尔', 47.5789600, -0.5523200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50129, 'Soulaines-sur-Aubance', 'Soulaines-sur-Aubance', 'Soulaines,Soulaines-sur-Aubance,Sulen-sjur-Obans,ao bang ke he pan su lai nei,Сулен-сюр-Обанс,奥邦克河畔苏莱内', 47.3638100, -0.5226500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50130, 'Soulac-sur-Mer', 'Soulac-sur-Mer', 'Solac,Soulac,Soulac-sur-Mer,Sulak-sjur-Mer,bin hai su la ke,Сулак-сюр-Мер,滨海苏拉克', 45.5106800, -1.1252400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50131, 'Souillac', 'Souillac', 'Souillac,Trente-un-Mai', 44.8972000, 1.4722400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50132, 'Soufflenheim', 'Soufflenheim', 'Sablono:TabelKapoLauCarta,Soufflenheim,Suefflum,Sufflenajm,Sufflenheim,Süfflum,su fu lei nan,sufuren''aimu,swflynhym,Ŝablono:TabelKapoLaŭĈarta,Суффленайм,سوفلينهيم,スフレンアイム,苏夫勒南', 48.8302600, 7.9626800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50133, 'Souffelweyersheim', 'Souffelweyersheim', 'Souffelweyersheim,Sueffelwirsche,Suffel''veersajm,Suffelweyersheim,Süffelwirsche,su fu er wei ai er sang,swfylwyrshym,Суффельвеерсайм,Суффельвеєрсайм,سوفيلويرشيم,苏弗尔韦埃尔桑', 48.6354000, 7.7414100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50134, 'Souesmes', 'Souesmes', 'Souesmes,Suem,su ai si mei,Суем,苏埃斯梅', 47.4563800, 2.1749500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50135, 'Soues', 'Soues', 'Soues', 43.2073600, 0.0987400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50136, 'Soudan', 'Soudan', 'Saoudan,Soudan', 47.7377700, -1.3056600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50137, 'Soucy', 'Soucy', 'Soucy', 48.2495600, 3.3238500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50138, 'Soucieu-en-Jarrest', 'Soucieu-en-Jarrest', 'Soucieu,Soucieu-en-Jarez,Soucieu-en-Jarrest', 45.6801700, 4.7033400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50139, 'Soucht', 'Soucht', 'Soucht', 48.9588800, 7.3348800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50140, 'Souchez', 'Souchez', 'Souchez,Sushe,su xie,swtshyz,Суше,سوتشيز,苏谢', 50.3929100, 2.7398400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50141, 'Soucelles', 'Soucelles', 'Soucelles,Susel'',su se lai,Сусель,苏瑟莱', 47.5684800, -0.4181900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50142, 'Soubise', 'Soubise', 'La Regeneration,La Regénération,Soubise', 45.9239500, -1.0093800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50143, 'Soual', 'Soual', 'Soual,Soual-et-lestap', 43.5553000, 2.1167900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50144, 'Sotteville-lès-Rouen', 'Sotteville-les-Rouen', 'Sottevil''-le-Ruan,Sotteville,Sotteville-les-Rouen,Sotteville-lès-Rouen,Sottvil''-le-Ruan,Sottville-les-Rouen,Sotvil le Ruan,soteubilleuluang,sottovu~iru=re=ruan,swtwwy lrwan,Сотвил ле Руан,Соттвиль-ле-Руан,Соттвіль-ле-Руан,Соттевиль-ле-Руан,سوتووی لروآن,ソットヴィル＝レ＝ルーアン,소트빌르루앙', 49.4097200, 1.0900500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50145, 'Sottevast', 'Sottevast', 'Sottevast,Sottva,suo te wa si,Соттва,索特瓦斯', 49.5237400, -1.5916900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50146, 'Sospel', 'Sospel', 'Hospitellum,Sospel,Sospel'',Sospello,Sospèl,Susper,sosuperu,suo si pei,swsbyl,Соспель,سوسبيل,ソスペル,索斯佩', 43.8784700, 7.4484000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50147, 'Sornay', 'Sornay', 'Sornay', 46.6302300, 5.1799900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50148, 'Sorigny', 'Sorigny', 'Sorigny,Sorin''i,suo li ni,Сориньї,索里尼', 47.2432900, 0.6952000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50149, 'Sorgues', 'Sorgues', 'Sorgues', 44.0102300, 4.8738100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50150, 'Sorges', 'Sorges', 'Sorges,Sorjas,Sorzh,Surges,Sòrges,Sòrjas,suo er re,Сорж,索尔热', 45.3056300, 0.8732800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50151, 'Sorèze', 'Soreze', 'Soreze,Sorèze', 43.4524100, 2.0679900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50152, 'Sorel-Moussel', 'Sorel-Moussel', 'Montagne-du-Droit-de-l''Homme,Sorel''-Mussel'',Sorel-Moussel,suo lei mu sai,Сорель-Муссель,索雷穆塞', 48.8339100, 1.3669900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50153, 'Sorède', 'Sorede', 'Sored,Sorede,Sorède,Sureda,suo lei de,Соред,索雷德', 42.5306900, 2.9570800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50154, 'Sorbiers', 'Sorbiers', 'Sorbier,Sorbiers', 45.4881500, 4.4493300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50155, 'Soorts-Hossegor', 'Soorts-Hossegor', 'Soorts,Soorts-Hossegor,Soorts-Hossegort,Soorts-Ossegor,Sort-Osgor,Sorts e Ossagor,Sòrts e Òssagòr,soru=osugoru,suo ao er te ao se ge,Соортс-Оссегор,Сорт-Осгор,ソール＝オスゴール,索奥尔特奥瑟戈', 43.6649000, -1.3971700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50156, 'Sonzay', 'Sonzay', 'Sonzay', 47.5268700, 0.4620300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50157, 'Sonnaz', 'Sonnaz', 'Sonna,Sonnaz,Sunacum,Сонна', 45.6216000, 5.9184000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50158, 'Sonnay', 'Sonnay', 'Sonnay', 45.3557000, 4.9063700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50159, 'Songeons', 'Songeons', 'Songeons,Sonjon,Sonzhon,song rong,Сонжон,松容', 49.5491600, 1.8536100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50160, 'Sonchamp', 'Sonchamp', 'Sonchamp,Sonsham,Соншам', 48.5759000, 1.8775300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50161, 'Sommières', 'Sommieres', 'Someire,Somm''er,Sommer,Sommieres,Sommières,suo mi ai,Соммьер,Соммєр,索米埃', 43.7853400, 4.0897300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50162, 'Somain', 'Somain', 'Somain', 50.3596100, 3.2810800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50163, 'Solliès-Ville', 'Sollies-Ville', 'Sol''e-Vil'',Sol''es-Vil'',Soliers,Soliers Vila,Sollies-Ville,Solliès-Ville,suo li ye wei lei,Сольес-Виль,Сольє-Віль,索利耶维勒', 43.1822800, 6.0385800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50164, 'Solliès-Toucas', 'Sollies-Toucas', 'Sollies-Toucas,Solliès-Toucas', 43.2082100, 6.0249600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50165, 'Solliès-Pont', 'Sollies-Pont', 'Lo Pont de Soliers,Lo Pònt de Soliers,Sol''e-Pon,Sol''es-Pon,Soliers Pont,Soliers Pònt,Sollies-Pont,Solliès-Pont,suo li ye peng,Сольес-Пон,Сольє-Пон,索利耶蓬', 43.1897800, 6.0432100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50166, 'Solignac-sur-Loire', 'Solignac-sur-Loire', 'Solignac,Solignac-sur-Loire', 44.9681900, 3.8852900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50167, 'Solignac', 'Solignac', 'Solenhac,Solignac,Solin''jak,suo li ni ya ke,Солиньяк,Соліньяк,索利尼亚克', 45.7552800, 1.2756300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50168, 'Soliers', 'Soliers', 'Soliers', 49.1344000, -0.2961300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50169, 'Solgne', 'Solgne', 'Solgne', 48.9657700, 6.2963500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50170, 'Solesmes', 'Solesmes', 'Solesmes', 50.1846800, 3.4979900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50171, 'Solesmes', 'Solesmes', 'Solesmes', 47.8500900, -0.2980600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50172, 'Solers', 'Solers', 'Solers', 48.6591900, 2.7161700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50173, 'Solaize', 'Solaize', 'Solaize,Solez,Солез', 45.6333300, 4.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50174, 'Soisy-sur-Seine', 'Soisy-sur-Seine', 'Soisy,Soisy-sur-Seine,Suazi-sjur-Sen,sai na he pan su wa xi,Суази-сюр-Сен,Суазі-сюр-Сен,塞纳河畔苏瓦西', 48.6487500, 2.4522300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50175, 'Soisy-sur-École', 'Soisy-sur-Ecole', 'Soisy,Soisy-Marat,Soisy-sur-Ecole,Soisy-sur-École,Suazi-sjur-Ekol'',ai ke er he pan su wa xi,Суази-сюр-Еколь,Суазі-сюр-Еколь,埃科尔河畔苏瓦西', 48.4763700, 2.4930100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50176, 'Soisy-sous-Montmorency', 'Soisy-sous-Montmorency', 'Emile,Mont-Emile,Soisy,Soisy-sous-Montmorency,Suazi-su-Monmoransi,su wa xi su meng te mo lang xi,Суази-су-Монморанси,Суазі-су-Монморансі,苏瓦西苏蒙特莫朗西', 48.9881300, 2.3015600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50177, 'Soissons', 'Soissons', 'Soason,Soissons,Suason,Suasonas,Suasson,Suessonae,XSS,sowason,su wa song,suasong,swaswn,Соасон,Суасон,Суассон,סואסון,سوآسون,سواسون,ソワソン,苏瓦松,수아송,', 49.3816700, 3.3236100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50178, 'Soings-en-Sologne', 'Soings-en-Sologne', 'Soings,Soings-en-Sologne', 47.4128900, 1.5245200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50179, 'Soignolles-en-Brie', 'Soignolles-en-Brie', 'Soignolles,Soignolles-en-Brie', 48.6535000, 2.6996800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50180, 'Socx', 'Socx', 'Socx,Soex', 50.9357100, 2.4242200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50181, 'Sochaux', 'Sochaux', 'Sochaux,Sosho,Soso,Sošo,sosyo,suo shao,Сошо,索绍,소쇼', 47.5080800, 6.8274800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50182, 'Smarves', 'Smarves', 'Smarv,Smarves,si ma er wo,Смарв,斯马尔沃', 46.5107800, 0.3498000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50183, 'Sizun', 'Sizun', 'Sizen,Sizun,xi zan,Сизен,Сізен,西赞', 48.4000000, -4.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50184, 'Sixt-sur-Aff', 'Sixt-sur-Aff', 'Seizh,Sixt,Sixt-sur-Aff', 47.7764800, -2.0786700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50185, 'Six-Fours-les-Plages', 'Six-Fours-les-Plages', 'Si For le Plazh,Si Fur le Plazh,Si-Fur-le-Plazh,Sieis Forns,Sieisforns de Mar,Sis-Fur-le-Plazh,Six Fours,Sièis Forns,shisu=furu=re=puraju,sipuleulepeullaju,syks fwr lplazh,xi fu er si-lei pu la re,Си Фор ле Плаж,Си Фур ле Плаж,Сис-Фур-ле-Плаж,Сі-Фур-ле-Плаж,سیکس فور لپلاژ,シス＝フール＝レ＝プラージュ,西富尔斯-勒普拉热,시푸르레플라주', 43.1000000, 5.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50186, 'Sisteron', 'Sisteron', 'Segustero,Sisteron,shisutoron,xi si te long,Систерон,Сістерон,シストロン,西斯特龙', 44.1875800, 5.9462300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50187, 'Sissonne', 'Sissonne', 'Sissonne', 49.5710700, 3.8936900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50188, 'Sireuil', 'Sireuil', 'Sireuil', 45.6166700, 0.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50189, 'Sion-les-Mines', 'Sion-les-Mines', 'Hezin-ar-Mengleuziou,Hezin-ar-Mengleuzioù,S''jon-le-Min,Sion,Sion-les-Mines,xiong lai mi nei,Сьйон-ле-Мін,雄莱米内', 47.7347600, -1.5919000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50190, 'Sin-le-Noble', 'Sin-le-Noble', 'Sen-le-Nobl'',Sin,Sin-le-Noble,Sin-le-Nope,Sin-les-Douai,Sin-lès-Douai,sang lei nuo bu lei,Сен-ле-Нобль,桑勒诺布勒', 50.3615900, 3.1311300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50191, 'Sinceny', 'Sinceny', 'Sincency,Sinceny', 49.5961900, 3.2467900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50192, 'Simiane-Collongue', 'Simiane-Collongue', 'Collongue,Sim''jan-Kollong,Simiane,Simiane-Collongue,Simjan-Kollong,Sumiana e Caulonga,Sumiana e Caulònga,xi mi ang ke long gai,Симьян-Коллонг,Сімян-Коллонг,西米昂科隆盖', 43.4306700, 5.4345400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50193, 'Simandres', 'Simandres', 'Simandres', 45.6197900, 4.8708700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50194, 'Simandre', 'Simandre', 'Simandre', 46.6236400, 4.9877700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50195, 'Silly-le-Long', 'Silly-le-Long', 'Silly,Silly-le-Long', 49.1074900, 2.7922600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50196, 'Sillingy', 'Sillingy', 'Felingi,Sienzhi,Sillingy,Сієнжі', 45.9454200, 6.0339200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50197, 'Sillery', 'Sillery', 'Sillery', 49.1982200, 4.1324400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50198, 'Sillé-le-Guillaume', 'Sille-le-Guillaume', 'Sie-le-Gijom,Sille,Sille-le-Guillaume,Sillee-la-Montagne,Sillé,Sillé-le-Guillaume,Sillée-la-Montagne,Сіє-ле-Гійом', 48.1826600, -0.1264200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50199, 'Sillans', 'Sillans', 'Sillans', 45.3406800, 5.3885900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50200, 'Sigolsheim', 'Sigolsheim', 'Sigol''sajm,Sigolsheim,Сигольсайм,Сігольсайм', 48.1347500, 7.3013700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50201, 'Signy-le-Petit', 'Signy-le-Petit', 'Signy,Signy-le-Petit', 49.9027700, 4.2799000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50202, 'Signes', 'Signes', 'Signes', 43.2901000, 5.8623200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50203, 'Sigean', 'Sigean', 'Sigean,Sijan,Sizhan,xi rang,Сижан,Сіжан,西让', 43.0277700, 2.9791600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50204, 'Sierentz', 'Sierentz', 'Sierentz,Sierenz,Sirenc,Сиренц,Сіренц', 47.6585200, 7.4542600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50205, 'Sierck-les-Bains', 'Sierck-les-Bains', 'Bad Sierck,S''erk-le-Ben,Sierck,Sierck-les-Bains,Sierk,xie er lai ban,Сьерк-ле-Бен,Сьєрк-ле-Бен,谢尔莱班', 49.4399200, 6.3605700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50206, 'Sibiril', 'Sibiril', 'Sibiril,Sibirill', 48.6666700, -4.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50207, 'Sézanne', 'Sezanne', 'Sezann,Sezanne,Sézanne,sai zha ne,Сезанн,塞扎讷', 48.7204700, 3.7233900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50208, 'Seyssuel', 'Seyssuel', 'Sejssjuel'',Sessjuehl'',Seyssuel,sai xu ai,Сейссюель,Сессюэль,塞叙埃', 45.5600600, 4.8532000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50209, 'Seyssins', 'Seyssins', 'Seyssins', 45.1551300, 5.6792100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50210, 'Seyssinet-Pariset', 'Seyssinet-Pariset', 'Sejssine-Parize,Sesine-Parize,Seyssinet,Seyssinet-Pariset,sai xi nei pa li sai,Сейссіне-Паризе,Сесине-Паризе,塞西内帕里塞', 45.1767500, 5.6938700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50211, 'Seysses', 'Seysses', '', 43.4980100, 1.3108100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50212, 'Seynod', 'Seynod', 'Sejno,Seynod,Сейно', 45.8854900, 6.0883100, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50213, 'Seyne-les-Alpes', 'Seyne-les-Alpes', 'Sanha,Seina,Sejn,Sen,Seyne,Seyne-les-Alpes,Sèina,sai en,sen,Сейн,Сен,塞恩,센', 44.3504200, 6.3563400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50214, 'Sévrier', 'Sevrier', 'Sevrie,Sevrier,Sévrier,Севріє', 45.8641500, 6.1402600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50215, 'Sevrey', 'Sevrey', 'Sevrey,Sezrey', 46.7382500, 4.8403000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50216, 'Sèvres-Anxaumont', 'Sevres-Anxaumont', 'Sadebria,Sevr-Anksomon,Sevres,Sevres-Anxaumont,Sèvres,Sèvres-Anxaumont,sai fu lei ang ke suo meng,Севр-Анксомон,塞夫勒昂克索蒙', 46.5703600, 0.4660300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50217, 'Sèvres', 'Sevres', 'Separa,Seur,Sevr,Sevres,Sèvres,sai fu er,sebeuleu,sevuru,swr,Σεβρ,Севр,Сеўр,Սևր,سور,セーヴル,塞夫尔,세브르', 48.8229200, 2.2175700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50218, 'Sevran', 'Sevran', 'Sevran,sai fu lang,sebeulang,suvuran,swran,swran  fransh,syfrwn,Севран,سوران,سوران، فرانسه,سيفرون,スヴラン,塞夫朗,세브랑', 48.9447200, 2.5274600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50219, 'Sévignac', 'Sevignac', 'Sevignac,Sevinieg,Sévignac', 48.3329700, -2.3391500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50220, 'Sévérac-le-Château', 'Severac-le-Chateau', 'Severac,Severac del Castel,Severac del Castèl,Severac-la-Montagne,Severac-le-Chateau,Severak-le-Shato,Sévérac,Sévérac-la-Montagne,Sévérac-le-Château,sai wei la ke lai sha tuo,Северак-ле-Шато,塞韦拉克莱沙托', 44.3242900, 3.0592900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50221, 'Sévérac', 'Severac', 'Severac,Severeg,Sévérac', 47.5500800, -2.0749600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50222, 'Seurre', 'Seurre', 'Serr,Seurre,Sjor,Surregium,se er,swr  fransh,Серр,Сёр,سور، فرانسه,瑟尔', 46.9992300, 5.1513800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50223, 'Seugy', 'Seugy', 'Seugy,Sezhi,Sjozhi,Сежи,Сежі,Сёжи', 49.1218200, 2.3937700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50224, 'Sète', 'Sete', 'Set,Seta,Setas,Sete,Sète,Sēte,XSY,sai te gang,seteu,setto,st,st  fransh,syt,Сет,סט,ست، فرانسه,سيت,セット,塞特港,세트', 43.4028000, 3.6927800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50225, 'Servon-sur-Vilaine', 'Servon-sur-Vilaine', 'Servon,Servon-sjur-Vilen,Servon-sur-Vilaine,Servonium,wei lan he pan sai er weng,Сервон-сюр-Вилен,Сервон-сюр-Вілен,维兰河畔塞尔翁', 48.1211400, -1.4597100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50226, 'Servon', 'Servon', 'Servon', 48.7166200, 2.5873700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50227, 'Servian', 'Servian', 'Servian', 43.4271600, 3.3003200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50228, 'Servas', 'Servas', 'Servas', 46.1329000, 5.1653800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50229, 'Serris', 'Serris', 'Serris', 48.8452800, 2.7861100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50230, 'Serrières', 'Serrieres', 'Port-du-Mezenc,Port-du-Mézenc,Serrieres,Serrieres-les-Saint-Sornin,Serrières,Serrières-les-Saint-Sornin', 45.3188500, 4.7634200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50231, 'Serres-Castet', 'Serres-Castet', 'Sent Julhan de Serras,Sent Julhan de Sèrras,Ser-Kastet,Serr-Kaste,Serras Casteth,Serras-Casteth,Serres,Serres-Castet,Sèrras Castèth,Sèrras-Castèth,sai er lei ka si tai,Сер-Кастет,Серр-Касте,塞尔雷卡斯泰', 43.3833300, -0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50232, 'Serres', 'Serres', 'Serres', 44.4286500, 5.7158100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50233, 'Serre-les-Sapins', 'Serre-les-Sapins', 'Serre', 47.2500000, 5.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50234, 'Serquigny', 'Serquigny', 'Serkin''i,Serquigny,sai er qu yi ni,Серкиньи,Серкіньї,塞尔屈伊尼', 49.1094300, 0.7101600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50235, 'Serqueux', 'Serqueux', 'Serqueux', 49.6320200, 1.5400500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50236, 'Serques', 'Serques', 'Serk,Serques,sai er ke,syrkyws,Серк,سيركيوس,塞尔克', 50.7933800, 2.2013400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50237, 'Serpaize', 'Serpaize', 'Serpaize', 45.5570900, 4.9206200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50238, 'Sernhac', 'Sernhac', 'Sernhac', 43.9111600, 4.5503900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50239, 'Sermoise-sur-Loire', 'Sermoise-sur-Loire', 'Sermoise-sur-Loire', 46.9500000, 3.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50240, 'Sermérieu', 'Sermerieu', 'Sermerieu,Sermérieu', 45.6707000, 5.4099600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50241, 'Sermaize-les-Bains', 'Sermaize-les-Bains', 'Sermaize,Sermaize-les-Bains,Sermez-le-Ben,sai er mai ci lai ban,Сермез-ле-Бен,塞尔迈兹莱班', 48.7850700, 4.9116900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50242, 'Sermaises', 'Sermaises', 'Sermaises,Sermez,sai er mai sai,Сермез,塞尔迈塞', 48.2965000, 2.2054600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50243, 'Sérigné', 'Serigne', 'Serigne,Sérigné', 46.5010700, -0.8445300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50244, 'Sérignan-du-Comtat', 'Serignan-du-Comtat', 'Serignan,Serignan-du-Comtat,Serin''jan-dju-Konta,Serinhan,Serinhan dau Comtat,Sérignan,Sérignan-du-Comtat,sai li ni ang di kong ta,Сериньян-дю-Конта,塞里尼昂迪孔塔', 44.1885000, 4.8440300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50245, 'Sérignan', 'Serignan', 'Serignan,Serin''jan,Serinhan,Sérignan,sai li ni ang,Сериньян,塞里尼昂', 43.2787300, 3.2771200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50246, 'Sérifontaine', 'Serifontaine', 'Serifontaine,Serifonten,Sérifontaine,sai li feng tan,Серифонтен,塞里丰坦', 49.3544000, 1.7687300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50247, 'Sergy', 'Sergy', 'Sergy', 46.2525700, 6.0005800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50248, 'Sergines', 'Sergines', 'Sergines', 48.3420300, 3.2621300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50249, 'Sérézin-du-Rhône', 'Serezin-du-Rhone', 'Serezin,Serezin-du-Rhone,Sérézin,Sérézin-du-Rhône', 45.6290200, 4.8246700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50250, 'Sérent', 'Serent', 'Seran,Serent,Sérent,sai lang,Серан,塞朗', 47.8233300, -2.5057100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50251, 'Serémange-Erzange', 'Seremange-Erzange', 'Erzange,Schoemange,Seremange,Seremange-Erzange,Seremanzh-Erzanzh,Serémange,Serémange-Erzange,sai lei mang ge ai er cang ge,Сереманж-Ерзанж,塞雷芒格埃尔藏格', 49.3188700, 6.0902500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50252, 'Séreilhac', 'Sereilhac', 'Sereilhac,Séreilhac', 45.7684300, 1.0805200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50253, 'Seraincourt', 'Seraincourt', 'Seraincourt', 49.0357300, 1.8670300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50254, 'Sequedin', 'Sequedin', 'Sequedin', 50.6257500, 2.9827600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50255, 'Septfonds', 'Septfonds', 'Septfonds', 44.1781300, 1.6180600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50256, 'Septeuil', 'Septeuil', 'Septej,Septeuil,Септей', 48.8924500, 1.6835700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50257, 'Septèmes-les-Vallons', 'Septemes-les-Vallons', 'Septemes,Septemes-les-Vallons,Septèmes-les-Vallons,Septêmes', 43.3983400, 5.3659600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50258, 'Septème', 'Septeme', 'Septeme,Septème', 45.5531500, 5.0034500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50259, 'Sentheim', 'Sentheim', 'Senheim', 47.7556000, 7.0530500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50260, 'Sens-de-Bretagne', 'Sens-de-Bretagne', 'Sen,Sens,Sens-de-Bretagne', 48.3324500, -1.5353500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50261, 'Sens', 'Sens', 'Agedincum,Sens,Sens-sur-Yonne,XSF', 48.2000000, 3.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50262, 'Senones', 'Senones', 'Senones', 48.3947500, 6.9781800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50263, 'Senonches', 'Senonches', 'Senonches,Senonsh,se nong shen,Сенонш,瑟农什', 48.5599900, 1.0306900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50264, 'Sennecey-lès-Dijon', 'Sennecey-les-Dijon', 'Sennecey,Sennecey-les-Dijon,Sennecey-lès-Dijon', 47.2898400, 5.1048500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50265, 'Sennecey-le-Grand', 'Sennecey-le-Grand', 'Grand-Sennecey,Sennecey,Sennecey-le-Grand', 46.6413700, 4.8670700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50266, 'Senlis', 'Senlis', 'Senlis,XSV', 49.2000000, 2.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50267, 'Séné', 'Sene', 'Sene,Sine,Séné', 47.6190000, -2.7370000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50268, 'Sénas', 'Senas', 'Senac,Senas,Senaç,Senàs,Sénas,sai na,Сенас,塞纳', 43.7437500, 5.0780000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50269, 'Semussac', 'Semussac', 'Semjussak,se mi sa ke,Семюссак,瑟米萨克', 45.6000000, -0.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50270, 'Semur-en-Auxois', 'Semur-en-Auxois', 'Semur', 47.4833300, 4.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50271, 'Semoy', 'Semoy', '', 47.9333300, 1.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50272, 'Séméac', 'Semeac', 'Semeac,Semeak,Semiac,Séméac,sai mei a ke,Семеак,塞梅阿克', 43.2291500, 0.1060200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50273, 'Sémalens', 'Semalens', 'Semalan,Semalens,Sémalens,sai ma lang,Семалан,塞马朗', 43.5922500, 2.1120800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50274, 'Selvigny', 'Selvigny', 'Selvigny', 50.0797100, 3.3489900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50275, 'Seltz', 'Seltz', 'Sel''c,Selz,sai er te,serutsu,slz,syltz,zlts,Сельц,סלץ,زلتس,سيلتز,セルツ,塞尔特', 48.8952000, 8.1075700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50276, 'Selongey', 'Selongey', 'Selongey', 47.5884600, 5.1848300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50277, 'Seloncourt', 'Seloncourt', 'Seloncourt', 47.4598900, 6.8553500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50278, 'Selles-sur-Cher', 'Selles-sur-Cher', 'Sel''-sjur-Sher,Selles,Selles-sur-Cher,xie he pan se lai,Сель-сюр-Шер,谢河畔瑟莱', 47.2790400, 1.5538700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50279, 'Selles-Saint-Denis', 'Selles-Saint-Denis', 'Selles,Selles-Saint-Denis', 47.3869500, 1.9229500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50280, 'Sélestat', 'Selestat', 'Schlestadt,Schlettstadt,Schlettstàdt,Selesta,Selestadium,Selestat,Sélestat,XSQ,sai lai si ta,seresuta,slsth,sylystat,Σελεστά,Селеста,סלסטה,سيليستات,セレスタ,塞莱斯塔', 48.2666700, 7.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50281, 'Seissan', 'Seissan', 'Seissan', 43.4921500, 0.5925000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50282, 'Seingbouse', 'Seingbouse', 'Seingbouse,Seingbousse', 49.1172400, 6.8302400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50283, 'Seine-Port', 'Seine-Port', 'Seine-Port,Sen-Por,Сен-Пор', 48.5574300, 2.5531600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50284, 'Seillans', 'Seillans', 'Celhan,Seillans,Sejan,Selhan,sai lang,Сейан,Сеян,塞朗', 43.6350000, 6.6466600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50285, 'Seilhac', 'Seilhac', 'Seilhac', 45.3666700, 1.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50286, 'Seilh', 'Seilh', 'Seilh', 43.6946900, 1.3550900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50287, 'Seigy', 'Seigy', 'Seigy', 47.2568800, 1.3996400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50288, 'Seignosse', 'Seignosse', 'Seignosse,Sen''oss,Senhossa,Senhòssa,sai ni ao si,Сеньосс,塞尼奥斯', 43.6877400, -1.3700000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50289, 'Seignelay', 'Seignelay', 'Seignelay', 47.9054200, 3.6013600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50290, 'Seiches-sur-le-Loir', 'Seiches-sur-le-Loir', 'Seiches,Sesh-sjur-le-Luar,lai-lu wa he pan sai xie,Сеш-сюр-ле-Луар,莱-卢瓦河畔塞谢', 47.5735100, -0.3562800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50291, 'Seichamps', 'Seichamps', 'Seichamps,Sesham,sai shang pu,Сешам,塞尚普', 48.7111400, 6.2618600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50292, 'Segré', 'Segre', 'Segre,sai ge lei,sugure,Сегре,スグレ,塞格雷', 47.6833300, -0.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50293, 'Segonzac', 'Segonzac', 'Segonzac', 45.6166700, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50294, 'Ségny', 'Segny', 'Segny,Ségny', 46.2960100, 6.0753600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50295, 'Séez', 'Seez', 'See,Seez,Sextum Segetium,Séez,Val-Joli,Сее', 45.6220900, 6.7995700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50296, 'Sées', 'Sees', 'Sagii,Se,Sees,Sées,sai zhen,se,Се,セー,塞镇', 48.6040300, 0.1724400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50297, 'Sedan', 'Sedan', 'Sedan,XSW,sudan,Седан,スダン', 49.7000000, 4.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50298, 'Secondigny', 'Secondigny', 'Secondigny,Secondigny-en-Gatine,Secondigny-en-Gâtine', 46.6102400, -0.4167900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50299, 'Seclin', 'Seclin', 'Seclin,Seklen,XSX,sai ke lan,sukuran,Секлен,スクラン,塞克兰', 50.5487300, 3.0273100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50300, 'Sebourg', 'Sebourg', 'Sebourg,Sebur,sai bu er,Себур,塞布尔', 50.3424900, 3.6435200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50301, 'Seboncourt', 'Seboncourt', 'Seboncourt', 49.9527300, 3.4758600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50302, 'Sébazac-Concourès', 'Sebazac-Concoures', 'Haute-Sebazac-Concoures,Haute-Sébazac-Concourès,Sebasac,Sebazac,Sebazak-Konkure,Sebazak-Konkures,Sébazac,sai ba zha ke kong ku lei,Себазак-Конкуре,Себазак-Конкурес,塞巴扎克孔库雷', 44.4048400, 2.6032400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50303, 'Scy-Chazelles', 'Scy-Chazelles', 'Scy,Scy-Chazelles,Si Shazel,Si-Shazel'',si xi sha ze lai,Си Шазел,Си-Шазель,Сі-Шазель,斯西沙泽莱', 49.1136000, 6.1161000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50304, 'Scorbé-Clairvaux', 'Scorbe-Clairvaux', 'Scorbe-Clairvaux,Scorbé-Clairvaux,Skorbe-Klervo,si ke er bo ke lai er wo,Скорбе-Клерво,斯科尔伯克莱尔沃', 46.8106100, 0.4136900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50305, 'Scionzier', 'Scionzier', 'Scionzier', 46.0544700, 6.5575700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50306, 'Sciez', 'Sciez', 'S''e,Sciez,Siez,Siéz,Сьє', 46.3290900, 6.3794700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50307, 'Schwindratzheim', 'Schwindratzheim', 'Schwingelse,Schwíngelse,Shvendracajm,shwyndratshaym,si ke wan de la te zan,stshwyndratzhym,Швендрацайм,ستشويندراتزهيم,شویندراتسهایم,斯克万德拉特赞', 48.7558200, 7.5989800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50308, 'Schweighouse-sur-Moder', 'Schweighouse-sur-Moder', 'Schweighausen,Schweighouse', 48.8166700, 7.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50309, 'Schœneck', 'Schoeneck', 'Schoenecken', 49.2166700, 6.9166700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50310, 'Schnersheim', 'Schnersheim', '', 48.6574100, 7.5670100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50311, 'Schirmeck', 'Schirmeck', 'Schirmeck,Shirmek,si xi er mei,stshyrmk,Ширмек,ستشيرمك,斯希尔梅', 48.4794200, 7.2151000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50312, 'Schiltigheim', 'Schiltigheim', 'Schilige,Schiltigheim,Schiltighein,Schílige,Shil''tigajm,Shiltigem,schilfigheim,shirutikaimu,shyltygm,siltigaim,stshyltyghhym,xi er di gai mu,Шилтигем,Шильтигайм,Шильтігайм,ستشيلتيغهيم,شیلتیگم,シルティカイム,希尔蒂盖姆,실티가임', 48.6074900, 7.7493100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50313, 'Scherwiller', 'Scherwiller', 'Scherweiler,Sherviller,shrwylr,si she er wei lai,stshyrwylyr,Шервиллер,Шервіллер,ستشيرويلير,شرویلر,斯舍尔维莱', 48.2871300, 7.4213500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50314, 'Scey-sur-Saône-et-Saint-Albin', 'Scey-sur-Saone-et-Saint-Albin', 'Scey-Saint-Albin,Scey-sur-Saone,Scey-sur-Saone-et-Saint-Albin,Scey-sur-Saône,Scey-sur-Saône-et-Saint-Albin', 47.6639800, 5.9745100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50315, 'Sceaux', 'Sceaux', 'Sceaux,Sceaux-l''Unite,Sceaux-l''Unité', 48.7764400, 2.2902600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50316, 'Scaër', 'Scaer', 'Scaer,Scaër,Skaer,si ka e,Скаер,斯卡厄', 48.0333300, -3.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50317, 'Saze', 'Saze', 'Saze', 43.9434000, 4.6809600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50318, 'Sayat', 'Sayat', 'Saiac,Sayat,Seja,sai a,Сея,赛阿', 45.8275400, 3.0520600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50319, 'Savy-Berlette', 'Savy-Berlette', 'Savi-Berlett,Savy-Berlette,sa wei bei er lai te,safy byrlyt,Сави-Берлетт,Саві-Берлетт,سافي بيرليت,萨维贝尔莱特', 50.3524900, 2.5645600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50320, 'Savonnières', 'Savonnieres', 'Savon''er,Savonniere,Savonnieres,Savonnière,Savonnières,sa wo ni ai,Савоньєр,萨沃尼埃', 47.3476900, 0.5496100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50321, 'Savigny-sur-Orge', 'Savigny-sur-Orge', 'Savigny,Savigny-sur-Orge,Savin''i-sjur-Orzh,Savini sir Orzh,ao er ri he pan sa wei ni,sabiniswileuoleuju,savu~ini=shuru=oruju,swynyy swr awrzh,Савиньи-сюр-Орж,Савињи сир Орж,Савіньї-сюр-Орж,سوینیی سور اورژ,サヴィニー＝シュル＝オルジュ,奥尔日河畔萨维尼,사비니쉬르오르주', 48.6767700, 2.3483500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50322, 'Savigny-sur-Braye', 'Savigny-sur-Braye', 'Savigny,Savin''i-sjur-Bre,bu lai ai he pan sa wei ni,Савіньї-сюр-Бре,布赖埃河畔萨维尼', 47.8792300, 0.8098100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50323, 'Savigny-Lévescault', 'Savigny-Levescault', 'Savigny,Savigny-Levescault,Savigny-Lévescault,Savigny-lEvescault,Savigny-lÉvescault,Savin''i-Levesko,sa wei ni lai fu si ke er,Савіньї-Левеско,萨维尼莱弗斯科尔', 46.5350200, 0.4771900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50324, 'Savigny-le-Temple', 'Savigny-le-Temple', 'Savigny,Savigny-le-Port,Savigny-le-Temple,Savigny-sur-Balory,Savin''i-le-Tampl'',Savin''i-le-khram,Savini le Templ,sabinileutangpeul,savu~ini=ru=tanpuru,swynyy lw tam,Савиньи-ле-Тампль,Савиньи-ле-храм,Савињи ле Темпл,Савіньї-ле-Тампль,سوینیی لو تام,サヴィニー＝ル＝タンプル,사비니르탕플', 48.5740900, 2.5828700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50325, 'Savigny-lès-Beaune', 'Savigny-les-Beaune', 'Savigny,Savigny-les-Beaune,Savigny-lès-Beaune,Savin''i-le-Bon,sa wei ni lai bo en,savu~ini=re=bonu,sawyny-l-bn,Савиньи-ле-Бон,Савіньї-ле-Бон,ساوینی-ل-بن,サヴィニー＝レ＝ボーヌ,萨维尼莱博恩', 47.0635700, 4.8182100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50326, 'Savigny-en-Véron', 'Savigny-en-Veron', 'Savigny-en-Veron,Savigny-en-Véron', 47.2007100, 0.1445700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50327, 'Savigny-en-Sancerre', 'Savigny-en-Sancerre', 'Savigny,Savigny-en-Sancerre', 47.4414200, 2.8095300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50328, 'Savigny', 'Savigny', 'Savigny', 45.8173200, 4.5754300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50329, 'Savigneux', 'Savigneux', 'Savigneux', 45.6167000, 4.0833000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50330, 'Savigné-sur-Lathan', 'Savigne-sur-Lathan', 'Savigne,Savigne-sur-Lathan,Savigné,Savigné-sur-Lathan', 47.4448300, 0.3209300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50331, 'Savigné', 'Savigne', 'Savigne,Savigné,Savin''e,sa wei ge,Савіньє,萨维格', 46.1595000, 0.3193700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50332, 'Saverne', 'Saverne', 'Savern,Saverne,Zabern,Zawere,Zàwere,sa wei er en,safyrn,savu~erunu,Саверн,סאברן,سافيرن,サヴェルヌ,萨韦尔恩', 48.7416400, 7.3622100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50333, 'Saverdun', 'Saverdun', 'Savardun,Saverden,Saverdjon,Saverdun,sa wei er dan,savu~erudan,Саверден,Савердён,サヴェルダン,萨韦尔丹', 43.2352600, 1.5739800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50334, 'Savennières', 'Savennieres', 'Saven''er,sa wei ni ai,Савеньєр,萨韦尼埃', 47.3822500, -0.6570800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50335, 'Savenay', 'Savenay', 'Savenay,Savene,Savenneg,sa wo nai,savune,Савене,サヴネ,萨沃奈', 47.3607200, -1.9421500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50336, 'Savasse', 'Savasse', 'Savasse', 44.6022900, 4.7793100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50337, 'Sauzé-Vaussais', 'Sauze-Vaussais', 'Sauze-Vaussais,Sauzé-Vaussais,Soze-Vosse,Созе-Воссе', 46.1336900, 0.1067300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50338, 'Sauzet', 'Sauzet', 'Sauzet', 44.6028800, 4.8178900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50339, 'Sauxillanges', 'Sauxillanges', 'Saussilanjas,Sauxillanges,Sosijanzh,sokushiyanju,suo ke xi lang re,Сосиянж,Сосіянж,ソクシヤンジュ,索克西朗热', 45.5526700, 3.3738000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50340, 'Sauvigny-les-Bois', 'Sauvigny-les-Bois', 'Sauvigny,Sauvigny-les-Bois', 46.9667600, 3.2719000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50341, 'Sauviat-sur-Vige', 'Sauviat-sur-Vige', 'Sauviat,Sauviat-sur-Vige', 45.9072000, 1.6082700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50342, 'Sauvian', 'Sauvian', 'Sauvian', 43.2929300, 3.2602400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50343, 'Sauveterre-de-Guyenne', 'Sauveterre-de-Guyenne', 'Sauvaterra de Guiana,Sauvatèrra de Guiana,Sauveterre,Sauveterre-de-Guyenne,Sovterr-de-Gjuienn,suo wei tai er de ji an,Совтерр-де-Гюиенн,Совтерр-де-Гюїенн,索韦泰尔德吉安', 44.6930000, -0.0854900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50344, 'Sauveterre', 'Sauveterre', 'Sauveterre', 44.0228200, 4.7934700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50345, 'Sauveterre-de-Béarn', 'Sauveterre-de-Bearn', 'Salbaterra Bearno,Sauvaterra,Sauvaterra de Biarn,Sauvatèrra,Sauvatèrra de Biarn,Sauveterre,Sovter-de-Bearn,Sovterr-de-Bearn,suo wei tai er de bei a er en,Совтер-де-Беарн,Совтерр-де-Беарн,索韦泰尔德贝阿尔恩', 43.4000000, -0.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50346, 'Sauverny', 'Sauverny', 'Sauvergny,Sauverny', 46.3151400, 6.1182700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50347, 'Sauve', 'Sauve', 'Sauve,Sov,suo fu,Сов,索夫', 43.9415000, 3.9490300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50348, 'Sauvagnon', 'Sauvagnon', 'Sauvagnon,Sauvanhon,Sovan''on,suo wa ni weng,Сованьон,索瓦尼翁', 43.4000000, -0.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50349, 'Sautron', 'Sautron', 'Salterona,Saotron,Sautron,Sotron,suo te long,Сотрон,索特龙', 47.2627400, -1.6710700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50350, 'Sausset-les-Pins', 'Sausset-les-Pins', 'Saucet,Sausset,Sausset dei Pins,Sausset-les-Pins,Sosse-le-Pen,suo sai lai pan,Соссе-ле-Пен,索塞莱潘', 43.3313600, 5.1043100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50351, 'Saussay', 'Saussay', 'Saussay,Sausset', 48.8557100, 1.4088900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50352, 'Saussan', 'Saussan', 'Saussan', 43.5722000, 3.7750000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50353, 'Sausheim', 'Sausheim', 'Sausheim,Sosajm,Сосайм', 47.7897600, 7.3713400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50354, 'Saumur', 'Saumur', 'Gorad Samjur,Salmurium,Saumur,Somir,Somjur,XSU,somwileu,somyuru,suo mi er,swmwr,swmyr,Горад Самюр,Сомир,Сомюр,סומיר,سومور,ソミュール,索米尔,소뮈르', 47.2666700, -0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50355, 'Saulzoir', 'Saulzoir', 'Saulzoir,Sol''zuar,suo er zu wa er,Сользуар,索尔祖瓦尔', 50.2405700, 3.4443000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50356, 'Saulxures-sur-Moselotte', 'Saulxures-sur-Moselotte', 'Saulxures,Saulxures-sur-Moselotte,Soksjur-sjur-Mozelott,mo si luo te he pan suo er ke xu er,Соксюр-сюр-Мозелотт,莫斯洛特河畔索尔克叙尔', 47.9489400, 6.7704000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50357, 'Saulxures-lès-Nancy', 'Saulxures-les-Nancy', 'Saulxures,Saulxures-les-Nancy,Saulxures-lès-Nancy', 48.6890700, 6.2458700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50358, 'Saulxures', 'Saulxures', 'Saulxures', 47.9553800, 5.5847700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50359, 'Saulx-les-Chartreux', 'Saulx-les-Chartreux', 'Saulx,Saulx-le-Rocher,Saulx-les-Chartreux,So-le-Shartre,Sol''-le-Shartre,suo er lai sha er te lei,Со-ле-Шартре,Соль-ле-Шартре,索尔莱沙尔特勒', 48.6906200, 2.2672700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50360, 'Sault-lès-Rethel', 'Sault-les-Rethel', 'Sault,Sault-les-Rethel,Sault-lès-Rethel', 49.4998000, 4.3622700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50361, 'Sault', 'Sault', 'Sault-de-Vaucluse', 44.0896800, 5.4083600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50362, 'Sault-Brénaz', 'Sault-Brenaz', 'Sault,Sault-Brenaz,Sault-Brénaz', 45.8543100, 5.4142400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50363, 'Saultain', 'Saultain', 'Saultain,Sol''ten,suo tan,Сольтен,索坦', 50.3367600, 3.5772300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50364, 'Saulny', 'Saulny', 'Saulny', 49.1583500, 6.1049800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50365, 'Saulnes', 'Saulnes', 'Saulnes', 49.5355500, 5.8262900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50366, 'Saulieu', 'Saulieu', 'Saulieu,Sedolocum,Sol''e,Sol''jo,suo li e,Солье,Сольё,Сольє,索利厄', 47.2802300, 4.2285700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50367, 'Saulgé', 'Saulge', 'Saulge,Saulgé,Sol''zhe,suo er re,Сольже,索尔热', 46.3775800, 0.8757700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50368, 'Saulcy-sur-Meurthe', 'Saulcy-sur-Meurthe', 'Saulcy,Saulcy-sur-Meurthe,Sol''si-sjur-Mert,mo er te he pan suo er xi,Сольси-сюр-Мерт,Сольсі-сюр-Мерт,默尔特河畔索尔西', 48.2375800, 6.9644300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50369, 'Saulce-sur-Rhône', 'Saulce-sur-Rhone', 'Sauca,Saulce,Saulce-sur-Rhone,Saulce-sur-Rhône,Saussa,Sauça,Sol''s-sjur-Ron,luo ne he pan suo er ke,Сольс-сюр-Рон,罗讷河畔索尔克', 44.7028000, 4.8016900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50370, 'Saujon', 'Saujon', 'Saujon,Sozhon,suo rong,Сожон,索容', 45.6730900, -0.9262000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50371, 'Saugues', 'Saugues', 'Saug,Saugues,Saugues-la-Montagne,Sog,sogu,suo gai,Сог,ソーグ,索盖', 44.9603900, 3.5478400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50372, 'Saugnac-et-Cambran', 'Saugnac-et-Cambran', '', 43.6709800, -0.9949500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50373, 'Saucats', 'Saucats', 'Saucats', 44.6540500, -0.5964300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50374, 'Saubrigues', 'Saubrigues', 'Saubrigues', 43.6098900, -1.3138100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50375, 'Saubion', 'Saubion', 'Saubion', 43.6714000, -1.3482100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50376, 'Saubens', 'Saubens', 'Saubens', 43.4798400, 1.3518900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50377, 'Satolas-et-Bonce', 'Satolas-et-Bonce', 'Satolas,Satolas-et-Bonce', 45.6929900, 5.1309900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50378, 'Satillieu', 'Satillieu', 'Satijjo,Satil''e,Satilhau,Satillieu,sa di li e,Сатийё,Сатільє,萨蒂利厄', 45.1503500, 4.6149300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50379, 'Sathonay-Village', 'Sathonay-Village', 'Sathonay,Sathonay-Village', 45.8327000, 4.8812100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50380, 'Sathonay-Camp', 'Sathonay-Camp', 'Sathonay-Camp,Satone-Kam,Сатоне-Кам', 45.8231000, 4.8675400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50381, 'Sassenay', 'Sassenay', 'Sassenay', 46.8307400, 4.9252300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50382, 'Sassenage', 'Sassenage', 'Sasnazh,Sassenage,Sassenajo,Sassenazh,Sassenâjo,sa se na ge,Саснаж,Сассенаж,萨瑟纳格', 45.2053100, 5.6651500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50383, 'Sarzeau', 'Sarzeau', 'Sarzeau,Sarzhav,Sarzo,sa er zuo,Сарзо,萨尔佐', 47.5277200, -2.7693300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50384, 'Sartrouville', 'Sartrouville', 'Sartrouville,Sartruvil,Sartruvil'',sa te lu wei er,saleuteulubil,sartrwfyl,sartrwwyl,sarutoruvu~iru,srtrwwyl,Сартрувил,Сартрувиль,Сартрувіль,سارتروفيل,سارتروویل,سرتروویل,サルトルーヴィル,薩特魯維爾,사르트루빌', 48.9482000, 2.1916900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50385, 'Sartilly', 'Sartilly', 'Sartilly', 48.7523900, -1.4567800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50386, 'Sartène', 'Sartene', 'Sarte,Sarten,Sartena,Sartene,Sartè,Sartène,sarutenu,Сартен,サルテーヌ', 41.6166700, 8.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50387, 'Sarry', 'Sarry', 'Sarry', 48.9185200, 4.4062100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50388, 'Sarrola-Carcopino', 'Sarrola-Carcopino', 'Sarrola,Sarrola-Carcopino', 42.0124100, 8.8505500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50389, 'Sarrians', 'Sarrians', 'Marat,Sarr''jan,Sarrian,Sarrians,sa er li ang,Саррьян,Сарріан,萨尔里昂', 44.0840100, 4.9696500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50390, 'Sarrewerden', 'Sarrewerden', 'Sarrewerden', 48.9226100, 7.0841200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50391, 'Sarre-Union', 'Sarre-Union', 'Buckenum,Saar-Union,Saarunion,Sarr-Junion,Sarr-Union,Sarre-Union,sa er yu ni weng,sar ywnywn,sar-awnywn,saru=yunion,Сарр-Юнион,Сарр-Юніон,سار يونيون,سار-اونیون,サール＝ユニオン,萨尔于尼翁', 48.9381800, 7.0937300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50392, 'Sarreinsming', 'Sarreinsming', 'Sarreinsmeing,Sarreinsming', 49.0896600, 7.1095800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50393, 'Sarreguemines', 'Sarreguemines', 'Germunda,Saargemines,Saargemuend,Saargemund,Saargemünd,Sargemin,Sarreguemines,Sarrequemines,Sarrgemin,sa er ge mi na,saleugeumin,sargmyn,saruguminu,srghwmyn,srgmyn,Саргемин,Сарргемин,Сарргемін,سارگمین,سرغومين,سرگمین,サルグミーヌ,萨尔格米纳,사르그민', 49.1099500, 7.0674700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50394, 'Sarrebourg', 'Sarrebourg', 'Saarburg,Saraburgum,Sarrbur,Sarrebourc,Sarrebourg,sa er lei bu er,saruburu,Саррбур,サールブール,萨尔雷布尔', 48.7333300, 7.0500000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50395, 'Sarras', 'Sarras', '', 45.1867900, 4.8000400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50396, 'Sarralbe', 'Sarralbe', 'Saaralben,Saravi Alba,Sarral''b,Sarralbe,sa er la er bu,saralb,Сарральб,سارالب,萨尔拉尔布', 48.9985800, 7.0307400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50397, 'Sarlat-la-Canéda', 'Sarlat-la-Caneda', 'Sarla-la-Kaneda,Sarlat,Sarlat e La Canedat,Sarlat e la Canedat,Sarlat-la-Caneda,Sarlat-la-Canéda,Sarlatum,sa la la ka nei da,sar la-la-kane da,sarla-la-kanda,sarura=ra=kaneda,Сарла-ла-Канеда,سارلا-لا-کاندا,ซาร์ลา-ลา-กาเนดา,サルラ＝ラ＝カネダ,萨拉拉卡内达', 44.8890200, 1.2165600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50398, 'Sari-Solenzara', 'Sari-Solenzara', 'Sari,Sari e Sulinzara,Sari è Sulinzara,Sari-Solencara,Sari-Solenzara,Sari-di-Porto-Vecchio,Сари-Соленцара,Сарі-Соленцара', 41.8351900, 9.3747000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50399, 'Sargé-sur-Braye', 'Sarge-sur-Braye', 'Sarge,Sarge-sur-Braye,Sargé,Sargé-sur-Braye', 47.9235200, 0.8534000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50400, 'Sargé-lès-le-Mans', 'Sarge-les-le-Mans', 'Sarge,Sargé,Sarzhe-le-le-Man,Сарже-ле-ле-Ман', 48.0333300, 0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50401, 'Sare', 'Sare', 'Sar,Sara,Sare,sa er,Сар,سارے,萨尔', 43.3126000, -1.5801200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50402, 'Sarcelles', 'Sarcelles', 'Sarcelles,Sarcelles-Lochere,Sarcelles-Lochère,Sarsel,Sarsel'',sa er sai lei,saleusel,sarsl,sarsyl,saruseru,srsl,Сарсел,Сарсель,סרסל,سارسل,سارسيل,سرسل,サルセル,薩爾塞勒,사르셀', 49.0000000, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50403, 'Sarbazan', 'Sarbazan', 'Sarbazan', 44.0202900, -0.3129400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50404, 'Saran', 'Saran', 'Saran', 47.9501300, 1.8760100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50405, 'Saône', 'Saone', 'Saone,Saône', 47.2231100, 6.1168200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50406, 'Sanvignes-les-Mines', 'Sanvignes-les-Mines', 'Sanvignes,Sanvignes-les-Mines', 46.6644400, 4.2918800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50407, 'Santes', 'Santes', 'Sant,Santes,sang te,Сант,桑特', 50.5931600, 2.9628900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50408, 'Santeny', 'Santeny', 'Santeny', 48.7273000, 2.5734600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50409, 'Santec', 'Santec', 'Santec,Santeg,Santek,sang tai ke,santekku,Сантек,サンテック,桑泰克', 48.7000000, -4.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50410, 'Santa-Maria-di-Lota', 'Santa-Maria-di-Lota', 'Santa Maria di Lota,Santa-Maria,Santa-Marija-di-Lota,Санта-Мария-ди-Лота,Санта-Марія-ді-Лота', 42.7478300, 9.4320200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50411, 'Santa-Lucia-di-Moriani', 'Santa-Lucia-di-Moriani', 'Sainte-Lucie-de-Moriani,Santa-Lucia,Santa-Lucia-di-Moriani', 42.3821200, 9.5224200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50412, 'Sansac-de-Marmiesse', 'Sansac-de-Marmiesse', 'Sansac,Sansac-de-Marmiesse', 44.8848500, 2.3470100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50413, 'Sannois', 'Sannois', 'Sannois,Sannua,Sanoa,sa nu wa,sanowa,sanua,snwa,Саннуа,Саноа,سنوآ,サノワ,薩努瓦,사누아', 48.9666700, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50414, 'San-Nicolao', 'San-Nicolao', 'San Nicolao,San-Nicolao,San-Nikolao,Santu Niculaiu di Moriani,Сан-Николао,Сан-Ніколао', 42.3693900, 9.5094300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50415, 'Sannerville', 'Sannerville', 'Sannervil'',Sannerville,sa nei er wei er,Саннервиль,Саннервіль,萨内尔维尔', 49.1801800, -0.2243400, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50416, 'San-Martino-di-Lota', 'San-Martino-di-Lota', 'San Martino di Lota,San Martinu di Lota,San-Martino,San-Martino-di-Lota,Сан-Мартино-ди-Лота,Сан-Мартіно-ді-Лота', 42.7316300, 9.4396600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50417, 'Sanguinet', 'Sanguinet', 'Sangine,Sanguinet,sang ji nei,Сангине,Сангіне,桑吉内', 44.4832000, -1.0745700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50418, 'Sangatte', 'Sangatte', 'Sangatt,Sangatte,sang jia te,sanjat,Сангатт,سانجات,桑加特', 50.9456400, 1.7532100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50419, 'Sandillon', 'Sandillon', 'Sandijon,Sandil''on,Sandillon,sang di long,Сандильон,Сандійон,桑迪隆', 47.8451000, 2.0315500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50420, 'Sand', 'Sand', 'Sand', 48.3823800, 7.6126100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50421, 'Sancoins', 'Sancoins', 'Sancoins,Sankuehn,Sankuen,sang kuan,Санкуен,Санкуэн,桑宽', 46.8331400, 2.9223800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50422, 'Sancey-le-Grand', 'Sancey-le-Grand', '', 47.2948900, 6.5828700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50423, 'Sancerre', 'Sancerre', 'Sancerre,Sanser,Sanserr,sang sai er,sanseru,Сансер,Сансерр,サンセール,桑塞尔', 47.3288900, 2.8344700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50424, 'Sancé', 'Sance', 'Sance,Sancé', 46.3392600, 4.8304900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50425, 'Sanary-sur-Mer', 'Sanary-sur-Mer', 'Sanari-sjur-Mer,Sanary,Sanary-sur-Mer,Sant Nari,bin hai sa na li,Санари-сюр-Мер,Санарі-сюр-Мер,滨海萨纳里', 43.1178300, 5.8000700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50426, 'Samoreau', 'Samoreau', 'Samoreau,Samoro,Саморо', 48.4294600, 2.7558700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50427, 'Samois-sur-Seine', 'Samois-sur-Seine', 'Samoa sjur Sen,Samois,Samois-sur-Seine,Samua-sjur-Sen,Самоа сюр Сен,Самуа-сюр-Сен', 48.4525100, 2.7504000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50428, 'Samoëns', 'Samoens', 'Samoens,Samoëns,Самоенс', 46.0828200, 6.7264700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50429, 'Sammeron', 'Sammeron', 'Sammeron', 48.9472100, 3.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50430, 'Samer', 'Samer', 'Same,Samer,Samé,sa mei er,samr,Саме,سامر,萨梅尔', 50.6384000, 1.7462800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50431, 'Saméon', 'Sameon', 'Sameon,Saméon', 50.4713500, 3.3354400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50432, 'Samatan', 'Samatan', 'Samatan', 43.4928600, 0.9297600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50433, 'Samadet', 'Samadet', 'Samadet', 43.6376100, -0.4878500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50434, 'Salviac', 'Salviac', 'Salviac', 44.6808000, 1.2650600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50435, 'Salouël', 'Salouel', 'Saloue,Salouel,Saloué,Salouël,Saluehl'',Saluel'',sa lu ai lei,Салуель,Салуэль,萨卢埃勒', 49.8698800, 2.2434000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50436, 'Salon-de-Provence', 'Salon-de-Provence', 'Salon,Salon d''o Provans,Salon de Provans,Salon-de-Provans,Salon-de-Provence,Selon,Selon de Provenca,Selon de Provença,pu luo wang si de qu sa long,sallongdeupeulobangseu,saron=do=purovu~ansu,slwn dw prwans,Салон де Прованс,Салон дьо Прованс,Салон-де-Прованс,سلون دو پروانس,サロン＝ド＝プロヴァンス,普罗旺斯地区萨隆,살롱드프로방스', 43.6407400, 5.0954500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50437, 'Salomé', 'Salome', 'Salome,Salomé', 50.5335200, 2.8470900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50438, 'Salles-sur-Mer', 'Salles-sur-Mer', 'Salles,Salles-sur-Mer', 46.1054300, -1.0574100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50439, 'Salles-la-Source', 'Salles-la-Source', 'Las Salas del Comtal,Sal''-la-Surs,Salas Comtals,Salles,Salles-la-Source,sa lai la su er ke,Саль-ла-Сурс,萨莱拉苏尔克', 44.4350500, 2.5128300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50440, 'Salles-Curan', 'Salles-Curan', 'Las Salas,Las Salas de Curanh,Sal''-Kjuran,Salles-Curan,sa lai qu lang,Саль-Кюран,萨莱屈朗', 44.1822000, 2.7882100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50441, 'Salles', 'Salles', 'Salles', 44.5500000, -0.8607300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50442, 'Sallertaine', 'Sallertaine', 'Sallertaine,Sallerten,sa lai er tai na,Саллертен,萨莱尔泰纳', 46.8601700, -1.9552200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50443, 'Sallebœuf', 'Salleboeuf', '', 44.8333300, -0.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50444, 'Sallaumines', 'Sallaumines', 'Sallaumine,Sallaumines,Sallaumones,Sallomin,sa luo mi ne,salawmynys,Салломин,Салломін,سالاومينيس,萨洛米讷', 50.4174900, 2.8617400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50445, 'Sallanches', 'Sallanches', 'Salenches,Sallansh,XSN,sllnchs,Салланш,سللنچس', 45.9442300, 6.6316200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50446, 'Salins-les-Thermes', 'Salins-les-Thermes', 'Salins', 45.4716900, 6.5305100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50447, 'Salins-les-Bains', 'Salins-les-Bains', 'Fort-Egalite,Fort-Egalité,Salen-le-Ben,Salins,Salins-les-Bains,sa lan lai ban,Сален-ле-Бен,ซาแล็ง-เล-แบ็ง,萨兰莱班', 46.9466300, 5.8776300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50448, 'Salins', 'Salins', 'Salins', 48.4215600, 3.0213000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50449, 'Salindres', 'Salindres', 'Salendr,Salindres,sa lan de lei,Салендр,萨兰德雷', 44.1717400, 4.1602000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50450, 'Saligny', 'Saligny', 'Saligny', 46.8083300, -1.4272600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50451, 'Salignac', 'Salignac', 'Salignac', 45.0160700, -0.3796400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50452, 'Salies-du-Salat', 'Salies-du-Salat', 'Salies,Salies-du-Salat', 43.1007400, 0.9586600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50453, 'Salies-de-Béarn', 'Salies-de-Bearn', 'Sali-de-Bearn,Salias,Salies,Saliese,sa li ye de bei a er en,salynay dy byarn,Сали-де-Беарн,Салі-де-Беарн,ساليناي دي بيارن,萨利耶德贝阿尔恩', 43.4742200, -0.9244800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50454, 'Saleux', 'Saleux', 'Saleux', 49.8563000, 2.2369800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50455, 'Sales', 'Sales', 'Sales', 45.8757600, 5.9599800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50456, 'Salernes', 'Salernes', 'Salern,Salerna,Salernas,Salernes,Salèrna,sa lai er na,Салерн,萨莱尔纳', 43.5634900, 6.2339800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50457, 'Saleilles', 'Saleilles', 'Saleilles,Salelles', 42.6541800, 2.9530900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50458, 'Salses-le-Château', 'Salses-le-Chateau', 'Sal''s-le-Shato,Salses,sa er sai lai sha tuo,Сальс-ле-Шато,萨尔塞莱沙托', 42.8333300, 2.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50459, 'Salbris', 'Salbris', 'Sal''bri,Salbris,sa er bu li,Сальбрі,萨尔布里', 47.4242000, 2.0512400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50460, 'Salbert', 'Salbert', 'Le Salbert,Salbert', 47.6723600, 6.8220900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50461, 'Salaise-sur-Sanne', 'Salaise-sur-Sanne', 'Salaise,Salaise-sur-Sanne', 45.3423400, 4.8182900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50462, 'Salagnon', 'Salagnon', 'Salagnon', 45.6671300, 5.3580900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50463, 'Saizerais', 'Saizerais', 'Saizerais,Sezre,sai ze lai,Сезре,赛泽赖', 48.7908300, 6.0447200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50464, 'Saïx', 'Saix', '', 43.5833300, 2.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50465, 'Saivres', 'Saivres', 'Saivres', 46.4326200, -0.2367700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50466, 'Saint-Zacharie', 'Saint-Zacharie', 'Saint-Zacharie,Theonlen,Théonlen', 43.3852100, 5.7080800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50467, 'Saint-Yzan-de-Soudiac', 'Saint-Yzan-de-Soudiac', 'Saint Yzan,Saint-Yzan-de-Soudiac', 45.1411800, -0.4107800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50468, 'Saint-Yvi', 'Saint-Yvi', 'Saint-Yvy,Sant-Ivi,Sent-Ivi,sheng yi wei,Сент-Іві,Сент-Иви,圣伊维', 47.9666700, -3.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50469, 'Saint-Yrieix-sur-Charente', 'Saint-Yrieix-sur-Charente', 'Saint Yrieix sobre Charenta,Saint-Yrieix,Saint-Yrieix-sur-Charente,San Yrieix sobre Charenta,Sent-Ir''eks-sjur-Sharant,Sent-Ire-sjur-Sharant,sha lang te he pan sheng yi li ye yi,Сент-Ірє-сюр-Шарант,Сент-Ирьекс-сюр-Шарант,沙朗特河畔圣伊里耶伊', 45.6833300, 0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50470, 'Saint-Yrieix-la-Perche', 'Saint-Yrieix-la-Perche', 'Saint-Yrieix,Saint-Yrieix-la-Perche,Sent Irieg de Glandon,Sent Iries,Sent Irièg de Glandon,Sent Iriès,Sent-Ir''e-la-Persh,Sent-Ire-la-Persh,Yrieix-la-Montagne,sheng yi li ye yi la pei er shen,Сент-Ірє-ла-Перш,Сент-Ирье-ла-Перш,圣伊里耶伊拉佩尔什', 45.5160400, 1.2056900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50471, 'Saint-Yorre', 'Saint-Yorre', 'Saint-Yorre,Sant Tiorre,Sen-Jor,Sent-Jor,sheng yi ao er,Сен-Йор,Сент-Йор,圣伊奥尔', 46.0605700, 3.4681300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50472, 'Saint-Yan', 'Saint-Yan', 'SYT,Saint-Yan,Yan-l''Arconce', 46.4114700, 4.0387600, 'FR', '2017-01-15', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50473, 'Saint-Xandre', 'Saint-Xandre', 'Gemmapes,Saint-Xandre', 46.2044400, -1.1026700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50474, 'Saint-Witz', 'Saint-Witz', 'Saint-Witz,Sen-Vic,Sen-Vitz,sheng wei,Сен-Витз,Сен-Виц,Сен-Вітз,圣维', 49.0910000, 2.5712200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50475, 'Saint-Wandrille-Rançon', 'Saint-Wandrille-Rancon', 'Saint-Vandrille,Saint-Wandrille,Saint-Wandrille-Rancon,Saint-Wandrille-Rançon', 49.5265800, 0.7649700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50476, 'Saint-Vrain', 'Saint-Vrain', 'Saint-Vrain', 48.5430200, 2.3333100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50477, 'Saint-Vite', 'Saint-Vite', 'Saint-Vite', 44.4713300, 0.9387600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50478, 'Saint-Vit', 'Saint-Vit', 'Egalite-sur-Doubs,Egalité-sur-Doubs,Saint-Vit,Sen-Vit,sheng wei,Сен-Віт,圣维', 47.1833300, 5.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50479, 'Saint-Vincent-sur-Oust', 'Saint-Vincent-sur-Oust', 'Saint-Vincent,Saint-Vincent-sur-Oust,Sant-Visant-an-Oud,Sant-Visant-an-Oust,Sen-Vensan-sjur-Ust,wu si he pan sheng wan sang,Сен-Венсан-сюр-Уст,乌斯河畔圣万桑', 47.7001000, -2.1465700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50480, 'Saint-Vincent-sur-Graon', 'Saint-Vincent-sur-Graon', 'Le Graon,Saint-Vincent,Saint-Vincent-sur-Graon,Sen-Vensan-sjur-Graon,ge lang he pan sheng wan kang,Сен-Венсан-сюр-Граон,格朗河畔圣万康', 46.5169000, -1.3888100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50481, 'Saint-Vincent-de-Tyrosse', 'Saint-Vincent-de-Tyrosse', 'Saint-Vincent,Saint-Vincent-de-Tyrosse,San Bisentse,Sen-Vensan-de-Tiross,Sent Vincenc de Tirossa,Sent Vincenç de Tiròssa,san=vu~ansan=do=tirosu,sheng wan sang de di luo si,Сен-Венсан-де-Тиросс,Сен-Венсан-де-Тіросс,サン＝ヴァンサン＝ド＝ティロス,圣万桑德蒂罗斯', 43.6603100, -1.3079900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50482, 'Saint-Vincent-des-Landes', 'Saint-Vincent-des-Landes', 'Saint Vincent,Saint-Vincent-des-Landes,Sant-Visant-al-Lann', 47.6569500, -1.4957200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50483, 'Saint-Vincent-de-Paul', 'Saint-Vincent-de-Paul', 'Saint-Vincent,Saint-Vincent-de-Paul', 44.9542900, -0.4675100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50484, 'Saint-Vincent-de-Paul', 'Saint-Vincent-de-Paul', '', 43.7443100, -1.0066200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50485, 'Saint-Vincent-de-Mercuze', 'Saint-Vincent-de-Mercuze', 'Saint Vincent-de Mercuse,Saint-Vincent,Saint-Vincent-de-Mercuze', 45.3706300, 5.9518200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50486, 'Saint-Vigor-le-Grand', 'Saint-Vigor-le-Grand', 'Saint-Vigor,Saint-Vigor-le-Grand', 49.2824200, -0.6857900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50487, 'Saint-Victurnien', 'Saint-Victurnien', 'Saint-Victurnien', 45.8785500, 1.0137600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50488, 'Saint-Victor-la-Coste', 'Saint-Victor-la-Coste', 'Saint-Victor,Saint-Victor-la-Coste,Serre-la-Coste', 44.0629500, 4.6423800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50489, 'Saint-Victoret', 'Saint-Victoret', 'Saint-Victoret,Sant Victoret,Sant Vitoret,Sen-Viktore,sheng wei ke tuo lei,Сен-Викторе,Сен-Вікторе,圣维克托雷', 43.4195700, 5.2339600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50490, 'Saint-Victor-de-Cessieu', 'Saint-Victor-de-Cessieu', 'Saint-Victor,Saint-Victor-de-Cessieu', 45.5500000, 5.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50491, 'Saint-Victor', 'Saint-Victor', 'Saint-Victor', 46.3946700, 2.6085800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50492, 'Saint-Viaud', 'Saint-Viaud', 'Saint-Viaud,Sant-Widel-Skovrid', 47.2561900, -2.0183300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50493, 'Saint-Viâtre', 'Saint-Viatre', 'Saint-Viatre,Saint-Viâtre', 47.5243800, 1.9327600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50494, 'Saint-Viance', 'Saint-Viance', 'Avelque-Courte,Belle-Rive,Saint-Viance', 45.2175200, 1.4528400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50495, 'Saint-Vérand', 'Saint-Verand', 'Saint-Verand,Saint-Vérand', 45.9199600, 4.5279100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50496, 'Saint-Vérand', 'Saint-Verand', 'Saint-Verand,Saint-Vérand', 45.1727700, 5.3319500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50497, 'Saint-Venant', 'Saint-Venant', 'Fanum Santi Venantii,Fort-Vert,Pot-Vert,Saint-Venant,Sen-Venan,san fynant,sheng wei nan,Сен-Венан,سان فينانت,圣韦南', 50.6195500, 2.5394600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50498, 'Saint-Vaury', 'Saint-Vaury', 'Saint-Vaury', 46.2041700, 1.7565400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50499, 'Saint-Varent', 'Saint-Varent', 'Saint-Varent', 46.8893400, -0.2321000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50500, 'Saint-Vallier-de-Thiey', 'Saint-Vallier-de-Thiey', 'Saint-Vallier,Saint-Vallier-de-Thiey', 43.6953900, 6.8443000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50501, 'Saint-Vallier', 'Saint-Vallier', 'Saint-Vallier,Vallier-les-Bois', 46.6410700, 4.3710700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50502, 'Saint-Vallier', 'Saint-Vallier', 'Saint-Vallier,Val-Libre', 45.1759200, 4.8151400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50503, 'Saint-Valery-sur-Somme', 'Saint-Valery-sur-Somme', 'La Montagne-sur-Somme,Port-Somme,Saint-Valery,Saint-Wary,Sen-Valeri-sjur-Somm,san=vu~areri=shuru=sonmu,suo mu he pan sheng wa lai li,Сен-Валери-сюр-Сомм,Сен-Валері-сюр-Сомм,サン＝ヴァレリー＝シュル＝ソンム,索姆河畔圣瓦莱里', 50.1833300, 1.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50504, 'Saint-Valery-en-Caux', 'Saint-Valery-en-Caux', 'Port-le-Pelletier,Saint-Valery,Saint-Valéry,Sen-Valeri-an-Ko,Сен-Валери-ан-Ко,Сен-Валері-ан-Ко', 49.8666700, 0.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50505, 'Saint-Valérien', 'Saint-Valerien', 'Saint-Valerien,Saint-Valérien', 48.1780500, 3.0952300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50506, 'Saint-Vaast-la-Hougue', 'Saint-Vaast-la-Hougue', 'La Hougue,Port-la-Hougue,Saint-Vaast,Saint-Vaast-la-Hougue,Sen-Va-la-Ug,san=vu~asuto=ra=ugu,sheng wa a si la wu gai,Сен-Ва-ла-Уг,サン＝ヴァースト＝ラ＝ウーグ,圣瓦阿斯拉乌盖', 49.5884300, -1.2693100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50507, 'Saint-Uze', 'Saint-Uze', 'Mont-Bertheud,Saint-Uze,Sent-Juz,sheng yu ci,Сент-Юз,圣于兹', 45.1850200, 4.8656100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50508, 'Saint-Usuge', 'Saint-Usuge', 'Chalon-sur-Seille,Saint-Usuge,Sent-Juzjuzh,Сент-Юзюж', 46.6790000, 5.2508900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50509, 'Saint-Usage', 'Saint-Usage', 'Bon-Usage,Saint-Usage', 47.1100900, 5.2604400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50510, 'Saint-Urbain', 'Saint-Urbain', 'Lannurvan,Saint-Urbain', 48.4000000, -4.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50511, 'Saint-Urbain', 'Saint-Urbain', 'Saint-Urbain', 46.8755700, -2.0096100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50512, 'Saint-Tropez', 'Saint-Tropez', 'Gorad Sen-Trapeh,Heraclea Cacabaris,Heraclee,Héraclée,Sain-Trope,Saint-Tropez,San-Trope,Sant Tropetz,Sen Trope,Sen-Trope,santorope,sheng te luo pei,sn-trwph,Σαιν-Τροπέ,Горад Сен-Трапэ,Сан-Тропе,Сен Тропе,Сен-Тропе,سن-تروپه,سین-تروپے,แซ็ง-ทรอเป,სენ-ტროპე,サントロペ,圣特罗佩', 43.2693200, 6.6398100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50513, 'Saint-Trojan-les-Bains', 'Saint-Trojan-les-Bains', 'La Montagne,Saint-Trojan,Saint-Trojan-les-Bains,Sen-Trozhan-le-Ben,sheng te luo rang lai ban,Сен-Трожан-ле-Бен,圣特罗让莱班', 45.8413400, -1.2072800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50514, 'Saint-Trivier-sur-Moignans', 'Saint-Trivier-sur-Moignans', 'Pont-Moignans,Saint-Trivier,Saint-Trivier-sur-Moignans,Sen Trivie syur Muanyan,Sen-Triv''e-sjur-Muan''jan,Sen-Trive-sjur-Muan''jan,mu wa ni ang he pan sheng te li wei ai,san-tryfyyh-swr-mwanyan  ayn,Сен-Тривье-сюр-Муаньян,Сен-Тривє-сюр-Муаньян,Սեն Տրիվիե սյուր Մուանյան,سان-تريفييه-سور-موانيان، أين,穆瓦尼昂河畔圣特里维埃', 46.0723300, 4.8975500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50515, 'Saint-Trivier-de-Courtes', 'Saint-Trivier-de-Courtes', 'Saint-Trivier,Saint-Trivier-de-Courtes,Val-Libre', 46.4590400, 5.0804700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50516, 'Saint-Thuriau', 'Saint-Thuriau', 'Saint-Thuriau,Sant-Turiav', 48.0166700, -2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50517, 'Saint-Thurial', 'Saint-Thurial', 'Saint-Thurial,Sant-Turiav-Porc''hoed', 48.0292400, -1.9318100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50518, 'Saint-Thonan', 'Saint-Thonan', 'Saint-Thonan,Sant-Tonan,Sen-Tonan,sheng tuo nan,Сен-Тонан,圣托南', 48.4833300, -4.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50519, 'Saint-Thibéry', 'Saint-Thibery', 'Saint-Thibery,Saint-Thibéry', 43.3965700, 3.4177400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50520, 'Saint-Thibault-des-Vignes', 'Saint-Thibault-des-Vignes', 'La Cote-des-Vignes,La Côte-des-Vignes,Saint-Thibault,Saint-Thibault-des-Vignes,Sen-Tibo-de-Vin'',Сен-Тибо-де-Винь,Сен-Тібо-де-Вінь', 48.8711100, 2.6804100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50521, 'Saint-Thégonnec', 'Saint-Thegonnec', 'Saint-Thegonnec,Saint-Thégonnec,Sant-Tegoneg,Sen-Tegonnek,sheng tai ge nei ke,Сен-Тегоннек,圣泰戈内克', 48.5166700, -3.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50522, 'Saint-Symphorien-sur-Coise', 'Saint-Symphorien-sur-Coise', 'Chausse-Armee,Chausse-Armée,Saint-Symphorien,Saint-Symphorien-sur-Coise,Sen-Semforjan-sjur-Kuaz,Сен-Семфорян-сюр-Куаз', 45.6320000, 4.4581100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50523, 'Saint-Symphorien-de-Lay', 'Saint-Symphorien-de-Lay', 'Lay,Saint-Symphorien,Saint-Symphorien-de-Lay,Symphorien-Lay', 45.9484900, 4.2120400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50524, 'Saint-Symphorien', 'Saint-Symphorien', 'Phorien-sur-Sevre,Phorien-sur-Sèvre,saint symphorien', 46.2644200, -0.4922000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50525, 'Saint-Symphorien', 'Saint-Symphorien', 'Grand-Air,La Hure,Saint-Symphorien', 44.4294100, -0.4904700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50526, 'Saint-Sylvestre-sur-Lot', 'Saint-Sylvestre-sur-Lot', 'Saint-Sylvestre,Saint-Sylvestre-sur-Lot', 44.3966700, 0.8044100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50527, 'Saint-Sylvestre-Pragoulin', 'Saint-Sylvestre-Pragoulin', 'Saint-Sylvestre,Saint-Sylvestre-Pragoulin,Sant Silvestre,Sen-Sil''vestr-Pragulen,sheng xi er wei si te er pu la gu lan,Сен-Сільвестр-Прагулен,圣西尔韦斯特尔普拉古兰', 46.0510100, 3.3990500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50528, 'Saint-Sylvestre-Cappel', 'Saint-Sylvestre-Cappel', 'Saint-Sylvestre-Cappel', 50.7762500, 2.5562200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50529, 'Saint-Sylvain', 'Saint-Sylvain', 'Saint-Sylvain', 49.0562400, -0.2175800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50530, 'Saint-Sulpice-sur-Risle', 'Saint-Sulpice-sur-Risle', 'Saint-Sulpice,Saint-Sulpice-sur-Rile,Saint-Sulpice-sur-Rille,Saint-Sulpice-sur-Risle,Saint-Sulpice-sur-Rîle,Sulpice-la-Montagne,Vendemiaire,Vendémiaire', 48.7806300, 0.6573900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50531, 'Saint-Sulpice-sur-Lèze', 'Saint-Sulpice-sur-Leze', 'Libre-Lese,Libre-Lèse,Saint-Sulpice,Saint-Sulpice-sur-Leze,Saint-Sulpice-sur-Lèze', 43.3307600, 1.3209100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50532, 'Saint-Sulpice-les-Feuilles', 'Saint-Sulpice-les-Feuilles', 'Saint-Sulpice,Saint-Sulpice-les-Feuilles', 46.3186800, 1.3679200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50533, 'Saint-Sulpice-le-Guérétois', 'Saint-Sulpice-le-Gueretois', 'Saint-Sulpice,Saint-Sulpice-le-Gueretois,Saint-Sulpice-le-Guérétois', 46.2009700, 1.8282600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50534, 'Saint-Sulpice-la-Forêt', 'Saint-Sulpice-la-Foret', 'Saint-Sulpice,Saint-Sulpice-la-Foret,Saint-Sulpice-la-Forêt,Sanctus Sulpicius de Abbatia,Sant-Suleg-ar-C''hoad,Sant-Suleg-ar-Choad,Sen-Sjul''pis-la-Fore,sheng xu er pi ke la fu lei,Сен-Сюльпис-ла-Форе,Сен-Сюльпіс-ла-Форе,圣叙尔皮克拉福雷', 48.2166700, -1.5797200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50535, 'Saint-Sulpice-et-Cameyrac', 'Saint-Sulpice-et-Cameyrac', 'Saint-Sulpice,Saint-Sulpice-et-Cameyrac,Sen-Sjul''pis-e-Kamerak,Sent Sulpici e Camairac,sheng xu er pi ke he ka mei la ke,Сен-Сюльпис-е-Камерак,Сен-Сюльпіс-е-Камерак,圣叙尔皮克和卡梅拉克', 44.9113100, -0.3904800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50536, 'Saint-Sulpice-de-Royan', 'Saint-Sulpice-de-Royan', 'Saint-Sulpice,Saint-Sulpice-de-Royan,Sen-Sjul''pis-de-Ruajan,sheng xu er pi ke de lu wa ang,Сен-Сюльпис-де-Руайан,Сен-Сюльпіс-де-Руаян,圣叙尔皮克德鲁瓦昂', 45.6703500, -1.0125200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50537, 'Saint-Sulpice-de-Faleyrens', 'Saint-Sulpice-de-Faleyrens', 'Saint-Sulpice,Saint-Sulpice-de Faleyren,Saint-Sulpice-de-Faleyrens,Sen-Sjul''pis-de-Faleran,Sent Sulpici de Faleirens,sheng xu er pi ke de fa lai lang,Сен-Сюльпис-де-Фалеран,Сен-Сюльпіс-де-Фалеран,圣叙尔皮克德法莱朗', 44.8666700, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50538, 'Saint-Sulpice-de-Cognac', 'Saint-Sulpice-de-Cognac', 'Saint-Sulpice,Saint-Sulpice-de-Cognac,Sen-Sjul''pis-de-Kon''jak,sheng xu er pi ke de ke ni ya ke,Сен-Сюльпис-де-Коньяк,Сен-Сюльпіс-де-Коньяк,圣叙尔皮克德科尼亚克', 45.7597800, -0.3809300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50539, 'Saint-Sulpice', 'Saint-Sulpice', 'Saint-Sulpice', 49.3504900, 2.1231400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50540, 'Saint-Sulpice-de-Pommeray', 'Saint-Sulpice-de-Pommeray', 'Les Gorges-Sableuses,Sulpice,Suplice', 47.6000000, 1.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50541, 'Saint-Sulpice-la-Pointe', 'Saint-Sulpice-la-Pointe', 'Saint-Sulpice,Saint-Sulpice-la-Pointe,Sant Somplesi,Sen Siulpisas,Sen-Sjul''pis,Sen-Sjul''pis-la-Puant,sheng xu er pi si,Сен-Сюльпис-ла-Пуант,Сен-Сюльпіс,聖敘爾皮斯', 43.7750000, 1.6851100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50542, 'Saint-Soupplets', 'Saint-Soupplets', 'Saint-Soupplets', 49.0386600, 2.8072300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50543, 'Saint-Souplet', 'Saint-Souplet', 'Saint-Souplet,Sen-Suple,sheng su pu lai,Сен-Супле,圣苏普莱', 50.0563900, 3.5317900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50544, 'Saint-Sorlin-en-Valloire', 'Saint-Sorlin-en-Valloire', 'Saint-Sorlin,Saint-Sorlin-en-Valloire', 45.2898600, 4.9520500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50545, 'Saint-Sorlin-en-Bugey', 'Saint-Sorlin-en-Bugey', 'Bonne-Fontaine,Saint-Sorlin,Saint-Sorlin-en-Bugey', 45.8846800, 5.3711000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50546, 'Saint-Simon', 'Saint-Simon', 'Saint-Simon', 44.9649100, 2.4909000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50547, 'Saint-Siméon-de-Bressieux', 'Saint-Simeon-de-Bressieux', 'Saint-Simeon', 45.3385000, 5.2659100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50548, 'Saint-Sever-Calvados', 'Saint-Sever-Calvados', 'Saint-Sever,Saint-Sever-Calvados,Sen-Seve-Kal''vado,Sen-Seve-Kal''vados,sheng se wei ka er wa duo,syn-swr-klwdws,Сен-Севе-Кальвадо,Сен-Севе-Кальвадос,سین-سور-کلودوس,圣瑟韦卡尔瓦多', 48.8403500, -1.0477300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50549, 'Saint-Sever', 'Saint-Sever', 'Mont-Adour,Saint-Sever,Saint-Sever-sur-l''Adour,Saint-Sever-sur-l’Adour,Sen-Seve,Sen-Sever,Sent Sever,sheng se wei,syn-swr,Сен-Севе,Сен-Север,سین-سور,圣瑟韦', 43.7572700, -0.5735700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50550, 'Saint-Seurin-sur-l’Isle', 'Saint-Seurin-sur-l''Isle', 'Saint-Seurin,Saint-Seurin-sur-l''Isle,Saint-Seurin-sur-l’Isle', 45.0166700, 0.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50551, 'Saint-Sernin-du-Bois', 'Saint-Sernin-du-Bois', 'Saint-Sernin,Saint-Sernin-du-Bois', 46.8407400, 4.4327100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50552, 'Saint-Sernin', 'Saint-Sernin', 'Saint-Sernin', 44.5720800, 4.3916300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50553, 'Saint-Senoux', 'Saint-Senoux', 'Saint-Senoux,Sant-Senour', 47.9055200, -1.7881900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50554, 'Saint-Senier-sous-Avranches', 'Saint-Senier-sous-Avranches', 'Saint-Senier,Saint-Senier-sous-Avranches', 48.6839900, -1.3312600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50555, 'Saint-Selve', 'Saint-Selve', 'Saint-Selve,Sen-Sel''v,Sent Seuve,sheng sai er fu,syn-slwy,Сен-Сельв,سین-سلوی,圣塞尔夫', 44.6709500, -0.4788700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50556, 'Saint-Sébastien-sur-Loire', 'Saint-Sebastien-sur-Loire', 'Engnia,Saint-Sebastien,Saint-Sebastien-sur-Loire,Saint-Sébastien,Saint-Sébastien-sur-Loire,San Sebastian sobre Loira,San Sebastián sobre Loira,Sankt-Sebast''jan-sjur-Luar,Sant-Sebastian-an-Enk,Sen Sebastjan suer Luar,Sen Sebastjan sür Luar,Sen Sebastjen sir Loar,Sen-Sebast''jan-sjur-Luar,lu wa er he pan sheng sai ba si di an,saengsebaseutiangswileulualeu,san=sebasutian=shuru=rowaru,sn sbastyn swr lwar,syn-sbastyn-swr-lwyr,Санкт-Себастьян-сюр-Луар,Сен Себастјен сир Лоар,Сен-Себастьян-сюр-Луар,سن سباستین سور لوآر,سین-سباستین-سور-لوئر,サン＝セバスティアン＝シュル＝ロワール,卢瓦尔河畔圣塞巴斯蒂安,생세바스티앙쉬르루아르', 47.2076800, -1.5033200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50557, 'Saint-Sébastien-de-Morsent', 'Saint-Sebastien-de-Morsent', 'Saint-Sebastien,Saint-Sebastien-de-Morsent,Saint-Sebastion-de Morsent,Saint-Sébastien,Saint-Sébastien-de-Morsent,Saint-Sébastion-de Morsent', 49.0109600, 1.0873000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50558, 'Saint-Savournin', 'Saint-Savournin', 'Saint-Savournin,Sant Savornin,Sen-Savurnen,sheng sa wu er nan,syn-swwrnyn,Сен-Савурнен,سین-سوورنین,圣萨武尔南', 43.4084800, 5.5269000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50559, 'Saint-Savinien', 'Saint-Savinien', 'Carriere-Charente,Carrière-Charente,La Roche-sur-Charente,Saint-Savinien,Sen-Savin''en,Sen-Savin''jan,sheng sa wei ni an,syn-swnyn,Сен-Савиньен,Сен-Савіньян,سین-سونین,圣萨维尼安', 45.8771100, -0.6791900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50560, 'Saint-Savin', 'Saint-Savin', 'Mont-des-Landes,Saint-Savin-de-Blay', 45.1500000, -0.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50561, 'Saint-Savin', 'Saint-Savin', 'Pont-sur-Gartempe,Saint-Savin,Saint-Savin-sur-Gartempe', 46.5652800, 0.8670900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50562, 'Saint-Savin', 'Saint-Savin', 'Saint-Savin', 45.6277000, 5.3072200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50563, 'Saint-Sauveur-sur-École', 'Saint-Sauveur-sur-Ecole', 'Saint-Sauveur', 48.4975000, 2.5471100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50564, 'Saint-Sauveur-le-Vicomte', 'Saint-Sauveur-le-Vicomte', 'Saint-Sauveur,Saint-Sauveur-le-Vicomte,Sauveur-sur-Douve,Sen-Sover-le-Vikont,sheng suo fu lai wei kong te,Сен-Совер-ле-Виконт,Сен-Совер-ле-Віконт,سین-سویر-لے-وکومتے,圣索弗莱维孔特', 49.3854700, -1.5331000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50565, 'Saint-Sauveur-Lendelin', 'Saint-Sauveur-Lendelin', 'Saint-Sauveur-Lendelin,Sen-Sover-Landelen,sheng suo fu lang dai lan,syn-swyr-lyndyln,Сен-Совер-Ланделен,سین-سویر-لیندیلن,圣索弗朗代兰', 49.1298800, -1.4140500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50566, 'Saint-Sauveur-en-Rue', 'Saint-Sauveur-en-Rue', 'Saint-Sauveur,Saint-Sauveur-en-Rue,Sant Salvador,Sant Sauvador jos Rua,Sen-Sover-an-Rju,lu ai de qu sheng suo fu,Сен-Совер-ан-Рю,سین-سویر-ین-رے,吕埃地区圣索弗', 45.2702100, 4.4952900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50567, 'Saint-Sauveur-des-Landes', 'Saint-Sauveur-des-Landes', 'Kersalver-al-Lann,Saint-Sauveur,Saint-Sauveur-des-Landes', 48.3427800, -1.3124800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50568, 'Saint-Sauveur-de-Montagut', 'Saint-Sauveur-de-Montagut', 'Saint-Sauveur,Saint-Sauveur-de-Montagut', 44.8214200, 4.5799300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50569, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 49.9379200, 2.2116200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50570, 'Saint-Sauveur', 'Saint-Sauveur', 'La Reunion,La Réunion,Saint-Sauveur,Sauveur-Geromenil,Sauveur-Géroménil', 49.3185700, 2.7832100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50571, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 47.8053000, 6.3858300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50572, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 46.8084100, 0.6227700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50573, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 45.2027200, -0.8343300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50574, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 45.1533500, 5.3528000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50575, 'Saint-Sauveur', 'Saint-Sauveur', 'Saint-Sauveur', 43.7483000, 1.4008500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50576, 'Saint-Sauves-d''Auvergne', 'Saint-Sauves-d''Auvergne', 'Saint-Sauves,Sauve-Libre', 45.6000000, 2.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50577, 'Saint-Sauvant', 'Saint-Sauvant', 'Saint-Sauvant,Saint-Sauvant-la-Plaine,Sauvent-la-Plaine', 46.3596500, 0.0563400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50578, 'Saint-Saulve', 'Saint-Saulve', 'Saint-Saulve,Sen-Sol''v,sheng suo er wo,Сен-Сольв,سین-سالوے,圣索尔沃', 50.3714100, 3.5561200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50579, 'Saint-Saturnin-sur-Loire', 'Saint-Saturnin-sur-Loire', 'Mont-Rude,Saint-Saturnin,Saint-Saturnin-sur-Loire,Sen-Satjurnen-sjur-Luar,lu wa er he pan sheng sa di er nan,syn-strnyn-swr-lwyr,Сен-Сатюрнен-сюр-Луар,سین-سترنین-سور-لوئر,卢瓦尔河畔圣萨蒂尔南', 47.3943800, -0.4356500, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50580, 'Saint-Saturnin-lès-Avignon', 'Saint-Saturnin-les-Avignon', 'Mont-Saturnin,Saint-Saturnin,Saint-Saturnin-les-Avignon,Saint-Saturnin-lès-Avignon,Sant Savornin dAvinhon,Sen-Satjurnen-lez-Avin''jon,Sen-Satjurnen-lez-Avin''on,sheng sa di er nan lai a wei ni weng,syn-strnyn-lys-awgnwn,Сен-Сатюрнен-лез-Авиньон,Сен-Сатюрнен-лез-Авіньйон,سین-سترنین-لیس-اوگنون,圣萨蒂尔南莱阿维尼翁', 43.9550100, 4.9254800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50581, 'Saint-Saturnin-lès-Apt', 'Saint-Saturnin-les-Apt', 'Saint-Saturnin,Sant Savornin dAte,Sen-Satjurnen-lez-Apt,sheng sa di er nan lai a pu,Сен-Сатюрнен-лез-Апт,سین-سترنین-لیس-اپٹ,圣萨蒂尔南莱阿普', 43.9333300, 5.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50582, 'Saint-Saturnin', 'Saint-Saturnin', 'Saint-Saturnin', 48.0579500, 0.1521800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50583, 'Saint-Saturnin', 'Saint-Saturnin', 'Saint-Saturnin', 45.6666700, 0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50584, 'Saint-Saturnin', 'Saint-Saturnin', 'Saint-Saturnin', 45.6594500, 3.0901900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50585, 'Saint-Satur', 'Saint-Satur', 'Saint-Satur,Thibault-la-Fontaine', 47.3391400, 2.8373400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50586, 'Saint-Samson-sur-Rance', 'Saint-Samson-sur-Rance', 'Saint-Samson,Saint-Samson-sur-Rance,Sant-Samzun', 48.4925200, -2.0286500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50587, 'Saint-Saëns', 'Saint-Saens', 'Saens-la-Foret,Saens-la-Forêt,Saint-Saens,Saint-Saëns', 49.6730200, 1.2852500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50588, 'Saints', 'Saints', 'Saints', 48.7606600, 3.0464500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50589, 'Saintry-sur-Seine', 'Saintry-sur-Seine', 'Saintry,Saintry-sur-Seine,Sentri-sjur-Sen,Stry-sur-Seine,sai na he pan sang te li,Сентри-сюр-Сен,Сентрі-сюр-Сен,سینٹرے-سور-سینے,塞纳河畔桑特里', 48.5964000, 2.4951500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50590, 'Saint-Romans', 'Saint-Romans', 'Romans-Libre,Saint-Romans', 45.1150700, 5.3275100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50591, 'Saint-Romain-sur-Cher', 'Saint-Romain-sur-Cher', 'Brutus,Saint-Romain,Saint-Romain-sur-Cher', 47.3187700, 1.3995600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50592, 'Saint-Romain-le-Puy', 'Saint-Romain-le-Puy', 'Saint-Romain,Saint-Romain-le-Puy,Sen-Romen-le-Pjui,sheng luo man lai pi yi,Сен-Ромен-ле-Пюї,سین-رومین-لے-پے,圣罗曼莱皮伊', 45.5595000, 4.1283900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50593, 'Saint-Romain-la-Motte', 'Saint-Romain-la-Motte', 'Saint-Romain,Saint-Romain-la-Motte', 46.0846000, 3.9816000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50594, 'Saint-Romain-en-Gal', 'Saint-Romain-en-Gal', 'Romain-les-Roches,Saint Romain,Saint-Romain-en-Gal,Sen-Romen-an-Gal'',syn-rwmyn-yn-gl,Сен-Ромен-ан-Галь,سین-رومین-ین-گل', 45.5315900, 4.8607400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50595, 'Saint-Romain-de-Popey', 'Saint-Romain-de-Popey', 'Saint Romain,Saint-Romain-de-Popey', 45.8476300, 4.5308200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50596, 'Saint-Romain-de-Jalionas', 'Saint-Romain-de-Jalionas', 'Saint Romain,Saint-Romain-de-Jalionas,Sen-Romen-de-Zhal''jona,Sen-Romen-de-Zhal''onas,sheng luo man de ya li ao na,Сен-Ромен-де-Жальйона,Сен-Ромен-де-Жальонас,سین-رومین-دے-جلیوناس,圣罗曼德雅利奥纳', 45.7569700, 5.2152700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50597, 'Saint-Romain-de-Colbosc', 'Saint-Romain-de-Colbosc', 'Romain-de-Colbosc,Saint-Romain,Saint-Romain-de-Colbosc', 49.5309300, 0.3571900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50598, 'Saint-Romain-de-Benet', 'Saint-Romain-de-Benet', 'Romain-la-Fontaine,Saint-Romain,Saint-Romain-de-Benet,Sen-Romen-de-Bene,sheng luo man de bo nei,Сен-Ромен-де-Бене,سین-رومین-دے-بنت,圣罗曼德伯内', 45.6915000, -0.8476500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50599, 'Saint-Rogatien', 'Saint-Rogatien', 'L''Egalite,L''Egalité,Prompt-Secours,Saint-Rogatien', 46.1500000, -1.0696300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50600, 'Saint-Riquier', 'Saint-Riquier', 'Centula,Saint-Riquier,Saint-Ritchier,Sen-Rike,san=rikie,sheng li ji ye,syn-ryqyr,Сен-Рикє,سین-ریقئر,サン＝リキエ,圣里基耶', 50.1323500, 1.9475500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50601, 'Saint-Restitut', 'Saint-Restitut', 'Restitut-la-Montagne,Saint-Restitut', 44.3350700, 4.7915500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50602, 'Saint-Renan', 'Saint-Renan', 'Lokournan,Saint-Renan,Sen-Renan,san=runan,sheng lei nan,syn-rnn,Сен-Ренан,سین-رنن,サン＝ルナン,圣雷南', 48.4333300, -4.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50603, 'Saint-Rémy-sur-Durolle', 'Saint-Remy-sur-Durolle', 'Montoncel,Saint-Remy,Saint-Remy-sur-Durolle,Saint-Rémy,Saint-Rémy-sur-Durolle,Sant Remic dau Montelh,Sen-Remi-sjur-Djurol'',di luo er he pan sheng lei mi,Сен-Ремі-сюр-Дюроль,سین-رمے-سور-درولے,迪罗尔河畔圣雷米', 45.8882200, 3.5912500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50604, 'Saint-Rémy-sur-Avre', 'Saint-Remy-sur-Avre', 'Saint Remi-sur-Avre,Saint Rémi-sur-Avre,Saint-Remy,Saint-Remy-Avre,Saint-Remy-sur-Avre,Saint-Rémy,Saint-Rémy-sur-Avre', 48.7614300, 1.2453200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50605, 'Saint-Rémy-lès-Chevreuse', 'Saint-Remy-les-Chevreuse', 'Saint-Remy,Saint-Remy-les-Chevreuse,Saint-Rémy-lès-Chevreuse,Sen-Remi-le-Shevrez,san=remi=re=shuvuruzu,Сен-Ремі-ле-Шеврез,سین-رمے-لیس-چوریسے,サン＝レミ＝レ＝シュヴルーズ', 48.7070800, 2.0769200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50606, 'Saint-Rémy-en-Rollat', 'Saint-Remy-en-Rollat', 'Saint-Remy,Saint-Remy-en-Rollat,Saint-Rémy,Saint-Rémy-en-Rollat,Sant Remai,Sen-Remi-an-Rolla,Servagnon,luo la de qu sheng lei mi,Сен-Реми-ан-Ролла,Сен-Ремі-ан-Ролла,سین-رمے-ین-رولت,罗拉地区圣雷米', 46.1855500, 3.3961300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50607, 'Saint-Rémy-en-Mauges', 'Saint-Remy-en-Mauges', 'Saint-Remy,Saint-Remy-en-Mauges,Saint-Rémy-en-Mauges', 47.2720200, -1.0749900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50608, 'Saint-Rémy-de-Provence', 'Saint-Remy-de-Provence', 'Glanum,Saint Remy Provence,Saint-Remy,Saint-Remy-de-Provence,Saint-Rémy,Saint-Rémy-de-Provence,Sant Romieg,Sant Romieg de Provenca,Sant Romieg de Provença,Sen-Remi-de-Provans,St Remy Provence,saenglemideupeulobangseu,san rymy dw brwfns,san=remi=do=purovu~ansu,senta-remi-de-probhinsa,sheng lei mi,sn-rmy-dw-prwans,Сен-Реми-де-Прованс,Сен-Ремі-де-Прованс,سان ريمي دو بروفنس,سن-رمی-دو-پروانس,سین-رمے-دے-پروونس,সেন্ট-রেমি-দে-প্রোভিন্স,แซ็ง-เรมี-เดอ-พรอว็องส์,サン＝レミ＝ド＝プロヴァンス,圣雷米,생레미드프로방스', 43.7884800, 4.8316700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50609, 'Saint-Rémy', 'Saint-Remy', 'Saint-Remy,Saint-Rémy', 48.9400700, -0.5034400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50610, 'Saint-Rémy', 'Saint-Remy', 'Bellevue-sur-Saone,Bellevue-sur-Saône,Chene-Libre,Chêne-Libre,Saint-Remy,Saint-Rémy', 46.7633400, 4.8392800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50611, 'Saint-Rémy-de-Maurienne', 'Saint-Remy-de-Maurienne', '', 45.4000000, 6.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50612, 'Saint-Raphaël', 'Saint-Raphael', 'Barraton,Saint Raphell,Saint-Raphael,Saint-Raphaël,Sent-Rafaehl'',XSK,Сент-Рафаэль', 43.4233200, 6.7735000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50613, 'Saint-Rambert-en-Bugey', 'Saint-Rambert-en-Bugey', 'Mont-Ferme,Saint-Rambert,Saint-Rambert-en-Bugey,Sen Ramber an Byuze,Sen-Ramber-an-Bjuzhe,Sen-Rambert-an-Bjuzhe,bi re de qu ang sheng lang bei er,san-rambyrt-awn-bwghyy  ayn,Сен-Рамбер-ан-Бюже,Сен-Рамберт-ан-Бюже,Սեն Ռամբեր ան Բյուժե,سان-رامبيرت-أون-بوغيي، أين,سین-رامبرٹ-ین-بگے,比热地区昂圣朗贝尔', 45.9442600, 5.4390400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50614, 'Saint-Quentin-sur-le-Homme', 'Saint-Quentin-sur-le-Homme', 'Saint-Quentin,Saint-Quentin-sur-le-Homme', 48.6475100, -1.3180600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50615, 'Saint-Quentin-sur-Isère', 'Saint-Quentin-sur-Isere', 'Saint-Quentin,Saint-Quentin-sur-Isere,Saint-Quentin-sur-Isère', 45.2788100, 5.5422100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50616, 'Saint-Quentin-la-Poterie', 'Saint-Quentin-la-Poterie', 'Quentin-la-Poterie,Saint-Quentin,Saint-Quentin-la-Poterie', 44.0439200, 4.4443200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50617, 'Saint-Quentin-Fallavier', 'Saint-Quentin-Fallavier', 'Fallavier,Grand-Chalier,Grand-Châlier,Saint-Quentin,Saint-Quentin Fallavier,Saint-Quentin-Fallavier,Sen-Kanten-Fallav''e,Sen-Kanten-Fallave,saengkangtaengpallabie,san kantan falafyyh,san=kantan=faravu~ie,sheng qu ang tan fa la wei ye,Сен-Кантен-Фаллавье,Сен-Кантен-Фаллавє,سان كانتان فالافييه,سین-قینٹین-فلوئر,サン＝カンタン＝ファラヴィエ,圣屈昂坦法拉维耶,생캉탱팔라비에', 45.6305000, 5.1092400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50618, 'Saint-Quentin-en-Mauges', 'Saint-Quentin-en-Mauges', 'Saint-Quentin,Saint-Quentin-en-Mauges,Sen-Kanten-an-Mozh,mo re de qu sheng qu ang tan,Сен-Кантен-ан-Мож,سین-قینٹین-ین-مگس,莫热地区圣屈昂坦', 47.2913000, -0.9119100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50619, 'Saint-Quentin-de-Baron', 'Saint-Quentin-de-Baron', 'Saint-Quentin,Saint-Quentin-de-Baron', 44.8180200, -0.2863600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50620, 'Saint-Quentin', 'Saint-Quentin', 'Egalite-sur-Somme,Egalité-sur-Somme,Linon-sur-Somme,Saint-Quentin,Somme-Libre', 49.8488900, 3.2875700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50621, 'Saint-Quay-Portrieux', 'Saint-Quay-Portrieux', 'Saint-Quay,Saint-Quay-Portrieux,Sant-Ke-Porzh-Olued,Sen-Ke-Porrie,Sen-Ke-Portrijo,sheng qu ai bo er te li e,Сен-Ке-Поррие,Сен-Ке-Порріє,Сен-Ке-Портриё,سین-قے-پورتیو,圣屈艾波尔特里厄', 48.6499200, -2.8305900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50622, 'Saint-Quay-Perros', 'Saint-Quay-Perros', 'Saint-Quay,Saint-Quay-Perros,Sant-Ke-Perroz', 48.7833300, -3.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50623, 'Saint-Python', 'Saint-Python', 'Saint-Python', 50.1900100, 3.4802700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50624, 'Saint-Pryvé-Saint-Mesmin', 'Saint-Pryve-Saint-Mesmin', 'Saint-Pryve,Saint-Pryve-Saint-Mesmin,Saint-Pryvé,Saint-Pryvé-Saint-Mesmin,Sen-Prive-Sen-Memen,sheng pu li wei sheng mei si man,Сен-Приве-Сен-Мемен,سین-پریوے-سین-مثمن,圣普里韦圣梅斯曼', 47.8817700, 1.8695000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50625, 'Saint-Prouant', 'Saint-Prouant', 'La Draperie,Saint-Prouant,Sen-Pruan,sheng pu lu ang,Сен-Пруан,سین-پروانٹ,圣普鲁昂', 46.7582200, -0.9570300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50626, 'Saint-Projet-Saint-Constant', 'Saint-Projet-Saint-Constant', 'Saint-Projet,Saint-Projet-Saint-Constant,Sen-Prozhe-Sen-Konstan,Sent Proget e Sent Constanc,Sent Proget e Sent Constanç,sheng pu luo re sheng kong si tang,Сен-Проже-Сен-Констан,سین-پروجیٹ-سین-کانسٹنٹ,圣普罗热圣孔斯唐', 45.7280200, 0.3385100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50627, 'Saint-Prix', 'Saint-Prix', 'Saint-Prix', 49.0166700, 2.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50628, 'Saint-Privat-la-Montagne', 'Saint-Privat-la-Montagne', 'Saint-Privat,Saint-Privat-la-Montagne,Sen-Priva-la-Montan'',sheng pu li wa la meng ta ni,sn-prywa-la-mwntany,Сен-Прива-ла-Монтань,سن-پریوا-لا-مونتانی,سین-پروہت-لا-مونٹاگنے,圣普里瓦拉蒙塔尼', 49.1878900, 6.0383200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50629, 'Saint-Privat-des-Vieux', 'Saint-Privat-des-Vieux', 'La Font-le-Vieux,Marat-de-Bruege,Marat-de-Bruège,Saint-Privat,Saint-Privat-des-Vieux', 44.1441500, 4.1298800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50630, 'Saint-Privat', 'Saint-Privat', 'Privat-Haute-Montagne,Privat-le-Centre,Saint-Privat', 45.1385700, 2.0986900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50631, 'Saint-Privat', 'Saint-Privat', 'Saint-Privat', 44.6300200, 4.4165600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50632, 'Saint-Priest-Taurion', 'Saint-Priest-Taurion', 'Saint-Priest,Saint-Priest-Taurion', 45.8868600, 1.4001600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50633, 'Saint-Priest-sous-Aixe', 'Saint-Priest-sous-Aixe', 'Saint-Priest,Saint-Priest-sous-Aixe', 45.8166700, 1.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50634, 'Saint-Priest-en-Jarez', 'Saint-Priest-en-Jarez', 'Saint-Priest,Saint-Priest-en-Jarez,Sen-Prie-an-Zhare,ya lei de qu sheng pu li ye si,Сен-Пріє-ан-Жаре,سین-پریسٹ-ین-جرز,雅雷地区圣普里耶斯', 45.4750100, 4.3761400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50635, 'Saint-Priest', 'Saint-Priest', 'Beau-Priest,Saint-Priest,Zele-Patriote,Zélé-Patriote', 45.6961300, 4.9389100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50636, 'Saint-Priest', 'Saint-Priest', 'Saint-Priest,Val-d''Or', 44.7176700, 4.5462000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50637, 'Saint-Prest', 'Saint-Prest', 'Saint-Prest,Sen-Pre,sheng pu lei si,syn-prst,Сен-Пре,سین-پرست,圣普雷斯', 48.4910700, 1.5303400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50638, 'Saint-Pourçain-sur-Sioule', 'Saint-Pourcain-sur-Sioule', 'Mont-sur-Sioule,Saint-Pourcain,Saint-Pourcain-sur-Sioule,Saint-Pourçain,Saint-Pourçain-sur-Sioule,Sanctus Portianus,Sant Porcanh de Siula,Sant Porçanh de Siula,Sen-Pursen-sjur-S''jul'',Sen-Pursen-sjur-Siul'',san=purusan=shuru=shiuru,xi wu lei he pan sheng pu er sang,Сен-Пурсен-сюр-Сиуль,Сен-Пурсен-сюр-Сьюль,Сен-Пурсен-сюр-Сіуль,سین-پورکین-سور-سولے,サン＝プルサン＝シュル＝シウール,锡乌勒河畔圣普尔桑', 46.3092700, 3.2878700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50639, 'Saint-Pouange', 'Saint-Pouange', 'Saint-Pouange', 48.2265600, 4.0397900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50640, 'Saint-Porquier', 'Saint-Porquier', 'Mont-Porquier,Saint-Porquier', 44.0034400, 1.1793200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50641, 'Saint-Porchaire', 'Saint-Porchaire', 'L''Epine,Saint-Porchaire,Sen-Porsher,sheng bo er xie er,Сен-Поршер,سین-پورچیرے,圣波尔谢尔', 45.8207500, -0.7823500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50642, 'Saint-Pons-de-Thomières', 'Saint-Pons-de-Thomieres', '', 43.4833300, 2.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50643, 'Saint-Pol-sur-Ternoise', 'Saint-Pol-sur-Ternoise', 'Pol,Rernois-Libre,Saint-Po-su-Ternoese,Saint-Po-su-Térnoèse,Saint-Pol,Saint-Pol-sur-Ternoise,Sen-Pol''-sjur-Ternuaz,san bwl swr tyrnwys,tai nu wa si he pan sheng bo lei,Сен-Поль-сюр-Тернуаз,سان بول سور تيرنويس,سین-پول-سور-تیرنویسے,泰努瓦斯河畔圣波勒', 50.3811300, 2.3340700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50644, 'Saint-Pol-sur-Mer', 'Saint-Pol-sur-Mer', 'Saint-Po-dsu-Mer,Saint-Po-dsu-Mér,Saint-Pol,Saint-Pol-sur-Mer,Sen Pol sir Mer,Sen-Pol''-sjur-Mer,Sint-Pols,Sint-Pols-aan-Zee,sn pwl swr mr,Сен Пол сир Мер,Сен-Поль-сюр-Мер,سن پول سور مر', 51.0311600, 2.3398300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50645, 'Saint-Pol-de-Léon', 'Saint-Pol-de-Leon', 'Fanum Sancti Pauli Leonensis,Kastell-Paol,Mont-Frimaire,Port-Pol,Saint-Pol-de-Leon,Saint-Pol-de-Léon,Sen-Pol''-de-Leon,san=poru=do=reon,sheng bo de lai weng,snt pl d lywn,Сен-Поль-де-Леон,سنت پل د لئون,سین-پول-دے-لون,サン＝ポル＝ド＝レオン,圣波德莱翁', 48.6833300, -3.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50646, 'Saint-Planchers', 'Saint-Planchers', 'Saint-Planchers', 48.8226900, -1.5259800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50647, 'Saint-Pierre-sur-Dives', 'Saint-Pierre-sur-Dives', 'Saint-Pierre,Saint-Pierre-sur-Dives,Sen-P''er-sjur-Div,Sen-P''err-sjur-Div,Sen-Perr-sjur-Div,di wei he pan sheng pi ye er,syn-pyry-swr-dws,Сен-Пьер-сюр-Див,Сен-Пьерр-сюр-Див,Сен-Пєрр-сюр-Дів,سین-پیری-سور-دوس,迪韦河畔圣皮耶尔', 49.0166700, -0.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50648, 'Saint-Pierre-Quiberon', 'Saint-Pierre-Quiberon', 'Saint Pierre Quiberon,Saint-Pierre-Quiberon,Sant-Per-Kiberen,Sant-Pêr-Kiberen,Sen-P''err-Kiberon,Sen-Perr-Kiberon,sheng pi ye er qu yi bo long,syn-pyry-qbrwn,Сен-Пьерр-Киберон,Сен-Пєрр-Кіберон,سین-پیری-قبرون,圣皮耶尔屈伊伯龙', 47.5206100, -3.1308400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50649, 'Saint-Pierre-Montlimart', 'Saint-Pierre-Montlimart', 'Saint-Pierre,Saint-Pierre-Montlimard,Saint-Pierre-Montlimart,Sen-Perr-Monlimar,sheng pi ye er meng te li ma er,Сен-Пєрр-Монлімар,سین-پیری-مونتلمارٹ,圣皮耶尔蒙特利马尔', 47.2697600, -1.0273800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50650, 'Saint-Pierre-lès-Nemours', 'Saint-Pierre-les-Nemours', 'Saint-Pierre,Saint-Pierre-les-Nemours,Saint-Pierre-lès-Nemours,Sen-P''err-le-Nemur,Sen-Perr-le-Nemur,syn-pyry-lys-nmwrs,Сен-Пьерр-ле-Немур,Сен-Пєрр-ле-Немур,سین-پیری-لیس-نمورس', 48.2673300, 2.6796600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50651, 'Saint-Pierre-lès-Elbeuf', 'Saint-Pierre-les-Elbeuf', 'Saint-Pierre,Saint-Pierre-les-Elbeuf,Saint-Pierre-lès-Elbeuf', 49.2790100, 1.0430500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50652, 'Saint-Pierre-le-Moûtier', 'Saint-Pierre-le-Moutier', 'Brutus-la-Vallee,Brutus-la-Vallée,Brutus-le-Magnanime,Brutus-le-Moutier,Saint-Pierre,Saint-Pierre-le-Moutier,Saint-Pierre-le-Moûtier', 46.7927700, 3.1165700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50653, 'Saint-Pierre-la-Palud', 'Saint-Pierre-la-Palud', 'Palud-la-Montagne,Pelletier-la-Palud,Saint Pierre,Saint-Pierre-la-Palud', 45.7895600, 4.6129100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50654, 'Saint-Pierre-la-Cour', 'Saint-Pierre-la-Cour', 'Bourg-l''Union,Saint-Pierre,Saint-Pierre-la-Cour,Sen-Perr-la-Kur,sheng pi ye er la ku,syn-pyry-la-kwr,Сен-Пєрр-ла-Кур,سین-پیری-لا-کور,圣皮耶尔拉库', 48.1125800, -1.0249600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50655, 'Saint-Pierre-en-Val', 'Saint-Pierre-en-Val', 'Saint-Pierre,Saint-Pierre-en-Val', 50.0216800, 1.4470700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50656, 'Saint-Pierre-Église', 'Saint-Pierre-Eglise', 'Pierre-Ferme,Saint-Pierre,Saint-Pierre-Eglise,Saint-Pierre-Église', 49.6684800, -1.4035800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50657, 'Saint-Pierre-du-Vauvray', 'Saint-Pierre-du-Vauvray', 'Saint-Pierre,Saint-Pierre-du-Vauvray', 49.2320800, 1.2212500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50658, 'Saint-Pierre-du-Regard', 'Saint-Pierre-du-Regard', 'Saint-Pierre,Saint-Pierre-du-Regard', 48.8428600, -0.5463100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50659, 'Saint-Pierre-du-Perray', 'Saint-Pierre-du-Perray', 'Saint-Pierre,Saint-Pierre-du-Perray,Sen-P''err-dju-Perre,Sen-Perr-dju-Perre,sheng pi ye er lei di pei er lai,Сен-Пьерр-дю-Перре,Сен-Пєрр-дю-Перре,سین-پیری-دو-پارے,圣皮耶尔勒迪佩尔赖', 48.6106400, 2.4942900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50660, 'Saint-Pierre-du-Mont', 'Saint-Pierre-du-Mont', 'Saint-Pierre', 43.8845300, -0.5218500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50661, 'Saint-Pierre-du-Chemin', 'Saint-Pierre-du-Chemin', 'Chemin-sur-le-Lay,Saint-Pierre,Saint-Pierre-du-Chemin', 46.6952300, -0.7009500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50662, 'Saint-Pierre-de-Varengeville', 'Saint-Pierre-de-Varengeville', 'Saint-Pierre,Saint-Pierre-de-Varengeville,Sen-P''err-de-Varanzhvil'',Sen-Perr-de-Varanzhvil'',Сен-Пьерр-де-Варанжвиль,Сен-Пєрр-де-Варанжвіль,سین-پیری-دے-ورینگولے', 49.5024000, 0.9311800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50663, 'Saint-Pierre-des-Nids', 'Saint-Pierre-des-Nids', 'Saint-Pierre,Saint-Pierre-des-Nids,Sen-Perr-de-Ni,sheng pi ye er dai ni de,Сен-Пєрр-де-Ні,سین-پیری-دے-نڈس,圣皮耶尔代尼德', 48.3982600, -0.0998400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50664, 'Saint-Pierre-des-Fleurs', 'Saint-Pierre-des-Fleurs', 'Saint-Pierre,Saint-Pierre-des-Fleurs', 49.2500000, 0.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50665, 'Saint-Pierre-des-Échaubrognes', 'Saint-Pierre-des-Echaubrognes', 'Saint-Pierre,Saint-Pierre-des-Echaubrognes,Saint-Pierre-des-Échaubrognes', 46.9898800, -0.7444100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50666, 'Saint-Pierre-des-Corps', 'Saint-Pierre-des-Corps', 'La Clarte-Republicaine,La Clarté-Républicaine,Saint-Pierre,Saint-Pierre-des-Corps,Sen-Perr-de-Kor,sheng pi ye er dai ke er pu,Сен-Пєрр-де-Кор,سین-پیری-دے-کور,圣皮耶尔代科尔普', 47.3862300, 0.7484900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50667, 'Saint-Pierre-de-Plesguen', 'Saint-Pierre-de-Plesguen', 'Saint-Pierre,Saint-Pierre-de-Plesguen,Sant-Per-Plewenn,Sant-Pêr-Plewenn,Sen-P''err-de-Plegan,Sen-Perr-de-Plegan,sheng pi ye er de pu lai si gai en,Сен-Пьерр-де-Плеган,Сен-Пєрр-де-Плеган,سین-پیری-دے-پلسگین,圣皮耶尔德普莱斯盖恩', 48.4463800, -1.9127800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50668, 'Saint-Pierre-de-Chandieu', 'Saint-Pierre-de-Chandieu', 'Chandieu-la-Montagne,Saint Pierre Chandieu,Saint-Pierre,Saint-Pierre-de-Chandieu,Sen-Perr-de-Shand''e,Сен-Пєрр-де-Шандьє,سین-پیری-دے-چانڈیو', 45.6455800, 5.0112800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50669, 'Saint-Pierre-de-Bœuf', 'Saint-Pierre-de-Boeuf', 'Saint Pierre,Saint-Pierre-de-Boeuf', 45.3666700, 4.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50670, 'Saint-Piat', 'Saint-Piat', 'Martel-les-Vaux,Saint-Piat', 48.5466800, 1.5836300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50671, 'Saint-Philibert', 'Saint-Philibert', 'Saint-Philibert,Sant-Filberzh', 47.5882100, -2.9997800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50672, 'Saint-Philbert-du-Peuple', 'Saint-Philbert-du-Peuple', 'Saint-Philbert,Saint-Philbert-du-Peuple,Sen-Fil''ber-dju-Pepl'',sheng fei er bei er di po pu er,Сен-Фільбер-дю-Пепль,سین-فلبرٹ-دو-پیوپل,圣菲尔贝尔迪珀普尔', 47.3931400, -0.0436000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50673, 'Saint-Philbert-de-Grand-Lieu', 'Saint-Philbert-de-Grand-Lieu', 'Saint Philbert de Grand-Lieu,Saint-Philbert,Saint-Philbert-de-Grand-Lieu,Sanctus Philibertus de Grandi Lacu,Sant-Filberzh-Deaz,Sen-Fil''ber-de-Gran-L''e,san=firuberu=do=guran=ryu,sheng fei er bei er de ge lang de-li e,Сен-Фільбер-де-Гран-Льє,سین-فلبرٹ-دے-گرینڈ-لیو,サン＝フィルベール＝ド＝グラン＝リュー,圣菲尔贝尔德格朗德-利厄', 47.0358000, -1.6412000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50674, 'Saint-Philbert-de-Bouaine', 'Saint-Philbert-de-Bouaine', 'Saint-Philbert,Saint-Philbert-de-Bouaine', 46.9856800, -1.5202200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50675, 'Saint-Perreux', 'Saint-Perreux', 'Saint-Perreux,Sant-Pereg,Sen-Perre,sheng pei er lei,syn-pyryw,Сен-Перре,سین-پیریو,圣佩尔勒', 47.6695200, -2.1080900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50676, 'Saint-Père-sur-Loire', 'Saint-Pere-sur-Loire', 'Saint-Pere,Saint-Père,Sen-Per-sjur-Luar,lu wa er he pan sheng pei er,Сен-Пер-сюр-Луар,سین-پرے-سور-لوئر,卢瓦尔河畔圣佩尔', 47.7666700, 2.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50677, 'Saint-Père-en-Retz', 'Saint-Pere-en-Retz', 'Fraternite,Fraternité,Saint-Pere-en-Retz,Saint-Père-en-Retz,Sanctus Petrus,Sant-Per-Raez,Sant-Pêr-Raez,Sen-Per-an-Re,lei te de qu sheng pei er,Сен-Пер-ан-Ре,سین-پرے-ین-رٹز,雷特地区圣佩尔', 47.2055900, -2.0409500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50678, 'Saint-Père', 'Saint-Pere', 'Saint-Pere,Saint-Père,Sant-Per-Poualed,Sant-Pêr-Poualed', 48.5872700, -1.9241300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50679, 'Saint-Perdon', 'Saint-Perdon', '', 43.8656000, -0.5906900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50680, 'Saint-Péray', 'Saint-Peray', 'Peray-Vin-Blanc,Saint-Peray,Saint-Péray', 44.9479900, 4.8463000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50681, 'Saint-Pée-sur-Nivelle', 'Saint-Pee-sur-Nivelle', 'Beaugard,Saint-Pee,Saint-Pee-sur-Nivelle,Saint-Pée,Saint-Pée-sur-Nivelle,Sant Per dIbarra,Sen-Pe-sjur-Nivel'',Senpere,Sent Per de Nivela,Sent Pèr de Nivela,ni wei er he pan sheng pei ai,Сен-Пе-сюр-Нивель,Сен-Пе-сюр-Нівель,سین-پی-سور-نوالے,尼韦尔河畔圣佩埃', 43.3556400, -1.5501300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50682, 'Saint-Pé-de-Bigorre', 'Saint-Pe-de-Bigorre', 'Saint-Pe,Saint-Pe-de-Bigorre,Saint-Pé,Saint-Pé-de-Bigorre', 43.1036900, -0.1594300, 'FR', '2016-12-05', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50683, 'Saint-Paul-Trois-Châteaux', 'Saint-Paul-Trois-Chateaux', 'Paul-les-Fontaines,Saint-Paul,Saint-Paul-Trois-Chateaux,Saint-Paul-Trois-Châteaux,Sanctus Paulus Tricastinorum,Sant Pau de Tricastin,Sant Paul de Tricastin,Sen-Pol''-Trua-Shato,sheng bo te lu wa sha tuo,syn-pal-trws-shatyw,Сен-Поль-Труа-Шато,سین-پال-تروص-شاتیو,圣波特鲁瓦沙托', 44.3490900, 4.7657400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50684, 'Saint-Paul-lès-Romans', 'Saint-Paul-les-Romans', 'Paul-la-Joyeuse,Saint-Paul,Saint-Paul-les-Romans,Saint-Paul-lès-Romans', 45.0694600, 5.1357500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50685, 'Saint-Paul-lès-Dax', 'Saint-Paul-les-Dax', 'Bonnet-Rouge,Saint-Paul,Saint-Paul-les-Dax,Saint-Paul-lès-Dax,Sen-Pol''-le-Daks,Sent Pau dAcs,Sent Pau de Dacs,sheng bo lai da,Сен-Поль-ле-Дакс,سین-پال-لیس-ڈش,圣波莱达', 43.7271500, -1.0516200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50686, 'Saint-Paulien', 'Saint-Paulien', 'Saint-Paulien,Velaune', 45.1365000, 3.8138400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50687, 'Saint-Paulet-de-Caisson', 'Saint-Paulet-de-Caisson', 'Caisson,Saint Paulet,Saint-Paulet-de-Caisson,Saint-Paulet-des-Caissons,Sen-Pole-de-Kesson,Sent Paulet de Caisson,sheng bo lai de kai song,Сен-Поле-де-Кессон,سین-پلیٹ-دے-کایسون,圣波莱德凯松', 44.2605500, 4.5978500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50688, 'Saint-Paul-en-Pareds', 'Saint-Paul-en-Pareds', 'La Regeneree,La Regénérée,Saint-Paul,Saint-Paul-en-Pareds,Sen-Pol''-an-Pare,pa lei de de qu sheng bo,syn-pal-yn-prds,Сен-Поль-ан-Паре,سین-پال-ین-پردس,帕雷德地区圣波', 46.8221400, -0.9897700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50689, 'Saint-Paul-en-Jarez', 'Saint-Paul-en-Jarez', 'Saint-Paul,Saint-Paul-en-Jarez,Sen-Pol''-an-Zhare,Valdorley,syn-pal-yn-jrz,ya lei de qu sheng bo,Сен-Поль-ан-Жаре,سین-پال-ین-جرز,雅雷地区圣波', 45.4823900, 4.5713200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50690, 'Saint-Paul-en-Forêt', 'Saint-Paul-en-Foret', 'Saint-Paul,Saint-Paul-en-Foret,Saint-Paul-en-Forêt', 43.5676200, 6.6947500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50691, 'Saint-Paul-en-Cornillon', 'Saint-Paul-en-Cornillon', 'Saint Paul,Saint-Paul-en-Cornillon', 45.3964700, 4.2269400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50692, 'Saint-Paul-en-Chablais', 'Saint-Paul-en-Chablais', 'Saint Paul,Saint Paul 74500,Saint-Paul,Saint-Paul 74500,Saint-Paul-en-Chablais,Sen-Pol''-an-Shable,syn-pal-yn-chblys,Сен-Поль-ан-Шабле,سین-پال-ین-چبلیس', 46.3756900, 6.6371100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50693, 'Saint-Paul-de-Varces', 'Saint-Paul-de-Varces', 'Ancoin,Paul-d''Ancoin,Saint-Paul', 45.0717500, 5.6424700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50694, 'Saint-Paul-de-Varax', 'Saint-Paul-de-Varax', 'Saint-Paul,Saint-Paul-de-Varax,Varax', 46.0984800, 5.1289700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50695, 'Saint-Paul-des-Landes', 'Saint-Paul-des-Landes', 'Saint-Paul,Saint-Paul-des-Landes', 44.9441600, 2.3142000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50696, 'Saint-Paul-de-Jarrat', 'Saint-Paul-de-Jarrat', 'Saint Paul,Saint-Paul-de-Jarrat', 42.9140400, 1.6543700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50697, 'Saint-Paul-de-Fenouillet', 'Saint-Paul-de-Fenouillet', 'Saint-Paul,Saint-Paul-de-Fenouillet,Sant Pau de Fenolhet,Sant Pau de Fenollet,Sen-Pol''-de-Fenue,san=poru=do=fenuie,sheng bo de fang wu yi lai,Сен-Поль-де-Фенуе,Сен-Поль-де-Фенує,سین-پال-دے-فنویلت,サン＝ポール＝ド＝フェヌイエ,圣波德方乌伊莱', 42.8093800, 2.5037400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50698, 'Saint-Paul-Cap-de-Joux', 'Saint-Paul-Cap-de-Joux', 'Agout-Rousseau,Saint-Paul,Saint-Paul-Cap-de-Joux', 43.6479100, 1.9755900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50699, 'Saint-Paul', 'Saint-Paul', 'Saint-Paul', 49.4296200, 2.0075500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50700, 'Saint-Paul', 'Saint-Paul', 'Saint-Paul,Saint-Paul-d''Eyjeaux,Saint-Paul-d’Eyjeaux', 45.7511400, 1.4323800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50701, 'Saint-Paul-de-Vence', 'Saint-Paul-de-Vence', 'Oppidum Sancti Pauli,Saint-Paul de Vence,Saint-Paul i Alpes-Maritimes,Saint-Paul-de-Vence,Sant Pau,Sen Pol d''o Vans,Sen-Pol''-de-Vans,St Paul de Vence,san bwl dy fyns,san=poru=do=vu~ansu,sheng bao luo,Сен Пол дьо Ванс,Сен-Поль-де-Ванс,סן-פול-דה-ואנס,سان بول دي فينس,سین-پال-دے-ونکے,サン＝ポール＝ド＝ヴァンス,圣保罗', 43.7000000, 7.1166700, 'FR', '2017-06-01', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50702, 'Saint-Pathus', 'Saint-Pathus', 'Saint-Pathus,Sen-Patjus,Сен-Патюс,سینٹ-پتہس', 49.0713600, 2.7988600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50703, 'Saint-Paterne-Racan', 'Saint-Paterne-Racan', 'Les Bains,Saint-Paterne,Saint-Paterne-Racan', 47.6021300, 0.4847800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50704, 'Saint-Paterne', 'Saint-Paterne', 'Saint-Paterne', 48.4161400, 0.1127100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50705, 'Saint-Parres-aux-Tertres', 'Saint-Parres-aux-Tertres', 'Saint-Parres,Saint-Parres-aux-Tertres', 48.2978000, 4.1175200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50706, 'Saint-Parize-le-Châtel', 'Saint-Parize-le-Chatel', 'Brennery,Saint-Parize,Saint-Parize-le-Chatel,Saint-Parize-le-Châtel,Sen-Pariz-le-Shatel'',sheng pa li ci lai sha tai,Сен-Париз-ле-Шатель,سینٹ-پرزے-لے-چٹیل,圣帕里兹莱沙泰', 46.8544700, 3.1826700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50707, 'Saint-Pargoire', 'Saint-Pargoire', 'Pargoire-l''Herault,Pargoire-l''Hérault,Saint-Pargoire,Sant Pargoli,Sant Pargori,Sant Pargòli,Sant Pargòri,Sen-Parguar,sheng pa er gua er,Сен-Паргуар,سینٹ-پرگرے,圣帕尔瓜尔', 43.5276600, 3.5187000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50708, 'Saint-Pardoux-la-Rivière', 'Saint-Pardoux-la-Riviere', 'Saint-Pardoux,Saint-Pardoux-la-Riviere,Saint-Pardoux-la-Rivière,Sen-Pardu-la-Riv''er,Sen-Pardu-la-River,Sent Pardol de la Ribiera,Sent Pardol la Ribiera,sheng pa er du la li wei ai,Сен-Парду-ла-Ривьер,Сен-Парду-ла-Ривєр,سینٹ-پاردو-لا-ریویرے,圣帕尔杜拉里维埃', 45.4938800, 0.7465100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50709, 'Saint-Pardoux-Isaac', 'Saint-Pardoux-Isaac', 'Saint-Pardoux,Saint-Pardoux-Isaac', 44.6119000, 0.3734500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50710, 'Saint-Pardoux', 'Saint-Pardoux', 'La Viette,Saint-Pardoux', 46.5715500, -0.3054200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50711, 'Saint-Pantaléon-de-Larche', 'Saint-Pantaleon-de-Larche', 'La Fraternite,La Fraternité,Saint-Pantaleon,Saint-Pantaleon-de-Larche,Saint-Pantaléon,Saint-Pantaléon-de-Larche', 45.1413800, 1.4460900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50712, 'Saint-Pal-de-Mons', 'Saint-Pal-de-Mons', 'Pal-Senouire,Pal-Sénouire,Saint-Pal,Saint-Pal-de-Mans,Saint-Pal-de-Mons,Sant Paul de Monc,Sant Paul de Mònç,Sen-Pal''-de-Mon,sheng pa de meng,Сен-Паль-де-Мон,سینٹ-پل-دے-مونس,圣帕德蒙', 45.2462800, 4.2741200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50713, 'Saint-Palais-sur-Mer', 'Saint-Palais-sur-Mer', 'Chaumiere-sur-Mer,Chaumière-sur-Mer,Saint-Palais,Sen-Pale-sjur-Mer,bin hai sheng pa lai,Сен-Пале-сюр-Мер,سینٹ-پلیس-سر-مر,滨海圣帕莱', 45.6425500, -1.0881000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50714, 'Saint-Palais', 'Saint-Palais', 'Donapaleu,Mont-Bidouze,Saint-Palais', 43.3286700, -1.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50715, 'Saint-Pair-sur-Mer', 'Saint-Pair-sur-Mer', 'Pair-Libre,Saint-Pair,Saint-Pair-sur-Mer,Sen-Per-sjur-Mer,bin hai sheng pei,Сен-Пер-сюр-Мер,سینٹ-پیر-سر-مر,滨海圣佩', 48.8145500, -1.5676100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50716, 'Saint-Paër', 'Saint-Paer', 'Saint-Paer,Saint-Paër', 49.5145200, 0.8793500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50717, 'Saint-Pabu', 'Saint-Pabu', 'Saint-Pabu,Sant-Pabu,Sen-Pabju,san=pabyu,sheng pa bi,Сен-Пабю,سینٹ-پبو,サン＝パビュ,圣帕比', 48.5666700, -4.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50718, 'Saint-Ours', 'Saint-Ours', 'Saint-Ours', 45.8500300, 2.8932100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50719, 'Saint-Ouen-l’Aumône', 'Saint-Ouen-l''Aumone', 'L''Aumone-la-Montagne,L''Aumône-la-Montagne,Montagne-sur-Oise,Saint-Ouen-l''Aumone,Saint-Ouen-l’Aumône,Sent-Uan-l''Omon,san=to~uan=romonu,sheng wu ang luo mo na,sn awan lwmwn,Сент-Уан-л''Омон,سن اوآن لومون,サン＝トゥアン＝ロモヌ,圣乌昂洛莫纳', 49.0435300, 2.1213400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50720, 'Saint-Ouen-en-Belin', 'Saint-Ouen-en-Belin', 'Saint-Ouen,Saint-Ouen-en-Belin', 47.8330200, 0.2092400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50721, 'Saint-Ouen-du-Tilleul', 'Saint-Ouen-du-Tilleul', 'Saint-Ouen,Saint-Ouen-du-Tilleul', 49.2972300, 0.9476000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50722, 'Saint-Ouen-de-Thouberville', 'Saint-Ouen-de-Thouberville', 'Saint-Ouen,Saint-Ouen-de-Thouberville', 49.3572600, 0.8884800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50723, 'Saint-Ouën-des-Toits', 'Saint-Ouen-des-Toits', 'Saint-Ouen', 48.1333300, -0.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50724, 'Saint-Ouen-des-Alleux', 'Saint-Ouen-des-Alleux', 'Saint-Ouen,Saint-Ouen-des-Alleux,Sant-Owen-an-Alloz', 48.3280500, -1.4259000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50725, 'Saint-Ouen', 'Saint-Ouen', 'Saint-Ouen,Sankt-Ouehn,Санкт-Оуэн', 50.0381900, 2.1208800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50726, 'Saint-Ouen', 'Saint-Ouen', 'Bain-sur-Seine,Saint-Ouen,Saint-Ouen-sur-Seine,Sankt-Ouehn,Санкт-Оуэн', 48.9065400, 2.3333900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50727, 'Saint-Ouen', 'Saint-Ouen', 'Fondouen,Saint-Ouen,Sankt-Ouehn,Санкт-Оуэн', 47.8140400, 1.0806700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50728, 'Saint-Orens-de-Gameville', 'Saint-Orens-de-Gameville', 'Saint-Orens,Saint-Orens-de-Gameville,Sant Orenc de Gamevila,Sant Orenç de Gamevila,Sent Orenc,Sent Orenç,Sent-Oran-de-Gamevil'',Sent-Orens-de-Gamvil'',sheng ao lang de jia mo wei er,Сент-Оран-де-Гамевіль,Сент-Оренс-де-Гамвиль,سینٹ-ارنس-دے-گمولے,圣奥朗德加默维尔', 43.5540200, 1.5341100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50729, 'Saint-Omer-en-Chaussée', 'Saint-Omer-en-Chaussee', 'Saint-Omer,Saint-Omer-en-Chaussee,Saint-Omer-en-Chaussée,Sent-Omer-an-Shosse,shao sai ai de qu sheng ao mei,Сент-Омер-ан-Шоссе,سینٹ-امر-این -چوسسے,绍塞埃地区圣奥梅', 49.5314200, 2.0033500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50730, 'Saint-Omer', 'Saint-Omer', 'Saint-Omer,Sint-Omaars,XSG', 50.7500000, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50731, 'Saint-Nom-la-Bretêche', 'Saint-Nom-la-Breteche', 'Saint-Nom-la-Breteche,Saint-Nom-la-Bretêche,Union-la-Montagne', 48.8594200, 2.0223300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50732, 'Saint-Nolff', 'Saint-Nolff', 'Saint-Nolff,Sant-Nolf,Sen-Nol''ff,sheng nuo er,Сен-Нольфф,سینٹ-نولفف,圣诺尔', 47.7036500, -2.6520900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50733, 'Saint-Nizier-sous-Charlieu', 'Saint-Nizier-sous-Charlieu', 'Saint-Nizier,Saint-Nizier-sous-Charlieu,Sen-Niz''e-su-Sharl''e,sheng ni qi ye su sha er li e,Сен-Нізьє-су-Шарльє,سینٹ-نظیر-سوس-چرلیو,圣尼齐耶苏沙尔利厄', 46.1535100, 4.1227900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50734, 'Saint-Nicolas-du-Pélem', 'Saint-Nicolas-du-Pelem', 'Saint-Nicolas,Saint-Nicolas-du-Pelem,Saint-Nicolas-du-Pélem,Sant-Nikolaz-ar-Pelem,Sen-Nikola-dju-Pelem,sheng ni ke la di pei lang,Сен-Никола-дю-Пелем,Сен-Нікола-дю-Пелем,سینٹ-نکولس-دو-پلم,圣尼科拉迪佩朗', 48.3122200, -3.1646500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50735, 'Saint-Nicolas-de-Redon', 'Saint-Nicolas-de-Redon', 'Saint-Nicolas,Saint-Nicolas-de-Redon,Sant-Nikolaz-an-Hent,Sen-Nikola-de-Redon,Union-sur-Vilaine,sheng ni ke la de lei dong,Сен-Нікола-де-Редон,سینٹ-نکولس-دے-رڈوں,圣尼科拉德雷东', 47.6434300, -2.0630500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50736, 'Saint-Nicolas-de-Port', 'Saint-Nicolas-de-Port', 'Port-sur-Meurthe,Saint-Nicolas,Saint-Nicolas-de-Port,Saint-Nicolas-du-Port,Sen-Nikola-de-Por,sheng ni ke la de bo er,Сен-Никола-де-Пор,Сен-Нікола-де-Пор,سینٹ-نکولس-دے-پورٹ,圣尼科拉德波尔', 48.6308900, 6.3003900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50737, 'Saint-Nicolas-de-la-Taille', 'Saint-Nicolas-de-la-Taille', 'Saint-Nicolas,Saint-Nicolas-de-la-Taille,Sen-Nikola-de-la-Taj,Сен-Никола-де-ла-Тай,Сен-Нікола-де-ла-Тай,سینٹ-نکولس-دے-لا-تالے', 49.5108500, 0.4740500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50738, 'Saint-Nicolas-de-la-Grave', 'Saint-Nicolas-de-la-Grave', 'La Grave-Bec-du-Tarn,La Grave-du-Bec,Saint-Nicolas,Saint-Nicolas-de-la-Grave,Saint-Nicolas-la-Grave,Sen-Nikola-de-la-Grav,Sent Micolau,Sent Micolau de la Grava,sheng ni ke la de la-ge la wo,Сен-Нікола-де-ла-Грав,سینٹ-نکولس-دے-لا-گریو,圣尼科拉德拉-格拉沃', 44.0641700, 1.0228000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50739, 'Saint-Nicolas-de-Bourgueil', 'Saint-Nicolas-de-Bourgueil', 'Saint-Nicolas,Saint-Nicolas-de-Bourgueil', 47.2849300, 0.1272700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50740, 'Saint-Nicolas-d’Aliermont', 'Saint-Nicolas-d''Aliermont', 'Saint-Nicolas,Saint-Nicolas-d''Aliermont,Saint-Nicolas-d’Aliermont', 49.8785700, 1.2248600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50741, 'Saint-Nicolas', 'Saint-Nicolas', 'Saint Nicolas Les Arras,Saint-Nicolas,Saint-Nicolas-lez-Arras,Saint-Nicolas-lèz-Arras', 50.3041300, 2.7793900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50742, 'Saint-Nazaire', 'Saint-Nazaire', 'Fanum Sancti Nazarii in Sinnuario,SNR,Sain-Nazair,Saint-Nazaire,Sant-Nazer,Sen Nazer,Sen Nazeras,Sen-Nazer,cen nacer,saengnajeleu,san=nazeru,sheng na ze er,sn nzr,sn-nzr,Σαιν-Ναζαίρ,Сен Назер,Сен-Назер,سن نزر,سن-نزر,سینٹ-نظارے,சென் நசேர்,แซ็ง-นาแซร์,サン＝ナゼール,圣纳泽尔,생나제르', 47.2833300, -2.2000000, 'FR', '2017-01-16', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50743, 'Saint-Nazaire-les-Eymes', 'Saint-Nazaire-les-Eymes', 'Saint-Nazaire', 45.2492100, 5.8525400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50744, 'Saint-Nazaire', 'Saint-Nazaire', 'Sen-Nazer,Сен-Назер', 44.1983300, 4.6241300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50745, 'Saint-Nazaire', 'Saint-Nazaire', 'Saint-Nazaire,Sant Nazari,Sen-Nazer,Сен-Назер', 42.6679000, 2.9916800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50746, 'Saint-Nauphary', 'Saint-Nauphary', 'Saint-Nauphary', 43.9671200, 1.4254900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50747, 'Saint-Nabord', 'Saint-Nabord', 'Roche-Libre,Saint-Nabord,Sen-Nabor,sheng na bo er,Сен-Набор,سینٹ-نبورد,圣纳博尔', 48.0517100, 6.5824800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50748, 'Saint-Morillon', 'Saint-Morillon', 'Saint-Morillon', 44.6506000, -0.5032200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50749, 'Saint-Molf', 'Saint-Molf', 'Saint-Molf,Sanctus Madulfus,Sant-Molf,Sen-Mol'',sheng mo er,Сен-Моль,سینٹ-مولف,圣莫尔', 47.3916700, -2.4235700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50750, 'Saint-Mitre-les-Remparts', 'Saint-Mitre-les-Remparts', 'Bellefont,Saint-Mitre,Saint-Mitre-les-Remparts,Sant Mitre,Sant Mitre dei Barris,Sen-Mitr-le-Rampar,sheng mi te er lai lang pa er te,Сен-Митр-ле-Рампар,Сен-Мітр-ле-Рампар,سینٹ-مٹرے-لیس-ریمپرٹس,圣米特尔莱朗帕尔特', 43.4548800, 5.0170200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50751, 'Saint-Mihiel', 'Saint-Mihiel', 'Roche-sur-Meuse,Saint-Mihiel,Sen-Miel'',sheng mi ye,Сен-Миель,Сен-Мієль,سینٹ-مہیل,圣米耶', 48.8874600, 5.5509900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50752, 'Saint-Michel-sur-Orge', 'Saint-Michel-sur-Orge', 'Saint-Michel,Saint-Michel-sur-Orge,Sen Mishel sir Orzh,Sen-Mishel''-sjur-Orzh,ao er ri he pan sheng mi she,saengmisyelswileuoleuju,san=misheru=shuru=oruju,sn myshl swr awrzh,Сен Мишел сир Орж,Сен-Мишель-сюр-Орж,Сен-Мішель-сюр-Орж,سن میشل سور اورژ,سینٹ-مشیل-سر-ورگے,サン＝ミシェル＝シュル＝オルジュ,奥尔日河畔圣米舍,생미셸쉬르오르주', 48.6347900, 2.3083100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50753, 'Saint-Michel-sur-Meurthe', 'Saint-Michel-sur-Meurthe', 'Belmont,Saint-Michel,Saint-Michel-sur-Meurthe,Sen-Mishel''-sjur-Mert,mo er te he pan sheng mi she,Сен-Мишель-сюр-Мерт,Сен-Мішель-сюр-Мерт,سینٹ-مشیل-سر-میرٹھ,默尔特河畔圣米舍', 48.3221900, 6.8902400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50754, 'Saint-Michel-Mont-Mercure', 'Saint-Michel-Mont-Mercure', 'Le Mont-Mercure,Saint-Michel,Saint-Michel-Mont-Mercure,Sen-Mishel''-Mon-Merkjur,sheng mi she meng mei er qu lei,Сен-Мішель-Мон-Меркюр,سینٹ-مشیل-مونٹ-مرکرے,圣米舍蒙梅尔屈勒', 46.8294100, -0.8829800, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50755, 'Saint-Michel-le-Cloucq', 'Saint-Michel-le-Cloucq', 'Saint-Michel,Saint-Michel-le-Cloucq,Sen-Mishel''-le-Kluk,sheng mi she lei ke lu,Сен-Мішель-ле-Клук,سینٹ-مشیل-لے-کلوکق,圣米舍勒克卢', 46.4850000, -0.7526200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50756, 'Saint-Michel-de-Maurienne', 'Saint-Michel-de-Maurienne', 'Pas-du-Roc,Saint-Michel,Saint-Michel-de-Maurienne,Sen-Mishel''-de-Morenn,Сен-Мішель-де-Морєнн,سینٹ-مشیل-دے-مورینے', 45.2184200, 6.4725700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50757, 'Saint-Michel-Chef-Chef', 'Saint-Michel-Chef-Chef', 'Chemicherium,Saint-Michel,Saint-Michel-Chef-Chef,Sant-Mikael-Keveger,Sen-Mishel''-Shef-Shef,san=misheru=shefu=shefu,sheng mi she xie xie,Сен-Мішель-Шеф-Шеф,سینٹ-مشیل-چیف-چیف,サン＝ミシェル＝シェフ＝シェフ,圣米舍谢谢', 47.1807200, -2.1486900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50758, 'Saint-Michel', 'Saint-Michel', 'Saint-Michel', 49.9195200, 4.1327800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50759, 'Saint-Michel', 'Saint-Michel', 'Saint-Michel', 45.6500000, 0.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50760, 'Saint-Mexant', 'Saint-Mexant', '', 45.2833300, 1.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50761, 'Saint-Mesmin', 'Saint-Mesmin', 'Beauvallon-sur-Sevre,Beauvallon-sur-Sèvre,Saint-Mesmin', 46.7936900, -0.7326200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50762, 'Saint-Menges', 'Saint-Menges', 'Saint-Menges,Sen-Manzh,Union,Сен-Манж,سینٹ-منگس', 49.7387300, 4.9262800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50763, 'Saint-Memmie', 'Saint-Memmie', 'Brutus,Saint-Memmie', 48.9524700, 4.3840900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50764, 'Saint-Même-le-Tenu', 'Saint-Meme-le-Tenu', 'Saint-Meme,Saint-Meme-le-Tenu,Saint-Même,Saint-Même-le-Tenu,Sant-Masen-ar-Porzh,Sen-Mem-le-Tenju,sheng mei mu lai te ni,Сен-Мем-ле-Теню,سینٹ-ممے-لے-تنوع,圣梅姆莱特尼', 47.0200500, -1.7945900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50765, 'Saint-Même-les-Carrières', 'Saint-Meme-les-Carrieres', 'Saint-Meme,Saint-Meme-les-Carrieres,Saint-Même,Saint-Même-les-Carrières,Sen-Mem-le-Kar''er,Sen-Mem-le-Karrer,sheng mei mu lai ka er li ai,Сен-Мем-ле-Каррєр,Сен-Мем-ле-Карьер,سینٹ-ممے-لیس-کرریرس,圣梅姆莱卡尔里埃', 45.6500000, -0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50766, 'Saint-Méloir-des-Ondes', 'Saint-Meloir-des-Ondes', 'Meloir-Richeux,Méloir-Richeux,Saint Meloir des Ondres,Saint-Meloir-des-Ondes,Saint-Méloir-des-Ondes,Sant-Meleg', 48.6379000, -1.9044800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50767, 'Saint-Melaine-sur-Aubance', 'Saint-Melaine-sur-Aubance', 'Aubance,Saint-Melaine,Saint-Mélaine,Sen-Melen-sjur-Obans,ao bang ke he pan sheng mo lan,Сен-Мелен-сюр-Обанс,سینٹ-ملانے-سر-اوبنکے,奥邦克河畔圣默兰', 47.3666700, -0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50768, 'Saint-Méen-le-Grand', 'Saint-Meen-le-Grand', 'Meen-Libre,Meen-la-Foret,Méen-Libre,Méen-la-Forêt,Saint-Meen,Saint-Meen-le-Grand,Saint-Méen,Saint-Méen-le-Grand,Sanctus Mevennus,Sant-Meven,Sen-Mean-le-Gran,da sheng mei ang,Сен-Меан-ле-Гран,سینٹ-مین-لے-گرینڈ,大圣梅昂', 48.1897100, -2.1948600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50769, 'Saint-Médard-sur-Ille', 'Saint-Medard-sur-Ille', 'Saint-Medard,Saint-Medard-sur-Ille,Saint-Médard,Saint-Médard-sur-Ille,Sant-Marzh-an-Il', 48.2720200, -1.6596800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50770, 'Saint-Médard-en-Jalles', 'Saint-Medard-en-Jalles', 'Fulminant,Saint-Medard,Saint-Medard-en-Jalles,Saint-Médard,Saint-Médard-en-Jalles,Sankt-Medard-an-Zhall'',Sen Medar an Zhal,Sen-Medar-an-Zhal'',Sent Medard de Jalas,saengmedaleuangjal,san=medaru=an=jaru,sn mdrdan zhl,ya lai de qu sheng mei da er,Санкт-Медард-ан-Жалль,Сен Медар ан Жал,Сен-Медар-ан-Жаль,سن مدردان ژل,سینٹ-میڈرڈ-این -جلوس,サン＝メダール＝アン＝ジャル,雅莱地区圣梅达尔,생메다르앙잘', 44.8969200, -0.7213600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50771, 'Saint-Médard-de-Mussidan', 'Saint-Medard-de-Mussidan', 'Saint-Medard,Saint-Medard-de-Mussidan,Saint-Médard,Saint-Médard-de-Mussidan', 45.0333300, 0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50772, 'Saint-Médard-de-Guizières', 'Saint-Medard-de-Guizieres', 'Saint-Medard,Saint-Medard-de-Guizieres,Saint-Médard,Saint-Médard-de-Guizières', 45.0166700, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50773, 'Saint-Maxire', 'Saint-Maxire', 'Saint-Maxire', 46.3991100, -0.4798800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50774, 'Saint-Maximin-la-Sainte-Baume', 'Saint-Maximin-la-Sainte-Baume', 'Marathon,Saint-Maximin,Saint-Maximin-la-Sainte-Baume,Sant Maissemin de la Santa Bauma,Sant Maissimin,Sen-Maksimen-la-Sent-Bom,saeng magsimang la saengteu bome,san=makushiman=ra=santo=bomu,sheng ma ke xi man la-sang te bo mo,Сен-Максимен-ла-Сент-Бом,Сен-Максімен-ла-Сент-Бом,سینٹ-شمن-لا-سین-بومے,サン＝マクシマン＝ラ＝サント＝ボーム,圣马克西曼拉-桑特博默,생 막시망 라 생트 보메', 43.4521400, 5.8621900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50775, 'Saint-Maximin', 'Saint-Maximin', 'Maximum,Saint-Maximin', 49.2218200, 2.4535900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50776, 'Saint-Max', 'Saint-Max', 'Max-la-Montagne,Saint-Max,Sen-Maks,sheng ma,Сен-Макс,سینٹ-میکس,圣马', 48.7042900, 6.2099900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50777, 'Saint-Maurice-sur-Moselle', 'Saint-Maurice-sur-Moselle', 'Saint-Maurice,Saint-Maurice-sur-Moselle,Sen Moris sur Mozelis,Sen-Moris-sjur-Mozel'',mo ze er he pan sheng mo li sai,Сен-Морис-сюр-Мозель,سینٹ-موریس-سر-موسیلے,摩泽尔河畔圣莫里塞', 47.8588900, 6.8247700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50778, 'Saint-Maurice-sur-Fessard', 'Saint-Maurice-sur-Fessard', 'Saint-Maurice,Saint-Maurice-sur-Fessard,Sen-Moris-sjur-Fessar,fei sa er he pan sheng mo li ke,Сен-Морис-сюр-Фессар,سینٹ-موریس-سر-فسسرد,费萨尔河畔圣莫里克', 47.9923100, 2.6215700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50779, 'Saint-Maurice-sur-Dargoire', 'Saint-Maurice-sur-Dargoire', 'Desille-sur-Dargoire,Désille-sur-Dargoire,Saint-Maurice,Saint-Maurice-sur-Dargoire', 45.5811700, 4.6311300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50780, 'Saint-Maurice-Montcouronne', 'Saint-Maurice-Montcouronne', 'Saint-Maurice,Saint-Maurice-Montcouronne,Sen-Moris-Monkuronn,sheng mo li sai meng te ku luo na,Сен-Морис-Монкуронн,سینٹ-موریس-مونتکوروں نے,圣莫里塞蒙特库罗纳', 48.5828800, 2.1250400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50781, 'Saint-Maurice-la-Souterraine', 'Saint-Maurice-la-Souterraine', 'Saint-Maurice,Saint-Maurice-la-Souterraine', 46.2138800, 1.4313000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50782, 'Saint-Maurice-la-Clouère', 'Saint-Maurice-la-Clouere', 'Saint-Maurice,Saint-Maurice-la-Clouere,Saint-Maurice-la-Clouère,Sen-Moris-la-Kluer,sheng mo li se la ke lu ai lei,Сен-Морис-ла-Клуер,سینٹ-موریس-لا-کلویرے,圣莫里瑟拉克卢埃勒', 46.3780400, 0.4125300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50783, 'Saint-Maurice-en-Gourgois', 'Saint-Maurice-en-Gourgois', 'Saint-Maurice,Saint-Maurice-en-Gourgois,Sant Maurise de Gorgos,Sant Maurise de Gorgós,Sen-Moris-an-Gurgua,gu er gua de qu sheng mo li ke,Сен-Морис-ан-Гургуа,سینٹ-موریس-این -گورگوس,古尔瓜地区圣莫里克', 45.4024600, 4.1823500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50784, 'Saint-Maurice-de-Lignon', 'Saint-Maurice-de-Lignon', 'Lignon,Saint-Maurice,Saint-Maurice-de-Lignon', 45.2243100, 4.1391100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50785, 'Saint-Maurice-de-Gourdans', 'Saint-Maurice-de-Gourdans', 'Saint Maurice,Saint-Maurice-de-Gourdan,Saint-Maurice-de-Gourdans', 45.8214000, 5.1946400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50786, 'Saint-Maurice-de-Beynost', 'Saint-Maurice-de-Beynost', 'La Fontaine,Saint Maurice,Saint-Maurice-de-Beynost,Sen Moris de Beno,Sen-Moris-de-Bejno,Sen-Moris-de-Beno,san-mwrys-dw-bynws  ayn,sheng mo li si de bei nuo si te,sn-mwrys-d-bynwst,Сен-Морис-де-Бейно,Сен-Морис-де-Бено,Սեն Մորիս դե Բենո,سان-موريس-دو-بينوس، أين,سن-موریس-د-بینوست,سینٹ-موریس-دے-بینوسٹ,圣莫里斯德贝诺斯特', 45.8344000, 4.9775000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50787, 'Saint-Maurice', 'Saint-Maurice', 'Charenton-Saint-Maurice,Saint-Maurice', 48.8218200, 2.4271600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50788, 'Saint-Maur-des-Fossés', 'Saint-Maur-des-Fosses', 'Saint-Maur,Saint-Maur-des-Fosses,Saint-Maur-des-Fossés,Saint-Maur-les-Fosses,Saint-Maur-les-Fossés,Sen Mor de Fose,Sen-Mor-de-Fosse,Vivant-sur-Marne,saengmoleudepose,san mwr dyh fwsyh,san=moru=de=fosse,sheng mo dai fu sai,sn mwr dfwsh,sn-mr-d-fwsh,Сен Мор де Фосе,Сен-Мор-де-Фоссе,سان مور ديه فوسيه,سن مور دفوسه,سن-مر-د-فوسه,سینٹ-موڑ-دس-فوسسس,サン＝モール＝デ＝フォッセ,圣莫代福塞,생모르데포세', 48.7939500, 2.4932300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50789, 'Saint-Maur', 'Saint-Maur', 'Saint-Maur', 46.8065700, 1.6390400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50790, 'Saint-Mathurin-sur-Loire', 'Saint-Mathurin-sur-Loire', 'Port-de-la-Vallee,Port-de-la-Vallée,Saint-Mathurin,Sen-Matjuren-sjur-Luar,lu wa er he pan sheng ma di lan,Сен-Матюрен-сюр-Луар,سینٹ-مطہریں -سر-لڑے,卢瓦尔河畔圣马蒂兰', 47.4166700, -0.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50791, 'Saint-Mathurin', 'Saint-Mathurin', 'Saint-Mathurin', 46.5649300, -1.7138900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50792, 'Saint-Mathieu-de-Tréviers', 'Saint-Mathieu-de-Treviers', 'Saint-Mathieu,Saint-Mathieu-de-Treviers,Saint-Mathieu-de-Tréviers,Sant Matieu de Treviers,Sant Matieu de Trevièrs,Sant Matiu,Sen-Mat''e-de-Trev''e,Sen-Mat''e-de-Treve,sheng ma di e de te lei wei ye er,Сен-Матье-де-Тревье,Сен-Матьє-де-Тревє,سینٹ-متھیو-دے-ترویرس,圣马蒂厄德特雷维耶尔', 43.7679500, 3.8581400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50793, 'Saint-Mathieu', 'Saint-Mathieu', 'Saint-Mathieu', 45.7067400, 0.7590800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50794, 'Saint-Martin-Vésubie', 'Saint-Martin-Vesubie', 'Fanum Sancti Martini Lantuscanorum,Saint-Martin,Saint-Martin-Vesubie,Saint-Martin-Vésubie,Saint-Martin-de-Vesubie,Saint-Martin-de-Vésubie,San Martino Lantosca,Sant Martin de Lantosca,Sant Martin de Vesubia,Sant Martin de Vesubiá,Sen-Marten-Vezjubi,san martn fyswby,sheng ma dan wei xu bi ye,Сен-Мартен-Везюби,Сен-Мартен-Везюбі,سان مارتن فيسوبي,سینٹ-مارٹن-وسبئے,圣马丹韦叙比耶', 44.0700400, 7.2554700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50795, 'Saint-Martin-sur-Oust', 'Saint-Martin-sur-Oust', 'Saint-Martin,Saint-Martin-sur-Oust,Sant-Varzhin-an-Oud,Sen-Marten-sjur-Ust,wu si he pan sheng ma dan,Сен-Мартен-сюр-Уст,سینٹ-مارٹن-سر-وسط,乌斯河畔圣马丹', 47.7460000, -2.2534300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50796, 'Saint-Martin-sur-Ocre', 'Saint-Martin-sur-Ocre', 'Saint-Martin,Saint-Martin-sur-Ocre', 47.6594200, 2.6581000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50797, 'Saint-Martin-sous-Mouzeuil', 'Saint-Martin-sous-Mouzeuil', 'Saint-Martin,Saint-Martin-sous-Mouzeuil', 46.4590500, -0.9889300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50798, 'Saint-Martin-Osmonville', 'Saint-Martin-Osmonville', 'Saint-Martin-Omonville,Saint-Martin-Osmonville', 49.6387300, 1.2995200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50799, 'Saint-Martin-Longueau', 'Saint-Martin-Longueau', 'Saint-Martin-Longueau,Sen-Marten-Longo,sheng ma dan long gai ao,Сен-Мартен-Лонго,سینٹ-مارٹن-لونگو,圣马丹隆盖奥', 49.3428100, 2.6027600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50800, 'Saint-Martin-le-Vinoux', 'Saint-Martin-le-Vinoux', 'Saint-Martin,Saint-Martin-le-Vinoux,Sen-Marten-le-Vinu,sheng ma dan lai wei nu,Сен-Мартен-ле-Вину,Сен-Мартен-ле-Віну,سینٹ-مارٹن-لے-نوش,圣马丹莱维努', 45.2030000, 5.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50801, 'Saint-Martin-le-Beau', 'Saint-Martin-le-Beau', 'Etableau,Le Beau-sur-Cher,Saint-Martin,Saint-Martin-le-Beau', 47.3556600, 0.9095300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50802, 'Saint-Martin-la-Plaine', 'Saint-Martin-la-Plaine', 'Saint-Martin,Saint-Martin-la-Plaine,Sen-Marten-la-Plen,sheng ma dan la pu lan,Сен-Мартен-ла-Плен,سینٹ-مارٹن-لا-پلانے,圣马丹拉普兰', 45.5473900, 4.5911500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50803, 'Saint-Martin-Lalande', 'Saint-Martin-Lalande', 'Saint Martin,Saint-Martin-Lalande', 43.2992800, 2.0200400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50804, 'Saint-Martin-Lacaussade', 'Saint-Martin-Lacaussade', 'Saint-Martin,Saint-Martin-Lacaussade', 45.1463100, -0.6431000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50805, 'Saint-Martin-en-Haut', 'Saint-Martin-en-Haut', 'Martin-l''Esperance,Martin-l''Espérance,Saint-Martin,Saint-Martin-d''en-Haut,Saint-Martin-d’en-Haut,Saint-Martin-en-Haut', 45.6596900, 4.5615300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50806, 'Saint-Martin-en-Campagne', 'Saint-Martin-en-Campagne', 'Saint-Martin,Saint-Martin-en-Campagne', 49.9564800, 1.2223300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50807, 'Saint-Martin-en-Bresse', 'Saint-Martin-en-Bresse', 'Saint-Martin,Saint-Martin-en-Bresse,Tell-les-Bois', 46.8172500, 5.0602700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50808, 'Saint-Martin-du-Vivier', 'Saint-Martin-du-Vivier', 'Saint-Martin,Saint-Martin-du-Vivier', 49.4666700, 1.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50809, 'Saint-Martin-du-Var', 'Saint-Martin-du-Var', 'Saint-Martin,Saint-Martin-du-Var', 43.8181200, 7.1903000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50810, 'Saint-Martin-du-Tertre', 'Saint-Martin-du-Tertre', 'Saint-Martin,Saint-Martin-du-Tertre', 49.1074300, 2.3453300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50811, 'Saint-Martin-du-Tertre', 'Saint-Martin-du-Tertre', 'Martin-Bel-Air,Saint-Martin,Saint-Martin-du-Tertre', 48.2165900, 3.2615100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50812, 'Saint-Martin-du-Mont', 'Saint-Martin-du-Mont', 'Bellevue,Saint-Martin,Saint-Martin-du-Mont', 46.1024700, 5.3283400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50813, 'Saint-Martin-du-Manoir', 'Saint-Martin-du-Manoir', 'Saint-Martin,Saint-Martin-du-Manoir', 49.5321300, 0.2375900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50814, 'Saint-Martin-du-Frêne', 'Saint-Martin-du-Frene', 'Mont-de-Fresne,Saint-Martin-du-Frene,Saint-Martin-du-Fresne,Saint-Martin-du-Frêne', 46.1385700, 5.5530200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50815, 'Saint-Martin-du-Fouilloux', 'Saint-Martin-du-Fouilloux', 'Saint-Martin,Saint-Martin-du-Fouilloux,Unite-sur-Loire,Unité-sur-Loire', 47.4336000, -0.7035700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50816, 'Saint-Martin-d’Hères', 'Saint-Martin-d''Heres', 'Heres-la-Montagne,Hères-la-Montagne,Saint-Martin,Saint-Martin-d''Heres,Saint-Martin-d''Hères,Saint-Martin-d’Hères,Sen-Marten-d''Ehr,Sen-Marten-d''Er,san martan dyrys,san=marutan=deru,sheng ma dan dai lei,sn mrtn dr,Сен-Мартен-д''Ер,Сен-Мартен-д''Эр,سان مارتان ديريس,سن مرتن در,サン＝マルタン＝デール,圣马丹代雷', 45.1652800, 5.7633700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50817, 'Saint-Martin-de-Valgalgues', 'Saint-Martin-de-Valgalgues', 'Mont-Valgalgues,Mont-Valgue,Saint-Martin,Saint-Martin-de-Valgalgues', 44.1631500, 4.0836400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50818, 'Saint-Martin-de-Valamas', 'Saint-Martin-de-Valamas', 'Mas-d''Erieu,Saint-Martin,Saint-Martin-de-Valamas', 44.9364800, 4.3655700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50819, 'Saint-Martin-des-Noyers', 'Saint-Martin-des-Noyers', 'Les Noyers,Saint-Martin,Saint-Martin-des-Noyers', 46.7222600, -1.1772700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50820, 'Saint-Martin-de-Seignanx', 'Saint-Martin-de-Seignanx', 'Montagne-Seignaux,Saint-Martin,Saint-Martin-de-Seignanx,Saint-Martin-de-Seignaux,Sen-Marten-de-Sen''jan,Sent Martin de Senhans,sheng ma dan de sai ni ang,Сен-Мартен-де-Сеньян,圣马丹德塞尼昂', 43.5428300, -1.3894600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50821, 'Saint-Martin-des-Champs', 'Saint-Martin-des-Champs', 'Saint-Martin,Saint-Martin-des-Champs', 48.6684100, -1.3339300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50822, 'Saint-Martin-des-Champs', 'Saint-Martin-des-Champs', 'Saint-Martin,Saint-Martin-des-Champs,Sant-Martin-war-ar-Maez,Unite-des-Champs,Unité-des-Champs', 48.5833300, -3.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50823, 'Saint-Martin-des-Besaces', 'Saint-Martin-des-Besaces', 'Saint-Martin,Saint-Martin-des-Besaces,Sen-Marten-de-Bezas,sheng ma dan dai bei sa sai,Сен-Мартен-де-Безас,سینٹ-مارٹن-دس-بسکس,圣马丹代贝萨塞', 49.0109100, -0.8450000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50824, 'Saint-Martin-de-Ré', 'Saint-Martin-de-Re', 'Fort-de-la-Montagne,Ile-de-la-Republique,Ile-de-la-République,Saint-Martin,Saint-Martin-de-Re,Saint-Martin-de-Ré,Sen-Marten-de-Re,san martyn dw ry,sheng ma dan de lei,Сен-Мартен-де-Ре,سان مارتين دو ري,سینٹ-مارٹن-دے-رے,圣马丹德雷', 46.2031100, -1.3672600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50825, 'Saint-Martin-de-Queyrières', 'Saint-Martin-de-Queyrieres', 'Roche-Forte,Saint-Martin,Sant Martin de Cairiera,Sen-Marten-de-Kejrer,Sen-Marten-de-Ker''er,sheng ma dan de qu ai li ai,Сен-Мартен-де-Кейрєр,Сен-Мартен-де-Керьер,سینٹ-مارٹن-دے-قےریرس,圣马丹德屈埃里埃', 44.8231900, 6.5790100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50826, 'Saint-Martin-de-Nigelles', 'Saint-Martin-de-Nigelles', 'Saint-Martin,Saint-Martin-de-Nigelles', 48.6123400, 1.6092000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50827, 'Saint-Martin-de-Londres', 'Saint-Martin-de-Londres', 'Saint-Martin,Saint-Martin-de-Londres', 43.7904000, 3.7306600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50828, 'Saint-Martin-de-la-Place', 'Saint-Martin-de-la-Place', 'Saint-Martin,Sen-Marten-de-la-Plas,sheng ma dan de la-pu la ke,Сен-Мартен-де-ла-Плас,سینٹ-مارٹن-دے-لا-پلیس,圣马丹德拉-普拉克', 47.3174700, -0.1484900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50829, 'Saint-Martin-de-Landelles', 'Saint-Martin-de-Landelles', 'Saint-Martin,Saint-Martin-Landelles,Saint-Martin-de-Landelle,Saint-Martin-de-Landelles', 48.5453000, -1.1724000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50830, 'Saint-Martin-de-Hinx', 'Saint-Martin-de-Hinx', 'Marat-de-Hinx,Saint-Martin,Saint-Martin-de-Hinx,Sen-Marten-de-Enks,Sent Martin de Hins,sheng ma dan de an,Сен-Мартен-де-Енкс,سینٹ-مارٹن-دے-حنش,圣马丹德安', 43.5823800, -1.2680900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50831, 'Saint-Martin-de-Fontenay', 'Saint-Martin-de-Fontenay', 'Saint-Martin,Saint-Martin-de-Fontenay,Sen-Marten-de-Fontene,sheng ma dan de feng te nai,Сен-Мартен-де-Фонтене,سینٹ-مارٹن-دے-فونٹنے,圣马丹德丰特奈', 49.1152300, -0.3739100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50832, 'Saint-Martin-de-Crau', 'Saint-Martin-de-Crau', 'Saint-Martin,Saint-Martin-de-Crau,Sant Martin de Crau,Sen-Marten-de-Kro,sheng ma dan de ke luo,Сен-Мартен-де-Кро,سینٹ-مارٹن-دے-کرو,圣马丹德克罗', 43.6395500, 4.8127000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50833, 'Saint-Martin-de-Boscherville', 'Saint-Martin-de-Boscherville', 'Boscherville,Saint-Martin,Saint-Martin-de-Boscherville,Sen-Marten-de-Boshervil'',Сен-Мартен-де-Бошервиль,Сен-Мартен-де-Бошервіль,سینٹ-مارٹن-دے-بوسچرولے', 49.4437700, 0.9627100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50834, 'Saint-Martin-de-Belleville', 'Saint-Martin-de-Belleville', 'Des-Ravins,Montalte,Saint-Martin', 45.3817500, 6.5051900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50835, 'Saint-Martin-Boulogne', 'Saint-Martin-Boulogne', 'La Montagne,Montagne-les-Boulogne,Montagne-lès-Boulogne,Saint-Martin,Saint-Martin-Boulogne,Section de-la-Montagne,Sen-Marten-Bulon'',Sint-Martiny-les-Boulonne,Sint-Martiny-lés-Boulonne,san martn bwlwjn,sheng ma dan bu luo nie,Сен-Мартен-Булонь,سان مارتن بولوجن,سینٹ-مارٹن-بولوگنے,圣马丹布洛涅', 50.7269100, 1.6186400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50836, 'Saint-Martin-Bellevue', 'Saint-Martin-Bellevue', 'Saint Martin,Saint-Martin-Bellevue,Sen-Marten-Bel''vju,Сен-Мартен-Бельвю,سینٹ-مارٹن-بلووے', 45.9626200, 6.1576300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50837, 'Saint-Martin-Belle-Roche', 'Saint-Martin-Belle-Roche', 'Saint-Martin,Saint-Martin-Belle-Roche', 46.3831200, 4.8553900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50838, 'Saint-Martin-au-Laërt', 'Saint-Martin-au-Laert', 'Saint-Martin,Saint-Martin-au-Laert,Saint-Martin-au-Laërt,Sen-Marten-o-Laer,san martn aw layrt,sheng ma dan ou la ai er,Сен-Мартен-о-Лаер,سان مارتن أو لايرت,سینٹ-مارٹن-او-لیرٹ,圣马丹欧拉埃尔', 50.7517900, 2.2405100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50839, 'Saint-Mars-la-Jaille', 'Saint-Mars-la-Jaille', 'Saint-Mars,Saint-Mars-la-Jaille,Sant-Marzh-an-Olivenn,Sen-Mars-la-Zhaj,sheng ma er la re er,Сен-Марс-ла-Жай,سینٹ-مارس-لا-جیلے,圣马尔拉热尔', 47.5256600, -1.1848300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50840, 'Saint-Mars-la-Brière', 'Saint-Mars-la-Briere', 'Briere-de-l''Egalite,Brière-de-l''Egalité,Saint-Mars', 48.0304600, 0.3731900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50841, 'Saint-Mars-du-Désert', 'Saint-Mars-du-Desert', 'Saint-Mars,Saint-Mars-du-Desert,Saint-Mars-du-Désert,Sant-Marzh-an-Dezerzh', 47.3656000, -1.4067800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50842, 'Saint-Mars-de-Coutais', 'Saint-Mars-de-Coutais', 'Saint-Mars,Saint-Mars-de-Coutais,Sant-Marzh-ar-C''hoad,Sant-Marzh-ar-Choad,Sen-Mars-de-Kute,san=marusu=do=kute,sheng ma er de ku tai,Сен-Марс-де-Куте,سینٹ-مارس-دے-کوتیس,サン＝マルス＝ド＝クテ,圣马尔德库泰', 47.1115300, -1.7343700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50843, 'Saint-Mariens', 'Saint-Mariens', 'Saint-Mariens', 45.1163100, -0.4008400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50844, 'Saint-Mard', 'Saint-Mard', 'Saint-Mard', 49.0370100, 2.6964500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50845, 'Saint-Marc-le-Blanc', 'Saint-Marc-le-Blanc', 'Saint-Marc,Saint-Marc-le-Blanc,Sant-Mezar-Elvinieg', 48.3649800, -1.4093800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50846, 'Saint-Marc-Jaumegarde', 'Saint-Marc-Jaumegarde', 'Saint-Marc,Saint-Marc-Jaumegarde,Sant Marc dAis,Sant Marc de Jaumegarda,Sen-Mark-Zhomgard,sheng ma er ke ruo mo jia er de,Сен-Марк-Жомгард,سینٹ-مارک-جومگاردے,圣马尔克若默加尔德', 43.5459900, 5.5127200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50847, 'Saint-Marcellin-en-Forez', 'Saint-Marcellin-en-Forez', 'Donjon-la-Plaine,Marcellin-la-Plaine,Saint-Marcellin,Saint-Marcellin-en-Forez,Sant Marcelin dau Pont,Sant Marcelin dau Pònt,Sen-Marsellen-an-Fore,fu lei de qu sheng ma er se lan,Сен-Марселлен-ан-Форе,سینٹ-مرکلن-این -فوریز,福雷地区圣马尔瑟兰', 45.4954900, 4.1692300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50848, 'Saint-Marcellin', 'Saint-Marcellin', 'Saint-Marcellin,Thermopyles', 45.1519200, 5.3238800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50849, 'Saint-Marcel-lès-Valence', 'Saint-Marcel-les-Valence', 'Saint-Marcel,Saint-Marcel-les-Valence,Saint-Marcel-lès-Valence', 44.9724600, 4.9601100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50850, 'Saint-Marcel-lès-Sauzet', 'Saint-Marcel-les-Sauzet', 'Saint-Marcel,Saint-Marcel-les-Sauzet,Saint-Marcel-lès-Sauzet', 44.5950100, 4.8062300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50851, 'Saint-Marcel-lès-Annonay', 'Saint-Marcel-les-Annonay', 'Marcel-de-Deome,Marcel-de-Déome,Saint Marcel,Saint-Marcel-les-Annonay,Saint-Marcel-lès-Annonay,Sant Marcel les Annonay,Sant Marcel lès Annonay,Sant Marceu dAnonai,Sant Marcèu dAnonai,Sen-Marsel''-lez-Annone,sheng ma er sai lai a nuo nai,Сен-Марсель-лез-Анноне,سینٹ-مارسیل-لیس-انونے,圣马尔塞莱阿诺奈', 45.2855500, 4.6247400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50852, 'Saint-Marcel', 'Saint-Marcel', 'Saint-Marcel', 49.1000000, 1.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50853, 'Saint-Marcel', 'Saint-Marcel', 'Saint-Marcel,Saint-Marcel-les Rues', 46.7737100, 4.8920500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50854, 'Saint-Marcel', 'Saint-Marcel', 'Cote-Franche,Côte-Franche,Saint-Marcel', 46.6019300, 1.5132400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50855, 'Saint-Marcel-sur-Aude', 'Saint-Marcel-sur-Aude', '', 43.2500000, 2.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50856, 'Saint-Manvieu', 'Saint-Manvieu', '', 49.1806700, -0.5021100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50857, 'Saint-Mandrier-sur-Mer', 'Saint-Mandrier-sur-Mer', 'Saint-Mandrier,Sant Mandrier,Sant Mandrier de Mar,Sen-Mandrie-sjur-Mer,bin hai sheng mang de li ye,Сен-Мандрие-сюр-Мер,Сен-Мандріє-сюр-Мер,سینٹ-مندرئر-سر-مر,滨海圣芒德里耶', 43.0780000, 5.9290000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50858, 'Saint-Mandé', 'Saint-Mande', 'Saint-Mande,Saint-Mandé,Sanctus Mandetus,Sankt-Mande,Sant Manden,Sen Mande,Sen-Mande,saengmangde,san=mande,sheng mang dai,sn mandh,sn-mandh,st Mande,st Mandé,st mande,Санкт-Манде,Сен Манде,Сен-Манде,سن مانده,سن-مانده,سینٹ-مندے,サン＝マンデ,圣芒代,생망데', 48.8386400, 2.4157900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50859, 'Saint-Mammès', 'Saint-Mammes', 'Saint-Mammes,Saint-Mammès,Sen-Mamme,sheng ma mei,Сен-Мамме,سینٹ-مممس,聖馬梅', 48.3845800, 2.8157800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50860, 'Saint-Mamet-la-Salvetat', 'Saint-Mamet-la-Salvetat', 'Saint-Mamet,Saint-Mamet-la-Salvetat', 44.8576500, 2.3061600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50861, 'Saint-Mamert-du-Gard', 'Saint-Mamert-du-Gard', 'Mamert,Mont-Mamert,Saint-Mamert,Saint-Mamert-du-Gard', 43.8883500, 4.1872500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50862, 'Saint-Malô-du-Bois', 'Saint-Malo-du-Bois', 'Saint-Malo', 46.9333300, -0.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50863, 'Saint-Malo-de-Guersac', 'Saint-Malo-de-Guersac', 'Saint-Malo,Saint-Malo-de-Guersac,Sant-Malou-Gwersac''h,Sant-Malou-Gwersach,Sant-Maloù-Gwersac''h,Sant-Maloù-Gwersach,Sen-Malo-de-Gersak,sheng ma luo de gai er sa ke,Сен-Мало-де-Герсак,سینٹ-ملو-دے-گیرساک,圣马洛德盖尔萨克', 47.3534500, -2.1777300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50864, 'Saint-Malo', 'Saint-Malo', 'Commune-de-la-Victoire,DNR,Maclovium,Mont-Mamet,Port-Malo,Sain-Malo,Saint Malo,Saint Mâlo,Saint-Malo,Sant-Malou,Sant-Maloù,Sen Malo,Sen-Malo,Senmalo,St-Malo,saengmallo,san malw,sen-malo,sheng ma luo,sn mlw,sn-mlw,Σαιν-Μαλό,Сен Мало,Сен-Мало,סן-מלו,سان مالو,سن ملو,سن-ملو,سینٹ-ملو,แซ็ง-มาโล,სენ-მალო,サン・マロ,圣马洛,생말로', 48.6500000, -2.0166700, 'FR', '2016-11-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50865, 'Saint-Maixant', 'Saint-Maixant', 'Saint-Maixant', 44.5786800, -0.2592000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50866, 'Saint-Macaire-en-Mauges', 'Saint-Macaire-en-Mauges', 'Saint-Macaire,Saint-Macaire-en-Mauges,Sen-Maker-an-Mozh,mo re de qu sheng ma kai er,san=makeru=an=moju,Сен-Макер-ан-Мож,سینٹ-مکرے-این -مگس,サン＝マケール＝アン＝モージュ,莫热地区圣马凯尔', 47.1235700, -0.9912000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50867, 'Saint-Macaire', 'Saint-Macaire', 'Saint-Macaire', 44.5652700, -0.2243100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50868, 'Saint-Lys', 'Saint-Lys', 'Eaubelle,Saint-Lys,Sen-Li,Sen-Lis,Sent Lis,sheng li,Сен-Лис,Сен-Лі,سینٹ-لیس,圣利', 43.5112700, 1.1755700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50869, 'Saint-Lyphard', 'Saint-Lyphard', 'Saint-Lyphard,Sant-Lefer', 47.3982200, -2.3064200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50870, 'Saint-Lyé', 'Saint-Lye', 'Saint-Lye,Saint-Lyé', 48.3650200, 3.9990000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50871, 'Saint-Lupicin', 'Saint-Lupicin', 'Lauconne,Saint-Lupicin', 46.4003400, 5.7922000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50872, 'Saint-Lunaire', 'Saint-Lunaire', 'Port-Lunaire,Saint-Lunaire,Sant-Luner,Sen-Ljuner,sheng lu nai er,Сен-Люнер,سینٹ-لونایرے,圣吕奈尔', 48.6381100, -2.1139200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50873, 'Saint-Lumine-de-Coutais', 'Saint-Lumine-de-Coutais', 'Saint-Lumine,Saint-Lumine-de-Coutais,Sant-Leven-ar-C''hoad,Sant-Leven-ar-Choad,Sen-Ljumin-de-Kute,sheng lu man de ku tai,Сен-Люмін-де-Куте,سینٹ-لمینے-دے-کوتیس,圣吕曼德库泰', 47.0539900, -1.7277700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50874, 'Saint-Lumine-de-Clisson', 'Saint-Lumine-de-Clisson', 'Saint-Lumine,Saint-Lumine-de-Clisson,Sant-Leven-Klison,Sen-Ljumin-de-Klisson,sheng lu man de ke li song,Сен-Люмін-де-Кліссон,سینٹ-لمینے-دے-کلاسوں,圣吕曼德克利松', 47.0841300, -1.3352400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50875, 'Saint-Lucien', 'Saint-Lucien', 'Saint-Lucien', 49.5088700, 1.4485600, 'FR', '2017-05-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50876, 'Saint-Lubin-des-Joncherets', 'Saint-Lubin-des-Joncherets', 'Saint-Lubin,Saint-Lubin-des-Joncherets', 48.7666700, 1.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50877, 'Saint-Loup-sur-Semouse', 'Saint-Loup-sur-Semouse', 'Saint-Loup,Saint-Loup-sur-Semouse,Sen-Lu-sjur-Semuz,Сен-Лу-сюр-Семуз,سینٹ-لوپ-سر-سموسے', 47.8834500, 6.2753000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50878, 'Saint-Loup-Cammas', 'Saint-Loup-Cammas', 'Montauloup,Saint-Loup,Saint-Loup-Cammas,Salut,Vertu', 43.6976700, 1.4812700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50879, 'Saint-Louis-de-Montferrand', 'Saint-Louis-de-Montferrand', 'Montferrand,Saint Louis-De Monferrand,Saint-Louis,Saint-Louis-de-Montferrand,Sen-Lui-de-Monferran,Sent Lois de Mont Ferrand,Sent Lois de Montferrand,Sent Loís de Mont Ferrand,Sent Loís de Montferrand,sheng lu yi de meng te fu er lang,Сен-Луи-де-Монферран,Сен-Луї-де-Монферран,سینٹ-لوئیس-دے-مونتفررانڈ,圣卢伊德蒙特弗尔朗', 44.9500000, -0.5354300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50880, 'Saint-Louis', 'Saint-Louis', 'Saint-Louis,Saint-Ludwig,Sen-Lui,St. Ludwig,Сен-Луи', 47.5883600, 7.5624700, 'FR', '2016-12-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50881, 'Saint-Loubès', 'Saint-Loubes', 'Saint-Loubes,Saint-Loubès,Sen-Lubes,Sent Lobes,Sent Lobés,sheng lu bei,Сен-Лубес,سینٹ-لوبس,圣卢贝', 44.9153600, -0.4270300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50882, 'Saint-Lô', 'Saint-Lo', 'Briovera,Gorad Sen-Lo,Rocher-de-la-Liberte,Rocher-de-la-Liberté,Sain-Lo,Saint-Lo,Saint-Lô,Sen Lo,Sen-Lo,saenglo,san=ro,sheng luo,sn lw,sn-lw,Σαιν-Λο,Горад Сен-Ло,Сен Ло,Сен-Ло,סן לו,سن-لو,سینٹ-لو,แซ็ง-โล,サン＝ロー,圣洛,생로', 49.1162400, -1.0903100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50883, 'Saint-Lizier', 'Saint-Lizier', 'Austrie-la-Montagne,Lugdunum Consoranorum,Saint-Lizier,Sen-Liz''e,Sent Liser,Sent Líser,sheng li qi ye,Сен-Лизье,Сен-Лізьє,سینٹ-لزئر,圣利齐耶', 43.0018300, 1.1368600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50884, 'Saint-Leu-la-Forêt', 'Saint-Leu-la-Foret', 'Claire-Fontaine,Saint-Leu,Saint-Leu-la-Foret,Saint-Leu-la-Forêt,Sen-Le-la-Fore,Sen-Ljo-la-Fore,sheng lei la fu lei,Сен-Ле-ла-Форе,Сен-Лё-ла-Форе,سینٹ-لو-لا-فورٹ,圣勒拉福雷', 49.0166700, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50885, 'Saint-Leu', 'Saint-Leu', '', 46.7306000, 4.5008300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50886, 'Saint-Léonard-de-Noblat', 'Saint-Leonard-de-Noblat', 'Leonard-sur-Vienne,Léonard-sur-Vienne,Saint-Leonard,Saint-Leonard-de-Noblat,Saint-Léonard,Saint-Léonard-de-Noblat,Sen-Leonar-de-Nobla,Sent Liunard,Tarn-Vienne,sheng lai ao na er de nuo bu la,Сен-Леонар-де-Нобла,سینٹ-لیونارڈ-دے-نوبلت,圣莱奥纳尔德诺布拉', 45.8356600, 1.4917400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50887, 'Saint-Léonard', 'Saint-Leonard', 'Saint-Leonard,Saint-Léonard', 50.6905800, 1.6253600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50888, 'Saint-Léonard', 'Saint-Leonard', 'Saint-Leonard,Saint-Léonard', 49.7425200, 0.3590700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50889, 'Saint-Léonard', 'Saint-Leonard', 'Saint-Leonard,Saint-Léonard', 48.2163800, 6.9435500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50890, 'Saint-Léger-sur-Roanne', 'Saint-Leger-sur-Roanne', 'Saint-Leger,Saint-Leger-sur-Roanne,Saint-Léger,Saint-Léger-sur-Roanne', 46.0412600, 3.9976400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50891, 'Saint-Léger-sur-Dheune', 'Saint-Leger-sur-Dheune', 'Grosne,Leger-la-Dheune,Leger-les-Rebais,Léger-la-Dheune,Léger-lès-Rebais,Rocaille,Saint-Leger,Saint-Leger-sur-Dheune,Saint-Léger,Saint-Léger-sur-Dheune', 46.8454800, 4.6360700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50892, 'Saint-Léger-sous-Cholet', 'Saint-Leger-sous-Cholet', 'Saint-Leger,Saint-Leger-sous-Cholet,Saint-Léger,Saint-Léger-sous-Cholet,Sen-Lezhe-su-Shole,sheng lai re su shao lai,Сен-Леже-су-Шоле,سینٹ-لگر-سوس-کھولت,圣莱热苏绍莱', 47.0940500, -0.9102400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50893, 'Saint-Léger-les-Vignes', 'Saint-Leger-les-Vignes', 'Saint-Leger,Saint-Leger-les-Vignes,Saint-Léger-les-Vignes,Sant-Lezer-ar-Gwiniegi', 47.1358700, -1.7306000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50894, 'Saint-Léger-lès-Domart', 'Saint-Leger-les-Domart', 'Saint-Leger,Saint-Leger-les-Domart,Saint-Léger,Saint-Léger-lès-Domart', 50.0520800, 2.1406700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50895, 'Saint-Léger-en-Yvelines', 'Saint-Leger-en-Yvelines', 'Marat-des-Bois,Saint-Leger,Saint-Leger-en Yveline,Saint-Leger-en-Yvelines,Saint-Léger,Saint-Léger-en Yveline,Saint-Léger-en-Yvelines,Sanctus Leodegarius in Acquilina,Sen-Lezhe-an-Ivelin,Sen-Lezhe-an-Ivlin,Сен-Леже-ан-Івлін,Сен-Леже-ан-Ивелин,سینٹ-لگر-این -یولنس', 48.7217300, 1.7663800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50896, 'Saint-Léger-du-Bourg-Denis', 'Saint-Leger-du-Bourg-Denis', 'Saint-Leger,Saint-Leger-du-Bourg-Denis,Saint-Léger,Saint-Léger-du-Bourg-Denis', 49.4334500, 1.1580300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50897, 'Saint-Léger-des-Vignes', 'Saint-Leger-des-Vignes', 'Saint Leger,Saint Léger,Saint-Leger-des-Vignes,Saint-Léger-des-Vignes', 46.8406300, 3.4548800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50898, 'Saint-Léger-des-Bois', 'Saint-Leger-des-Bois', 'Beauchene,Beauchêne,Saint-Leger,Saint-Leger-des-Bois,Saint-Léger-des-Bois', 47.4623800, -0.7095300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50899, 'Saint-Léger-de-Montbrun', 'Saint-Leger-de-Montbrun', 'Saint-Leger,Saint-Leger-de-Montbrun,Saint-Léger,Saint-Léger-de-Montbrun', 47.0000000, -0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50900, 'Saint-Laurent-sur-Sèvre', 'Saint-Laurent-sur-Sevre', 'Saint-Laurent,Saint-Laurent-sur-Sevre,Saint-Laurent-sur-Sèvre,Sen-Loran-sjur-Sevr,sai fu lei he pan sheng luo lang,Сен-Лоран-сюр-Севр,سینٹ-لارنٹ-سر-سورے,塞夫勒河畔圣洛朗', 46.9580900, -0.8939200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50901, 'Saint-Laurent-sur-Saône', 'Saint-Laurent-sur-Saone', 'Ain-sur-Saone,Ain-sur-Saône,Saint-Laurent,Saint-Laurent-de-l''Ain,Saint-Laurent-les-Macon,Saint-Laurent-lès-Macon', 46.3053200, 4.8411900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50902, 'Saint-Laurent-sur-Gorre', 'Saint-Laurent-sur-Gorre', 'Saint-Laurent,Saint-Laurent-sur-Gorre', 45.7705200, 0.9585900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50903, 'Saint-Laurent-en-Royans', 'Saint-Laurent-en-Royans', 'Montagne-de-Larps,Saint-Laurent,Saint-Laurent-en-Royans,Sant Laurenc de Roians,Sant Laurenç de Roians,Sen-Loran-an-Ruajan,lu wa ang de qu sheng luo lang,Сен-Лоран-ан-Руаян,سینٹ-لارنٹ-این -رویانس,鲁瓦昂地区圣洛朗', 45.0290700, 5.3277700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50904, 'Saint-Laurent-du-Var', 'Saint-Laurent-du-Var', 'Saint-Laurent,Saint-Laurent-du-Var,Sant Laurenc de Var,Sant Laurenç de Var,Sen Loren di Var,Sen-Loran-dju-Var,saenglolangdwibaleu,san lawrynt dw far,san=roran=de~yu=vu~aru,sheng luo lan du wa,sn lwran dw wr,sn-lwran-dw-wr,Сен Лорен ди Вар,Сен-Лоран-дю-Вар,سان لاورينت دو فار,سن لوران دو ور,سن-لوران-دو-ور,سینٹ-لارنٹ-دو-ور,サン＝ローラン＝デュ＝ヴァール,聖羅蘭度瓦,생로랑뒤바르', 43.6709700, 7.1760600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50905, 'Saint-Laurent-du-Pont', 'Saint-Laurent-du-Pont', 'Laurent-Libre,Pont-la-Montagne,Saint-Laurent,Saint-Laurent-du-Pont,Sen-Loran-dju-Pon,sheng luo lang di peng,Сен-Лоран-дю-Пон,سینٹ-لارنٹ-دو-پونٹ,圣洛朗迪蓬', 45.3900900, 5.7352100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50906, 'Saint-Laurent-du-Pape', 'Saint-Laurent-du-Pape', 'Saint-Laurent,Saint-Laurent-du-Pape', 44.8242800, 4.7612700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50907, 'Saint-Laurent-Nouan', 'Saint-Laurent-Nouan', 'Saint-Laurent,Saint-Laurent-des-Eaux,Sen-Loran-Nuan,sheng luo lang nu ang,Сен-Лоран-Нуан,سینٹ-لارنٹ-نواں,圣洛朗努昂', 47.7166700, 1.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50908, 'Saint-Laurent-des-Autels', 'Saint-Laurent-des-Autels', 'Saint-Laurent,Saint-Laurent-des-Autels,Sen-Loran-dez-Otel'',san=roran=dezoteru,sheng luo lang dai ao tai er,Сен-Лоран-дез-Отель,سینٹ-لارنٹ-دس-اٹلس,サン＝ローラン＝デゾテル,圣洛朗代奥泰尔', 47.2852400, -1.1888100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50909, 'Saint-Laurent-des-Arbres', 'Saint-Laurent-des-Arbres', 'Saint-Laurent,Saint-Laurent-des-Arbres,Sen-Loran-dez-Arbr,Sent Laurenc deis Aubres,Sent Laurenç deis Aubres,St Laurent des Arbres,sheng luo lang dai a er bu lei,Сен-Лоран-дез-Арбр,سینٹ-لارنٹ-دس-اربریس,圣洛朗代阿尔布雷', 44.0549300, 4.7002600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50910, 'Saint-Laurent-de-Mure', 'Saint-Laurent-de-Mure', 'Saint Laurent,Saint-Laurent-de-Mure', 45.6887000, 5.0465600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50911, 'Saint-Laurent-de-la-Salanque', 'Saint-Laurent-de-la-Salanque', 'Saint-Laurent,Saint-Laurent-de-la-Salanque,Sant Llorenc de la Salanca,Sant Llorenç de la Salanca,Sentinelle-de-l''Agly', 42.7727000, 2.9899800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50912, 'Saint-Laurent-de-la-Prée', 'Saint-Laurent-de-la-Pree', 'Saint-Laurent,Saint-Laurent-de-la-Pree,Saint-Laurent-de-la-Prée,Sen-Loran-de-la-Pre,sheng luo lang de la-pu lei ai,Сен-Лоран-де-ла-Пре,سینٹ-لارنٹ-دے-لا-پڑے,圣洛朗德拉-普雷埃', 45.9825900, -1.0362500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50913, 'Saint-Laurent-de-la-Plaine', 'Saint-Laurent-de-la-Plaine', 'Saint-Laurent,Saint-Laurent-de-la-Plaine,Sen-Loran-de-la-Plen,sheng luo lang de la-pu lan,Сен-Лоран-де-ла-Плен,سینٹ-لارنٹ-دے-لا-پلانے,圣洛朗德拉-普兰', 47.3173800, -0.8033300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50914, 'Saint-Laurent-de-Chamousset', 'Saint-Laurent-de-Chamousset', 'Chalier-la-Montagne,Saint-Laurent,Saint-Laurent-de-Chamousset,Sen-Loran-de-Shamusse,Сен-Лоран-де-Шамуссе,سینٹ-لارنٹ-دے-چموسسیت', 45.7393200, 4.4634000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50915, 'Sant Llorenç de Cerdans', 'Sant Llorenc de Cerdans', 'Saint-Laurent-de-Cerdans,Sant Llorenc de Cerdans,Sant Llorenç de Cerdans', 42.3847300, 2.6132000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50916, 'Saint-Laurent-de-Brévedent', 'Saint-Laurent-de-Brevedent', 'Saint-Laurent,Saint-Laurent-de-Brevedent,Saint-Laurent-de-Brévedent', 49.5256400, 0.2545800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50917, 'Saint-Laurent-Blangy', 'Saint-Laurent-Blangy', 'Bellemotte-lez-Arras,Imercourt,Saint-Laurent,Saint-Laurent-Blangy,Saint-Leurint-Blangy,Sen-Loran-Blanzhi,san lwran blanjy,sheng luo lang bu lang ri,Сен-Лоран-Бланжи,Сен-Лоран-Бланжі,سان لوران بلانجي,سینٹ-لارنٹ-بلانگے,圣洛朗布朗日', 50.2944600, 2.8069800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50918, 'Saint-Laurent', 'Saint-Laurent', 'Saint-Laurent,Vautrincourt', 49.7644900, 4.7719300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50919, 'Saint-Lattier', 'Saint-Lattier', 'Lattier,Saint-Lattier', 45.0876800, 5.1926100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50920, 'Saint-Lary-Soulan', 'Saint-Lary-Soulan', 'Saint-Lary,Sainte-Lary-Soulan,Sen-Lari-Sulan,Sent Lari e Sola,sheng la li su lang,Сен-Лари-Сулан,Сен-Ларі-Сулан,سینٹ-لڑے-سولان,圣拉里苏朗', 42.8171300, 0.3223800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50921, 'Saint-Lambert-la-Potherie', 'Saint-Lambert-la-Potherie', 'Saint-Lambert,Saint-Lambert-la-Potherie,Sen-Lamber-la-Potri,sheng lang bei er la bo te li ye,Сен-Ламбер-ла-Потрі,سینٹ-لیمبرٹ-لا-پوتھیرے,圣朗贝尔拉波特里耶', 47.4828900, -0.6778900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50922, 'Saint-Lambert-du-Lattay', 'Saint-Lambert-du-Lattay', 'Saint-Lambert,Saint-Lambert-de-Lattay,Saint-Lambert-du-Lattay,Sen-Lamber-dju-Latte,sheng lang bei er di la tai,Сен-Ламбер-дю-Латте,سینٹ-لیمبرٹ-دو-لاتے,圣朗贝尔迪拉泰', 47.3025000, -0.6332100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50923, 'Saint-Just-Saint-Rambert', 'Saint-Just-Saint-Rambert', 'Saint-Just-sur-Loire,Sen-Zhu-Sen-Ramber,sheng rui si sheng lang bei er,Сен-Жу-Сен-Рамбер,سینٹ-جست-سینٹ-رامبرٹ,圣瑞斯圣朗贝尔', 45.4997300, 4.2414100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50924, 'Saint-Just-Sauvage', 'Saint-Just-Sauvage', 'Just-en-Val,Saint-Just,Saint-Just-Sauvage,Sauvage', 48.5547800, 3.7844900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50925, 'Saint-Just-Malmont', 'Saint-Just-Malmont', 'Mont-Blanc,Saint-Just,Saint-Just-Malmont', 45.3397300, 4.3133500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50926, 'Saint-Just-le-Martel', 'Saint-Just-le-Martel', 'Saint-Just,Saint-Just-le-Martel,Sent Just', 45.8635100, 1.3882900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50927, 'Saint-Just-la-Pendue', 'Saint-Just-la-Pendue', 'Saint-Just,Saint-Just-la-Pendue,Sen-Zhu-la-Pandju,sheng rui si la pang di ai,Сен-Жу-ла-Пандю,سینٹ-جست-لا-پیندے,圣瑞斯拉庞迪埃', 45.8953200, 4.2427600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50928, 'Saint-Just-en-Chevalet', 'Saint-Just-en-Chevalet', 'Mont-Marat,Saint-Just,Saint-Just-en-Chevalet', 45.9139600, 3.8446000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50929, 'Saint-Just-en-Chaussée', 'Saint-Just-en-Chaussee', 'Saint-Just,Saint-Just-en-Chaussee,Saint-Just-en-Chaussée,Saint-Just-in-Coeuchie,Saint-Just-in-Cœuchie,Sen-Zhju-an-Shosse,Sen-Zhust-an-Shosse,shao sai ai de qu sheng rui si,Сен-Жуст-ан-Шоссе,Сен-Жю-ан-Шоссе,سینٹ-جست-این -چوسسے,绍塞埃地区圣瑞斯', 49.5050300, 2.4328500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50930, 'Saint-Just-de-Claix', 'Saint-Just-de-Claix', 'Saint-Just,Saint-Just-de-Claix', 45.0739100, 5.2878300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50931, 'Saint-Just-Chaleyssin', 'Saint-Just-Chaleyssin', 'Saint-Just-Chaleyssin', 45.5853400, 4.9988800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50932, 'Saint-Just', 'Saint-Just', 'Saint-Just', 49.1085200, 1.4410100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50933, 'Saint-Just', 'Saint-Just', 'Saint-Just,Sant-Yust', 47.7658100, -1.9609600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50934, 'Saint-Just-Luzac', 'Saint-Just-Luzac', 'Sen-Zhjust-Ljuzak,Sen-Zhust-Ljuzak,sheng rui si lu zha ke,Сен-Жуст-Люзак,Сен-Жюст-Люзак,سینٹ-جست-لژاک,圣瑞斯吕扎克', 45.8000000, -1.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50935, 'Saint-Just-d''Ardèche', 'Saint-Just-d''Ardeche', 'Saint-Just', 44.3000000, 4.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50936, 'Saint-Just', 'Saint-Just', 'Saint-Just,Sant Just,Sen-Zhust,sheng rui si,Сен-Жуст,سینٹ-جست، حیراالٹ,圣瑞斯', 43.6580600, 4.1147200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50937, 'Saint-Junien', 'Saint-Junien', 'Junien-la-Montagne,Saint-Junien,Sen-Zhun''jan,Sent Junian,Sent Junian de Chalhac,san jwnyan,sheng rui ni an,Сен-Жуньян,سان جونيان,سینٹ-جنین,圣瑞尼安', 45.8886700, 0.9014300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50938, 'Saint-Julien-Molin-Molette', 'Saint-Julien-Molin-Molette', 'Saint-Julien,Saint-Julien-Molin-Molette,Sant Julian de Moleta,Sen-Zhul''en-Molen-Molett,sheng rui li an mo lan mo lai te,Сен-Жульєн-Молен-Молетт,سینٹ-جلیں -مولن-مولتے,圣瑞利安莫兰莫莱特', 45.3233500, 4.6139400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50939, 'Saint-Julien-les-Villas', 'Saint-Julien-les-Villas', 'Saint-Julien,Saint-Julien-les-Villas', 48.2712700, 4.0990100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50940, 'Saint-Julien-lès-Metz', 'Saint-Julien-les-Metz', 'Saint-Julien,Saint-Julien-les-Metz,Saint-Julien-lès-Metz,Sen-Zhjul''en-le-Mec,Sen-Zhul''en-le-Mec,sheng rui li an lai mei te,sn-zhwlyn-lh-mts,Сен-Жульен-ле-Мец,Сен-Жульєн-ле-Мец,Сен-Жюльен-ле-Мец,سن-ژولین-له-متس,سینٹ-جلیں -لیس-متز,圣瑞利安莱梅特', 49.1328800, 6.2024000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50941, 'Saint-Julien-en-Saint-Alban', 'Saint-Julien-en-Saint-Alban', 'Saint-Julien,Saint-Julien-en-Saint-Alban', 44.7541700, 4.6967800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50942, 'Saint-Julien-en-Genevois', 'Saint-Julien-en-Genevois', 'Fanum Sancti Iuliani,Saint-Julien,Sen-Zhjul''en-an-Zhenevua,Sen-Zhul''en-an-Zhenevua,san=jurian=an=junuvu~owa,Сен-Жульєн-ан-Женевуа,Сен-Жюльен-ан-Женевуа,سینٹ-جلیں -این -گنووس,サン＝ジュリアン＝アン＝ジュヌヴォワ', 46.1443400, 6.0825600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50943, 'Saint-Julien-en-Born', 'Saint-Julien-en-Born', 'Saint-Julien,Saint-Julien-en-Born,Sen-Zhjul''en-an-Born,Sen-Zhul''en-an-Born,Sent Julian de Born,Sent Julian de Bòrn,bo er en de qu sheng rui li an,Сен-Жульен-ан-Борн,Сен-Жульєн-ан-Борн,Сен-Жюльен-ан-Борн,سینٹ-جلیں -این -بورن,博尔恩地区圣瑞利安', 44.0631100, -1.2244500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50944, 'Saint-Julien-du-Sault', 'Saint-Julien-du-Sault', 'Saint-Julien,Saint-Julien-du-Sault,Sen-Zhul''en-dju-So,sheng rui li an di suo er,Сен-Жульен-дю-Со,Сен-Жульєн-дю-Со,سینٹ-جلیں -دو-سالٹ,圣瑞利安迪索尔', 48.0318800, 3.2955600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50945, 'Saint-Julien-les-Rosiers', 'Saint-Julien-les-Rosiers', 'Saint-Julien,Saint-Julien-de-Valgalgues', 44.1744500, 4.1080300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50946, 'Saint-Julien-des-Landes', 'Saint-Julien-des-Landes', 'Landes,Saint-Julien,Saint-Julien-des-Landes', 46.6394000, -1.7138100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50947, 'Saint-Julien-de-Peyrolas', 'Saint-Julien-de-Peyrolas', 'Peyrolas,Saint-Julien,Saint-Julien-de-Peyrolas', 44.2883700, 4.5650700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50948, 'Saint-Julien-de-Concelles', 'Saint-Julien-de-Concelles', 'Saint-Julien,Saint-Julien-de-Concelles,Sanctus Iulianus de Concellis,Sant-Juluan-Kankell,Sen-Zhul''en-de-Konsel'',sheng rui li an de kong se lai,Сен-Жульєн-де-Консель,سینٹ-جلیں -دے-کونکلیس,圣瑞利安德孔瑟莱', 47.2528500, -1.3842800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50949, 'Saint-Julien-Chapteuil', 'Saint-Julien-Chapteuil', 'Mont-Megal,Mont-Mégal,Saint Julien,Saint-Julien-Chapteuil,Sant Julian e Chaptuelh,Sant Julian e Chaptuèlh,Sen-Zhjul''en-Shaptjoj,Sen-Zhul''en-Shaptej,san=jurian=shato~uiyu,sheng rui li an sha pu te yi,Сен-Жульен-Шаптей,Сен-Жульєн-Шаптей,Сен-Жюльен-Шаптёй,سینٹ-جلیں -چپتیؤل,サン＝ジュリアン＝シャトゥイユ,圣瑞利安沙普特伊', 45.0339700, 4.0622900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50950, 'Saint-Julien', 'Saint-Julien', 'Saint-Julien,Sant-Juluan-Pentevr', 48.4514200, -2.8125000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50951, 'Saint-Julien', 'Saint-Julien', 'Saint-Julien,Val-Julien', 47.4002900, 5.1416300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50952, 'Saint-Julien', 'Saint-Julien', 'Mont-Rocher,Saint-Julien,Saint-Julien-le-Montagne', 43.6947800, 5.9158200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50953, 'Saint-Juéry', 'Saint-Juery', 'Bellevue,Juery-les-Azalate,Juéry-les-Azalate,Saint-Juery-les-Azalate,Saint-Juéry-les-Azalate', 43.9500000, 2.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50954, 'Saint-Jouvent', 'Saint-Jouvent', 'Saint-Jouvent', 45.9568000, 1.2050000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50955, 'Saint-Jouin-Bruneval', 'Saint-Jouin-Bruneval', 'Saint-Jouin,Saint-Jouin-Bruneval,Saint-Jouin-sur-Mer,Sen-Zhuen-Brjuneval'',Сен-Жуен-Брюневаль,سینٹ-جوائن-برنول', 49.6427500, 0.1640000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50956, 'Saint-Jouan-des-Guérets', 'Saint-Jouan-des-Guerets', 'Saint-Jouan,Saint-Jouan-des-Guerets,Saint-Jouan-des-Guérets,Sant-Yowan-an-Havreg', 48.5993200, -1.9737200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50957, 'Saint-Josse', 'Saint-Josse', 'Bois-Fontaine,Fontaines-aux-Bois,Saint-Josse', 50.4680100, 1.6618000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50958, 'Saint-Joseph-de-Rivière', 'Saint-Joseph-de-Riviere', 'Saint-Joseph,Saint-Joseph-de-Riviere,Saint-Joseph-de-Rivière', 45.3757400, 5.6976800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50959, 'Saint-Joseph', 'Saint-Joseph', 'Saint-Joseph', 45.5569300, 4.6159600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50960, 'Saint-Jory', 'Saint-Jory', 'Saint-Jory', 43.7414600, 1.3708900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50961, 'Saint-Jorioz', 'Saint-Jorioz', 'Laudon,Saint-Jorioz,Sen-Zhorjo,Сен-Жорйо,سینٹ-جوروز', 45.8329500, 6.1650300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50962, 'Saint-Joachim', 'Saint-Joachim', 'Les Iles,Saint-Joachim,Sant-Yoasin', 47.3834900, -2.1923900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50963, 'Saint-Jeoire', 'Saint-Jeoire', 'Saint-Jeoire,Saint-Jeoire-Faucigny,Saint-Jeoire-en-Faucigny,Sen-Zhuar,Сен-Жуар,سینٹ-جوڑے', 46.1377700, 6.4588600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50964, 'Saint-Jean-sur-Veyle', 'Saint-Jean-sur-Veyle', 'Saint-Jean,Saint-Jean-sur-Veyle', 46.2587600, 4.9175100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50965, 'Saint-Jean-sur-Mayenne', 'Saint-Jean-sur-Mayenne', 'Boisse,Saint-Jean,Saint-Jean-sur-Mayenne,Sen-Zhan-sjur-Maenn,mai ang he pan sheng rang,Сен-Жан-сюр-Маєнн,سینٹ-ژاں -سر-مینے,迈昂河畔圣让', 48.1352200, -0.7561300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50966, 'Saint-Jean-sur-Couesnon', 'Saint-Jean-sur-Couesnon', 'Saint-Jean,Saint-Jean-sur-Couesnon,Sant-Yann-ar-C''houenon', 48.2901300, -1.3683500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50967, 'Sant Joan de Pladecorts', 'Sant Joan de Pladecorts', 'Saint-Jean-Pla-de-Corts,Sant Joan,Sant Joan de Pages,Sant Joan de Pagès,Sant Joan de Pladecorts', 42.5106900, 2.7909100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50968, 'Saint-Jean-Pied-de-Port', 'Saint-Jean-Pied-de-Port', 'Donibane Garazi,Donibane-Garazi,Fanum Sancti Ioannis Pedeportuensis,Nive-Franche,Saint-Jean-Pied-de-Port,San Juan Pie de Puerto,Sant Chuan Piet de Puerto,Sant Joan de Peu de Port,Sen-Zhan-P''e-de-Por,Sen-Zhan-Pe-de-Por,Sent Joan Pe de Port,Sent Joan Pè de Pòrt,St.-Jean-Pied-de-Port,san=jan=pie=do=poru,sheng rang-pi ye de bo er,Сен-Жан-Пье-де-Пор,Сен-Жан-Пє-де-Пор,سینٹ-ژاں -پید-دے-پورٹ,サン＝ジャン＝ピエ＝ド＝ポル,圣让-皮耶德波尔', 43.1636300, -1.2373800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50969, 'Saint-Jeannet', 'Saint-Jeannet', 'Saint-Jeannet', 43.7472300, 7.1428400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50970, 'Saint-Jean-le-Vieux', 'Saint-Jean-le-Vieux', 'Saint-Jean,Saint-Jean-le-Vieux,Vieux-d''Oizellon', 46.0284900, 5.3898200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50971, 'Saint-Jean-les-Deux-Jumeaux', 'Saint-Jean-les-Deux-Jumeaux', 'Saint-Jean,Saint-Jean-les-Deux-Jumeaux', 48.9514000, 3.0195900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50972, 'Saint-Jean-le-Blanc', 'Saint-Jean-le-Blanc', '', 47.8932700, 1.9154000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50973, 'Saint-Jean-la-Poterie', 'Saint-Jean-la-Poterie', 'Saint-Jean,Saint-Jean-la-Poterie,Sant-Yann-ar-Wern', 47.6358100, -2.1242000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50974, 'Saint-Jean-en-Royans', 'Saint-Jean-en-Royans', 'Lyonne,Saint-Jean,Saint-Jean-en-Royans,Sant Joan de Roians,Sen-Zhan-an-Ruajan,lu wa ang de qu sheng rang,Сен-Жан-ан-Руаян,سینٹ-ژاں -این -رویانس,鲁瓦昂地区圣让', 45.0169300, 5.2945400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50975, 'Saint-Jean-du-Gard', 'Saint-Jean-du-Gard', 'Brion-du-Gard,Saint-Jean,Saint-Jean-du-Gard,Sant Joan de Gardonenca,Sen-Zhan-dju-Gar,Sent Jan de Gardonenca,sheng rang di jia er,Сен-Жан-дю-Гар,سینٹ-ژاں -دو-گرد,圣让迪加尔', 44.1052300, 3.8856600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50976, 'Saint-Jean-du-Falga', 'Saint-Jean-du-Falga', 'Saint-Jean,Saint-Jean-du-Falga', 43.0864700, 1.6278000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50977, 'Saint-Jean-du-Cardonnay', 'Saint-Jean-du-Cardonnay', 'Saint-Jean,Saint-Jean-du-Cardonnay', 49.5045500, 1.0114000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50978, 'Saint-Jean-de-Védas', 'Saint-Jean-de-Vedas', 'Saint-Jean,Sant Joan de Vedats,Sen-Zhan-de-Vedas,sheng rang de wei da,Сен-Жан-де-Ведас,سینٹ-ژاں -دے-ودس,圣让德韦达', 43.5775900, 3.8260300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50979, 'Saint-Jean-de-Thouars', 'Saint-Jean-de-Thouars', 'Saint-Jean,Saint-Jean-de-Thouars', 46.9648600, -0.2111400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50980, 'Saint-Jean-de-Soudain', 'Saint-Jean-de-Soudain', 'Saint-Jean,Saint-Jean-de-Soudain,Saint-Jean-de-Soudin', 45.5708700, 5.4302700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50981, 'Saint-Jean-des-Mauvrets', 'Saint-Jean-des-Mauvrets', 'Les Mauvrets,Saint-Jean,Saint-Jean-des-Mauvrets,Sen-Zhan-de-Movre,sheng rang dai mo fu lei te,Сен-Жан-де-Мовре,سینٹ-ژاں -دس-مووریٹس,圣让代莫夫雷特', 47.3985700, -0.4492900, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50982, 'Saint-Jean-de-Sixt', 'Saint-Jean-de-Sixt', 'Saint-Jean,Saint-Jean-de-Sixt', 45.9221600, 6.4099100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50983, 'Saint-Jean-des-Champs', 'Saint-Jean-des-Champs', 'Saint-Jean,Saint-Jean-des-Champs', 48.8280000, -1.4648700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50984, 'Saint-Jean-des-Baisants', 'Saint-Jean-des-Baisants', 'Saint-Jean-des-Baisants,Sen-Zhan-de-Bezan,sheng rang dai bai sheng,Сен-Жан-де-Безан,سینٹ-ژاں -دس-بیسنٹس,圣让代拜圣', 49.0937100, -0.9728900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50985, 'Saint-Jean-de-Sauves', 'Saint-Jean-de-Sauves', 'Saint-Jean,Saint-Jean-de-Sauves,Sen-Zhan-de-Sov,sheng re ang de suo wo,Сен-Жан-де-Сов,سینٹ-ژاں -دے-سوس,圣热昂德索沃', 46.8413000, 0.0927200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50986, 'Saint-Jean-de-Niost', 'Saint-Jean-de-Niost', 'Saint-Jean,Sen Zan de Nio,Sen-Zhan-de-N''o,Sen-Zhan-de-Nio,san-jwn-dw-nyws  ayn,sheng yue han de ni ao si te,Сен-Жан-де-Ньо,Сен-Жан-де-Ніо,Սեն Ժան դե Նիո,سان-جون-دو-نيوس، أين,سینٹ-ژاں -دے-نیوسٹ,圣约翰德尼奥斯特', 45.8333300, 5.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50987, 'Saint-Jean-de-Muzols', 'Saint-Jean-de-Muzols', 'Muzols,Saint-Jean,Saint-Jean-de-Muzols', 45.0804000, 4.8142100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50988, 'Saint-Jean-de-Monts', 'Saint-Jean-de-Monts', 'Grands-Monts,Saint-Jean,Saint-Jean-de-Monts,Sen-Zhan-de-Mon,sheng re ang de meng te,Сен-Жан-де-Мон,سینٹ-ژاں -دے-مونٹس,圣热昂德蒙特', 46.7908800, -2.0821900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50989, 'Saint-Jean-de-Moirans', 'Saint-Jean-de-Moirans', 'Moiraxis,Saint-Jean,Saint-Jean-de-Moirans,Sen-Zhan-de-Muaran,sheng rang de mu wa lang,Сен-Жан-де-Муаран,سینٹ-ژاں -دے-مویرانس,圣让德穆瓦朗', 45.3426200, 5.5861500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50990, 'Saint-Jean-de-Maurienne', 'Saint-Jean-de-Maurienne', 'Arc,Fanum Sancti Ioannis Maurianensis,Saint-Jean,Saint-Jean-de-Maurienne,San Giovanni di Moriana,Sen-Zhan-de-Mor''en,Sen-Zhan-de-Morenn,Sent-Jian-de-Moriena,Sent-Jian-de-Môrièna,san=jan=do=morien''nu,Сен-Жан-де-Морьен,Сен-Жан-де-Морєнн,سینٹ-ژاں -دے-مورینے,サン＝ジャン＝ド＝モーリエンヌ', 45.2833300, 6.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50991, 'Saint-Jean-de-Luz', 'Saint-Jean-de-Luz', 'Chauvin-le-Dragon,Donibane Lohizune,Fanum Sancti Ioannis de Luce,Saint-Jean,Saint-Jean-de-Luz,San Juan de Luz,San Juan de Luze,Sant Chuan de Luz,Sant Joan Lohitzune,Sen-Zhan-de-Ljuz,Sent Joan de Lus,St.-Jean-de-Luz,XJZ,san=jan=do=ryuzu,sheng rang de lu,Сен-Жан-де-Люз,سینٹ-ژاں -دے-لز,サン＝ジャン＝ド＝リュズ,圣让德吕', 43.3887100, -1.6626700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50992, 'Saint-Jean-de-Losne', 'Saint-Jean-de-Losne', 'Belle-Defense,Belle-Défense,Latona,Saint-Jean,Saint-Jean-de-Losne,Sen-Zhan-de-Lon,sheng rang de luo si en,sn-zhan-d-lsn,Сен-Жан-де-Лон,سن-ژان-د-لسن,سینٹ-ژاں -دے-لوسنے,圣让德洛斯恩', 47.1024700, 5.2655600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50993, 'Saint-Jean-de-Liversay', 'Saint-Jean-de-Liversay', 'La Gerbe,Saint-Jean,Saint-Jean-de-Liversay', 46.2689400, -0.8738500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50994, 'Saint-Jean-de-la-Ruelle', 'Saint-Jean-de-la-Ruelle', 'Saint-Jean,Saint-Jean-de-la-Ruelle,Sen-Zhan-de-la-Rjuel'',sheng rang de la-lu ai er,Сен-Жан-де-ла-Рюель,سینٹ-ژاں -دے-لا-روےلے,圣让德拉-吕埃尔', 47.9112700, 1.8648300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50995, 'Saint-Jean-de-Gonville', 'Saint-Jean-de-Gonville', 'Saint-Jean,Saint-Jean-de-Gonville', 46.2129800, 5.9504700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50996, 'Saint-Jean-de-Fos', 'Saint-Jean-de-Fos', 'Fort-l''Herault,Fort-l''Hérault,Saint-Jean,Saint-Jean-de-Fos', 43.7010000, 3.5517100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50997, 'Saint-Jean-de-Braye', 'Saint-Jean-de-Braye', 'Saint-Jean-de-Braye,Sen-Zhan-de-Bre,sheng rang de bu lai ai,Сен-Жан-де-Бре,سینٹ-ژاں -دے-بڑے,圣让德布赖埃', 47.9130300, 1.9770500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50998, 'Saint-Jean-de-Bournay', 'Saint-Jean-de-Bournay', 'Saint Jean,Saint-Jean-de-Bournay,Toile-a-Voiles,Toile-à-Voiles', 45.5013500, 5.1396300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(50999, 'Saint-Jean-de-Boiseau', 'Saint-Jean-de-Boiseau', 'Saint-Jean,Saint-Jean-de-Boiseau,Sant-Yann-ar-Granneg,Sen-Zhan-de-Buazo,sheng rang de bu wa suo,Сен-Жан-де-Буазо,سینٹ-ژاں -دے-بوسو,圣让德布瓦索', 47.1931500, -1.7234000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51000, 'Saint-Jean-d''Angély', 'Saint-Jean-d''Angely', 'Saint-Jean-d''Angely,Saint-Jean-d’Angély,Sen-Zhan-d''Anzheli,san=jan=danjeri,sheng rang dang re li,Сен-Жан-д''Анжелі,Сен-Жан-д’Анжели,サン＝ジャン＝ダンジェリ,圣让当热利', 45.9500000, -0.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51001, 'Saint-Jean-Cap-Ferrat', 'Saint-Jean-Cap-Ferrat', 'Saint-Jean,Saint-Jean-Cap-Ferrat,Sant Joan de Cap Ferrat,Sen-Zhan-Kap-Ferra,St Jean Cap Ferrat,san jyan kab fyrat,san=jan=kappu=fera,sheng rang ka fu er la,Сен-Жан-Кап-Ферра,سان جيان كاب فيرات,سینٹ-ژاں -کیپ-پھرت,サン＝ジャン＝カップ＝フェラ,圣让卡弗尔拉', 43.6892200, 7.3323800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51002, 'Saint-Jean-Brévelay', 'Saint-Jean-Brevelay', 'Saint-Jean,Saint-Jean-Brevalay,Saint-Jean-Brevelay,Saint-Jean-Brévalay,Saint-Jean-Brévelay,Sant-Yann-Brevele,Sen-Zhan-Brevele,sheng rang bu lei wei lai,Сен-Жан-Бревеле,سینٹ-ژاں -برولے,圣让布雷韦莱', 47.8449700, -2.7223100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51003, 'Saint-Jean-Bonnefonds', 'Saint-Jean-Bonnefonds', 'Saint-Jean-Bonnefonds,Sen-Zhan-Bonnfon,sheng rang bo nei feng de,Сен-Жан-Боннфон,سینٹ-ژاں -بونفونڈس,圣让博内丰德', 45.4529400, 4.4505700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51004, 'Saint-Jean', 'Saint-Jean', '', 47.2455300, -0.3841300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51005, 'Saint-Jean', 'Saint-Jean', 'Saint-Jean', 43.6642000, 1.4994100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51006, 'Saint-Jans-Cappel', 'Saint-Jans-Cappel', 'Saint-Jans-Cappel,Sen-Zhan-Kappel'',Sint-Jans-Kapel,Sint-Janskappel,sheng rang ka pei lei,Сен-Жан-Каппель,سینٹ-جنس-کپپیل,圣让卡佩勒', 50.7638700, 2.7222700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51007, 'Saint-James', 'Saint-James', 'Beuvron-les-Monts,Saint-James,Sen-Zham,san=jamu,sheng ya mei,Сен-Жам,سینٹ-جیمز,サン＝ジャム,圣雅梅', 48.5218000, -1.3262900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51008, 'Saint-Jacut-les-Pins', 'Saint-Jacut-les-Pins', 'Saint-Jacut-les-Pins,Sanctus Iacutus Pinis,Sant-Yagu-ar-Bineg,Sen-Zhakju-le-Pen,sheng ya qu lai pan,Сен-Жакю-ле-Пен,سینٹ-جکوٹ-لیس-پنس,圣雅屈莱潘', 47.6858100, -2.2151400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51009, 'Saint-Jacques-sur-Darnétal', 'Saint-Jacques-sur-Darnetal', 'Saint-Jacques,Saint-Jacques-sur-Darnetal,Saint-Jacques-sur-Darnétal', 49.4398000, 1.2035900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51010, 'Saint-Jacques-de-la-Lande', 'Saint-Jacques-de-la-Lande', 'Saint-Jacques,Saint-Jacques-de-la-Lande,Sanctus Iacobus de Landis,Sant-Jakez-Al-Lann,Sant-Jakez-al-Lann,Sen-Zhak-de-la-Land,sheng ya qu ai de la-lang de,Сен-Жак-де-ла-Ланд,سینٹ-جکقوس-دے-لا-لنڈے,圣雅屈埃德拉-朗德', 48.0651400, -1.7208600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51011, 'Saint-Ismier', 'Saint-Ismier', 'Mansval,Saint-Ismier', 45.2470800, 5.8286300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51012, 'Saint-Hippolyte-du-Fort', 'Saint-Hippolyte-du-Fort', 'Mont-Polite,Saint-Hippolyte,Saint-Hippolyte-du-Fort,Sen-Ippolit-dju-For,Sent Ipolit,sheng yi bo li te di fu er,Сен-Іпполіт-дю-Фор,Сен-Ипполит-дю-Фор,سینٹ-ہپپولیتے-دو-فورٹ,圣伊波利特迪福尔', 43.9636200, 3.8557200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51013, 'Saint-Hippolyte', 'Saint-Hippolyte', 'Saint-Hippolyte', 48.2321700, 7.3684300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51014, 'Saint-Hippolyte', 'Saint-Hippolyte', 'Doubs-Marat,Saint-Hippolyte', 47.3188000, 6.8161700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51015, 'Saint-Hippolyte', 'Saint-Hippolyte', 'Saint-Hippolyte', 45.9188400, -0.8918300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51016, 'Saint-Hippolyte', 'Saint-Hippolyte', 'Saint-Hippolyte,Sant Hipolit de la Salanca,Sant Hipòlit de la Salanca', 42.7855000, 2.9662000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51017, 'Saint-Hilaire-Saint-Mesmin', 'Saint-Hilaire-Saint-Mesmin', 'Saint-Hilaire,Saint-Hilaire-Saint-Mesmin,Sen-Iler-Sen-Memen,sheng yi lai er sheng mei si man,Сен-Ілер-Сен-Мемен,سینٹ-ہلیری-سینٹ-مثمن,圣伊莱尔圣梅斯曼', 47.8661400, 1.8335100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51018, 'Saint-Hilaire-Petitville', 'Saint-Hilaire-Petitville', 'Saint-Hilaire,Saint-Hilaire-Petitville', 49.3025000, -1.2199500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51019, 'Saint-Hilaire-lez-Cambrai', 'Saint-Hilaire-lez-Cambrai', 'Bon-Air,Saint-Hilaire,Saint-Hilaire-lez-Cambrai,Sen-Iler-le-Kambre,sheng yi lai er lai kang bu lei,Сен-Ілер-ле-Камбре,Сен-Илер-ле-Камбре,圣伊莱尔莱康布雷', 50.1841900, 3.4132700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51020, 'Saint-Hilaire-la-Palud', 'Saint-Hilaire-la-Palud', 'La Palud,Saint-Hilaire,Saint-Hilaire-la Pallud,Saint-Hilaire-la-Palud', 46.2667600, -0.7138000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51021, 'Saint-Hilaire-du-Rosier', 'Saint-Hilaire-du-Rosier', 'Saint-Hilaire,Saint-Hilaire-du-Rosier', 45.1003800, 5.2501200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51022, 'Saint-Hilaire-du-Harcouët', 'Saint-Hilaire-du-Harcouet', 'Hilaire-Harcouet,Hilaire-Harcouët,Saint-Hilaire,Saint-Hilaire-du-Harcouet,Saint-Hilaire-du-Harcout,Saint-Hilaire-du-Harcouët,Sen-Iler-dju-Arkue,Sent-Iler-dju-Arkueh,sheng yi lai er di a er ku e,Сен-Ілер-дю-Аркуе,Сен-Илер-дю-Аркуе,Сент-Илер-дю-Аркуэ,سینٹ-ہلیری-دو-ہرکووٹ,圣伊莱尔迪阿尔库厄', 48.5770000, -1.0900400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51023, 'Saint-Hilaire-de-Villefranche', 'Saint-Hilaire-de-Villefranche', 'Angely-Boutonne,Angély-Boutonne,Belisaire,Bélisaire,L''Egalite,L''Egalité,Saint-Hilaire,Saint-Hilaire-de-Villefranche,Sen-Iler-de-Vil''fransh,Sent-Iler-de-Vil''fransh,sheng yi lai er de wei lai fu lang ke,Сен-Ілер-де-Вільфранш,Сент-Илер-де-Вильфранш,سینٹ-ہلیری-دے-ولفرانچے,圣伊莱尔德维莱夫朗克', 45.8509100, -0.5299300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51024, 'Saint-Hilaire-de-Talmont', 'Saint-Hilaire-de-Talmont', 'Le Tanes,Le Tanès,Saint-Hilaire,Saint-Hilaire-de-Talmont', 46.4700200, -1.6035900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51025, 'Saint-Hilaire-des-Loges', 'Saint-Hilaire-des-Loges', 'Saint-Hilaire,Saint-Hilaire-des-Loges,Sen-Iler-de-Lozh,sheng yi lai lei dai luo re,Сен-Ілер-де-Лож,سینٹ-ہلیری-دس-لوگس,圣伊莱勒代洛热', 46.4719000, -0.6639300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51026, 'Saint-Hilaire-de-Riez', 'Saint-Hilaire-de-Riez', 'La Revolution,La Révolution,Saint-Hilaire,Saint-Hilaire-de-Riez,Sen-Iler-de-Rez,sheng yi lai lei de li ye,Сен-Ілер-де-Рєз,سینٹ-ہلیری-دے-ریز,圣伊莱勒德里耶', 46.7130800, -1.9258300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51027, 'Saint-Hilaire-de-Loulay', 'Saint-Hilaire-de-Loulay', 'Saint-Hilaire,Saint-Hilaire-de-Loulay,Sen-Iler-de-Lule,sheng yi lai lei de lu lai,Сен-Ілер-де-Луле,سینٹ-ہلیری-دے-لولے,圣伊莱勒德卢莱', 47.0019000, -1.3307900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51028, 'Saint-Hilaire-de-la-Côte', 'Saint-Hilaire-de-la-Cote', 'Hilaire-la-Montagne,Saint-Hilaire,Saint-Hilaire-de-la-Cote,Saint-Hilaire-de-la-Côte', 45.3909800, 5.3228700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51029, 'Saint-Hilaire-de-Clisson', 'Saint-Hilaire-de-Clisson', 'Saint-Hilaire,Saint-Hilaire-de-Clisson,Saint-Hilaire-du-Bois,Sant-Eler-Neved,Sen-Iler-de-Klisson,sheng yi lai er de ke li song,Сен-Ілер-де-Кліссон,سینٹ-ہلیری-دے-کلاسوں,圣伊莱尔德克利松', 47.0622200, -1.3077800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51030, 'Saint-Hilaire-de-Chaléons', 'Saint-Hilaire-de-Chaleons', 'Saint Helaire-de-Chaleons,Saint-Hilaire,Saint-Hilaire-de-Chaleons,Saint-Hilaire-de-Chaléons,Sant-Eler-Kaleon,Sen-Iler-de-Shaleon,sheng yi lai er de sha lai weng,Сен-Ілер-де-Шалеон,سینٹ-ہلیری-دے-چلونس,圣伊莱尔德沙莱翁', 47.1019600, -1.8669000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51031, 'Saint-Hilaire-de-Brethmas', 'Saint-Hilaire-de-Brethmas', 'Brethmas-Avesnes,Saint-Hilaire,Saint-Hilaire-de-Brethmas', 44.0800300, 4.1247800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51032, 'Saint-Hilaire', 'Saint-Hilaire', 'Saint-Hilaire,Saint-Hilaire-du-Touvet', 45.3000000, 5.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51033, 'Saint-Hilaire', 'Saint-Hilaire', '', 44.5333300, 0.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51034, 'Saint-Herblon', 'Saint-Herblon', 'Bellevue,Saint-Herblon,Sanctus Hermelandus,Sant-Ervlon-ar-Roz,Sen-Erblon,sheng ai er bu long,Сен-Ерблон,圣埃尔布隆', 47.4078600, -1.0973800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51035, 'Saint-Herblain', 'Saint-Herblain', 'Saint-Herblain,Sant-Ervlan,Sen-Erblen,Sent Erblen,saengteleubeullaeng,san=teruburan,sheng ai er bu lan,snt arbln,Сен-Ерблен,Сент Ерблен,سنت اربلن,سینٹ-ہربلیں,サン＝テルブラン,聖埃爾布蘭,생테르블랭', 47.2176500, -1.6484100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51036, 'Saint-Hélen', 'Saint-Helen', 'Saint-Helen,Saint-Hélen,Sant-Haelen', 48.4700200, -1.9589400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51037, 'Saint-Héand', 'Saint-Heand', 'Mont-Pailloux,Saint-Heand,Saint-Héand,Sen-Ean,sheng ai ang,Сен-Еан,سینٹ-ہینڈ,圣埃昂', 45.5281700, 4.3737700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51038, 'Saint-Grégoire', 'Saint-Gregoire', 'Saint-Gregoire,Saint-Grégoire,Sant-Gregor', 48.1508500, -1.6870600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51039, 'Saint-Gratien', 'Saint-Gratien', 'Saint-Gratien', 48.9735000, 2.2872900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51040, 'Saint-Gonnery', 'Saint-Gonnery', 'Saint-Gonnery,Sant-Goneri', 48.1246500, -2.8184800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51041, 'Saint-Gobain', 'Saint-Gobain', 'Mont-Libre,Saint-Gobain', 49.5957200, 3.3775000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51042, 'Saint-Girons', 'Saint-Girons', 'Lunoque', 42.9833300, 1.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51043, 'Saint-Gilles-Croix-de-Vie', 'Saint-Gilles-Croix-de-Vie', 'Saint-Gilles,Sen-Zhil''-Krua-de-Vi,san=jiru=kurowa=do=vu~i,sheng ji lai si-ke lu wa de wei ye,Сен-Жиль-Круа-де-Ві,سینٹ-گلیس-کروئی-دے-وی,サン＝ジル＝クロワ＝ド＝ヴィ,圣吉莱斯-克鲁瓦德维耶', 46.6976100, -1.9456100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51044, 'Saint-Gilles', 'Saint-Gilles', 'Saint-Gilles,Sant-Jili-Roazhon', 48.1538100, -1.8247700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51045, 'Saint-Gilles', 'Saint-Gilles', 'Heraclee,Héraclée,Mont-d''Abloux,Saint-Gilles,Saint-Gilles-du-Gard', 43.6765600, 4.4302400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51046, 'Saint-Gildas-des-Bois', 'Saint-Gildas-des-Bois', 'Gweltaz-Lambrizig,Saint-Gildas,Saint-Gildas-des-Bois', 47.5162200, -2.0365900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51047, 'Saint-Gildas-de-Rhuys', 'Saint-Gildas-de-Rhuys', 'Abelard,Abélard,Lokentaz,Saint-Gildas,Saint-Gildas de Ruys,Saint-Gildas-de Ruis,Saint-Gildas-de-Rhuys,Sanctus Gildasius Ruiensis,Sen-Zhil''da-de-Rjui,san=jiruda=do=ryuisu,sheng ji er da de lu yi,Сен-Жильда-де-Рюи,Сен-Жильда-де-Рюї,سینٹ-گلدس-دے-رھیس,サン＝ジルダ＝ド＝リュイス,圣吉尔达德吕伊', 47.5006000, -2.8382500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51048, 'Saint-Gervasy', 'Saint-Gervasy', 'Belleviste,Saint-Gervasy', 43.8768700, 4.4658800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51049, 'Saint-Gervais-les-Trois-Clochers', 'Saint-Gervais-les-Trois-Clochers', 'Saint-Gervais,Saint-Gervais-les 3 Clochers,Saint-Gervais-les-Trois-Clochers,Sen-Zherve-le-Trua-Kloshe,sheng re er wei lai si-te lu wa ke luo xie er,Сен-Жерве-ле-Труа-Клоше,سینٹ-گروس-لیس-تروص-کلوچرس,圣热尔韦莱斯-特鲁瓦克洛谢尔', 46.9006700, 0.4076600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51050, 'Saint-Gervais-les-Bains', 'Saint-Gervais-les-Bains', 'Fanum Sancti Gervasii ad Balnea,Saint-Gervais,Saint-Gervais-les-Bains,Sen-Zherve-le-Ben,Verosse,Vérosse,Сен-Жерве-ле-Бен,سینٹ-گروس-لیس-بانس', 45.8929000, 6.7138100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51051, 'Saint-Gervais-la-Forêt', 'Saint-Gervais-la-Foret', 'Bonne-Creme,Bonne-Crème,Gervais-sur-Cosson,Saint-Gervais,Saint-Gervais-la-Foret,Saint-Gervais-la-Forêt,Sen-Zherve-la-Fore,sheng re er wei la fu lei,Сен-Жерве-ла-Форе,سینٹ-گروس-لا-فورٹ,圣热尔韦拉福雷', 47.5670500, 1.3549300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51052, 'Saint-Gervais-en-Belin', 'Saint-Gervais-en-Belin', 'Saint-Gervais,Saint-Gervais-en-Belin', 47.8772000, 0.2177000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51053, 'Saint-Gervais-d’Auvergne', 'Saint-Gervais-d''Auvergne', 'Saint-Gervais,Saint-Gervais-d''Auvergne,Saint-Gervais-d’Auvergne', 46.0287100, 2.8194000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51054, 'Saint-Gervais', 'Saint-Gervais', 'Saint-Gervais', 46.9017400, -2.0021000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51055, 'Saint-Gervais', 'Saint-Gervais', 'Saint-Gervais', 45.0158300, -0.4523800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51056, 'Saint-Germer-de-Fly', 'Saint-Germer-de-Fly', 'Saint-Germer,Saint-Germer-de-Fly', 49.4428100, 1.7798600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51057, 'Saint-Germain-Village', 'Saint-Germain-Village', 'Saint-Germain,Saint-Germain-Village,Sen-Zhermen-Villazh,sheng ri er man wei la ge,Сен-Жермен-Виллаж,Сен-Жермен-Віллаж,سینٹ-گرمین-ولیج,圣日尔曼维拉格', 49.3490800, 0.5033100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51058, 'Saint-Germain-sur-Morin', 'Saint-Germain-sur-Morin', 'Saint-Germain,Saint-Germain-sur-Morin', 48.8825700, 2.8512700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51059, 'Saint-Germain-sur-Moine', 'Saint-Germain-sur-Moine', 'Saint-Germain,Saint-Germain-sur-Moine,Sen-Zhermen-sjur-Muan,mu wan he pan sheng ri er man,Сен-Жермен-сюр-Муан,سینٹ-گرمین-سر-منے,穆万河畔圣日尔曼', 47.1174600, -1.1222300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51060, 'Saint-Germain-Nuelles', 'Saint-Germain-Nuelles', 'Barras-sur-l''Arbresle,Saint Germain,Saint-Germain-sur-l''Arbresle', 45.8524200, 4.6118200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51061, 'Saint-Germain-sur-Avre', 'Saint-Germain-sur-Avre', 'Saint-Germain,Saint-Germain-sur-Avre,Sen-Zhermen-sjur-Avr,a fu er he pan sheng ri er man,Сен-Жермен-сюр-Авр,سینٹ-گرمین-سر-اورے,阿夫尔河畔圣日尔曼', 48.7646600, 1.2677600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51062, 'Saint-Germain-Lespinasse', 'Saint-Germain-Lespinasse', 'Saint-Germain,Saint-Germain-Lespinasse', 46.1016500, 3.9620400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51063, 'Saint-Germain-lès-Corbeil', 'Saint-Germain-les-Corbeil', 'Saint-Germain,Saint-Germain-les-Corbeil,Saint-Germain-lès-Corbeil,Sen-Zhermen-le-Korbej,Vieux-Corbeil,sheng re er man lai ke er bei,Сен-Жермен-ле-Корбей,سینٹ-گرمین-لیس-کوربیل,圣热尔曼莱科尔贝', 48.6221100, 2.4877500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51064, 'Saint-Germain-les-Belles', 'Saint-Germain-les-Belles', 'Mont-les-Belles,Saint-Germain,Saint-Germain-les-Belles', 45.6135600, 1.4949000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51065, 'Saint-Germain-lès-Arpajon', 'Saint-Germain-les-Arpajon', 'Franc-Val,Germain-les-Chatres,Germain-lès-Châtres,Germinal-sur-Orge,Saint-Germain,Saint-Germain-les-Arpajon,Saint-Germain-lès-Arpajon,Sen-Zhermen-lez-Arpazhon,sheng re er man lai a er pa rong,Сен-Жермен-лез-Арпажон,سینٹ-گرمین-لیس-ارپجوں,圣热尔曼莱阿尔帕容', 48.5973300, 2.2648100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51066, 'Saint-Germain-Lembron', 'Saint-Germain-Lembron', 'Liziniac-Lembron,Saint-Germain,Saint-Germain-Lembron', 45.4579800, 3.2395000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51067, 'Saint-Germain-Laval', 'Saint-Germain-Laval', 'Gardeloup-sur-Seine,Saint-Germain-Laval', 48.3996800, 2.9978100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51068, 'Saint-Germain-Laval', 'Saint-Germain-Laval', 'Chalier,Montchalier-Laval,Saint-Germain-Laval', 45.8313800, 4.0144500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51069, 'Saint-Germain-Laprade', 'Saint-Germain-Laprade', 'Saint-Germain,Saint-Germain-Laprade', 45.0386200, 3.9700400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51070, 'Saint-Germain-la-Blanche-Herbe', 'Saint-Germain-la-Blanche-Herbe', 'Saint-Germain,Saint-Germain-la-Blanche-Herbe', 49.1832700, -0.4042600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51071, 'Saint-Germain-en-Laye', 'Saint-Germain-en-Laye', 'Montagne-du-Bon-Air,Saint Germain en Laye,Saint-Germain,Saint-Germain-en-Laye,Sanctus Germanus in Laya,Sen Zhermen an Le,Sen-Zhermen-an-Le,saengjeleumaeng-angle,san=jeruman=an=re,sheng ri er man ang lai,sn jrmn an lh,sn zhrmn an lh,Сен Жермен ан Ле,Сен-Жермен-ан-Ле,سن جرمن آن له,سن ژرمن آن له,سینٹ-گرمین-این -لیے,แซ็ง-แฌร์แม็ง-อ็อง-แล,サン＝ジェルマン＝アン＝レー,圣日耳曼昂莱,생제르맹앙레', 48.9000000, 2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51072, 'Saint-Germain-en-Coglès', 'Saint-Germain-en-Cogles', 'Saint-Germain,Saint-Germain-en-Cogles,Saint-Germain-en-Coglès,Sant-Jermen-Gougleiz', 48.4053100, -1.2636900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51073, 'Saint-Germain-du-Puy', 'Saint-Germain-du-Puy', 'La Montagne-du-Puy,Saint Germain,Saint-Germain-du-Puy,Sen-Zhermen-dju-Pjui,sheng ri er man di pi yi,Сен-Жермен-дю-Пюи,Сен-Жермен-дю-Пюї,سینٹ-گرمین-دو-پے,圣日尔曼迪皮伊', 47.1000000, 2.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51074, 'Saint-Germain-du-Puch', 'Saint-Germain-du-Puch', 'Saint-Germain,Saint-Germain-du-Puch', 44.8500000, -0.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51075, 'Saint-Germain-du-Plain', 'Saint-Germain-du-Plain', 'Le Pelletier-du-Plain,Saint-Germain,Saint-Germain-du-Plain,Thorey-sur-Saone,Thorey-sur-Saône', 46.6993800, 4.9851000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51076, 'Saint-Germain-du-Corbéis', 'Saint-Germain-du-Corbeis', 'Lisie-du-Corbeis,Lisie-du-Corbéis,Saint-Germain,Saint-Germain-du-Corbeis,Saint-Germain-du-Corbéis', 48.4221500, 0.0619300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51077, 'Saint-Germain-du-Bois', 'Saint-Germain-du-Bois', 'Belle-Place,Bellevue-des-Bois,Grand-Bois,Saint-Germain,Saint-Germain-du-Bois,Sen-Zhermen-dju-Bua,Сен-Жермен-дю-Буа,سینٹ-گرمین-دو-بوس', 46.7528700, 5.2453000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51078, 'Saint-Germain-des-Prés', 'Saint-Germain-des-Pres', 'Saint-Germain,Saint-Germain-des-Pres,Saint-Germain-des-Prés', 47.9538400, 2.8484600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51079, 'Saint-Germain-des-Prés', 'Saint-Germain-des-Pres', 'Pres-Fleuris,Prés-Fleuris,Saint-Germain,Saint-Germain-des-Pres,Saint-Germain-des-Prés', 47.4099800, -0.8334200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51080, 'Saint-Germain-des-Fossés', 'Saint-Germain-des-Fosses', 'Puymourgon,Saint-Germain,Saint-Germain-de-Salles,Saint-Germain-des-Fosses,Saint-Germain-des-Fossés,Sant German daus Fossats,Sen-Zhermen-de-Fosse,sheng ri er man dai fu sai,Сен-Жермен-де-Фоссе,سینٹ-گرمین-دس-فوسسس,圣日尔曼代福塞', 46.2021100, 3.4324500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51081, 'Saint-Germain-de-Prinçay', 'Saint-Germain-de-Princay', 'Princay-le-Vineux,Prinçay-le-Vineux,Saint-Germain,Saint-Germain-de-Princay,Saint-Germain-de-Prinçay,Saint-Germain-le Princay,Saint-Germain-le Prinçay', 46.7210700, -1.0215300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51082, 'Saint-Germain-de-Marencennes', 'Saint-Germain-de-Marencennes', 'Gerrnain-la-Rondee,Gerrnain-la-Rondée,Saint-Germain,Saint-Germain-de-Marencennes', 46.0773300, -0.7913300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51083, 'Saint-Germain-de-Lusignan', 'Saint-Germain-de-Lusignan', 'Germain-Lusignan,Saint-Germain,Saint-Germain-de-Lusignan', 45.4501100, -0.4614700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51084, 'Saint-Germain-de-la-Grange', 'Saint-Germain-de-la-Grange', 'Saint-Germain,Saint-Germain-de-la-Grange', 48.8343600, 1.8988400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51085, 'Saint-Germain', 'Saint-Germain', 'Saint-Germain', 48.2573600, 4.0326400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51086, 'Saint-Germain', 'Saint-Germain', 'Le Mont-Germain,Saint-Germain', 47.7249600, 6.5311700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51087, 'Saint-Géréon', 'Saint-Gereon', 'Saint-Gereon,Saint-Géréon,Sant-Gerent', 47.3677400, -1.2026200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51088, 'Saint-Gérand-le-Puy', 'Saint-Gerand-le-Puy', 'Puy-Redan,Saint-Gerand,Saint-Gerand-le-Puy,Saint-Gérand,Saint-Gérand-le-Puy,Sant Girand,Sen-Zheran-le-Pjui,sheng re lang lai pi yi,Сен-Жеран-ле-Пюи,Сен-Жеран-ле-Пюї,سینٹ-گرانڈ-لے-پے,圣热朗莱皮伊', 46.2575800, 3.5122000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51089, 'Saint-Geours-de-Maremne', 'Saint-Geours-de-Maremne', 'Saint-Geours,Saint-Geours-de Maremme,Saint-Geours-de-Maremne', 43.6893600, -1.2293700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51090, 'Saint-Georges-sur-Loire', 'Saint-Georges-sur-Loire', 'Beau-Site,Saint-Georges,Saint-Georges-sur-Loire,Sen-Zhorzh-sjur-Luar,lu wa er he pan sheng ruo er re,Сен-Жорж-сюр-Луар,سینٹ-گیورگس-سر-لڑے,卢瓦尔河畔圣若尔热', 47.4079200, -0.7619400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51091, 'Saint-Georges-sur-Eure', 'Saint-Georges-sur-Eure', 'Saint-Georges,Saint-Georges-sur-Eure', 48.4186900, 1.3546000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51092, 'Saint-Georges-sur-Cher', 'Saint-Georges-sur-Cher', 'Albion-sur-Cher,Saint-Georges,Saint-Georges-sur-Cher', 47.3299600, 1.1326100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51093, 'Saint-Georges-sur-Baulche', 'Saint-Georges-sur-Baulche', 'Saint-Georges,Saint-Georges-sur-Baulche', 47.8003900, 3.5314400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51094, 'Saint-Georges-sur-Allier', 'Saint-Georges-sur-Allier', 'Saint-Georges,Saint-Georges-sur-Allier', 45.7109300, 3.2429600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51095, 'Saint-Georges-les-Bains', 'Saint-Georges-les-Bains', 'Saint-Georges,Saint-Georges-les-Bains', 44.8622200, 4.8075800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51096, 'Saint-Georges-lès-Baillargeaux', 'Saint-Georges-les-Baillargeaux', 'La Montagne,Saint-Georges,Saint-Georges-les-Baillargeaux,Saint-Georges-lès-Baillargeaux,Sen-Zhorzh-le-Bajarzho,sheng re ao er re lai bai la er ge,Сен-Жорж-ле-Баяржо,سینٹ-گیورگس-لیس-لڑگےش,圣热奥尔热莱拜拉尔戈', 46.6701700, 0.4020900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51097, 'Saint-Georges-Haute-Ville', 'Saint-Georges-Haute-Ville', 'Saint Georges,Saint-Georges-Haute-Ville', 45.5548700, 4.0995200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51098, 'Saint-Georges-du-Bois', 'Saint-Georges-du-Bois', 'Saint-Georges,Saint-Georges-du-Bois', 47.9724200, 0.1011300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51099, 'Saint-Georges-du-Bois', 'Saint-Georges-du-Bois', 'Saint-Georges,Saint-Georges-du-Bois', 46.1407400, -0.7339300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51100, 'Saint-Georges-des-Groseillers', 'Saint-Georges-des-Groseillers', 'Saint-Georges,Saint-Georges-des-Groseillers,Saint-Georges-des-Groseilliers,Sen-Zhorzh-de-Grozee,sheng ruo er re dai ge luo sai lai er,Сен-Жорж-де-Грозее,Сен-Жорж-де-Грозеє,سینٹ-گیورگس-دس-گروسیلیرس,圣若尔热代格罗塞莱尔', 48.7699300, -0.5676800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51101, 'Saint-Georges-des-Coteaux', 'Saint-Georges-des-Coteaux', 'Les Coteaux,Saint-Georges,Sen-Zhorzh-de-Koto,sheng ruo er re dai ke tuo,Сен-Жорж-де-Кото,سینٹ-گیورگس-دس-وتےش,圣若尔热代科托', 45.7666700, -0.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51102, 'Saint-Georges-de-Reneins', 'Saint-Georges-de-Reneins', 'Reneins-les-Sables,Saint-Georges,Saint-Georges-de-Reneins', 46.0603400, 4.7256000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51103, 'Saint-Georges-de-Reintembault', 'Saint-Georges-de-Reintembault', 'Saint-Georges,Saint-Georges-de-Reintembault,Sanctus Georgius Renistembaldi,Sant-Jord-Restembaod,Sen-Zhorzh-de-Rentambo,sheng ruo er re de lan tang bo er,Сен-Жорж-де-Рентамбо,سینٹ-گیورگس-دے-رینٹمبالٹ,圣若尔热德兰唐博尔', 48.5074400, -1.2432800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51104, 'Saint-Georges-de-Pointindoux', 'Saint-Georges-de-Pointindoux', 'Carriere-Grison,Carrière-Grison,Saint-Georges,Saint-Georges-de-Pointindoux', 46.6446200, -1.6220400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51105, 'Saint-Georges-de-Montaigu', 'Saint-Georges-de-Montaigu', 'Saint-Georges,Saint-Georges-de-Montaigu,Sen-Zhorzh-de-Montegju,sheng re ao er re de meng tai ju,Сен-Жорж-де-Монтегю,سینٹ-گیورگس-دے-مونٹیگو,圣热奥尔热德蒙泰居', 46.9465500, -1.2926200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51106, 'Saint-Georges-de-Mons', 'Saint-Georges-de-Mons', 'Mons-le-Libre,Saint-Georges,Saint-Georges-de-Mons', 45.9399400, 2.8406000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51107, 'Saint-Georges-de-Luzençon', 'Saint-Georges-de-Luzencon', 'Fonds-Fort,George-Camboulas,Saint-Georges-de-Luzancon,Saint-Georges-de-Luzançon,Saint-Georges-de-Luzencon,Saint-Georges-de-Luzençon', 44.0647100, 2.9859700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51108, 'Saint-Georges-de-Didonne', 'Saint-Georges-de-Didonne', 'Didonne,Saint-Georges,Saint-Georges-de-Didonne,Sen-Zhorzh-de-Didon,Sen-Zhorzh-de-Didonn,sheng ruo er re de di dong,Сен-Жорж-де-Дидон,Сен-Жорж-де-Дідонн,سینٹ-گیورگس-دے-دیدوں نے,圣若尔热德迪东', 45.6034200, -1.0048700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51109, 'Saint-Georges-de-Commiers', 'Saint-Georges-de-Commiers', 'Saint Gorges-de Commiers,Saint-Georges,Saint-Georges-de-Comiers,Saint-Georges-de-Commiers,Saint-Georges-de-Comners', 45.0385400, 5.7022600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51110, 'Saint-Georges-Buttavent', 'Saint-Georges-Buttavent', 'Saint-Georges,Saint-Georges-Butavent,Saint-Georges-Buttavent', 48.3101800, -0.6937200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51111, 'Saint-Geoire-en-Valdaine', 'Saint-Geoire-en-Valdaine', 'Saint-Geoire,Saint-Geoire-en-Valdaine,Sen-Zhuar-an-Val''den,Val-d''Eynan,wa er dan de qu sheng ru wa er,Сен-Жуар-ан-Вальден,سینٹ-گورے-این -ولدہینے,瓦尔丹地区圣茹瓦尔', 45.4569900, 5.6341500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51112, 'Saint-Genix-sur-Guiers', 'Saint-Genix-sur-Guiers', 'Entre-Rives,Saint-Genix,Saint-Genix-sur-Guiers', 45.5996600, 5.6343600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51113, 'Saint-Genis-Pouilly', 'Saint-Genis-Pouilly', 'Saint-Genis,Sen-Zheni-Pui,Sen-Zheni-Puji,san-jyny-bwyy  ayn,sheng re ni-pu yi,sn-zhany-pwyy,Сен-Жени-Пуйи,Сен-Жені-Пуї,سان-جيني-بويي، أين,سن-ژانی-پویی,سینٹ-گینس-پویل,圣热尼－普伊', 46.2435600, 6.0211900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51114, 'Saint-Genis-les-Ollières', 'Saint-Genis-les-Ollieres', 'Ollieres,Ollières,Saint Genis,Saint-Genis-les-Ollieres,Saint-Genis-les-Ollières', 45.7571900, 4.7289200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51115, 'Saint-Genis-Laval', 'Saint-Genis-Laval', 'Genis-le-Patriote,Saint Genis,Saint-Genis-Laval,Sen Zheni Laval,Sen-Zheni-Laval'',St. Genis Laval,Сен Жени Лавал,Сен-Жени-Лаваль,Сен-Жені-Лаваль,سینٹ-گینس-لاول', 45.6955800, 4.7934000, 'FR', '2017-07-13', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51116, 'Saint-Genis-de-Saintonge', 'Saint-Genis-de-Saintonge', 'Saint-Genis,Saint-Genis-de-Saintonge,Sen-Zheni-de-Sentonzh,sheng re ni de sang tong ge,Сен-Жени-де-Сентонж,Сен-Жені-де-Сентонж,سینٹ-گینس-دے-سینٹونگے,圣热尼德桑通格', 45.4810700, -0.5684800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51117, 'Saint-Génis-des-Fontaines', 'Saint-Genis-des-Fontaines', 'Saint-Genis-des-Fontaines,Saint-Génis-des-Fontaines,Sant Genis de Fontanes,Sant Genís de Fontanes', 42.5432500, 2.9206000, 'FR', '2016-06-15', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51118, 'Saint-Geniès-des-Mourgues', 'Saint-Genies-des-Mourgues', 'Saint-Genies,Saint-Genies-des-Mourgues,Saint-Geniès,Saint-Geniès-des-Mourgues,Sant Ginieis de las Morgas,Sant Ginièis de las Morgas,Sen-Zhen''es-de-Murg,sheng re nie dai mu er gai,Сен-Женьес-де-Мург,Сен-Женьєс-де-Мург,سینٹ-گنیس-دس-مورگیس,圣热涅代穆尔盖', 43.6978000, 4.0361000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51119, 'Saint-Geniès-de-Malgoirès', 'Saint-Genies-de-Malgoires', 'Mont-Esquielle,Montesquielle', 43.9500000, 4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51120, 'Saint-Geniès-de-Comolas', 'Saint-Genies-de-Comolas', 'Mont-Comolas,Montclos,Saint-Genies,Saint-Genies-de-Comolas,Saint-Geniès,Saint-Geniès-de-Comolas,Sanctus Genesius de Comolacio,Sen-Zhen''es-de-Komolas,Sent Genieis de Comolac,Sent Genièis de Comolaç,sheng re nie de kong ao la,Сен-Женьес-де-Комолас,Сен-Женьєс-де-Комолас,سینٹ-گنیس-دے-کومولس,圣热涅德孔奥拉', 44.0661700, 4.7215700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51121, 'Saint-Geniès-Bellevue', 'Saint-Genies-Bellevue', 'Saint-Genies,Saint-Genies-Bellevue,Saint-Geniès,Saint-Geniès-Bellevue', 43.6840900, 1.4869300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51122, 'Saint-Gengoux-le-National', 'Saint-Gengoux-le-National', 'Gengoux-le-National,Jouvence,Saint-Gengoux,Saint-Gengoux-le-National,Sen-Zhangu-le-Nas''onal'',Сен-Жангу-ле-Насьональ,سینٹ-ینگوش-لے-نیشنل', 46.6147600, 4.6626100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51123, 'Saint-Genest-Malifaux', 'Saint-Genest-Malifaux', 'Saint-Genest,Saint-Genest-Malifaux,Sant Geneis de Malifaus,Sant Genèis de Malifaus,Semeine-et-Furans,Sen-Zhene-Malifo,sheng re nei si ma li fu,Сен-Жене-Маліфо,سینٹ-گنیست-لفش,圣热内斯马利福', 45.3423400, 4.4195400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51124, 'Saint-Genest-Lerpt', 'Saint-Genest-Lerpt', 'Saint-Genest-Lerpt,Saint-Genet-Lerpt,Sen-Zhene-Ler,sheng re nei si lai er pu,Сен-Жене-Лер,سینٹ-گنیست-لرپٹ,圣热内斯莱尔普', 45.4452900, 4.3362200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51125, 'Saint-Genès-Champanelle', 'Saint-Genes-Champanelle', 'Saint-Genes-Champanelle,Saint-Genest-de-Champanelle,Saint-Genès-Champanelle,Sant Genest de Champanela,Sant Genèst de Champanèla,Sen-Zhene-Shampanel'',sheng re nei shang pa nei er,Сен-Жене-Шампанель,سینٹ-گینس-چمپنلے,圣热内尚帕内尔', 45.7191500, 3.0188700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51126, 'Saint-Gence', 'Saint-Gence', 'Saint-Gence', 45.9219800, 1.1372600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51127, 'Saint-Gély-du-Fesc', 'Saint-Gely-du-Fesc', 'Saint-Gely,Saint-Gely-du-Fesc,Saint-Gély,Saint-Gély-du-Fesc', 43.6927200, 3.8049200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51128, 'Saint-Gelais', 'Saint-Gelais', 'Gelais-sur-Sevre,Gelais-sur-Sèvre,Saint-Gelais', 46.3823400, -0.3908400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51129, 'Saint-Gaultier', 'Saint-Gaultier', 'Roche-Libre,Saint-Gaultier,Sen-Got''e,sheng ge er di ye,Сен-Готье,Сен-Готьє,سینٹ-گولٹیر,圣戈尔蒂耶', 46.6351800, 1.4128900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51130, 'Saint-Gaudens', 'Saint-Gaudens', 'Mont-d''Unite,Mont-d''Unité,Saint-Gaudens,Sent Gaudenc,Sent Gaudenç', 43.1166700, 0.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51131, 'Saint-Gatien-des-Bois', 'Saint-Gatien-des-Bois', '', 49.3500000, 0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51132, 'Saint-Galmier', 'Saint-Galmier', 'Commune-Fond-Fort,Saint-Galmier,Sen-Gal''me,Ville-Fontfort,sheng jia er mi ye,Сен-Гальмє,سینٹ-گلمیر,圣加尔米耶', 45.5919900, 4.3174300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51133, 'Saint-Fulgent', 'Saint-Fulgent', 'Fulgent-les-Bois,Saint-Fulgent,Sen-Fjul''zhan,sheng fei er gang,Сен-Фюльжан,سینٹ-فلگنٹ,圣菲尔冈', 46.8522600, -1.1779800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51134, 'Saint-François', 'Saint-Francois', '', 46.4153700, 3.9054200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51135, 'Saint-Fort', 'Saint-Fort', 'Saint-Fort', 47.7992800, -0.7209500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51136, 'Saint-Forgeux', 'Saint-Forgeux', 'Saint-Forgeux', 45.8597900, 4.4748600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51137, 'Saint-Fons', 'Saint-Fons', 'Saint-Fons,Sen-Fon,sheng-feng,Сен-Фон,سینٹ-فونس,生-丰', 45.7088000, 4.8605700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51138, 'Saint-Folquin', 'Saint-Folquin', 'Le Bas-Morin,Saint-Folquin,Sen-Fol''ken,san fwlkywn,sheng fu kan,Сен-Фолькен,سان فولكيون,سینٹ-فولقیں,圣福坎', 50.9447300, 2.1243300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51139, 'Saint-Flour', 'Saint-Flour', 'Fort-Cantal,Fort-Libre,Mont-Flour,Saint-Flour', 45.0333300, 3.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51140, 'Saint-Florent-sur-Cher', 'Saint-Florent-sur-Cher', 'Saint-Florent,Saint-Florent-sur-Cher,Sen-Floran-sjur-Sher,xie he pan sheng fu luo lang,Сен-Флоран-сюр-Шер,سینٹ-فلورینٹ-سر-چر,谢河畔圣夫洛朗', 46.9955200, 2.2507600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51141, 'Saint-Florent-sur-Auzonnet', 'Saint-Florent-sur-Auzonnet', 'Mont-Mayard,Montmajord,Saint-Florens,Saint-Florent,Saint-Florent-sur-Auzonnet', 44.2403200, 4.1125200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51142, 'Saint-Florent-le-Vieil', 'Saint-Florent-le-Vieil', 'Mont-Glone,Saint-Florent,Saint-Florent-le-Vieil,Sen-Floran-le-Vej,sheng fu luo lang lai wei ye yi,Сен-Флоран-ле-Вєй,سینٹ-فلورینٹ-لے-ویل,圣夫洛朗莱维耶伊', 47.3606900, -1.0151500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51143, 'Saint-Florentin', 'Saint-Florentin', 'Mont-Armance,Pont-Civique,Saint-Florentin', 48.0005700, 3.7248900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51144, 'Saint-Florent-des-Bois', 'Saint-Florent-des-Bois', 'Bois-Milon,Saint-Florent,Saint-Florent-des-Bois,Sen-Floran-de-Bua,sheng fu luo lang dai bu wa,Сен-Флоран-де-Буа,سینٹ-فلورینٹ-دس-بوس,圣夫洛朗代布瓦', 46.5937700, -1.3158000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51145, 'Saint-Florent', 'Saint-Florent', 'Saint-Florent,San Fiurenzu', 42.6815000, 9.3039600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51146, 'Saint-Fiacre-sur-Maine', 'Saint-Fiacre-sur-Maine', 'Saint-Fiacre,Saint-Fiacre-sur-Maine,Sant-Fieg-ar-Mewan,Sen-Fiakr-sjur-Men,man en he pan sheng fei a ke er,san=fiakuru=shuru=menu,Сен-Фіакр-сюр-Мен,سینٹ-فیکڑے-سر-مہینے,サン＝フィアクル＝シュル＝メーヌ,曼恩河畔圣菲阿克尔', 47.1425500, -1.4171400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51147, 'Saint-Félix-Lauragais', 'Saint-Felix-Lauragais', 'Saint-Felix,Saint-Felix-Lauragais,Saint-Félix,Saint-Félix-Lauragais', 43.4486300, 1.8881400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51148, 'Saint-Félix', 'Saint-Felix', 'Saint-Felix,Saint-Félix', 45.8023000, 5.9710500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51149, 'Saint-Félicien', 'Saint-Felicien', 'Felisval,Saint-Felicien,Saint-Félicien', 45.0845800, 4.6271800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51150, 'Saint-Fargeau-Ponthierry', 'Saint-Fargeau-Ponthierry', 'Saint-Fargeau-sur-Seine,Sen-Farzho-Pont''erri,Сен-Фаржо-Понтьерри,Сен-Фаржо-Понтьєррі,سینٹ-فرگو-پونتھیررے', 48.5571300, 2.5284000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51151, 'Saint-Fargeau', 'Saint-Fargeau', 'Le Peletier,Saint Fageau,Saint-Fargeau', 47.6413300, 3.0706600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51152, 'Sainte-Verge', 'Sainte-Verge', 'Sainte-Verge', 47.0081800, -0.2103300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51153, 'Saint-Évarzec', 'Saint-Evarzec', 'Saint-Evarzec,Saint-Évarzec,Sant-Evarzeg,Sent-Evarzek,santevu~aruzekku,sheng ai wa er ze ke,Сент-Еварзек,سینٹ-ایوارزیک,サンテヴァルゼック,圣埃瓦尔泽克', 47.9333300, -4.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51154, 'Saint-Eustache-la-Forêt', 'Saint-Eustache-la-Foret', 'Saint-Eustache,Saint-Eustache-la-Foret,Saint-Eustache-la-Forêt', 49.5513700, 0.4559900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51155, 'Saint-Eusèbe', 'Saint-Eusebe', 'Cremont,Montfleury,Saint-Eusebe,Saint-Eusèbe,Sparte', 46.7134600, 4.4620300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51156, 'Sainte-Tulle', 'Sainte-Tulle', 'Sainte-Tulle,Santa Tullia,Santa Túllia,Sent-Tjul'',Tulle-les-Durance,sheng di er,Сент-Тюль,سین-تلے,圣蒂尔', 43.7884500, 5.7673600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51157, 'Saint-Étienne-sur-Chalaronne', 'Saint-Etienne-sur-Chalaronne', 'Saint-Etienne,Saint-Etienne-sur-Chalaronne,Saint-Étienne,Saint-Étienne-sur-Chalaronne', 46.1478100, 4.8655500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51158, 'Saint-Étienne-lès-Remiremont', 'Saint-Etienne-les-Remiremont', 'Saint-Etienne,Saint-Etienne-les-Remiremont,Saint-Étienne,Saint-Étienne-lès-Remiremont,Sent-Et''enn-le-Remirmon,Valmoselle,sheng ai di ye na lai lei mi lei meng,Сент-Етьенн-ле-Ремирмон,Сент-Етьєнн-ле-Ремірмон,سینٹ-ایٹیینے-لیس-ریمرمونٹ,圣埃蒂耶纳莱雷米雷蒙', 48.0228700, 6.6086800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51159, 'Le Dévoluy', 'Le Devoluy', 'Saint-Etienne,Saint-Etienne-en-Devoluy,Saint-Étienne,Saint-Étienne-en-Dévoluy', 44.6936200, 5.9406300, 'FR', '2017-01-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51160, 'Saint-Étienne-en-Coglès', 'Saint-Etienne-en-Cogles', 'Saint-Etienne,Saint-Etienne-en-Cogles,Saint-Étienne,Saint-Étienne-en-Coglès,Sant-Stefan-Gougleiz', 48.4017200, -1.3281200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51161, 'Saint-Étienne-du-Rouvray', 'Saint-Etienne-du-Rouvray', 'Saint-Etienne,Saint-Etienne-du-Rouvray,Saint-Étienne,Saint-Étienne-du-Rouvray,Sent Etjen di Ruvre,Sent-Eht''en-dju-Ruvreh,Sent-Et''enn-dju-Ruvre,saengtetiendwilubeule,san=tetien''nu=de~yu=ruvure,snt atyn dw rwwrh,Сент Етјен ди Рувре,Сент-Етьенн-дю-Рувре,Сент-Етьєнн-дю-Рувре,Сент-Этьен-дю-Руврэ,سنت اتین دو رووره,سینٹ-ایٹیینے-دو-روورے,サン＝テティエンヌ＝デュ＝ルヴレ,생테티엔뒤루브레', 49.3779400, 1.1046700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51162, 'Saint-Étienne-du-Grès', 'Saint-Etienne-du-Gres', 'Saint-Etienne,Saint-Etienne-du-Gres,Saint-Étienne,Saint-Étienne-du-Grès,Sant Esteve dau Gres,Sant Esteve de Tarascon,Sant Estève dau Gres,Sant Estève de Tarascon,Sent-Eht''en-dju-Gres,Sent-Et''enn-dju-Gre,sheng ai di an di ge lei,Сент-Етьєнн-дю-Гре,Сент-Этьен-дю-Грес,سینٹ-ایٹیینے-دو-گریس,圣埃蒂安迪格雷', 43.7811100, 4.7216300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51163, 'Saint-Étienne-du-Bois', 'Saint-Etienne-du-Bois', 'Saint-Etienne,Saint-Etienne-du-Bois,Saint-Étienne,Saint-Étienne-du-Bois', 46.8304100, -1.5971400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51164, 'Saint-Étienne-du-Bois', 'Saint-Etienne-du-Bois', 'Saint-Etienne,Saint-Etienne-du-Bois,Saint-Étienne-du-Bois,Sant-Stefan-ar-C''hoad', 46.2876600, 5.2948100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51165, 'Saint-Etienne-de-Tulmont', 'Saint-Etienne-de-Tulmont', 'Saint-Etienne,Saint-Etienne-de-Tulmont,Saint-Étienne,Saint-Étienne-de-Tulmont', 44.0500000, 1.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51166, 'Saint-Étienne-de-Saint-Geoirs', 'Saint-Etienne-de-Saint-Geoirs', 'Marathon,Mont-Geoirs,Saint-Etienne,Saint-Etienne-de-Saint-Geoirs,Saint-Étienne,Saint-Étienne-de-Saint-Geoirs', 45.3393100, 5.3449000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51167, 'Saint-Étienne-de-Montluc', 'Saint-Etienne-de-Montluc', 'Messidor,Saint-Etienne,Saint-Etienne-de-Montluc,Saint-Étienne,Saint-Étienne-de-Montluc,Sanctus Stephanus de Monteluci,Sant-Stefan-Brengolou,Sant-Stefan-Brengoloù,Sent-Et''enn-de-Monljuk,sheng ai di an de meng te lu ke,Сент-Етьєнн-де-Монлюк,سینٹ-ایٹیینے-دے-مونتلک,圣埃蒂安德蒙特吕克', 47.2769000, -1.7807200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51168, 'Saint-Étienne-de-Mer-Morte', 'Saint-Etienne-de-Mer-Morte', 'Mellomars,Saint-Etienne,Saint-Etienne-de-Mer-Morte,Saint-Étienne,Saint-Étienne-de-Mer-Morte,Sant-Stefan-Melveurzh,Sant-Stefan-Melveuzh,Sent-Et''enn-de-Mer-Mort,sheng ai di an de mei er-mo er te,Сент-Етьєнн-де-Мер-Морт,سین-ایتین-دے-مر-مورتے,圣埃蒂安德梅尔-莫尔特', 46.9284800, -1.7427200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51169, 'Saint-Étienne-de-Fontbellon', 'Saint-Etienne-de-Fontbellon', 'Saint-Etienne,Saint-Etienne-de-Fontbellon,Saint-Étienne,Saint-Étienne-de-Fontbellon', 44.6017500, 4.3858100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51170, 'Saint-Etienne-de-Cuines', 'Saint-Etienne-de-Cuines', 'Cuines,Saint-Etienne', 45.3500000, 6.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51171, 'Saint-Étienne-de-Crossey', 'Saint-Etienne-de-Crossey', 'Saint-Etienne,Saint-Etienne-de-Crossey,Saint-Étienne,Saint-Étienne-de-Crossey', 45.3791400, 5.6452700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51172, 'Saint-Étienne-de-Chigny', 'Saint-Etienne-de-Chigny', 'Chigne-les-Bois,Chigny-les-Bois,Chigné-les-Bois,Saint-Etienne,Saint-Etienne-de-Chigny,Saint-Étienne,Saint-Étienne-de-Chigny', 47.3833300, 0.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51173, 'Saint-Étienne-de-Baïgorry', 'Saint-Etienne-de-Baigorry', 'Baigorri,Saint-Etienne,Saint-Etienne-de-Baigorry,Saint-Étienne,Saint-Étienne-de-Baïgorry,Sent Esteve de Baigorri,Sent Estève de Baigòrri,Sent-Eht''en-de-Baigorri,Sent-Et''enn-de-Baigorri,Thermopile,sheng ai di an de bai ge er li,Сент-Етьенн-де-Баигорри,Сент-Етьєнн-де-Баїгоррі,Сент-Этьен-де-Баигорри,سینٹ-ایٹیینے-دے-بیگوررے,圣埃蒂安德拜戈尔里', 43.1753300, -1.3467000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51174, 'Saint-Étienne-au-Mont', 'Saint-Etienne-au-Mont', 'Audisque,Saint-Etienne,Saint-Etienne-au-Mont,Saint-Étienne,Saint-Étienne-au-Mont,Sent-Eht''enn-o-Mon,Sent-Et''enn-o-Mon,san aytyan aw mwnt,san=tetien''nu=o=mon,sheng ai di an ou meng,Сент-Етьенн-о-Мон,Сент-Етьєнн-о-Мон,Сент-Этьенн-о-Мон,سان إيتيان أو مونت,سینٹ-ایٹیینے-او-مونٹ,サン＝テティエンヌ＝オ＝モン,圣艾蒂安欧蒙', 50.6779400, 1.6308400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51175, 'Saint-Étienne', 'Saint-Etienne', 'Armes-Ville,Canton-d''Armes,Commune-d''Armes,EBU,Libre-Ville,Lungsod ng Saint-Etienne,Lungsod ng Saint-Étienne,Saint-Etien,Saint-Etienne,Saint-Étienne,Sainte,Sainté,Sanctus Stephanus de Furano,Sankta-Stefano,Sant Esteve,Sant Estève,Sant-Etieve,Sant-Etiève,Sent Etien,Sent Etjen,Sent Etjenas,Sent-Ehc''en,Sent-Eht''en,Sent-Et''en,Sent-Etyen,Sentetjena,Sentetjēna,St Etienne,St Étienne,saengtetien,san=techien''nu,san=tetien''nu,sant atyan,senta-etyena,sheng ai di an,sn-atyn,snt atyn,Σαιντ-Ετιέν,Сент Етиен,Сент Етјен,Сент-Етьєн,Сент-Этьен,Сент-Эцьен,Սենտ Էտիեն,סנט אטיין,سانت إتيان,ساں اتین,سن-اتین,سنت اتین,سینٹ-ایٹیینے,सेंत-एत्येन,แซ็งเตเตียน,სენტ-ეტიენი,サン＝テチエンヌ,サン＝テティエンヌ,圣艾蒂安,생테티엔', 45.4338900, 4.3900000, 'FR', '2016-05-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51176, 'Sainte-Terre', 'Sainte-Terre', 'Sainte-Terre', 44.8333300, -0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51177, 'Sainte-Suzanne', 'Sainte-Suzanne', 'Mont-d''Erve,Sainte-Suzanne', 48.0981800, -0.3543900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51178, 'Sainte-Suzanne', 'Sainte-Suzanne', 'Sainte-Suzanne', 47.5001700, 6.7677500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51179, 'Saint-Estève', 'Saint-Esteve', 'Saint-Esteve,Saint-Estève,Sant Esteve del Monestir,Sent-Estev,santesutevu,sheng ai si tai fu,Сент-Естев,سینٹ-ایسٹیوے,サンテステーヴ,圣埃斯泰夫', 42.7117500, 2.8449000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51180, 'Saint-Estèphe', 'Saint-Estephe', 'Saint-Estephe,Saint-Estèphe', 45.2625200, -0.7723700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51181, 'Sainte-Soulle', 'Sainte-Soulle', 'Roche-Libre,Rousseau,Sainte-Soulle', 46.1884700, -1.0160700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51182, 'Sainte-Solange', 'Sainte-Solange', 'Sainte-Solange', 47.1362800, 2.5501900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51183, 'Saintes-Maries-de-la-Mer', 'Saintes-Maries-de-la-Mer', 'Commune-de-la-Mer,Lei Santas,Lei Santei Marias de la Mar,Les Saintes Maries de la Mer,Les Saintes-Maries,Saintes-Maries,Saintes-Maries-de-la-Mer,Sent-Mari-de-la-Mer,Ville-de-la-Mer,sang tai si-ma li ye de la-mei,santo=mari=do=ra=meru,Сент-Мари-де-ла-Мер,Сент-Марі-де-ла-Мер,سینتیس-ماریس-دے-لا-مر,サント＝マリー＝ド＝ラ＝メール,桑泰斯-马里耶德拉-梅', 43.4521400, 4.4291300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51184, 'Sainte-Sigolène', 'Sainte-Sigolene', 'Sainte-Sigolene,Sainte-Sigolène,Santa Sigolena,Segolaine-les-Bois,Sent-Sigolen,Sigolaine,Sigolene,Sigolène,santo=shigorenu,sheng xi ge lai en,Сент-Сиголен,Сент-Сіголен,سین-سگولنے,サント＝シゴレーヌ,圣西戈莱恩', 45.2432900, 4.2334300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51185, 'Sainte-Savine', 'Sainte-Savine', 'Sainte-Savine,Sent-Savin,sheng sa wan,Сент-Савин,Сент-Савін,سین-سونے,圣萨万', 48.2963700, 4.0464200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51186, 'Saintes', 'Saintes', 'XST,Xantes', 45.7500000, -0.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51187, 'Saint-Erme-Outre-et-Ramecourt', 'Saint-Erme-Outre-et-Ramecourt', 'Saint-Erme,Saint-Erme-Outre e Ramecourt,Saint-Erme-Outre-et-Ramecourt,Sent-Ehrm-Utr-eh-Ramekur,Sent-Erm-Utr-e-Ramkur,sheng ai mo wu te er he la mo ku er,Сент-Ерм-Утр-е-Рамкур,Сент-Эрм-Утр-э-Рамекур,سینٹ-یرمے-اترے-یت-رامکورٹ,圣埃默乌特尔和拉默库尔', 49.5146400, 3.8406000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51188, 'Sainte-Reine-de-Bretagne', 'Sainte-Reine-de-Bretagne', 'Sainte-Reine,Sainte-Reine-de-Bretagne,Santez-Rouanez-Breizh', 47.4413100, -2.1923800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51189, 'Saint-Erblon', 'Saint-Erblon', 'Saint-Erblon,Sant-Ervlon-an-Dezerzh', 48.0189500, -1.6516200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51190, 'Sainte-Radegonde', 'Sainte-Radegonde', 'Sainte-Radegonde-Vrines', 46.9833300, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51191, 'Sainte-Radegonde', 'Sainte-Radegonde', 'Bel-Air,Sainte-Radegonde,Varanzay', 44.3374300, 2.6267200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51192, 'Sainte-Pazanne', 'Sainte-Pazanne', 'Franchere,Franchère,Sainte-Pazanne,Sancta Pisenia,Santez-Pezhenn,Sent-Pazann,sheng pa cang,Сент-Пазанн,سین-پزانے,圣帕藏', 47.1030100, -1.8095000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51193, 'Saint-Épain', 'Saint-Epain', 'Saint-Epain,Saint-Épain,Sent-Epen,sheng ai pan,Сент-Епен,سینٹ-اپین,圣埃潘', 47.1448200, 0.5366800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51194, 'Saint-Émilion', 'Saint-Emilion', 'Emilion-la-Montagne,Saint Emilion,Saint-Emilion,Saint-Emilion hegykoezseg,Saint-Émilion,Saint-Émilion hegyközség,Sent Milion,Sent-Ehmil''on,Sent-Emil''jon,san=temirion,sheng ai mi li weng,Сент-Емильйон,Сент-Емільйон,Сент-Эмильон,סנט-אמיליון,سینٹ-عملوں,แซ็งเตมีลียง,სენტ-ემილიონი,サン＝テミリオン,圣埃米利翁', 44.8833300, -0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51195, 'Sainte-Mère-Église', 'Sainte-Mere-Eglise', 'Mere-Libre,Mère-Libre,Saint-Mer-Enkliz,Sainte-Mere-Eglise,Sainte-Mère-Église,Sent-Mer-Egliz,Sent-Mer-Ehgliz,santo=meru=egurizu,sheng mei er ai ge li si,Σαιντ-Μερ-Εγκλίζ,Сент-Мер-Еглиз,Сент-Мер-Егліз,Сент-Мер-Эглиз,סנט מר אגליז,سین-میرے-ایگلیسے,サント＝メール＝エグリーズ,圣梅尔埃格利斯', 49.4100000, -1.3172600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51196, 'Sainte-Menehould', 'Sainte-Menehould', 'Montagne-sur-Aisne,Sancta Manechildis,Sent-Menu,santo=munu,sheng mei nei wu er de,Сент-Мену,سین-منیھولڈ,サント＝ムヌー,圣梅内乌尔德', 49.0833300, 4.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51197, 'Sainte-Maxime', 'Sainte-Maxime', 'Cassius,Saint-Maxine,Sainte-Maxime,Sainte-Maxime-sur-Mer,Santa Maxima,Sent-Maksim,sang te ma ke xi mo,Сент-Максим,Сент-Максім,سین-شمے,桑特马克西默', 43.3090700, 6.6384900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51198, 'Sainte-Maure-de-Touraine', 'Sainte-Maure-de-Touraine', 'Maure-Libre,Sainte-Maure,Sainte-Maure-de-Touraine', 47.1113000, 0.6223600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51199, 'Sainte-Maure', 'Sainte-Maure', 'Mont-Bel-Air,Sainte-Maure', 48.3472900, 4.0596200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51200, 'Sainte-Marie-Plage', 'Sainte-Marie-Plage', '', 42.7249800, 3.0375100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51201, 'Sainte-Marie-Kerque', 'Sainte-Marie-Kerque', 'Sainte-Marie-Kerque,Sent-Mari-Kerk,san mary kyrkyw,sheng ma li kai er ke,Сент-Мари-Керк,Сент-Марі-Керк,سان ماري كيركيو,سین-مرے-کرقے,圣玛丽凯尔克', 50.8991700, 2.1366400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51202, 'Sainte-Marie-des-Champs', 'Sainte-Marie-des-Champs', 'Sainte-Marie,Sainte-Marie-des-Champs', 49.6212000, 0.7790400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51203, 'Sainte-Marie-de-Ré', 'Sainte-Marie-de-Re', 'La Pointe,Sainte-Marie,Sainte-Marie-de-Re,Sainte-Marie-de-Ré,Sent-Mari-de-Re,Union,sheng ma li de lei,Сент-Мари-де-Ре,Сент-Марі-де-Ре,سین-مرے-دے-رے,圣玛丽德雷', 46.1523700, -1.3128100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51204, 'Sainte-Marie-de-Gosse', 'Sainte-Marie-de-Gosse', 'Barra,Sainte-Marie,Sainte-Marie-de-Gosse', 43.5500000, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51205, 'Sainte-Marie-aux-Mines', 'Sainte-Marie-aux-Mines', 'Markirch,Sainte Marie aux Mains,Sainte-Marie-aux-Mines,Sent-Mari-o-Min,Val-aux-Mines,Сент-Мари-о-Мин,Сент-Марі-о-Мін,سین-مرے-آ-مائنز', 48.2468000, 7.1852800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51206, 'Sainte-Marie-aux-Chênes', 'Sainte-Marie-aux-Chenes', 'Sainte-Marie,Sainte-Marie-aux-Chenes,Sainte-Marie-aux-Chênes,Sent-Mari-o-Shen,sheng ma li-ao xie nei,Сент-Мари-о-Шен,Сент-Марі-о-Шен,سین-مرے-آ-چنیس,圣玛丽-奥谢内', 49.1916800, 6.0006500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51207, 'Sainte-Marie', 'Sainte-Marie', 'Lokmaria-Redon,Sainte-Marie', 47.6942900, -2.0019000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51208, 'Sainte-Marguerite-sur-Duclair', 'Sainte-Marguerite-sur-Duclair', 'Sainte-Marguerite,Sainte-Marguerite-sur-Duclair', 49.5085200, 0.8436200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51209, 'Sainte-Marguerite', 'Sainte-Marguerite', 'Meurthe-Fave,Sainte-Marguerite', 48.2673500, 6.9843900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51210, 'Sainte-Luce-sur-Loire', 'Sainte-Luce-sur-Loire', 'Sainte-Luce,Sainte-Luce-sur-Loire,Santez-Lusenn,Sent-Ljus-sjur-Luar,lu wa er he pan sheng lu ke,santo=ryusu=shuru=rowaru,Сент-Люс-сюр-Луар,سین-لکے-سر-لڑے,サント＝リュース＝シュル＝ロワール,卢瓦尔河畔圣吕克', 47.2538100, -1.4843000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51211, 'Saint-Éloy-les-Mines', 'Saint-Eloy-les-Mines', 'Saint-Eloy,Saint-Eloy-les-Mines,Saint-Éloy,Saint-Éloy-les-Mines', 46.1579300, 2.8362300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51212, 'Saint-Éloy-de-Gy', 'Saint-Eloy-de-Gy', 'Saint-Eloy,Saint-Eloy-de-Gy,Saint-Éloy-de-Gy', 47.1555200, 2.3426700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51213, 'Saint-Éloi', 'Saint-Eloi', 'Loi,Saint-Eloi,Saint-Éloi', 46.9734200, 3.2222800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51214, 'Sainte-Lizaigne', 'Sainte-Lizaigne', 'Sainte-Lizaigne,Sent-Lizen'',Vin-Bon,sheng li ze ni,Сент-Лизень,Сент-Лізень,سین-لیزایگنے,圣利泽尼', 47.0069500, 2.0226600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51215, 'Sainte-Livrade-sur-Lot', 'Sainte-Livrade-sur-Lot', 'Sainte-Livrade,Sainte-Livrade-sur-Lot,Santa Liurada,Sent-Livrad-sjur-Lot,Senta Liurada,luo te he pan sheng li fu la de,Сент-Ливрад-сюр-Лот,Сент-Ліврад-сюр-Лот,سین-لورادے-سر-لوٹ,洛特河畔圣利夫拉德', 44.3992900, 0.5912000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51216, 'Sainte-Jamme-sur-Sarthe', 'Sainte-Jamme-sur-Sarthe', 'Sainte-Jamme,Sainte-Jamme-sur-Sarthe,Sainte-Jammes-sur-Sarthe,Sainte-Jeanne,Sent-Zhamm-sjur-Sart,Сент-Жамм-сюр-Сарт,سین-جممے-سر-سرٹھے', 48.1426400, 0.1674300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51217, 'Sainte-Honorine-du-Fay', 'Sainte-Honorine-du-Fay', 'Sainte-Honorine,Sainte-Honorine-du-Fay', 49.0777500, -0.4929500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51218, 'Sainte-Hermine', 'Sainte-Hermine', 'Hermand-le-Guerrier,Hermine-sur-Sinagne,Sainte-Hermine', 46.5561900, -1.0547600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51219, 'Sainte-Hélène-sur-Isère', 'Sainte-Helene-sur-Isere', 'Les Forges,Sainte-Helene,Sainte-Helene-sur-Isere,Sainte-Hélène,Sainte-Hélène-sur-Isère', 45.6131300, 6.3206500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51220, 'Sainte-Hélène', 'Sainte-Helene', 'Sainte-Helene,Sainte-Hélène,Santez-Elen', 47.7197600, -3.2035900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51221, 'Sainte-Hélène', 'Sainte-Helene', 'Sainte-Helene,Sainte-Hélène', 44.9666700, -0.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51222, 'Sainte-Geneviève-sur-Argence', 'Sainte-Genevieve-sur-Argence', 'Sainte-Genevieve,Sainte-Genevieve-sur-Argence,Sainte-Geneviève,Sainte-Geneviève-sur-Argence,Sant Jurveva,Sant Jurvèva,Sent Jurveva,Sent Jurvèva,Sent-Zhenev''ev-sjur-Arzhans,Sent-Zhenevev-sjur-Arzhans,a er rang ke he pan sheng re na wei ye fu,Сент-Женевьев-сюр-Аржанс,Сент-Женевєв-сюр-Аржанс,سین-گنویوے-سر-ارگنکے,阿尔让克河畔圣热纳维耶夫', 44.8022200, 2.7595400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51223, 'Sainte-Geneviève-des-Bois', 'Sainte-Genevieve-des-Bois', 'Colbert-la-Reunion,Colbert-la-Réunion,Sainte-Genevieve,Sainte-Genevieve-des-Bois,Sainte-Geneviève,Sainte-Geneviève-des-Bois,Sent-Zhenev''ev-de-Bua,Сент-Женевьев-де-Буа', 48.6468200, 2.3196500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51224, 'Sainte-Geneviève-des-Bois', 'Sainte-Genevieve-des-Bois', 'Sainte-Genevieve,Sainte-Genevieve-des-Bois,Sainte-Geneviève,Sainte-Geneviève-des-Bois,Sent-Zhenev''ev-de-Bua,Сент-Женевьев-де-Буа', 47.8177700, 2.8165200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51225, 'Sainte-Geneviève', 'Sainte-Genevieve', 'Sainte-Genevieve,Sainte-Geneviève', 49.2892000, 2.1990400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51226, 'Sainte-Gemmes-sur-Loire', 'Sainte-Gemmes-sur-Loire', 'Sainte-Gemme,Sainte-Gemmes-sur Loire,Sent-Zhemm-sjur-Luar,lu wa er he pan sheng re mei,Сент-Жемм-сюр-Луар,سین-گممس-سر-لڑے,卢瓦尔河畔圣热梅', 47.4229000, -0.5568400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51227, 'Sainte-Gemme-la-Plaine', 'Sainte-Gemme-la-Plaine', 'Les Bruyeres,Les Bruyères,Sainte-Gemme,Sainte-Gemme-la-Plaine', 46.4828600, -1.1132100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51228, 'Sainte-Gauburge-Sainte-Colombe', 'Sainte-Gauburge-Sainte-Colombe', 'Sainte-Gauburge,Sainte-Gauburge-Sainte-Colombe,Sent-Gobjurzh-Sent-Kolomb,sheng ge bi er re-sheng ke long bu,Сент-Гобюрж-Сент-Коломб,سین-گوبرگے-سین-کولومبے,圣戈比尔热-圣科隆布', 48.7172200, 0.4312600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51229, 'Sainte-Foy-lès-Lyon', 'Sainte-Foy-les-Lyon', 'Beauvais-l''Isle-Barbe,Bonnefey,Canton-Chalier,Canton-Egalite,Canton-Egalité,Canton-de-Marat,Canton-de-la-Convention,Canton-de-la-Federation,Canton-de-la-Fédération,Canton-de-la-Liberte,Canton-de-la-Liberté,Canton-de-la-Montagne,Canton-de-la-Raison,Canton-le-Peletier,Canton-sans-Culotte,Commune-Affranchie,Commune-Chalier,Mont-Chalier,Quartier-de-la-Montagne,Saint-Foy,Sainte-Foy,Sainte-Foy-les-Lyon,Sainte-Foy-lez-Lyon,Sainte-Foy-lès-Lyon,Sent Foa le Lion,Sent-Fua-le-Lion,saengteupualeliong,santo=fowa=re=riyon,snt fwa llywn,Сент Фоа ле Лион,Сент-Фуа-ле-Лион,Сент-Фуа-ле-Ліон,سنت فوآ للیون,سین-فوے-لیس-لیوں,サント＝フォワ＝レ＝リヨン,생트푸아레리옹', 45.7369200, 4.7968800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51230, 'Sainte-Foy-l’Argentière', 'Sainte-Foy-l''Argentiere', 'Foy-sur-Brevenne,Saint-Foy-l''Argentiere,Saint-Foy-l’Argentière,Sainte-Foy,Sainte-Foy-l''Argentiere,Sainte-Foy-l’Argentière', 45.7083200, 4.4726600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51231, 'Sainte-Foy-de-Peyrolières', 'Sainte-Foy-de-Peyrolieres', 'Peyroulieres,Peyroulières,Sainte-Foy,Sainte-Foy de Peyrollieres,Sainte-Foy de Peyrollières,Sainte-Foy-de-Peyrolieres,Sainte-Foy-de-Peyrolières,Sainte-Foy-de-Peyrolleres,Sainte-Foy-de-Peyrollères', 43.4926200, 1.1447700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51232, 'Sainte-Foy', 'Sainte-Foy', 'Le Desert,Le Désert,Sainte-Foy', 46.5448800, -1.6726500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51233, 'Sainte-Fortunade', 'Sainte-Fortunade', 'Sainte-Fortunade,Sent-Fortjunad,Senta Fortunada,sheng fu er di na de,Сент-Фортюнад,سین-فورتنادے,圣福尔蒂纳德', 45.2080500, 1.7718100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51234, 'Sainte-Florine', 'Sainte-Florine', 'Florine-le-Charbon,Sainte-Florine,Santa Florina,Sent-Florin,santo=furorinu,sheng fu luo lan,Сент-Флорин,سین-فلورنے,サント＝フロリーヌ,圣弗洛兰', 45.4054600, 3.3199500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51235, 'Sainte-Flaive-des-Loups', 'Sainte-Flaive-des-Loups', 'Louvetiere,Louvetière,Sainte-Flaive,Sainte-Flaive-des-Loups', 46.6130300, -1.5808200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51236, 'Sainte-Feyre', 'Sainte-Feyre', 'Sainte-Feyre', 46.1390000, 1.9151700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51237, 'Sainte-Féréole', 'Sainte-Fereole', 'Montagne-Frimaire,Montfrimaire,Saint-Fereole,Saint-Féréole,Sainte-Fereole,Sainte-Féréole', 45.2280600, 1.5827800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51238, 'Sainte-Euphémie', 'Sainte-Euphemie', 'Sainte-Euphemie,Sainte-Euphémie', 45.9719600, 4.7943700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51239, 'Sainte-Eulalie', 'Sainte-Eulalie', 'Sainte-Eulalie', 44.9066700, -0.4741700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51240, 'Saint-Égrève', 'Saint-Egreve', 'Saint Egreve,San Egreve,Sent-Egrev,Sent-Ehgrev,Vence,sheng ai ge lei fu,Сент-Егрев,Сент-Эгрев,سینٹ-ایگریوے,圣埃格雷夫', 45.2333300, 5.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51241, 'Sainte-Croix-en-Plaine', 'Sainte-Croix-en-Plaine', 'Heilig-Kreuz,Saint-Croix,Sent-Krua-en-Plen,Сент-Круа-ен-Плен,سین-کروئی-این -پلانے', 48.0087600, 7.3855600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51242, 'Sainte-Croix-aux-Mines', 'Sainte-Croix-aux-Mines', 'Sainte-Croix,Sainte-Croix-aux-Mines,Sent-Krua-o-Min,syn-krwyy-a-maynz,Сент-Круа-о-Мин,Сент-Круа-о-Мін,سین-کروئی-آ-مائنز', 48.2612400, 7.2244500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51243, 'Sainte-Consorce', 'Sainte-Consorce', 'Les Marrons,Sainte-Consorce', 45.7770600, 4.6973500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51244, 'Sainte-Colombe-en-Bruilhois', 'Sainte-Colombe-en-Bruilhois', 'Sainte-Colombe,Sainte-Colombe-en-Bruilhois,Sent-Kolomb-an-Brjuiua,Senta Coloma de Brulhes,Senta Coloma de Brulhés,Senta Colomba de la Pluma,bu lu yi yue yi de qu sheng ke long bu,Сент-Коломб-ан-Брюиуа,Сент-Коломб-ан-Брюїуа,سین-کولومبے-این -بریلھوس,布吕伊约伊地区圣科隆布', 44.1782200, 0.5157200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51245, 'Sainte-Colombe', 'Sainte-Colombe', 'Sainte-Colombe', 48.5304700, 3.2551700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51246, 'Sainte-Colombe', 'Sainte-Colombe', 'Sainte-Colombe', 45.5247400, 4.8613600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51247, 'Sainte-Cécile-les-Vignes', 'Sainte-Cecile-les-Vignes', 'Cecile-Montagnarde,Cécile-Montagnarde,Sainte-Cecile,Sainte-Cecile-les-Vignes,Sainte-Cécile,Sainte-Cécile-les-Vignes,Santa Celha dei Vinhas,Sent-Sesil''-le-Vin'',sang te sai xi lai-lai wei ge,Сент-Сесиль-ле-Винь,Сент-Сесіль-ле-Вінь,سین-کیلے-لیس-وگنس,桑特塞西莱-莱维格', 44.2450600, 4.8839000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51248, 'Sainte-Cécile', 'Sainte-Cecile', 'Sainte-Cecile,Sainte-Cécile', 46.7428600, -1.1142900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51249, 'Sainte-Catherine', 'Sainte-Catherine', 'Sainte-Catherine,Sainte-Catherine-lez-Arras,Sainte-Catherine-lèz-Arras', 50.3075700, 2.7640400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51250, 'Sainte-Bazeille', 'Sainte-Bazeille', 'Chalier,Sainte-Bazeille,Sent-Bazej,Senta Baselha,Senta Vaselha,sheng ba ze er,Сент-Базей,سین-بزیلے,圣巴泽尔', 44.5307300, 0.0974000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51251, 'Sainte-Anne-sur-Brivet', 'Sainte-Anne-sur-Brivet', 'Sainte-Anne,Sainte-Anne-de-Campbon,Santez-Anna-ar-Brived,Sent-Ann-sjur-Brive,bu li wei he pan sheng ang,syn-ayn-sr-brwt,Сент-Анн-сюр-Бриве,سین-این-سر-بروت,布里韦河畔圣昂', 47.4607100, -2.0041500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51252, 'Sainte-Anastasie-sur-Issole', 'Sainte-Anastasie-sur-Issole', 'Sainte-Anastasie,Sainte-Anastasie-sur-Issole', 43.3421100, 6.1235900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51253, 'Sainte-Agnès', 'Sainte-Agnes', 'Saint-Agnes,Saint-Agnès,Sainte-Agnes,Sainte-Agnès', 43.7994300, 7.4659500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51254, 'Sainte-Adresse', 'Sainte-Adresse', 'Cap-d''Antifer,Cap-de-la-Heve,Cap-de-la-Hève,Sent-Adress,Сент-Адресс,سین-ادریسسے', 49.5089000, 0.0844600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51255, 'Saint-Dyé-sur-Loire', 'Saint-Dye-sur-Loire', 'Die,Die-sur-Loire,Dié,Dié-sur-Loire,Saint-Dye,Saint-Dye-sur-Loire,Saint-Dyé,Saint-Dyé-sur-Loire,Sen-Die-sjur-Luar,lu wa er he pan sheng di ai,Сен-Діе-сюр-Луар,سینٹ ڈائی سر لورے,卢瓦尔河畔圣迪埃', 47.6559500, 1.4884700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51256, 'Saint-Drézéry', 'Saint-Drezery', 'Saint-Drezery,Saint-Drézéry', 43.7299100, 3.9762000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51257, 'Saint-Doulchard', 'Saint-Doulchard', 'Saint-Doulchard,Unite-sur-Yevre,Unité-sur-Yèvre', 47.1037100, 2.3520000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51258, 'Saint-Donan', 'Saint-Donan', 'Saint-Donan,Sant-Donan,Sen-Donan,sheng duo nan,Сен-Донан,سینٹ-دوناں,圣多南', 48.4695800, -2.8844200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51259, 'Saint-Domineuc', 'Saint-Domineuc', 'Landoveneg,Saint-Domineuc', 48.3719100, -1.8754400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51260, 'Saint-Dolay', 'Saint-Dolay', 'Saint-Dolay,Sant-Aelwez', 47.5447600, -2.1546600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51261, 'Saint-Dizier', 'Saint-Dizier', 'Saint-Dizier,Sanctus Desiderius,Sankt-Diz''e,Sen Dizje,Sen-Diz''e,saengdijie,san=dijie,sheng di ji ye,sn dyzyh,Санкт-Дизье,Сен Дизје,Сен-Дизье,Сен-Дізьє,سن دیزیه,سینٹ-دزئر,แซ็ง-ดีซีเย,サン＝ディジエ,聖迪濟耶,생디지에', 48.6333300, 4.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51262, 'Saint-Dié-des-Vosges', 'Saint-Die-des-Vosges', 'Sanctus Deodatus,Sen Dje de Vogez,Sen-D''e-de-Vozh,Sen-Dye-de-Voj,Sendjedevoza,Sendjēdevoža,Vogezu Sen Dje,Vogėzų Sen Djė,XTD,dyyh-dh-wwz,fu ri sheng di ye,saengdiedeboju,san=die=de=vu~oju,sn-dyh-dh-wwzh,snt dy,synt dy,Сен Дје де Вогез,Сен-Дье-де-Вож,Сен-Дьє-де-Вож,דייה-דה-ווז,سن-دیه-ده-ووژ,سنت دی,سينت دي,سینٹ-دے-دس-ووسگس,サン＝ディエ＝デ＝ヴォージュ,孚日圣迪耶,생디에데보주', 48.2833300, 6.9500000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51263, 'Saint-Didier-sur-Chalaronne', 'Saint-Didier-sur-Chalaronne', 'Saint-Didier,Saint-Didier-de Chalaronne,Saint-Didier-sur-Chalaronne', 46.1775100, 4.8171900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51264, 'Saint-Didier-sous-Riverie', 'Saint-Didier-sous-Riverie', 'Basse-Montagne,Beaurepaire,Saint Didier,Saint-Didier-sous-Riverie', 45.5962700, 4.6065000, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51265, 'Saint-Didier-en-Velay', 'Saint-Didier-en-Velay', 'Saint-Didier,Saint-Didier-en-Velay', 45.3023400, 4.2756100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51266, 'Saint-Didier-de-la-Tour', 'Saint-Didier-de-la-Tour', 'Saint Didier,Saint-Didier-de-la-Tour', 45.5554800, 5.4831400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51267, 'Saint-Didier-de-Formans', 'Saint-Didier-de-Formans', 'Saint-Didier,Saint-Didier-de-Formans', 45.9536100, 4.7848500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51268, 'Saint-Didier', 'Saint-Didier', 'Saint-Didier,Sant-Ider', 48.0950600, -1.3727600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51269, 'Saint-Didier', 'Saint-Didier', 'Pierre-Blanche,Saint Didier-les-Bois', 44.0042400, 5.1105300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51270, 'Saint-Désir', 'Saint-Desir', 'Saint-Desir,Saint-Désir', 49.1405600, 0.2139800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51271, 'Saint-Denis-sur-Sarthon', 'Saint-Denis-sur-Sarthon', 'Saint-Denis,Saint-Denis-sur-Sarthon,Sarthon-sous-Chaumont', 48.4532000, -0.0472000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51272, 'Saint-Denis-les-Ponts', 'Saint-Denis-les-Ponts', 'Saint-Denis,Saint-Denis-les-Ponts', 48.0669200, 1.2976400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51273, 'Saint-Denis-lès-Bourg', 'Saint-Denis-les-Bourg', 'Saint-Denis,Saint-Denis-les-Bourg,Saint-Denis-lès-Bourg,Sen Deni le Bur,Sen-Deni-le-Bur,san-dyny-ly-bwr  ayn,sheng dan ni lai bu er ge,Сен-Дени-ле-Бур,Сен-Дені-ле-Бур,Սեն Դենի լե Բուր,سان-ديني-لي-بور، أين,سینٹ-ڈینس-لیس-بارگ,圣但尼莱布尔格', 46.2021700, 5.1892400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51274, 'Saint-Denis-la-Chevasse', 'Saint-Denis-la-Chevasse', 'Saint-Denis,Saint-Denis-la-Chevasse', 46.8227300, -1.3574900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51275, 'Saint-Denis-en-Val', 'Saint-Denis-en-Val', 'Saint-Denis,Saint-Denis-en-Val,Sen-Deniz-an-Val'',wa de qu sheng de ni,Сен-Деніз-ан-Валь,سینٹ-ڈینس-این -ول,瓦地区圣德尼', 47.8732100, 1.9660100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51276, 'Saint-Denis-en-Bugey', 'Saint-Denis-en-Bugey', 'Le Chosson-d''Albarine,Saint-Denis,Saint-Denis-en-Bugey', 45.9489000, 5.3280800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51277, 'Saint-Denis-d’Oléron', 'Saint-Denis-d''Oleron', 'Cite-de-la-Reunion,Cité-de-la-Réunion,La Reunion-sur-mer,La Réunion-sur-mer,Saint-Denis,Saint-Denis-d''Oleron,Saint-Denis-d’Oléron,Sen-Deni-d''Oleron,Сен-Дени-д''Олерон', 46.0349600, -1.3786700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51278, 'Saint-Denis-de-Pile', 'Saint-Denis-de-Pile', 'Saint-Denis-de Pilles,Saint-Denis-de-Pile', 45.0000000, -0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51279, 'Saint-Denis-de-Gastines', 'Saint-Denis-de-Gastines', 'Saint-Denis,Saint-Denis-de-Gastines', 48.3421000, -0.8586900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51280, 'Saint-Denis-de-Cabanne', 'Saint-Denis-de-Cabanne', 'Saint-Denis,Saint-Denis-de-Cabanne', 46.1734800, 4.2109100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51281, 'Saint-Denis', 'Saint-Denis', 'Kamuna Sen-Dehni,Sain-Nteni,Saint-Denis,Sanctus Dionysius,Sen Deni,Sen-Deni,Sendeni,Sendenī,saengdeuni,san dwny,san=doni,senta denisa,senta-denisa,sheng dan ni,sn-dny,Σαιν-Ντενί,Камуна Сен-Дэні,Сен Дени,Сен-Дени,Сен-Дені,سان دوني,ساں ڈینس,سن-دنی,سینٹ-ڈینس,सेंट डेनिस,सेंत-देनिस,แซ็ง-เดอนี,サン＝ドニ,聖但尼,생드니', 48.9333300, 2.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51282, 'Saint-Cyr-sur-Morin', 'Saint-Cyr-sur-Morin', 'La Fraternite,La Fraternité,Saint-Cyr,Saint-Cyr-sur-Morin', 48.9066400, 3.1801600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51283, 'Saint-Cyr-sur-Mer', 'Saint-Cyr-sur-Mer', 'Saint-Cyr,Saint-Cyr-sur-Mer,Sant Ceri de Mar,Sen Sir sjur Mer,Sen-Sir-sjur-Mer,St-Cyr-sur-Mer,bin hai sheng xi,Сен Сир сюр Мер,Сен-Сир-сюр-Мер,Сен-Сір-сюр-Мер,سینٹ-کیر-سر-مر,滨海圣西', 43.1835200, 5.7091400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51284, 'Saint-Cyr-sur-Menthon', 'Saint-Cyr-sur-Menthon', 'Saint-Cyr,Saint-Cyr-sur-Menthon,Sen Sir syur Manton,Sen-Sir-sjur-Manton,mang tong he pan sheng xi er,san-syr-swr-myntw  ayn,Сен-Сир-сюр-Мантон,Сен-Сір-сюр-Мантон,Սեն Սիր սյուր Մանտոն,سان-سير-سور-مينتو، أين,سینٹ-کیر-سر-منتھوں,芒通河畔圣西尔', 46.2754900, 4.9722900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51285, 'Saint-Cyr-sur-Loire', 'Saint-Cyr-sur-Loire', 'Belle-Cote,Belle-Côte,Saint-Cyr,Saint-Cyr-sur-Loire', 47.4000000, 0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51286, 'Saint-Cyr-sur-le-Rhône', 'Saint-Cyr-sur-le-Rhone', 'Ovize-sur-le-Rhone,Ovize-sur-le-Rhône,Saint Cyr,Saint-Cyr-sur-le-Rhone,Saint-Cyr-sur-le-Rhône', 45.5153700, 4.8500200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51287, 'Saint-Cyr-sous-Dourdan', 'Saint-Cyr-sous-Dourdan', 'Franc-Cyr,Saint-Cyr,Sen-Sir-su-Durdan,sheng xi su du er dang,Сен-Сир-су-Дурдан,Сен-Сір-су-Дурдан,سینٹ-کیر-سوس-ڈوردان,圣西苏杜尔当', 48.5666700, 2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51288, 'Saint-Cyr-l’École', 'Saint-Cyr-l''Ecole', 'Libreval,Saint-Cyr,Saint-Cyr-l''Ecole,Saint-Cyr-l''École,Saint-Cyr-l’École,Sen-Sir-Lekol'',Sen-Sir-l''Ekol'',Val-Libre,sant syr akwl,Сен-Сир-Леколь,Сен-Сир-л''Еколь,Сен-Сір-л''Еколь,سانت سير إكول', 48.7986500, 2.0681400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51289, 'Saint-Cyr-en-Val', 'Saint-Cyr-en-Val', 'Saint-Cyr-en-Val,Sen-Sir-an-Val'',wa de qu sheng xi,Сен-Сір-ан-Валь,سینٹ-کیر-این -ول,瓦地区圣西', 47.8318200, 1.9667200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51290, 'Saint-Cyr-en-Bourg', 'Saint-Cyr-en-Bourg', 'Saint-Cyr', 47.1952000, -0.0608500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51291, 'Saint-Cyr', 'Saint-Cyr', 'Ciran,Saint-Cyr', 45.2524300, 4.7307400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51292, 'Saint-Cyprien-Plage', 'Saint-Cyprien-Plage', 'Saint-Cyprien-Plage', 42.6322900, 3.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51293, 'Saint-Cyprien', 'Saint-Cyprien', 'Saint-Cyprien', 45.5337500, 4.2331100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51294, 'Saint-Cyprien', 'Saint-Cyprien', 'Cyprien-sur-Dordogne', 44.8692400, 1.0415600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51295, 'Saint-Crespin-sur-Moine', 'Saint-Crespin-sur-Moine', 'Saint-Crespin,Saint-Crespin-sur-Moine,Sen-Krespen-sjur-Muan,mu wan he pan sheng ke lei si pan,Сен-Креспен-сюр-Муан,سینٹ-کرسپن-سر-منے,穆万河畔圣克雷斯潘', 47.0996800, -1.1865100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51296, 'Saint-Crépin-Ibouvillers', 'Saint-Crepin-Ibouvillers', 'Saint-Crepin,Saint-Crepin-Ibouvillers,Saint-Crépin,Saint-Crépin-Ibouvillers', 49.2628300, 2.0779300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51297, 'Saint-Coulomb', 'Saint-Coulomb', 'Coulomb-Rocher,Saint-Coulomb,Sant-Kouloum,Sen-Kulom,sheng ku long,Сен-Кулом,سینٹ-کولومب,圣库隆', 48.6746500, -1.9109200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51298, 'Saint-Cosme-en-Vairais', 'Saint-Cosme-en-Vairais', 'Montrecipe,Saint-Cosme,Saint-Cosme-de-Vair,Saint-Gosme-de-Vair', 48.2666700, 0.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51299, 'Saint-Contest', 'Saint-Contest', 'Saint-Contest,Sen-Kontest,sheng kong tai si,Сен-Контест,سینٹ-کانٹیسٹ,圣孔泰斯', 49.2140100, -0.4022100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51300, 'Saint-Cloud', 'Saint-Cloud', 'La Montagne-Cherie,La Montagne-Chérie,Pont-la-Montagne,Saint-Cloud,Sanctus Clodoaldus,Sen Klu,Sen-Klu,Senklu,Senklū,san klw,san=kuru,sheng ke lu,sn klw,Сен Клу,Сен-Клу,سان كلو,سن کلو,サン＝クルー,圣克卢', 48.8459800, 2.2028900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51301, 'Saint-Clément-des-Levées', 'Saint-Clement-des-Levees', 'Saint-Clement,Saint-Clement-des-Levees,Saint-Clément,Saint-Clément-des-Levées', 47.3333300, -0.1822200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51302, 'Saint-Clément-de-la-Place', 'Saint-Clement-de-la-Place', 'Saint-Clement,Saint-Clement-de-la-Place,Saint-Clément,Saint-Clément-de-la-Place,Sen-Kleman-de-la-Plas,sheng ke lai mang de la-pu la ke,Сен-Клеман-де-ла-Плас,سینٹ-کلیمنٹ-دے-لا-پلیس,圣克莱芒德拉-普拉克', 47.5274400, -0.7454500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51303, 'Saint-Clément', 'Saint-Clement', 'Saint-Clement,Saint-Clément', 48.2172400, 3.2960900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51304, 'Saint-Clément', 'Saint-Clement', 'Saint-Clement,Saint-Clément', 45.3418800, 1.6857300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51305, 'Saint-Clément-de-Rivière', 'Saint-Clement-de-Riviere', 'Sant Clamenc,Sant Clamenç,Sen-Kleman-de-Riv''er,Sen-Kleman-de-River,sheng ke lai mang de li wei ai,Сен-Клеман-де-Ривьер,Сен-Клеман-де-Ривєр,سینٹ-کلیمنٹ-دے-ریویرے,圣克莱芒德里维埃', 43.6833300, 3.8333300, 'FR', '2017-04-27', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51306, 'Saint-Claude-de-Diray', 'Saint-Claude-de-Diray', 'Claude,Diray-Moret,Diray-la-Montagne,Mont-Mentel,Morest-la-Montagne,Saint-Claude,Saint-Claude-de-Diray,Sen-Klod-de-Dire,sheng ke luo de de di lai,Сен-Клод-де-Діре,سینٹ-کلاڈ-دے-ڈیرے,圣克洛德德迪赖', 47.6165100, 1.4179800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51307, 'Saint-Claude', 'Saint-Claude', 'XTC', 46.3867900, 5.8647300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51308, 'Saint-Claud', 'Saint-Claud', 'Claud-la-Montagne,Saint-Claud,Sen-Klo,Sent Claud,sheng ke luo,Сен-Кло,سینٹ-کلاؤڈ,圣克洛', 45.8952600, 0.4645400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51309, 'Saint-Clair-du-Rhône', 'Saint-Clair-du-Rhone', 'Saint-Clair,Saint-Clair-du-Rhone,Saint-Clair-du-Rhône,Sen-Kler-dju-Ron,sheng ke lai di long,Сен-Клер-дю-Рон,سینٹ-کلئیر-دو-رہونے,圣克莱迪龙', 45.4390900, 4.7717800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51310, 'Saint-Clair-de-la-Tour', 'Saint-Clair-de-la-Tour', 'Mont-Clair,Saint-Clair,Saint-Clair-de-la-Tour', 45.5734300, 5.4833200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51311, 'Saint-Ciers-sur-Gironde', 'Saint-Ciers-sur-Gironde', 'Saint-Ciers,Saint-Ciers-sur-Gironde,Sen-S''e-sjur-Zhirond,ji long de he pan sheng xie er,Сен-Сье-сюр-Жиронд,Сен-Сьє-сюр-Жиронд,سینٹ-کیرس-سر-گروندے,吉龙德河畔圣谢尔', 45.2885500, -0.6079400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51312, 'Saint-Ciers-d’Abzac', 'Saint-Ciers-d''Abzac', 'Gar-Dor-Isle,Saint-Ciers,Saint-Ciers-d''Abzac,Saint-Ciers-d’Abzac', 45.0333300, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51313, 'Saint-Christophe-Vallon', 'Saint-Christophe-Vallon', 'Saint-Christophe,Saint-Christophe-Vallon', 44.4707200, 2.4118400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51314, 'Saint-Christophe-sur-le-Nais', 'Saint-Christophe-sur-le-Nais', 'Saint-Christophe,Saint-Christophe-sur-le-Nais,Sen-Kristof-sjur-le-Ne,Val-Riam,Val-Riant,lai-nai he pan sheng ke li si tuo fu,Сен-Кристоф-сюр-ле-Не,سینٹ-کروسٹوفے-سر-لے-نائس,莱-奈河畔圣克里斯托夫', 47.6172000, 0.4780100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51315, 'Saint-Christophe-du-Ligneron', 'Saint-Christophe-du-Ligneron', 'Christophe-pres-la-Boulogne,Christophe-près-la-Boulogne,Le Ligneron,Saint-Christophe,Saint-Christophe-du-Ligneron', 46.8247800, -1.7658600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51316, 'Saint-Christophe-du-Bois', 'Saint-Christophe-du-Bois', 'Saint-Christophe,Saint-Christophe-du-Bois,Sen-Kristof-dju-Bua,sheng ke li si tuo fu di bu wa,Сен-Кристоф-дю-Буа,سینٹ-کروسٹوفے-دو-بوس,圣克里斯托夫迪布瓦', 47.0301200, -0.9444100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51317, 'Saint-Christoly-de-Blaye', 'Saint-Christoly-de-Blaye', 'Saint-Christoly,Saint-Christoly-de-Blaye', 45.1317900, -0.5076000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51318, 'Saint-Christol-lès-Alès', 'Saint-Christol-les-Ales', 'Auxon,Saint-Christol,Saint-Christol-les-Ales,Saint-Christol-lez-Ales,Saint-Christol-lès-Alès,Saint-Christol-lèz-Alès,Sen-Kristol''-lez-Ales,Sent Cristou dAles,Sent Cristou dAlest,Sent Cristòu dAlès,Sent Cristòu dAlèst,sheng ke li si tuo lai a lai,Сен-Кристоль-лез-Алес,سینٹ-چرستول-لیس-الث,圣克里斯托莱阿莱', 44.0825600, 4.0750600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51319, 'Saint-Christol', 'Saint-Christol', 'Saint-Christol', 43.7280500, 4.0799100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51320, 'Saint-Christo-en-Jarez', 'Saint-Christo-en-Jarez', 'Saint-Christo,Saint-Christo-en-Jarez', 45.5431600, 4.4847400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51321, 'Saint-Chinian', 'Saint-Chinian', 'Saint-Chinian,Vernodure', 43.4223800, 2.9464300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51322, 'Saint-Chéron', 'Saint-Cheron', 'Saint-Cheron,Saint-Chéron', 48.5543300, 2.1240300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51323, 'Saint-Chef', 'Saint-Chef', 'Francvallon,Saint-Chef,Sen-Shef,sheng she,Сен-Шеф,سینٹ-چیف,圣舍', 45.6338500, 5.3651800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51324, 'Saint-Chaptes', 'Saint-Chaptes', 'Beauregard,Saint-Chaptes', 43.9717200, 4.2781200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51325, 'Saint-Chamond', 'Saint-Chamond', 'Mont-Rousseau,Saint Chamond,Saint-Chamond,Sen-Shamon,Sensamona,Senšamona,Val-Rousseau,Vallee-Roussean,Vallée-Roussean,san=shamon,sheng shang weng,sn shmwn,sn-shamwn,Сен-Шамон,سن شمون,سن-شامون,サン＝シャモン,圣尚翁', 45.4736500, 4.5254100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51326, 'Saint-Chamas', 'Saint-Chamas', 'Port-Chamas,Saint-Chamas,St Chamas', 43.5494600, 5.0332400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51327, 'Saint-Chaffrey', 'Saint-Chaffrey', 'Chaffre,Chaffré,Saint-Chaffrey', 44.9255500, 6.6076800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51328, 'Saint-Cézaire-sur-Siagne', 'Saint-Cezaire-sur-Siagne', 'Saint-Cesaire-sur-Siagne,Saint-Cezaire,Saint-Cezaire-sur-Siagne,Saint-Césaire-sur-Siagne,Saint-Cézaire,Saint-Cézaire-sur-Siagne,Sant Cesari de Sianha,Sen-Sezer-sjur-S''jan'',san syzar swr syajn,xi ya ni he pan sheng sai ze er,Сен-Сезер-сюр-Сьянь,سان سيزار سور سياجن,سینٹ-کزئیرے-سر-سیاگنے,西亚尼河畔圣塞泽尔', 43.6488400, 6.7938400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51329, 'Saint-Cernin', 'Saint-Cernin', 'Saint-Cernin,Saint-Cernin-du-Cantal', 45.0573000, 2.4223200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51330, 'Saint-Cergues', 'Saint-Cergues', 'Saint-Cergues,Sen-Serg,Сен-Серг,سینٹ-کرگیس', 46.2334900, 6.3195400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51331, 'Saint-Céré', 'Saint-Cere', 'Franc-Cere,Franc-Céré,Saint-Cere,Saint-Céré,Sant Seren,Sen-Sere,Seu-Cere,Seu-Céré,sheng sai lei,Сен-Сере,سینٹ-کرے,圣塞雷', 44.8572600, 1.8941500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51332, 'Saint-Cast-le-Guildo', 'Saint-Cast-le-Guildo', 'Havre-Cast,Saint-Cast,Saint-Cast Bourg,Saint-Cast-le-Guildo,Sant-Kast-ar-Gwildou,Sant-Kast-ar-Gwildoù,Sen-Ka-le-Gil''do,Sen-Kast-le-Gil''do,sheng ka si lai ji er duo,Сен-Ка-ле-Гильдо,Сен-Каст-ле-Гильдо,Сен-Каст-ле-Гільдо,سینٹ-کاسٹ-لے-گیلڈو,圣卡斯莱吉尔多', 48.6302800, -2.2577700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51333, 'Saint-Cassien', 'Saint-Cassien', 'Saint Cassient,Saint-Cassien', 45.3597100, 5.5532100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51334, 'Saint-Carreuc', 'Saint-Carreuc', 'Saint-Carreuc,Sant-Kareg', 48.3988900, -2.7305600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51335, 'Saint-Caradec', 'Saint-Caradec', 'Caradec-sur-Oust,Saint-Caradec,Sant-Karadeg', 48.1942900, -2.8438600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51336, 'Saint-Caprais-de-Bordeaux', 'Saint-Caprais-de-Bordeaux', 'Saint-Caprais,Saint-Caprais-de-Bordeaux,Sen-Kapre-de-Bordo,Sent Caprasi,Sent Caprasi de Bordeu,Sent Caprasi de Bordèu,sheng ka pu lai de bo er duo,Сен-Капре-де-Бордо,سینٹ-کاپریس-دے-بورڈو,圣卡普赖德博尔多', 44.7478600, -0.4319200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51337, 'Saint-Cannat', 'Saint-Cannat', 'Le Saizet,Le Sauzet,Saint-Cannat,Sant Canat,Sen-Kanna,sheng ka na,Сен-Канна,سینٹ-کنت,圣卡纳', 43.6208900, 5.2969000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51338, 'Saint-Calais', 'Saint-Calais', 'Calais-sur-Anille,Saint-Calais,Sen-Kale,Сен-Кале,سینٹ-کلاس', 47.9221100, 0.7458700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51339, 'Saint-Broladre', 'Saint-Broladre', 'Saint-Broladre,Sant-Brewalaer', 48.5867700, -1.6576900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51340, 'Saint-Brisson-sur-Loire', 'Saint-Brisson-sur-Loire', 'Saint-Brisson,Saint-Brisson-sur-Loire,Sen-Brisson-sjur-Luar,lu wa er he pan sheng bu li song,Сен-Бриссон-сюр-Луар,سینٹ-برسسوں -سر-لڑے,卢瓦尔河畔圣布里松', 47.6468600, 2.6822900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51341, 'Saint-Bris-le-Vineux', 'Saint-Bris-le-Vineux', 'Bris-le-Vineux,Saint-Bris,Saint-Bris-le-Vineux,Sen-Bri-le-Vine,san=buri=ru=vu~inu,sheng bu li lei wei na,Сен-Бри-ле-Вине,Сен-Брі-ле-Віне,سینٹ-برس-لے-نےش,サン＝ブリ＝ル＝ヴィヌー,圣布里勒维纳', 47.7439600, 3.6492200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51342, 'Saint-Brieuc', 'Saint-Brieuc', 'Fanum Sancti Brioci,Port-Brieuc,SBK,Sain-Briek,Saint-Brieu,Saint-Brieuc,Sant-Brieg,Sen Brijek,Sen-Brie,Sen-Brijo,Sent-Brie,saengbeulioe,san=buriyu,sant brywk,sen-brie,sheng bu li e,sn brywk,sn-bryw,Σαιν-Μπριέκ,Сен Бријек,Сен-Брие,Сен-Бриё,Сен-Бріє,Сент-Брие,סן-בריו,سانت بريوك,سن بریوک,سینٹ-بریک,სენ-ბრიე,サン＝ブリユー,圣布里厄,생브리외', 48.5151300, -2.7683800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51343, 'Saint-Brice-sur-Vienne', 'Saint-Brice-sur-Vienne', 'Saint-Brice,Saint-Brice-sur-Vienne', 45.8785200, 0.9559400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51344, 'Saint-Brice-sous-Forêt', 'Saint-Brice-sous-Foret', 'Saint-Brice,Saint-Brice-sous-Foret,Saint-Brice-sous-Forêt,Sen-Bris-su-Fore,sheng bu li si su fu lei,sn-bry-sws-pwrt,Сен-Брис-су-Форе,סן-ברי-סוס-פורט,سینٹ-برکے-سوس-فورٹ,圣布里斯苏福雷', 49.0013200, 2.3536100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51345, 'Saint-Brice-Courcelles', 'Saint-Brice-Courcelles', 'Liberte-sur-Vesle,Liberté-sur-Vesle,Montriqueux,Saint-Brice', 49.2666700, 3.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51346, 'Saint-Brice-en-Coglès', 'Saint-Brice-en-Cogles', 'Saint-Brice,Saint-Brice-en-Cogles,Saint-Brice-en-Coglès,Sanctus Bricius de Coglesio,Sant-Brizh-Gougleiz,Sen-Bris-an-Kogle,ke ge lai de qu sheng bu li ke,Сен-Брис-ан-Когле,سینٹ-برکے-این -کوگلیس,科格莱地区圣布里克', 48.4115700, -1.3701900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51347, 'Saint-Brice', 'Saint-Brice', 'Saint-Brice', 45.6833300, -0.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51348, 'Saint-Briac-sur-Mer', 'Saint-Briac-sur-Mer', 'Port-Briac,Saint-Briac,Saint-Briac-sur-Mer,Sanctus Briacus,Sant-Briag,Sen-Briak-sjur-Mer,bin hai sheng bu li a ke,Сен-Бриак-сюр-Мер,Сен-Бріак-сюр-Мер,سینٹ-براک-سر-مر,滨海圣布里阿克', 48.6218900, -2.1343500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51349, 'Saint-Brevin-les-Pins', 'Saint-Brevin-les-Pins', 'Saint-Brevin,Saint-Brévin,Sanctus Brevenus,Sant-Brewenn,Sen-Breven-le-Pen,Union,sheng bu lei wan lai pan,Сен-Бревен-ле-Пен,سینٹ-بروں -لیس-پنس,圣布勒万莱潘', 47.2500000, -2.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51350, 'Saint-Brès', 'Saint-Bres', 'Saint-Bres,Saint-Brès', 43.6674200, 4.0310500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51351, 'Saint-Brandan', 'Saint-Brandan', 'Saint-Brandan,Sant-Vedan', 48.3900800, -2.8687500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51352, 'Saint-Branchs', 'Saint-Branchs', 'Saint-Branchs,Sen-Bransh,sheng bu lang ke,Сен-Бранш,سینٹ-برانچس,圣布朗克', 47.2265500, 0.7730600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51353, 'Saint-Bon-Tarentaise', 'Saint-Bon-Tarentaise', 'Prairial,Saint-Bon,Sen-Bon-Tarantez,Sent-Bon-Tarentesa,Sent-Bon-Tarentèsa,Сен-Бон-Тарантез,سینٹ-بون-ٹھہریں تیسے', 45.4337300, 6.6368600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51354, 'Saint-Bonnet-près-Riom', 'Saint-Bonnet-pres-Riom', 'Saint-Bonnet,Saint-Bonnet-pres-Riom,Saint-Bonnet-près-Riom', 45.9289500, 3.1116200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51355, 'Saint-Bonnet-les-Oules', 'Saint-Bonnet-les-Oules', 'Saint-Bonnet,Saint-Bonnet-les-Oules', 45.5425000, 4.3314500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51356, 'Saint-Bonnet-le-Château', 'Saint-Bonnet-le-Chateau', 'Bonnet-la-Montagne,Saint Bonnet,Saint-Bonnet-le-Chateau,Saint-Bonnet-le-Château,Sant Bonet dau Chastel,Sant Bonet dau Chastèl,Sen-Bonne-le-Shato,sheng bo nei lai sha tuo,Сен-Бонне-ле-Шато,سینٹ-بونٹ-لے-چتو,圣博内莱沙托', 45.4233800, 4.0667300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51357, 'Saint-Bonnet-de-Mure', 'Saint-Bonnet-de-Mure', 'Saint Bonnet,Saint-Bonnet-de-Mure', 45.6995800, 5.0202600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51358, 'Saint-Bonnet-en-Champsaur', 'Saint-Bonnet-en-Champsaur', 'Bonnet-Libre,Sant Bonet,Sant Bonet de Champsaur,Sen-Bonne-an-Shamsor,Sen-Bonne-an-Shansor,shang pu suo de qu sheng bo nei,Сен-Бонне-ан-Шамсор,Сен-Бонне-ан-Шансор,سینٹ-بونٹ-این -چمپساور,尚普索地区圣博内', 44.6833300, 6.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51359, 'Saint-Berthevin', 'Saint-Berthevin', 'Saint-Berthevin-sur-Vicoin', 48.0666700, -0.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51360, 'Saint-Béron', 'Saint-Beron', 'Gorges-de-Chailles,Saint-Beron,Saint-Béron', 45.5014100, 5.7301200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51361, 'Saint-Berain-sous-Sanvignes', 'Saint-Berain-sous-Sanvignes', 'Saint-Berain,Saint-Berain-sous-Sanvignes,Saint-Bérain', 46.7067800, 4.2940500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51362, 'Saint-Benoît-sur-Loire', 'Saint-Benoit-sur-Loire', 'Fanum Sancti Benedicti ad Ligerim,Saint-Benoit-sur-Loire,Saint-Benoît-sur-Loire,Sen-Benua-sjur-Luar,lu wa er he pan sheng bang wa,Сен-Бенуа-сюр-Луар,سینٹ-بنوٹ-سر-لڑے,卢瓦尔河畔圣邦瓦', 47.8056100, 2.3127400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51363, 'Saint-Benoît-de-Carmaux', 'Saint-Benoit-de-Carmaux', 'La Montagne,Saint-Benoit,Saint-Benoit-de-Carmaux,Saint-Benoît-de-Carmaux,Sant Benesech de Carmauc,Sant Benesech de Carmauç,Sen-Benua-de-Karmo,sheng bang wa de ka er mo,Сен-Бенуа-де-Кармо,سینٹ-بنوٹ-دے-ڑمش,圣邦瓦德卡尔莫', 44.0503700, 2.1291100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51364, 'Saint-Benoît', 'Saint-Benoit', 'Quincay-les-Plaisirs,Quinçay-les-Plaisirs,Saint-Benoit,Saint-Benoît', 46.5531500, 0.3419000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51365, 'Saint-Bauzille-de-Putois', 'Saint-Bauzille-de-Putois', 'Bel-Herault,Bel-Hérault,Saint-Bauzille,Saint-Bauzille-de-Putois,Sen-Bozij-de-Pjutua,Sent Bauseli,Sent Bauseli de Pedoci,Sent Bausèli,Sent Bausèli de Pedoci,sheng bo qi er de pi tu wa,Сен-Бозий-де-Пютуа,Сен-Бозій-де-Пютуа,سینٹ-بہزلے-دے-پتوس,圣博齐尔德皮图瓦', 43.8945400, 3.7358000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51366, 'Saint-Baudelle', 'Saint-Baudelle', 'Saint-Baudelle,Saint-Beaudelle', 48.2808100, -0.6372800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51367, 'Saint-Barthélemy-de-Vals', 'Saint-Barthelemy-de-Vals', 'Saint-Barthelemy,Saint-Barthelemy-de-Vals,Saint-Barthélemy,Saint-Barthélemy-de-Vals,Sen-Bartelemi-de-Val'',sheng ba er tai lai mi de wa er,Сен-Бартелемі-де-Валь,سینٹ-برتھلمے-دے-ولس,圣巴尔泰莱米德瓦尔', 45.1672900, 4.8697700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51368, 'Saint-Barnabé', 'Saint-Barnabe', 'Saint-Barnabe,Saint-Barnabé,Sant-Barnev', 48.1371200, -2.7048300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51369, 'Saint-Baldoph', 'Saint-Baldoph', 'L''Albanne,Saint-Baldoph,Sen-Bal''dof,Сен-Бальдоф,سینٹ-بلدوف', 45.5312000, 5.9521700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51370, 'Saint-Ay', 'Saint-Ay', 'Ay-sur-Loire,Saint-Ay,Sent-I,sheng ai,Сент-І,Сент-И,سینٹ-ے,圣艾', 47.8589000, 1.7513700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51371, 'Saint-Avold', 'Saint-Avold', 'Rosselgene,Rosselgène,Saint-Avold,Sankt Avold,Sent-Avol''d,Trimonts,sheng a wo er de,Сент-Авольд,سینٹ-اوولڈ,聖阿沃爾德', 49.1027000, 6.7006400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51372, 'Saint-Avertin', 'Saint-Avertin', 'Saint-Avertin,Sent-Averten,Vancay,Vansay,Vançay,sheng a wei er tan,Сент-Авертен,سینٹ-عورتیں,圣阿韦尔坦', 47.3635700, 0.7399300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51373, 'Saint-Avé', 'Saint-Ave', 'Saint-Ave,Saint-Avé,Sant-Teve,Sent-Ave,sheng a wei,Сент-Аве,سینٹ-اوے,圣阿韦', 47.6908500, -2.7464800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51374, 'Saint-Aupre', 'Saint-Aupre', '', 45.3833300, 5.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51375, 'Saint-Aunès', 'Saint-Aunes', 'Saint-Aunes,Saint-Aunès,Sant Aunes,Sant Aunès,Sent-Ones,sheng ao nei,Сент-Онес,سینٹ-انس,圣奥内', 43.6408300, 3.9658300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51376, 'Saint-Aulaye', 'Saint-Aulaye', 'Saint-Aulaye,Sent-Ole,Sent-Olej,Senta Eulalia,Senta Eulalia de Pueimangor,Senta Eulàlia,Senta Eulàlia de Pueimangor,sheng ao lai ai,Сент-Оле,Сент-Олей,سینٹ-اولے,圣奥莱埃', 45.2000000, 0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51377, 'Saint-Augustin', 'Saint-Augustin', 'Mont-l''Unite,Mont-l''Unité,Saint-Augustin', 48.7833300, 3.0301600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51378, 'Saint-Aubin-sur-Scie', 'Saint-Aubin-sur-Scie', 'Saint Aubin,Saint-Aubin-sur-Scie', 49.8716200, 1.0682300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51379, 'Saint-Aubin-sur-Mer', 'Saint-Aubin-sur-Mer', 'Saint-Aubin,Saint-Aubin-sur-Mer', 49.3278700, -0.3869600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51380, 'Saint-Aubin-sur-Gaillon', 'Saint-Aubin-sur-Gaillon', 'La Montagne,Montagne-sur-Gaillon,Puits-Foret,Puits-Forêt,Saint-Aubin,Saint-Aubin-sur-Gaillon', 49.1470100, 1.3291400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51381, 'Saint-Aubin-Routot', 'Saint-Aubin-Routot', 'Saint-Aubin-Routot', 49.5234100, 0.3260200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51382, 'Saint-Aubin-lès-Elbeuf', 'Saint-Aubin-les-Elbeuf', 'Saint-Aubin,Saint-Aubin-les-Elbeuf,Saint-Aubin-lès-Elbeuf', 49.3036000, 1.0105600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51383, 'Saint-Aubin-le-Cloud', 'Saint-Aubin-le-Cloud', 'Saint-Aubin,Saint-Aubin-le-Cloud', 46.6530800, -0.3525800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51384, 'Saint-Aubin-en-Bray', 'Saint-Aubin-en-Bray', 'Saint-Aubin-en-Bray,Sent-Oben-an-Bre,bu lai de qu sheng ao ban,Сент-Обен-ан-Бре,سینٹ-آبن-این -برے,布赖地区圣奥班', 49.4205100, 1.8778200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51385, 'Saint-Aubin-du-Cormier', 'Saint-Aubin-du-Cormier', 'Fanum Sancti Albini,Montagne-la-Foret,Montagne-la-Forêt,Saint-Aubin,Saint-Aubin-du-Cormier,Sant-Albin-an-Hiliber,Sent-Oben-dju-Korm''e,Sent-Oben-dju-Korme,sheng ao ban di ke er mi ye,Сент-Обен-дю-Кормье,Сент-Обен-дю-Кормє,سینٹ-آبن-دو-کورمئر,圣奥班迪科尔米耶', 48.2584300, -1.4025200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51386, 'Saint-Aubin-des-Ormeaux', 'Saint-Aubin-des-Ormeaux', 'Aubin-la-Pierre,Saint-Aubin,Saint-Aubin-des-Ormeaux', 46.9923800, -1.0427400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51387, 'Saint-Aubin-des-Châteaux', 'Saint-Aubin-des-Chateaux', 'Saint-Aubin,Saint-Aubin-des-Chateaux,Saint-Aubin-des-Châteaux,Sanctus Albinus de Castris,Sant-Albin-ar-C''hestell,Sant-Albin-ar-Chestell,Sent-Oben-de-Shato,sheng ao ban dai sha tuo,Сент-Обен-де-Шато,سینٹ-آبن-دس-ہتےش,圣奥班代沙托', 47.7204700, -1.4887600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51388, 'Saint-Aubin-des-Bois', 'Saint-Aubin-des-Bois', 'Saint-Aubin,Saint-Aubin-des-Bois', 48.4654900, 1.3578400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51389, 'Saint-Aubin-de-Médoc', 'Saint-Aubin-de-Medoc', 'Saint-Aubin,Saint-Aubin-de-Medoc,Saint-Aubin-de-Médoc', 44.9118000, -0.7246000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51390, 'Saint-Aubin', 'Saint-Aubin', 'Saint-Aubin', 47.0333600, 5.3266600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51391, 'Saint-Aubert', 'Saint-Aubert', 'Libreval,Saint-Aubert', 50.2080500, 3.4172700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51392, 'Saint-Astier', 'Saint-Astier', 'Astier-sur-l''Isle,Saint-Astier', 45.1458200, 0.5289800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51393, 'Saint-Arnoult-en-Yvelines', 'Saint-Arnoult-en-Yvelines', 'La Mejeanne,Montagne-sur-Remarde,Saint-Arnoult,Saint-Arnoult-en-Yvelines,Sent-Arnu-an-Ivelin,Sent-Arnu-an-Ivlin,Сент-Арну-ан-Івлін,Сент-Арну-ан-Ивелин,سینٹ-ارنولٹ-این -یولنس', 48.5711100, 1.9395000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51394, 'Saint-Arnoult', 'Saint-Arnoult', 'Saint-Arnoult', 49.5267600, 0.6711700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51395, 'Saint-Armel', 'Saint-Armel', 'Saint-Armel,Sant-Armael', 48.0130500, -1.5915200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51396, 'Saint-Apollinaire', 'Saint-Apollinaire', 'Saint-Apollinaire,Sent-Apolliner,Сент-Аполлинер', 47.3333300, 5.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51397, 'Saint-Antoine-du-Rocher', 'Saint-Antoine-du-Rocher', 'Le Rocher,Saint-Antoine,Saint-Antoine-du-Rocher', 47.4967700, 0.6299700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51398, 'Saint-Antoine-de-Breuilh', 'Saint-Antoine-de-Breuilh', 'Saint-Antoine,Saint-Antoine-de-Breuilh', 44.8333300, 0.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51399, 'Saint-Antoine-l''Abbaye', 'Saint-Antoine-l''Abbaye', 'Saint-Antoine-l''Abbaye,Saint-Antoine-lAbbaye,Saint-Antoine-l’Abbaye,Sent-Antuan-l''Abbei,Сент-Антуан-л’Аббеи', 45.1666700, 5.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51400, 'Saint-André-Treize-Voies', 'Saint-Andre-Treize-Voies', 'Saint-Andre,Saint-Andre-Treize-Voies,Saint-André,Saint-André-Treize-Voies,Treize-Voies', 46.9336900, -1.4127400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51401, 'Saint-André-sur-Vieux-Jonc', 'Saint-Andre-sur-Vieux-Jonc', 'Saint-Andre,Saint-Andre-sur-Vieux-Jonc,Saint-André,Saint-André-sur-Vieux-Jonc', 46.1500000, 5.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51402, 'Saint-André-sur-Orne', 'Saint-Andre-sur-Orne', 'Saint-Andre,Saint-Andre-sur-Orne,Saint-André,Saint-André-sur-Orne,Sent-Andre-sjur-Orn,ao er en he pan sheng ang de lei,Сент-Андре-сюр-Орн,سینٹ-آندرے-سر-اڑنے,奥尔恩河畔圣昂德雷', 49.1174100, -0.3822700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51403, 'Saint-André-les-Vergers', 'Saint-Andre-les-Vergers', 'Saint-Andre,Saint-Andre-les-Vergers,Saint-André,Saint-André-les-Vergers', 48.2852700, 4.0521000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51404, 'Saint-André-le-Puy', 'Saint-Andre-le-Puy', 'Saint-Andre-le-Puy,Saint-André-le-Puy', 45.6445800, 4.2574400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51405, 'Saint-André-le-Gaz', 'Saint-Andre-le-Gaz', 'Saint-Andre,Saint-Andre-le-Gaz,Saint-André,Saint-André-le-Gaz', 45.5494300, 5.5350300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51406, 'Saint-André-de-Seignanx', 'Saint-Andre-de-Seignanx', 'Saint Andre,Saint André', 43.5580000, -1.3518300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51407, 'Saint-André-des-Eaux', 'Saint-Andre-des-Eaux', 'Saint-Andre,Saint-Andre-des-Eaux,Saint-André,Saint-André-des-Eaux,Sant-Andrev-an-Dour', 47.3146100, -2.3110500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51408, 'Saint-André-de-Sangonis', 'Saint-Andre-de-Sangonis', 'Beaulieu,La Source,Saint-Andre,Saint-Andre-de-Sangonis,Saint-Andre-de-Sangoui,Saint-André,Saint-André-de-Sangonis,Saint-André-de-Sangoui', 43.6475300, 3.5020900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51409, 'Saint-André-de-la-Marche', 'Saint-Andre-de-la-Marche', 'Saint-Andre,Saint-Andre-de-la-Marche,Saint-André,Saint-André-de-la-Marche,Sent-Andre-de-la-Marsh,sheng ang de lei de la-ma er ke,Сент-Андре-де-ла-Марш,سینٹ-آندرے-دے-لا-مارچے,圣昂德雷德拉-马尔克', 47.0995200, -0.9944100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51410, 'Saint-André-de-Corcy', 'Saint-Andre-de-Corcy', 'Saint-Andre,Saint-Andre-de-Corcy,Saint-André,Saint-André-de-Corcy', 45.9259000, 4.9516600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51411, 'Saint-André-lez-Lille', 'Saint-Andre-lez-Lille', 'Sent-Andre-le-Lill'',sheng an de lie lai li er,Сент-Андре-ле-Лилль,Сент-Андре-ле-Лілль,سینٹ-آندرے-لیز-للے,圣安德烈莱里尔', 50.6666700, 3.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51412, 'Saint-André-de-la-Roche', 'Saint-Andre-de-la-Roche', '', 43.7333300, 7.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51413, 'Sant Andreu de Sureda', 'Sant Andreu de Sureda', 'Saint-Andre,Saint-André,Sant Andreu,Sant Andreu de Sureda', 42.5520100, 2.9712900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51414, 'Saint-Andiol', 'Saint-Andiol', 'Saint-Andiol,Sant Andiou,Sant Andiòu,Sent-And''jol'',Sent-And''ol'',sheng ang di ao,Сент-Андьйоль,Сент-Андьоль,سینٹ-اندول,圣昂迪奥', 43.8348400, 4.9445300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51415, 'Saint-Andéol-le-Château', 'Saint-Andeol-le-Chateau', 'Andeol-Libre,Andéol-Libre,Saint Andeol,Saint Andéol,Saint-Andeol-le-Chateau,Saint-Andéol-le-Château,Sent-Andeol''-le-Shato,Sent-Anduer,Sent-Anduér,Сент-Андеоль-ле-Шато,سینٹ-اندول-لے-چتو', 45.5870300, 4.6949500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51416, 'Saint-Amour', 'Saint-Amour', 'Franc-Amour,Saint-Amour', 46.4363800, 5.3441600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51417, 'Saint-Amé', 'Saint-Ame', 'Nol-sur-Moselle,Saint-Ame,Saint-Amé,Sent-Ame,sheng a mo,Сент-Аме,سینٹ-امی,圣阿默', 48.0238800, 6.6641600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51418, 'Saint-Ambroix', 'Saint-Ambroix', 'Pont-Ceze,Pont-Cèze,Saint-Ambroix', 44.2589300, 4.1983300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51419, 'Saint-Amarin', 'Saint-Amarin', 'Saint-Amarin,Sankt Amarin,Sent-Amaren,Сент-Амарен,سینٹ-عمریں', 47.8733500, 7.0319300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51420, 'Saint-Amant-Tallende', 'Saint-Amant-Tallende', 'Saint-Amand-Tallende,Saint-Amande-Tallende,Saint-Amant,Saint-Amant-Tallende', 45.6683900, 3.1101000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51421, 'Saint-Amant-de-Boixe', 'Saint-Amant-de-Boixe', 'Saint-Amant,Saint-Amant-de-Boixe,Sent-Aman-de-Buaks,sheng a mang de bu wa ke si,Сент-Аман-де-Буакс,سینٹ-امانت-دے-وشے,圣阿芒德布瓦克斯', 45.7979000, 0.1352400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51422, 'Saint-Amans-Valtoret', 'Saint-Amans-Valtoret', 'Saint-Amans,Saint-Amans-Valtoret', 43.4807100, 2.4909500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51423, 'Saint-Amans-Soult', 'Saint-Amans-Soult', 'La Bastida de Sant Amanc,La Bastida de Sant Amanç,Saint-Amans-Soult,Sant Amanc de Solt,Sant Amanç de Solt,Sent-Aman-Su,sheng a mang su er,Сент-Аман-Су,سینٹ-امانس-صولت,圣阿芒苏尔', 43.4769700, 2.4907600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51424, 'Saint-Amand-sur-Sèvre', 'Saint-Amand-sur-Sevre', 'Saint-Amand,Saint-Amand-sur-Sevre,Saint-Amand-sur-Sèvre', 46.8690500, -0.7944100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51425, 'Saint-Amand-Montrond', 'Saint-Amand-Montrond', 'Libreval,Mons Rotundus,Saint Amand,Saint Amano,Sant Amand Montrond,Sent-Aman-Monron,Sent-Aman-Montron,san=taman=monron,sheng a mang meng te long,Сент-Аман-Монрон,Сент-Аман-Монтрон,سینٹ-امنڈ-مونٹروند,サン＝タマン＝モンロン,圣阿芒蒙特龙', 46.7166700, 2.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51426, 'Saint-Amand-les-Eaux', 'Saint-Amand-les-Eaux', 'Elnon-Libre,Saint-Amand,Saint-Amand-les-Eaux,Sent-Aman-lez-O,sheng a mang lai suo,Сент-Аман-лез-О,سینٹ-امنڈ-لیس-وا,圣阿芒莱索', 50.4471800, 3.4307600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51427, 'Saint-Amand-en-Puisaye', 'Saint-Amand-en-Puisaye', 'Saint-Amand-en Puysaye,Saint-Amand-en-Puisaye', 47.5291300, 3.0740000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51428, 'Saint-Amand-Longpré', 'Saint-Amand-Longpre', 'Saint-Amand,Saint-Amand-de-Vendome,Saint-Amand-de-Vendôme,Sent-Aman-Lonpre,sheng a mang long ge pu lei,Сент-Аман-Лонпре,سینٹ-امنڈ-لونگپرے,圣阿芒隆格普雷', 47.6833300, 1.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51429, 'Saint-Amand', 'Saint-Amand', 'Saint-Amand', 49.0433800, -0.9649100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51430, 'Saint-Alexandre', 'Saint-Alexandre', 'Roquebrune,Saint-Alexandre', 44.2274100, 4.6208100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51431, 'Saint-Alban-sur-Limagnole', 'Saint-Alban-sur-Limagnole', 'Saint-Alban,Saint-Alban-sur-Limagnole', 44.7810000, 3.3879300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51432, 'Saint-Alban-de-Roche', 'Saint-Alban-de-Roche', 'Mont-Alban,Saint-Alban,Saint-Alban-de-Roche', 45.5952600, 5.2230400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51433, 'Saint-Alban', 'Saint-Alban', 'Saint-Alban,Sant-Alvan', 48.5563000, -2.5401300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51434, 'Saint-Alban-Leysse', 'Saint-Alban-Leysse', 'Saint-Alban-Leysse,Sent-Al''ban-Lejss,Sent-Al''ban-Les,Сент-Альбан-Лейсс,Сент-Альбан-Лес,سینٹ-البن-لیسسے', 45.5833300, 5.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51435, 'Saint-Alban', 'Saint-Alban', 'Saint-Alban', 43.6927000, 1.4102000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51436, 'Saint-Aigulin', 'Saint-Aigulin', 'Ami-des-Lois,Le Grand-Aigulin,Le Petit-Aigulin,Sent-Egjulen,Sent-Ehgjulen,sheng ai ju lan,Сент-Егюлен,Сент-Эгюлен,سینٹ-ایگلین,圣艾居兰', 45.1573500, -0.0086300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51437, 'Saint-Aignan', 'Saint-Aignan', 'Carismont,Saint-Aignan,Saint-Aignan-sur-Cher', 47.2689200, 1.3761400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51438, 'Saint-Agrève', 'Saint-Agreve', 'Mont-Chiniac,Saint-Agreve,Saint-Agrève,Sant Agreve,Sant Agrève,Sent-Agrev,sheng a ge lei fu,Сент-Агрев,سینٹ-اگریوے,圣阿格雷夫', 45.0099300, 4.3937500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51439, 'Saint-Agnant-de-Versillat', 'Saint-Agnant-de-Versillat', 'Saint-Agnant,Saint-Agnant-de-Versillat,Versillat-le-Marat', 46.2780000, 1.5096200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51440, 'Saint-Agnant', 'Saint-Agnant', 'Mont-Agnan,Saint-Agnant', 45.8735400, -0.9611900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51441, 'Saint-Agathon', 'Saint-Agathon', 'Bonvalon,Fanum Sancti Negantoni,Saint-Agathon,Sant-Eganton,Sent-Agaton,sheng a jia tong,Сент-Агатон,سینٹ-اگاتھوں,圣阿加通', 48.5586700, -3.1052500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51442, 'Saint-Affrique', 'Saint-Affrique', 'La Montagne-sur-Sorgue,Sant Africa,Sent-Affrik,Sent-Afrik,sheng a fu li qu ai,Сент-Африк,Сент-Аффрик,སེན་ཏེ་ཨ་ཧྥེ་རི་ཁེ།,圣阿夫里屈埃', 43.9557500, 2.8891500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51443, 'Sains-en-Gohelle', 'Sains-en-Gohelle', 'Sains,Sains-en-Gohelle,Sains-in-Gohelle,Sen-an-Goehl'',Sen-an-Goel'',sang ang ge ai lei,synz an jwhyl,Сен-ан-Гоель,Сен-ан-Гоэль,سائنس-این -گوھلے,سينز إن جوهيل,桑昂戈埃勒', 50.4451200, 2.6830100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51444, 'Sains-en-Amiénois', 'Sains-en-Amienois', 'Sains,Sains-en-Amienois,Sains-en-Amiénois,Sains-in-Anmienoe,Sains-in-Anmiénoé,Sen-an-Amenua,sang ang na mi ye nu wa,sayns-ayn -amynws,Сен-ан-Амєнуа,سائنس-این -امینوس,桑昂纳米耶努瓦', 49.8171600, 2.3186200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51445, 'Sains-du-Nord', 'Sains-du-Nord', 'Sains,Sains-du-Nord,Sen-dju-Nor,sang di nuo er,sayns-dw-nwrd,Сен-дю-Нор,سائنس-دو-نورد,桑迪诺尔', 50.0937700, 4.0089800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51446, 'Sainghin-en-Weppes', 'Sainghin-en-Weppes', 'Sainghin,Sainghin-en-Weppes', 50.5640700, 2.8980400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51447, 'Sainghin-en-Mélantois', 'Sainghin-en-Melantois', 'Sainghin,Sainghin-en-Melantois,Sainghin-en-Mélantois', 50.5883600, 3.1661900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51448, 'Sain-Bel', 'Sain-Bel', 'Bel-les-Mines,Sain-Bel', 45.8107000, 4.5981500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51449, 'Sail-sous-Couzan', 'Sail-sous-Couzan', 'Sail,Sail-sous-Couzan,Saj-su-Kuzan,sai su ku cang,syl-sws-kwzn,Сай-су-Кузан,سیل-سوس-کوزن,赛苏库藏', 45.7348200, 3.9689800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51450, 'Sailly-sur-la-Lys', 'Sailly-sur-la-Lys', 'Sai-sjur-la-Li,Sai-sjur-la-Lis,Sailly,Sailly an de Leie,Sailly-sur-la-Lys,Saji-sjur-la-Lis,li si he pan sa yi,saly swr la lyz,Саи-сюр-ла-Ли,Сайи-сюр-ла-Лис,Саї-сюр-ла-Ліс,سالي سور لا ليز,سیلے-سر-لا-لیس,利斯河畔萨伊', 50.6582000, 2.7687200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51451, 'Sailly-lez-Lannoy', 'Sailly-lez-Lannoy', 'Sai-le-Lannua,Sailly,sa yi lai la nu wa,Саи-ле-Ланнуа,Саї-ле-Ланнуа,سیلے-لیز-لنوے,萨伊莱拉努瓦', 50.6500000, 3.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51452, 'Sailly-Labourse', 'Sailly-Labourse', 'Sai-Laburs,Sailly,Sailly-Labourse,sa yi la bu er si,saly labwrs,Саи-Лабурс,Саї-Лабурс,سالي لابورس,سیلے-لبورسے,萨伊拉布尔斯', 50.5012000, 2.6970800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51453, 'Sailly-Flibeaucourt', 'Sailly-Flibeaucourt', 'Sailly,Sailly-Flibeaucourt,Sally', 50.1841900, 1.7718000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51454, 'Saignon', 'Saignon', 'Saignon,Sanhon,Sen''on,sai ni weng,Сеньон,سیگنوں,赛尼翁', 43.8618200, 5.4278200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51455, 'Sahurs', 'Sahurs', 'Sahurs,Sajur,Саюр,سہرس', 49.3586300, 0.9425600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51456, 'Sagy', 'Sagy', 'Sagy', 49.0498800, 1.9521600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51457, 'Sagy', 'Sagy', 'Sagy', 46.6012900, 5.3104500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51458, 'Saffré', 'Saffre', 'Saffre,Saffré,Safriacum,Saverieg,sa fu lei,Саффре,سففرے,萨夫雷', 47.5014300, -1.5785600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51459, 'Sadirac', 'Sadirac', 'Sadirac,Sadirak,sa di la ke,sdrk,Садирак,Садірак,صدرک,萨迪拉克', 44.7817900, -0.4133400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51460, 'Sacy-le-Grand', 'Sacy-le-Grand', 'Sacy,Sacy-le-Grand,Sasi-le-Gran,da sa xi,Сасі-ле-Гран,سکے-لے-گرینڈ,大萨西', 49.3547900, 2.5446100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51461, 'Saclay', 'Saclay', 'Saclay,Sakle,sa ke lei,sakure,Сакле,サクレー,萨克雷', 48.7326000, 2.1692300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51462, 'Saclas', 'Saclas', 'Saclas,Sakla,sa ke la,sklas,Сакла,سکلاس,萨克拉', 48.3584500, 2.1234900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51463, 'Saché', 'Sache', 'Sache,Saché', 47.2470700, 0.5445500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51464, 'Sabres', 'Sabres', '', 44.1489600, -0.7412300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51465, 'Sabran', 'Sabran', 'Sabran', 44.1504000, 4.5482000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51466, 'Sablons', 'Sablons', 'Sablons', 45.3207300, 4.7750100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51467, 'Sablons', 'Sablons', 'Sablons', 45.0333300, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51468, 'Sablonceaux', 'Sablonceaux', 'Sablonceaux,Sablonso,sa bu long suo,Саблонсо,سبلونچےش,萨布隆索', 45.7096300, -0.8880600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51469, 'Sablet', 'Sablet', 'Sable,Sablet,Sablet-pres-l''Ouveze,Sablet-près-l’Ouvèze,sa bu lai,sblt,Сабле,سبلت,萨布莱', 44.1905600, 5.0061300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51470, 'Sablé-sur-Sarthe', 'Sable-sur-Sarthe', 'Sable,Sable sobre Sarthe,Sable-sjur-Sart,Sablé,Sabolium super Sartham,sa er te he pan sa bu lai,sabure=shuru=saruto,Сабле-сюр-Сарт,سابلے-سور-سارتھے,サブレ＝シュル＝サルト,薩爾特河畔薩布萊', 47.8376500, -0.3329400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51471, 'Saâcy-sur-Marne', 'Saacy-sur-Marne', 'Saacy,Saacy-sur-Marne,Saâcy-sur-Marne', 48.9621000, 3.2108300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51472, 'Ruy', 'Ruy', 'Ruy', 45.5877200, 5.3189000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51473, 'Russange', 'Russange', 'Russange', 49.4830800, 5.9523900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51474, 'Russ', 'Russ', 'Russ', 48.4949500, 7.2605300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51475, 'Rurange-lès-Thionville', 'Rurange-les-Thionville', 'Rorchingen,Rupange-lez Thionville,Rurange,Rurange-les-Thionville,Rurange-lès-Thionville', 49.2771100, 6.2313900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51476, 'Rupt-sur-Moselle', 'Rupt-sur-Moselle', 'Rju-sjur-Mozel'',Rupt,Rupt-sur-Moselle,mo ze er he pan lu pu,Рю-сюр-Мозель,摩泽尔河畔吕普', 47.9227100, 6.6629100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51477, 'Ruoms', 'Ruoms', 'Ruoms', 44.4535100, 4.3426500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51478, 'Rungis', 'Rungis', 'Marche de Rungis,Renzhi,Renzhis,Rungis,lan ji,ranjisu,Ренжи,Ренжис,ランジス,兰吉', 48.7460700, 2.3527500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51479, 'Ruminghem', 'Ruminghem', 'Rjumengem,Ruminghem,Ruminghin,lu man gai mu,rwmynghm,rwmynhym,Рюменгем,رومنگھم,رومينهيم,رومینگهم,吕曼盖姆', 50.8592200, 2.1583800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51480, 'Rumilly-en-Cambrésis', 'Rumilly-en-Cambresis', 'Rjumii-an-Kambrezi,Rumilly,Rumilly-en-Cambresis,Rumilly-en-Cambrésis,lu mi yi ang kang bu lei xi,Рюмии-ан-Камбрези,Рюмії-ан-Камбрезі,吕米伊昂康布雷西', 50.1269100, 3.2187400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51481, 'Rumilly', 'Rumilly', 'Rumilly,Rumilly-Albanais', 45.8687300, 5.9365200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51482, 'Rumersheim-le-Haut', 'Rumersheim-le-Haut', 'Rumersheim,Rumersheim-le-Haut', 47.8512700, 7.5213300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51483, 'Rumegies', 'Rumegies', 'Rumegies', 50.4887700, 3.3513100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51484, 'Rully', 'Rully', 'Rully', 46.8749900, 4.7432200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51485, 'Ruitz', 'Ruitz', 'Ruitz', 50.4664300, 2.5887600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51486, 'Ruillé-sur-Loir', 'Ruille-sur-Loir', 'Ruille,Ruille-sur-Loir,Ruille-sur-le-Loir,Ruillé,Ruillé-sur-Loir,Ruillé-sur-le-Loir', 47.7507500, 0.6205800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51487, 'Rugles', 'Rugles', 'Rjugl'',Rugles,lu ge lai,Рюгль,吕格莱', 48.8221200, 0.7097900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51488, 'Ruffiac', 'Ruffiac', 'Ruffiac,Rufieg', 47.8186600, -2.2823800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51489, 'Ruffey-lès-Echirey', 'Ruffey-les-Echirey', 'Ruffey', 47.3666700, 5.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51490, 'Ruffec', 'Ruffec', 'Ruffec', 46.0287700, 0.1982100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51491, 'Ruelle-sur-Touvre', 'Ruelle-sur-Touvre', 'Rjuehl''-sjur-Tuvr,Rjuel''-sjur-Tuvr,Ruelle,Ruelle-sur-Touvre,tu fu er he pan lu ai er,Рюель-сюр-Тувр,Рюэль-сюр-Тувр,图夫尔河畔吕埃尔', 45.6833300, 0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51492, 'Ruelisheim', 'Ruelisheim', 'Ruelisheim', 47.8230600, 7.3594000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51493, 'Rueil-Malmaison', 'Rueil-Malmaison', 'Rijej Malmezon,Rjuehj-Mal''mezon,Rjuej Malmezon,Rjuej-Mal''mezon,Rodolium,Rueil,Rueil-Malmaison,lu ai ma er mei song,lwieyumalmejong,rwy mlmzwn,rwy-malmyzwn,ryueiyu=marumezon,Ријеј Малмезон,Рюей Малмезон,Рюей-Мальмезон,Рюэй-Мальмезон,روي-مالميزون,روی ملمزون,リュエイユ＝マルメゾン,吕埃马尔梅松,뤼에유말메종', 48.8765000, 2.1896700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51494, 'Rue', 'Rue', 'Rue', 50.2715000, 1.6716300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51495, 'Rubelles', 'Rubelles', 'Rubelles', 48.5532700, 2.6759300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51496, 'Ruaudin', 'Ruaudin', 'Ruaudin', 47.9450900, 0.2676000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51497, 'Roz-sur-Couesnon', 'Roz-sur-Couesnon', 'Roz,Roz-an-Arvor,Roz-sur-Couesnon', 48.5886700, -1.5921300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51498, 'Rozoy-sur-Serre', 'Rozoy-sur-Serre', 'Rozoy,Rozoy-sur-Serre,Rozua-sjur-Ser,Rozua-sjur-Serr,sai er he pan luo zu wa,Розуа-сюр-Сер,Розуа-сюр-Серр,塞尔河畔罗祖瓦', 49.7095600, 4.1290200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51499, 'Roz-Landrieux', 'Roz-Landrieux', 'Roz-Landrieux,Roz-Lanrieg', 48.5433700, -1.8158600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51500, 'Rozier-en-Donzy', 'Rozier-en-Donzy', 'Roz''er-an-Donzi,Rozier,Rozier-en-Donzy,dong qi de qu luo qi ye,Розьєр-ан-Донзі,东齐地区罗齐耶', 45.7965000, 4.2734400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51501, 'Rozérieulles', 'Rozerieulles', 'Rozer''el'',Rozer''jol'',Rozerel'',Rozerieulles,Rozérieulles,luo ze li ye yu lai,Розерьель,Розерьёль,Розерєль,罗泽里耶于莱', 49.1068000, 6.0823800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51502, 'Rozay-en-Brie', 'Rozay-en-Brie', 'Rozay-en-Brie,Roze-an-Bri,Rozoy,Rozoy-l''Unite,Rozoy-l''Unité,Розе-ан-Бри,Розе-ан-Брі', 48.6833300, 2.9581600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51503, 'Roye', 'Roye', 'Roye', 49.7003800, 2.7895900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51504, 'Roye', 'Roye', 'Roye', 47.6699500, 6.5413900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51505, 'Roybon', 'Roybon', 'Roybon,Ruabon,lu wa bang,Руабон,鲁瓦邦', 45.2596600, 5.2445500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51506, 'Royat', 'Royat', 'Roiac,Roiat,Royat,Ruaja,Ruajja,lu wa a,rowaiya,Руайя,Руая,ロワイヤ,鲁瓦阿', 45.7637900, 3.0495500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51507, 'Royan', 'Royan', 'Gorad Ruajjan,RYN,Roajan,Roian,Roiannum,Rouagian,Royan,Ruajan,Ruajana,Ruajanas,Ruajāna,Ruayan,lu wa yang,luayang,rowaiyan,rwyan,Ρουαγιάν,Горад Руайян,Роаян,Роајан,Руайан,Руаян,رویان,ロワイヤン,鲁瓦扬,루아양', 45.6284600, -1.0281000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51508, 'Rouziers-de-Touraine', 'Rouziers-de-Touraine', 'Rouziers,Rouziers-de-Touraine', 47.5172000, 0.6484800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51509, 'Rouxmesnil-Bouteilles', 'Rouxmesnil-Bouteilles', 'Rouxmesnil,Rouxmesnil-Bouteilles', 49.9063300, 1.0797600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51510, 'Rouvroy', 'Rouvroy', 'Rouvroy', 50.3924700, 2.9039600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51511, 'Rousson', 'Rousson', 'Rousson', 44.1913600, 4.1478600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51512, 'Roussillon', 'Roussillon', 'Roussillon', 45.3730200, 4.8072500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51513, 'Roussillon', 'Roussillon', 'Catalogna Nord,Comtat del Rossello,Comtat del Rosselló,Comte de Roussillon,Comté de Roussillon,Rosellon,Rosellón,Roselyo,Rossiglione,Rossilhao,Rossilhão,Roussillon,Rusijon,Russil''jon,Russil''on,lu xi yong,rushiyon,rwsywn,Русийон,Руссильон,Руссільйон,Ռոսելյո,روسيون,ルシヨン,鲁西永', 43.9008400, 5.2947000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51514, 'Rousset', 'Rousset', 'Rousset', 43.4830700, 5.6195900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51515, 'Roussay', 'Roussay', 'Roussay', 47.0901100, -1.0641700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51516, 'Rousies', 'Rousies', 'Rousies,Ruzi,lu xi,Рузи,Рузі,鲁西', 50.2734600, 4.0038200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51517, 'Roumare', 'Roumare', 'Roumare', 49.5100800, 0.9742200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51518, 'Roullet-Saint-Estèphe', 'Roullet-Saint-Estephe', 'Rulle-Sent-Ehstef,Rulle-Sent-Estef,lu lai sheng ai si tai fu,Рулле-Сент-Естеф,Рулле-Сент-Эстеф,鲁莱圣埃斯泰夫', 45.5833300, 0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51519, 'Roulans', 'Roulans', 'Roulans,Roulans-le-Grand', 47.3155300, 6.2290100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51520, 'Roujan', 'Roujan', 'Roujan', 43.5048900, 3.3107100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51521, 'Rouillon', 'Rouillon', '', 48.0062900, 0.1352700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51522, 'Rouillé', 'Rouille', 'Rouille,Rouillé,Ruil''e,lu yi lei,Руїльє,鲁伊勒', 46.4202400, 0.0407300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51523, 'Rouillac', 'Rouillac', 'Rouillac', 45.7758200, -0.0638000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51524, 'Rouhling', 'Rouhling', 'Rouhling,Ruhling,rouhling', 49.1345000, 6.9942900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51525, 'Rougiers', 'Rougiers', 'Rougiers', 43.3923300, 5.8514400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51526, 'Rougemont-le-Château', 'Rougemont-le-Chateau', 'Rougemont,Rougemont-le-Chateau,Rougemont-le-Château', 47.7338900, 6.9689900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51527, 'Rougemont', 'Rougemont', 'Rougemont', 47.4821100, 6.3557400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51528, 'Rougé', 'Rouge', 'Rouge,Rougé,Ruzhe,Ruzieg,lu re,Руже,鲁热', 47.7836700, -1.4476300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51529, 'Rouffignac-Saint-Cernin-de-Reilhac', 'Rouffignac-Saint-Cernin-de-Reilhac', 'Rofinhac e Sent Sarnin de Relhac,Ruffin''jak-Sen-Sernen-de-Rejak,lu fei ni ya ke-sheng sai er nan de lei ya ke,Руффиньяк-Сен-Сернен-де-Реяк,Руффіньяк-Сен-Сернен-де-Реяк,鲁菲尼亚克-圣塞尔南德雷亚克', 45.0500000, 0.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51530, 'Rouffiac-Tolosan', 'Rouffiac-Tolosan', 'Rouffiac,Rouffiac-Tolosan,Rouffire', 43.6657600, 1.5252100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51531, 'Rouffach', 'Rouffach', 'Rufach,Ruffak,Руффак', 47.9578600, 7.3001600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51532, 'Rouen', 'Rouen', 'Erruan,Gorad Ruan,Roan,Rodem,Roeaan,Rothomagus,Rouan,Rouen,Rovan,Roðem,Ruan,Ruana,Ruanas,Ruao,Ruduborg,Rueno,Ruán,Ruão,Ruāna,Rúðuborg,URO,lu ang,luang,ro''am,ru x xng,ru''am,ruan,ruani,rwan,rwn,Ρουέν,Горад Руан,Руан,Ռուան,רואן,رؤن,روان,रुआं,रोआँ,รูอ็อง,რუანი,ሩዋን,ルーアン,盧昂,鲁昂,루앙', 49.4431300, 1.0993200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51533, 'Roubaix', 'Roubaix', 'Robaais,Rosbacum,Roubaix,Roubes,Roubés,Rube,Rubē,Rubė,XRX,lu bei,lube,ru bæ,rube,rwbh,rwbyh,Рубе,רובה,روبه,روبيه,روبے,รูแบ,ルーベ,鲁贝,루베', 50.6942100, 3.1745600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51534, 'Rouans', 'Rouans', 'Barra-les-Marais,Rodent,Rouans,Ruans,lu ang,Руанс,鲁昂', 47.1832100, -1.8592900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51535, 'Rots', 'Rots', 'Rots', 49.2123500, -0.4731900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51536, 'Rothau', 'Rothau', 'Roto,luo tuo,rtaw,rwthaw,Рото,رتاو,روثاو,罗托', 48.4568700, 7.2077200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51537, 'Rosult', 'Rosult', 'Rosult', 50.4588800, 3.3590200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51538, 'Rostrenen', 'Rostrenen', 'Rostrenen,Rostrenenn', 48.2369600, -3.3144200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51539, 'Rosselange', 'Rosselange', 'Rosselange', 49.2582100, 6.0697500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51540, 'Rosporden', 'Rosporden', 'Rasperden,Rospordan,Rosporden,luo si bo er dang,Роспордан,罗斯波尔当', 47.9666700, -3.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51541, 'Rospez', 'Rospez', 'Rospez,Rospezh', 48.7294000, -3.3836400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51542, 'Rosny-sur-Seine', 'Rosny-sur-Seine', 'Roni-sjur-Sen,Rosny,Rosny-sur-Seine,Рони-сюр-Сен,Роні-сюр-Сен', 48.9980800, 1.6313000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51543, 'Rosny-sous-Bois', 'Rosny-sous-Bois', 'Redomatum,Rodoniacum,Roni,Roni su Boa,Roni-su-Bua,Rosny,Rosny-sous-Bois,Rôni,lonisubua,luo ni cong lin,roni=su=bowa,rwzny sw bwa,Рони су Боа,Рони-су-Буа,Роні-су-Буа,روزنی سو بوآ,ロニー＝スー＝ボワ,罗尼丛林,로니수부아', 48.8701700, 2.4991000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51544, 'Rosières-près-Troyes', 'Rosieres-pres-Troyes', 'Rosieres,Rosieres-pres-Troyes,Rosières,Rosières-près-Troyes,Roz''er-pre-Trua,luo xi ai pu lei te lu wa ai,rwsys-prs-trwys,Розьер-пре-Труа,Розьєр-пре-Труа,روسیس-پرس-ترویس,罗西埃普雷特鲁瓦埃', 48.2618200, 4.0739600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51545, 'Rosières-en-Santerre', 'Rosieres-en-Santerre', 'Rosieres,Rosieres-en-Santerre,Rosières,Rosières-en-Santerre,Rousiere-in-Santerre,Rousière-in-Santérre,Roz''er-an-Santer,Roz''er-an-Santerr,luo xi ye er-ang sang tai er,Розьер-ан-Сантер,Розьєр-ан-Сантерр,罗西耶尔-昂桑泰尔', 49.8143300, 2.7009500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51546, 'Rosières-aux-Salines', 'Rosieres-aux-Salines', 'Rosieres,Rosieres-aux-Salines,Rosières,Rosières-aux-Salines', 48.5929000, 6.3320800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51547, 'Rosières', 'Rosieres', 'Rosieres,Rosières', 45.1323300, 3.9876800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51548, 'Rosières', 'Rosieres', 'Baubiac,Rosieres,Rosières', 44.4830700, 4.2559800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51549, 'Rosheim', 'Rosheim', 'Rosajm,Rosheim,Ruuse,luo sai mu,rwshym,Росайм,روشيم,罗塞姆', 48.4971000, 7.4710500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51550, 'Rosenau', 'Rosenau', 'Rosenau', 47.6347100, 7.5409900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51551, 'Roscoff', 'Roscoff', 'Roscoff,Roscovia,Rosko,Roskof,Roskoff,luo si ke,Роскоф,Роскофф,罗斯科', 48.7238100, -3.9870900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51552, 'Roscanvel', 'Roscanvel', 'Roscanvel,Roskanvel,Roskanvel'',Roskañvel,luo si kang wei,rosukan''vu~eru,Росканвель,ロスカンヴェル,罗斯康韦', 48.3152000, -4.5493700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51553, 'Roquevaire', 'Roquevaire', 'Rocavaira,Rokver,Roquevaire,Ròcavaira,luo qu ai wei er,Роквер,罗屈埃韦尔', 43.3502100, 5.6041400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51554, 'Roquettes', 'Roquettes', 'Roket,Rokett,Roquetas,luo qu ai tai,Рокет,Рокетт,罗屈埃泰', 43.4973300, 1.3684800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51555, 'Roquetoire', 'Roquetoire', 'Roktuar,Roquetoire,luo ke tu wa er,rwkywytwyr,Роктуар,روكيويتوير,罗克图瓦尔', 50.6702900, 2.3430700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51556, 'Roquemaure', 'Roquemaure', 'Roquemaure', 44.0494400, 4.7774000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51557, 'Roquefort-la-Bédoule', 'Roquefort-la-Bedoule', 'Rocafort e la Bedola,Rokfor-la-Bedul'',Roquefort,Roquefort-la-Bedoule,Roquefort-la-Bédoule,Ròcafòrt e la Bedola,luo qu ai fu er la bei du er,Рокфор-ла-Бедуль,罗屈埃福尔拉贝杜尔', 43.2488300, 5.5901500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51558, 'Roquefort', 'Roquefort', 'Roquefort', 44.1753000, 0.5610700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51559, 'Roquefort', 'Roquefort', 'Roquefort', 44.0350000, -0.3232300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51560, 'Roquecourbe', 'Roquecourbe', 'Rocacorba,Rokkurb,Roquecourbe,Ròcacorba,luo qu ai ku er bu,Роккурб,罗屈埃库尔布', 43.6644200, 2.2926400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51561, 'Roquebrune-sur-Argens', 'Roquebrune-sur-Argens', 'Rocabruna,Rocabruna dArgenc,Rokbrjun-sjur-Arzhan,Rokbrjun-sjur-Arzhans,Roquebrune,Ròcabruna,Ròcabruna dArgenç,a er gang he pan luo qu ai bu lu na,Рокбрюн-сюр-Аржан,Рокбрюн-сюр-Аржанс,阿尔冈河畔罗屈埃布吕纳', 43.4333300, 6.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51562, 'Roquebrune-Cap-Martin', 'Roquebrune-Cap-Martin', 'Rocabruna,Rocabruna Caup Martin,Rocca Bruna,Roccabruna,Rokbrjun-Kap-Marten,Roquebrune,Roquebrune-Cap-Martin,Ròcabruna,Ròcabruna Caup Martin,luo qu ai bu lan ka ma er tan,rkbrwn-kap-martn,rokuburyunu=kappu=marutan,rwkywbrwn,Рокбрюн-Кап-Мартен,Рокебрюн — Кап-Мартен,روكيوبرون,رکبرون-کاپ-مارتن,ロクブリュヌ＝カップ＝マルタン,罗屈埃布兰卡马尔坦', 43.7640800, 7.4820700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51563, 'Roquebillière', 'Roquebilliere', 'Rocabilhiera,Rocca Bilaria,Rokbijer,Roquebilliere,Roquebillière,Ròcabilhiera,luo qu ai bi li ai,rokubirieru,rwkywbylyr,Рокбийер,Рокбійєр,روكيوبيلير,ロクビリエール,罗屈埃比利埃', 44.0125000, 7.3074800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51564, 'Roppenheim', 'Roppenheim', '', 48.8416700, 8.0531500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51565, 'Roost-Warendin', 'Roost-Warendin', 'Roost-Warendin', 50.4192000, 3.1037400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51566, 'Roncq', 'Roncq', 'Roenk,Roncq,Ronk,Ronq,long ke,Ронк,龙克', 50.7533000, 3.1213100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51567, 'Ronchin', 'Ronchin', 'Ronchin,Ronshen,Rumcinium,long shang,Роншен,龙尚', 50.5988300, 3.0905600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51568, 'Roncherolles-sur-le-Vivier', 'Roncherolles-sur-le-Vivier', 'Roncherolles', 49.4666700, 1.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51569, 'Ronchamp', 'Ronchamp', 'Ronchamp,Ronsham,Ronshan,rnshwn,Роншам,Роншан,رنشون', 47.7006300, 6.6359100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51570, 'Romorantin-Lanthenay', 'Romorantin-Lanthenay', 'Romarantin,Romoranten-Lantene,Romorantin,luo mo lang tan lang te nai,romorantan=rantone,Роморантен-Лантене,ロモランタン＝ラントネー,罗莫朗坦朗特奈', 47.3666700, 1.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51571, 'Romilly-sur-Seine', 'Romilly-sur-Seine', 'Romii-sjur-Sen,Romiji-sjur-Sen,Romilly,Romilly-Voltaire,Romilly-sur-Seine,Rumiliacum ad Sequanam,sai na he pan luo mi li,Ромийи-сюр-Сен,Ромії-сюр-Сен,塞纳河畔罗米利', 48.5108500, 3.7263400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51572, 'Romilly-sur-Andelle', 'Romilly-sur-Andelle', 'Romii-sjur-Andel'',Romiji-sjur-Andel'',Romilly,Romilly-sur-Andelle,ang dai er he pan luo mi li,Ромии-сюр-Андель,Ромийи-сюр-Андель,Ромії-сюр-Андель,昂代尔河畔罗米利', 49.3319000, 1.2612700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51573, 'Romillé', 'Romille', 'Romille,Romillé,Rovelieg', 48.2161900, -1.8922900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51574, 'Romenay', 'Romenay', 'Romenay', 46.5020800, 5.0690400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51575, 'Rombas', 'Rombas', 'Romba,Rombach,Rombach  Lothringen,Rombas,long ba,Ромба,龙巴', 49.2491100, 6.0940500, 'FR', '2016-07-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51576, 'Romanswiller', 'Romanswiller', 'Romansviller', 48.6455600, 7.4076200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51577, 'Romans-sur-Isère', 'Romans-sur-Isere', 'Roman-sjur-Izer,Romans,Romans-sur-Isere,Romans-sur-Isère,Romas sur Isere,Romas sur Isère,Romen sir Izer,Rumans,lomangswileu-ijeleu,rmn- swr-ayzr,roman=shuru=izeru,rwman swr ayzr,yi sai er he pan luo mang,Роман-сюр-Ізер,Роман-сюр-Изер,Ромен сир Изер,رمن- سور-ایزر,رومان سور ایزر,ロマン＝シュル＝イゼール,伊塞尔河畔罗芒,로망쉬르이제르', 45.0463900, 5.0562000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51578, 'Romanèche-Thorins', 'Romaneche-Thorins', 'Romaneche-Thorins,Romanèche-Thorins', 46.1840200, 4.7424200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51579, 'Romainville', 'Romainville', 'Romainville,Romenvil,Romenvil'',lomaengbil,luo man wei er,roman''vu~iru,rwmn wyl,rwmynfyl,Роменвил,Роменвиль,Роменвіль,رومن ویل,رومينفيل,ロマンヴィル,罗曼维尔,로맹빌', 48.8854000, 2.4348200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51580, 'Romagny', 'Romagny', 'Romagny', 48.6393100, -0.9660500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51581, 'Romagnieu', 'Romagnieu', 'Romagnieu', 45.5704000, 5.6400200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51582, 'Romagné', 'Romagne', 'Romagne,Romagné,Rovenieg', 48.3401900, -1.2775100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51583, 'Romagnat', 'Romagnat', 'Romagnat,Roman''ja,Romanhac,Romanhat,luo ma ni ya,Романья,罗马尼亚', 45.7287800, 3.0989300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51584, 'Rolleville', 'Rolleville', 'Rolleville', 49.5823200, 0.2117700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51585, 'Rolampont', 'Rolampont', 'Rolampont', 47.9495100, 5.2856000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51586, 'Roissy-en-France', 'Roissy-en-France', 'QZV,Roissy,Roissy-en-France,Ruassi-an-Frans,fu lang si de qu lu wa xi,rowashi=an=furansu,Руасси-ан-Франс,Руассі-ан-Франс,ロワシー＝アン＝フランス,弗朗斯地区鲁瓦西', 49.0044300, 2.5170300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51587, 'Roissy-en-Brie', 'Roissy-en-Brie', 'Roasi an Bri,Roissy,Roissy-en-Brie,Roissy-les-Friches,Ruassi-an-Bri,luasiangbeuli,rowashi=an=buri,rwasyan bry,Роаси ан Бри,Руасси-ан-Бри,Руассі-ан-Брі,روآسیان بری,ロワシー＝アン＝ブリー,루아시앙브리', 48.7915900, 2.6474700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51588, 'Roisel', 'Roisel', 'Resi,Roisel,Ruazel'',Rési,lu wa sai lei,Руазель,鲁瓦塞勒', 49.9476800, 3.0997300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51589, 'Roiffieux', 'Roiffieux', 'Librefieux,Reifioc,Reifiòc,Roiffieux,Ruaf''jo,Ruafe,lu wa fei e,Руафьё,Руафє,鲁瓦菲厄', 45.2264700, 4.6550200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51590, 'Rohrbach-lès-Bitche', 'Rohrbach-les-Bitche', 'Rohrbach,Rohrbach-les-Bitche,Rohrbach-lès-Bitche', 49.0451600, 7.2658800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51591, 'Rohan', 'Rohan', 'Roc''han,Rohan', 48.0683300, -2.7512000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51592, 'Rognonas', 'Rognonas', 'Rognonas,Ron''ona,Ron''onas,Ronhonac,Ronhonaç,luo ni ao na,Роньона,Роньонас,罗尼奥纳', 43.8999300, 4.8036900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51593, 'Rognes', 'Rognes', 'Rognes', 43.6641800, 5.3480100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51594, 'Rognac', 'Rognac', 'Rognac,Ron''jak,Ronhac,luo ni ya ke,Роньяк,罗尼亚克', 43.4876100, 5.2338700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51595, 'Rogerville', 'Rogerville', 'Rogerville', 49.5029600, 0.2651600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51596, 'Roézé-sur-Sarthe', 'Roeze-sur-Sarthe', 'Roeze,Roeze-sur-Sarthe,Roézé,Roézé-sur-Sarthe', 47.8954600, 0.0672300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51597, 'Rœux', 'Roeux', 'Re,Roeux,lei cun,rwks,Ре,روكس,勒村', 50.2952600, 2.9007300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51598, 'Rœulx', 'Roeulx', 'Rel'',Rjol'',Roeulx,lei lei,rl,Рель,Рёль,رل,勒勒', 50.3000000, 3.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51599, 'Rodilhan', 'Rodilhan', 'Rod''jan,Rodilhan,luo di yang,Родьян,罗迪扬', 43.8272500, 4.4308800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51600, 'Rodez', 'Rodez', 'RDZ,Rodes,Rodez,Rodezas,Rodezo,Rodés,Segodunum,lodejeu,luo de ci,rdz,rodezu,Родез,ردز,รอแดซ,རོ་ཌེ་ཛི།,ロデズ,ロデーズ,罗德兹,로데즈', 44.3525800, 2.5733800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51601, 'Rocroi', 'Rocroi', 'Roc-Libre,Rocroi,Rokroa,Rokrua,luo ke lu wa,rokurowa,Рокроа,Рокруа,ロクロワ,罗克鲁瓦', 49.9261000, 4.5222000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51602, 'Rocquencourt', 'Rocquencourt', 'Rocquencourt', 48.8378300, 2.1022800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51603, 'Rochetaillée-sur-Saône', 'Rochetaillee-sur-Saone', 'Rochetaillee-sur-Saone,Rochetaillée-sur-Saône', 45.8500000, 4.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51604, 'Roches-Prémarie-Andillé', 'Roches-Premarie-Andille', 'Les Roches-Premarie,Les Roches-Prémarie,Roche-Premarie-Andille,Roche-Prémarie-Andillé,Roches-Premarie,Roches-Premarie-Andille,Roches-Prémarie,Roches-Prémarie-Andillé,Rosh-Premari-Andil''e,luo she pu lei ma li ye ang di lei,Рош-Премарі-Андільє,罗舍普雷马里耶昂迪勒', 46.4825100, 0.3710600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51605, 'Rocheservière', 'Rocheserviere', 'Rocheserviere,Rocheservière', 46.9376500, -1.5114300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51606, 'Rochemaure', 'Rochemaure', 'Rochamaura,Rochemaure,Roshmor,Ròchamaura,luo xie mo er,Рошмор,罗谢莫尔', 44.5874700, 4.7050700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51607, 'Roche-la-Molière', 'Roche-la-Moliere', 'Roche-la-Moliere,Roche-la-Molière,Rosh-la-Mol''er,luo ke la mo li ai,Рош-ла-Мольєр,罗克拉莫利埃', 45.4340800, 4.3227700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51608, 'Rochegude', 'Rochegude', 'Rochegude', 44.2485900, 4.8292200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51609, 'Rochefort-sur-Loire', 'Rochefort-sur-Loire', 'Rochefort,Rochefort-sur-Loire,Roshfor-sjur-Luar,lu wa er he pan luo xie fu er,Рошфор-сюр-Луар,卢瓦尔河畔罗谢福尔', 47.3570500, -0.6569600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51610, 'Rochefort-du-Gard', 'Rochefort-du-Gard', 'Rocafort de Gardon,Rochefort,Rochefort-du-Gard,Roshfor-dju-Gar,Ròcafòrt de Gardon,luo xie fu er di jia er,Рошфор-дю-Гар,罗谢福尔迪加尔', 43.9765200, 4.6902300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51611, 'Rochefort', 'Rochefort', 'Gorad Rashfor,RCO,Rochefort i Charente-Maritime,Rochefort-sur-Mer,Roshfor,losyupoleu,luo shen fu er,roshpori,roshuforu,rwshfw  sharant-marytym,rwshfwr  shrant-marytym,Горад Рашфор,Рошфор,روشفو، شارانت-ماریتیم,روشفور، شرانت-ماریتیم,როშფორი,ロシュフォール,羅什福爾,로슈포르', 45.9333300, -0.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51612, 'Rochecorbon', 'Rochecorbon', 'Rochecorbon,Roshkorbon,Rupes Corbonis,luo xie ke er bang,Рошкорбон,罗谢科尔邦', 47.4165800, 0.7552100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51613, 'Rochechouart', 'Rochechouart', '', 45.8166700, 0.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51614, 'Roche', 'Roche', 'Roche', 45.5870900, 5.1596500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51615, 'Rocbaron', 'Rocbaron', 'Rocbaron', 43.3044900, 6.0905900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51616, 'Robion', 'Robion', 'Robion', 43.8470700, 5.1097500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51617, 'Robecq', 'Robecq', 'Robecq,Robek,Robeke,luo bei ke,rwbysk,Робек,روبيسك,罗贝克', 50.5960800, 2.5626200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51618, 'Roanne', 'Roanne', 'RNE,Roan,Roana,Roann,Roanne,Rodumna,Rouana,loan,luo a ne,roan''nu,rwan,Роан,Роанн,روآن,ロアンヌ,罗阿讷,로안', 46.0333300, 4.0666700, 'FR', '2017-07-16', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51619, 'Rixheim', 'Rixheim', 'Rixheim', 47.7514000, 7.4009100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51620, 'Rivière-Saas-et-Gourby', 'Riviere-Saas-et-Gourby', 'Riviere-Saas,Riviere-Saas-et-Gourby,Rivière-Saas,Rivière-Saas-et-Gourby', 43.6799000, -1.1498600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51621, 'Rivières', 'Rivieres', 'Rivieres,Rivières', 45.7529500, 0.3612800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51622, 'Rivière', 'Riviere', 'Riviere,Rivière', 50.2331600, 2.6920000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51623, 'Rivesaltes', 'Rivesaltes', 'Ribesaltes,Rival''t,Rivesaltes,li wei sa er tai,rivusaruto,Ривальт,リヴサルト,里韦萨尔泰', 42.7694500, 2.8723900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51624, 'Rives', 'Rives', 'Rives,Rives-sur-Fure', 45.3550500, 5.4992700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51625, 'Rivery', 'Rivery', 'Riveri,Rivery,Rivroe,Rivroé,li wei li,Ривері,里韦里', 49.9032800, 2.3223500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51626, 'Rivedoux-Plage', 'Rivedoux-Plage', 'Rivdu-Plazh,Rivedoux,li wei du pu la ge,Ривду-Плаж,里韦杜普拉格', 46.1585400, -1.2709300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51627, 'Rive-de-Gier', 'Rive-de-Gier', 'Riv-de-Zhe,Rive-de-Gier,Vers-de-Gier,Vèrs-de-Giér,li fu de bi ye,Рив-де-Жє,里夫德比耶', 45.5275500, 4.6158900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51628, 'Ris-Orangis', 'Ris-Orangis', 'Brutus,Ris,Ris-Orangis,Ris-Oranzhis,Riz Oranzhis,li ao lang ji,lijolangjiseu,ri=zoranjisu,ry awranzhy,Риз Оранжис,Рис-Оранжис,ری اورانژی,リ＝ゾランジス,里奥朗吉,리조랑지스', 48.6511000, 2.4140600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51629, 'Riscle', 'Riscle', 'Riscle', 43.6563300, -0.0860700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51630, 'Riquewihr', 'Riquewihr', 'Reichenweier,Rikevir,Rikvir,Riquewihr,li qu ai wei,rikuvu~iru,Риквир,Рикевир,Рикевір,رکوہر,リクヴィール,里屈埃维', 48.1667200, 7.2970700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51631, 'Rioz', 'Rioz', 'R''oz,Rioz,Rjo,Рйо,Рьоз', 47.4252100, 6.0659800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51632, 'Riotord', 'Riotord', 'Riotord', 45.2322600, 4.4037600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51633, 'Riorges', 'Riorges', 'Riorges,Riorzh,li ao er re,Ріорж,里奥尔热', 46.0417900, 4.0496500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51634, 'Rions', 'Rions', 'Rions,Rjon,li weng,Рйон,里翁', 44.6637800, -0.3511300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51635, 'Rion-des-Landes', 'Rion-des-Landes', 'Rion,Rion-les-Landes', 43.9344900, -0.9238800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51636, 'Riom-ès-Montagnes', 'Riom-es-Montagnes', 'R''om-ehs-Montan'',Riom de las Montanhas,Riòm de las Montanhas,Rjom-e-Montan'',li weng ai meng ta gai,riomesu=montanyu,Рйом-е-Монтань,Рьом-эс-Монтань,リオメス＝モンターニュ,里翁埃蒙塔盖', 45.2833300, 2.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51637, 'Riom', 'Riom', 'R''om,Riam,Ricomagus,Riom,Rion,XRI,li yong,liong,rion,rywm,Рьом,Ріон,ريوم,リオン,里永,리옹', 45.9000000, 3.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51638, 'Rinxent', 'Rinxent', 'Renksan,Rincquessent,Rinxent,lan ke sang,rynksynt,Ренксан,رينكسينت,兰克桑', 50.8071400, 1.7289900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51639, 'Rimogne', 'Rimogne', 'Rimogne,Rimon'',li mo nie,Римонь,里莫涅', 49.8407500, 4.5394100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51640, 'Rilly-la-Montagne', 'Rilly-la-Montagne', 'Rilly,Rilly-la-Montagne', 49.1655300, 4.0456800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51641, 'Rillieux-la-Pape', 'Rillieux-la-Pape', 'Rije le Pap,Rije-la-Pap,Rilliehuks-la-Pap,lillioelapapeu,riryu=ra=papu,ryw lpp,Риллиэукс-ла-Пап,Рије ле Пап,Рійє-ла-Пап,ریو لپپ,リリュー＝ラ＝パプ,릴리외라파프', 45.8166700, 4.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51642, 'Rilhac-Rancon', 'Rilhac-Rancon', 'Rilhac,Rilhac-Rancon', 45.9000000, 1.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51643, 'Riez', 'Riez', 'R''ez,Re,Reius,Ries,Riez,Riés,li ye,Рьез,Рє,里耶', 43.8179300, 6.0929500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51644, 'Rieux-Minervois', 'Rieux-Minervois', 'Rieux,Rieux-Minervois', 43.2819400, 2.5868700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51645, 'Rieux-en-Cambrésis', 'Rieux-en-Cambresis', 'Rieux,Rieux-en-Cambresis,Rieux-en-Cambrésis', 50.2006900, 3.3523200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51646, 'Rieux', 'Rieux', 'Rieux', 49.3000000, 2.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51647, 'Rieux', 'Rieux', 'Reoz,Rieux', 47.5978100, -2.1082800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51648, 'Rieux-Volvestre', 'Rieux-Volvestre', 'Rie-Vol''vestr,Rieux,Rius,Rivi,er yue wo er wei si te er,Ріє-Вольвестр,尔约沃尔韦斯特尔', 43.2500000, 1.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51649, 'Rieupeyroux', 'Rieupeyroux', 'Rieupeyroux', 44.3079900, 2.2381900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51650, 'Rieumes', 'Rieumes', 'R''jom,Rem,Rieumes,Riumas,li ye yu mei,Рьём,Рєм,里耶于梅', 43.4114300, 1.1170200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51651, 'Rieulay', 'Rieulay', 'R''ele,Rele,Rieulay,e lai,Рьеле,Рєле,略莱', 50.3785600, 3.2528400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51652, 'Riedisheim', 'Riedisheim', 'Ridisajm,Riedisheim,li ye di sang,Ридисайм,Ридісайм,里耶迪桑', 47.7475700, 7.3666500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51653, 'Riec-sur-Belon', 'Riec-sur-Belon', 'Riec,Riec-sur-Belon,Riec-sur-Bélon,Rieg,Rieo-sur-Belon', 47.8333300, -3.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51654, 'Richwiller', 'Richwiller', 'Reichweiler,Richwiller,Rikviller,Rishviller,li ke wei lai,Риквиллер,Ришвиллер,Ришвіллер,里克维莱', 47.7794800, 7.2822500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51655, 'Richemont', 'Richemont', 'Reichersberg,Richemont', 49.2769000, 6.1626800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51656, 'Richelieu', 'Richelieu', 'Richelieu,Ricolocus,Rishel''e,Rishel''jo,li xie li e,Ришельё,Ришельє,里谢利厄', 47.0138900, 0.3240600, 'FR', '2016-06-08', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51657, 'Richebourg-l''Avoué', 'Richebourg-l''Avoue', 'Richebourg,Richebourg-l''Avoue,Richebourg-l''Avoué', 50.5699900, 2.7488400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51658, 'Richardménil', 'Richardmenil', 'Richardmenil,Richardménil', 48.5985100, 6.1699200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51659, 'Ribérac', 'Riberac', 'Rabairac,Riberac,Riberak,Ribérac,li bei la ke,Риберак,里贝拉克', 45.2500000, 0.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51660, 'Ribemont', 'Ribemont', 'Ercuriacum,Ribemont,Ribmon,li bu meng,Рибмон,里布蒙', 49.7954000, 3.4589300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51661, 'Ribeauvillé', 'Ribeauville', 'Rappoltsweiler,Ribeauville,Ribeauvillé,Riboville,li bo wei lai,ribovu~ire,Рибовилле,Рибовілле,リボヴィレ,里博维莱', 48.1951000, 7.3193800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51662, 'Ribaute-les-Tavernes', 'Ribaute-les-Tavernes', 'Ribaute,Ribaute-les-Tavernes', 44.0372400, 4.0804600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51663, 'Riantec', 'Riantec', 'R''jantek,Riantec,Rianteg,Rjantek,li ang tai ke,Рьянтек,Рянтек,里昂泰克', 47.7109300, -3.3162900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51664, 'Rians', 'Rians', '', 47.1787500, 2.6135900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51665, 'Rians', 'Rians', 'Rians', 43.6065900, 5.7558900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51666, 'Riaillé', 'Riaille', 'Ree,Riaille,Riaillé,Rialeg,li ai lai,Рєє,里艾莱', 47.5179700, -1.2940400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51667, 'Ria-Sirach', 'Ria-Sirach', 'Ria,Rià', 42.6166700, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51668, 'Rhinau', 'Rhinau', 'Rheinau,Rhinai,Rhinau,Rhinài,Rino,li nuo,rhynaw,Рино,رهيناو,里诺', 48.3180900, 7.7061300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51669, 'Rezé', 'Reze', 'Ratiatum,Reudied,Reza,Reze,Rezé,lei ze,leuje,ruze,rwzh  fransh,Реза,Резе,روزه، فرانسه,ルゼ,雷泽,르제', 47.1814400, -1.5496500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51670, 'Reyrieux', 'Reyrieux', 'Rejre,Rer''jo,Reryo,Reyrieux,lei li e,ryyryw  ayn,Рейрє,Рерьё,Ռերյո,رييريو، أين,雷里厄', 45.9330600, 4.8239400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51671, 'Reiners', 'Reiners', 'Reiners,Reynes,Reynès', 42.4770200, 2.7068000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51672, 'Rexpoëde', 'Rexpoede', 'Rekspoed,Rekspoede,Respoee,Respoeë,Rexpoede,Rexpoëde,lei ke si bo ai de,Рекспоед,雷克斯波埃德', 50.9392600, 2.5391400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51673, 'Revin', 'Revin', 'Reven,Revin,lei wan,rwyn,Ревен,روین,勒万', 49.9403900, 4.6350300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51674, 'Réville', 'Reville', 'Revil'',Reville,Réville,lei wei er,Ревиль,Ревіль,雷维尔', 49.6190600, -1.2586800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51675, 'Revigny-sur-Ornain', 'Revigny-sur-Ornain', 'Revigny,Revigny-sur-Ornain', 48.8301600, 4.9855800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51676, 'Reventin-Vaugris', 'Reventin-Vaugris', 'Reventin,Reventin-Vaugris', 45.4638000, 4.8376900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51677, 'Revel', 'Revel', 'Revel', 45.1864600, 5.8685200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51678, 'Revel', 'Revel', 'Revel', 43.4581200, 2.0046900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51679, 'Reuilly', 'Reuilly', 'Reuilly', 47.0847600, 2.0430500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51680, 'Reugny', 'Reugny', 'Reugny', 47.4820800, 0.8846800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51681, 'Rety', 'Rety', '', 50.8000000, 1.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51682, 'Retournac', 'Retournac', 'Retornac,Retournac,Returnak,lei tu er na ke,ruto~urunakku,Ретурнак,ルトゥールナック,雷图尔纳克', 45.2062900, 4.0355400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51683, 'Retonfey', 'Retonfey', 'Retonfe,Retonfey,lei tong fei,Ретонфе,雷通费', 49.1348700, 6.3074900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51684, 'Retiers', 'Retiers', 'Rester,Resteria,Ret''e,Retiers,lei di ye er,Ретье,Ретьє,雷蒂耶尔', 47.9139200, -1.3796700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51685, 'Rethel', 'Rethel', 'Gorad Rehtehl'',Retel'',Rethel,lei tai lei,ruteru,Горад Рэтэль,Ретель,ルテル,勒泰勒', 49.5166700, 4.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51686, 'Restinclières', 'Restinclieres', 'Restincheres,Restinchères,Restinclieres,Restinclières', 43.7225200, 4.0347600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51687, 'Restigné', 'Restigne', 'Restigne,Restigné', 47.2822400, 0.2278800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51688, 'Ressons-sur-Matz', 'Ressons-sur-Matz', 'Reson-sjur-Ma,Resson-sjur-Ma,Ressons,Ressons-sur-Matz,Roye-sur-Matz,ma ci he pan lei song,Ресон-сюр-Ма,Рессон-сюр-Ма,马茨河畔雷松', 49.5385800, 2.7441600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51689, 'Réquista', 'Requista', 'Rekista,Requista,Requistar,Réquista,lei ji si ta,Рекиста,Рекіста,雷基斯塔', 44.0332500, 2.5355400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51690, 'Requeil', 'Requeil', 'Requeil', 47.7837100, 0.1610500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51691, 'Replonges', 'Replonges', 'Replonges,Replonz,Replonzh,lei pu long ri,rwblwnj,Реплонж,Ռեպլոնժ,روبلونج,勒普隆日', 46.3111100, 4.8796400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51692, 'Renwez', 'Renwez', 'Ranve,Renwez,lang wei,Ранве,朗韦', 49.8383900, 4.6033400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51693, 'Rennes', 'Rennes', 'Condate Redonum,Gorad Rehn,RNS,Ren,Renas,Renes,Renn,Renn Shehiri,Renna,Rennes,Roazhon,Rènes,Rénn Shehiri,lei en,len,ren,ren''nu,reni,rhena,rn,ryn,Ρεν,Горад Рэн,Рен,Ренн,Ռեն,רן,رن,رين,رین,رینے,ऱ्हेन,ரேன்,แรน,რენი,レンヌ,雷恩,렌', 48.1119800, -1.6742900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51694, 'Renescure', 'Renescure', 'Renescure,Reneskjur,Ruisscheure,Ruuscheure,lei nei si qu er,Ренескюр,勒内斯屈尔', 50.7275400, 2.3680100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51695, 'Renazé', 'Renaze', 'Renaze,Renazé,lei na ze,Реназе,雷纳泽', 47.7934000, -1.0543700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51696, 'Renaison', 'Renaison', 'Renaison,Renezon,lei nai song,Ренезон,雷奈松', 46.0517900, 3.9256800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51697, 'Renage', 'Renage', 'Renage', 45.3352900, 5.4852800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51698, 'Remy', 'Remy', '', 49.4333300, 2.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51699, 'Remoulins', 'Remoulins', 'Remolins,Remoulins,Remulen,lei mu lan,rmwln,Ремулен,رمولن,雷穆兰', 43.9394900, 4.5679900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51700, 'Remouillé', 'Remouille', 'Remouille,Remouillé,Remue,Romuliacum,Ruvelieg,lei mu yi lai,Ремує,雷穆伊莱', 47.0558700, -1.3768200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51701, 'Remiremont', 'Remiremont', 'Libremont,Remiremont,Remirmon,Romarici Mons,lei mi lei meng,Ремирмон,Ремірмон,雷米雷蒙', 48.0175400, 6.5882000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51702, 'Rémilly', 'Remilly', 'Remilly,Rémilly', 49.0121900, 6.3958300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51703, 'Rémelfing', 'Remelfing', 'Remelfing,Rémelfing', 49.0883800, 7.0885300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51704, 'Rémalard', 'Remalard', 'Remal-la-Montagne,Remalar,Remalard,Rémalard,lei ma la er,Ремалар,雷马拉尔', 48.4286700, 0.7718500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51705, 'Reiningue', 'Reiningue', 'Reiningen,Reiningue,Reneng,lei nan gai,Рененг,雷南盖', 47.7505400, 7.2325000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51706, 'Reims', 'Reims', 'Durocortorum,Gorad Rehjms,RHE,Reims,Reimsa,Reimsas,Rejms,Remes,Remeš,Rems,Rens,Reyms,Rheims,laengseu,lan si,rans,ransu,rayym,reimsi,rensa,rms,rns,ryyms,Ρενς,Горад Рэймс,Реймс,Ремс,Ռեյմս,ריימס,رائیم,رانس,رمس,رنس,रेंस,แร็งส์,რეიმსი,ランス,兰斯,랭스', 49.2500000, 4.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51707, 'Reillanne', 'Reillanne', 'Ralhana,Reillanne,Rejan,Rejann,lei lang,Рейан,Реянн,雷朗', 43.8813100, 5.6573600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51708, 'Reignier-Ésery', 'Reignier-Esery', '', 46.1333300, 6.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51709, 'Reignac-sur-Indre', 'Reignac-sur-Indre', 'Reignac,Reignac-sur-Indre,Ren''jak-sjur-Endr,Val-Indre,an de er he pan lei ni ya ke,Реньяк-сюр-Ендр,安德尔河畔雷尼亚克', 47.2266200, 0.9158700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51710, 'Reignac', 'Reignac', 'Reignac', 45.2339300, -0.5062700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51711, 'Reichstett', 'Reichstett', 'Reichstett,Rejshstet,Richstett,lei ke si tai,rayshtt,rytshstyt,Рейшстет,رایشتت,ريتشستيت,雷克斯泰', 48.6485600, 7.7545500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51712, 'Reichshoffen', 'Reichshoffen', 'Reichshofen,Reichshoffen,Rejshsoffen,Risshoffe,lei ke suo fang,rayshshwfn,rytshshwfyn,Рейшсоффен,رایشسهوفن,ريتششوفين,雷克索方', 48.9328700, 7.6656100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51713, 'Réhon', 'Rehon', 'Rehon,Réhon', 49.5047700, 5.7475500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51714, 'Régusse', 'Regusse', 'Regjus,Regjuss,Regussa,Regusse,Régusse,lei ju si,Регюс,Регюсс,雷居斯', 43.6572400, 6.1297200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51715, 'Réguisheim', 'Reguisheim', '', 47.9000000, 7.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51716, 'Réguiny', 'Reguiny', 'Regini,Reguiny,Réguiny,lei ji ni,Регини,Регіні,雷吉尼', 47.9764900, -2.7447800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51717, 'Régny', 'Regny', 'Ren''i,lei ni,Реньї,雷尼', 45.9833300, 4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51718, 'Redon', 'Redon', 'Redon,XRN', 47.6500000, -2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51719, 'Réding', 'Reding', 'Reding,Réding', 48.7517700, 7.1074700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51720, 'Redessan', 'Redessan', 'Redessan', 43.8311700, 4.4977100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51721, 'Rédené', 'Redene', 'Redene,Rédené,lei dai nei,redene,Редене,レデネ,雷代内', 47.8500000, -3.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51722, 'Recquignies', 'Recquignies', '', 50.2839600, 4.0372200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51723, 'Rebréchien', 'Rebrechien', 'Rebrechien,Rebreshjan,Rebréchien,lei bu lei xi an,Ребрешян,雷布雷希安', 47.9872700, 2.0443200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51724, 'Rebais', 'Rebais', 'Rebais,Rebe,Ребе', 48.8472100, 3.2323200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51725, 'Réalville', 'Realville', 'Garde-Mont,Realville,Réalville', 44.1145200, 1.4799800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51726, 'Réalmont', 'Realmont', 'Montdadou,Realmont,Réalmont', 43.7775400, 2.1888500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51727, 'Razès', 'Razes', 'Razes,Razès', 46.0321900, 1.3367600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51728, 'Ravières', 'Ravieres', 'Ravieres,Ravières', 47.7347500, 4.2277700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51729, 'Ravenel', 'Ravenel', 'Ravenel', 49.5152300, 2.5019200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51730, 'Rauzan', 'Rauzan', 'Rauzan', 44.7783800, -0.1246500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51731, 'Raon-aux-Bois', 'Raon-aux-Bois', 'Raon,Raon-aux-Bois,Raon-o-Bua,lang ao bu wa,Раон-о-Буа,朗奥布瓦', 48.0568600, 6.5209800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51732, 'Ranville', 'Ranville', 'Ranvil'',Ranville,lang wei er,Ранвиль,Ранвіль,朗维尔', 49.2307100, -0.2556000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51733, 'Rantigny', 'Rantigny', 'Rantigny,Rantin''i,lang di ni,Рантіньї,朗蒂尼', 49.3275800, 2.4424400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51734, 'Rannée', 'Rannee', 'Radenez,Radenix,Ranne,Rannee,Rannée,la nei ai,Ранне,拉内埃', 47.9238300, -1.2412400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51735, 'Rang-du-Fliers', 'Rang-du-Fliers', 'Ran-dju-Fl''e,Rang-du-Fliers,Rin-du-Fiyers,Rin-du-Fïyers,lang di fu li ye,ranj dw flyrs,Ран-дю-Флье,Ран-дю-Фльє,رانج دو فليرس,朗迪夫利耶', 50.4170800, 1.6443100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51736, 'Randan', 'Randan', 'Randan', 46.0159500, 3.3552200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51737, 'Ranchicourt', 'Ranchicourt', 'Ranchicourt', 50.4355900, 2.5569000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51738, 'Ramonville-Saint-Agne', 'Ramonville-Saint-Agne', 'Ramonvil''-Sent-An'',Ramonvila e Sant Anha,Ramonvila e Sent Anhan,Ramonville,la meng wei er sheng a ni,Рамонвиль-Сент-Ань,Рамонвіль-Сент-Ань,拉蒙维尔圣阿尼', 43.5461800, 1.4749100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51739, 'Ramonchamp', 'Ramonchamp', 'Ramonchamp,Ramonsham,la meng shang,Рамоншам,拉蒙尚', 47.8942900, 6.7417100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51740, 'Rambouillet', 'Rambouillet', 'Rambolitum,Rambouillet,Rambouillet-forhandlingerne,Rambue,Rambuje,XRT,lang bu yi ai,langbuye,rambwyyyh,ranbuie,Рамбуе,Рамбуйе,Рамбуйє,Рамбује,رامبوئییه,ランブイエ,朗布依埃,랑부예', 48.6500000, 1.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51741, 'Rambervillers', 'Rambervillers', 'Ramberville,Ramberviller,Rambervilleriae,Rambervillers,lang bei er wei lai er,Рамбервилле,Рамбервиллер,Рамбервілле,朗贝尔维莱尔', 48.3424000, 6.6358000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51742, 'Ramatuelle', 'Ramatuelle', 'Ramatjuehl'',Ramatjuel'',Ramatuela,Ramatuelle,la ma di ai er,Раматюель,Раматюэль,拉马蒂埃尔', 43.2169600, 6.6113700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51743, 'Rai', 'Rai', 'Rai-sur-Rile,Rai-sur-Rîle', 48.7500000, 0.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51744, 'Raismes', 'Raismes', 'Raismes,Rem,lai mu,Рем,赖姆', 50.3833300, 3.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51745, 'Raimbeaucourt', 'Raimbeaucourt', 'Raimbeaucourt,Rembokur,lan bo ku er,Рембокур,兰博库尔', 50.4346600, 3.0933300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51746, 'Raillencourt-Sainte-Olle', 'Raillencourt-Sainte-Olle', 'Rajankur-Sent-Ol'',la ye lang ku er sheng ao lei,Раянкур-Сент-Оль,拉耶朗库尔圣奥勒', 50.1833300, 3.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51747, 'Raedersheim', 'Raedersheim', '', 47.8889500, 7.2822200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51748, 'Radon', 'Radon', 'Radon', 48.5024600, 0.1027800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51749, 'Radinghem-en-Weppes', 'Radinghem-en-Weppes', 'Radinghem,Radinghem-en-Weppes', 50.6188400, 2.9092400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51750, 'Racquinghem', 'Racquinghem', 'Racquinghem,Racquinghin,Rakengem,la kan gai mu,raskywynhym,Ракенгем,راسكيوينهيم,拉坎盖姆', 50.6924500, 2.3573600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51751, 'Râches', 'Raches', 'Raches,Rash,Râches,la shen,Раш,拉什', 50.4170600, 3.1363500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51752, 'Rabastens-de-Bigorre', 'Rabastens-de-Bigorre', 'Rabastens,Rabastens-de-Bigorre', 43.3876900, 0.1512200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51753, 'Rabastens', 'Rabastens', 'Rabastens,la ba si tang,Рабастенс,拉巴斯唐', 43.8251200, 1.7238200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51754, 'Quistinic', 'Quistinic', 'Kistinid,Kistinik,Quistinic,qu yi si di ni ke,Кистиник,Кістінік,屈伊斯蒂尼克', 47.9041000, -3.1340000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51755, 'Quissac', 'Quissac', 'Ouissac,Quissac', 43.9134100, 3.9992000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51756, 'Quintin', 'Quintin', 'Kenten,Kintin,Quintin,Quintinum,qu an tan,Кентен,屈安坦', 48.4034200, -2.9105000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51757, 'Quintenas', 'Quintenas', 'Kentena,Quintenas,Quintenàs,qu an te na,Кентена,屈安特纳', 45.1896600, 4.6873200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51758, 'Quinssaines', 'Quinssaines', 'Quins-Sames,Quinssaimes,Quinssaines', 46.3333300, 2.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51759, 'Quinsac', 'Quinsac', 'Quinsac', 44.7553500, -0.4869700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51760, 'Quingey', 'Quingey', 'Kenzhe,Quingey,kan re,Кенже,坎热', 47.1025000, 5.8831200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51761, 'Quincy-Voisins', 'Quincy-Voisins', 'Kensi-Vuazen,Quincy,Quincy-Segy,Quincy-Ségy,Quincy-Voisins,Кенси-Вуазен,Кенсі-Вуазен', 48.9011400, 2.8755900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51762, 'Quincy-sous-Sénart', 'Quincy-sous-Senart', 'Kensi-su-Senar,Quincy,Quincy-sous-Senart,Quincy-sous-Sénart,qu an xi su sai na er,Кенси-су-Сенар,Кенсі-су-Сенар,屈安西苏塞纳尔', 48.6729400, 2.5341900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51763, 'Quincieux', 'Quincieux', 'Quincieux', 45.9103600, 4.7782300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51764, 'Quincié-en-Beaujolais', 'Quincie-en-Beaujolais', 'Quincie,Quincie-en-Beaujolais,Quincié,Quincié-en-Beaujolais', 46.1217800, 4.6234200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51765, 'Quincey', 'Quincey', 'Quincey', 47.6116500, 6.1855600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51766, 'Quincampoix', 'Quincampoix', 'Kenkampua,Quincampoix,Кенкампуа', 49.5271000, 1.1884900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51767, 'Quimperlé', 'Quimperle', 'Kemperle,Quimperle,Quimperlium,Quimperlé,kan pei er lai,kanperure,Кемперле,カンペルレ,坎佩尔莱', 47.8666700, -3.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51768, 'Quimper', 'Quimper', 'Coriosopitum,Kemper,Kempera,Kempēra,Montagne-sur-Odet,Quimper,Tchimper,Tchîmpèr,UIP,kaengpeleu,kambar,kan pei er,kanperu,kmpr,kwympr,Кемпер,كامبار,کمپر,کویمپر,კემპერი,カンペール,坎佩尔,캥페르', 48.0000000, -4.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51769, 'Quilly', 'Quilly', 'Killig,Quilly', 47.4613100, -1.9527400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51770, 'Quillebeuf-sur-Seine', 'Quillebeuf-sur-Seine', 'Quillebeuf,Quillebeuf-sur-Seine', 49.4693400, 0.5279300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51771, 'Quillan', 'Quillan', 'Kijan,Quilhan,Quillan,qu yi lang,Кийан,Киян,Кіян,屈伊朗', 42.8757900, 2.1817600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51772, 'Quiévy', 'Quievy', 'K''evi,Kevi,Quievy,Quiévy,ji ye wei,Кьеви,Кєві,基耶维', 50.1680400, 3.4283400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51773, 'Quiévrechain', 'Quievrechain', 'K''evreshen,Kevreshen,ji ye fu lei shang,Кьеврешен,Кєврешен,基耶夫勒尚', 50.3917200, 3.6681500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51774, 'Quiers-sur-Bézonde', 'Quiers-sur-Bezonde', 'Ke-sjur-Bezond,Quiers,Quiers-sur-Bezonde,Quiers-sur-Bézonde,bei zong de he pan qu ye er,Кє-сюр-Безонд,贝宗德河畔屈耶尔', 47.9961500, 2.4414100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51775, 'Quiberon', 'Quiberon', 'Kiberen,Kiberon,Quiberon,kiburon,qu yi bo long,Киберон,Кіберон,キブロン,屈伊伯龙', 47.4841200, -3.1196300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51776, 'Quévert', 'Quevert', 'Kever,Quevert,Quévert,qu ai wei er,Кевер,屈埃韦尔', 48.4640200, -2.0874500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51777, 'Quéven', 'Queven', 'Kewenn,Queven,Quéven', 47.7833300, -3.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51778, 'Quevauvillers', 'Quevauvillers', 'Quevauvillers', 49.8237600, 2.0843100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51779, 'Quettreville-sur-Sienne', 'Quettreville-sur-Sienne', 'Quettreville,Quettreville-sur-Sienne', 48.9680200, -1.4678200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51780, 'Quettehou', 'Quettehou', 'Kettu,Quettehou,Tchettehou,qu ai tai wu,Кетту,屈埃泰乌', 49.5930800, -1.3035200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51781, 'Quetigny', 'Quetigny', '', 47.3166700, 5.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51782, 'Questembert', 'Questembert', 'Kestamber,Kistreberzh,Questembert,qu ai si tang bei er,Кестамбер,屈埃斯唐贝尔', 47.6629600, -2.4522000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51783, 'Quessoy', 'Quessoy', 'Kesoue,Quessoy', 48.4220800, -2.6608900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51784, 'Quesnoy-sur-Deûle', 'Quesnoy-sur-Deule', 'Kenoe-su-Deule,Kenua-sjur-Dejul'',Kenua-sjur-Djol'',Kiezenet,Kénoé-su-Deule,Le Quesnoy-sur-Deule,Le Quesnoy-sur-Deûle,Quesnoy-sur-Deule,Quesnoy-sur-Deûle,de lei he pan kai nu wa,Кенуа-сюр-Деюль,Кенуа-сюр-Дёль,德勒河畔凯努瓦', 50.7135900, 2.9999600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51785, 'Querrien', 'Querrien', 'Kerien,Kerrijan,Querrien,qu ai er li an,Керриян,Керріян,屈埃尔里安', 47.9666700, -3.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51786, 'Querqueville', 'Querqueville', 'Kerkevil'',Querqueville,qu ai er qu ai wei er,Керкевиль,Керкевіль,屈埃尔屈埃维尔', 49.6625100, -1.6911900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51787, 'Quend', 'Quend', 'Kan,Quend,Quend-le-Jeune,Tchin,kan,kang cun,Кан,カン,康村', 50.3158400, 1.6360900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51788, 'Quemper-Guézennec', 'Quemper-Guezennec', 'Kemper-Gwezhenneg,Quemper-Guezennac,Quemper-Guezennec,Quemper-Guézennac,Quemper-Guézennec', 48.7037800, -3.1052200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51789, 'Quéménéven', 'Quemeneven', 'Kemenevan,Kemeneven,Quemeneven,Quéménéven,kemenevu~an,qu ai mei nei wang,Кеменеван,ケメネヴァン,屈埃梅内旺', 48.1166700, -4.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51790, 'Quelaines-Saint-Gault', 'Quelaines-Saint-Gault', '', 47.9333300, -0.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51791, 'Quédillac', 'Quedillac', 'Kedijak,Kedilieg,Quedillac,Quédillac,qu ai di la ke,Кедияк,Кедіяк,屈埃迪拉克', 48.2490400, -2.1424100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51792, 'Québriac', 'Quebriac', 'Kevrieg,Quebriac,Québriac', 48.3444400, -1.8272300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51793, 'Quarouble', 'Quarouble', 'Quarouble', 50.3863400, 3.6230600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51794, 'Quarante', 'Quarante', 'Quarante', 43.3471100, 2.9622800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51795, 'Quaëdypre', 'Quaedypre', 'Quaedypre,Quaëdypre', 50.9352700, 2.4544500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51796, 'Puyoô', 'Puyoo', 'Pjuioo,Pujou,Pujòu,Puyoo,Puyoô,pi yi ao ao,Пюиоо,Пюїоо,皮伊奥奥', 43.5250200, -0.9128300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51797, 'Puymoyen', 'Puymoyen', 'Pjuimuajan,Pjuimuajen,Puymoyen,pi yi mu wa ang,Пюимуайен,Пюїмуаян,皮伊穆瓦昂', 45.6166700, 0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51798, 'Puyloubier', 'Puyloubier', 'Pjuilub''e,Pjuilube,Pueglobier,Puyloubier,pi yi lu bi ye,Пюилубье,Пюїлубє,皮伊卢比耶', 43.5252200, 5.6765000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51799, 'Puylaurens', 'Puylaurens', 'Puylaurens', 43.5720200, 2.0122700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51800, 'Puy-Guillaume', 'Puy-Guillaume', 'Pjui-Gijom,Pueiguillaume,Puy-Guillaume,Puèiguillaume,pi yi ji luo mu,Пюї-Гійом,皮伊吉洛姆', 45.9598500, 3.4714300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51801, 'Puygouzon', 'Puygouzon', 'Puygouzon-et-Montsalvy', 43.9000000, 2.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51802, 'Puteaux', 'Puteaux', 'Pito,Pjuto,Puteaux,Puteolus,Puteux,pi tuo,pwito,pwtw,pyuto,Пито,Пюто,پوتو,ピュトー,皮托,퓌토', 48.8834100, 2.2389400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51803, 'Pussay', 'Pussay', 'Pjusse,Pussay,pi sai,Пюссе,皮赛', 48.3490800, 1.9918200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51804, 'Pusignan', 'Pusignan', 'Pjuzin''jan,Pusignan,Пюзіньян', 45.7581400, 5.0672400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51805, 'Pusey', 'Pusey', 'Pusey', 47.6524300, 6.1261500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51806, 'Pulversheim', 'Pulversheim', 'Pjul''versajm,pi er wei er sang,Пюльверсайм,皮尔韦尔桑', 47.8375300, 7.3011900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51807, 'Pulnoy', 'Pulnoy', 'Pulnoy', 48.7029200, 6.2579200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51808, 'Pulligny', 'Pulligny', 'Pjullin''i,Pulligny,pi li ni,Пюллиньи,Пюлліньї,皮利尼', 48.5422200, 6.1421900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51809, 'Pujols', 'Pujols', '', 44.3942400, 0.6881000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51810, 'Pujaut', 'Pujaut', 'Pujaut', 44.0040400, 4.7757500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51811, 'Pujaudran', 'Pujaudran', 'Pjuzhodran,Pujaudran,pi ruo de lang,Пюжодран,皮若德朗', 43.5895400, 1.1497700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51812, 'Puisserguier', 'Puisserguier', 'Pjuissergie,Puegserguier,Puisserguier,Puègserguièr,pi yi sai er ji ye,Пюиссергие,Пюїссергіе,皮伊塞尔吉耶', 43.3676700, 3.0404700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51813, 'Puissalicon', 'Puissalicon', 'Pjuissalikon,Pueg-ericon,Puissalicon,Puèg-ericon,pi yi sa li kong,Пюиссаликон,Пюїссалікон,皮伊萨利孔', 43.4582800, 3.2369000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51814, 'Puiseux-en-France', 'Puiseux-en-France', 'Pjuize-an-Frans,Pjuizjo-an-Frans,Puiseux,Puiseux-en-France,Puiseux-les-Louvres,fu lang si de qu pi yi sai,Пюизе-ан-Франс,Пюизё-ан-Франс,Пюїзе-ан-Франс,弗朗斯地区皮伊塞', 49.0555200, 2.5003500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51815, 'Puiseaux', 'Puiseaux', '', 48.0923400, 2.0596700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51816, 'Puilboreau', 'Puilboreau', 'Pjuijboro,Pjuil''boro,Puilboreau,Pyuilboro,pi yi er bo luo,Пюильборо,Пюійборо,Պյուիլբորո,皮伊尔博罗', 46.1862000, -1.1179700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51817, 'Puicheric', 'Puicheric', 'Puicheric,Puicheric-d''Aude,Puicheric-d’Aude,Puicherie-d''Aude,Puicherie-d’Aude', 43.2238000, 2.6245500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51818, 'Pugnac', 'Pugnac', 'Pjun''jak,Pugnac,pi ni ya ke,Пюньяк,皮尼亚克', 45.0819000, -0.4961800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51819, 'Puget-Ville', 'Puget-Ville', 'Lo Puget de Cuer,Pjuzhe-Vil'',Puget,Puget Vila,Puget-Ville,pi re wei er,Пюже-Виль,Пюже-Віль,皮热维尔', 43.2894400, 6.1361200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51820, 'Puget-Théniers', 'Puget-Theniers', 'Lo Puget Tenier,Lo Puget de Tenier,Pjuzhe-Ten''e,Podium Thenarium,Puget-Theniers,Puget-Théniers,bwjyt thynyrs,pi re tai nie er,Пюже-Тенье,Пюже-Теньє,بوجيت ثينيرس,皮热泰涅尔', 43.9546400, 6.8911500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51821, 'Puget-sur-Argens', 'Puget-sur-Argens', 'Le Puget,Le Puget-sur-Argens,Lo Puget dArgenc,Lo Puget dArgenç,Lo Puget de Frejus,Lo Puget de Frejús,Pjuzhe-sjur-Arzhan,Puget,a er gang he pan pi re,Пюже-сюр-Аржан,阿尔冈河畔皮热', 43.4500000, 6.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51822, 'Publier', 'Publier', 'Pjubl''e,Populetum,Publier - Amphion-les-Bains,Пюбльє', 46.3877300, 6.5435600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51823, 'Pruniers-en-Sologne', 'Pruniers-en-Sologne', 'Prjun''e-an-Solon'',suo luo ni de qu pu lu nie er,Прюньє-ан-Солонь,索洛尼地区普吕涅尔', 47.3166700, 1.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51824, 'Prunelli-di-Fiumorbo', 'Prunelli-di-Fiumorbo', 'I Pruneddi di Fiumorbu,Prunelli,Prunelli di Fiumorbo,Prunelli-di-F''jumorbo,Prunelli-di-Fiumerbo,Prunelli-di-Fiumorbo,Прунелли-ди-Фьюморбо,Прунеллі-ді-Фьюморбо', 42.0104700, 9.3247300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51825, 'Pruillé-le-Chétif', 'Pruille-le-Chetif', 'Pruille,Pruillé', 47.9938300, 0.1067700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51826, 'Provins', 'Provins', 'Byen Provins,Provehn,Proven,Provins,Pruvinum,XPS,peulobaeng,pu luo wan,purovu~an,Προβέν,Провен,Провэн,พรอแว็ง,ປະໂລແວງ,პროვენი,プロヴァン,普罗万,프로뱅', 48.5500000, 3.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51827, 'Provin', 'Provin', '', 50.5143000, 2.9079400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51828, 'Proville', 'Proville', 'Provil'',Proville,pu luo wei er,Провиль,Провіль,普罗维尔', 50.1613700, 3.2062900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51829, 'Prouvy', 'Prouvy', 'Prouvy', 50.3179300, 3.4509600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51830, 'Propriano', 'Propriano', 'PRP,Propriano,Prupia,Prupià,puropuriano,Проприано,Пропріано,プロプリアノ', 41.6752500, 8.9030200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51831, 'Priziac', 'Priziac', 'Brisiacum,Priz''jak,Priziac,Prizieg,pu li qi a ke,Призьяк,普里齐阿克', 48.0666700, -3.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51832, 'Prix-lès-Mézières', 'Prix-les-Mezieres', 'Prix,Prix-les-Mezieres,Prix-lès-Mézières', 49.7554900, 4.6911300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51833, 'Privas', 'Privas', 'Priva,Privas,Privatum,Privàs,peuliba,pu li wa,purivu~a,Прива,プリヴァ,普里瓦,프리바', 44.7333300, 4.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51834, 'Prissé', 'Prisse', 'Prisse,Prissé', 46.3213000, 4.7446900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51835, 'Prinquiau', 'Prinquiau', 'Prenkjo,Prevenkel,Prinquiau,pu lan qu yi ao,Пренкйо,普兰屈伊奥', 47.3621500, -2.0095200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51836, 'Pringy', 'Pringy', 'Pringy', 48.5181500, 2.5633300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51837, 'Pringy', 'Pringy', 'Pringy', 45.9462200, 6.1260800, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51838, 'Prigonrieux', 'Prigonrieux', 'Prigond Riu,Prigond-riu,Prigonr''e,Prigonre,Prigonrieux,Prigonrijo,pu li gong li e,Пригонриё,Пригонрье,Пригонрє,普里贡里厄', 44.8545100, 0.4027500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51839, 'Priay', 'Priay', 'Priay', 46.0018800, 5.2877500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51840, 'Preuilly-sur-Claise', 'Preuilly-sur-Claise', 'Prei-sjur-Klez,Preuilly,Preuilly-sur-Claise,ke lai si he pan pu lei yi li,Преї-сюр-Клез,克莱斯河畔普勒伊利', 46.8542400, 0.9295400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51841, 'Précieux', 'Precieux', 'Precieux', 45.5833300, 4.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51842, 'Presles-en-Brie', 'Presles-en-Brie', 'Prel''-an-Bri,Presles,Presles-en-Brie,Прель-ан-Бри,Прель-ан-Брі', 48.7152700, 2.7411200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51843, 'Préseau', 'Preseau', 'Perziau,Preseau,Prezo,Préseau,Pérziau,pu lei zuo,Презо,普雷佐', 50.3112200, 3.5743400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51844, 'Prémilhat', 'Premilhat', 'Premilhat,Prémilhat', 46.3166700, 2.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51845, 'Prémesques', 'Premesques', 'Premesk,Premesques,Prémesques,pu lei mei ke,Премеск,普雷梅克', 50.6557200, 2.9516200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51846, 'Prémery', 'Premery', 'Premery,Prémery', 47.1695200, 3.3274300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51847, 'Preignan', 'Preignan', 'Preignan', 43.7117700, 0.6260800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51848, 'Preignac', 'Preignac', 'Preignac,Pren''jak,Prenhac,pu lei ni ya ke,Преньяк,普雷尼亚克', 44.5843800, -0.2942300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51849, 'Préfailles', 'Prefailles', 'Pradvael,Prefaille,Prefailles,Prefaj,Préfaille,Préfailles,pu lei fei lai,purefaiyu,Префай,プレファイユ,普雷费莱', 47.1283900, -2.2169300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51850, 'Pré-en-Pail', 'Pre-en-Pail', 'Pre-an-Paj,pu lei ang pa yi,Пре-ан-Пай,普雷昂帕伊', 48.4599300, -0.1981400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51851, 'Précy-sur-Oise', 'Precy-sur-Oise', 'Precy,Precy-sur-Oise,Presi-sjur-Uaz,Précy,Précy-sur-Oise,wa si he pan pu lei xi,Пресі-сюр-Уаз,瓦斯河畔普雷西', 49.2077900, 2.3726600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51852, 'Précigné', 'Precigne', 'Precigne,Presin''e,Précigné,Пресіньє', 47.7669200, -0.3249100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51853, 'Préchac', 'Prechac', 'Prechac,Préchac', 44.3988300, -0.3538700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51854, 'Préaux', 'Preaux', 'Preaux,Préaux', 49.4913600, 1.2158300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51855, 'Praz-sur-Arly', 'Praz-sur-Arly', 'Pra-sjur-Arli,Prata de Megevia,Praz,Praz-sur-Arly,le Praz,Пра-сюр-Арлі', 45.8366100, 6.5732000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51856, 'Prayssac', 'Prayssac', 'Prayssac', 44.5044000, 1.1886200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51857, 'Prats de Molló', 'Prats de Mollo', 'Prats de Mollo,Prats de Molló,Prats-de-Mollo', 42.4040400, 2.4792800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51858, 'Prat', 'Prat', 'Prad,Prat', 48.6767700, -3.2970700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51859, 'Prahecq', 'Prahecq', 'Prahecq', 46.2589700, -0.3442500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51860, 'Pradines', 'Pradines', 'Pradines', 44.4834100, 1.4010500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51861, 'Prades-le-Lez', 'Prades-le-Lez', 'Prad-le-Lez,Pradas de Les,Prades,Prades-le-Lez,pu la dai lai lai,Прад-ле-Лез,普拉代莱莱', 43.6975400, 3.8646300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51862, 'Prades', 'Prades', 'Prada,Prada de Conflent,Prades', 42.6166700, 2.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51863, 'Pouzauges', 'Pouzauges', 'Pouzauges,Pouzauges-la-Montagne,Pouzauges-la-Vallee,Pouzauges-la-Vallée,Pouzauiges,Puzozh,pu zuo re,Пузож,普佐热', 46.7794100, -0.8361900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51864, 'Pouzac', 'Pouzac', 'Posac,Pouzac,Puzak,pu zha ke,Пузак,普扎克', 43.0860600, 0.1352200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51865, 'Pouxeux', 'Pouxeux', 'Pouxeux', 48.1062100, 6.5729900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51866, 'Poussan', 'Poussan', 'Pocan,Poussan,Poçan,Pussan,pu sang,Пуссан,普桑', 43.4894400, 3.6708300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51867, 'Pouru-Saint-Remy', 'Pouru-Saint-Remy', 'Pouru-sur-Chiers', 49.6833300, 5.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51868, 'Pourrières', 'Pourrieres', 'Porrieras,Porrièras,Pur''er,Purrier,pu er li ai,Пуррієр,Пурьер,普尔里埃', 43.5061100, 5.7345200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51869, 'Pourrain', 'Pourrain', 'Pourrain', 47.7561500, 3.4119300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51870, 'Poulx', 'Poulx', 'Poulx,Pous,Pul'',pu er,Пуль,普尔', 43.9079800, 4.4162900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51871, 'Poullaouen', 'Poullaouen', 'Poullaouen,Pullauan,pu luo ang,Пуллауан,普洛昂', 48.3333300, -3.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51872, 'Poullan-sur-Mer', 'Poullan-sur-Mer', 'Poullan,Poullan-sur-Mer,Poullann,Pullan-sjur-Mer,bin hai pu lang,puran=shuru=meru,Пуллан-сюр-Мер,プラン＝シュル＝メール,滨海普朗', 48.0833300, -4.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51873, 'Pouligny-Saint-Pierre', 'Pouligny-Saint-Pierre', 'Pouligny,Pouligny-Saint-Pierre,Pulin''i-Sen-P''er,Pulin''i-Sen-Perr,pu li ni sheng pi ye er,Пулиньи-Сен-Пьер,Пуліньї-Сен-Пєрр,普利尼圣皮耶尔', 46.6809500, 1.0387700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51874, 'Pouldreuzic', 'Pouldreuzic', 'Pouldreuzic,Pouldreuzig,Pul''drezik,pu er de lei qi ke,Пульдрезик,Пульдрезік,普尔德勒齐克', 47.9500000, -4.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51875, 'Pouldergat', 'Pouldergat', 'Pouldergat,Pouldregad,Pul''derga,pu er dai er jia,Пульдерга,普尔代尔加', 48.0500000, -4.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51876, 'Poulainville', 'Poulainville', 'Poulainville', 49.9474500, 2.3137300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51877, 'Pouilly-sur-Loire', 'Pouilly-sur-Loire', 'Pouilly,Pouilly-sur-Loire,Pui-sjur-Luar,lu wa er he pan pu yi,pui~i=shuru=rowaru,Пуи-сюр-Луар,Пуї-сюр-Луар,プイィ＝シュル＝ロワール,卢瓦尔河畔普伊', 47.2837700, 2.9544200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51878, 'Pouilly-sous-Charlieu', 'Pouilly-sous-Charlieu', 'Pouilly,Pouilly-sous-Charlieu', 46.1456600, 4.1089000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51879, 'Pouilly-les-Nonains', 'Pouilly-les-Nonains', 'Pouilly,Pouilly-les-Nonains', 46.0382000, 3.9819800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51880, 'Pouilly-lès-Feurs', 'Pouilly-les-Feurs', 'Pouilly', 45.8000000, 4.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51881, 'Pouilly-en-Auxois', 'Pouilly-en-Auxois', 'Pouilly,Pouilly-en-Auxois', 47.2623800, 4.5558300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51882, 'Pouillon', 'Pouillon', 'Pouillon', 43.6048000, -0.9994700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51883, 'Pouilley-les-Vignes', 'Pouilley-les-Vignes', 'Pouilley,Pouilley-les-Vignes,Pue-le-Vin'',pu yi lai lai wei gai,Пує-ле-Вінь,普伊莱莱维盖', 47.2577000, 5.9358100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51884, 'Pougues-les-Eaux', 'Pougues-les-Eaux', 'Pougues,Pougues-les-Eaux', 47.0751800, 3.1015000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51885, 'Pouancé', 'Pouance', 'Pouance,Pouancé,Puanse,pu ang sai,Пуансе,普昂塞', 47.7416700, -1.1736600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51886, 'Potigny', 'Potigny', 'Potigny', 48.9692500, -0.2416600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51887, 'Poses', 'Poses', 'Poses', 49.3053900, 1.2435300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51888, 'Portvendres', 'Portvendres', 'Port-Vendres,Port-de-la-Victoire,Portvendres', 42.5179200, 3.1055300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51889, 'Port-sur-Saône', 'Port-sur-Saone', 'Port-sur-Saone,Port-sur-Saône', 47.6877400, 6.0501100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51890, 'Port-Saint-Père', 'Port-Saint-Pere', 'Por-Sen-Per,Port-Boulay,Port-Saint-Pere,Port-Saint-Père,Portus Sancti Petri,Porzh-Per,Porzh-Pêr,poru=san=peru,sheng pei er gang,Пор-Сен-Пер,ポール＝サン＝ペール,圣佩尔港', 47.1329400, -1.7485000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51891, 'Port-Saint-Louis-du-Rhône', 'Port-Saint-Louis-du-Rhone', 'Lo Port dArle,Lo Pòrt dArle,Por-Sen-Lui-dju-Ron,Port Sant Lois,Port-Saint-Louis,Port-Saint-Louis-du-Rhone,Port-Saint-Louis-du-Rhône,Pòrt Sant Loís,Saint Louis,Saint-Louis-du-Rhone,Saint-Louis-du-Rhône,sheng lu yi si-di long gang,Пор-Сен-Луи-дю-Рон,Пор-Сен-Луї-дю-Рон,圣卢伊斯-迪龙港', 43.3873400, 4.8260900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51892, 'Port-Sainte-Marie', 'Port-Sainte-Marie', 'Port-Sainte-Marie,Port-de-la-Montagne-sur-Garonne', 44.2515800, 0.3913400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51893, 'Port-Sainte-Foy-et-Ponchapt', 'Port-Sainte-Foy-et-Ponchapt', 'Lo Port de Senta Fe e Ponchac,Lo Pòrt de Senta Fe e Ponchac,Por-Sent-Fua-e-Ponshap,Por-Sent-Fua-eh-Ponshap,Port-Sainte Foy,Port-Sainte-Foy-et-Ponchapt,Sent Avit de Tisac,bo er te-sheng fu wa he peng sha pu,poru=santo=fowa=e=ponsha,Пор-Сент-Фуа-е-Поншап,Пор-Сент-Фуа-э-Поншап,ポール＝サント＝フォワ＝エ＝ポンシャ,波尔特-圣富瓦和蓬沙普', 44.8333300, 0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51894, 'Porto-Vecchio', 'Porto-Vecchio', 'Portivechju,Porto Vecchio,Porto-Vecchio,Porto-Vekk''o,Portus Syracusanus,poruto=vu~ekkio,wei ji ao gang,Порто-Веккьо,ポルト＝ヴェッキオ,韦基奥港', 41.5910100, 9.2794700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51895, 'Port-Louis', 'Port-Louis', 'Port-Liberte,Port-Liberté,Port-Louis,Port-de-l''Egalite,Port-de-l''Egalité,Porzh-Loeiz', 47.7070400, -3.3548400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51896, 'Port-la-Nouvelle', 'Port-la-Nouvelle', 'La Nouvelle,La Novela,La Novella,La Novèla,Por-la-Nuvel'',Port-la-Nouvelle,bo er la nu wei er,Пор-ла-Нувель,波尔拉努韦尔', 43.0199100, 3.0436600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51897, 'Portiragnes', 'Portiragnes', 'Portiragnes,Portiran'',Portiranhas,bo er di la gai,Портирань,Портірань,波尔蒂拉盖', 43.3046000, 3.3336500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51898, 'Portieux', 'Portieux', 'Port''e,Portieux,bo er di e,Портье,Портьє,波尔蒂厄', 48.3446600, 6.3446500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51899, 'Portet-sur-Garonne', 'Portet-sur-Garonne', 'Porte-sjur-Garon,Porte-sjur-Garonn,Portet,Portet sobre Garona,Portet-sur-Garonne,Porteth de Garona,Portèth de Garona,jia long he pan bo tai,Порте-сюр-Гарон,Порте-сюр-Гаронн,加龙河畔波泰', 43.5233300, 1.4065100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51900, 'Portets', 'Portets', 'Porteth,Porteths,Portets,Portèth,Portèths,bo er tai te,Портетс,波尔泰特', 44.6967900, -0.4245200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51901, 'Portes-lès-Valence', 'Portes-les-Valence', 'Fiancac,Fiançac,Port-le-Valans,Portas,Portes,Portes-les-Valence,Portes-lès-Valence,Pòrtas,bo er tai lai wa lang ke,Порт-ле-Валанс,波尔泰莱瓦朗克', 44.8737000, 4.8810000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51902, 'Port-en-Bessin-Huppain', 'Port-en-Bessin-Huppain', 'Por-an-Bessen-Juppen,Port,Port-en-Bessin,Port-en-Bessin-Huppain,bei sang yu pan gang,Пор-ан-Бессен-Юппен,贝桑于潘港', 49.3446000, -0.7555700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51903, 'Portel-des-Corbières', 'Portel-des-Corbieres', '', 43.0500000, 2.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51904, 'Port-de-Bouc', 'Port-de-Bouc', 'Lo Port de Boc,Lo Pòrt de Boc,Por-de-Buk,Port-de-Boue,bo er de bu ke,Пор-де-Бук,波尔德布克', 43.4065700, 4.9809000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51905, 'Port-Brillet', 'Port-Brillet', 'Por-Brie,Port-Brillet,bo er bu li lai,Пор-Бріє,波尔布里莱', 48.1131500, -0.9708000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51906, 'Portbail', 'Portbail', 'Porbaj,Portbail,bo er te bai,Порбай,波尔特拜', 49.3357100, -1.6956000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51907, 'Porspoder', 'Porspoder', 'Porspode,Porspoder,bo er si bo dai,Порсподе,波尔斯波代', 48.5000000, -4.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51908, 'Pornichet', 'Pornichet', 'Pornichet,Pornishe,Pornizhan,bo er ni xie,Порніше,波尔尼谢', 47.2668200, -2.3379400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51909, 'Pornic', 'Pornic', 'Pornic,Pornik,Pornizh,Porsnitus,Roche-Peltier,bo er ni ke,porunikku,Порнік,ポルニック,波尔尼克', 47.1120500, -2.0888800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51910, 'Pordic', 'Pordic', 'Pordic,Pordik,Porzhig,bo er di ke,Пордик,Пордік,波尔迪克', 48.5705100, -2.8178300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51911, 'Porcieu-Amblagnieu', 'Porcieu-Amblagnieu', 'Amblagnieu,Porcieu-Amblagnieu,Porcieux', 45.8344300, 5.4021800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51912, 'Porcheville', 'Porcheville', 'Porcheville,Porshvil'',Поршвиль,Поршвіль', 48.9725400, 1.7797300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51913, 'Porcelette', 'Porcelette', 'Porcelette,Porselett,bo er se lai te,Порселетт,波尔瑟莱特', 49.1553800, 6.6581000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51914, 'Pontvallain', 'Pontvallain', 'Pontvallain,Ponvallen,Ponvallenum,Понваллен', 47.7516900, 0.1914500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51915, 'Pont-sur-Yonne', 'Pont-sur-Yonne', 'Pon-sjur-Ionn,Pont,Pont-sur-Yonne,yue ne he pan peng,Пон-сюр-Іонн,Пон-сюр-Ионн,约讷河畔蓬', 48.2829700, 3.2019800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51916, 'Pont-sur-Sambre', 'Pont-sur-Sambre', 'Pon-sjur-Sambr,Pont,Pont-sur-Sambre,sang bu er he qiao cun,Пон-сюр-Самбр,桑布尔河桥村', 50.2219500, 3.8469300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51917, 'Pont-Scorff', 'Pont-Scorff', 'Pon-Skorff,Pons Scorvi,Pont-Scorff,Pont-Skorf,peng si ke er,Пон-Скорфф,蓬斯科尔', 47.8334300, -3.4025100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51918, 'Pont-Salomon', 'Pont-Salomon', 'Pont-Salomon', 45.3392400, 4.2481000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51919, 'Pont-Saint-Vincent', 'Pont-Saint-Vincent', 'Pon-Sen-Vensan,Pont-Saint-Vincent,Pont-la-Montagne,peng sheng wan sang,Пон-Сен-Венсан,蓬圣万桑', 48.6029800, 6.0994200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51920, 'Pont-Saint-Pierre', 'Pont-Saint-Pierre', 'Pont-Saint-Pierre', 49.3356100, 1.2760100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51921, 'Pont-Saint-Martin', 'Pont-Saint-Martin', 'Pont-Saint-Martin', 47.1233800, -1.5845500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51922, 'Pont-Saint-Esprit', 'Pont-Saint-Esprit', 'Lo Pont Sant Esperit,Lo Pont de Sent Esperit,Lo Pònt Sant Esperit,Lo Pònt de Sent Esperit,Pon-Sent-Ehspri,Pon-Sent-Espri,Pont-Saint-Esprit,Pont-sur-Rhone,Pont-sur-Rhône,peng sheng ai si pu li,pon=san=tesupuri,Пон-Сент-Еспри,Пон-Сент-Еспрі,Пон-Сент-Эспри,ポン＝サン＝テスプリ,蓬圣埃斯普里', 44.2549400, 4.6473600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51923, 'Pont-Sainte-Maxence', 'Pont-Sainte-Maxence', 'Pon-Sent-Maksans,Pont,Pont-Sainte-Maxence,Pont-la-Montagne,Pont-sur-Oise,peng sheng ma ke sang ke,Пон-Сент-Максанс,蓬圣马克桑克', 49.3016800, 2.6046700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51924, 'Pont-Sainte-Marie', 'Pont-Sainte-Marie', 'Pont,Pont-Sainte-Marie', 48.3184800, 4.0944700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51925, 'Pontrieux', 'Pontrieux', 'Pontrev,Pontrieux', 48.7011100, -3.1596700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51926, 'Pont-Remy', 'Pont-Remy', '', 50.0500000, 1.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51927, 'Pontpoint', 'Pontpoint', 'Ponpuen,Pontpoint,peng te pu an,Понпуен,蓬特普安', 49.3000000, 2.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51928, 'Pontorson', 'Pontorson', 'Ardevoun,Ardévoun,Pontorson,peng tuo er song,Ποντορσόν,Понторсон,蓬托尔松', 48.5531600, -1.5075400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51929, 'Pontoise', 'Pontoise', 'POX,Pontisara,Pontoaz,Pontoise,Pontuaz,peng tu wa ci,pngtws,pongtuajeu,pontowazu,pwntwaz,Понтоаз,Понтуаз,پونتوآز,ปงตวซ,ポントワーズ,蓬图瓦兹,퐁투아즈', 49.0500000, 2.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51930, 'Pontlevoy', 'Pontlevoy', 'Ponlevua,Pontlevoy,peng te lei wa,Понлевуа,蓬特勒瓦', 47.3900200, 1.2546500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51931, 'Pontivy', 'Pontivy', 'Pondi,Pondivi,Pontivi,Pontivium,Pontivy,peng di wei,pontivu~i,Понтиви,Понтіві,ポンティヴィ,蓬蒂维', 48.0666700, -2.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51932, 'Ponthierry', 'Ponthierry', '', 48.5336600, 2.5441900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51933, 'Pont-Hébert', 'Pont-Hebert', 'Pont-Hebert,Pont-Hébert', 49.1671400, -1.1342800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51934, 'Pontfaverger-Moronvilliers', 'Pontfaverger-Moronvilliers', 'Ponfaverzhe-Moronvil''e,Pontfaverger,Pontfaverger-Moronvilliers,peng te fa wei er re mo long wei li ye er,Понфаверже-Моронвільє,蓬特法韦尔热莫龙维利耶尔', 49.2970200, 4.3165700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51935, 'Pont-Évêque', 'Pont-Eveque', 'Pont-Eveque,Pont-Évêque', 45.5269100, 4.9143200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51936, 'Pontenx-les-Forges', 'Pontenx-les-Forges', 'Pontenx,Pontenx-les-Forges', 44.2413400, -1.1209500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51937, 'Pont-en-Royans', 'Pont-en-Royans', 'Lo Pont de Santa Eulalia,Pon-an-Ruajan,Pont,Pont-an-Ruajan,Pont-en-Royans,Pont-sur-Bourne,lu wa ang de qu peng,Пон-ан-Руаян,Понт-ан-Руайан,鲁瓦昂地区蓬', 45.0636100, 5.3413600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51938, 'Ponteilla', 'Ponteilla', 'Ponteilla,Pontella,Pontellà', 42.6259400, 2.8133500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51939, 'Pont-Écrepin', 'Pont-Ecrepin', '', 48.7642500, -0.2445500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51940, 'Pont-du-Château', 'Pont-du-Chateau', 'Pon-dju-Shato,Pont dau Chastel,Pont dau Chastèl,Pont-du-Chateau,Pont-du-Château,Pont-sur-Allier,peng di sha tuo,pon=de~yu=shato,Пон-дю-Шато,ポン＝デュ＝シャトー,蓬迪沙托', 45.8007800, 3.2500800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51941, 'Pont-du-Casse', 'Pont-du-Casse', 'Lo Pont del Casso,Pon-dju-Kass,Pont del Casso,Pont-du-Casse,peng di ka si,Пон-дю-Касс,蓬迪卡斯', 44.2286700, 0.6792400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51942, 'Pont-de-Veyle', 'Pont-de-Veyle', 'Pon de Vel,Pon-de-Vejl'',Pon-de-Vel'',Pont,Pont-de-Veyle,bwn-dw-fy,peng de wei er,Пон-де-Вейль,Пон-де-Вель,Պոն դե Վել,بون-دو-في,蓬德韦尔', 46.2624800, 4.8871700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51943, 'Pont-de-Vaux', 'Pont-de-Vaux', 'Pont,Pont-de-Vaux', 46.4317100, 4.9401200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51944, 'Pont-de-Salars', 'Pont-de-Salars', 'Le Pont-de-Salars,Lo Pont de Salars,Lo Pònt de Salars,Pon-de-Salar,Pont-de-Salars,peng de sa la er,Пон-де-Салар,蓬德萨拉尔', 44.2808000, 2.7278300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51945, 'Pont-de-Roide', 'Pont-de-Roide', 'Pon-de-Ruad,Pont-de-Roide,Pont-de-Roide-Vermondans,peng de lu wa de,Пон-де-Руад,蓬德鲁瓦德', 47.3873800, 6.7684000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51946, 'Pont-de-Metz', 'Pont-de-Metz', 'Pont-de-Metz', 49.8782000, 2.2426600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51947, 'Pont-de-Larn', 'Pont-de-Larn', 'Pont-de-Larn', 43.5041200, 2.4078600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51948, 'Pont-de-Chéruy', 'Pont-de-Cheruy', 'Pon-de-Sherjui,Pont-de-Cheruy,Pont-de-Chéruy,peng de xie lu yi,pwndwshrwy,Пон-де-Шерюи,Пон-де-Шерюї,پوندوشروی,蓬德谢吕伊', 45.7516600, 5.1848800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51949, 'Pontchâteau', 'Pontchateau', 'Pons Castelli,Ponshato,Pontchateau,Pontchâteau,Pontkastell-Keren,peng te sha tuo,Поншато,蓬特沙托', 47.4379700, -2.0901100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51950, 'Pontcharra-sur-Turdine', 'Pontcharra-sur-Turdine', 'Ponsharra-sjur-Tjurdin,Pontcharra,Pontcharra-sur Tardine,Pontcharra-sur-Turdine,Поншарра-сюр-Тюрдін', 45.8774000, 4.4899300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51951, 'Pontcharra', 'Pontcharra', 'Ponsharra,Pont-Charra,Pont-Charrâ,Pontcharra,Pontcharra vald,Pontcharra-sur-Breda,Pontcharra-sur-Bréda,peng te sha er la,Поншарра,蓬特沙尔拉', 45.4329000, 6.0142400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51952, 'Pontcarré', 'Pontcarre', 'Ponkarre,Pontcarre,Pontcarré,Понкарре', 48.7977200, 2.7050800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51953, 'Pont-à-Vendin', 'Pont-a-Vendin', 'Pont-a-Vanden,Pont-a-Vendin,Pont-à-Vendin,bwnt afyndyn,peng ta wang dan,Понт-а-Ванден,بونت أفيندين,蓬塔旺丹', 50.4735800, 2.8888400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51954, 'Pont-Aven', 'Pont-Aven', 'Aveni pons,Pon-Avan,Pont-Aven,a wang qiao,pon=tavu~an,pongtaben,pwn-awan,Пон-Аван,Понт-Авен,פונט אוון,پون-آوان,ポン＝タヴァン,阿旺桥,퐁타벤', 47.8500000, -3.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51955, 'Pont-Audemer', 'Pont-Audemer', 'Pont Audemer,Pont-Audemer,Pont-Odeme,peng ao dai mei,Понт-Одеме,蓬奥代梅', 49.3500000, 0.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51956, 'Pontarlier', 'Pontarlier', 'Pontarl''e,Pontarlier,peng ta er li ye,pontarurie,pwntralyh,Понтарлье,Понтарльє,پونترالیه,ポンタルリエ,蓬塔尔利耶', 46.9034700, 6.3554200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51957, 'Pont-à-Mousson', 'Pont-a-Mousson', 'Mussipons,Pont-a-Mousson,Pont-a-Musson,Pont-à-Mousson,peng a mu song,ponta=musson,Понт-а-Муссон,ポンタ＝ムッソン,蓬阿穆松', 48.9078600, 6.0589000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51958, 'Pont-à-Marcq', 'Pont-a-Marcq', 'Pont-a-Marck,Pont-a-Marcq,Pont-a-Marq,Pont-à-Marcq,Pont-à-Marq', 50.5221300, 3.1144100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51959, 'Pontailler-sur-Saône', 'Pontailler-sur-Saone', 'Pontailler,Pontailler-sur-Saone,Pontailler-sur-Saône', 47.3045500, 5.4147900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51960, 'Pontacq', 'Pontacq', 'Pontac,Pontacq,Pontak,peng ta,Понтак,蓬塔', 43.1833300, -0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51961, 'Pons', 'Pons', 'Pons', 45.5798800, -0.5478300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51962, 'Poncin', 'Poncin', 'Poncin', 46.0838400, 5.4096600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51963, 'Ponchon', 'Ponchon', 'Ponchon', 49.3465200, 2.1967700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51964, 'Pomponne', 'Pomponne', 'Pomponne', 48.8813000, 2.6823200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51965, 'Pompignan', 'Pompignan', 'Pompignan,Pompignan-Montagne', 43.8176800, 1.3120900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51966, 'Pompignac', 'Pompignac', 'Pompignac,Pompin''jak,Pompinhac,peng pi ni ya ke,Помпиньяк,Помпіньяк,蓬皮尼亚克', 44.8511400, -0.4370500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51967, 'Pompey', 'Pompey', 'Pompey', 48.7665300, 6.1216200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51968, 'Pompertuzat', 'Pompertuzat', 'Pompertjuzat,Pompertusat,Pompertuzat,Pontpertusat,peng pei er di zha,Помпертюзат,蓬佩尔蒂扎', 43.4927700, 1.5153100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51969, 'Pompaire', 'Pompaire', 'Pompaire', 46.6072700, -0.2323700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51970, 'Pommiers', 'Pommiers', 'Pommiers', 45.9559400, 4.6935300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51971, 'Pommeuse', 'Pommeuse', 'Pommeuse,Pommez,bo mo si,Поммез,波默斯', 48.8166700, 3.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51972, 'Pommerit-le-Vicomte', 'Pommerit-le-Vicomte', 'Panvrid-ar-Beskont,Pañvrid-ar-Beskont,Pomaretum Vicecomitis,Pommeri-le-Vikont,Pommerit,Pommerit-le-Vicomte,Pommerit-les-Bois,Pomrit-le-Vikont,bo mo li lai wei kong te,Поммери-ле-Виконт,Поммері-ле-Віконт,Помрит-ле-Виконт,波默里莱维孔特', 48.6198900, -3.0900000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51973, 'Pommerit-Jaudy', 'Pommerit-Jaudy', 'Peurid-ar-Roc''h,Peurid-ar-Roch,Pommeri-Zhodi,Pommerit,Pommerit-Jaudy,Pomrit-Zhodi,bo mo li ruo di,Поммери-Жоди,Поммері-Жоді,Помрит-Жоди,波默里若迪', 48.7305800, -3.2420800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51974, 'Pommeret', 'Pommeret', 'Peunvrid,Peuñvrid,Pommeret', 48.4637800, -2.6268900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51975, 'Pomérols', 'Pomerols', 'Pomeirous,Pomeiròus,Pomerol'',Pomerols,Pomérols,bo mei luo er,Помероль,波梅罗尔', 43.3913900, 3.4994400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51976, 'Pomarez', 'Pomarez', 'Pomares,Pomarez,Pomarés,bo ma lei,Помарез,波马雷', 43.6297100, -0.8293400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51977, 'Polminhac', 'Polminhac', 'Polminhac', 44.9522300, 2.5784600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51978, 'Pollionnay', 'Pollionnay', 'Pol''jonne,Pollionnay,Польйонне', 45.7647300, 4.6609900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51979, 'Polliat', 'Polliat', 'Polliat', 46.2484900, 5.1265800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51980, 'Pollestres', 'Pollestres', 'Pollestres', 42.6420000, 2.8711600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51981, 'Poligny', 'Poligny', 'Poligny', 46.8371200, 5.7050500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51982, 'Polignac', 'Polignac', 'Mont-Danise,Polignac,Polinhac', 45.0709000, 3.8603100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51983, 'Poix-du-Nord', 'Poix-du-Nord', 'Poix,Poix-du-Nord', 50.1892700, 3.6095600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51984, 'Poix-de-Picardie', 'Poix-de-Picardie', '', 49.7833300, 1.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51985, 'Poitiers', 'Poitiers', 'Gorad Puac''e,PIS,Peitieus,Pictavium,Piteus,Poatie,Poatje,Poitiers,Pouatie,Pouetiers,Pouètiérs,Puat''e,Puatie,Puatje,Puatjē,Puatjė,bwatyyh,paw tiye,po''iti,powachie,pu wa jie,puatie,pwatyh,Πουατιέ,Горад Пуацье,Поатие,Поатје,Пуатье,Пуатьє,Պուատիե,פואטייה,بواتييه,پوئیٹیرز,پواتیه,पॉइती,ปัวตีเย,პუატიე,ポワチエ,普瓦捷,푸아티에', 46.5833300, 0.3333300, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51986, 'Poisy', 'Poisy', 'Poisy,Posiacum,Puazi,Пуазі', 45.9230500, 6.0643500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51987, 'Poissy', 'Poissy', 'Pinciacum,Poasi,Poissy,Puassi,powashi,pu wa xi,puasi,pwasy,Поаси,Пуасси,Пуассі,پوآسی,ポワシー,普瓦西,푸아시', 48.9290200, 2.0495200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51988, 'Poisat', 'Poisat', 'Poisat', 45.1586300, 5.7618800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51989, 'Poilly-lez-Gien', 'Poilly-lez-Gien', 'Poilly,Poilly-lez-Gien,Puai-lez-Zhian,pu wa li lai ran,Пуаї-лез-Жіан,普瓦利莱然', 47.6772400, 2.5974300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51990, 'Poey-de-Lescar', 'Poey-de-Lescar', 'Poe-de-Leskar,Poeh-de-Leskar,Poey,Poey-de-Lescar,Puei de Lescar,bo ai de lai si ka,Пое-де-Лескар,Поэ-де-Лескар,波埃德莱斯卡', 43.3500000, -0.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51991, 'Podensac', 'Podensac', 'Podansak,Podencac,Podensac,Podençac,bo dang sa ke,Подансак,波当萨克', 44.6503800, -0.3550800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51992, 'Pocé-sur-Cisse', 'Poce-sur-Cisse', 'Poce,Poce-sur-Cisse,Pocé,Pocé-sur-Cisse,Pose-sjur-Siss,xi si he pan bo sai,Посе-сюр-Сісс,西斯河畔波塞', 47.4433000, 0.9914200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51993, 'Pocé-les-Bois', 'Poce-les-Bois', 'Poce,Poce-les-Bois,Pocé,Pocé-les-Bois,Pozieg', 48.1162600, -1.2516800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51994, 'Pluzunet', 'Pluzunet', 'Pluned,Pluzunet,Plûned', 48.6407600, -3.3711300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51995, 'Pluvigner', 'Pluvigner', 'Pleuwigner,Pljuvin''e,Pluvigner,pu lu wei gai,Плювинье,Плювіньє,普吕维盖', 47.7762700, -3.0101300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51996, 'Plurien', 'Plurien', 'Plurien', 48.6255900, -2.4042300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51997, 'Pluneret', 'Pluneret', 'Pljunere,Plumeret,Plunered,Pluneret,pu lu na lei,Плюнере,普吕纳雷,', 47.6752500, -2.9578200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51998, 'Plumieux', 'Plumieux', 'Plumieux,Pluvaeg', 48.1030300, -2.5838200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(51999, 'Plumergat', 'Plumergat', 'Pljumerga,Plumergat,Pluvergad,pu lu mei er jia,Плюмерга,普吕梅尔加', 47.7413400, -2.9150100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52000, 'Plumelin', 'Plumelin', 'Pljumelen,Plumelin,Pluverin,pu lu mo lan,Плюмелен,普吕默兰', 47.8603600, -2.8875400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52001, 'Pluméliau', 'Plumeliau', 'Pljumel''jo,Plumeliau,Pluméliau,Pluniav,pu lu mei li ao,Плюмельйо,普吕梅利奥', 47.9576900, -2.9749400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52002, 'Plumelec', 'Plumelec', 'Pljumelek,Plumelec,Pluveleg,pu lu mo lai ke,puryumurekku,Плюмелек,プリュムレック,普吕默莱克', 47.8375400, -2.6398700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52003, 'Plumaugat', 'Plumaugat', 'Pljumoga,Pljumogat,Plumaugat,Pluvaelgad,pu lu mo jia,Плюмога,Плюмогат,普吕莫加', 48.2547900, -2.2384300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52004, 'Pluherlin', 'Pluherlin', 'Pljuerlen,Pluherlin,Pluhernin,pu lu ai er lan,Плюерлен,普吕埃尔兰', 47.6963200, -2.3634900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52005, 'Pluguffan', 'Pluguffan', 'Pljugjuffan,Pluguen,Pluguffan,pu lu ju fang,puryugyufan,Плюгюффан,プリュギュファン,普吕居方', 47.9833300, -4.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52006, 'Pluduno', 'Pluduno', 'Pluduno,Pludunou,Pludunoù', 48.5311000, -2.2684800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52007, 'Plozévet', 'Plozevet', 'Plodemet,Plodémet,Plozeve,Plozeved,Plozevet,Plozévet,pu luo ze wei,Плозеве,普洛泽韦', 47.9833300, -4.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52008, 'Plouzévédé', 'Plouzevede', 'Gwitevede,Plouzevede,Plouzévédé', 48.6000000, -4.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52009, 'Plouzané', 'Plouzane', 'Plebs Sanae,Plouzane,Plouzané,Pluzane,pu lu zha nei,puruzane,Плузане,プルザネ,普卢扎内', 48.3833300, -4.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52010, 'Plouvorn', 'Plouvorn', 'Plouvorn,Pluvorn,pu lu wo er en,Плуворн,普卢沃尔恩', 48.5833300, -4.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52011, 'Plouvien', 'Plouvien', 'Plouvien,Pluv''jan,Pluvjan,pu lu wei an,Плувьян,Плувян,普卢维安', 48.5333300, -4.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52012, 'Plourivo', 'Plourivo', 'Plouriviou,Plourivioù,Plourivo,Plourivou,Plourivoù,Plurivo,pu lu li wo,Плуриво,普卢里沃', 48.7455000, -3.0707500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52013, 'Plourin-lès-Morlaix', 'Plourin-les-Morlaix', 'Plourin-Montroulez,Pluren-le-Morle,pu lu lan lai mo er lai,Плурен-ле-Морле,普卢兰莱莫尔莱', 48.5333300, -3.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52014, 'Plouray', 'Plouray', 'Plourae,Plouray,Plure,pu lu lai,Плуре,普卢赖', 48.1458000, -3.3867100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52015, 'Plounévez-Quintin', 'Plounevez-Quintin', 'Plounevez-Kintin,Plounevez-Quintin,Plounévez-Quintin', 48.2833300, -3.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52016, 'Plounévez-Moëdec', 'Plounevez-Moedec', 'Plounevez-Moedec,Plounevez-Moedeg,Plounévez-Moëdec', 48.5666700, -3.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52017, 'Plounévez-Lochrist', 'Plounevez-Lochrist', 'Gwinevez,Plounevez,Plounevez-Lochrist,Plounévez-Lochrist,Plouvenez-Lochrist,Pluneve-Lokrist,pu lu nei wei luo ke li si,purunevu~e=rokurisuto,Плуневе-Локрист,プルネヴェ＝ロクリスト,普卢内韦洛克里斯', 48.6166700, -4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52018, 'Plounévézel', 'Plounevezel', 'Plojunevezel'',Plonevell,Plounevezel,Plounévézel,pu lu nei wei ze,purunevu~ezeru,Плоюневезель,プルネヴェゼル,普卢内韦泽', 48.3000000, -3.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52019, 'Plounéventer', 'Plouneventer', 'Gwineventer,Plojunevante,Plouneventer,Plounéventer,pu lu nei wang tai,Плоюневанте,普卢内旺泰', 48.5166700, -4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52020, 'Plounéour-Trez', 'Plouneour-Trez', 'Plojuneur-Tre,Plouneour-Traezh,Plouneour-Trez,Plounéour-Trez,pu lu nei wu te lei,Плоюнеур-Тре,普卢内乌特雷', 48.6500000, -4.3166700, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52021, 'Plounéour-Ménez', 'Plouneour-Menez', 'Plojuneur-Mene,Plouneour,Plouneour-Menez,Plounéour,Plounéour-Ménez,pu lu nei wu mei nei,Плоюнеур-Мене,普卢内乌梅内', 48.4500000, -3.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52022, 'Ploumoguer', 'Ploumoguer', 'Plonger,Ploumoguer,Ploñger,Plumoge,pu lu mo gai,purumogeru,Плумоге,プルモゲール,普卢莫盖', 48.4000000, -4.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52023, 'Ploumilliau', 'Ploumilliau', 'Plouilio,Ploumilliau,Plumil''jo,Plumil''o,pu lu mi li ao,purumirio,Плумильйо,Плумильо,Плумільйо,プルミリオー,普卢米利奥', 48.6833300, -3.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52024, 'Ploumagoar', 'Ploumagoar', 'Ploumagoar,Plouvagor,Plumagoar,pu lu ma ge a,Плумагоар,普卢马戈阿', 48.5450900, -3.1323300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52025, 'Plouisy', 'Plouisy', 'Plouisy,Plouizi', 48.5781700, -3.1843400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52026, 'Plouigneau', 'Plouigneau', 'Plouigneau,Plouigno,Pluin''o,pu lu yi gai ao,puruinyo,Плуиньо,Плуїньо,プルイニョー,普卢伊盖奥', 48.5666700, -3.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52027, 'Plouider', 'Plouider', 'Plouider,Pluide,pu lu yi dai,Плуиде,Плуїде,普卢伊代', 48.6166700, -4.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52028, 'Plouhinec', 'Plouhinec', 'Ploeneg,Plouhinec', 48.0166700, -4.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52029, 'Plouharnel', 'Plouharnel', 'Plouharnel,Pluarnel'',pu lu a er nei,Плуарнель,普卢阿尔内', 47.5980400, -3.1127400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52030, 'Plouha', 'Plouha', 'Ploaha,Plouha,Plua,pu lu a,Плуа,普卢阿', 48.6765000, -2.9284200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52031, 'Plouguin', 'Plouguin', 'Plougin,Plouguin,Plugin,pu lu ji en,Плугин,Плугін,普卢吉恩', 48.5333300, -4.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52032, 'Plouguiel', 'Plouguiel', 'Plouguiel,Priel', 48.7974200, -3.2388300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52033, 'Plouguernével', 'Plouguernevel', 'Plougernevel,Plouguernevel,Plouguernével,Plugernevel'',pu lu gai er nei wei,Плугерневель,普卢盖尔内韦', 48.2394000, -3.2507100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52034, 'Plouguerneau', 'Plouguerneau', 'Plougerne,Plouguerneau,Plugerno,pu lu gai er nuo,purugeruno,Плугерно,プルゲルノー,普卢盖尔诺', 48.6000000, -4.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52035, 'Plouguenast', 'Plouguenast', 'Plougonwaz,Plouguenast,Plugena,Plugenas,pu lu gai na si,Плугена,Плугенас,普卢盖纳斯', 48.2820800, -2.7044300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52036, 'Plougrescant', 'Plougrescant', 'Plougouskant,Plougrescant,Plougreseant', 48.8402600, -3.2288600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52037, 'Plougourvest', 'Plougourvest', 'Gwikourvest,Plougourvest', 48.5500000, -4.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52038, 'Plougoumelen', 'Plougoumelen', 'Plougoumelen,Plougouvelen', 47.6507000, -2.9171600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52039, 'Plougoulm', 'Plougoulm', 'Plougoulm,Plougouloum,Plugul''m,pu lu gu er mu,Плугульм,普卢古尔姆', 48.6666700, -4.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52040, 'Plougonven', 'Plougonven', 'Plougonven,Plugonvan,pu lu gong wang,Плугонван,普卢贡旺', 48.5166700, -3.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52041, 'Plougonvelin', 'Plougonvelin', 'Plougonvelen,Plougonvelin', 48.3405900, -4.7184600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52042, 'Plougastel-Daoulas', 'Plougastel-Daoulas', 'Plougastel,Plougastel-Daoulas,Plougastell-Daoulaz,Plugastel''-Daula,Plugastel''-Daulas,pu lu jia si tai duo la,Плугастель-Даула,Плугастель-Даулас,普卢加斯泰多拉', 48.3666700, -4.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52043, 'Plougasnou', 'Plougasnou', 'Plouganou,Plouganoù,Plougasnou,Pluganu,pu lu jia si nu,Плугану,普卢加斯努', 48.7000000, -3.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52044, 'Ploufragan', 'Ploufragan', 'Ploufragan,Plufragan,pu lu fu la gang,Плуфраган,普卢夫拉冈', 48.4914100, -2.7945800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52045, 'Plouézec', 'Plouezec', 'Ploueg-ar-Mor,Plouezec,Plouézec,Pluehzek,Pluezek,pu lu ai ze ke,Плуезек,Плуэзек,普卢埃泽克', 48.7512200, -2.9846700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52046, 'Plouescat', 'Plouescat', 'Plouescat,Ploueskad,Plueskat,Pluskat,pu lu ai si ka,Плуескат,Плускат,普卢埃斯卡', 48.6666700, -4.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52047, 'Plouër-sur-Rance', 'Plouer-sur-Rance', 'Plouer,Plouer-sur-Rance,Plouhern,Plouër,Plouër-sur-Rance,Pluehr-sjur-Rans,Pluer-sjur-Rans,lang ke he pan pu lu e,Плуер-сюр-Ранс,Плуэр-сюр-Ранс,朗克河畔普卢厄', 48.5266900, -2.0029800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52048, 'Plouénan', 'Plouenan', 'Plebs Menoeni,Plouenan,Plouénan,Pluenan,pu lu ai nan,Плуенан,普卢埃南', 48.6333300, -4.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52049, 'Plouédern', 'Plouedern', 'Plouedern,Plouédern,Pluedern,pu lu ai dai er en,Плуедерн,普卢埃代尔恩', 48.4833300, -4.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52050, 'Plouëc-du-Trieux', 'Plouec-du-Trieux', 'Ploeuc,Ploueg-Pontrev,Pluehk-dju-Trijo,Pluek-dju-Trie,pu lu e ke di te li e,Плуек-дю-Трие,Плуек-дю-Тріє,Плуэк-дю-Триё,普卢厄克迪特里厄,', 48.6833300, -3.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52051, 'Ploudaniel', 'Ploudaniel', 'Ploudaniel,Plouzeniel,Pludan''el'',pu lu da nie,Плуданьель,Плуданьєль,普卢达涅', 48.5333300, -4.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52052, 'Ploudalmézeau', 'Ploudalmezeau', 'Gwitalmeze,Plebs Telmedoviae,Ploudaimezau,Ploudalmezeau,Ploudalmézeau,Pludal''mezo,plwdalmz,pu lu da er mei zuo,purudarumezo,Плудальмезо,پلودالمز,プルダルメゾー,普卢达尔梅佐', 48.5333300, -4.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52053, 'Ploubezre', 'Ploubezre', 'Plouber,Ploubezre,Ploubêr,Pluber,Plubezr,pu lu bei ci er,Плубезр,Плубер,普卢贝兹尔', 48.7000000, -3.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52054, 'Ploubazlanec', 'Ploubazlanec', 'Plaeraneg,Ploubazlanec,Plubalanek,Plubazlanek,pu lu ba ci la nei ke,Плубазланек,Плубаланек,普卢巴兹拉内克', 48.8000000, -3.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52055, 'Ploubalay', 'Ploubalay', 'Ploubalay,Plouvalae,Plubale,pu lu ba lai,Плубале,普卢巴莱', 48.5810900, -2.1406900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52056, 'Plouay', 'Plouay', 'Plouay,Ploue,Plue,Pluē,pu lu ai,Плуе,普卢艾', 47.9144400, -3.3338400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52057, 'Plouasne', 'Plouasne', 'Plouan,Plouasne', 48.3008100, -2.0069800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52058, 'Plouarzel', 'Plouarzel', 'Plouarzel,Plouarzhel,Pluarzel,Pluarzel'',pu lu a er ze,Плуарзел,Плуарзель,普卢阿尔泽', 48.4333300, -4.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52059, 'Plouaret', 'Plouaret', 'Plouared,Plouaret,Pluare,pu lu a lei,Плуаре,普卢阿雷', 48.6166700, -3.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52060, 'Plouagat', 'Plouagat', 'Plagad,Plouagat,Pluaga,Pluagat,pu lu a jia,Плуага,Плуагат,普卢阿加', 48.5361100, -2.9995600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52061, 'Plonévez-Porzay', 'Plonevez-Porzay', 'Ploneve-Porze,Plonevez-Porsay,Plonevez-Porzay,Plonevez-Porzhe,Plonévez-Porsay,Plonévez-Porzay,pu luo nei wei bo er ze,puronevu~e=poruze,Плоневе-Порзе,プロネヴェ＝ポルゼ,普洛内韦波尔泽', 48.1000000, -4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52062, 'Plonévez-du-Faou', 'Plonevez-du-Faou', 'Ploneve-dju-Fau,Plonevez,Plonevez-ar-Faou,Plonevez-du-Faou,Plonévez,Plonévez-du-Faou,pu luo nei wei di fu,Плоневе-дю-Фау,普洛内韦迪福', 48.2500000, -3.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52063, 'Plonéour-Lanvern', 'Ploneour-Lanvern', 'Ploneour,Ploneour-Lanvern,Ploneour-Lanwern,Ploneur-Lanvern,Plonéour,Plonéour-Lanvern,pu luo nei wu lang wei er en,Плонеур-Ланверн,普洛内乌朗韦尔恩', 47.9000000, -4.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52064, 'Plonéis', 'Ploneis', 'Plonei,Ploneis,Ploneiz,Plonéis,pu luo nei yi,puroneisu,Плонеи,Плонеї,プロネイス,普洛内伊', 48.0166700, -4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52065, 'Plomodiern', 'Plomodiern', 'Plomod''ern,Plomodiern,Ploudiern,pu luo mo di ye er en,Пломодьерн,Пломодьєрн,普洛莫迪耶尔恩', 48.1833300, -4.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52066, 'Plomeur', 'Plomeur', 'Plomer,Plomeur,Ploveur,Sablono:TabelKapoLauCarta,pu luo mo,puromuru,Ŝablono:TabelKapoLaŭĈarta,Пломер,プロムール,普洛默', 47.8333300, -4.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52067, 'Plomelin', 'Plomelin', 'Plomelin,Ploveilh', 47.9333300, -4.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52068, 'Plombières-lès-Dijon', 'Plombieres-les-Dijon', 'Plombieres,Plombieres-les-Dijon,Plombières,Plombières-lès-Dijon', 47.3333300, 4.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52069, 'Plombières-les-Bains', 'Plombieres-les-Bains', 'Plomb''er-le-Ben,Plomber-le-Ben,Plombieres,Plombieres-les-Bains,Plombières,Plombières-les-Bains,blwmbyyh ly ban,pu long bi ai lai ban,Пломбьер-ле-Бен,Пломбєр-ле-Бен,بلومبييه لي بان,普隆比埃莱班', 47.9633700, 6.4575800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52070, 'Plogonnec', 'Plogonnec', 'Plogoneg,Plogonnec,Plogonnek,pu luo ge nei ke,Плогоннек,普洛戈内克', 48.0833300, -4.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52071, 'Plogoff', 'Plogoff', 'Plogastel-Saint-Germain,Plogof,Plogoff,Plougon,Plougoñ,pu luo ge,purogofu,Плогоф,Плогофф,プロゴフ,普洛戈', 48.0370000, -4.6660600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52072, 'Plogastel-Saint-Germain', 'Plogastel-Saint-Germain', 'Plogastel,Plogastel''-Sen-Zhermen,Plogastel-Saint-Germain,Plogastell-Sant-Jermen,pu luo jia si tai sheng ri er man,purogasuteru=san=jeruman,Плогастель-Сен-Жермен,プロガステル＝サン＝ジェルマン,普洛加斯泰圣日尔曼', 47.9833300, -4.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52073, 'Ploëzal', 'Ploezal', 'Pleuzal,Ploezal,Ploëzal', 48.7153400, -3.2033300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52074, 'Plœuc-sur-Lié', 'Ploeuc-sur-Lie', 'Plek-sjur-L''e,Pljok-sjur-L''e,Ploeuc-sur-Lie,Ploeuc-sur-Lié,Ploheg,li ai he pan pu luo e ke,Плек-сюр-Лье,Плек-сюр-Льє,Плёк-сюр-Лье,利埃河畔普洛厄克', 48.3500000, -2.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52075, 'Ploërmel', 'Ploermel', 'Plebs Armagili,Ploermael,Ploermel,Ploermel'',Ploërmel,pu luo e er mei,puroerumeru,Плоермель,プロエルメル,普洛厄尔梅', 47.9317200, -2.3978100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52076, 'Ploeren', 'Ploeren', 'Ploeran,Ploeren,Ploveren,Plœren,pu luo ai lang,Плоеран,普洛埃朗', 47.6571300, -2.8639700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52077, 'Ploërdut', 'Ploerdut', 'Plebs Hilduti,Pleurdud,Ploerdju,Ploerdut,Ploërdut,pu luo e er di,Плоердю,普洛厄尔迪', 48.0874200, -3.2855000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52078, 'Ploemeur', 'Ploemeur', 'Planvour,Plañvour,Ploemer,Ploemeur,Plœmeur,pu luo ai mo,Плоемер,普洛埃默', 47.7333300, -3.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52079, 'Ploemel', 'Ploemel', 'Plenver,Pleñver,Ploemel,Ploemel'',Plœmel,pu luo ai mei,Плоемель,普洛埃梅', 47.6515300, -3.0703000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52080, 'Plobsheim', 'Plobsheim', 'Plobsajm,Plobse,Plobsheim,blwbshym,plwbshaym,pu luo bu sang,Плобсайм,بلوبشيم,پلوبسهایم,普洛布桑', 48.4697900, 7.7244200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52081, 'Plobannalec-Lesconil', 'Plobannalec-Lesconil', 'Plobanaleg,Plobannalec,Plobannalek-Leskonij,Pornaleg-Leskonil,pu luo ba na lai ke lai si ke ni,Плобанналек-Лесконий,Плобанналек-Лесконій,普洛巴纳莱克莱斯科尼', 47.8166700, -4.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52082, 'Pleyber-Christ', 'Pleyber-Christ', 'Pleiber-Christ,Pleiber-Krist,Plejbe-Krist,Pleyber-Christ,pu lai bei ke li si,Плейбе-Крист,普莱贝克里斯', 48.5000000, -3.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52083, 'Pleyben', 'Pleyben', 'Pleiben,Plejban,Pleyben,pu lai bang,Плейбан,普莱邦', 48.2333300, -3.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52084, 'Pleuven', 'Pleuven', 'Pleuven,Pleuwenn,Plevan,Pluwenn,pu lei wang,Плеван,普勒旺', 47.9000000, -4.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52085, 'Pleurtuit', 'Pleurtuit', 'Plertjui,Pleurestud,Pleurtuit,Plevrestud,pu lei er di yi,Плертюи,Плертюї,普勒尔蒂伊', 48.5785800, -2.0580500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52086, 'Pleumeur-Gautier', 'Pleumeur-Gautier', 'Plemer-Got''e,Pleumeur,Pleumeur-Gautier,Pleuveur-Gaoter,Pljomjor-Got''e,pu lei mo ge di ye,Племер-Готье,Племер-Готьє,Плёмёр-Готье,普勒默戈蒂耶', 48.8004400, -3.1557800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52087, 'Pleumeur-Bodou', 'Pleumeur-Bodou', 'Plemer-Bodu,Pleumeur,Pleumeur-Bodou,Pleuveur-Bodou,Pleuveur-Bodoù,Pljomjor-Bodu,pu lei mo bo du,Племер-Боду,Плёмёр-Боду,普勒默博杜', 48.7666700, -3.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52088, 'Pleumeleuc', 'Pleumeleuc', 'Plemelek,Pleumeleuc,Pleveleg,pu lei mo lei ke,Племелек,普勒默勒克', 48.1843800, -1.9196200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52089, 'Pleumartin', 'Pleumartin', 'Plemarten,Pleumartin,pu lei ma er tan,Племартен,普勒马尔坦', 46.7378600, 0.7690000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52090, 'Pleugueneuc', 'Pleugueneuc', 'Plegeneg,Pleugueneuc,Plougueneuc', 48.3973500, -1.9030100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52091, 'Pleugriffet', 'Pleugriffet', 'Pleugriffet,Ploueg-Grifed', 47.9859400, -2.6845400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52092, 'Pleudihen-sur-Rance', 'Pleudihen-sur-Rance', 'Pledian-sjur-Rans,Pleudehen,Pljodien-sjur-Rans,lang ke he pan pu lei di an,Пледиан-сюр-Ранс,Пледіан-сюр-Ранс,Плёдиен-сюр-Ранс,朗克河畔普勒迪安', 48.5166700, -1.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52093, 'Pleudaniel', 'Pleudaniel', 'Planiel,Pleudaniel', 48.7664400, -3.1403300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52094, 'Pleucadeuc', 'Pleucadeuc', 'Plegadeg,Plekadek,Pleucadeuc,Pljokadjok,pu lei ka de ke,Плекадек,Плёкадёк,普勒卡德克', 47.7587600, -2.3736200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52095, 'Pleubian', 'Pleubian', 'Pleubian,Pleuvihan', 48.8426700, -3.1390000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52096, 'Plestin-les-Grèves', 'Plestin-les-Greves', 'Plesten-le-Grev,Plestin,Plestin-les-Greves,Plestin-les-Grèves,Plistin,pu lai si tan lai ge lei wei,Плестен-ле-Грев,普莱斯坦莱格雷韦', 48.6584400, -3.6305600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52097, 'Plestan', 'Plestan', 'Plestan,Pletan,pu lai si tang,Плестан,Плетан,普莱斯唐', 48.4226600, -2.4477700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52098, 'Plessé', 'Plesse', 'Plesei,Plesse,Plessé,pu lai sai,Плессе,普莱塞', 47.5418000, -1.8860900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52099, 'Plessala', 'Plessala', 'Plesala,Plessala', 48.2764200, -2.6187600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52100, 'Pleslin-Trigavou', 'Pleslin-Trigavou', '', 48.5333300, -2.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52101, 'Plescop', 'Plescop', 'Plescop,Pleskob', 47.6972600, -2.8056000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52102, 'Plérin', 'Plerin', 'Pleren,Plerin,Plérin,pu lai lan,Плерен,普莱兰', 48.5424900, -2.7798300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52103, 'Plerguer', 'Plerguer', 'Plergar,Plerge,Plerguer,pu lai er gai,Плерге,普莱尔盖', 48.5267600, -1.8476900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52104, 'Pléneuf-Val-André', 'Pleneuf-Val-Andre', 'Plenef-Val''-Andre,Pleneg-Nantraezh,Pleneuf,Pleneuf-Val-Andre,Plenjof-Val''-Andre,Pléneuf,Pléneuf-Val-André,pu lai na wa ang de lei,Пленеф-Валь-Андре,Пленёф-Валь-Андре,普莱纳瓦昂德雷', 48.5930000, -2.5467500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52105, 'Plénée-Jugon', 'Plenee-Jugon', 'Plened-Yugon,Plenee-Jugon,Plénée-Jugon', 48.3646200, -2.4003600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52106, 'Plémy', 'Plemy', 'Plemy,Plevig,Plémy', 48.3364400, -2.6824400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52107, 'Plémet', 'Plemet', 'Plemet,Plezeved,Plémet', 48.1760100, -2.5932500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52108, 'Plélo', 'Plelo', 'Plelo,Pleuloc''h,Plélo', 48.5553400, -2.9463400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52109, 'Plélan-le-Petit', 'Plelan-le-Petit', 'Plelan,Plelan-le-Petit,Plelann-Vihan,Plélan,Plélan-le-Petit', 48.4315700, -2.2174000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52110, 'Plélan-le-Grand', 'Plelan-le-Grand', 'Plelan-le-Gran,Plelan-le-Grand,Plelann-Veur,Plélan-le-Grand,da pu lai lang,Плелан-ле-Гран,大普莱朗', 48.0012400, -2.0991400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52111, 'Pleine-Fougères', 'Pleine-Fougeres', 'Planfili,Pleine-Fougeres,Pleine-Fougères,Plen-Fuzher,Plena Filix,pu lai ne fu re er,Плен-Фужер,普莱讷富热尔', 48.5330800, -1.5653400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52112, 'Pléhédel', 'Plehedel', 'Plehedel,Pléhédel', 48.6964500, -3.0083300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52113, 'Pléguien', 'Pleguien', 'Pleguien,Plian,Pléguien', 48.6352500, -2.9400100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52114, 'Plédran', 'Pledran', 'Pledran,Plédran,pu lai de lang,Пледран,普莱德朗', 48.4460000, -2.7466700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52115, 'Plédéliac', 'Pledeliac', 'Pledeliac,Pledeliav,Plédéliac', 48.4500000, -2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52116, 'Pléchâtel', 'Plechatel', 'Plebs Castelli,Plechatel,Plegastell,Pleshatel'',Pléchâtel,pu lai sha tai,Плешатель,普莱沙泰', 47.8949600, -1.7487600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52117, 'Pleaux', 'Pleaux', '', 45.1333300, 2.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52118, 'Plauzat', 'Plauzat', 'Plauzat', 45.6217100, 3.1489600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52119, 'Plaudren', 'Plaudren', 'Plaodren,Plaudren', 47.7786800, -2.6933100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52120, 'Plappeville', 'Plappeville', 'Plappeville,Plappvil'',pu la po wei er,Плаппвиль,Плаппвіль,普拉珀维尔', 49.1304100, 6.1237600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52121, 'Planguenoual', 'Planguenoual', 'Plangenual'',Plangonwal,Planguenoual,pu lang gai nu a,Плангенуаль,普朗盖努阿', 48.5330000, -2.5764200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52122, 'Le Plan-de-la-Tour', 'Le Plan-de-la-Tour', 'Le-Plan-de-la-Tur,Lo Plan de la Tor,Lo Plan de la Torre,lai pu lang de la tu,Ле-План-де-ла-Тур,莱普朗德拉图', 43.3333300, 6.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52123, 'Plan-de-Cuques', 'Plan-de-Cuques', 'Cuques,Lo Plan de Cucas,Plan-de-Cuques,Plan-de-Kjuk,pu lang de qu qu ai,План-де-Кюк,普朗德屈屈埃', 43.3475300, 5.4639800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52124, 'Plan-d''Aups-Sainte-Baume', 'Plan-d''Aups-Sainte-Baume', 'Plan-d''Aups-Sainte-Baume,Plan-d''Ops-Sent-Bom,Plan-dAups-Sainte-Baume,Plan-d’Aups-Sainte-Baume,План-д’Опс-Сент-Бом', 43.3333300, 5.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52125, 'Plancoët', 'Plancoet', 'Plancoet,Plancoët,Plangoed', 48.5219900, -2.2354000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52126, 'Plancher-les-Mines', 'Plancher-les-Mines', 'Plancher-les-Mines,Planshe-le-Min,Планше-ле-Мин,Планше-ле-Мін', 47.7615000, 6.7430800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52127, 'Plancher-Bas', 'Plancher-Bas', 'Plancher-Bas,Planshe-Ba,Планше-Ба', 47.7197700, 6.7304100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52128, 'Plaisir', 'Plaisir', 'Plaisir', 48.8231900, 1.9541000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52129, 'Plaisance-du-Touch', 'Plaisance-du-Touch', 'Plaisance,Plaisance-du-Touch', 43.5656600, 1.2974900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52130, 'Plaisance', 'Plaisance', 'Plaisance', 43.6043600, 0.0461500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52131, 'Plaintel', 'Plaintel', 'Plaintel,Pleneventer', 48.4073300, -2.8173300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52132, 'Plainfaing', 'Plainfaing', 'Plainfaing,Plenfen,pu lan fan,Пленфен,普兰凡', 48.1728400, 7.0153900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52133, 'Plaine-Haute', 'Plaine-Haute', 'Plaine-Haute,Plenaod', 48.4444200, -2.8541600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52134, 'Plaimpied-Givaudins', 'Plaimpied-Givaudins', 'Plaimpied,Plaimpied-Givaudins,Plainpied-Givaudins', 46.9980000, 2.4542800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52135, 'Plailly', 'Plailly', 'Plai,Plailly,pu lai li,Плаї,普莱利', 49.1028800, 2.5854900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52136, 'Plabennec', 'Plabennec', 'Albennoca,Plabennec,Plabenneg,Plabennek,pu la bo nei ke,Плабеннек,普拉伯内克', 48.5024400, -4.4265600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52137, 'Pithiviers-le-Vieil', 'Pithiviers-le-Vieil', 'Pithiviers-le-Vieil,Pitive-le-Vej,pi di wei ye er lai wei ye yi,Пітівє-ле-Вєй,皮蒂维耶尔莱维耶伊', 48.1631300, 2.2092200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52138, 'Pithiviers', 'Pithiviers', 'Pithiviers,Pitiv''e,Pitive,pi di wei ye,pitivu~ie,Питивье,Пітівє,ピティヴィエ,皮蒂维耶', 48.1666700, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52139, 'Pissy-Pôville', 'Pissy-Poville', 'Pissy,Pissy-Poville,Pissy-Pôville', 49.5298600, 0.9928100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52140, 'Pissotte', 'Pissotte', 'Pissotte', 46.4972500, -0.8066600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52141, 'Pissos', 'Pissos', 'Pissos', 44.3083300, -0.7796300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52142, 'Pirou', 'Pirou', 'Pirou,Piru,pi lu,Пиру,Піру,皮鲁', 49.1808900, -1.5738400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52143, 'Piriac-sur-Mer', 'Piriac-sur-Mer', 'Penc''herieg,Pencherieg,Piriac,Piriac-sur-Mer,Piriak-sjur-Mer,bin hai pi li a ke,piriakku=shuru=meru,Піріак-сюр-Мер,ピリアック＝シュル＝メール,滨海皮里阿克', 47.3793800, -2.5461600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52144, 'Pirey', 'Pirey', 'Pirey', 47.2613600, 5.9646600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52145, 'Piré-sur-Seiche', 'Pire-sur-Seiche', 'Pereg,Pire,Pire-sjur-Sesh,Pire-sur-Seiche,Piriacus,Piré-sur-Seiche,sai ke he pan pi lei,Пире-сюр-Сеш,Піре-сюр-Сеш,塞克河畔皮雷', 48.0095800, -1.4290900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52146, 'Pipriac', 'Pipriac', 'Pipriac,Presperieg', 47.8095300, -1.9463800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52147, 'Pionsat', 'Pionsat', 'Pionsat', 46.1094900, 2.6936200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52148, 'Piolenc', 'Piolenc', 'P''olenk,Piolenc,Piolene,Pjolank,Puegoulen,pi ao lang,Пйоланк,Пьоленк,皮奥朗', 44.1794500, 4.7640800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52149, 'Pinsaguel', 'Pinsaguel', '', 43.5104000, 1.3883100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52150, 'Pinon', 'Pinon', 'Pinon', 49.4891600, 3.4470300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52151, 'Piney', 'Piney', '', 48.3636600, 4.3332500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52152, 'Pinet', 'Pinet', 'Pinet', 43.4055600, 3.5100000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52153, 'Pignans', 'Pignans', 'Pignans', 43.3012800, 6.2274800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52154, 'Pignan', 'Pignan', 'Pignan,Pin''jan,Pinhan,pi ni ang,Пиньян,Піньян,皮尼昂', 43.5836500, 3.7598100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52155, 'Pietrosella', 'Pietrosella', 'Pietrosella', 41.8361800, 8.8457800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52156, 'Pierry', 'Pierry', 'Perri,Pierry,pi ye er li,Пєррі,皮耶尔里', 49.0202400, 3.9407100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52157, 'Pierrevillers', 'Pierrevillers', 'P''errville,P''erviller,Perrville,Pierrevillers,pi ye er lei wei lai er,Пьервиллер,Пьеррвилле,Пєррвілле,皮耶尔勒维莱尔', 49.2242000, 6.1019700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52158, 'Pierrevert', 'Pierrevert', 'P''erver,Peiraverd,Peiravèrd,Peireverd,Perrver,Pierrevert,Pèirevèrd,pi ye er lei wei er,Пьервер,Пєррвер,皮耶尔勒韦尔', 43.8163400, 5.7463800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52159, 'Pierres', 'Pierres', 'Pierres', 48.5920900, 1.5644400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52160, 'Pierrepont', 'Pierrepont', 'Pierrepont', 49.4161400, 5.7140000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52161, 'Pierrelaye', 'Pierrelaye', 'Pierrelaye', 49.0211000, 2.1548100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52162, 'Pierrelatte', 'Pierrelatte', 'Peiralata,Perrlatt,Pierrelatte,Pèiralata,pi ye er lei la te,pieruratto,Пєррлатт,ピエールラット,皮耶尔雷拉特', 44.3775600, 4.7019800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52163, 'Pierrefort', 'Pierrefort', 'P''erfor,P''errfor,Peirafort,Perrfor,Pierrefort,Pèirafòrt,pi ye er lei fu er,Пьеррфор,Пьерфор,Пєррфор,皮耶尔雷福尔', 44.9220300, 2.8390000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52164, 'Pierrefontaine-les-Varans', 'Pierrefontaine-les-Varans', 'Pierrefontaine', 47.2160100, 6.5403000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52165, 'Pierrefonds', 'Pierrefonds', 'Pierrefonds les-Bain', 49.3487800, 2.9779000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52166, 'Pierrefitte-sur-Seine', 'Pierrefitte-sur-Seine', 'P''errfitt-sjur-Sen,Perrfitt-sjur-Sen,Petraficta ad Sequanam,Pierrefitte,Pierrefitte-sur-Seine,Pjerfit sir Sen,pieleupiteuswileusen,pierufitto=shuru=senu,pyrwfyt swr sn,Пьеррфитт-сюр-Сен,Пєррфітт-сюр-Сен,Пјерфит сир Сен,پیروفیت سور سن,ピエールフィット＝シュル＝セーヌ,피에르피트쉬르센', 48.9669100, 2.3610400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52167, 'Pierrefitte-Nestalas', 'Pierrefitte-Nestalas', 'Pierrefitte-Nestalas', 42.9666700, -0.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52168, 'Pierrefeu-du-Var', 'Pierrefeu-du-Var', 'P''erfjo-dju-Var,Peirafuec,Perrfe-dju-Var,Pierrefeu,Pierrefeu-du-Var,Pèirafuec,pi ye er lei fu di wa,Пьерфё-дю-Вар,Пєррфе-дю-Вар,皮耶尔雷弗迪瓦', 43.2244800, 6.1432900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52169, 'Pierre-Châtel', 'Pierre-Chatel', 'Pierre-Chatel,Pierre-Châtel', 44.9565400, 5.7772900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52170, 'Pierre-Buffière', 'Pierre-Buffiere', 'Pierre-Buffiere,Pierre-Buffière', 45.6919300, 1.3619300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52171, 'Pierre-Bénite', 'Pierre-Benite', 'Perr-Benit,Pierre-Benite,Pierre-Bénite,Пєрр-Беніт', 45.7009000, 4.8251100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52172, 'Pierre-de-Bresse', 'Pierre-de-Bresse', 'P''err-de-Bress,Perr-de-Bress,Пьерр-де-Бресс,Пєрр-де-Бресс', 46.8833300, 5.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52173, 'Piennes', 'Piennes', 'Pienne,Piennes', 49.3059100, 5.7883600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52174, 'Piégut-Pluviers', 'Piegut-Pluviers', 'P''egju-Pljuv''e,Pegju-Pljuve,Piegut,Piegut-Pluviers,Piégut,Piégut-Pluviers,Puei Gut e Pluviers,Pueiagut de Perigord,Pueiagut de Perigòrd,pi ai ju pu lu wei ye er,Пьегю-Плювье,Пєгю-Плювє,皮埃居普吕维耶尔', 45.6229700, 0.6901300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52175, 'Picquigny', 'Picquigny', 'Picquigny,Pikin''i,Pitchigny,pi ji ni,Пикиньи,Пікіньї,皮基尼', 49.9441300, 2.1437600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52176, 'Picauville', 'Picauville', 'Picauville', 49.3781000, -1.4004800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52177, 'Pibrac', 'Pibrac', 'Pibrac,Pibrak,pi bu la ke,Пибрак,Пібрак,皮布拉克', 43.6204200, 1.2854000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52178, 'Pia', 'Pia', 'Pia', 42.7449000, 2.9193000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52179, 'Phalsbourg', 'Phalsbourg', 'Fal''sbur,Fort-Francais,Fort-Français,Pfalzburg,Phalsbourg,Roc-Ferme,fa er si bu er,falsbwrg,Фальсбур,فالسبورگ,法尔斯布尔', 48.7675200, 7.2569500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52180, 'Phalempin', 'Phalempin', 'Falampen,Phalempin,fa lang pan,Фалампен,法朗潘', 50.5169100, 3.0158400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52181, 'Pfulgriesheim', 'Pfulgriesheim', '', 48.6440300, 7.6708600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52182, 'Pfetterhouse', 'Pfetterhouse', 'Pfetterhausen,Pfetterhouse,Pfetteruz,pu fei te lu si,Пфеттеруз,普费特鲁斯', 47.5006100, 7.1653500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52183, 'Pfastatt', 'Pfastatt', 'Fastat,Pfastat,Pfastatt,pu fa si ta,Пфастат,Фастат,普法斯塔', 47.7704400, 7.3010300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52184, 'Pfaffenhoffen', 'Pfaffenhoffen', 'Pfaffenhofen,Pfaffenhoffen,Pfaffenoffen,Pfaffoffe,bfafynhwfyn,pfafnhwfn,pu fa fang ao fang,Пфаффеноффен,بفافينهوفين,پفافنهوفن,普法方奥方', 48.8410600, 7.6067900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52185, 'Pfaffenheim', 'Pfaffenheim', 'Pfaffenajm,Pfaffenheim,Pfaffenkhajm,pu fa fei nan,Пфаффенайм,Пфаффенхайм,普法费南', 47.9843800, 7.2885700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52186, 'Pézilla-la-Rivière', 'Pezilla-la-Riviere', 'Pezilla,Pezilla-de-la-Riviere,Pezilla-la-Riviere,Pézilla,Pézilla-de-la-Rivière,Pézilla-la-Rivière', 42.6953600, 2.7711500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52187, 'Pezens', 'Pezens', 'Pezens', 43.2544600, 2.2686800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52188, 'Pézenas', 'Pezenas', 'Pesenas,Pesenàs,Pezenas,Pézenas,pei ze na,Пезенас,佩泽纳', 43.4595300, 3.4238400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52189, 'Peyruis', 'Peyruis', 'Peirueis,Pejrjui,Perjui,Peyruis,pei lu yi,Пейрюї,Перюи,佩吕伊', 44.0295900, 5.9426200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52190, 'Peyrolles-en-Provence', 'Peyrolles-en-Provence', 'Peirola,Peirola de Provenca,Peiròla,Peiròla de Provença,Pejrol''-an-Provans,Perol''-an-Provans,Peyrolles,Peyrolles-en-Provence,pu luo wang si de qu pei luo lai,Пейроль-ан-Прованс,Пероль-ан-Прованс,普罗旺斯地区佩罗莱', 43.6453200, 5.5834700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52191, 'Peyrins', 'Peyrins', 'Peyrins', 45.0924100, 5.0476700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52192, 'Peyrilhac', 'Peyrilhac', 'Peyrilhac', 45.9504300, 1.1350300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52193, 'Peyriac-Minervois', 'Peyriac-Minervois', 'Peyriac,Peyriac-Minervois', 43.2906800, 2.5661300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52194, 'Peyriac-de-Mer', 'Peyriac-de-Mer', 'Peyriac,Peyriac-de-Mer', 43.0872000, 2.9583100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52195, 'Peyrestortes', 'Peyrestortes', 'Peyrestortes', 42.7548000, 2.8523200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52196, 'Peyrehorade', 'Peyrehorade', 'Peira Horada,Peirahorada,Pejrorad,Perorad,Pevrehorade,Peyrehorade,Pèira Horada,Pèirahorada,pei lei ao la de,Пейрорад,Перорад,佩雷奥拉德', 43.5488600, -1.1157400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52197, 'Peyrat-de-Bellac', 'Peyrat-de-Bellac', 'Pevrat-la-Montagne,Peyrat,Peyrat-de-Bellac', 46.1408700, 1.0366100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52198, 'Peypin', 'Peypin', 'Pejpen,Pepen,Peypin,Puegpin,pei pan,Пейпен,Пепен,佩潘', 43.3850300, 5.5778800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52199, 'Peynier', 'Peynier', 'Pejn''e,Pen''e,Peynier,Puegnier,pei nie,Пейньє,Пенье,佩涅', 43.4483700, 5.6413900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52200, 'Peymeinade', 'Peymeinade', 'Peymeinade', 43.6363600, 6.8777600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52201, 'Peujard', 'Peujard', 'Peujard', 45.0361900, -0.4409600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52202, 'Petiville', 'Petiville', 'Petiville', 49.4607800, 0.5874000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52203, 'Petit-Réderching', 'Petit-Rederching', 'Petit-Rederching,Petit-Réderching', 49.0577600, 7.3050900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52204, 'Petit-Noir', 'Petit-Noir', '', 46.9333300, 5.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52205, 'Petit-Mars', 'Petit-Mars', 'Kervarc''h,Kervarch,Parvus Marcius,Peti-Mars,Petit-Mars,pei di ma er,Петі-Марс,佩蒂马尔', 47.3951200, -1.4526200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52206, 'Petite-Rosselle', 'Petite-Rosselle', 'Kleinrosseln,Petit Rossel,Petit-Rossel'',Petite-Rosselle,Petite-Rousselle,pei di te luo sai er,Петит-Россель,Петіт-Россель,佩蒂特罗塞尔', 49.2117700, 6.8560700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52207, 'Petite-Forêt', 'Petite-Foret', '', 50.3666700, 3.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52208, 'Pessac', 'Pessac', 'Pecac,Pecac de Bordeu,Pesak,Pessac,Pessak,Pessake,Peçac,Peçac de Bordèu,pei sa ke,pesakeu,pesakku,pwsk,Песак,Пессак,Пессаке,پوسک,ペサック,佩萨克,페사크', 44.8101100, -0.6412900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52209, 'Pesmes', 'Pesmes', 'Pem,Pesmes,Пем', 47.2800800, 5.5669800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52210, 'Peschadoires', 'Peschadoires', 'Peschadoire,Peschadoires', 45.8239100, 3.5024300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52211, 'Pertuis', 'Pertuis', 'Pertuis', 43.6925200, 5.5028500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52212, 'Perthes', 'Perthes', '', 48.4782100, 2.5550900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52213, 'Pers-Jussy', 'Pers-Jussy', 'Pers,Pers-Jussy', 46.1062500, 6.2674900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52214, 'Persan', 'Persan', 'Persan', 49.1533500, 2.2721800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52215, 'Perrusson', 'Perrusson', 'Perrusson', 47.0987300, 1.0143800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52216, 'Perros-Guirec', 'Perros-Guirec', 'Perro-Girek,Perros,Perros-Girek,Perros-Guirec,Perroz-Gireg,pei luo si-ji lei ke,Перро-Гирек,Перро-Гірек,Перрос-Гирек,佩罗斯-吉雷克', 48.8145400, -3.4396300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52217, 'Perrigny-lès-Dijon', 'Perrigny-les-Dijon', 'Perrigny,Perrigny-les-Dijon,Perrigny-lès-Dijon,Perrin''i-le-Dizhon,pei er li ni lai di rong,pryny-l-dyzhn,Перриньи-ле-Дижон,Перриньї-ле-Діжон,پرینی-ل-دیژن,佩尔里尼莱迪容', 47.2664800, 5.0062800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52218, 'Perrigny', 'Perrigny', 'Perrigny', 46.6674400, 5.5845600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52219, 'Perrignier', 'Perrignier', 'Perrignier', 46.3064000, 6.4446500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52220, 'Perriers-sur-Andelle', 'Perriers-sur-Andelle', 'Perriers,Perriers-sur-Andelle', 49.4148700, 1.3709800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52221, 'Perreux', 'Perreux', 'Perreux', 46.0383800, 4.1220500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52222, 'Perrecy-les-Forges', 'Perrecy-les-Forges', 'Cercy-la-Dheune,Perrecey,Perrecy,Perrecy-les-Forges', 46.6145300, 4.2138000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52223, 'Perpignan', 'Perpignan', 'Gorad Perpin''jan,PGF,Perpignan,Perpignan la Catalane,Perpignano,Perpin''jan,Perpinan,Perpinana,Perpinha,Perpinhan,Perpinhã,Perpinia,Perpinian,Perpinianum,Perpinjan,Perpinjanas,Perpinjano,Perpinya,Perpinya la Catalana,Perpinyan,Perpinyà,Perpinyà la Catalana,Perpinyán,Perpiñán,Perpiņāna,Villa Perpiniarum,ban he bi rang,byrbynya,pei pi ni ang,peleupinyang,perpinam,perupinyan,prpynan,prpynya,prpynyan,Περπινιάν,Горад Перпіньян,Перпиньян,Перпинян,Перпињан,Перпіньян,פערפיניאן,פרפיניאן,بيربينيا,پرپگناں,پرپینان,پرپینیا,پرپینیان,पेर्पिञां,ペルピニャン,佩皮尼昂,班合比让,페르피냥', 42.6976400, 2.8954100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52224, 'Péroy-les-Gombries', 'Peroy-les-Gombries', 'Peroy,Peroy-les-Gombries,Péroy,Péroy-les-Gombries', 49.1624800, 2.8455600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52225, 'Pérouges', 'Perouges', 'Perouges,Peruz,Peruzh,Pérouges,byrwj,pei lu ri,Перуж,Պերուժ,بيروج,佩鲁日', 45.9073500, 5.1727300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52226, 'Péronne', 'Peronne', '', 49.9333300, 2.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52227, 'Péronnas', 'Peronnas', 'Peronna,Peronnas,Péronnas,byrwna,pei luo na si,Перонна,بيرونا,佩罗纳斯', 46.1907300, 5.2081900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52228, 'Péron', 'Peron', '', 46.1905300, 5.9252400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52229, 'Pérols', 'Perols', 'Perol'',Perols,Perous,Peròus,Pérols,pei luo er,Пероль,佩罗尔', 43.5631300, 3.9520300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52230, 'Pernes-les-Fontaines', 'Pernes-les-Fontaines', 'Pern-le-Fonten,Pernas dei Fonts,Pernes,Pernes-les-Fontaines,Pèrnas dei Fònts,pei er na lei feng tai na,Перн-ле-Фонтен,佩尔纳勒丰泰纳', 44.0002800, 5.0514100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52231, 'Pernes', 'Pernes', 'Pernes,Pernes-en-Artois', 50.4843700, 2.4125300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52232, 'Périgueux', 'Perigueux', 'Gorad Perygjo,PGX,Perige,Perigjo,Perigueers,Periguers,Perigueux,Perigus,Perigús,Perigüers,Perigē,Perigė,Petrocorium,Périgueux,pei li ge,peligoe,peri kex,perigu,prygw,Горад Перыгё,Периге,Перигё,Періге,פריגו,پریگو,เปรีเกอ,პერიგე,ペリグー,佩里格,페리괴', 45.1833300, 0.7166700, 'FR', '2016-12-11', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52233, 'Périgny', 'Perigny', 'Perigny,Perigny-sur-Yerres,Périgny,Périgny-sur-Yerres', 48.6965600, 2.5553700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52234, 'Périgny', 'Perigny', 'Perigny,Périgny', 46.1551900, -1.0982200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52235, 'Périgneux', 'Perigneux', 'Perigneux,Périgneux', 45.4400100, 4.1565500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52236, 'Pérignat-sur-Allier', 'Perignat-sur-Allier', 'Perignat,Perignat-es-Allier,Perignat-les-Allier,Perignat-sur-Allier,Pérignat,Pérignat-es-Allier,Pérignat-les-Allier,Pérignat-sur-Allier', 45.7290400, 3.2348000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52237, 'Pérignat-lès-Sarliève', 'Perignat-les-Sarlieve', 'Perignat,Perignat-les-Sarlieve,Pérignat,Pérignat-lès-Sarliève', 45.7357100, 3.1402400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52238, 'Pérignac', 'Perignac', 'Perignac,Pérignac', 45.6230600, -0.4648800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52239, 'Périers', 'Periers', 'Periers,Périers', 49.1866700, -1.4076200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52240, 'Peri', 'Peri', 'Peri', 42.0039400, 8.9209600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52241, 'Pérenchies', 'Perenchies', 'Peranshi,Perenchies,Pérenchies,pei lang xi,Перанши,Перанші,佩朗希', 50.6701300, 2.9702400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52242, 'Percy', 'Percy', 'Percy', 48.9171400, -1.1891600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52243, 'Pépieux', 'Pepieux', 'Pepieux,Pépieux', 43.2973500, 2.6795200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52244, 'Penvénan', 'Penvenan', 'Panvenan,Penvenan,Perwenan,pan''vu~enan,pang wei nan,Панвенан,Пенвенан,パンヴェナン,庞韦南', 48.8118200, -3.2955000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52245, 'Penta-di-Casinca', 'Penta-di-Casinca', 'A Penta di Casinca,Penta,Penta di Casinca,Penta-di-Casinca,Penta-di-Kazinka,Пента-ди-Казинка,Пента-ді-Казінка', 42.4668700, 9.4590200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52246, 'Pennautier', 'Pennautier', 'Pennautier', 43.2451300, 2.3189200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52247, 'Pénestin', 'Penestin', 'Penesten,Penestin,Pennestin,Pénestin,pei nei si tan,penesutan,Пенестен,ペネスタン,佩内斯坦', 47.4822600, -2.4727500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52248, 'Pendé', 'Pende', 'Pende,Pendé', 50.1605500, 1.5854100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52249, 'Pencran', 'Pencran', 'Pencran,Penn-ar-C''hrann', 48.4333300, -4.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52250, 'Pélussin', 'Pelussin', 'Peljussen,Pelussin,Pélussin,pei lu sang,Пелюссен,佩吕桑', 45.4180800, 4.6824800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52251, 'Peltre', 'Peltre', 'Pel''tr,Peltre,pei er te er,Пельтр,佩尔特尔', 49.0747000, 6.2269200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52252, 'Pelousey', 'Pelousey', 'Pelousey', 47.2753800, 5.9226300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52253, 'Pellouailles-les-Vignes', 'Pellouailles-les-Vignes', 'Pellouailles', 47.5217200, -0.4395400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52254, 'Pellegrue', 'Pellegrue', 'Pel''grju,Pelagrua,Pellegrue,pei lai ge lu ai,Пельгрю,佩莱格吕埃', 44.7435500, 0.0759500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52255, 'Pélissanne', 'Pelissanne', 'Pelicana,Pelissan,Pelissana,Pelissann,Pelissanne,Peliçana,Pélissanne,pei li sa ne,Пелиссан,Пеліссанн,佩利萨讷', 43.6351200, 5.1513100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52256, 'Peipin', 'Peipin', 'Peipin,Pepen,pei pan,Пепен,佩潘', 44.1377800, 5.9572200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52257, 'Peillonnex', 'Peillonnex', 'Peillonnex', 46.1321500, 6.3758000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52258, 'Peillon', 'Peillon', 'Peillon,Pejon,Pelhon,Pylio,bylwn,pei long,Пейон,بيلون,佩隆', 43.7786100, 7.3827800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52259, 'Peille', 'Peille', 'Peille,Pej,Pelha,Pyla Nicaeensium,byly,pei er,Пей,بيلي,佩尔', 43.8058700, 7.4042900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52260, 'Peillac', 'Peillac', 'Paolieg,Peillac', 47.7139100, -2.2197100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52261, 'Pégomas', 'Pegomas', 'Pegoma,Pegomac,Pegomas,Pegomaç,Pegomàs,Pégomas,byjwmas,pegoma,pei ge ma,Пегома,بيجوماس,ペゴマ,佩戈马', 43.5985000, 6.9303200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52262, 'Pédernec', 'Pedernec', 'Pedernec,Pederneg,Pédernec', 48.5968200, -3.2694800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52263, 'Pecquencourt', 'Pecquencourt', 'Pecquencourt,Pekankur,pei ke ku er,Пеканкур,佩克库尔', 50.3785000, 3.2127700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52264, 'Pechbonnieu', 'Pechbonnieu', 'Echbonnieu,Pechbonnieu,Peshbon''e,Peshbon''jo,Puegbonieu,Puègbonieu,pei ke bo ni e,Пешбоньё,Пешбоньє,佩克博尼厄', 43.7024200, 1.4653800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52265, 'Péchabou', 'Pechabou', 'Pechabou,Péchabou', 43.5024100, 1.5093400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52266, 'Péaule', 'Peaule', 'Peaule,Peol'',Pleaol,Plebs Gabla,Péaule,pei ao er,Пеоль,佩奥尔', 47.5797200, -2.3560100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52267, 'Peaugres', 'Peaugres', 'Peaugres', 45.2877100, 4.7291000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52268, 'Payzac', 'Payzac', 'Payzac-de-Lanouaille', 45.4000000, 1.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52269, 'Payrin-Augmontel', 'Payrin-Augmontel', 'Payrin,Payrin-Augmontel', 43.5445000, 2.3540600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52270, 'Payns', 'Payns', 'Payns', 48.3825500, 3.9775500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52271, 'Pavilly', 'Pavilly', 'Pavilly', 49.5670300, 0.9544500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52272, 'Pavie', 'Pavie', 'Padie,Pavie', 43.6096900, 0.5914300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52273, 'Paulx', 'Paulx', 'Palud,Paulx', 46.9618100, -1.7552000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52274, 'Paulhan', 'Paulhan', 'Paulhan', 43.5394400, 3.4576000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52275, 'Paulhaguet', 'Paulhaguet', 'Paulhaguet', 45.2078200, 3.5141700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52276, 'Paulhac', 'Paulhac', 'Paulhac', 43.7563900, 1.5566700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52277, 'Pauillac', 'Pauillac', 'Pauillac,Paulhac,Pojak,Pojjak,bo ya ke,poiyakku,Пойяк,Пояк,ポーイヤック,波亚克', 45.1964400, -0.7487300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52278, 'Pau', 'Pau', 'PUF,Pau,Paue,po,Пау,ポー', 43.3000000, -0.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52279, 'Patay', 'Patay', 'Pataium,Patay,Pate,pa ti,Пате,帕提', 48.0483300, 1.6950000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52280, 'Passy', 'Passy', 'Passy', 45.9202800, 6.6876500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52281, 'Pasly', 'Pasly', 'Pasly', 49.4016700, 3.2963100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52282, 'Paslières', 'Paslieres', 'Palheiras de Noalhac,Palhèiras de Noalhac,Pasl''er,Paslieres,Paslières,pa si li ai,Пасльєр,帕斯利埃', 45.9284400, 3.4935200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52283, 'Parthenay', 'Parthenay', 'Partene,Parthiniacum,pa er te nai,parutone,Партене,パルトネー,帕爾特奈', 46.6500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52284, 'Paron', 'Paron', 'Paron', 48.1788800, 3.2507500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52285, 'Parmain', 'Parmain', 'Parmain,Parmen,pa er man,Пармен,帕尔曼', 49.1124700, 2.2148700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52286, 'Paris', 'Paris', 'Baariis,Bahliz,Gorad Paryzh,Lungsod ng Paris,Lutece,Lutetia,Lutetia Parisorum,Lutèce,PAR,Pa-ri,Paarys,Palika,Paname,Pantruche,Paraeis,Paras,Pari,Paries,Parigge,Pariggi,Parighji,Parigi,Pariis,Pariisi,Pariizu,Pariižu,Parij,Parijs,Paris,Parisi,Parixe,Pariz,Parize,Parizh,Parizh osh,Parizh'',Parizo,Parizs,Pariž,Parys,Paryz,Paryzius,Paryż,Paryžius,Paräis,París,Paríž,Parîs,Parĩ,Parī,Parīze,Paříž,Páras,Párizs,Ville-Lumiere,Ville-Lumière,ba li,barys,pairisa,pali,pari,paris,parys,paryzh,perisa,pryz,pyaris,pyarisa,pyrs,Παρίσι,Горад Парыж,Париж,Париж ош,Парижь,Париз,Парис,Паріж,Փարիզ,פאריז,פריז,باريس,پارىژ,پاريس,پاریس,پیرس,ܦܐܪܝܣ,पॅरिस,पेरिस,पैरिस,প্যারিস,ਪੈਰਿਸ,પૅરિસ,பாரிஸ்,పారిస్,ಪ್ಯಾರಿಸ್,പാരിസ്,ปารีส,ཕ་རི།,ပါရီမြို့,პარიზი,ፓሪስ,ប៉ារីស,パリ,巴黎,파리', 48.8534100, 2.3488000, 'FR', '2017-06-12', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52287, 'Parigny', 'Parigny', 'Parigny', 48.5945000, -1.0792500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52288, 'Parigné-le-Pôlin', 'Parigne-le-Polin', 'Parigne,Parigne-le-Polin,Parigné,Parigné-le-Pôlin', 47.8498700, 0.1070500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52289, 'Parigné', 'Parigne', 'Parigne,Parigné,Parinieg', 48.4272700, -1.1921000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52290, 'Pargny-sur-Saulx', 'Pargny-sur-Saulx', 'Pargny,Pargny-sur-Saulx,Parn''i-sjur-So,Parni sjur So,Parni-sur-So,suo er he pan pa er ni,Парни сюр Со,Парни-сур-Со,Парньї-сюр-Со,索尔河畔帕尔尼', 48.7686600, 4.8375800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52291, 'Parentis-en-Born', 'Parentis-en-Born', 'Parantis-an-Born,Parentias,Parentis,Parentis-en-Born,Parentís,bo er en de qu pa lang di,Парантис-ан-Борн,Парантіс-ан-Борн,博尔恩地区帕朗蒂', 44.3527400, -1.0709500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52292, 'Parempuyre', 'Parempuyre', 'Parempuyre', 44.9503800, -0.6045300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52293, 'Parcé-sur-Sarthe', 'Parce-sur-Sarthe', 'Parce,Parce-sur-Sarthe,Parcé,Parcé-sur-Sarthe', 47.8435600, -0.2010400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52294, 'Parçay-Meslay', 'Parcay-Meslay', 'Parcay-Meslay,Parçay-Meslay', 47.4419500, 0.7484700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52295, 'Parçay-les-Pins', 'Parcay-les-Pins', 'Parcay,Parcay-les-Pins,Parse-le-Pen,Parçay,Parçay-les-Pins,pa er sai lai pan,Парсе-ле-Пен,帕尔赛莱潘', 47.4366800, 0.1631200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52296, 'Paray-Vieille-Poste', 'Paray-Vieille-Poste', 'Paray,Paray-Vielly,Pare-V''ej-Post,Pare-Vej-Post,pa lai wei ye yi lei bo si te,Паре-Вьей-Пост,Паре-Вєй-Пост,帕赖维耶伊勒波斯特', 48.7140200, 2.3628300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52297, 'Paray-le-Monial', 'Paray-le-Monial', 'Paray,Paray-le-Monial,Pare-le-Mon''jal'',Паре-ле-Моньяль', 46.4545700, 4.1158400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52298, 'Paradou', 'Paradou', 'Le Paradou,Lo Parador,Paradou,Paradu,baradw,pa la du,parado~u,Параду,بارادو,パラドゥー,帕拉杜', 43.7172900, 4.7845800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52299, 'Pantin', 'Pantin', 'Panten,Pantin,bantan,pang tan,pangtaeng,pantan,pantn,Пантен,Пантин,بانتان,پانتن,パンタン,庞坦,팡탱', 48.8943700, 2.4093500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52300, 'Pannes', 'Pannes', 'Pannes', 48.0193700, 2.6675500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52301, 'Pannecé', 'Pannece', 'Panezeg,Pannece,Pannecé,Pannse,pa nei sai,Паннсе,帕内塞', 47.4858300, -1.2394000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52302, 'Panissières', 'Panissieres', 'Panissieres,Panissières', 45.7928200, 4.3395500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52303, 'Pancé', 'Pance', 'Pance,Pancé,Panse,Pantieg,pang sai,Пансе,庞塞', 47.8818100, -1.6595300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52304, 'Panazol', 'Panazol', 'Panasou,Panasòu,Panazol,Panazol'',pa na zuo,Паназоль,帕纳佐', 45.8346500, 1.3275900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52305, 'Pamproux', 'Pamproux', 'Pamproux', 46.3957800, -0.0532700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52306, 'Pamiers', 'Pamiers', 'Appamiae,Pam''e,Pame,Pamias,Pamiers,Pamies,Pamje,Pamjē,Pàmias,Pàmies,pa mi ye,pamie,pamyh,Памье,Памє,پامیه,パミエ,帕米耶', 43.1166700, 1.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52307, 'Palinges', 'Palinges', 'Palinges', 46.5535700, 4.2196400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52308, 'Palavas-les-Flots', 'Palavas-les-Flots', 'Palavas,Palavas-le-Flo,Palavas-les-Flots,Palavàs,pa la wa lai fu luo te,Палавас-ле-Фло,帕拉瓦莱弗洛特', 43.5280500, 3.9270500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52309, 'Palau-del-Vidre', 'Palau-del-Vidre', 'Palau,Palau-del-Vidre', 42.5716200, 2.9603300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52310, 'Palaja', 'Palaja', 'Palaja', 43.1736300, 2.3846200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52311, 'Palaiseau', 'Palaiseau', 'Palaiseau,Palezo,Paliseau,balyzw,pa lai suo,pallejo,parezo,plzw,Палезо,باليزو,پلزو,パレゾー,帕莱索,팔레조', 48.7166700, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52312, 'Paimpont', 'Paimpont', 'Paimpont,Panis Pontis,Pempon,Pempont,pan peng,Пемпон,潘蓬', 48.0180900, -2.1710500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52313, 'Paimpol', 'Paimpol', 'Paimpol,Pempol'',Pempoull,Pimpolium,pan bo,Пемполь,潘波', 48.7784100, -3.0437500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52314, 'Paimboeuf', 'Paimboeuf', 'Paimboeuf,Paimbœuf,Pembef,Pembo,Saint-Paimboeuf,pan bo e,Пембеф,潘博厄', 47.2865400, -2.0304800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52315, 'Paillet', 'Paillet', 'Pae,Paillet,Palhet,pei lai,Пае,Пає,佩莱', 44.6851200, -0.3650000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52316, 'Pagny-sur-Moselle', 'Pagny-sur-Moselle', 'Pagny,Pagny-sur-Moselle,Pan''i-sjur-Mozel'',mo sai er he pan pa ni,Паньи-сюр-Мозель,Паньї-сюр-Мозель,莫塞尔河畔帕尼', 48.9834900, 6.0208400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52317, 'Pacy-sur-Eure', 'Pacy-sur-Eure', 'Pacy,Pacy-sur-Eure', 49.0166700, 1.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52318, 'Pacé', 'Pace', 'Pace,Pacé,Pazieg', 48.1484800, -1.7732700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52319, 'Pabu', 'Pabu', 'Pabju,Pabu,pa bi,Пабю,帕比', 48.5860800, -3.1360800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52320, 'Ozouer-le-Voulgis', 'Ozouer-le-Voulgis', 'Ozouer,Ozouer-le-Voulgis,Ozue-le-Vul''zhi,Озуе-ле-Вульжи,Озуе-ле-Вульжі', 48.6601200, 2.7740900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52321, 'Ozoir-la-Ferrière', 'Ozoir-la-Ferriere', 'Ozoar la Ferje,Ozoir,Ozoir-la-Ferriere,Ozoir-la-Ferrière,Ozoir-la-Raison,Ozuar-la-Ferr''er,Ozuar-la-Ferrer,awzwar lfryyr,awzwar-la-fryyr,ojualeulapelieleu,ozowaru=ra=ferieru,Озоар ла Ферје,Озуар-ла-Феррьер,Озуар-ла-Феррєр,اوزوآر لفریئر,اوزوآر-لا-فرییر,オゾワール＝ラ＝フェリエール,오주아르라페리에르', 48.7669900, 2.6687100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52322, 'Oytier-Saint-Oblas', 'Oytier-Saint-Oblas', 'Oytier,Oytier-Saint-Oblas', 45.5610400, 5.0206500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52323, 'Oyonnax', 'Oyonnax', 'Ojonaks,Ojonna,Oyannax,Oyonnax,awywna,awywnks,oyona,wa yue na ke si,Ойонна,Ојонакс,أويونا,اویونکس,オヨナ,瓦约纳克斯,오요나', 46.2591700, 5.6572700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52324, 'Oye-Plage', 'Oye-Plage', 'Ooie,Oye,Oye-Plage,Ua-Plazh,ao ye pu la ri,awyy blaj,Уа-Плаж,أويي بلاج,奥耶普拉日', 50.9771300, 2.0427600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52325, 'Ouzouer-sur-Trézée', 'Ouzouer-sur-Trezee', 'Ouzouer,Ouzouer-sur-Trezee,Ouzouer-sur-Trézée,Uzue-sjur-Treze,te lei ze ai he pan wu zu ai,Узуе-сюр-Трезе,特雷泽埃河畔乌祖埃', 47.6726600, 2.8080000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52326, 'Ouzouer-sur-Loire', 'Ouzouer-sur-Loire', 'Ouzouer-sur-Loire,Uzue-sjur-Luar,lu wa er he pan wu zu ai,Узуе-сюр-Луар,卢瓦尔河畔乌祖埃', 47.7663800, 2.4803800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52327, 'Ouzouer-le-Marché', 'Ouzouer-le-Marche', 'Ouzouer,Ouzouer-le-Marche,Ouzouer-le-Marché', 47.9105500, 1.5260700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52328, 'Ouveillan', 'Ouveillan', 'Ouveillan', 43.2891500, 2.9712400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52329, 'Outreau', 'Outreau', 'Outreau,Outriauwe,Utro,awtryaw,wu te luo,Утро,أوترياو,乌特罗', 50.7053500, 1.5897000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52330, 'Outarville', 'Outarville', 'Outarville,Utarvil'',wu ta er wei er,Утарвіль,乌塔尔维尔', 48.2139300, 2.0219800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52331, 'Ousse', 'Ousse', 'Ousse', 43.2833300, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52332, 'Ourville-en-Caux', 'Ourville-en-Caux', 'Ourville,Ourville-en-Caux', 49.7285400, 0.6046000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52333, 'Oursbelille', 'Oursbelille', 'Oursbelille', 43.2850800, 0.0347300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52334, 'Ouroux-sur-Saône', 'Ouroux-sur-Saone', 'Ouroux,Ouroux-sur-Saone,Ouroux-sur-Saône,Uru-sjur-Son,Уру-сюр-Сон', 46.7214700, 4.9526200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52335, 'Oullins', 'Oullins', 'Oullins,Ulen,Ullen,awln,awlynz,ullaeng,uran,Улен,Уллен,أولينز,اولن,ウラン,울랭', 45.7177400, 4.8038200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52336, 'Oulins', 'Oulins', 'Oulins', 48.8645100, 1.4703800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52337, 'Ouistreham', 'Ouistreham', 'Ouistrehain,Ouistreham,Uistream,wu yi si te lei ang,Уистреам,Уїстреам,乌伊斯特雷昂', 49.2756600, -0.2591000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52338, 'Ouges', 'Ouges', 'Ouges', 47.2616400, 5.0739500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52339, 'Oudon', 'Oudon', 'Oudon,Udon,Uldo,wu dong,Удон,乌东', 47.3477400, -1.2850000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52340, 'Oucques', 'Oucques', 'Oncques,Oucques,Ukk,wu qu ai,Укк,乌屈埃', 47.8225200, 1.2938300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52341, 'Ouches', 'Ouches', 'Ouches', 46.0165700, 3.9882400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52342, 'Ottrott', 'Ottrott', 'Ottrot,ao te luo,awtrwt,ottorotto,Оттрот,أوتروت,オットロット,奥特罗', 48.4564200, 7.4255600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52343, 'Ottmarsheim', 'Ottmarsheim', 'Ottmarsheim', 47.7865500, 7.5093500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52344, 'Otterswiller', 'Otterswiller', '', 48.7256800, 7.3787800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52345, 'Ottange', 'Ottange', 'Ottange', 49.4419100, 6.0173400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52346, 'Othis', 'Othis', 'Oti,Оти,Оті', 49.0738700, 2.6750200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52347, 'Ostwald', 'Ostwald', 'Ostwald', 48.5436900, 7.7109900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52348, 'Ostricourt', 'Ostricourt', 'Ostricourt,Ostrikur,ao si te li ku er,Острикур,奥斯特里库尔', 50.4514500, 3.0341700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52349, 'Ostheim', 'Ostheim', 'Ostheim', 48.1599900, 7.3698200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52350, 'Ossun', 'Ossun', 'Aussun,Aussun de Tarba,Beauvais-de-Preau,Beauvais-de-Préau,Mardin,Osjon,Ossen,Ossun,awswn,Оссен,Осён,اوسون', 43.1833300, -0.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52351, 'Osséja', 'Osseja', 'Oceja,Osseja,Osséja', 42.4138300, 1.9819200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52352, 'Ossé', 'Osse', 'Oc''heg,Ocheg,Osse,Ossé,ao sai,Оссе,奥塞', 48.0554200, -1.4502900, 'FR', '2017-06-01', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52353, 'Osny', 'Osny', 'Oni,Osny,ao ni,Они,Оні,奥尼', 49.0701000, 2.0627700, 'FR', '2016-03-01', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52354, 'Orvault', 'Orvault', 'Orsvaldum,Orvault,Orvez,Orvo,ao er wo,awrww,oleubo,oruvu~o,Орво,اوروو,オルヴォー,奧爾沃,오르보', 47.2709500, -1.6219000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52355, 'Orval', 'Orval', 'Orval', 46.7258100, 2.4714400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52356, 'Orthez', 'Orthez', 'Ortes,Ortesium,Ortez,Orthe,Orthez,Ortheze,Ortès,ao er tai,orutezu,Ортез,オルテズ,奥尔泰', 43.4883900, -0.7724400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52357, 'Ortaffa', 'Ortaffa', 'Ortafa,Ortaffa,Ortafà', 42.5797700, 2.9265300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52358, 'Orsay', 'Orsay', 'Orsay,Orse,ao sai,oruse,Орсе,オルセー,奧賽', 48.6957200, 2.1872700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52359, 'Orsan', 'Orsan', 'Orsan,ao er sang,Орсан,奥尔桑', 44.1310600, 4.6652000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52360, 'Orry-la-Ville', 'Orry-la-Ville', 'Orri-la-Vil'',Orry,Orry-la-Ville,ao er li la wei er,Орри-ла-Виль,Оррі-ла-Віль,奥尔里拉维尔', 49.1334500, 2.5113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52361, 'Ornex', 'Ornex', 'Orne,Ornex,ao er nei ke si,awrnyh,Орне,Օրնե,أورنيه,奥尔内克斯', 46.2727000, 6.0998200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52362, 'Ornans', 'Ornans', 'Ornacum,Ornan,Ornans,ao er nan,Орнан,奥尔南', 47.1074900, 6.1430600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52363, 'Ornaisons', 'Ornaisons', 'Ornaisons', 43.1804000, 2.8368900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52364, 'Ormoy', 'Ormoy', 'Ormoy', 48.5748900, 2.4520600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52365, 'Ormesson-sur-Marne', 'Ormesson-sur-Marne', 'Ormesson,Ormesson-sjur-Marn,Ormesson-sur-Marne,ma en he pan ao er mei song,Ормессон-сюр-Марн,马恩河畔奥尔梅松', 48.7863000, 2.5447100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52366, 'Ormes', 'Ormes', 'Ormes', 47.9415200, 1.8182300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52367, 'Orly', 'Orly', 'Orli,Orly,ao li,awrly,oleulli,oruri,Орли,Орлі,אורלי,اورلی,オルリー,奥利,오를리', 48.7479200, 2.3925300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52368, 'Orliénas', 'Orlienas', 'Orlienas,Orliénas', 45.6585900, 4.7170700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52369, 'Orleix', 'Orleix', 'Orleix', 43.2793200, 0.1203300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52370, 'Orléat', 'Orleat', 'Orleat,Orléat', 45.8616300, 3.4219400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52371, 'Orléans', 'Orleans', 'Aurelianum,Gorad Arlean,ORE,Orleaes,Orlean,Orleana,Orleanas,Orleani,Orleans,Orleañs,Orleáns,Orleães,Orleāna,Orliens,Orlèans,Orléans,ao er liang,awrlyan,awrlynz,oleulleang,orleani,orleyom,orurean,xxr lex xng,Ορλεάνη,Горад Арлеан,Орлеан,Օռլեան,אורליאן,أورليان,اورلئان,اورلینز,ओर्लेयों,ออร์เลอ็อง,အော်လီယန်းမြို့,ორლეანი,オルレアン,奥尔良,奧爾良,오를레앙', 47.9028900, 1.9038900, 'FR', '2016-10-30', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52372, 'Orival', 'Orival', 'Orival', 49.7242900, 1.2051200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52373, 'Origny-Sainte-Benoite', 'Origny-Sainte-Benoite', 'Origny,Origny-sur-Oise', 49.8333300, 3.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52374, 'Origny-en-Thiérache', 'Origny-en-Thierache', 'Origny,Origny-en-Thierache,Origny-en-Thiérache,Origny-sur-le-Thon', 49.8932700, 4.0164400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52375, 'Orgueil', 'Orgueil', 'Orgueil', 43.9061800, 1.4107100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52376, 'Orgon', 'Orgon', 'Orgon,ao er gong,Оргон,奥尔贡', 43.7910800, 5.0386900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52377, 'Orgeval', 'Orgeval', 'Orgeval', 48.9216200, 1.9779000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52378, 'Orgerus', 'Orgerus', 'Orgerus,Orzherju,Оржерю', 48.8385100, 1.7013200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52379, 'Orgères-en-Beauce', 'Orgeres-en-Beauce', 'Orgeres,Orgeres-en-Beauce,Orgères,Orgères-en-Beauce', 48.1463600, 1.6838000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52380, 'Orgères', 'Orgeres', 'An Heizeg,Orgeres,Orgères', 47.9988600, -1.6678100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52381, 'Orgelet', 'Orgelet', 'Orgelet', 46.5209600, 5.6104900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52382, 'Orcines', 'Orcines', 'Orcines,Orsin,ao er xi nei,Орсін,奥尔西内', 45.7838000, 3.0122000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52383, 'Orchies', 'Orchies', 'Orchies,Orshi,ao er xi,Орши,Орші,奥尔希', 50.4666700, 3.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52384, 'Orchamps-Vennes', 'Orchamps-Vennes', 'Orchamps,Orsham-Venn,ao er shang pu wei nei,Оршам-Венн,奥尔尚普韦内', 47.1304200, 6.5246800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52385, 'Orchamps', 'Orchamps', 'Orchamps', 47.1475100, 5.6587300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52386, 'Orcet', 'Orcet', 'Orcet', 45.7035100, 3.1680700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52387, 'Orbey', 'Orbey', 'Orbe,ao er bei,Орбе,奥尔贝', 48.1265100, 7.1645500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52388, 'Orbec', 'Orbec', 'Orbec-en-Auge,Orbek,ao er bei ke,Орбек,奥尔贝克', 49.0166700, 0.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52389, 'Orange', 'Orange', 'Arausio,Aurenja,Orange,Oranz,Oranzas,Oranzh,Oranžas,ao lang ri,awranzh  wwklwz,awrnj  wwklwz,olangju,oranju,xx r xngch,Оранж,Օրանժ,אורנז,اورانژ، ووکلوز,اورنج، ووکلوز,ออร็องฌ์,オランジュ,奥朗日,오랑주', 44.1392000, 4.8079100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52390, 'Oraison', 'Oraison', 'Oraison', 43.9160900, 5.9175600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52391, 'Oradour-sur-Vayres', 'Oradour-sur-Vayres', 'Oradour,Oradour-sur-Vavres,Oradour-sur-Vayres,Quardor', 45.7328600, 0.8645700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52392, 'Oradour-sur-Glane', 'Oradour-sur-Glane', 'Matanza de Oradour-sur-Glane,Orador de Glana,Oradour,Oradour-sur-Glane,Oradur sir Glan,Oradur-sjur-Glan,Roche-sur-Graine,ge la ne he pan ao la du er,oladuleu swileu geullan,orado~uru=shuru=guranu,Орадур сир Глан,Орадур-сюр-Глан,אורדור-סור-גלאן,オラドゥール＝シュル＝グラヌ,格拉讷河畔奥拉杜尔,오라두르 쉬르 글란', 45.9340500, 1.0317000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52393, 'Oppède', 'Oppede', 'Aupeda,Opeda,Opped,Oppede,Oppede-les-Poulivets,Oppède,Oppède-les-Poulivets,ao pei de,Оппед,奥佩德', 43.8286500, 5.1616100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52394, 'Opio', 'Opio', 'Opio', 43.6686200, 6.9821200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52395, 'Onzain', 'Onzain', 'Onzain,Onzen,weng zan,Онзен,翁赞', 47.4995600, 1.1770100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52396, 'Ons-en-Bray', 'Ons-en-Bray', 'Ons,Ons-en-Bray,Onsembray', 49.4163100, 1.9230200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52397, 'Onnaing', 'Onnaing', 'Onnaing', 50.3858400, 3.5996300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52398, 'Onesse-Laharie', 'Onesse-Laharie', 'Onesse,Onesse-et-Laharie', 44.0614600, -1.0698400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52399, 'Ondres', 'Ondres', 'Ondr,Ondres,weng de lei,Ондр,翁德雷', 43.5646100, -1.4444900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52400, 'Ondes', 'Ondes', 'Ond,Ondas,Ondes,weng dai,Онд,翁代', 43.7825000, 1.3082300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52401, 'Omissy', 'Omissy', 'Omissy', 49.8776000, 3.3123500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52402, 'Oloron-Sainte-Marie', 'Oloron-Sainte-Marie', 'Auloron,Auloron e Senta Maria,Aulorón,Maratide,Olaro,Oloroe-Donamaria,Oloron,Oloron Ste Marie,Oloron-Sent-Mari,Redoute-Maritime,Redoute-de-l''Agly,ao luo long-sheng ma li,ororon=santo=mari,Олорон-Сент-Мари,Олорон-Сент-Марі,オロロン＝サント＝マリー,奥洛龙-圣玛丽', 43.1944100, -0.6106900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52403, 'Olonzac', 'Olonzac', 'Olonzac', 43.2829400, 2.7309800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52404, 'Olonne-sur-Mer', 'Olonne-sur-Mer', 'Olonn-sjur-Mer,Olonne,Olonne-sur-Mer,bin hai ao luo na,Олонн-сюр-Мер,滨海奥洛纳', 46.5352400, -1.7729300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52405, 'Olmeto', 'Olmeto', 'Olmeto', 41.7188500, 8.9202300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52406, 'Ollioules', 'Ollioules', 'Ol''jul'',Oliolas,Oliulas,Ollioules,Olliul'',ao li wu lei,Олліуль,Ольюль,奥利乌勒', 43.1351700, 5.8480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52407, 'Ollainville', 'Ollainville', 'Ollainville', 48.5908100, 2.2193600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52408, 'Olivet', 'Olivet', 'Oliva,Olivet,Олива', 47.8621900, 1.8991000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52409, 'Oletta', 'Oletta', 'Oletta,Олетта', 42.6323700, 9.3560000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52410, 'Olemps', 'Olemps', 'Olan,Olem,ao lang pu,Олан,Олем,奥朗普', 44.3463800, 2.5514000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52411, 'Oisy-le-Verger', 'Oisy-le-Verger', 'Oisy,Oisy-le-Verger,Uazi-le-Verzhe,awysy ly fyrjyr,wa xi lei wei er ri,Уази-ле-Верже,Уазі-ле-Верже,أويسي لي فيرجير,瓦西勒韦尔日', 50.2504700, 3.1233000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52412, 'Oissery', 'Oissery', 'Oissery', 49.0704700, 2.8181900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52413, 'Oissel', 'Oissel', 'Oissel,Oissel-sur-Seine,Uassel'',Уассель', 49.3330900, 1.0941300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52414, 'Oisseau', 'Oisseau', 'Oisseau,Uasso,wa suo,Уассо,瓦索', 48.3555900, -0.6714800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52415, 'Oisemont', 'Oisemont', 'Oesemont,Oisemont,Oésemont,Uazmon,wa si meng,Уазмон,瓦斯蒙', 49.9558700, 1.7670300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52416, 'Oinville-sur-Montcient', 'Oinville-sur-Montcient', 'Oinville,Oinville-sur-Montcient,Uenvil''-sjur-Mons''jan,Уенвиль-сюр-Монсьян,Уенвіль-сюр-Монсьян', 49.0272200, 1.8492800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52417, 'Oignies', 'Oignies', 'Oignies', 50.4633100, 2.9937600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52418, 'Ohlungen', 'Ohlungen', 'Ohlungen', 48.8112000, 7.7007500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52419, 'Ognes', 'Ognes', 'Ognes', 49.6124400, 3.1934000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52420, 'Ogeu-les-Bains', 'Ogeu-les-Bains', 'Augeu,Ogeu,Ogeu-les-Bains,Ozhe-le-Ben,Ozhjo-le-Ben,ao re lai ban,Оже-ле-Бен,Ожё-ле-Бен,奥热莱班', 43.1500000, -0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52421, 'Offranville', 'Offranville', 'Offranville', 49.8720800, 1.0481700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52422, 'Offenheim', 'Offenheim', 'Offenheim', 48.6307400, 7.6175200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52423, 'Offemont', 'Offemont', 'Offemon,Offemont,ao fei meng,Оффемон,奥费蒙', 47.6641600, 6.8805600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52424, 'Oeyreluy', 'Oeyreluy', 'Oeyreluy', 43.6687600, -1.0827600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52425, 'Œting', 'Oeting', 'OEting,Œting', 49.1666700, 6.9166700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52426, 'Oermingen', 'Oermingen', 'Oermingen,Ormingen', 48.9989900, 7.1274400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52427, 'Odos', 'Odos', 'Audos,Audòs,Odos,ao duo,Одос,奥多', 43.1962200, 0.0569300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52428, 'Oderen', 'Oderen', 'Oderen,Odern,ao de lang,Одерен,奥德朗', 47.9105300, 6.9747500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52429, 'Octeville-sur-Mer', 'Octeville-sur-Mer', 'Octeville,Octeville-sur-Mer', 49.5549600, 0.1166000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52430, 'Octeville', 'Octeville', '', 49.6261200, -1.6434900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52431, 'Objat', 'Objat', 'Objat', 45.2623800, 1.4078100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52432, 'Oberschaeffolsheim', 'Oberschaeffolsheim', 'Oberschaeffolsheim,Oberschäffolsheim,Obersheffol''sajm,Schafelse,abrshflshaym,ao bei er si sha ai fu er sang,awbrstshayfwlshym,Обершеффольсайм,أوبرستشايفولشيم,ابرشفلسهایم,奥贝尔斯沙埃福尔桑', 48.5864300, 7.6501800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52433, 'Obernai', 'Obernai', 'Ewernahn,Ewernàhn,Oberehnheim,Obernai,Oberne,Ompernai,ao bei er nai,awbyrnay,oberune,Ομπερναί,Оберне,אוברנה,أوبيرناي,オベルネ,奥贝尔奈', 48.4631300, 7.4810000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52434, 'Obermodern-Zutzendorf', 'Obermodern-Zutzendorf', '', 48.8500000, 7.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52435, 'Oberhoffen-sur-Moder', 'Oberhoffen-sur-Moder', 'Oberhofen,Oberhoffen,Oberhoffen-sur-Moder,Oberhosen', 48.7805900, 7.8692600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52436, 'Oberhergheim', 'Oberhergheim', 'Oberhergheim', 47.9684900, 7.3960900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52437, 'Oberhausbergen', 'Oberhausbergen', 'Oberosbergen,Owerhuesbarje,Owerhüsbàrje,abrhawsbrgn,ao bo luo si bo er rang,awbrhasbyrghyn,Оберосберген,أوبرهاسبيرغين,ابرهاوسبرگن,奥伯罗斯伯尔让', 48.6060700, 7.6884600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52438, 'Oberhaslach', 'Oberhaslach', 'Oberhaslach', 48.5503900, 7.3321300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52439, 'Oberbronn', 'Oberbronn', '', 48.9402000, 7.6070000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52440, 'Betschdorf', 'Betschdorf', 'Batschdorf,Bechdorf,Betshdorf,Oberbetschdorf,bchdwrf,bei te si ke duo er,betchidorufu,bytstshdwrf,Бетшдорф,Бечдорф,بيتستشدورف,بچدورف,ベッチドルフ,贝特斯克多尔', 48.9000000, 7.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52441, 'Obenheim', 'Obenheim', 'Obenheim', 48.3592100, 7.6895200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52442, 'Nyons', 'Nyons', 'N''on,Niom,Nion,Nyons,ni yong si,niyon,Ньон,Ніон,ንዮን,ニヨン,尼永斯', 44.3666700, 5.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52443, 'Nyoiseau', 'Nyoiseau', 'Nyoiseau', 47.7166700, -0.9166700, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52444, 'Nuits-Saint-Georges', 'Nuits-Saint-Georges', 'Njui-Sen-Zhorzh,Nuits,Nuits-Saint-Georges,ni yi te sheng ruo er re,nwyy-sn-zhrzh,nyui=san=joruju,Нюи-Сен-Жорж,Нюї-Сен-Жорж,نویی-سن-ژرژ,ニュイ＝サン＝ジョルジュ,尼伊特圣若尔热', 47.1368300, 4.9490000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52445, 'Nuillé-sur-Vicoin', 'Nuille-sur-Vicoin', 'Nuille,Nuille-sur-Vicoin,Nuillé,Nuillé-sur-Vicoin', 47.9855600, -0.7835100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52446, 'Nueil-sur-Layon', 'Nueil-sur-Layon', 'Njuej-sjur-Lejon,Nueil,Nueil-sur-Layon,lai weng he pan ni ai,Нюей-сюр-Лейон,莱翁河畔尼埃', 47.1181100, -0.3657300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52447, 'Nueil-les-Aubiers', 'Nueil-les-Aubiers', 'Aubiers,Njuej-lez-Obe,Nueil,Obije,Нюей-лез-Обє,Обије', 46.9333300, -0.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52448, 'Nuaillé', 'Nuaille', 'Njuae,Nuaille,Nuaillé,ni ai lai,Нюає,尼艾莱', 47.0952400, -0.7947700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52449, 'Nozay', 'Nozay', 'Nozay,Nozjo,Нозё', 48.6592100, 2.2415100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52450, 'Nozay', 'Nozay', 'Nozay,Nozieg', 47.5649500, -1.6262900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52451, 'Noyon', 'Noyon', 'Noajon,Noeyon,Noviomum,Noyon,Noéyon,Nuajon,Nyon,nowaiyon,nu wa yong,Ноайон,Нуайон,ኖዮን,ノワイヨン,努瓦永', 49.5833300, 3.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52452, 'Noyers-sur-Cher', 'Noyers-sur-Cher', 'Noyers,Noyers-sur-Cher', 47.2770100, 1.4032000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52453, 'Noyen-sur-Sarthe', 'Noyen-sur-Sarthe', 'Noyen,Noyen-sur-Sarthe', 47.8718700, -0.0991600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52454, 'Noyelles-sous-Lens', 'Noyelles-sous-Lens', 'Noielles-dsous-Lins,Noyelles,Noyelles-sous-Lens,Noïelles-dsous-Lins,Nuael''-su-Lan,Nuajel''-su-Lans,nu wa ye er su lang si,nwylys sws lyns,Нуаель-су-Лан,Нуайель-су-Ланс,Нуаєль-су-Лан,نويليس سوس لينس,努瓦耶尔苏朗斯', 50.4308400, 2.8722100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52455, 'Noyelles-lès-Vermelles', 'Noyelles-les-Vermelles', 'Noyelles,Noyelles-les-Vermelles,Noyelles-lez Vermelles,Noyelles-lès-Vermelles,Nuael''-le-Vermel'',nu wa ye er lai wei er mei er,nwylys lyh fyrmylys,Нуаель-ле-Вермель,Нуаєль-ле-Вермель,نويليس ليه فيرميليس,努瓦耶尔莱韦尔梅尔', 50.4900100, 2.7262800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52456, 'Noyelles-Godault', 'Noyelles-Godault', 'Noeyel-Godault,Noyelles-Godault,Nuael''-Godo,Nuajel''-Godo,Nöyel-Godault,nu wa ye er ge duo,nwylys jwdawlt,Нуаель-Годо,Нуайель-Годо,Нуаєль-Годо,نويليس جوداولت,努瓦耶尔戈多', 50.4175300, 2.9930600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52457, 'Noyarey', 'Noyarey', 'Noyarey,Nuajare,nu wa a lei,Нуайаре,Нуаяре,努瓦阿雷', 45.2476000, 5.6283700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52458, 'Noyant-la-Gravoyère', 'Noyant-la-Gravoyere', 'Noyant,Noyant-la-Gravoyere,Noyant-la-Gravoyère,Nuajan-la-Gravuaer,nu wa ang la ge la wa ai er,Нуаян-ла-Гравуаєр,努瓦昂拉格拉瓦埃尔', 47.7034800, -0.9573000, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52459, 'Noyant', 'Noyant', 'Noiant,Noyant,Noyant-sous-le-Lude,Nuajan,nu wa ang,Нуаян,努瓦昂', 47.5104800, 0.1177100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52460, 'Noyal-sur-Vilaine', 'Noyal-sur-Vilaine', 'Noal-ar-Gwilen,Noyal,Noyal-sur-Vilaine,Nuajal''-sjur-Vilen,Nulliacum super Vicenoniam,wei lan he pan nu wa a,Нуаяль-сюр-Вилен,Нуаяль-сюр-Вілен,维兰河畔努瓦阿', 48.1121900, -1.5233300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52461, 'Noyal-Pontivy', 'Noyal-Pontivy', 'Noal-Pondi,Noal-Pondivi,Noyal-Pontivy,Nuajal''-Pontivi,nu wa a peng di wei,Нуаяль-Понтиви,Нуаяль-Понтіві,努瓦阿蓬蒂维', 48.0666700, -2.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52462, 'Noyal-Muzillac', 'Noyal-Muzillac', 'Noal-Muzilheg,Noyal-Muzillac,Nuajal''-Mjuzijak,nu wa a mi qi la ke,Нуаяль-Мюзияк,Нуаяль-Мюзіяк,努瓦阿米齐拉克', 47.5916900, -2.4555700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52463, 'Novillars', 'Novillars', 'Novillars', 47.2846500, 6.1287800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52464, 'Noves', 'Noves', 'Nov,Novas,Noves,Nòvas,nuo wei,Нов,诺韦', 43.8773600, 4.9024800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52465, 'Novéant-sur-Moselle', 'Noveant-sur-Moselle', 'Noveant,Noveant-sur-Moselle,Novéant,Novéant-sur-Moselle', 49.0215400, 6.0455800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52466, 'Novalaise', 'Novalaise', 'Novalaise,Novalez,Новалез', 45.5969300, 5.7659100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52467, 'Nouzonville', 'Nouzonville', 'Nouzon,Nouzonville,Nuzonvil'',nu zong wei er,Нузонвиль,Нузонвіль,努宗维尔', 49.8136900, 4.7473600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52468, 'Nouzilly', 'Nouzilly', 'Nouzilly,Nuzii,nu qi li,Нузії,努齐利', 47.5449900, 0.7462300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52469, 'Nouvoitou', 'Nouvoitou', 'Neveztell,Nouvoitou', 48.0410500, -1.5471400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52470, 'Nouvion-sur-Meuse', 'Nouvion-sur-Meuse', 'Nouvion,Nouvion-sur-Meuse', 49.6994900, 4.7956200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52471, 'Nouvion', 'Nouvion', 'Nouvion-en-Ponthieu,Nouvion-in-Pontiu,Nuv''on,Nuvion,nu wei yong,nuvu~ion,Нувион,Нувьон,Нувіон,ヌヴィオン,努维永', 50.2000000, 1.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52472, 'Nousty', 'Nousty', 'Nostin,Nusti,nu si di,Нусти,Нусті,努斯蒂', 43.2666700, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52473, 'Nouan-le-Fuzelier', 'Nouan-le-Fuzelier', 'Nouan,Nouan-le-Fuzelier,Nuan-le-Fjuzel''e,nu ang lai fei ze li ye,Нуан-ле-Фюзельє,努昂莱菲泽利耶', 47.5360000, 2.0364700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52474, 'Nouaillé-Maupertuis', 'Nouaille-Maupertuis', 'Nouaille,Nouaille-Maupertuis,Nouaillé,Nouaillé-Maupertuis,Nuae-Mopertjui,nu ai lei mo pei er di yi,Нуає-Мопертюї,努艾勒莫佩尔蒂伊', 46.5111300, 0.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52475, 'Notre-Dame-des-Landes', 'Notre-Dame-des-Landes', 'Kernitron-al-Lann,Notr-Dam-de-Land,Notre-Dame,Notre-Dame-des-Landes,nuo te er da mei-dai lang dai,Нотр-Дам-де-Ланд,诺特尔达梅-代朗代', 47.3804800, -1.7090400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52476, 'Notre-Dame-de-Sanilhac', 'Notre-Dame-de-Sanilhac', 'Nostra Dama de Sanilhac,Notr-Dam-de-San''jak,Notr-Dam-de-Sanijak,Notre-Dame,Notre-Dame-de-Sanilhac,Nòstra Dama de Sanilhac,Sanilhac,nuo te lei-dang de sa ni ya ke,Нотр-Дам-де-Санийак,Нотр-Дам-де-Саньяк,诺特雷-当德萨尼亚克', 45.1212100, 0.7115700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52477, 'Notre-Dame-de-Riez', 'Notre-Dame-de-Riez', 'Notr-Dam-de-Rez,Notre-Dame-de-Riez,Riez,nuo te lei-da mo de li ye,Нотр-Дам-де-Рєз,诺特雷-达默德里耶', 46.7444500, -1.9085700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52478, 'Notre-Dame-de-Monts', 'Notre-Dame-de-Monts', 'Notr-Dam-de-Mon,Notre-Dame,nuo te lei-da mo de meng te,Нотр-Дам-де-Мон,诺特雷-达默德蒙特', 46.8310000, -2.1310000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52479, 'Notre-Dame-de-Mésage', 'Notre-Dame-de-Mesage', 'Notr-Dam-de-Mezazh,Notre-Dame-de-Mesage,Notre-Dame-de-Mésage,nuo te lei-dang de mei sa ge,Нотр-Дам-де-Мезаж,诺特雷-当德梅萨格', 45.0624100, 5.7588000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52480, 'Notre-Dame-de-Gravenchon', 'Notre-Dame-de-Gravenchon', 'Notr-Dam-de-Gravanshon,Notre-Dame-de-Gravenchon,Нотр-Дам-де-Граваншон', 49.4894000, 0.5718800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52481, 'Notre-Dame-de-Fresnay', 'Notre-Dame-de-Fresnay', 'Notre-Dame,Notre-Dame-de-Fresnay', 48.9626500, 0.0427100, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52482, 'Notre-Dame-de-Bondeville', 'Notre-Dame-de-Bondeville', 'Notre-Dame,Notre-Dame-de-Bondeville', 49.4833300, 1.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52483, 'Nostang', 'Nostang', 'Lostenk,Nostang', 47.7487000, -3.1863900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52484, 'Nort-sur-Erdre', 'Nort-sur-Erdre', 'Enorzh,Nor-sjur-Erdr,Nort,Nort-sur-Erdre,Nortum,ai er de er he pan nuo er,noru=shuru=erudoru,Нор-сюр-Ердр,ノール＝シュル＝エルドル,埃尔德尔河畔诺尔', 47.4388100, -1.4983300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52485, 'Nortkerque', 'Nortkerque', 'Nortkerk,Nortkerque,nuo er kai er ke,nwrtkyrkyw,Норткерк,نورتكيركيو,诺尔凯尔克', 50.8751900, 2.0246400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52486, 'Norroy-lès-Pont-à-Mousson', 'Norroy-les-Pont-a-Mousson', 'Norroy,Norroy-les-Pont-a-Mousson,Norroy-lès-Pont-à-Mousson', 48.9346000, 6.0280600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52487, 'Norrent-Fontes', 'Norrent-Fontes', 'Norran-Font,Norrint-Fontes,nuo lang feng tai,nwrynt fwnts,Норран-Фонт,نورينت فونتس,诺朗丰泰', 50.5833300, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52488, 'Normanville', 'Normanville', 'Normanville', 49.0786800, 1.1591500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52489, 'Nordhouse', 'Nordhouse', 'Nordhausen', 48.4483300, 7.6732600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52490, 'Nontron', 'Nontron', 'Nontron,Nontronh,nong te long,nontoron,Нонтрон,ノントロン,农特龙', 45.5333300, 0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52491, 'Nonancourt', 'Nonancourt', 'Nonancourt', 48.7708600, 1.1979900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52492, 'Nommay', 'Nommay', 'Nommay', 47.5378000, 6.8421900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52493, 'Nomexy', 'Nomexy', 'Nomexy', 48.3074100, 6.3857200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52494, 'Nomeny', 'Nomeny', 'Nom ny,Nomeni,Nòm ny,nuo mo ni,Номени,Номені,诺默尼', 48.9000000, 6.2333300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52495, 'Nomain', 'Nomain', 'Nomain,Nomen,nuo man,Номен,诺曼', 50.4985700, 3.2499100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52496, 'Nolay', 'Nolay', 'Nolay', 46.9520200, 4.6340500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52497, 'Noizay', 'Noizay', 'Noizay', 47.4218800, 0.8920100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52498, 'Noisy-sur-École', 'Noisy-sur-Ecole', 'Noisy,Noisy-sur-Ecole,Noisy-sur-École', 48.3670100, 2.5080400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52499, 'Noisy-le-Sec', 'Noisy-le-Sec', 'Noazi,Noisy,Noisy-le-Sec,Nuazi-le-Sek,Shumnaja-le-Sek,nowaji=ru=sekku,nuajileusekeu,nuo wa xi lei sai ke,nwazy lw sk,Ноази,Нуази-ле-Сек,Нуазі-ле-Сек,Шумная-ле-Сек,نوآزی لو سک,ノワジー＝ル＝セック,诺瓦西勒塞克,누아지르세크', 48.8914800, 2.4645100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52500, 'Noisy-le-Roi', 'Noisy-le-Roi', 'Noisy,Noisy-le-Roi,Nuazi-le-Rua,nowaji=ru=rowa,Нуази-ле-Руа,Нуазі-ле-Руа,ノワジー＝ル＝ロワ', 48.8444500, 2.0634500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52501, 'Noisy-le-Grand', 'Noisy-le-Grand', 'Noazi le Gran,Noisy,Noisy-le-Grand,Nuazi-le-Gran,Shumnaja-le-Gran,da nuo wa xi,nowaji=ru=guran,nwazy lw ghran,nwazy-lw-grand,Ноази ле Гран,Нуази-ле-Гран,Нуазі-ле-Гран,Шумная-ле-Гран,نوآزی-لو-گراند,نوازي لو غران,ノワジー＝ル＝グラン,大诺瓦西', 48.8497900, 2.5626600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52502, 'Noisiel', 'Noisiel', 'Noisiel,Nuaz''el'',Нуазьель,Нуазьєль', 48.8486800, 2.6243500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52503, 'Noiseau', 'Noiseau', 'Noiseau,Nuazo,nu wa suo,Нуазо,努瓦索', 48.7758900, 2.5489200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52504, 'Noirétable', 'Noiretable', 'Noiretable,Noirétable', 45.8180000, 3.7627600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52505, 'Nointot', 'Nointot', 'Nointot', 49.5982200, 0.4767400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52506, 'Noidans-lès-Vesoul', 'Noidans-les-Vesoul', 'Noidans,Noidans-les-Vesoul,Noidans-lès-Vesoul,Nuadan-le-Vezul'',Нуадан-ле-Везуль', 47.6129900, 6.1257100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52507, 'Nohic', 'Nohic', 'Nohic', 43.8897000, 1.4374100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52508, 'Nohanent', 'Nohanent', 'Noanan,Noanent,Nohanent,nuo a nan,Ноанан,诺阿南', 45.8100300, 3.0565800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52509, 'Nogent-sur-Vernisson', 'Nogent-sur-Vernisson', 'Nogent,Nogent-sur-Vernisson,Nozhan-sjur-Vernisson,wei er ni song he pan nuo rang,Ножан-сюр-Верніссон,韦尔尼松河畔诺让', 47.8460300, 2.7426700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52510, 'Nogent-sur-Seine', 'Nogent-sur-Seine', 'Nogent,Novigentum ad Sequanam,Nozhan-sjur-Sen,nojan=shuru=senu,sai na he pan nuo rang,Ножан-сюр-Сен,ノジャン＝シュル＝セーヌ,塞纳河畔诺让', 48.4833300, 3.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52511, 'Nogent-sur-Oise', 'Nogent-sur-Oise', 'Nogent,Nogent-sur-Oise,Nozhan-sjur-Uaz,wa si he pan nuo rang,Ножан-сюр-Уаз,瓦斯河畔诺让', 49.2715800, 2.4707400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52512, 'Nogent-sur-Marne', 'Nogent-sur-Marne', 'Nogent,Nozhan sir Marn,Nozhan-sjur-Marn,ma en he pan nuo rang,nojan=shuru=marunu,nwzhan swr mrn,nwzhan-swr-mrn,Ножан сир Марн,Ножан-сюр-Марн,נוזאן-סור-מארן,نوژان سور مرن,نوژان-سور-مرن,ノジャン＝シュル＝マルヌ,马恩河畔诺让', 48.8333300, 2.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52513, 'Nogent-le-Rotrou', 'Nogent-le-Rotrou', 'Nazhan-le-Ratru,Nogent,Nogent-le-Republicain,Nogent-le-Rotrou,Nogent-le-Républicain,Novigentum Rotroudi,Nozhan-le-Rotru,Nozhen le Rotru,nuo rang lai luo te lu,nwzhan-lw-rwtrw,Нажан-ле-Ратру,Ножан-ле-Ротру,Ножен ле Ротру,نوژان-لو-روترو,诺让莱罗特鲁', 48.3166700, 0.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52514, 'Nogent-le-Roi', 'Nogent-le-Roi', 'Nogent,Nogent-Roullebois,Nogent-le-Roi,Novigentum Regis,Nozhan-le-Rua,nuo rang lai lu wa,Ножан-ле-Руа,诺让莱鲁瓦', 48.6478500, 1.5293300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52515, 'Nogent-le-Phaye', 'Nogent-le-Phaye', 'Nogent,Nogent-le-Phaye', 48.4452800, 1.5777700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52516, 'Nogent-le-Bas', 'Nogent-le-Bas', 'Nogent-Haute-Marne,Nogent-le-Bas', 48.0197400, 5.3332300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52517, 'Nogentel', 'Nogentel', 'Nogentel', 49.0175000, 3.4025000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52518, 'Nogaro', 'Nogaro', 'Nogaro,Nogarou,Nogarò,Nogaròu,nogaro,nuo jia luo,Ногаро,ノガロ,诺加罗', 43.7585600, -0.0329300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52519, 'Nœux-les-Mines', 'Noeux-les-Mines', 'Ne-le-Min,Njo-le-Min,Noeux-les-Mines,ne lai mi ne,nwks lyh mynys,Не-ле-Мин,Не-ле-Мін,Нё-ле-Мин,نوكس ليه مينيس,讷莱米讷', 50.4833300, 2.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52520, 'Noé', 'Noe', 'Noe,Noé', 43.3581400, 1.2770900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52521, 'Noailles', 'Noailles', 'Longvillers-Boncourt,Noailles', 49.3286600, 2.2002400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52522, 'Noaillan', 'Noaillan', 'Noaillan,Noajan,Noalhan,nuo ai lang,Ноаян,诺艾朗', 44.4805700, -0.3664000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52523, 'Nivolas-Vermelle', 'Nivolas-Vermelle', 'Nivolas-Vermelle', 45.5551800, 5.3068200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52524, 'Nivillac', 'Nivillac', 'Nivilieg,Nivillac,Nivillak,Noviliacum,ni wei la ke,Нивиллак,Нівіллак,尼维拉克', 47.5337100, -2.2829800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52525, 'Nissan-lez-Enserune', 'Nissan-lez-Enserune', 'Nica,Nissa dAusseruna,Nissan,Nissan-lez-Anserjun,Nissan-lez-Enserune,Nissan-lez-Ensérune,Niça,ni sang lai ang se lan,Ниссан-лез-Ансерюн,Ніссан-лез-Ансерюн,尼桑莱昂瑟兰', 43.2896100, 3.1270500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52526, 'Niort', 'Niort', 'N''or,NIT,Nior,Niort,Niortium,Niòrt,Njoras,ni ao er,nioleu,nioru,nywr,Ниор,Ньор,Ніор,ניור,نيور,نیور,ニオール,尼奥尔,니오르', 46.3231300, -0.4587700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52527, 'Nîmes', 'Nimes', 'FNI,Gorad Nim,Nemausus,Nim,Nima,Nimas,Nime,Nimes,Nimo,Nismes,Nîme,Nîmes,Nīma,nayym,ni mu,nim,nimi,nimu,nym,Νιμ,Горад Нім,Ним,Нім,Նիմ,נים,نائیم,نيم,نیم,นีม,ნიმი,ニーム,尼姆,님', 43.8333300, 4.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52528, 'Nilvange', 'Nilvange', 'Nilvange', 49.3399500, 6.0548300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52529, 'Niherne', 'Niherne', 'Niern,Niherne,nie er en,Ниерн,Ніерн,涅尔恩', 46.8276800, 1.5638400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52530, 'Niévroz', 'Nievroz', 'N''evro,Nevro,Nievro,ni ai fu luo,nyyfrw,Ньевро,Ньєвро,Նիևրո,نييفرو,尼埃夫罗', 45.8333300, 5.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52531, 'Nieul-sur-Mer', 'Nieul-sur-Mer', 'N''el''-sjur-Mer,N''jol''-sjur-Mer,Nieul,Nieul-sur-Mer,bin hai nie yu,Ньёль-сюр-Мер,Ньєль-сюр-Мер,滨海涅于', 46.2058300, -1.1644900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52532, 'Nieul-lès-Saintes', 'Nieul-les-Saintes', 'Nieul,Nieul-les-Saintes,Nieul-les-Xantes,Nieul-lès-Saintes', 45.7602100, -0.7313700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52533, 'Nieul-le-Dolent', 'Nieul-le-Dolent', 'Nieul,Nieul-le-Dolent', 46.5737900, -1.5080800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52534, 'Nieul', 'Nieul', 'N''el'',Nuelh,Nuèlh,ni yue lei,Ньель,Ньєль,尼约勒', 45.9266800, 1.1749400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52535, 'Nieppe', 'Nieppe', 'N''epp,Niepkerke,Nieppe,nie pu,Ньепп,Ньєпп,涅普', 50.7042500, 2.8350600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52536, 'Niederschaeffolsheim', 'Niederschaeffolsheim', 'Nieder Scheffelscheim,Niederschaeffolsheim,Niederschaffolsheim,Niederschäffolsheim', 48.7719600, 7.7387400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52537, 'Niedernai', 'Niedernai', 'Nidernahn,Niderne,Niederehnheim,Niedernai,Nídernahn,nie dai er nai,nydrnay,Нидерне,Нідерне,نيدرناي,نیدرنای,涅代尔奈', 48.4513400, 7.5148700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52538, 'Niederhausbergen', 'Niederhausbergen', '', 48.6240000, 7.7021000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52539, 'Niederhaslach', 'Niederhaslach', 'Ingerhosle,Nideraslak,Niederhaslach,nie de la si la ke,nydyrhaslatsh,Íngerhosle,Нидераслак,Нідераслак,نيديرهاسلاتش,涅德拉斯拉克', 48.5426400, 7.3428200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52540, 'Niederbronn-les-Bains', 'Niederbronn-les-Bains', 'Bad Niederbronn,Niderbronn-le-Ben,Niderbrunn,Niederbronn,Niederbronn-les-Bains,Níderbrunn,nideruburon=re=ban,nie dai er bu long lai ban,nydrbrwn-l-bn,nydyrbrwn lyh bayns,Нидербронн-ле-Бен,Нідербронн-ле-Бен,نيديربرون ليه باينس,نیدربرون-ل-بن,ニーデルブロン＝レ＝バン,涅代尔布龙莱班', 48.9516500, 7.6427100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52541, 'Niderviller', 'Niderviller', 'Niderviller', 48.7129400, 7.1062700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52542, 'Nice', 'Nice', 'Gorad Nica,NCE,Nica,Nicaea,Nicc,Nicca,Niccae,Nice,Nicea,Nico,Nikaia,Nis,Nisa,Nissa,Nissa Maritima,Nissa Marìtima,Nitza,Niza,Nizza,Niça,Nìsa,ni si,nis,nisa,niseu,nisu,nitsa,nys,Νίκαια,Горад Ніца,Ница,Ниццæ,Ницца,Ніцца,Նիս,ניס,نيس,نیس,नीस,নিস,ਨੀਸ,நீஸ்,నీస్,นิส,ნიცა,ニース,尼斯,니스', 43.7031300, 7.2660800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52543, 'Neydens', 'Neydens', '', 46.1216200, 6.1043600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52544, 'Nexon', 'Nexon', 'Nexon', 45.6796200, 1.1855500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52545, 'Nevoy', 'Nevoy', 'Nevey,Nevoy,Nevua,na wa,Невуа,纳瓦', 47.7159100, 2.5779100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52546, 'Néville', 'Neville', 'Neville,Néville', 49.8247200, 0.7086200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52547, 'Névian', 'Nevian', 'Nevian,Névian', 43.2123800, 2.9028600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52548, 'Névez', 'Nevez', 'Neve,Nevez,Névez,nei wei,nevu~e,Неве,ネヴェ,内韦', 47.8192400, -3.7922500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52549, 'Nevers', 'Nevers', 'NVS,Never,Neveras,Nevers,Niverns,Nivernum,Nivèrns,ne wei er,neubeleu,nuvu~eru,nwrs,Νεβέρ,Невер,نورس,เนอแวร์,ヌヴェール,讷韦尔,느베르', 46.9895600, 3.1590000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52550, 'Neuwiller-lès-Saverne', 'Neuwiller-les-Saverne', 'Neiwiller,Neuweiler bei Zabern,Neuwiller,Neviller-le-Savern,na wei lai lai sa wei er en,nwylr-l-sawrn,nywwylyr lyh safyrn,Невиллер-ле-Саверн,Невіллер-ле-Саверн,نویلر-ل-ساورن,نيوويلير ليه سافيرن,纳维莱莱萨韦尔恩', 48.8250600, 7.4051300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52551, 'Neuvy-sur-Loire', 'Neuvy-sur-Loire', 'Neuvy,Neuvy-sur-Loire', 47.5232300, 2.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52552, 'Neuvy-sur-Barangeon', 'Neuvy-sur-Barangeon', 'Neuvy,Neuvy-sur-Barangeon', 47.3149500, 2.2534300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52553, 'Neuvy-Sautour', 'Neuvy-Sautour', 'Neuvy,Neuvy-Sautour', 48.0419000, 3.7947200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52554, 'Neuvy-Saint-Sépulchre', 'Neuvy-Saint-Sepulchre', 'Neuvy,Neuvy-Saint-Sepulchre,Neuvy-Saint-Sepulcre,Neuvy-Saint-Sépulchre,Neuvy-Saint-Sépulcre,Neuvy-sur-Bouzanne,Nevi-Sen-Sepjul''shr,Njovi-Sen-Sepjul''kr,ne wei sheng sai pi er ke er,nwwy-sn-spwlqr,Неві-Сен-Сепюльшр,Нёви-Сен-Сепюлькр,נווי-סן-ספולקר,讷维圣塞皮尔克尔', 46.5978100, 1.8060100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52555, 'Neuvy-Pailloux', 'Neuvy-Pailloux', 'Neuvy,Neuvy-Pailloux,Nevi-Paju,Njovi-Paju,ne wei pei lu,Неві-Паю,Нёви-Пайу,讷维佩卢', 46.8848600, 1.8615200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52556, 'Neuvy-le-Roi', 'Neuvy-le-Roi', 'Neuvy,Neuvy-la-Loi,Neuvy-le-Roi', 47.6038600, 0.5947200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52557, 'Neuvy', 'Neuvy', 'Neuvy', 46.5603700, 3.2899000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52558, 'Neuville-sur-Sarthe', 'Neuville-sur-Sarthe', 'Neuville,Neuville-sur-Sarthe', 48.0761500, 0.1926400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52559, 'Neuville-sur-Saône', 'Neuville-sur-Saone', 'Marat-sur-Saone,Marat-sur-Saône,Neuville,Neuville-sur-Saone,Neuville-sur-Saône,Nevil''-sjur-Son,Невіль-сюр-Сон', 45.8770400, 4.8492000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52560, 'Neuville-sur-Oise', 'Neuville-sur-Oise', 'Neuville,Neuville-sur-Oise,Nevil''-sjur-Uaz,Njovil''-sjur-Uaz,wa ci he pan na wei er,Невиль-сюр-Уаз,Невіль-сюр-Уаз,Нёвиль-сюр-Уаз,瓦兹河畔纳维尔', 49.0166700, 2.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52561, 'Neuville-sur-Escaut', 'Neuville-sur-Escaut', 'Neuville,Neuville-sur-l''Escaut,Nevil''-sjur-Esko,ai si ke he pan ne wei er,Невиль-сюр-Еско,Невіль-сюр-Еско,埃斯科河畔讷维尔', 50.3000000, 3.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52562, 'Neuville-sur-Ain', 'Neuville-sur-Ain', 'Neuville,Neuville-sur-Ain', 46.0807400, 5.3776400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52563, 'Neuville-Saint-Vaast', 'Neuville-Saint-Vaast', 'Neuville,Neuville-Saint-Vaast,Neuville-l''Egalite,Neuville-l''Egalité,Nevil''-Sen-Vaast,ne wei er sheng wa si te,nwfyl san fas,Невиль-Сен-Вааст,Невіль-Сен-Вааст,نوفيل سان فاس,讷维尔圣瓦斯特', 50.3575600, 2.7626100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52564, 'Neuville-Saint-Rémy', 'Neuville-Saint-Remy', 'Neuville,Neuville-Saint-Remy,Neuville-Saint-Rémy,Neuvilly,Nevil''-Sen-Remi,Njovil''-Sen-Remi,ne wei er sheng lei mi,Невиль-Сен-Реми,Невіль-Сен-Ремі,Нёвиль-Сен-Реми,讷维尔圣雷米', 50.1861800, 3.2240400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52565, 'Neuville-les-Dames', 'Neuville-les-Dames', 'Neuville,Neuville-les-Dames,Neuville-sur-Renon', 46.1622800, 5.0039900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52566, 'Neuville-en-Ferrain', 'Neuville-en-Ferrain', 'Ferrain,Neuville,Neuville en Farram,Neuville-en-Ferrain,Nevil''-an-Ferren,Njovil''-an-Ferren,ne wei er ang fei lan,Невиль-ан-Феррен,Невіль-ан-Феррен,Нёвиль-ан-Феррен,讷维尔昂费兰', 50.7483900, 3.1567600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52567, 'Neuville-de-Poitou', 'Neuville-de-Poitou', 'Neuville,Nevil''-de-Puatu,na wei lei de pu wa tu,Невіль-де-Пуату,纳维勒德普瓦图', 46.6833300, 0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52568, 'Neuville-aux-Bois', 'Neuville-aux-Bois', 'Neuville,Neuville-aux-Bois', 48.0681300, 2.0537200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52569, 'Neuvic-Entier', 'Neuvic-Entier', 'Neuvic,Neuvic-Entier', 45.7220600, 1.6130300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52570, 'Neuvic', 'Neuvic', 'Neuvic,Neuvic d''Ussel,Neuvic d’Ussel', 45.3833300, 2.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52571, 'Neuvic', 'Neuvic', 'Neuvic,Neuvic-sur-l''Isle,Neuvic-sur-l’Isle', 45.1003300, 0.4690100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52572, 'Neuves-Maisons', 'Neuves-Maisons', 'Neuves-Maisons', 48.6202900, 6.1069800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52573, 'Neuvéglise', 'Neuveglise', 'Neuveglise,Neuvéglise', 44.9278700, 2.9834300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52574, 'Neuvecelle', 'Neuvecelle', '', 46.3950200, 6.6125700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52575, 'Neussargues-Moissac', 'Neussargues-Moissac', 'Neussargues,Neussargues-Moissac', 45.1326000, 2.9798500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52576, 'Neung-sur-Beuvron', 'Neung-sur-Beuvron', 'Nen-sjur-Bevron,Neung,Neung-sur-Beuvron,bo fu luo ne he pan na en,Нен-сюр-Беврон,伯夫罗讷河畔纳恩', 47.5348600, 1.8051400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52577, 'Neulliac', 'Neulliac', 'Neulieg,Neulliac', 48.1283600, -2.9828900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52578, 'Neulise', 'Neulise', 'Neulise,Neulize', 45.9027900, 4.1809400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52579, 'Neuilly-sur-Seine', 'Neuilly-sur-Seine', 'Kamuna Njoi-sjur-Sen,N''oj sjur Sen,Neigi-syr-Sen,Neiji pie Senas,Neijī pie Sēnas,Neji na Seni,Neji-sjur-Sen,Neuilly,Neuilly sur Seine,Neuilly-sur-Seine,Njoji-sjur-Sen,Noeyi-suer-Sen,Noviliacum ad Sequanam,Nöyi-sür-Sen,QNL,noeiswileusen,nuii=shuru=senu,nwy-swr-sn,nwyy-swr-syn,nyy-syr-sn,sai na he pan na yi,sai na he pan ne yi,Νεϊγί-συρ-Σεν,Камуна Нёі-сюр-Сен,Нейи-сюр-Сен,Нейї-сюр-Сен,Неји на Сени,Ньой сюр Сен,Нёйи-сюр-Сен,ניי-סיר-סן,نويي-سور-سين,نوی-سور-سن,ヌイイ＝シュル＝セーヌ,塞纳河畔纳伊,塞纳河畔讷伊,뇌이쉬르센', 48.8846000, 2.2696500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52580, 'Neuilly-sur-Marne', 'Neuilly-sur-Marne', 'Nei-sjur-Marn,Neji sir Marn,Neji-sjur-Marn,Neuilly,Neuilly-sur-Marne,Njoji-sjur-Marn,ma en he pan ne yi,nuii=shuru=marunu,nwy swr mrn,nywyly swr marny,Неи-сюр-Марн,Нейи-сюр-Марн,Неї-сюр-Марн,Неји сир Марн,Нёйи-сюр-Марн,نوی سور مرن,نيويلي سور مارني,ヌイイ＝シュル＝マルヌ,马恩河畔讷伊', 48.8537300, 2.5490300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52581, 'Neuilly-sous-Clermont', 'Neuilly-sous-Clermont', 'Nei-su-Klermon,Neuilly,Neuilly-sous-Clermont,ne yi su ke lai meng,Неї-су-Клермон,讷伊苏克莱蒙', 49.3443700, 2.4103000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52582, 'Neuilly-Saint-Front', 'Neuilly-Saint-Front', 'Neuilly,Neuilly-Saint-Front,Neuilly-sur-Ourcq', 49.1701200, 3.2639300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52583, 'Neuilly-Plaisance', 'Neuilly-Plaisance', 'Nei-Plezans,Neji Plezans,ne yi-pu lai sang si,nuii=purezansu,Неи-Плезанс,Неї-Плезанс,Неји Плезанс,ヌイイ＝プレザンス,讷伊-普莱桑斯', 48.8634200, 2.5060000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52584, 'Neuilly-lès-Dijon', 'Neuilly-les-Dijon', 'Neuilly,Neuilly-les-Dijon,Neuilly-lès-Dijon', 47.2794300, 5.1064500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52585, 'Neuilly-le-Réal', 'Neuilly-le-Real', 'Neuilly,Neuilly-le-Real,Neuilly-le-Réal,Neuilly-sur-Sanne', 46.4646600, 3.4316100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52586, 'Neuilly-en-Thelle', 'Neuilly-en-Thelle', 'Neuilly,Neuilly-en-Thelle', 49.2244500, 2.2852500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52587, 'Neuillé-Pont-Pierre', 'Neuille-Pont-Pierre', 'Neuille,Neuille-Pont-Pierre,Neuillé,Neuillé-Pont-Pierre', 47.5484000, 0.5496200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52588, 'Neufmoutiers-en-Brie', 'Neufmoutiers-en-Brie', 'Nefmut''e-an-Bri,Neufmoutiers,Neufmoutiers-en-Brie,Нефмутье-ан-Бри,Нефмутьє-ан-Брі', 48.7688200, 2.8315600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52589, 'Neufmanil', 'Neufmanil', 'Nefmanij,Neufmanil,Njomanil'',ne fu ma ni lei,Нефманій,Нёманиль,讷夫马尼勒', 49.8109600, 4.7967300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52590, 'Neufgrange', 'Neufgrange', 'Neufgrange', 49.0760200, 7.0580600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52591, 'Neufchef', 'Neufchef', 'Nefshef,Neufchef,Neunhauser,Neunhaüser,na fu xie,nfshf,Нефшеф,نفشف,纳夫谢', 49.3151400, 6.0234100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52592, 'Neufchâtel-Hardelot', 'Neufchatel-Hardelot', 'Nefshatel''-Ardelo,Neufchatel,Neufchatel-Hardelot,Neufchâtel,Neufchâtel-Hardelot,ne sha tai lei a er dai luo,nywftshatyl hardylwt,Нефшатель-Ардело,نيوفتشاتيل هارديلوت,讷沙泰勒阿尔代洛', 50.6201800, 1.6422300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52593, 'Neufchâtel-en-Bray', 'Neufchatel-en-Bray', 'Gorad Njoshatehl''-an-Breh,Nefshatel''-an-Bre,Neufchatel,Neufchatel-en-Bray,Neufchâtel,Neufchâtel-en-Bray,Njoshatel''-an-Bre,Горад Нёшатэль-ан-Брэ,Нефшатель-ан-Бре,Нёшатель-ан-Бре', 49.7331500, 1.4395600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52594, 'Neufchâteau', 'Neufchateau', '', 48.3500000, 5.7000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52595, 'Neuf-Brisach', 'Neuf-Brisach', 'Brisacum Novum,Nef-Brizak,Neu-Breisach,Neuf-Brisach,Njof-Brizakh,na bu li sa ke,nufu=burizakku,nywf bryzakh,nywf-brysash,Неф-Бризак,Нёф-Бризах,نيوف-بريساش,نیوف بریزاخ,ヌフ＝ブリザック,纳布里萨克', 48.0178300, 7.5279500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52596, 'Neuf-Berquin', 'Neuf-Berquin', 'Neuf-Berquin', 50.6606500, 2.6721300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52597, 'Nesmy', 'Nesmy', 'Nemi,Nesmy,nei si mi,Немі,内斯米', 46.5907800, -1.4007400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52598, 'Nesles-la-Vallée', 'Nesles-la-Vallee', 'Nel''-la-Valle,Nesles,Nesles-la-Vallee,Nesles-la-Vallée,nei si lei la wa lai e,Нель-ла-Валле,内斯勒拉瓦莱厄', 49.1320200, 2.1709900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52599, 'Nesles-la-Montagne', 'Nesles-la-Montagne', 'Nesles,Nesles-la-Montagne', 49.0196400, 3.4260700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52600, 'Nesles', 'Nesles', 'Nesles', 50.6258800, 1.6564100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52601, 'Nesle', 'Nesle', 'Nel'',Nele,Nesle,Nèle,nei lei,Нель,内勒', 49.7588800, 2.9113300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52602, 'Nersac', 'Nersac', 'Nersac,Nersak,nei er sa ke,Нерсак,内尔萨克', 45.6333300, 0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52603, 'Nérondes', 'Nerondes', '', 46.9975800, 2.8183400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52604, 'Néris-les-Bains', 'Neris-les-Bains', 'Neri-le-Ben,Neriomagus,Neris,Nerís,Néris,nei li lai ban,Нери-ле-Бен,Нері-ле-Бен,内里莱班', 46.2868800, 2.6586900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52605, 'Nercillac', 'Nercillac', 'Nercillac,Nersijak,nei er xi la ke,Нерсийак,Нерсіяк,内尔西拉克', 45.7166700, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52606, 'Nérac', 'Nerac', 'Nerac,Nerak,Nérac,ne rak,nei la ke,nerakku,Нерак,เนรัก,ネラック,内拉克', 44.1333300, 0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52607, 'Néoules', 'Neoules', 'Neoules,Néoules', 43.3103400, 6.0129800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52608, 'Nemours', 'Nemours', 'Gorad Nemur,Nemours,Nemur,nei mu er,nmwr,numuru,Горад Немур,Немур,نمور,ヌムール,内穆尔', 48.2751100, 2.6907800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52609, 'Nègrepelisse', 'Negrepelisse', 'Negrapelissa,Negrepeliss,Negrepelisse,Nègrepelisse,nei ge lei pei li se,Негрепелісс,内格雷佩利瑟', 44.0743600, 1.5197800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52610, 'Nébian', 'Nebian', 'Nebian,Nébian', 43.6065700, 3.4313300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52611, 'Neauphle-le-Château', 'Neauphle-le-Chateau', 'Neauphle,Neauphle-la-Montagne,Neauphle-le-Chateau,Neauphle-le-Château,Nofl''-le-Shato,nwfl lwshatw,Нофль-ле-Шато,نوفل لوشاتو,نوفل‌لوشاتو', 48.8141800, 1.9056700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52612, 'Neaufles-Saint-Martin', 'Neaufles-Saint-Martin', 'Neaufles,Neaufles-Saint-Martin', 49.2765000, 1.7279400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52613, 'Nazelles-Négron', 'Nazelles-Negron', '', 47.4333300, 0.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52614, 'Nay', 'Nay', 'Nay', 43.1833300, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52615, 'Naves', 'Naves', '', 45.3139500, 1.7670800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52616, 'Navenne', 'Navenne', 'Navenne', 47.6087300, 6.1617600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52617, 'Naveil', 'Naveil', 'Naveil,Navej,na wei,Навей,纳韦', 47.7957600, 1.0322200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52618, 'Navarrenx', 'Navarrenx', 'Nabarrengose,Navarrencs,Navarrenks,Navarrens,Navarrenx,na wa er lang,Наварренкс,Наварренс,纳瓦尔朗', 43.3213500, -0.7592700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52619, 'Navailles-Angos', 'Navailles-Angos', 'Navailles,Navailles-Angos,Navaj-Angos,Navalhas e Angos,Navalhas e Angòs,na wei lai ang ge,Навай-Ангос,纳韦莱昂戈', 43.4166700, -0.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52620, 'Naucelles', 'Naucelles', 'Naucelles', 44.9578200, 2.4188900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52621, 'Naucelle', 'Naucelle', 'Naucela,Naucelle,Naucèla,Nosel'',nuo sai er,Носель,诺塞尔', 44.1981000, 2.3431000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52622, 'Nassandres', 'Nassandres', 'Nassandr,Nassandres,na sang de lei,Нассандр,纳桑德雷', 49.1263200, 0.7359700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52623, 'Narrosse', 'Narrosse', 'Narrosse', 43.7038100, -1.0074200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52624, 'Nargis', 'Nargis', 'Nargis', 48.1110600, 2.7559700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52625, 'Narbonne', 'Narbonne', 'Gorad Narbona,NNE,Narbo,Narbon,Narbona,Narbonas,Narbonn,Narbonna,Narbonne,arbwnt,na bo ne,naleubon,narubon''nu,nrbwn,Горад Нарбона,Нарбон,Нарбонн,Нарбонна,נרבון,أربونة,نربون,ናርቦን፣ ፈረንሳይ,ナルボンヌ,纳博讷,나르본', 43.1839600, 3.0014100, 'FR', '2016-06-19', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52626, 'Naours', 'Naours', 'Naours', 50.0368200, 2.2769100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52627, 'Nantua', 'Nantua', 'Nantjua,Nantua,Nantuat,nan di a,nangtwia,nante~yua,nantwa,Нантюа,Նանտուա,نانتوآ,نانتوا,ナンテュア,南蒂阿,낭튀아', 46.1500000, 5.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52628, 'Nantiat', 'Nantiat', 'Nantiat', 46.0091000, 1.1730800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52629, 'Nanteuil-lès-Meaux', 'Nanteuil-les-Meaux', 'Nanteuil,Nanteuil-les-Meaux,Nanteuil-lès-Meaux', 48.9294000, 2.8959400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52630, 'Nanteuil-le-Haudouin', 'Nanteuil-le-Haudouin', 'Nantej-le-Oduen,Nanteuil,Nanteuil-le-Haudouin,Nantjoj-le-Oduehn,nan te yi lai ao du an,Нантей-ле-Одуен,Нантёй-ле-Одуэн,南特伊莱奥杜安', 49.1408200, 2.8114200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52631, 'Nanteuil-en-Vallée', 'Nanteuil-en-Vallee', 'Nantej-an-Valle,Nanteuil,Nanteuil-en-Vallee,Nanteuil-en-Vallée,Nantjoj-an-Valle,wa lai ai de qu nan te yi,Нантей-ан-Валле,Нантёй-ан-Валле,瓦莱埃地区南特伊', 46.0008900, 0.3220600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52632, 'Nanteuil', 'Nanteuil', 'Nanteuil', 46.4117200, -0.1746100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52633, 'Nantes', 'Nantes', 'NTE,Nant,Nante,Nantes,Nanto,Naoned,Portus Namnetus,nan te,nant,nanta,nanto,Нант,נאנט,نانت,नांत,ナント,南特', 47.2172500, -1.5533600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52634, 'Nanterre', 'Nanterre', 'Gorad Nantehr,Nanter,Nanteras,Nanterr,Nanterre,Nemetodurum,nan tai er,nangteleu,nanteru,nantr,nantyr,Горад Нантэр,Нантер,Нантерр,نانتر,نانتير,نانتیرے,ナンテール,楠泰尔,낭테르', 48.8919800, 2.2067500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52635, 'Nans-les-Pins', 'Nans-les-Pins', 'Nan-le-Pen,Nanc,Nans,Nans-le-Pen,Nans-les-Pins,Nanç,nan lai pan,Нан-ле-Пен,Нанс-ле-Пен,南莱潘', 43.3703500, 5.7834000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52636, 'Nangis', 'Nangis', 'Nangis', 48.5553500, 3.0130600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52637, 'Nandy', 'Nandy', 'Nandy', 48.5830100, 2.5629200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52638, 'Nancy', 'Nancy', 'ETZ,Nanceium,Nancio,Nancy,Nansi,Nanzeg,nan xi,nanshi,nansi,nansy,Нанси,נאנסי,نانسي,نانسی,नांसी,ナンシー,南希', 48.6843900, 6.1849600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52639, 'Nancray', 'Nancray', 'Nancray', 47.2453600, 6.1828300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52640, 'Nalliers', 'Nalliers', 'Nalliers', 46.4707100, -1.0277400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52641, 'Naizin', 'Naizin', 'Naizin,Neizin,Nezen,nai zan,Незен,奈赞', 47.9899300, -2.8328700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52642, 'Naintré', 'Naintre', 'Naintre,Naintré,Nentre,nan te lei,Нентре,南特勒', 46.7635400, 0.4868300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52643, 'Nailloux', 'Nailloux', 'Nailloux,Naju,Nalhos,Nalhós,nai lu,Найу,Наю,奈卢', 43.3571800, 1.6230200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52644, 'Nages-et-Solorgues', 'Nages-et-Solorgues', 'Nages,Nages-et-Solorgues,Najas e Solorgues,Najas e Solòrgues,Nazh-e-Solorg,na re he suo luo er gai,Наж-е-Солорг,纳热和索洛尔盖', 43.7901000, 4.2302700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52645, 'Muzillac', 'Muzillac', 'Mjuzijak,Musiliacum,Muzilheg,Muzillac,mi qi la ke,Мюзияк,Мюзіяк,米齐拉克', 47.5545100, -2.4804100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52646, 'Mutzig', 'Mutzig', 'Mjucig,Muetzig,Mutzig,Mützig,mi te qi,mutsu~ihi,Мюциг,ムツィヒ,米特齐', 48.5397400, 7.4559400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52647, 'Muttersholtz', 'Muttersholtz', 'Mieterschulz,Mjuttersol''c,Muettersholz,Mutherholz,Muttersholtz,Muttersholz,Müttersholz,mi tai er suo er te,myutterusorutsu,Мюттерсольц,ミュッテルソルツ,米泰尔索尔特', 48.2663900, 7.5319700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52648, 'Mussy-sur-Seine', 'Mussy-sur-Seine', 'Mjussi-sjur-Sen,Mussy,Mussy-sur-Seine,sai na he pan mi xi,Мюсси-сюр-Сен,Мюссі-сюр-Сен,塞纳河畔米西', 47.9779100, 4.4974300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52649, 'Mussig', 'Mussig', '', 48.2299300, 7.5196300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52650, 'Mussidan', 'Mussidan', 'Mjusidan,Mjussidan,Moissida,Mussidan,mi xi dang,Мюсидан,Мюссидан,Мюссідан,米西当', 45.0354200, 0.3629000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52651, 'Mus', 'Mus', 'Mus', 43.7391900, 4.2025700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52652, 'Murviel-lès-Montpellier', 'Murviel-les-Montpellier', 'Mervielh,Mervielh de Montpelhier,Mervièlh,Mervièlh de Montpelhièr,Mjurv''el''-le-Monpel''e,Mjurvel''-le-Monpel''e,Murviel,Murviel-les-Montpellier,Murviel-lès-Montpellier,mi er wei ye lai meng bi li ai,Мюрвьель-ле-Монпелье,Мюрвєль-ле-Монпельє,米尔维耶莱蒙彼利埃', 43.6052800, 3.7375000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52653, 'Mûrs-Erigné', 'Murs-Erigne', 'Mjur-Erin''e,Murs,Mûrs,mi er ai li nie,Мюр-Ериньє,米尔埃里涅', 47.4000000, -0.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52654, 'Muron', 'Muron', 'Muron', 46.0344400, -0.8286700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52655, 'Muret', 'Muret', 'Barrancu,Lapangan Terbang LHerm,Mire,Mjure,Muret,Mureth,Muriel,Murèth,mi lei,mwrh,myure,Мире,Мюре,موره,ミュレ,米雷', 43.4666700, 1.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52656, 'Mur-de-Sologne', 'Mur-de-Sologne', 'Mur,Mur-de-Sologne', 47.4123900, 1.6083200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52657, 'Mûr-de-Bretagne', 'Mur-de-Bretagne', 'Mjur-de-Bretan'',Mur,Mur-de-Bretagne,Mûr-de-Bretagne,mi de bu lei ta ni,myuru=do=burutanyu,Мюр-де-Бретань,ミュール＝ド＝ブルターニュ,米德布雷塔尼', 48.2000000, -2.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52658, 'Murat', 'Murat', 'Murat', 45.1079700, 2.8666500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52659, 'Munster', 'Munster', 'Munster', 48.0408900, 7.1333800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52660, 'Mundolsheim', 'Mundolsheim', 'Mjundol''sajm,Mundelse,man duo er sang,mwndwlshym,Мюндольсайм,موندولشيم,曼多尔桑', 48.6421500, 7.7137800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52661, 'Munchhouse', 'Munchhouse', 'Munchhausen,Munchhouse,Münchhausen', 47.8678000, 7.4516700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52662, 'Mulsanne', 'Mulsanne', 'Mjul''sann,Mulsanne,mwlsan,Мюльсанн,مولسان', 47.9117200, 0.2493800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52663, 'Mulhouse', 'Mulhouse', 'EAP,Gorad Mjuluz,MLH,Miluz,Miluza,Miuluzas,Miulūzas,Mjuluz,Mueihausn,Muelhausen,Mulhouse,Mulhousen,Mulhusia,Mylhuzy,Mylhúzy,Mylouz,Müihausn,Mülhausen,mi lu si,miuluzi,mwillujeu,mwlwz,mylwz,myulujha,myuruzu,Μυλούζ,Горад Мюлуз,Милуз,Мюлуз,ملہاؤز,مولوز,ميلوز,म्युलुझ,მიულუზი,ミュルーズ,米卢斯,뮐루즈', 47.7500000, 7.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52664, 'Muizon', 'Muizon', 'Mjuizon,Muizon,mi yi zong,Мюїзон,米伊宗', 49.2749900, 3.8908300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52665, 'Muides-sur-Loire', 'Muides-sur-Loire', 'Mjuid-sjur-Luar,Muides,Muides-sur-Loire,lu wa er he pan mi yi dai,Мюїд-сюр-Луар,卢瓦尔河畔米伊代', 47.6695800, 1.5269400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52666, 'Mugron', 'Mugron', 'Mjugron,Mugron,mi ge long,Мюгрон,米格龙', 43.7495200, -0.7517900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52667, 'Mozé-sur-Louet', 'Moze-sur-Louet', 'Moze,Moze-sur-Louet,Mozé,Mozé-sur-Louet', 47.3585600, -0.5529500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52668, 'Mozac', 'Mozac', 'Mausac,Moza,Mozac,mo zha ke,Моза,莫扎克', 45.8916600, 3.0909500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52669, 'Moyrazès', 'Moyrazes', 'Moyrazes,Moyrazès', 44.3420400, 2.4393300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52670, 'Moyeuvre-Grande', 'Moyeuvre-Grande', 'Grande Moyeuvre,Moyeuvre,Moyeuvre-Grande,Moyeuvre-la-Grande,Muaevr-Grand,mu wa e fu er ge lang de,mwaywr-grand,Муаевр-Гранд,Муаєвр-Гранд,موایور-گراند,穆瓦厄夫尔格朗德', 49.2516500, 6.0475400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52671, 'Moyenmoutier', 'Moyenmoutier', 'Moyenmoutier,Muaenmut''e,mu wa ang mu di ye,Муаенмутье,Муаєнмутьє,穆瓦昂穆蒂耶', 48.3773000, 6.9004700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52672, 'Moye', 'Moye', 'Moye', 45.8791100, 5.9143500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52673, 'Moyaux', 'Moyaux', '', 49.1951100, 0.3560300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52674, 'Mouzon', 'Mouzon', 'Mouzon,Ville-le-Libre,Villé-le-Libre', 49.6070600, 5.0756900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52675, 'Mouzillon', 'Mouzillon', 'Maodilon,Mouzillon', 47.1409600, -1.2819100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52676, 'Mouzeil', 'Mouzeil', 'Mouzeil,Mouzel,Muzej,mu ze,Музей,穆泽', 47.4473800, -1.3478600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52677, 'Mouy', 'Mouy', 'Mouy,Mui,mu yi,Муи,Муї,穆伊', 49.3153500, 2.3195400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52678, 'Mouxy', 'Mouxy', 'Mouxy,Muksi,Муксі', 45.6839900, 5.9353800, 'FR', '2017-05-14', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52679, 'Mouvaux', 'Mouvaux', 'Mouvaux,Mouveaux,Muvo,mu wo,Муво,穆沃', 50.6994400, 3.1342900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52680, 'Moutiers', 'Moutiers', 'Moutiers', 49.2336900, 5.9649800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52681, 'Moûtiers', 'Moutiers', 'Mont-Salins,Motiers,Motiérs,Mut''e,Мутье,Мутьє', 45.4833300, 6.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52682, 'Mouthiers-sur-Boëme', 'Mouthiers-sur-Boeme', 'Mouthiers,Mouthiers-sur-Boeme,Mouthiers-sur-Boëme,Mut''e-sjur-Boehm,Mut''e-sjur-Boem,bo e mu he pan mu di ye er,Мутье-сюр-Боэм,Мутьє-сюр-Боем,博厄姆河畔穆蒂耶尔', 45.5500000, 0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52683, 'Moustoir-Ac', 'Moustoir-Ac', 'Moustoer-Logunec''h,Moustoir-Ac', 47.8546100, -2.8348100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52684, 'Moussy-le-Vieux', 'Moussy-le-Vieux', 'Moussy-le-Vieux', 49.0471200, 2.6249300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52685, 'Moussy-le-Neuf', 'Moussy-le-Neuf', 'Moussy-le-Neuf,Mussi-le-Nef,Мусси-ле-Неф,Муссі-ле-Неф', 49.0642700, 2.6025200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52686, 'Moussan', 'Moussan', 'Moussan', 43.2309100, 2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52687, 'Moussac', 'Moussac', 'Moussac', 43.9811900, 4.2264700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52688, 'Mours-Saint-Eusèbe', 'Mours-Saint-Eusebe', 'Mours,Mours-Saint-Eusebe,Mours-Saint-Eusèbe', 45.0682900, 5.0575200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52689, 'Mours', 'Mours', 'Mours,Mur,mu er,Мур,穆尔', 49.1307700, 2.2676100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52690, 'Mouroux', 'Mouroux', 'Mouroux', 48.8226300, 3.0387900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52691, 'Mourmelon-le-Grand', 'Mourmelon-le-Grand', 'Mourmelon,Mourmelon-le-Grand', 49.1325600, 4.3642000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52692, 'Mouriès', 'Mouries', 'Mories,Moriés,Mouries,Mouriès,Mur''es,Mure,mu li ye,Мурьес,Мурє,穆里耶', 43.6899700, 4.8708900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52693, 'Mourenx', 'Mourenx', 'Morencs,Mourenx,Murans,Murenks,mu lang,Муранс,Муренкс,穆朗', 43.3833300, -0.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52694, 'Moult', 'Moult', 'Moult', 49.1149400, -0.1647200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52695, 'Moulis-en-Médoc', 'Moulis-en-Medoc', 'Moulis,Moulis-en-Medoc,Moulis-en-Médoc', 45.0593800, -0.7703300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52696, 'Moulins-lès-Metz', 'Moulins-les-Metz', 'Moulins,Moulins-les-Metz,Moulins-lès-Metz', 49.1031800, 6.1072100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52697, 'Moulins-Engilbert', 'Moulins-Engilbert', 'Moulins-Engilbert,Moulins-la-Republique,Moulins-la-République,Mulen-Anzhil''ber,mu lan ang ji er bei er,Мулен-Анжильбер,穆兰昂吉尔贝尔', 46.9882100, 3.8108400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52698, 'Moulins', 'Moulins', 'Molins,Moulins,Mulin,muran,Мулин,ムーラン', 46.5666700, 3.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52699, 'Mouliets-et-Villemartin', 'Mouliets-et-Villemartin', 'Mouliets,Mouliets-et-Villemartin', 44.8333300, -0.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52700, 'Mouleydier', 'Mouleydier', 'Cybard-de-Mouleydier,Mont Leidier,Mont Leidièr,Montleidier e Sench Ibarc,Montleidièr e Sench Ibarç,Mouleydier,Muled''e,mu lai di ye,Муледье,Муледьє,穆莱迪耶', 44.8557200, 0.5975900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52701, 'Moulay', 'Moulay', 'Moulay', 48.2724500, -0.6273400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52702, 'Mouilleron-le-Captif', 'Mouilleron-le-Captif', 'Mouilleron,Mouilleron-le-Captif,Mouilleron-le-Libre,Mujron-le-Kaptif,mu yi lai long lei ka pu di,Муйрон-ле-Каптіф,穆伊莱龙勒卡普蒂', 46.7189800, -1.4546300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52703, 'Mouilleron-en-Pareds', 'Mouilleron-en-Pareds', 'Mouilleron,Mouilleron-en-Pareds', 46.6763000, -0.8494000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52704, 'Mouguerre', 'Mouguerre', 'Moguerre,Mouguerre,Muger,Mugerr,Mugerre,mu gai er,Мугер,Мугерр,穆盖尔', 43.4679500, -1.4182400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52705, 'Mougon', 'Mougon', 'Mougon,Mugon,Мугон', 46.2956100, -0.2865900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52706, 'Mougins', 'Mougins', 'Mogins,Mougins,Muginis,Muzhen,mu ran,mujan,Мужен,ムージャン,穆然', 43.5987300, 7.0043400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52707, 'Mouen', 'Mouen', 'Mouen', 49.1469600, -0.4836600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52708, 'Mouchin', 'Mouchin', 'Mouchin', 50.5163900, 3.2962700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52709, 'Mouchard', 'Mouchard', 'Mouchard', 46.9725900, 5.7962600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52710, 'Mouchamps', 'Mouchamps', 'Mouchamps,Musham,mu shang pu,Мушам,穆尚普', 46.7813100, -1.0617900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52711, 'Mouans-Sartoux', 'Mouans-Sartoux', 'Mouans-Sartoux', 43.6222400, 6.9731200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52712, 'Morzine', 'Morzine', 'Morzena,Morzin,Murisinium,XMQ,morujinu,Морзін,モルジヌ', 46.1814900, 6.7066400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52713, 'Morvillars', 'Morvillars', 'Marvillars,Morvillars', 47.5487400, 6.9343900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52714, 'Mortrée', 'Mortree', 'Mortree,Mortrée', 48.6389900, 0.0790900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52715, 'Morteau', 'Morteau', 'Morto,mo er tuo,Морто,莫尔托', 47.0578400, 6.6071600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52716, 'Mortcerf', 'Mortcerf', 'Morser,Mortcerf,Морсер', 48.7887900, 2.9169200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52717, 'Mortain', 'Mortain', 'Moretoin,Mortain,Morten,mo er tan,Мортен,莫尔坦', 48.6478200, -0.9405500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52718, 'Mortagne-sur-Sèvre', 'Mortagne-sur-Sevre', 'Mortagne,Mortagne-sur-Sevre,Mortagne-sur-Sèvre,Mortan''-sjur-Sevr,sai fu er he pan mo er ta nie,Мортань-сюр-Севр,塞夫尔河畔莫尔塔涅', 46.9920300, -0.9473800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52719, 'Mortagne-sur-Gironde', 'Mortagne-sur-Gironde', 'Mortagne,Mortagne-sur-Gironde,Mortan''-sjur-Zhirond,ji long de he pan mo er ta ni,mwrtan swr jyrwnd,Мортань-сюр-Жиронд,مورتان سور جيروند,吉龙德河畔莫尔塔尼', 45.4813900, -0.7870200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52720, 'Mortagne-du-Nord', 'Mortagne-du-Nord', 'Mortagne,Mortagne-du-Nord,Mortan''-dju-Nor,bei mo er ta nie,Мортань-дю-Нор,北莫尔塔涅', 50.5035200, 3.4535200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52721, 'Mortagne-au-Perche', 'Mortagne-au-Perche', 'Mortagne,Mortan''-o-Persh,mo er ta nie ou pei shen,morutanyu=o=perushu,mwrtany-aw-prsh,Мортань-о-Перш,مورتانی-او-پرش,モルターニュ＝オー＝ペルシュ,莫尔塔涅欧佩什', 48.5166700, 0.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52722, 'Morschwiller-le-Bas', 'Morschwiller-le-Bas', 'Morschweiler,Morschwiller,Morschwiller-le-Bas,Morshviller-le-Ba,mo er si ke wei lai lai ba,Моршвиллер-ле-Ба,Моршвіллер-ле-Ба,莫尔斯克维莱莱巴', 47.7360900, 7.2668700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52723, 'Morsbach', 'Morsbach', 'Morsbach', 49.1708600, 6.8795800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52724, 'Morsang-sur-Orge', 'Morsang-sur-Orge', 'Morsan sir Orzh,Morsan-sjur-Orzh,Morsang,Morsang-sur-Orge,ao er ri he pan mo er sang,moleusangswileuoleuju,morusan=shuru=oruju,mwrsan swr awrzh,Морсан сир Орж,Морсан-сюр-Орж,مورسان سور اورژ,モルサン＝シュル＝オルジュ,奥尔日河畔莫尔桑,모르상쉬르오르주', 48.6618100, 2.3533800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52725, 'Morre', 'Morre', 'Morre', 47.2259500, 6.0751200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52726, 'Morosaglia', 'Morosaglia', 'Merusaglia,Morosaglia,Morozal''ja,Морозалья', 42.4360000, 9.3069400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52727, 'Mornas', 'Mornas', 'Mornas,Mornats,mo er na,morunasu,Морнас,モルナス,莫尔纳', 44.2002500, 4.7290200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52728, 'Mornant', 'Mornant', 'Mornan,Mornant,Морнан', 45.6189700, 4.6737000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52729, 'Mornac', 'Mornac', 'Mornac', 45.6833300, 0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52730, 'Mormoiron', 'Mormoiron', 'Mormeiron,Mormoiron,Mormuaron,mo er mu wa long,Мормуарон,莫尔穆瓦龙', 44.0678300, 5.1788500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52731, 'Mormant', 'Mormant', 'Morinant-l''Egalite,Morinant-l''Egalité,Mormant', 48.6090100, 2.8902500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52732, 'Morlaix', 'Morlaix', 'MXN,Mons Relaxus,Montroulez,Morlaix,Morle,mo er lai,morure,mwrlyks,Морле,مورلیکس,モルレー,莫尔莱', 48.5833300, -3.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52733, 'Morlaas', 'Morlaas', 'Morlaas', 43.3500000, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52734, 'Morigny-Champigny', 'Morigny-Champigny', 'Morigny,Morigny-Champigny,Morin''i-Shampin''i,mo li ni shang pi ni,Мориньи-Шампиньи,Мориньї-Шампіньї,莫里尼尚皮尼', 48.4468500, 2.1835100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52735, 'Morières-lès-Avignon', 'Morieres-les-Avignon', 'Mor''er-lez-Avin''on,Morer-lez-Avin''jon,Morieras dAvinhon,Morieres,Morieres-les-Avignon,Morières,Morières-lès-Avignon,mo li ai lai a wei ni weng,Морьер-лез-Авиньон,Морєр-лез-Авіньйон,莫里埃莱阿维尼翁', 43.9403000, 4.9011000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52736, 'Morienval', 'Morienval', 'Morjanval'',mo li an wa,Морянваль,莫里安瓦', 49.2977000, 2.9207800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52737, 'Morhange', 'Morhange', 'Morhange', 48.9229900, 6.6417900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52738, 'Morez', 'Morez', 'More,Morez,Morez-la-Montagne,mo lei ci,Море,莫雷兹', 46.5254000, 6.0258900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52739, 'Moreuil', 'Moreuil', 'Morej,Moreuil,Moreul,Morjoj,mo lei yi,Морей,Морёй,莫勒伊', 49.7745700, 2.4827300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52740, 'Moret-sur-Loing', 'Moret-sur-Loing', 'More-sjur-Luen,Moret,Море-сюр-Луен', 48.3723900, 2.8171300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52741, 'Morestel', 'Morestel', 'Morestel', 45.6760000, 5.4707900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52742, 'Morée', 'Moree', 'Moree,Morée', 47.9039700, 1.2342100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52743, 'Moréac', 'Moreac', 'Moreac,Moréac,Mourieg', 47.9196700, -2.8193400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52744, 'Mordelles', 'Mordelles', 'Mauricella,Mordel'',Mordelles,Morzhell,mo er dai lai,Мордель,莫尔代莱', 48.0757100, -1.8428600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52745, 'Morcenx', 'Morcenx', 'Morcens,Morcenx,Morsanks,mo er sang,Морсанкс,莫尔桑', 44.0353600, -0.9137500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52746, 'Morbier', 'Morbier', 'Morbier', 46.5369300, 6.0153200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52747, 'Morbecque', 'Morbecque', 'Morbecque', 50.6936500, 2.5178700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52748, 'Morannes', 'Morannes', 'Morann,Morannes,mo la nei,Моранн,莫拉内', 47.7436400, -0.4160400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52749, 'Morangis', 'Morangis', 'Morangis', 48.7038300, 2.3390800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52750, 'Morancez', 'Morancez', 'Morancez', 48.4005100, 1.4938800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52751, 'Morancé', 'Morance', 'Morance,Morancé', 45.8978100, 4.7004100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52752, 'Morainvilliers', 'Morainvilliers', 'Morainvilliers,Morenvil''e,Моренвилье,Моренвільє', 48.9290200, 1.9362100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52753, 'Moosch', 'Moosch', 'Moosch', 47.8596800, 7.0500700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52754, 'Montussan', 'Montussan', 'Montjussan,Montucan,Montussan,Montuçan,meng di sang,Монтюссан,蒙蒂桑', 44.8805700, -0.4218100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52755, 'Montsûrs', 'Montsurs', 'Hercule-Montsurs,Montsurs,Montsûrs', 48.1360400, -0.5541300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52756, 'Mont-sous-Vaudrey', 'Mont-sous-Vaudrey', 'Mon-su-Vodre,Mont,Mont-sous-Vaudrey,meng su wo de lei,Мон-су-Водре,蒙苏沃德雷', 46.9787400, 5.6029500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52757, 'Montsoult', 'Montsoult', 'Monsoult,Monsu,Montsoult,meng te su er,Монсу,蒙特苏尔', 49.0694200, 2.3196600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52758, 'Montségur-sur-Lauzon', 'Montsegur-sur-Lauzon', 'Montsegur,Montsegur-sur-Lauzon,Montségur,Montségur-sur-Lauzon', 44.3613500, 4.8592600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52759, 'Mont-Saxonnex', 'Mont-Saxonnex', 'Mon-Saksonne,Mons Saxonensis,Mont-Saxonnex,Мон-Саксонне', 46.0545900, 6.4878800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52760, 'Mont-Saint-Martin', 'Mont-Saint-Martin', 'Mont-Saint-Martin', 49.5466900, 5.7937500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52761, 'Mont-Saint-Éloi', 'Mont-Saint-Eloi', 'Mon-Sent-Elua,Mont-Saint-Eloi,Mont-Saint-Eloue,Mont-Saint-Eloy,Mont-Saint-Éloi,Mont-Saint-Éloué,Mont-Saint-Éloy,Mont-la-Liberte,Mont-la-Liberté,meng sheng ai lu wa,mwnt san alwy,Мон-Сент-Елуа,مونت سان إلوي,蒙圣埃卢瓦', 50.3510500, 2.6924900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52762, 'Mont-Saint-Aignan', 'Mont-Saint-Aignan', 'Le Mont-Libre,Mon Sent Enan,Mon-Sent-En''jan,Mont-Saint-Aignan,mon=santenyan,mongsaengtenyang,mw sntnyan,Мон Сент Ењан,Мон-Сент-Еньян,مو سنتنیان,モン＝サンテニャン,몽생테냥', 49.4630700, 1.0936400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52763, 'Monts', 'Monts', 'Monts', 47.2772300, 0.6247300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52764, 'Montry', 'Montry', 'Montry', 48.8840900, 2.8291500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52765, 'Montrouge', 'Montrouge', 'Monruzh,Montrouge,meng lu ri,mongluju,monruju,mwntrwzh,Монруж,مونتروژ,モンルージュ,蒙鲁日,몽루주', 48.8162000, 2.3139300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52766, 'Montrottier', 'Montrottier', 'Montrotier,Montrottier', 45.7914200, 4.4662700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52767, 'Montrond-les-Bains', 'Montrond-les-Bains', 'Meylieu-Montrond,Monron-le-Ben,Montrond,Montrond-les-Bains,meng te long lai ban,Монрон-ле-Бен,蒙特龙莱班', 45.6509800, 4.2318700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52768, 'Montrodat', 'Montrodat', 'Montrodat', 44.5503800, 3.3292900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52769, 'Montricoux', 'Montricoux', 'Montricoux', 44.0758900, 1.6194600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52770, 'Montrichard', 'Montrichard', 'Monrishar,Montegalite,Montrichard,Montégalité,meng te li sha er,montorisharu,Монришар,モントリシャール,蒙特里沙尔', 47.3431000, 1.1865300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52771, 'Montrevel-en-Bresse', 'Montrevel-en-Bresse', 'Montrevel,Montrevel-en-Bresse', 46.3366400, 5.1234000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52772, 'Montrevault', 'Montrevault', 'Monrevo,Montrevault,meng te lei wo er,montoruvu~o,Монрево,モントルヴォー,蒙特勒沃尔', 47.2596500, -1.0467900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52773, 'Montreux-Château', 'Montreux-Chateau', 'Montreux-Chateau,Montreux-Château', 47.6085700, 7.0042300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52774, 'Montreuil', 'Montreuil', 'Montrej,Montreuil,Montreuil-sur-Mer,Монтрей', 50.4666700, 1.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52775, 'Montreuil-sur-Ille', 'Montreuil-sur-Ille', 'Montreuil,Montreuil-sur-Ille,Mousterel-an-Il', 48.3078800, -1.6688000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52776, 'Montreuil-sous-Pérouse', 'Montreuil-sous-Perouse', 'Monasteriolum super Petrosam,Montrej-su-Peruz,Montreuil,Montreuil-sous-Perouse,Montreuil-sous-Pérouse,Mousterel-ar-Veineg,meng te lei yi su pei lu si,Монтрей-су-Перуз,蒙特勒伊苏佩鲁斯', 48.1517600, -1.2394600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52777, 'Montreuil-le-Gast', 'Montreuil-le-Gast', 'Montreuil,Montreuil-le-Gast,Mousterel-ar-Gwast', 48.2464700, -1.7249800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52778, 'Montreuil-Bellay', 'Montreuil-Bellay', 'Montrej-Belle,Montreuil-Bellay,Montreuil-le-Thouet,meng te lei yi bei lai,Монтрей-Белле,蒙特勒伊贝莱', 47.1310600, -0.1520900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52779, 'Montreuil-aux-Lions', 'Montreuil-aux-Lions', 'Montreuil,Montreuil-aux-Lions,Montreuil-l''Union', 49.0212400, 3.1954300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52780, 'Montreuil', 'Montreuil', 'Montrej,Montreuil,Montreuil-sous-Bois,Монтрей', 48.8641500, 2.4432200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52781, 'Montrem', 'Montrem', 'Monrem,Montrem,Montrenc,meng te lang,Монрем,蒙特朗', 45.1341700, 0.5902900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52782, 'Montréjeau', 'Montrejeau', 'Monrezho,Mont-rejau,Montrejau,Montrejeau,Montréjeau,meng te lei ruo,Монрежо,蒙特雷若', 43.0855500, 0.5647000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52783, 'Montredon-Labessonnié', 'Montredon-Labessonnie', 'Montredon,Montredon-Labessonnie,Montredon-Labessonnié', 43.7172300, 2.3245400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52784, 'Montréal-la-Cluse', 'Montreal-la-Cluse', 'Delilia-de-Crose,Monreal''-la-Kljuz,meng lei a er la ke ci,mwnrya-la-klws  ayn,Монреаль-ла-Клюз,مونريا-لا-كلوس، أين,蒙雷阿尔拉克兹', 46.1833300, 5.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52785, 'Montréal', 'Montreal', 'Mont-Franc,Montreal,Montreal-du-Gers,Montréal,Montréal-du-Gers', 43.9501600, 0.2035800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52786, 'Montréal', 'Montreal', 'Montreal,Montréal', 43.1998000, 2.1412200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52787, 'Montrabé', 'Montrabe', 'Montrabe,Montrabé', 43.6447700, 1.5238400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52788, 'Mont-près-Chambord', 'Mont-pres-Chambord', 'Mon-pre-Shambor,Mont,Mont-pres-Chambord,Mont-près-Chambord,meng pu lei shang bo er,Мон-пре-Шамбор,蒙普雷尚博尔', 47.5623500, 1.4571200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52789, 'Montpont-en-Bresse', 'Montpont-en-Bresse', 'Monpont-an-Bress,Montpont,Montpont-en-Bresse,Монпонт-ан-Бресс', 46.5563000, 5.1645900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52790, 'Montpon-Ménestérol', 'Montpon-Menesterol', 'Monpon-Menesterol'',Monpont,Mont Paun e Menestairou,Mont Paun e Menestairòu,Montpaun e Menestairou,Montpaun e Menestairòu,Montpon,Montpon-Menesterol,Montpon-Ménestérol,Montpon-sur-l''Isle,Montpon-sur-l’Isle,meng te peng mei nei si tai luo,Монпон-Менестероль,蒙特蓬梅内斯泰罗', 45.0000000, 0.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52791, 'Montpeyroux', 'Montpeyroux', 'Montpeyroux', 43.6959000, 3.5054200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52792, 'Montpellier', 'Montpellier', 'Gorad Manpel''e,MPL,Monpel''e,Monpele,Monpelie,Monpelje,Monpeljē,Monpeljė,Monpelye,Monspessulanus,Montpelhier,Montpelhièr,Montpeller,Montpellier,Montpelyier,Montpelyiér,mamtapeli''e,meng bi li ai,meng bi li ye,mngpex liye,mongpellie,monperie,mwnblyyh,mwnplyh,mwnplyyh,Μονπελιέ,Горад Манпелье,Монпелие,Монпелье,Монпельє,Монпелје,Монпеље,Մոնպելիե,מונפלייה,مونبلييه,مونٹپلائیر,مونپلیه,مونپیلیے,مون‌پلیه,माँतपेलिए,มงเปอลีเย,მონპელიე,モンペリエ,夢比利耶,蒙庇利埃,蒙彼利埃,몽펠리에', 43.6109200, 3.8772300, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52793, 'Montournais', 'Montournais', 'Montournais,Monturne,meng tu er nai,Монтурне,蒙图尔奈', 46.7419100, -0.7646400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52794, 'Montoison', 'Montoison', 'Montoison', 44.7969300, 4.9418600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52795, 'Montois-la-Montagne', 'Montois-la-Montagne', 'Montois,Montois-la-Montagne', 49.2175200, 6.0230500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52796, 'Montoire-sur-le-Loir', 'Montoire-sur-le-Loir', 'Montoire,Montoire-sur-le-Loir,Montuar-sjur-le-Luar,lai-lu wa he pan meng tu wa er,Монтуар-сюр-ле-Луар,莱-卢瓦河畔蒙图瓦尔', 47.7531600, 0.8652500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52797, 'Montoir-de-Bretagne', 'Montoir-de-Bretagne', 'Montoir,Montoir-de-Bretagne,Montorium,Montuar-de-Bretan'',Mouster-al-Loc''h,Mouster-al-Loch,meng tu wa de bu lei ta ni,Монтуар-де-Бретань,蒙图瓦德布雷塔尼', 47.3301200, -2.1510700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52798, 'Montmorot', 'Montmorot', 'Monmoro,Montmorot,meng te mo luo,Монморо,蒙特莫罗', 46.6754100, 5.5228300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52799, 'Montmorillon', 'Montmorillon', 'Monmorijon,Mons Morillonis,meng te mo li long,monmoriyon,Монморийон,Монморійон,モンモリヨン,蒙特莫里隆', 46.4333300, 0.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52800, 'Montmorency', 'Montmorency', 'Monmoransi,Montmorency,Монморанси', 48.9882600, 2.3434000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52801, 'Montmoreau-Saint-Cybard', 'Montmoreau-Saint-Cybard', 'Monmoro-Sen-Sibar,meng te mo luo sheng xi ba er,Монморо-Сен-Сибар,Монморо-Сен-Сібар,蒙特莫罗圣西巴尔', 45.4000000, 0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52802, 'Montmirail', 'Montmirail', 'Montmirail', 48.8721400, 3.5379700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52803, 'Montmeyran', 'Montmeyran', 'Monmejran,Montmairan,Montmeyran,Montnieyran,meng te mei lang,Монмейран,蒙特梅朗', 44.8332000, 4.9747300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52804, 'Montmerle-sur-Saône', 'Montmerle-sur-Saone', 'Monmerl syur Son,Monmerl''-sjur-Son,mwnmyrl-swr-swn,suo en he pan meng mei er,Монмерль-сюр-Сон,Մոնմերլ սյուր Սոն,مونميرل-سور-سون,索恩河畔蒙梅尔', 46.0833300, 4.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52805, 'Montmélian', 'Montmelian', 'Monmel''jan,Montmelian,Montmelyan,Montmèlyan,Montmélian,Монмельян', 45.4999400, 6.0504700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52806, 'Montmédy', 'Montmedy', 'Monmedi,Montmedy,Montmédy,meng mei di,Монмеди,Монмеді,蒙梅迪', 49.5209600, 5.3683500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52807, 'Montmartin-sur-Mer', 'Montmartin-sur-Mer', 'Montmartin,Montmartin-sur-Mer', 48.9886100, -1.5253000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52808, 'Montmarault', 'Montmarault', 'Montmarault', 46.3166800, 2.9561300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52809, 'Montmain', 'Montmain', 'Montmain', 49.4099600, 1.2374200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52810, 'Montmagny', 'Montmagny', 'Montmagny', 48.9733800, 2.3468800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52811, 'Montmacq', 'Montmacq', 'Montmacq', 49.4818100, 2.9025700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52812, 'Montluel', 'Montluel', 'Monljuehl'',Monljuel'',Monluel,Montluel,meng lu er,mwnlwyh,Монлюель,Монлюэль,Մոնլուել,مونلويه,蒙吕尔', 45.8519000, 5.0578000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52813, 'Montluçon', 'Montlucon', 'MCU,Monlison,Monljuson,Mons Luzonis,Montlucon,Montluçon,meng lu song,monglwisong,monryuson,mwnlwswn,Монлисон,Монлюсон,مونلوسون,モンリュソン,蒙吕松,몽뤼송', 46.3333300, 2.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52814, 'Montlouis-sur-Loire', 'Montlouis-sur-Loire', 'Monlui-sjur-Luar,Mont-Loire,Montlouis,Montlouis-sur-Loire,Montoire,lu wa er he pan meng te lu yi,monrui=shuru=rowaru,Монлуї-сюр-Луар,モンルイ＝シュル＝ロワール,卢瓦尔河畔蒙特卢伊', 47.3884500, 0.8320800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52815, 'Montlivault', 'Montlivault', 'Montivault,Montlivault', 47.6398700, 1.4448700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52816, 'Montlignon', 'Montlignon', 'Monlin''on,Montlignon,meng te li ni weng,Монлиньон,Монліньон,蒙特利尼翁', 49.0063600, 2.2870500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52817, 'Montlieu-la-Garde', 'Montlieu-la-Garde', 'Monl''e-la-Gard,Monl''jo-la-Gard,meng te li e la jia er de,Монльё-ла-Гард,Монльє-ла-Гард,蒙特利厄拉加尔德', 45.2500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52818, 'Montlhéry', 'Montlhery', 'Monleri,Mons Lehericus,Montlhery,Montlhéry,meng li rui,Монлери,Монлері,蒙丽瑞', 48.6400400, 2.2746500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52819, 'Montlebon', 'Montlebon', '', 47.0377800, 6.6111100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52820, 'Montlaur', 'Montlaur', 'Chateau de Montlaur,Château de Montlaur,Montlaur', 43.4893500, 1.5680700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52821, 'Montjoire', 'Montjoire', 'Montjoire', 43.7689900, 1.5336200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52822, 'Montjoie-en-Couserans', 'Montjoie-en-Couserans', 'Montjoie,Montjoie-en Conserans,Montjoie-en-Couserans', 43.0025000, 1.1600000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52823, 'Montjean-sur-Loire', 'Montjean-sur-Loire', 'Montjean,Montjean-sur-Loire,Monzhan-sjur-Luar,lu wa er he pan meng te rang,Монжан-сюр-Луар,卢瓦尔河畔蒙特让', 47.3884200, -0.8587300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52824, 'Montivilliers', 'Montivilliers', 'Brutus-Villiers,Montivil''e,Montivilliers,Монтівільє', 49.5451800, 0.1876900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52825, 'Montigny-sur-Loing', 'Montigny-sur-Loing', 'Montigny,Montigny-sur-Loing', 48.3357500, 2.7442300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52826, 'Montigny-lès-Metz', 'Montigny-les-Metz', 'Metz-les-Montigny,Metz-lès-Montigny,Montigny,Montigny-les-Metz,Montigny-lès-Metz,Montin''i-le-Mec,Montini le Mec,meng di ni lai mei te,mongtinilemeseu,montini=re=mesu,mwntyny-lh-ms,mwntynyh lmtz,Монтиньи-ле-Мец,Монтињи ле Мец,Монтіньї-ле-Мец,مونتینی-له-مس,مونتینیه لمتز,モンティニー＝レ＝メス,蒙蒂尼莱梅特,몽티니레메스', 49.0943500, 6.1516700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52827, 'Montigny-lès-Cormeilles', 'Montigny-les-Cormeilles', 'Montigny,Montigny-les-Cormeilles,Montigny-lès-Cormeilles,Montin''i-le-Kormej,meng di ni lai ke er mei ye,Монтиньи-ле-Кормей,Монтіньї-ле-Кормей,蒙蒂尼莱科尔梅耶', 48.9820100, 2.2003500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52828, 'Montigny-Lencoup', 'Montigny-Lencoup', 'Montigny-Lencoup', 48.4516200, 3.0650300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52829, 'Montigny-le-Bretonneux', 'Montigny-le-Bretonneux', 'Montaniacum,Montigny,Montigny-le-Bretonneux,Montin''i-le-Bretonne,Montin''i-le-Bretonnjo,Montini le Bretone,mongtinileubeuleutonoe,montini=ru=buruton''nu,mwntynyh lw brwtwnw,Монтиньи-ле-Бретонне,Монтиньи-ле-Бретоннё,Монтињи ле Бретоне,Монтіньї-ле-Бретонне,مونتینیه لو بروتونو,モンティニー＝ル＝ブルトンヌー,몽티니르브르토뇌', 48.7663600, 2.0340500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52830, 'Montigny-en-Ostrevent', 'Montigny-en-Ostrevent', 'Montigny,Montin''i-an-Ostrevan,meng di ni ang ao si te lei wang,Монтиньи-ан-Остреван,Монтіньї-ан-Остреван,蒙蒂尼昂奥斯特雷旺', 50.3666700, 3.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52831, 'Montigny-en-Gohelle', 'Montigny-en-Gohelle', 'Montigny,Montigny-en-Gohelle,Montin''i-an-Goehl'',Montin''i-an-Goel'',Montini-in-Gohelle,meng di ni ang ge ai lei,mwntyjny an jwhyl,Монтиньи-ан-Гоель,Монтиньи-ан-Гоэль,Монтіньї-ан-Гоель,مونتيجني إن جوهيل,蒙蒂尼昂戈埃勒', 50.4254000, 2.9390200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52832, 'Montigny', 'Montigny', 'Montigny', 49.4596000, 1.0016800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52833, 'Montigné-le-Brillant', 'Montigne-le-Brillant', 'Montigne,Montigne-le-Brillant,Montigné,Montigné-le-Brillant,Montin''e-le-Brijan,meng di nie lai bu li lang,Монтіньє-ле-Бріян,蒙蒂涅莱布里朗', 48.0087200, -0.8148800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52834, 'Montignac', 'Montignac', 'Montignac', 45.0642900, 1.1619600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52835, 'Montier-en-Der', 'Montier-en-Der', 'Montier-en-Der', 48.4782300, 4.7707300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52836, 'Montierchaume', 'Montierchaume', 'Mont''ershom,Mont''eshom,Montierchaume,meng di ye er shao mu,Монтьешом,Монтьєршом,蒙蒂耶尔绍姆', 46.8636200, 1.7718100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52837, 'Monticello', 'Monticello', 'Monticello', 42.6170500, 8.9547700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52838, 'Monthyon', 'Monthyon', 'Monthyon', 49.0075300, 2.8261000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52839, 'Monthermé', 'Montherme', 'Monterme,Montherme,Monthermé,meng te er mei,Монтерме,蒙特尔梅', 49.8846500, 4.7301300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52840, 'Montguyon', 'Montguyon', 'Mongjujon,Mongvion,Montguyon,meng te ji weng,Монгвіон,Монгюйон,蒙特吉翁', 45.2166700, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52841, 'Montgivray', 'Montgivray', 'Montgivray,Monzhivre,meng te ji fu lai,Монживре,蒙特吉夫赖', 46.6032400, 1.9816200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52842, 'Montgiscard', 'Montgiscard', 'Montgiscard,Monzhiskar,meng te ji si ka er,Монжискар,蒙特吉斯卡尔', 43.4607200, 1.5673900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52843, 'Montgeron', 'Montgeron', 'Montgeron,Monzheron,Monzherone,meng te re long,mongjulong,monjuron,mwnzhwrwn,Монжерон,Монжероне,مونژورون,モンジュロン,蒙特热龙,몽주롱', 48.7054300, 2.4503900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52844, 'Montgermont', 'Montgermont', 'Menezgervant,Mons Germundi,Montgermont,Monzhermon,meng te re er meng,Монжермон,蒙特热尔蒙', 48.1559200, -1.7146400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52845, 'Montgaillard', 'Montgaillard', 'Montgailhard,Montgaillard', 42.9333300, 1.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52846, 'Montfrin', 'Montfrin', 'Monfren,Montfrin,meng te fu lan,Монфрен,蒙特夫兰', 43.8759600, 4.5995900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52847, 'Montfort-sur-Meu', 'Montfort-sur-Meu', 'Monfor-sjur-Me,Monfort-sur Meu,Monforzh,Monsfortis,Montfort,Montfort-la-Montagne,Montfort-sur-Meu,Moñforzh,mo he pan meng te fu er,Монфор-сюр-Ме,默河畔蒙特福尔', 48.1354200, -1.9520100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52848, 'Montfort-le-Gesnois', 'Montfort-le-Gesnois', 'Monfor-le-Zhenua,Montfort,Montfort-le-Rotrou,Монфор-ле-Женуа', 48.0500000, 0.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52849, 'Montfort-en-Chalosse', 'Montfort-en-Chalosse', 'Monfor-an-Shaloss,Monfort-an-Shaloss,Montfort,Montfort-en-Chalosse,Monthort,Monthòrt,sha luo si de qu meng te fu er,Монфор-ан-Шалосс,Монфорт-ан-Шалосс,沙洛斯地区蒙特福尔', 43.7112400, -0.8394700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52850, 'Montferrier-sur-Lez', 'Montferrier-sur-Lez', 'Monferrie-sjur-Lez,Montferrier,Montferrier de Les,Montferrier-sur-Lez,Montferrièr de Les,lai he pan meng te fu er li ye,Монферрие-сюр-Лез,Монферріє-сюр-Лез,莱河畔蒙特弗尔里耶', 43.6674200, 3.8543900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52851, 'Montferrat', 'Montferrat', 'Montferra,Montferrat', 45.4859100, 5.5907200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52852, 'Montferrat', 'Montferrat', 'Montferrat', 43.6107200, 6.4823800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52853, 'Montferrand-le-Château', 'Montferrand-le-Chateau', 'Monferran-le-Shato,Montferrand,Montferrand-le-Chateau,Montferrand-le-Château,meng te fu er lang lai sha tuo,Монферран-ле-Шато,蒙特弗尔朗莱沙托', 47.1753600, 5.9153400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52854, 'Montfermeil', 'Montfermeil', 'Monfermej,Montfermeil,meng fei mei yi,monferumeiyu,mongpeleumeyu,mwnfrmay,mwnfrmy,Монфермей,Монфермеј,مونفرماي,مونفرمی,モンフェルメイユ,蒙费梅伊,몽페르메유', 48.8982000, 2.5791300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52855, 'Montfavet', 'Montfavet', 'Montfavet', 43.9333500, 4.8734200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52856, 'Montfaucon', 'Montfaucon', 'Montfaucon', 47.2356200, 6.0816200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52857, 'Montfaucon-Montigné', 'Montfaucon-Montigne', 'Monfokon-Montin''e,Montfaucon,Montfaucon-sur-Moine,meng te fu kong meng di nie,Монфокон-Монтіньє,蒙特福孔蒙蒂涅', 47.1000000, -1.1166700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52858, 'Montfaucon-en-Velay', 'Montfaucon-en-Velay', 'Montfaucon du Velay', 45.1856100, 4.3137600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52859, 'Montfaucon', 'Montfaucon', 'Montfaucon', 44.0724500, 4.7550400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52860, 'Montévrain', 'Montevrain', 'Montevrain,Montevren,Montévrain,Монтеврен', 48.8741500, 2.7511400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52861, 'Monteux', 'Monteux', 'Monteux', 44.0348000, 4.9971900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52862, 'Montesson', 'Montesson', 'Montesson,Монтессон', 48.9092400, 2.1375400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52863, 'Montesquieu-Volvestre', 'Montesquieu-Volvestre', 'Montesk''jo-Vol''vestr,Monteske-Vol''vestr,Montesquieu,Montesquieu-Volvestre,Montesquiu de Bolbestra,Montesquiu de Bolbèstra,Montesquiu de Toars,Montesquiu de Volvestre,Montesquiu de Volvèstre,meng tai si ji e wo er wei si te er,Монтескьё-Вольвестр,Монтескє-Вольвестр,蒙泰斯基厄沃尔韦斯特尔', 43.2072500, 1.2286200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52864, 'Montesquiu d''Albera', 'Montesquiu d''Albera', 'Montesquieu-des-Alberes,Montesquieu-des-Albères,Montesquiu,Montesquiu d''Albera', 42.5179800, 2.8824300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52865, 'Montescourt-Lizerolles', 'Montescourt-Lizerolles', 'Montescourt-Lizerolles', 49.7382800, 3.2573600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52866, 'Montescot', 'Montescot', 'Montescot', 42.6069200, 2.9331800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52867, 'Monterfil', 'Monterfil', 'Monterfij,Monterfil,Mousterfil,meng tai er fei,Монтерфий,Монтерфій,蒙泰尔菲', 48.0673300, -1.9790500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52868, 'Montereau-Fault-Yonne', 'Montereau-Fault-Yonne', 'Monasteriolum Senonum,Montereau,Montero-Fo-Ionn,Montro-Fot-Jon,meng te luo,Монтеро-Фо-Іонн,Монтеро-Фо-Ионн,Монтро-Фот-Йон,蒙特羅', 48.3833300, 2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52869, 'Monterblanc', 'Monterblanc', 'Monterblan,Monterblanc,Sterwenn,meng tai er bu lang ke,Монтерблан,蒙泰尔布朗克', 47.7421100, -2.6795000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52870, 'Montenois', 'Montenois', 'Montenois', 47.4922200, 6.6656100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52871, 'Montendre', 'Montendre', 'Montandr,Montendre,meng tang de er,Монтандр,蒙唐德尔', 45.2846900, -0.4062700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52872, 'Montenay', 'Montenay', 'Montenay,Montene,meng te nai,Монтене,蒙特奈', 48.2878700, -0.8937300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52873, 'Montélimar', 'Montelimar', 'Acumum,Montelaimar,Montelimar,Montelimare,Montélimar,meng te li ma er,mongtellimaleu,monterimaru,mwntlymr,Μοντελιμάρ,Монтелимар,Монтелимаре,Монтелімар,مونتلیمر,モンテリマール,蒙特利馬爾,몽텔리마르', 44.5583800, 4.7509400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52874, 'Montélier', 'Montelier', 'Montaleir,Montalèir,Montel''e,Montelier,Montélier,meng tai li ye,Монтельє,蒙泰利耶', 44.9372600, 5.0311800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52875, 'Montéléger', 'Monteleger', 'Monteleger,Montéléger', 44.8552200, 4.9318100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52876, 'Monteils', 'Monteils', 'Monteils', 44.1686200, 1.5760800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52877, 'Montech', 'Montech', 'Montech,Montesh,Montueg,Montuèg,meng tai ke,Монтеш,蒙泰克', 43.9581600, 1.2320400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52878, 'Montebourg', 'Montebourg', 'Montebaurg,Montebourg,Montebur,meng te bu er,Монтебур,蒙特布尔', 49.4877400, -1.3803600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52879, 'Montdidier', 'Montdidier', '', 49.6500000, 2.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52880, 'Mont-de-Marsan', 'Mont-de-Marsan', 'Lo Mont,Lo Mont de Marsan,Martianum,Mon d''o Marsan,Mon de Marsan,Mon-de-Marsan,Mont-Marat,Mont-de-Marat,Mont-de-Marsan,XMJ,meng de ma sang,mng-dex-mar s xng,mon-de-marsani,mon=do=marusan,mongdeumaleusang,mwn dwmarsan,mwn-dw-marsan,Мон де Марсан,Мон дьо Марсан,Мон-де-Марсан,مون دومارسان,مون-دو-مارسان,มง-เดอ-มาร์ซ็อง,მონ-დე-მარსანი,モン＝ド＝マルサン,蒙德马桑,몽드마르상', 43.8902200, -0.4971300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52881, 'Mont-de-Lans', 'Mont-de-Lans', 'Lo Mont de Lans,Mon-de-Lan,Mon-de-Lans,Mont-de-Lans,meng de lang,Мон-де-Лан,Мон-де-Ланс,蒙德朗', 45.0362600, 6.1314100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52882, 'Montcy-Notre-Dame', 'Montcy-Notre-Dame', 'Montcy,Montcy-Notre-Dame', 49.7750700, 4.7424500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52883, 'Montcuq', 'Montcuq', 'Monkjuk,Montcuc,Montcuq,meng ju ke,Монкюк,蒙居克', 44.3383800, 1.2085000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52884, 'Montcresson', 'Montcresson', 'Monkresson,Montcresson,Monteresson,meng te ke lei song,Монкрессон,蒙特克雷松', 47.9056100, 2.8079600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52885, 'Montcourt-Fromonville', 'Montcourt-Fromonville', 'Montcourt-Fromonville', 48.3067200, 2.7046000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52886, 'Montcornet', 'Montcornet', 'Montcornet', 49.6952600, 4.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52887, 'Montchanin', 'Montchanin', 'Montchanin,Montchanin-les-Mines', 46.7496400, 4.4707000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52888, 'Montcenis', 'Montcenis', 'Montcenis', 46.7878500, 4.3873800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52889, 'Montceau-les-Mines', 'Montceau-les-Mines', 'Mon''ko-le-Min,Monke-le-Mine,Monso le Men,Monso le Min,Monso le Minas,Monso-le-Min,Montceau,Montceau-les-Mines,Μονκό-λε-Μιν,Монке-ле-Мине,Монсо ле Мен,Монсо ле Мин,Монсо-ле-Мин,Монсо-ле-Мін', 46.6666700, 4.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52890, 'Montcaret', 'Montcaret', 'Moncaret,Monkare,Mont Caret,Montcaret,meng te ka lei,Монкаре,蒙特卡雷', 44.8500000, 0.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52891, 'Montbronn', 'Montbronn', 'Mombronn,Monbronn,Montbronn,meng te bu long,Монбронн,蒙特布龙', 48.9939200, 7.3105800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52892, 'Montbron', 'Montbron', 'Monbron,Montberol,Montbron,meng te bu long,Монброн,蒙特布龙', 45.6666700, 0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52893, 'Montbrison', 'Montbrison', 'Montbrise,Montbrisé', 45.6000000, 4.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52894, 'Montboucher-sur-Jabron', 'Montboucher-sur-Jabron', 'Montboucher,Montboucher-sur-Jabron', 44.5503600, 4.8024500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52895, 'Montbonnot-Saint-Martin', 'Montbonnot-Saint-Martin', 'Montbonnot,Montbonnot-Saint-Martin', 45.2223600, 5.8035300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52896, 'Montblanc', 'Montblanc', 'Montblanc', 43.3948600, 3.3675200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52897, 'Montbizot', 'Montbizot', 'Montbizot', 48.1499500, 0.1838400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52898, 'Montbeton', 'Montbeton', 'Montbeton', 44.0166700, 1.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52899, 'Montbert', 'Montbert', 'Monber,Montbert,Monteverzh,meng te bei er,Монбер,蒙特贝尔', 47.0561300, -1.4889000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52900, 'Montberon', 'Montberon', 'Montberon', 43.7158600, 1.4796800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52901, 'Mont-Bernanchon', 'Mont-Bernanchon', '', 50.5833300, 2.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52902, 'Montbéliard', 'Montbeliard', 'Gorad Manbel''jar,Monbel''jar,Monbelijar,Monbeljaras,Mons Biliardi,Mont-Reuni,Mont-Réuni,Montbeliard,Montbèliard,Montbéliard,Montoeliard,meng bei li ya er,mngbe li yar,monberiaru,mongbellialeu,mwntblyar,mwntblyr,Горад Манбельяр,Монбелијар,Монбельяр,مونتبليار,مونتبلیر,มงเบลียาร์,モンベリアル,蒙贝利亚尔,몽벨리아르', 47.5166700, 6.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52903, 'Montbazon', 'Montbazon', 'Monbazon,Montbazon,meng te ba zong,Монбазон,蒙特巴宗', 47.2834800, 0.6998800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52904, 'Montbazin', 'Montbazin', 'Monbazen,Montbasin,Montbazin,meng te ba zan,Монбазен,蒙特巴赞', 43.5166700, 3.6966700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52905, 'Montbazens', 'Montbazens', 'Montbazens', 44.4780700, 2.2298000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52906, 'Montbard', 'Montbard', 'Monbar,Montbard,meng ba er,monbaru,Монбар,Монтбард,モンバール,蒙巴尔', 47.6166700, 4.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52907, 'Montayral', 'Montayral', 'Montairal,Montayral,Monteral'',meng tai la,Монтераль,蒙泰拉', 44.4751300, 0.9876900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52908, 'Montauville', 'Montauville', 'Montauville', 48.9001400, 6.0205500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52909, 'Montaut', 'Montaut', 'Montaut', 43.1333300, -0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52910, 'Montauroux', 'Montauroux', 'Montauron,Montauroux,Montoru,meng tuo lu,Монтору,蒙托鲁', 43.6190500, 6.7749900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52911, 'Montaure', 'Montaure', 'Montaure', 49.2341700, 1.0883700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52912, 'Montauban-de-Bretagne', 'Montauban-de-Bretagne', 'Menezalban,Montauban,Montauban-de-Bretagne,Montoban-de-Bretan'',meng tuo bang de bu lei ta ni,Монтобан-де-Бретань,蒙托邦德布雷塔尼', 48.1993300, -2.0447600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52913, 'Montauban', 'Montauban', 'Mons Albanus,Montalban,Montauban,Montoban,Montobanas,Montompan,Rive-Civique,XMW,meng tuo bang,mng to b xng,mongtobang,montoban,mwntwban,Μοντωμπάν,Монтобан,مونتوبان,มงโตบ็อง,モントーバン,蒙托邦,몽토방', 44.0166700, 1.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52914, 'Montataire', 'Montataire', 'Montataire,Montater,meng ta tai er,Монтатер,蒙塔泰尔', 49.2590000, 2.4377700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52915, 'Montastruc-la-Conseillère', 'Montastruc-la-Conseillere', 'Montastruc,Montastruc-la-Conseillere,Montastruc-la-Conseillère', 43.7198200, 1.5901900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52916, 'Montarnaud', 'Montarnaud', 'Montarnaud,Montarno,meng ta er nuo,Монтарно,蒙塔尔诺', 43.6474300, 3.6969000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52917, 'Montargis', 'Montargis', 'Mons Argii,Mont-Coulounies,Montargis,Montarzhi,meng ta ri,montaruji,mwntarghys,Монтаржи,Монтаржі,مونتارغيس,モンタルジ,蒙塔日', 48.0000000, 2.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52918, 'Montaren-et-Saint-Médiers', 'Montaren-et-Saint-Mediers', 'Montaren,Montaren-et-Saint-Mediers,Montaren-et-Saint-Médiers,Vivacite,Vivacité', 44.0286900, 4.3803000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52919, 'Montardon', 'Montardon', 'Montardon,meng ta er dong,Монтардон,蒙塔尔东', 43.3666700, -0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52920, 'Montans', 'Montans', '', 43.8670000, 1.8856800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52921, 'Montanay', 'Montanay', 'Montanay', 45.8781800, 4.8630300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52922, 'Montamisé', 'Montamise', 'Montamise,Montamisé,Montamize,meng ta mi se,Монтамізе,蒙塔米瑟', 46.6218100, 0.4244200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52923, 'Montalieu-Vercieu', 'Montalieu-Vercieu', 'Montalieu,Montalieu-Vercieu', 45.8157700, 5.4039300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52924, 'Montaigut-sur-Save', 'Montaigut-sur-Save', 'Montagut de Sava,Montaigut,Montaigut-sur-Save,Montegju-sjur-Sav,sa fu he pan meng tai ju,Монтегю-сюр-Сав,萨夫河畔蒙泰居', 43.6894700, 1.2313300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52925, 'Montaigut', 'Montaigut', 'Montaigut', 45.6126700, 3.4477500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52926, 'Montaigu-de-Quercy', 'Montaigu-de-Quercy', 'Montaigu,Montaigu-de-Quercy', 44.3396400, 1.0169000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52927, 'Montaigu', 'Montaigu', 'Montaigu', 46.9766700, -1.3084600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52928, 'Montagny', 'Montagny', 'Montagny', 45.6269900, 4.7578100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52929, 'Montagne', 'Montagne', 'Montagne', 44.9333300, -0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52930, 'Montagnat', 'Montagnat', 'Montagnat', 46.1704800, 5.2905200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52931, 'Montagnac', 'Montagnac', 'Montagnac', 43.4808700, 3.4831200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52932, 'Montady', 'Montady', 'Montadi,Montadin,Montady,meng ta di,Монтади,Монтаді,蒙塔迪', 43.3359000, 3.1278000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52933, 'Mont', 'Mont', 'Mont', 43.4333300, -0.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52934, 'Monswiller', 'Monswiller', 'Monswiller', 48.7551100, 7.3773200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52935, 'Mons-en-Pévèle', 'Mons-en-Pevele', 'Mon-an-Pevel'',Mons,Mons-en Peyele,Mons-en-Pevele,Mons-en-Puelle,Mons-en-Pévèle,Mont-en-Pevele,Mont-en-Pévèle,meng sang pei wei lei,Мон-ан-Певель,蒙桑佩韦勒', 50.4792600, 3.0976700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52936, 'Mons-en-Barœul', 'Mons-en-Baroeul', 'Mons,Mons-en-Baroeul,Mons-en-Barœul', 50.6333300, 3.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52937, 'Monsempron-Libos', 'Monsempron-Libos', 'Monsampron-Libos,Monsempron,Monsempron-Libos,Montsempron,Montsempron e Libos,Montsempron e Libós,meng sang pu long li bo,Монсампрон-Либос,Монсампрон-Лібос,蒙桑普龙利博', 44.4900400, 0.9409000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52938, 'Monségur', 'Monsegur', 'Monsegur,Monségur', 44.6504000, 0.0804700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52939, 'Mons', 'Mons', 'Mons', 44.1148000, 4.1732500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52940, 'Mons', 'Mons', 'Mons', 43.6124000, 1.5720700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52941, 'Monnières', 'Monnieres', 'Meliner,Monnieres,Monnières', 47.1330100, -1.3531700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52942, 'Monnetier-Mornex', 'Monnetier-Mornex', 'Monasterium Mornense,Monnetier,Monnt''e-Morne,Моннтьє-Морне', 46.1603000, 6.2066700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52943, 'Monnaie', 'Monnaie', 'Monnaie', 47.5016200, 0.7887200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52944, 'Monistrol-sur-Loire', 'Monistrol-sur-Loire', 'Monistrol,Monistrol de Leir,Monistrol''-sjur-Luar,Monistrol-sur-Loire,Monistrou de Velai,Monistròl de Leir,Monistròu de Velai,lu wa er he pan mo ni si te luo,Монистроль-сюр-Луар,Моністроль-сюр-Луар,卢瓦尔河畔莫尼斯特罗', 45.2933500, 4.1716100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52945, 'Monflanquin', 'Monflanquin', 'Monflanken,Monflanquin,Montflanquin,meng fu lang qu an,mwnflynkwyn,Монфланкен,مونفلینکوئن,蒙夫朗屈安', 44.5296600, 0.7677200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52946, 'Monéteau', 'Moneteau', 'Moneteau,Monéteau', 47.8492300, 3.5817800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52947, 'Monestiés', 'Monesties', '', 44.0666700, 2.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52948, 'Monein', 'Monein', 'Monein,Monen,Monenh,Muneine,Muneiñe,mo nan,Монен,莫南', 43.3333300, -0.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52949, 'Mondragon', 'Mondragon', 'Mondragon,Montdragon', 44.2385800, 4.7100500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52950, 'Mondoubleau', 'Mondoubleau', 'Mondoubleau,Mondublo,meng du bu luo,Мондубло,蒙杜布洛', 47.9806100, 0.8978200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52951, 'Mondonville', 'Mondonville', 'Mondonville', 43.6729600, 1.2859200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52952, 'Mondeville', 'Mondeville', 'Mondeville', 49.1749700, -0.3223800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52953, 'Mondelange', 'Mondelange', 'Mondelange', 49.2646900, 6.1708700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52954, 'Moncoutant', 'Moncoutant', 'Moncoutant,Monkutan,Mons Constantis,Монкутан', 46.7254700, -0.5879700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52955, 'Moncontour', 'Moncontour', 'Moncontour,Moncontour-de-Poitou,Montagne-sur-Dive', 46.8808600, -0.0199600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52956, 'Monclar-de-Quercy', 'Monclar-de-Quercy', 'Monclar,Monclar-de-Quercy', 43.9655400, 1.5858700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52957, 'Monchy-Saint-Éloi', 'Monchy-Saint-Eloi', 'Monchy,Monchy-Saint-Eloi,Monchy-Saint-Éloi,Monshi Sent Eloa,Monshi-Sent-Elua,meng xi sheng ai lu wa,Монши Сент Елоа,Монші-Сент-Елуа,蒙希圣埃卢瓦', 49.2904200, 2.4673900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52958, 'Monchecourt', 'Monchecourt', 'Monchecourt', 50.3041300, 3.2102900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52959, 'Moncé-en-Belin', 'Monce-en-Belin', 'Monce,Monce-en-Belin,Monce-les-Le Mans,Moncé,Moncé-en-Belin,Moncé-lès-Le Mans,Monse-an-Belen,Монсе-ан-Белен', 47.8944200, 0.1980900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52960, 'Monbazillac', 'Monbazillac', 'Monbazijak,Monbazillac,Mont Basalhac,Montbasalhac,meng ba qi la ke,monbajakku,Монбазияк,Монбазіяк,モンバジャック,蒙巴齐拉克', 44.7937400, 0.4925600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52961, 'Mommenheim', 'Mommenheim', 'Mommemheim,Mommenheim', 48.7575800, 7.6429000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52962, 'Molsheim', 'Molsheim', 'Mol''sajm,Mol''sem,Molsajm,Molse,Molsheim,mo er sai mu,morusuaimu,mwlshaym,mwlshym,mwlzhyym,mxl sim,Молсайм,Мольсайм,Мольсем,מולצהיים,مولشایم,مولشيم,มอลไซม์,モルスアイム,莫尔塞姆', 48.5404200, 7.4919900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52963, 'Mollégès', 'Molleges', 'Moleges,Molegés,Molleges,Mollezhe,Mollezhes,Mollégès,mo lai re,Моллеже,Моллежес,莫莱热', 43.8070300, 4.9493400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52964, 'Molinet', 'Molinet', 'Molinet', 46.4683600, 3.9416100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52965, 'Molières-sur-Cèze', 'Molieres-sur-Ceze', 'Molieres,Molieres-sur-Ceze,Molières,Molières-sur-Cèze', 44.2598900, 4.1583600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52966, 'Molières', 'Molieres', 'Molieres,Molières', 44.1930500, 1.3631800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52967, 'Molac', 'Molac', 'Molac,Moulleg', 47.7301100, -2.4348400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52968, 'Moissy-Cramayel', 'Moissy-Cramayel', 'Mois-la-Plaine,Moissy,Moissy-Cramayel,Moissy-Gramayel,Muassi-Kramael'',Muassi-Kramajel'',Муасси-Крамаель,Муасси-Крамайель,Муассі-Крамаєль', 48.6260500, 2.6012500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52969, 'Moisselles', 'Moisselles', 'Moisselles,Muassel'',mu wa sai lai,Муассель,穆瓦塞莱', 49.0500000, 2.3359700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52970, 'Moissac', 'Moissac', 'Moissac,Muassak,Musciacum,mowasakku,mu wa sa ke,Муассак,モワサック,穆瓦萨克', 44.1023600, 1.0945000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52971, 'Moislains', 'Moislains', 'Moislains,Molin,Mualen,mu wa lan,Муален,穆瓦兰', 49.9882000, 2.9640400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52972, 'Moisenay', 'Moisenay', 'Moisenay', 48.5626600, 2.7352700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52973, 'Moisdon-la-Rivière', 'Moisdon-la-Riviere', 'Maedonium,Maezon-ar-Ster,Maezon-ar-Stêr,Meisdon-la-Riviere,Meisdon-la-Rivière,Moisdon,Moisdon-la-Riviere,Moisdon-la-Rivière,Muadon-la-River,mu wa si dong la li wei ai,Муадон-ла-Ривєр,穆瓦斯东拉里维埃', 47.6217500, -1.3725800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52974, 'Moirans-en-Montagne', 'Moirans-en-Montagne', 'Moirans,Moirans-en-Montagne,Muaran-an-Montan'',meng ta ni de qu mu wa lang,Муаран-ан-Монтань,蒙塔尼地区穆瓦朗', 46.4338100, 5.7264300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52975, 'Moirans', 'Moirans', 'Moirans,Muaran,mu wa lang,Муаран,穆瓦朗', 45.3283000, 5.5534200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52976, 'Moigny-sur-École', 'Moigny-sur-Ecole', 'Muan''i-sjur-Ekol'',ai ke er he pan mu wa ni,Муаньи-сюр-Еколь,Муаньї-сюр-Еколь,埃科尔河畔穆瓦尼', 48.4326200, 2.4580200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52977, 'Moidieu-Détourbe', 'Moidieu-Detourbe', 'Moidieu,Moidieu-Detourbe,Moidieu-Détourbe', 45.5098800, 5.0161300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52978, 'Mogneville', 'Mogneville', 'Mogneville,Mon''evil'',mo gai wei er,Моньєвіль,莫盖维尔', 49.3153500, 2.4717000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52979, 'Moëlan-sur-Mer', 'Moelan-sur-Mer', 'Moelan,Moelan-sjur-Mer,Moelan-sur-Mer,Molan,Moëlan,Moëlan-sur-Mer,bin hai mo e lang,Моелан-сюр-Мер,滨海莫厄朗', 47.8141800, -3.6289200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52980, 'Modane', 'Modane', 'Modan,Modana,Modane,Modâna,XMO,modani,Модан,მოდანი', 45.2000000, 6.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52981, 'Mittelhausbergen', 'Mittelhausbergen', 'Hausbergen', 48.6143600, 7.6900900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52982, 'Mitry-Mory', 'Mitry-Mory', 'Mitri-Mori,Mitry-Mory,Митри-Мори,Мітрі-Морі', 48.9833300, 2.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52983, 'Missillac', 'Missillac', 'Merzhelieg,Missijak,Missilac,Missillac,mi xi la ke,Міссіяк,米西拉克', 47.4815500, -2.1600000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52984, 'Misérieux', 'Miserieux', 'Miserieux,Misérieux', 45.9730900, 4.8123100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52985, 'Miserey-Salines', 'Miserey-Salines', 'Miserey,Miserey-Salines', 47.2863800, 5.9738700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52986, 'Miribel-les-Échelles', 'Miribel-les-Echelles', 'Miribel,Miribel-les-Echelles,Miribel-les-Échelles', 45.4290600, 5.7083500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52987, 'Miribel', 'Miribel', 'Miribel,Miribel'',mi li bei er,myrybyl,Мирибель,Мірибель,Միրիբել,ميريبيل,米里贝尔', 45.8258000, 4.9544000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52988, 'Mireval', 'Mireval', 'Miravau,Mireval,Mireval'',mi lei wa,Миреваль,Міреваль,米勒瓦', 43.5086000, 3.8017000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52989, 'Mirepoix', 'Mirepoix', 'Mirepoix', 43.0877300, 1.8735000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52990, 'Mirepeix', 'Mirepeix', 'Mirapeish,Mirepeix,Mirpe,Mirpeks,mi lei pei,Мирпе,Мирпекс,Мірпекс,米雷佩', 43.1833300, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52991, 'Miremont', 'Miremont', 'Miremont', 43.3699500, 1.4172400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52992, 'Mirefleurs', 'Mirefleurs', 'Mirefleurs', 45.6934600, 3.2244100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52993, 'Mirecourt', 'Mirecourt', 'EPL,Mirecourt,Mirekur,mi lei ku er,Мирекур,Мірекур,米雷库尔', 48.3008900, 6.1328200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52994, 'Mirebeau-sur-Bèze', 'Mirebeau-sur-Beze', 'Mirebeau,Mirebeau-sur-Beze,Mirebeau-sur-Bèze', 47.3982800, 5.3209300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52995, 'Mirebeau', 'Mirebeau', 'Mirabellum,Mirbo,Mirebeau,Mirebeau-en-Poitou,mi lei bo,Мірбо,米雷博', 46.7874300, 0.1834100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52996, 'Miré', 'Mire', 'Mire,Miré', 47.7575900, -0.4915700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52997, 'Mirandol-Bourgnounac', 'Mirandol-Bourgnounac', 'Mirandol,Mirandol-Bourgnounac,Mirandol-Bouroougnac', 44.1427300, 2.1685700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52998, 'Mirande', 'Mirande', 'Mirand,Miranda,mi lang de,mirando,Миранд,Міранд,ミランド,米朗德', 43.5166700, 0.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(52999, 'Miramont-de-Guyenne', 'Miramont-de-Guyenne', 'Miramont,Miramont-de-Guyenne', 44.6015700, 0.3624700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53000, 'Mirambeau', 'Mirambeau', 'Mirambeau', 45.3731000, -0.5706700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53001, 'Miramas', 'Miramas', 'Mirama,Miramas,Miramas Gare,Miramàs,mi la ma,milama,mirama,myrma,Мирама,Мирамас,Мірамас,میرما,ミラマ,米拉马,미라마', 43.5866600, 5.0046400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53002, 'Mirabel-aux-Baronnies', 'Mirabel-aux-Baronnies', 'Mirabel,Mirabel''-o-Baronni,Mirabel-aux-Baronnies,Mirabeu,Mirabèu,mi la bei ao ba luo nie,Мірабель-о-Баронні,米拉贝奥巴罗涅', 44.3113300, 5.0984600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53003, 'Mios', 'Mios', 'Mios', 44.6048900, -0.9332900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53004, 'Mions', 'Mions', 'Mions,Mjon,Мйон', 45.6643200, 4.9499400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53005, 'Mionnay', 'Mionnay', 'Mionnay', 45.8955700, 4.9307400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53006, 'Minihy-Tréguier', 'Minihy-Treguier', 'Ar Vinic''hi,Ar Vinichi,Minihy-Treguier,Minihy-Tréguier,Minii-Treg''e,Minii-Tregie,mi ni yi te lei ji ye,Минии-Трегие,Минии-Трегье,Мінії-Трегіє,米尼伊特雷吉耶', 48.7774600, -3.2288300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53007, 'Miniac-Morvan', 'Miniac-Morvan', 'Min''jak-Morvan,Miniac,Miniac-Morvan,Minieg-Morvan,mi ni a ke mo er wang,Миньяк-Морван,Міньяк-Морван,米尼阿克莫尔旺', 48.5147700, -1.8995500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53008, 'Mimizan', 'Mimizan', 'Mamisan,Mimizan,mi mi cang,Мимизан,Мімізан,米米藏', 44.2005700, -1.2288600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53009, 'Mimet', 'Mimet', 'Mime,Mimet,mi mei,Миме,Міме,米梅', 43.4139300, 5.5049500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53010, 'Mimbaste', 'Mimbaste', '', 43.6488700, -0.9738300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53011, 'Milly-sur-Thérain', 'Milly-sur-Therain', 'Milly,Milly-sur-Therain,Milly-sur-Thérain', 49.5024000, 1.9960500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53012, 'Milly-la-Forêt', 'Milly-la-Foret', 'Mauriliacum,Mii-la-Fore,Milly,Milly-la-Foret,Milly-la-Forêt,mi li la fu lei,Мии-ла-Форе,Мії-ла-Форе,米利拉福雷', 48.4040000, 2.4701500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53013, 'Millery', 'Millery', 'Millery', 45.6317400, 4.7862800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53014, 'Millau', 'Millau', 'Mijo,Milhau,Millan,Millau,mi yue,miyo,myyw,Мийо,Мијо,Мійо,مییو,ሚሎ,ミヨー,米约,미요', 44.1000000, 3.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53015, 'Millas', 'Millas', 'Mijas,Millars,Millas,mi la,Мияс,Міяс,米拉', 42.6920300, 2.6950800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53016, 'Milizac', 'Milizac', 'Milizac,Milizag,Milizak,mi li zha ke,mirizakku,Милизак,Мілізак,ミリザック,米利扎克', 48.4666700, -4.5666700, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53017, 'Milhaud', 'Milhaud', 'Milhaud', 43.7897700, 4.3103500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53018, 'Migné-Auxances', 'Migne-Auxances', 'Migne,Migne-Auxances,Migné,Migné-Auxances,Min''e-Oksans,mi ge ao ke sang se,Міньє-Оксанс,米格奥克桑瑟', 46.6274500, 0.3145800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53019, 'Mignaloux-Beauvoir', 'Mignaloux-Beauvoir', 'Mignaloux,Mignaloux-Beauvoir,Min''jalu-Bovuar,mi ni ya lu bo wa,Міньялу-Бовуар,米尼亚卢博瓦', 46.5415700, 0.4153800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53020, 'Migennes', 'Migennes', 'Migennes', 47.9654800, 3.5178700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53021, 'Mieussy', 'Mieussy', '', 46.1336900, 6.5241600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53022, 'Miélan', 'Mielan', 'M''elan,Melan,Mielan,Miélan,Polastron,mi ai lang,Мьелан,Мєлан,米埃朗', 43.4305400, 0.3079400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53023, 'Mézy-sur-Seine', 'Mezy-sur-Seine', 'Mezi-sjur-Sen,Мези-сюр-Сен,Мезі-сюр-Сен', 49.0000000, 1.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53024, 'Méziré', 'Mezire', 'Mezire,Méziré', 47.5320900, 6.9187200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53025, 'Mézin', 'Mezin', 'Mesin,Mezen,Mezin,Mézin,mei zan,Мезен,梅赞', 44.0566800, 0.2587400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53026, 'Mézières-sur-Seine', 'Mezieres-sur-Seine', 'Mez''er-sjur-Sen,Mezieres-sur-Seine,Mézières-sur-Seine,Мезьер-сюр-Сен,Мезьєр-сюр-Сен', 48.9612800, 1.7924500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53027, 'Mézières-en-Drouais', 'Mezieres-en-Drouais', 'Mezieres,Mezieres-en-Drouais,Mézières,Mézières-en-Drouais', 48.7241300, 1.4244000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53028, 'Mézières-en-Brenne', 'Mezieres-en-Brenne', 'Mez''er-an-Brenn,Mezieres,Mezieres-en-Brenne,Mézières,Mézières-en-Brenne,bu lang de qu mei qi ai,Мезьер-ан-Бренн,Мезьєр-ан-Бренн,布朗地区梅齐埃', 46.8197900, 1.2112300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53029, 'Mézériat', 'Mezeriat', 'Mezeriat,Mézériat', 46.2343100, 5.0480600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53030, 'Mézeray', 'Mezeray', 'Mezeray,Mézeray', 47.8268200, -0.0177000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53031, 'Mezel', 'Mezel', 'Mezel', 45.7551900, 3.2431500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53032, 'Mèze', 'Meze', 'Mesa,Mez,Meze,Mèze,mei ci,Мез,梅兹', 43.4250400, 3.6059000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53033, 'Meyzieu', 'Meyzieu', 'Mejz''e,Meyzieu,Mezje,meijioe,meiju,mzyw,Мезје,Мейзьє,مزیو,メイジュー,메이지외', 45.7666700, 5.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53034, 'Meythet', 'Meythet', 'Meithet,Mejte,Melitetum,Meythet,Мейте', 45.9183600, 6.0942200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53035, 'Meysse', 'Meysse', 'Meysse', 44.6102800, 4.7230600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53036, 'Meyssac', 'Meyssac', 'Meyssac', 45.0557100, 1.6738600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53037, 'Meyrueis', 'Meyrueis', 'Marueis,Maruèis,Mejrjue,Meyrueis,mei lu ai,Мейрюе,梅吕埃', 44.1773700, 3.4308300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53038, 'Meyreuil', 'Meyreuil', 'Mairuelh,Mejrej,Merjoj,Meyreuil,mei lei yi,Мейрей,Мерёй,梅勒伊', 43.4878000, 5.4957400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53039, 'Meyrargues', 'Meyrargues', 'Mairarga,Mejrarg,Merarg,Meyrargues,mei la er gai,Мейрарг,Мерарг,梅拉尔盖', 43.6380600, 5.5261100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53040, 'Meynes', 'Meynes', 'Meynes', 43.8797400, 4.5595800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53041, 'Meymac', 'Meymac', 'Maimac,Maismac,Mejmak,Memak,Meymac,mei ma ke,Меймак,Мемак,梅马克', 45.5348700, 2.1450200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53042, 'Meylan', 'Meylan', 'Mejlan,Melan,Meylan,mei lang,Мейлан,Мелан,梅朗', 45.2198800, 5.7900700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53043, 'Meyenheim', 'Meyenheim', 'Meenajm,Meienheim,Mejenajm,mei ai nan,Меенайм,Мейенайм,Меєнайм,梅埃南', 47.9136400, 7.3556000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53044, 'Mexy', 'Mexy', 'Mexy', 49.5014900, 5.7807000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53045, 'Meximieux', 'Meximieux', 'Meksim''jo,Meksime,Meximieux,mei ke xi mi e,myksymyw,Мексимьё,Мексімє,Մեքսիմյո,ميكسيميو,梅克西米厄', 45.9084100, 5.1952700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53046, 'Meursault', 'Meursault', 'Meursault', 46.9782200, 4.7695200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53047, 'Meursac', 'Meursac', 'Mersak,Meursac,Mjorsak,mo er sa ke,Мерсак,Мёрсак,默尔萨克', 45.6489000, -0.8080100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53048, 'Meurchin', 'Meurchin', 'Mershen,Meurchin,mo er shang,mywrtshyn,Мершен,ميورتشين,默尔尚', 50.4983100, 2.8931800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53049, 'Meung-sur-Loire', 'Meung-sur-Loire', 'Magdunum ad Ligerim,Men-sjur-Luar,Meung,Meung-sur-Loire,lu wa er he pan mo en,Мен-сюр-Луар,卢瓦尔河畔默恩', 47.8312400, 1.6958200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53050, 'Meulan-en-Yvelines', 'Meulan-en-Yvelines', 'Melan,Melan-an-Ivlin,Meulan,Мелан,Мелан-ан-Івлін', 49.0076800, 1.9060200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53051, 'Meudon', 'Meudon', 'Medon,Meudon,Mjodon,Moldonium,Rabelais,mo dong,moedong,mudon,mwdwn,mydwn,Медон,Мёдон,مودون,ميدون,ムードン,默东,뫼동', 48.8138100, 2.2350000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53052, 'Meucon', 'Meucon', 'Mekon,Meucon,Meukon,mo kong,mwkwn,Мекон,موکون,默孔', 47.7164800, -2.7617000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53053, 'Metz-Tessy', 'Metz-Tessy', 'Mec Tesi,Mec-Tessi,Metae,Metz,Metz-Tessy,Мец Теси,Мец-Тессі', 45.9340600, 6.1082600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53054, 'Metzervisse', 'Metzervisse', 'Mecerviss,Metzervisse,Metzerwiesen,mei te ze er wei si,mtsrwysh,Мецервисс,Мецервісс,متسرویسه,梅特泽尔维斯', 49.3150100, 6.2855200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53055, 'Metzeral', 'Metzeral', 'Meceral'',Mecral'',Metzeral,mei te ze la,Мецераль,Мецраль,梅特泽拉', 48.0104400, 7.0708800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53056, 'Metz', 'Metz', 'Divodurum,ETZ,Gorad Mec,Mec,Meca,Mecas,Mediomatricum,Meds,Mets,Mettis,Mety,Metz,Mètz,Méty,Métz,mei si,mesa,meseu,mesu,metcu,metsi,mtz,mytz,mz,Μετς,Горад Мец,Мец,Մեց,מעץ,מץ,متز,میتز,میٹز,मेस,மெட்சு,แม็ส,མེ་ཊི་ཛི།,მეცი,መትዝ,メス,梅斯,메스', 49.1191100, 6.1726900, 'FR', '2016-02-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53057, 'Mettray', 'Mettray', 'Mettre,mei te lai,Меттре,梅特赖', 47.4525100, 0.6493900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53058, 'Méteren', 'Meteren', 'Meteran,Meteren,Metern,mei tai lang,Метеран,梅泰朗', 50.7333300, 2.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53059, 'Messimy', 'Messimy', 'Messimy', 45.6974100, 4.6729100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53060, 'Messigny-et-Vantoux', 'Messigny-et-Vantoux', '', 47.4066600, 5.0171500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53061, 'Messery', 'Messery', 'Messery', 46.3503400, 6.2959000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53062, 'Messei', 'Messei', 'Messe,Messei-Saint-Gervais,mei sai,Мессе,梅塞', 48.7115700, -0.5373900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53063, 'Messein', 'Messein', 'Messein', 48.6112900, 6.1407300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53064, 'Messac', 'Messac', 'Messac,Mezeg,Port de Messac', 47.8239900, -1.8108500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53065, 'Mesquer', 'Mesquer', 'Meske,Mesker,Mesquer,mei si qu ai,mesukeru,Меске,メスケール,梅斯屈埃', 47.3991900, -2.4598600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53066, 'Mesnières-en-Bray', 'Mesnieres-en-Bray', 'Mesnieres,Mesnieres-en-Bray,Mesnières,Mesnières-en-Bray', 49.7617200, 1.3818700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53067, 'Meslay-du-Maine', 'Meslay-du-Maine', 'Mele-dju-Men,Meslay,Meslay-du-Maine,mei si lai di man,Меле-дю-Мен,梅斯莱迪曼', 47.9511600, -0.5542800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53068, 'Meslan', 'Meslan', 'Melan,Melann,Meslan,Mêlann,mei si lang,Мелан,梅斯朗', 47.9950200, -3.4328500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53069, 'Meschers-sur-Gironde', 'Meschers-sur-Gironde', 'Meschers,Meschers-sur-Gironde,Meshe-sjur-Zhirond,Mesher-sjur-Zhirond,ji long de he pan mei si xie er,meshe=shuru=jirondo,Меше-сюр-Жиронд,Мешер-сюр-Жиронд,メシェ＝シュル＝ジロンド,吉龙德河畔梅斯谢尔', 45.5603700, -0.9547000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53070, 'Mésanger', 'Mesanger', 'Mesanger,Mezansker,Mezanzhe,Mésanger,mei sang re,Мезанже,梅桑热', 47.4313100, -1.2279800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53071, 'Méry-sur-Seine', 'Mery-sur-Seine', 'Mery,Mery-sur-Seine,Méry,Méry-sur-Seine', 48.5093700, 3.8912900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53072, 'Méry-sur-Oise', 'Mery-sur-Oise', 'Meri-sjur-Uaz,Mery,Mery-sur-Oise,Méry,Méry-sur-Oise,wa ci he pan mei li,Мери-сюр-Уаз,Мері-сюр-Уаз,瓦兹河畔梅里', 49.0587600, 2.1911300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53073, 'Méry', 'Mery', 'Mery,Méry', 45.6432500, 5.9378200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53074, 'Merxheim', 'Merxheim', '', 47.9112800, 7.2949200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53075, 'Merville-Franceville-Plage', 'Merville-Franceville-Plage', 'Mervil''-Fransvil''-Plazh,Merville,Merville-Franceville-Plage,mei er wei er fu lang se wei er pu la ge,Мервиль-Франсвиль-Плаж,Мервіль-Франсвіль-Плаж,梅尔维尔弗朗瑟维尔普拉格', 49.2721800, -0.1961600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53076, 'Merville', 'Merville', 'Merville', 50.6432900, 2.6412500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53077, 'Merville', 'Merville', '', 43.7235400, 1.2965600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53078, 'Mervent', 'Mervent', 'Mervent,Mervont', 46.5223900, -0.7565400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53079, 'Mervans', 'Mervans', 'Mervan,Mervans,Мерван', 46.7992300, 5.1843000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53080, 'Méru', 'Meru', 'Merju,Meru,Méru,mei lu,Мерю,梅吕', 49.2333300, 2.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53081, 'Mertzwiller', 'Mertzwiller', 'Mercviller,Mertzwiller,Merzmuhler,Merzweiler,Merzwiller,mei er te ci wei lai,mrtswylr,myrtzwylyr,Мерцвиллер,Мерцвіллер,مرتسویلر,ميرتزويلير,梅尔特兹维莱', 48.8684500, 7.6831000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53082, 'Merten', 'Merten', 'Merten', 49.2491000, 6.6663200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53083, 'Mers-les-Bains', 'Mers-les-Bains', 'Mer-le-Ben,Mers,Mers-ches-Bains,Mers-le-Ben,Mers-les-Bains,Mérs-chés-Bains,mei er lai ban,meru=re=ban,Мер-ле-Бен,Мерс-ле-Бен,メール＝レ＝バン,梅尔莱班', 50.0653800, 1.3881000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53084, 'Merlimont', 'Merlimont', 'Mellimont,Merlimon,Merlimont,Méllimont,mei li meng,myrlymwnt,Мерлимон,Мерлімон,ميرليمونت,梅利蒙', 50.4559000, 1.6131500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53085, 'Merlevenez', 'Merlevenez', 'Brelevenez,Merlevenez,Merlevne,mei er lei wei nei,Мерлевне,梅尔勒韦内', 47.7356300, -3.2304700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53086, 'Mérindol', 'Merindol', 'Merendol'',Merindol,Merindou,Merindòu,Mérindol,mei lan duo,Мерендоль,梅兰多', 43.7551600, 5.2035700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53087, 'Mérignies', 'Merignies', 'Merignies,Merini,Mérignies,mei li ni,Мерини,Мерині,梅里尼', 50.5060900, 3.1104300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53088, 'Mérignac', 'Merignac', 'Meirinhac,Merignac,Merignae,Mérignac', 44.8324800, -0.6338100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53089, 'Mériel', 'Meriel', 'Mer''el'',Merel'',Meriel,Mériel,mei li ye,meliel,Мерьель,Мерєль,梅里耶,메리엘', 49.0761400, 2.2105400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53090, 'Méricourt', 'Mericourt', 'Mericourt,Méricourt', 50.4011600, 2.8624600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53091, 'Méribel', 'Meribel', 'MFX,Meribel,Meribel'',Meribelis,Méribel,Мерибель', 45.4149700, 6.5650000, 'FR', '2017-01-15', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53092, 'Méréville', 'Mereville', 'Mereville,Méréville', 48.5913800, 6.1508500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53093, 'Méréville', 'Mereville', 'Mereville,Méréville', 48.3147600, 2.0860900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53094, 'Méreau', 'Mereau', 'Mereau,Méreau', 47.1629500, 2.0508600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53095, 'Méré', 'Mere', 'Mere,Méré', 48.7844500, 1.8124700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53096, 'Merdrignac', 'Merdrignac', 'Medrigneg,Merdrignac,Merdrin''jak,mei er de li ni ya ke,Мердриньяк,梅尔德里尼亚克', 48.1937200, -2.4153300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53097, 'Mercy-le-Bas', 'Mercy-le-Bas', 'Mercy,Mercy-le-Bas', 49.3830200, 5.7504400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53098, 'Mercus-Garrabet', 'Mercus-Garrabet', 'Mercus,Mercus-Garrabet', 42.8779000, 1.6290000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53099, 'Mercury', 'Mercury', 'Mercury-Gemilly,Mercury-Gémilly', 45.6745200, 6.3368800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53100, 'Mercurol-Veaunes', 'Mercurol-Veaunes', 'Mercurol', 45.0743700, 4.8927900, 'FR', '2016-05-09', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53101, 'Mer', 'Mer', 'Mer', 47.7055500, 1.5062100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53102, 'Méounes-lès-Montrieux', 'Meounes-les-Montrieux', 'Meounes,Meounes-les-Montrieux,Méounes,Méounes-lès-Montrieux', 43.2796600, 5.9701200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53103, 'Menucourt', 'Menucourt', 'Menjukur,Menucourt,mei ni ku er,Менюкур,梅尼库尔', 49.0284100, 1.9804600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53104, 'Menton', 'Menton', 'Menton,Mentona,Mentone,XMT,Ментона', 43.7764900, 7.5043500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53105, 'Menthon-Saint-Bernard', 'Menthon-Saint-Bernard', 'Manton-Sen-Bernar,Mentho Gebennensium,Menthon,Мантон-Сен-Бернар', 45.8599500, 6.1955200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53106, 'Mensignac', 'Mensignac', 'Mansin''jak,Mencinhac,Mensignac,mang xi ni ya ke,Мансиньяк,Мансіньяк,芒西尼亚克', 45.2250500, 0.5621400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53107, 'Mens', 'Mens', 'Mens', 44.8175300, 5.7513700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53108, 'Menneval', 'Menneval', 'Menneval,Mennval'',mo na wa,Меннваль,默纳瓦', 49.1000000, 0.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53109, 'Mennecy', 'Mennecy', 'Mennecy,Mennesi,mei nei xi,Меннеси,Меннесі,梅内西', 48.5690300, 2.4438400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53110, 'Ménilles', 'Menilles', 'Menij,Menilles,Ménilles,mei ni lai,Мений,Меній,梅尼莱', 49.0333300, 1.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53111, 'Ménétrol', 'Menetrol', 'Menetrol,Menetrol'',Menistrou,Menistròu,Ménétrol,mei nei te luo,Менетроль,梅内特罗', 45.8718400, 3.1274100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53112, 'Menetou-Salon', 'Menetou-Salon', 'Menetou-Salon,Mentu-Salon,mo nei tu sa long,Менту-Салон,默内图萨隆', 47.2317200, 2.4871500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53113, 'Ménestreau-en-Villette', 'Menestreau-en-Villette', 'Marcilly-en-Villette,Menestreau,Menestreau-en-Villette,Menestro-an-Vil''tte,Ménestreau-en-Villette,wei lai te de qu mei nei si te luo,Менестро-ан-Вільтте,维莱特地区梅内斯特罗', 47.6996200, 2.0233300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53114, 'Ménesplet', 'Menesplet', 'Menesplet,Ménesplet', 45.0166700, 0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53115, 'Ménerbes', 'Menerbes', 'Menerb,Menerba,Menèrba,mei nei er bo,Менерб,梅内尔伯', 43.8324200, 5.2059700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53116, 'Ménéac', 'Meneac', 'Meneac,Meneak,Menieg,Miniacum,Ménéac,mei nei a ke,Менеак,梅内阿克', 48.1397200, -2.4613400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53117, 'Mende', 'Mende', 'MEN,Mende,mando,マンド', 44.5166700, 3.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53118, 'Melun', 'Melun', 'Gorad Meljon,Melen,Meljon,Meljun,Melodunum,Melun,meulloeng,mo lun,muran,mwln,Горад Мелён,Мелен,Мелюн,Мелён,מלאן,مولن,ムラン,默伦,믈룅', 48.5333300, 2.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53119, 'Melrand', 'Melrand', 'Mel''ran,Melrand,Melrant,Mêlrant,mei er lang,Мельран,梅尔朗', 47.9800200, -3.1094100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53120, 'Mellecey', 'Mellecey', 'Mellecey,Mellese,Меллесе', 46.8108400, 4.7282200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53121, 'Melle', 'Melle', 'Melle', 46.2228500, -0.1421600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53122, 'Mellac', 'Mellac', 'Mellac,Mellag,Mellak,mo la ke,Меллак,默拉克', 47.9034500, -3.5767500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53123, 'Mélisey', 'Melisey', 'Melisey,Mélisey', 47.7522900, 6.5801400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53124, 'Melgven', 'Melgven', 'Mel''gvan,Melgven,Melwenn,Mêlwenn,mei er ge wang,Мельгван,梅尔格旺', 47.9062600, -3.8351800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53125, 'Melesse', 'Melesse', 'Melecia,Meled,Meless,Melesse,mo lai si,Мелесс,默莱斯', 48.2177100, -1.6949600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53126, 'Melay', 'Melay', 'Melay,Mele,mo lai,Меле,默莱', 47.1833300, -0.6942900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53127, 'Meistratzheim', 'Meistratzheim', 'Meistratzheim', 48.4480800, 7.5453000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53128, 'Meillonnas', 'Meillonnas', 'Meillonnas,Mejonna,Melyonas,Melyonâs,Meyona,mei yue na si,mylwna,Мейонна,Մեյոնա,ميلونا,梅约纳斯', 46.2434200, 5.3492900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53129, 'Meillac', 'Meillac', 'Meillac,Mejak,Melieg,mei la ke,Меяк,梅拉克', 48.4117400, -1.8137800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53130, 'Meilhan-sur-Garonne', 'Meilhan-sur-Garonne', 'Meilhan,Meilhan-sur-Garonne,Mejan-sjur-Garonn,Melhan,jia luo ne he pan mei yang,Меян-сюр-Гаронн,加罗讷河畔梅扬', 44.5213100, 0.0347200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53131, 'Meilhan', 'Meilhan', '', 43.8643600, -0.7058700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53132, 'Mehun-sur-Yèvre', 'Mehun-sur-Yevre', 'Magdunum,Meehn-sjur-Jevr,Meen-sjur-Evr,Mehun,Mehun-sur-Yevre,Mehun-sur-Yevres,Mehun-sur-Yèvre,Mehun-sur-Yèvres,yi ai fu er he pan mo en,Меен-сюр-Євр,Меэн-сюр-Йевр,伊埃夫尔河畔默恩', 47.1378200, 2.2110500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53133, 'Megève', 'Megeve', 'MVV,Megeva,Megeve,Megevia,Megevo,Megève,Megéva,Mezhev,mgww,mujevu,Межев,مگوو,ムジェーヴ', 45.8523300, 6.6128600, 'FR', '2017-01-15', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53134, 'Mées', 'Mees', 'Mees,Mées', 43.7045200, -1.1095200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53135, 'Médréac', 'Medreac', 'Mederieg,Medreac,Medreak,Médréac,mei de lei a ke,Медреак,梅德雷阿克', 48.2670300, -2.0661800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53136, 'Médis', 'Medis', 'Medi,Medis,Médis,RYN,mei di,Меди,Меді,梅迪', 45.6433700, -0.9629800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53137, 'Médan', 'Medan', 'Medan,Médan', 48.9553900, 1.9949400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53138, 'Mécleuves', 'Mecleuves', 'Mecleuves,Meklev,Mécleuves,mei ke lei wei,Меклев,梅克勒韦', 49.0424000, 6.2716800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53139, 'Meaux', 'Meaux', 'Meldis,Mo,mo,mo cheng,mw,mw  fransh,Мо,مو,مو، فرانسه,モー,莫城,모', 48.9601400, 2.8788500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53140, 'Méaulte', 'Meaulte', 'Meaulte,Meol''t,Mieute,Méaulte,mo er te,Меольт,莫尔特', 49.9816700, 2.6612100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53141, 'Méaudre', 'Meaudre', 'Meaudre,Méaudre', 45.1269500, 5.5270700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53142, 'Mazingarbe', 'Mazingarbe', 'Mazengarb,Mazingarbe,Mazingarpe,ma zan jia er bo,mazynjarb,Мазенгарб,مازينجارب,马赞加尔伯', 50.4710900, 2.7154400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53143, 'Mazières-en-Mauges', 'Mazieres-en-Mauges', 'Mazieres,Mazieres-en-Mauges,Mazières,Mazières-en-Mauges', 47.0453600, -0.8170200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53144, 'Mazières-de-Touraine', 'Mazieres-de-Touraine', 'Mazieres,Mazieres-de-Touraine,Mazières,Mazières-de-Touraine', 47.3832600, 0.4254800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53145, 'Mazet-Saint-Voy', 'Mazet-Saint-Voy', 'Maze-Sen-Vua,Mazet,Mazet-Saint-Voy,Mont-Lizieu,Sant Evosi de Bonas,Sant Evòsi de Bonàs,ma ze sheng wa,Мазе-Сен-Вуа,马泽圣瓦', 45.0478800, 4.2449900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53146, 'Mazères-Lezons', 'Mazeres-Lezons', 'Maseras e Leson,Maseras-Leson,Masèras e Leson,Masèras-Leson,Mazer-Lezon,Mazeres,Mazères,ma ze lei lei zong,Мазер-Лезон,马泽雷勒宗', 43.2666700, -0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53147, 'Mazères', 'Mazeres', 'Mazeres,Mazères', 43.2505500, 1.6772800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53148, 'Mazé', 'Maze', 'Maze,Mazé', 47.4563200, -0.2710600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53149, 'Mazan', 'Mazan', 'Mazan', 44.0568000, 5.1274700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53150, 'Mazamet', 'Mazamet', 'Masamet,Mazame,Mazamet,ma zha mo,Мазаме,马扎默', 43.4900100, 2.3730400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53151, 'May-sur-Orne', 'May-sur-Orne', 'May,May-sur-Orne,Me-sjur-Orn,ao er en he pan mai,Ме-сюр-Орн,奥尔恩河畔迈', 49.1010700, -0.3747100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53152, 'Mayet', 'Mayet', 'Mayet', 47.7596800, 0.2746800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53153, 'Mayenne', 'Mayenne', '', 48.3000000, -0.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53154, 'Maxilly-sur-Léman', 'Maxilly-sur-Leman', 'Maxilly,Maxilly-sur-Leman,Maxilly-sur-Léman', 46.4002700, 6.6461700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53155, 'Maxéville', 'Maxeville', 'Maksevil'',Maxeville,Maxéville,ma ke sai wei er,Максевиль,Максевіль,马克塞维尔', 48.7081600, 6.1696000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53156, 'Maxent', 'Maxent', 'Maxent,Skiriou-Masen,Skirioù-Masen', 47.9833300, -2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53157, 'Mauzé-Thouarsais', 'Mauze-Thouarsais', 'Mauze-Thouarsais,Mauzé-Thouarsais,Moze-Tuarse,Мозе-Туарсе', 46.9761100, -0.2784600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53158, 'Mauzé-sur-le-Mignon', 'Mauze-sur-le-Mignon', 'Mauze,Mauze-sur-le-Mignon,Mauzé,Mauzé-sur-le-Mignon,Moze-sjur-le-Min''on,Мозе-сюр-ле-Міньон', 46.1951600, -0.6703200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53159, 'Mauves-sur-Loire', 'Mauves-sur-Loire', 'Malva,Malvid,Mauve-sur-Loire,Mauves,Mauves-sur-Loire,Mov-sjur-Luar,lu wa er he pan mo wei,Мов-сюр-Луар,卢瓦尔河畔莫韦', 47.2973800, -1.3876300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53160, 'Mauves', 'Mauves', 'Mauves', 45.0352500, 4.8300000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53161, 'Maussane-les-Alpilles', 'Maussane-les-Alpilles', 'Maucana,Maussana deis Aupilhas,Maussane,Maussanne,Mauçana,Mossan-lez-Al''pij,mo sang lai a er pi lai,Моссан-лез-Альпий,Моссан-лез-Альпій,莫桑莱阿尔皮莱', 43.7223600, 4.8049700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53162, 'Maurs', 'Maurs', 'Maurs,Maurs-la-Jolie', 44.7111700, 2.1983200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53163, 'Mauron', 'Mauron', 'Maoron,Mauron,Mauronium,Moron,mo long,Морон,莫龙', 48.0825700, -2.2847700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53164, 'Mauriac', 'Mauriac', 'Mauriac', 45.2166700, 2.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53165, 'Maurepas', 'Maurepas', 'Maurepas', 48.7648600, 1.9292300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53166, 'Maureillas-las-Illas', 'Maureillas-las-Illas', 'Maureillas,Morejas-la-Illas,Morellas,Morellas i les Illes,Morellàs,Morellàs i les Illes,mo lei la la yi la,mrya-la-zyla,mwrya-la-zyla,Мореяс-ла-Іллас,Мореяс-ла-Иллас,مریا-لا-زیلا,موریا-لا-زیلا,莫雷拉拉伊拉', 42.4901400, 2.8075200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53167, 'Maureilhan', 'Maureilhan', 'Maureilhan-et-Ramejan,Maureilhan-et-Raméjan', 43.3500000, 3.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53168, 'Maure-de-Bretagne', 'Maure-de-Bretagne', 'Anast,Maure,Maure-de-Bretagne,Mor-de-Bretan'',mo er de bu lei ta ni,Мор-де-Бретань,莫尔德布雷塔尼', 47.8923900, -1.9910400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53169, 'Maurecourt', 'Maurecourt', 'Maurecourt,Morekur,Морекур', 48.9961400, 2.0615500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53170, 'Maulévrier', 'Maulevrier', 'Maulevrier,Maulévrier,Molevrie,mo lai fu li ye,Молевріє,莫莱夫里耶', 47.0092900, -0.7423900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53171, 'Mauléon-Licharre', 'Mauleon-Licharre', 'Maule-Lextarre,Mauleo,Mauleon,Mauleon-Licharre,Mauleon-Soule,Mauleón,Mauleón-Licharre,Maulion,Mauléon,Mauléon-Licharre,Mauléon-Soule,Moleon-Lishar,Moleon-Lisharr,mo lai weng li sha er,moreon=risharu,Молеон-Лишар,Молеон-Лишарр,Молеон-Лішарр,モレオン＝リシャール,莫莱翁利沙尔', 43.2268400, -0.8803800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53172, 'Maule', 'Maule', 'Maule', 48.9105600, 1.8526400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53173, 'Mauguio', 'Mauguio', 'Condado de Melguelh,Mauguio,Mauguiò,Mauguou,Mauguòu,Melgorium,Mogio,Mont-Salaison,mo ji ao,Могио,Могіо,莫吉奥', 43.6181000, 4.0073900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53174, 'Maubourguet', 'Maubourguet', 'Mauborguet,Maubourguet,Moburge,Moburget,mo bu er gai,Мобурге,Мобургет,莫布尔盖', 43.4682400, 0.0357800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53175, 'Maubeuge', 'Maubeuge', 'Malbodium,Maubeuche,Maubeuge,Mobezh,Mobjozh,XME,mo bo ri,moboeju,mobuju,mwbwzh,Мобеж,Мобёж,موبوژ,モブージュ,莫伯日,모뵈주', 50.2787500, 3.9726700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53176, 'Maubec', 'Maubec', 'Maubec', 45.5674900, 5.2643400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53177, 'Maubec', 'Maubec', 'Maubec', 43.8459300, 5.1402700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53178, 'Matzenheim', 'Matzenheim', '', 48.3945000, 7.6218500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53179, 'Matour', 'Matour', 'Matour', 46.3065400, 4.4817800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53180, 'Matignon', 'Matignon', 'Matignon', 48.5962700, -2.2912500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53181, 'Mathieu', 'Mathieu', 'Mathieu', 49.2544800, -0.3718800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53182, 'Mathay', 'Mathay', 'Mate,Mathay,ma tai,Мате,马泰', 47.4390500, 6.7848700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53183, 'Matha', 'Matha', 'Matha', 45.8682300, -0.3184900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53184, 'Massy', 'Massy', 'Massi,Massy,Масси', 48.7269200, 2.2830100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53185, 'Massongy', 'Massongy', 'Massongy', 46.3160100, 6.3350300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53186, 'Massieux', 'Massieux', 'Massieux', 45.9096900, 4.8332100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53187, 'Massiac', 'Massiac', 'Maciac,Mas''jak,Mass''jak,Massiac,ma xi ya ke,Массьяк,Масьяк,马西亚克', 45.2555100, 3.1975900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53188, 'Masseube', 'Masseube', 'Masjob,Masseb,Masseube,Masseuva,ma se bu,Массеб,Масёб,马瑟布', 43.4298400, 0.5781000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53189, 'Massay', 'Massay', 'Massay,Masse,ma sai,Массе,马赛', 47.1532400, 1.9933400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53190, 'Masny', 'Masny', 'Mani,Masny,ma ni,Мани,Мані,马尼', 50.3479700, 3.2016500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53191, 'Masnières', 'Masnieres', 'Man''er,Masnieres,Masnières,ma ni ye er,Маньер,Маньєр,马尼耶尔', 50.1148900, 3.2088900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53192, 'Masevaux', 'Masevaux', 'Masmuenster,Masmünster,Massevaux,Mazevo,Mazvo,ma se wo,Мазво,Мазево,马瑟沃', 47.7767100, 6.9968300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53193, 'Marzy', 'Marzy', 'Marzy', 46.9812500, 3.0935200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53194, 'Marzan', 'Marzan', 'Marzan,Marzhan,ma er cang,Марзан,马尔藏', 47.5406900, -2.3246600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53195, 'Mary-sur-Marne', 'Mary-sur-Marne', 'Mary-sur-Marne', 49.0159100, 3.0278800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53196, 'Marvejols', 'Marvejols', 'Maruejols,Maruèjols,Marvejols,Marvezhol'',ma er wei ruo er,Марвежоль,马尔韦若尔', 44.5537800, 3.2913700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53197, 'Martres-Tolosane', 'Martres-Tolosane', 'Martres,Martres-Tolosane', 43.1992900, 1.0105600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53198, 'Martizay', 'Martizay', 'Martizay,Martize,ma er di ze,Мартизе,Мартізе,马尔蒂泽', 46.8076700, 1.0432400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53199, 'Martinvast', 'Martinvast', 'Martenva,Martinvast,ma er tan wa si,Мартенва,马尔坦瓦斯', 49.5960800, -1.6643400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53200, 'Martin-Église', 'Martin-Eglise', 'Martin,Martin-Eglise,Martin-Église', 49.9017400, 1.1412000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53201, 'Martillac', 'Martillac', '', 44.7110000, -0.5374700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53202, 'Martigues', 'Martigues', 'Lo Martegue,Martig,Martigas,Martigues,ma er di gai,maleutigeu,marutigu,mrtyg,Мартиг,Мартіг,مرتیگ,マルティーグ,马尔蒂盖,마르티그', 43.4073500, 5.0552600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53203, 'Martigné-Ferchaud', 'Martigne-Ferchaud', 'Martigne-Ferchaud,Martigne-Forchaud,Martigneium Ferri Calidi,Martigné-Ferchaud,Martigné-Forchaud,Martin''e-Fersho,Marzhinieg-Houarnruz,Mazhinieg-Houarnruz,ma er di nie fu er shao,Мартинье-Фершо,Мартіньє-Фершо,马尔蒂涅弗尔绍', 47.8293400, -1.3191100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53204, 'Martigné-Briand', 'Martigne-Briand', 'Martigne,Martigne-Briand,Martigné,Martigné-Briand,Martin''e-Brian,ma er di nie bu li ang,Мартіньє-Бріан,马尔蒂涅布里昂', 47.2335800, -0.4293300, 'FR', '2017-05-31', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53205, 'Martigné-sur-Mayenne', 'Martigne-sur-Mayenne', 'Martigre,Martigré', 48.2000000, -0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53206, 'Martignat', 'Martignat', 'Martignat', 46.2097200, 5.6104900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53207, 'Martignas-sur-Jalle', 'Martignas-sur-Jalle', 'Martignas,Martignas-sur-Jalle,Martignas-sur-dalle,Martin''jas-sjur-Zhal'',Martinhas,Martinhàs,ya er he pan ma er di ni ya,Мартиньяс-сюр-Жаль,Мартіньяс-сюр-Жаль,雅尔河畔马尔蒂尼亚', 44.8452800, -0.7806000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53208, 'Marthod', 'Marthod', 'Marthod,Marto,Марто', 45.7284000, 6.4129800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53209, 'Marssac-sur-Tarn', 'Marssac-sur-Tarn', 'Marssac,Marssac-sur-Tarn', 43.9176800, 2.0292100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53210, 'Marsilly', 'Marsilly', 'Marsilly', 46.2302700, -1.1384000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53211, 'Marsillargues', 'Marsillargues', 'Macilhargues,Marcilhanicae,Marsijarg,Marsilhargues,Marsillargues,ma er xi la er gai,Марсиярг,Марсіярг,马尔西拉尔盖', 43.6642400, 4.1744800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53212, 'Marseille', 'Marseille', 'Gorad Marsel'',MRS,Marseggia,Marsegia,Marseglia,Marseilla,Marseille,Marseilles,Marsej,Marseja,Marsejlo,Marsel,Marsel'',Marsela,Marsele,Marselha,Marselis,Marsella,Marsella - Marseille,Marselye,Marsey,Marseya,Marseļa,Marsiella,Marsigghia,Marsiglia,Marsiho,Marsilha,Marsilia,Marsilija,Marsilya,Marsylia,Marsylijo,Marsèja,Marsêle,Marsêy,Massalia,Massilia,ma sai,maleuseyu,mar se,mar sæy,marcey,marsaiya,marsela,marseli,marsy,marsylya,marsylz,maruseiyu,mrsylya,mrsyy,Μασσαλία,Горад Марсель,Марсель,Марсеј,Марсељ,Марсилия,Մարսել,מארסיי,מרסיי,مارسيليا,مارسی,مارسیلز,مارسێی,مرسيليا,मार्सेल,मार्सैय,மர்சேய்,มาร์เซ,มาร์แซย์,မာဆေးမြို့,მარსელი,ማርሴ,マルセイユ,马赛,마르세유', 43.2969500, 5.3810700, 'FR', '2017-04-11', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53213, 'Marseillan', 'Marseillan', 'Marseillan', 43.3561800, 3.5279500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53214, 'Marsat', 'Marsat', 'Marcac de Riam,Marsa,Marsat,Marçac de Riam,ma er sa,Марса,马尔萨', 45.8765500, 3.0828800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53215, 'Marsanne', 'Marsanne', 'Marsanne', 44.6437500, 4.8739400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53216, 'Marsannay-la-Côte', 'Marsannay-la-Cote', 'Marsannay,Marsannay-la-Cote,Marsannay-la-Côte,Marsanne-la-Kot,ma er sa nai la ke te,marsany-la-kt,marusane=ra=koto,Марсанне-ла-Кот,مارسانی-لا-کت,マルサネ＝ラ＝コート,马尔萨奈拉科特', 47.2709500, 4.9889500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53217, 'Marsac-sur-Don', 'Marsac-sur-Don', 'Marciacum,Marsac,Marsac-sur-Don,Marsak-sjur-Don,Marzheg,dong he pan ma er sa ke,marusakku=shuru=don,Марсак-сюр-Дон,マルサック＝シュル＝ドン,东河畔马尔萨克', 47.5964800, -1.6795200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53218, 'Marsac-en-Livradois', 'Marsac-en-Livradois', 'Marsac,Marsac-en-Livradois', 45.4788200, 3.7272600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53219, 'Marquise', 'Marquise', 'Beaupre,Beaupré,Marquise', 50.8129400, 1.7078600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53220, 'Marquion', 'Marquion', 'Mark''on,Markjon,Marquion,ma ji yong,markywywn,Маркйон,Маркьон,ماركيويون,马基永', 50.2112600, 3.0871900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53221, 'Marquillies', 'Marquillies', 'Markii,Marquillies,ma er ji ye,Маркии,Маркії,马尔基耶', 50.5557700, 2.8706700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53222, 'Marquette-lez-Lille', 'Marquette-lez-Lille', 'Markett-le-Lill'',Marquette,ma kai te lai li er,Маркетт-ле-Лилль,Маркетт-ле-Лілль,马凯特莱里尔', 50.6762800, 3.0661300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53223, 'Marquefave', 'Marquefave', 'Marquefave', 43.3176600, 1.2466100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53224, 'Marpent', 'Marpent', 'Marpan,Marpen,Marpent,ma er pang,Марпан,马尔庞', 50.2925200, 4.0793600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53225, 'Maromme', 'Maromme', 'Maromm,Maromme,Маромм', 49.4792500, 1.0237500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53226, 'Marolles-sur-Seine', 'Marolles-sur-Seine', 'Marolles,Marolles-sur-Seine', 48.3866200, 3.0356200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53227, 'Marolles-les-Braults', 'Marolles-les-Braults', 'Marol''-le-Bro,Marolles,Marolles-les-Braults,Мароль-ле-Бро', 48.2527100, 0.3163100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53228, 'Marolles-en-Hurepoix', 'Marolles-en-Hurepoix', 'Marol''-an-Jurepua,Marolles,Marolles-en-Hurepoix,yu lei pu wa de qu ma luo lei,Мароль-ан-Юрепуа,于雷普瓦地区马罗勒', 48.5623200, 2.2988500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53229, 'Maroilles', 'Maroilles', 'Maroilles,Maroilles-en-Thierache,Maroilles-en-Thiérache', 50.1350800, 3.7613200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53230, 'Marœuil', 'Maroeuil', 'Marej,Mareul,Marjoj,Maroeuil,Marœuil,ma lei yi,marwyl,Марей,Марёй,مارويل,马勒伊', 50.3251900, 2.7050400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53231, 'Marnes-la-Coquette', 'Marnes-la-Coquette', 'Marn la Koket,Marn-la-Kokett,Marna,Marnes,Marnes-la-Coquette,ma er na la ke qu ai te,marunu=ra=koketto,Марн ла Кокет,Марн-ла-Кокетт,マルヌ＝ラ＝コケット,马尔纳拉科屈埃特', 48.8273200, 2.1715100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53232, 'Marnaz', 'Marnaz', 'Marnaz', 46.0620100, 6.5269200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53233, 'Marnay', 'Marnay', 'Marnay', 47.2908800, 5.7727700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53234, 'Marmoutier', 'Marmoutier', 'Marmoutier', 48.6900500, 7.3819500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53235, 'Marmande', 'Marmande', 'Marmand,Marmanda,Marmande,XMR,ma er mang de,marmand,marumando,Марманд,مارماند,マルマンド,马尔芒德', 44.5000000, 0.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53236, 'Marmagne', 'Marmagne', 'Marmagne', 47.1000000, 2.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53237, 'Marmagne', 'Marmagne', 'Marmagne', 46.8366600, 4.3589200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53238, 'Marly', 'Marly', 'Marly-sur-Seille', 49.0666700, 6.1500000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53239, 'Marly-le-Roi', 'Marly-le-Roi', 'Marli le Roa,Marli-le-Rua,Marly,Marly-la-Machine,Marly-le-Roi,maruri=ru=rowa,Марли ле Роа,Марли-ле-Руа,Марлі-ле-Руа,マルリー＝ル＝ロワ', 48.8666700, 2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53240, 'Marly-la-Ville', 'Marly-la-Ville', 'Marli-la-Vil'',Marly,Marly-la-Ville,ma er li cheng,Марли-ла-Виль,Марлі-ла-Віль,马尔利城', 49.0820100, 2.5034700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53241, 'Marly', 'Marly', 'Marly', 50.3455600, 3.5495900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53242, 'Marlhes', 'Marlhes', 'Marl'',Marlhas,Marlhes,ma er ye,Марль,马尔耶', 45.2832100, 4.3975200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53243, 'Marles-les-Mines', 'Marles-les-Mines', 'Marl''-le-Min,Marles,Marles-les-Mines,ma er lei lai mi ne,marlys lyh mynys,Марль-ле-Мин,Марль-ле-Мін,مارليس ليه مينيس,马尔勒莱米讷', 50.5047800, 2.5088200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53244, 'Marles-en-Brie', 'Marles-en-Brie', 'Marl''-an-Bri,Marles,Marles-en-Brie,Марль-ан-Бри,Марль-ан-Брі', 48.7278300, 2.8800300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53245, 'Marlenheim', 'Marlenheim', 'Maarle,Marlenajm,Mààrle,ma er lei nan,marlnhaym,marlynhym,Марленайм,مارلنهایم,مارلينهيم,马尔勒南', 48.6213400, 7.4909600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53246, 'Marle', 'Marle', 'Marle,Marle-et-Behaine', 49.7400600, 3.7706000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53247, 'Maringues', 'Maringues', 'Manergium,Mareng,Maringas,Maringues,ma lan gai,Маренг,马兰盖', 45.9211700, 3.3296900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53248, 'Marines', 'Marines', 'Marines', 49.1448500, 1.9822600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53249, 'Marin', 'Marin', 'Marin', 46.3747200, 6.5302200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53250, 'Marigny-les-Usages', 'Marigny-les-Usages', 'Marigny,Marigny-les-Usages,Marin''i-lez-Juzazh,ma li ni lai yu sa re,Мариньї-лез-Юзаж,马里尼莱于萨热', 47.9579900, 2.0146200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53251, 'Marigny-le-Châtel', 'Marigny-le-Chatel', 'Marigny,Marigny-le-Chatel,Marigny-le-Châtel,Marin''i-le-Shatel'',ma li ni lai sha tai,Мариньи-ле-Шатель,Мариньї-ле-Шатель,马里尼莱沙泰', 48.4029100, 3.7358800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53252, 'Marigny-Brizay', 'Marigny-Brizay', 'Marigny,Marigny-Brizay,Marin''i-Brize,ma li ni bu li ze,Мариньї-Бризе,马里尼布里泽', 46.7462200, 0.3762600, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53253, 'Marigny', 'Marigny', 'Marigny', 49.0995200, -1.2417900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53254, 'Marignier', 'Marignier', '', 46.0901400, 6.5000400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53255, 'Marigné-Laillé', 'Marigne-Laille', 'Marigne,Marigne-Laille,Marigné,Marigné-Laillé', 47.8176500, 0.3405000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53256, 'Marignane', 'Marignane', 'Marignanc,Marignane,Marin''jan,Marinan,Marinhana,ma li ni ang,malinyan,marinyanu,mrynyn,Мариньян,Марињан,مرینین,マリニャーヌ,马里尼昂,마리냔', 43.4160400, 5.2145300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53257, 'Marguerittes', 'Marguerittes', 'Margarida,Margaridas,Margeritt,Marguerittes,ma er gai li tai,Маргеритт,马尔盖里泰', 43.8596000, 4.4451700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53258, 'Margon', 'Margon', 'Margon', 48.3356800, 0.8345400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53259, 'Margny-lès-Compiègne', 'Margny-les-Compiegne', 'Margny,Margny-les-Compiegne,Margny-lès-Compiègne,Marn''i-le-Komp''en'',Marn''i-le-Kompen'',ma er ni lai kong pi ye ni,Марньи-ле-Компьень,Марньї-ле-Компєнь,马尔尼莱孔皮耶尼', 49.4255900, 2.8180600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53260, 'Margency', 'Margency', 'Margency,Marzhansi,ma er gang xi,Маржанси,Маржансі,马尔冈西', 49.0000000, 2.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53261, 'Margencel', 'Margencel', 'Margencel', 46.3370000, 6.4330500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53262, 'Margaux', 'Margaux', 'Margaux', 45.0401200, -0.6789200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53263, 'Mareuil-sur-Ourcq', 'Mareuil-sur-Ourcq', 'Mareuil,Mareuil-sur-Ourcq', 49.1375200, 3.0782200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53264, 'Mareuil-sur-Lay-Dissais', 'Mareuil-sur-Lay-Dissais', 'Mareuil,Vigneron', 46.5333300, -1.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53265, 'Mareuil-sur-Cher', 'Mareuil-sur-Cher', 'Mareuil,Mareuil-sur-Cher', 47.2931400, 1.3289700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53266, 'Mareuil', 'Mareuil', 'Mareuil-sur-Belle', 45.4500000, 0.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53267, 'Mareuil-sur-Ay', 'Mareuil-sur-Ay', 'Mareuil,Mareuil-sur-Ay', 49.0458100, 4.0358700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53268, 'Mareuil-lès-Meaux', 'Mareuil-les-Meaux', 'Mareuil,Mareuil-les-Meaux,Mareuil-lès-Meaux', 48.9264800, 2.8613400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53269, 'Mareuil-le-Port', 'Mareuil-le-Port', 'Mareuil,Mareuil-le-Port', 49.0817900, 3.7601100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53270, 'Maretz', 'Maretz', 'Maretz', 50.0453000, 3.4180800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53271, 'Marennes', 'Marennes', 'Marennes', 45.8228000, -1.1054600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53272, 'Marennes', 'Marennes', 'Marennes', 45.6205400, 4.9155100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53273, 'Mareil-sur-Mauldre', 'Mareil-sur-Mauldre', 'Mareil,Mareil-sur-Mauldre,Marej-sjur-Mol''dr,Марей-сюр-Мольдр', 48.8952100, 1.8687000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53274, 'Mareil-Marly', 'Mareil-Marly', 'Mareil,Mareil-Marly,Marej-Marli,Марей-Марли,Марей-Марлі', 48.8821300, 2.0735100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53275, 'Mareau-aux-Prés', 'Mareau-aux-Pres', 'Mareau,Mareau-aux-Pres,Mareau-aux-Prés,Maro-o-Pre,ma luo ao pu lei,Маро-о-Пре,马罗奥普雷', 47.8666700, 1.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53276, 'Mardié', 'Mardie', 'Mard''e,Mardie,Mardié,ma er di ai,Мардьє,马尔迪埃', 47.8861700, 2.0574500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53277, 'Mardeuil', 'Mardeuil', 'Mardeuil', 49.0539300, 3.9300000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53278, 'Marcq-en-Barœul', 'Marcq-en-Baroeul', 'Marcq,Marcq-en-Baroeul,Marcq-en-Barœul,Mark an Baro,Mark-an-Barel'',Mark-an-Barjol'',Marke-in-Bareul,Marq,Marq-en-Baroeul,Marquette-en-Baroeul,ma er kang ba lei er,maleukeuangbaloel,maruku=an=baruru,mrkan brwl,Марк ан Баро,Марк-ан-Барель,Марк-ан-Барёль,مرکان برول,マルク＝アン＝バルール,马尔康巴勒尔,마르크앙바뢸', 50.6666700, 3.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53279, 'Marcoussis', 'Marcoussis', 'Marcoussis,Markussi,ma er ku xi,Маркусси,Маркуссі,马尔库西', 48.6402600, 2.2385800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53280, 'Marcorignan', 'Marcorignan', 'Marcorignan', 43.2263400, 2.9228100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53281, 'Marconnelle', 'Marconnelle', 'Marconelle,Marconnelle', 50.3758800, 2.0110800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53282, 'Marconne', 'Marconne', 'Fontaine-Libre,Marconne', 50.3714300, 2.0466900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53283, 'Marçon', 'Marcon', 'Marcon,Marçon', 47.7105900, 0.5110100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53284, 'Marcoing', 'Marcoing', 'Marcoing', 50.1211000, 3.1732100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53285, 'Marckolsheim', 'Marckolsheim', 'Markelse,Markol''sajm,Markolsheim,Màrkelse,ma er ke er sang,marklshaym,markwlshym,Маркольсайм,ماركولشيم,مارکلسهایم,马尔科尔桑', 48.1647100, 7.5440000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53286, 'Marck', 'Marck', 'Marck', 50.9489700, 1.9432800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53287, 'Marcilly-sur-Tille', 'Marcilly-sur-Tille', 'Marcilly,Marcilly-sur-Tille', 47.5170000, 5.1297900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53288, 'Marcilly-sur-Eure', 'Marcilly-sur-Eure', 'Marcilly,Marcilly-sur-Eure,Marsii-sjur-Er,e er he pan ma er xi li,Марсии-сюр-Ер,Марсії-сюр-Ер,厄尔河畔马尔西利', 48.8256800, 1.3474100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53289, 'Marcilly-en-Villette', 'Marcilly-en-Villette', 'Marcilly-en-Villette,Marsii-an-Vil''tte,wei lai te de qu ma er xi li,Марсії-ан-Вільтте,维莱特地区马尔西利', 47.7650500, 2.0226600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53290, 'Marcillac-Vallon', 'Marcillac-Vallon', 'Marcillac,Marcillac-Vallon,Marcillac-d''Aveyron', 44.4746400, 2.4645400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53291, 'Marcillac', 'Marcillac', 'Marcillac,Marcillac-de Blaye', 45.2687000, -0.5237900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53292, 'Marcigny', 'Marcigny', 'Marcigny,Marcigny-sur-Loire,Marsin''i,Марсиньи,Марсіньї', 46.2762700, 4.0395700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53293, 'Marciac', 'Marciac', 'Marciac,Mars''jak,ma er xi ya ke,Марсьяк,马尔西亚克', 43.5232100, 0.1609100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53294, 'Marchiennes', 'Marchiennes', 'Marchienne,Marchiennes,Marchiennes-Campagne,Marsh''en,Marsh''enn,Marshenn,ma er xie ne,Маршьен,Маршьенн,Маршєнн,马尔谢讷', 50.4000000, 3.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53295, 'Marcheprime', 'Marcheprime', 'Marcha Prima,Marchaprima,Marcheprime,Marshprim,ma er xie pu li mu,Маршприм,马尔谢普里姆', 44.6914600, -0.8549600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53296, 'Marcey-les-Grèves', 'Marcey-les-Greves', 'Marcey,Marcey-les-Greves,Marcey-les-Grèves', 48.6967300, -1.3915600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53297, 'Marcellaz-Albanais', 'Marcellaz-Albanais', 'Marcellatium Gebennensium,Marcellaz,Marcellaz-Albanais,Marsella-Al''bane,Марселла-Альбане', 45.8752600, 6.0016200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53298, 'Marcamps', 'Marcamps', '', 45.0404500, -0.4927500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53299, 'Marboz', 'Marboz', 'Marboz', 46.3433700, 5.2597800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53300, 'Marboué', 'Marboue', 'Marboue,Marboué', 48.1137700, 1.3321000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53301, 'Marbache', 'Marbache', 'Marbache', 48.7957200, 6.0975200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53302, 'Maraussan', 'Maraussan', 'Maraucan,Maraussan,Marauçan,Marossan,ma luo sang,Мароссан,马罗桑', 43.3689500, 3.1564300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53303, 'Marans', 'Marans', 'Marans', 46.3081100, -0.9945000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53304, 'Marange-Silvange', 'Marange-Silvange', 'Marange,Marange-Silvange', 49.2074800, 6.1022800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53305, 'Manziat', 'Manziat', 'Manziat', 46.3594000, 4.9066200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53306, 'Manzat', 'Manzat', 'Manza,Manzac,Manzat,mang zha,Манза,芒扎', 45.9610500, 2.9420500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53307, 'Manthelan', 'Manthelan', 'Manthelan,Manthelon', 47.1363200, 0.7931900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53308, 'Mantes-la-Ville', 'Mantes-la-Ville', 'Mant-la-Vil'',Mantes-la-Ville,manto=ra=vu~iru,Мант-ла-Виль,Мант-ла-Віль,マント＝ラ＝ヴィル', 48.9737400, 1.7025300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53309, 'Mantes-la-Jolie', 'Mantes-la-Jolie', 'Madante,Mant la Zholi,Mant-la-Zholi,Mant-lja-Zholi,Mantes,Mantes-Gassicourt,Mantes-Sur-Seine,Mantes-la-Jolie,Maðante,Medanta,mangteulajolli,mant-azhwly,manto=ra=jori,Мант ла Жоли,Мант-ла-Жоли,Мант-ла-Жолі,Мант-ля-Жоли,مانت-اژولی,マント＝ラ＝ジョリー,망트라졸리', 48.9833300, 1.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53310, 'Mansle', 'Mansle', 'Manl'',Mansle,mang si er,Манль,芒斯尔', 45.8752600, 0.1791400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53311, 'Mansigné', 'Mansigne', 'Mansigne,Mansigné', 47.7483300, 0.1331100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53312, 'Mansac', 'Mansac', 'Mansac', 45.1687000, 1.3834100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53313, 'Manosque', 'Manosque', 'Manosca,Manosk,Manoske,Manosque,Manòsca,mang ao si qu ai,manoseukeu,manosuku,mnwsk,Маноск,Маноске,منوسک,マノスク,芒奥斯屈埃,마노스크', 43.8288300, 5.7868800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53314, 'Manom', 'Manom', 'Manom,Monhofen,mang weng,manwm,Маном,مانوم,芒翁', 49.3698500, 6.1855500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53315, 'Manneville-sur-Risle', 'Manneville-sur-Risle', 'Manneville,Manneville-sur-Risle', 49.3517300, 0.5452600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53316, 'Manéglise', 'Maneglise', 'Maneglise,Manegliz,Manéglise,Манеглиз,Манегліз', 49.5657800, 0.2557200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53317, 'Mane', 'Mane', 'Mane', 43.9374700, 5.7667700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53318, 'Manduel', 'Manduel', 'Mandjuel'',Manduel,Manduelh,Manduèlh,mang di ai,Мандюель,芒迪埃', 43.8185500, 4.4724700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53319, 'Mandres-les-Roses', 'Mandres-les-Roses', 'Mandr-le-Roz,Mandres,Mandres-les-Roses,mang de lei lai luo si,Мандр-ле-Роз,芒德雷莱罗斯', 48.7019800, 2.5466200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53320, 'Mandeure', 'Mandeure', 'Epamanduodurum,Mander,Mandeure,mang de er,Мандер,芒德尔', 47.4492100, 6.8076200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53321, 'Mandelieu-la-Napoule', 'Mandelieu-la-Napoule', 'Mandaluec la Napola,Mandatluec,Mandel''e-la-Napul'',Mandel''jo-la-Napul'',Mandelieu,Mandelieu-La Napoule,Mandelije la Napul,mandlyw lnpwl,mandoryu=ra=napuru,mandylyw la nabwl,mang dai li e la na pu er,mangdeullioelanapul,Манделије ла Напул,Мандельё-ла-Напуль,Мандельє-ла-Напуль,ماندلیو لنپول,مانديليو لا نابول,マンドリュー＝ラ＝ナプール,芒代利厄拉納普爾,망들리외라나풀', 43.5500000, 6.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53322, 'Mancieulles', 'Mancieulles', 'Mancieulles', 49.2855300, 5.8971000, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53323, 'Mamirolle', 'Mamirolle', 'Mamirol'',Mamirolle,ma mi luo er,Маміроль,马米罗尔', 47.1985700, 6.1592400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53324, 'Mametz', 'Mametz', 'Mametz', 50.6348500, 2.3247800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53325, 'Mamers', 'Mamers', 'Mame,mameru,Маме,マメール', 48.3500000, 0.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53326, 'Malzéville', 'Malzeville', 'Mal''zevil'',Malzeville,Malzéville,ma er ze wei er,Мальзевиль,Мальзевіль,马尔泽维尔', 48.7118100, 6.1817600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53327, 'Malville', 'Malville', 'Kerwall,Malville', 47.3590500, -1.8622700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53328, 'Mallemort', 'Mallemort', 'Mal''mor,Malamort,Malamòrt,Mallemort,ma lai mo er,Мальмор,马莱莫尔', 43.7317200, 5.1794500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53329, 'Mallemoisson', 'Mallemoisson', 'Mal''muasson,Malameisson,Mallemoisson,ma lai mu wa song,Мальмуассон,马莱穆瓦松', 44.0481300, 6.1245900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53330, 'Malissard', 'Malissard', 'Maleissart,Malissar,Malissard,ma li sa er,Маліссар,马利萨尔', 44.9020100, 4.9591500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53331, 'Malintrat', 'Malintrat', 'Malentra,Malintrac,Malintrat,ma lan te la,Малентра,马兰特拉', 45.8144600, 3.1871800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53332, 'Malijai', 'Malijai', 'Malijai,Malizhe,ma li re,Малиже,Маліже,马利热', 44.0460600, 6.0319500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53333, 'Malicorne-sur-Sarthe', 'Malicorne-sur-Sarthe', 'Malicorne,Malicorne-sur-Sarthe,Malicorre,Malikorn-sjur-Sart,Малікорн-сюр-Сарт', 47.8131700, -0.0815200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53334, 'Malguénac', 'Malguenac', 'Malgeneg,Malguenac,Malguénac', 48.0800800, -3.0524800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53335, 'Malestroit', 'Malestroit', 'Malestred,Malestroit', 47.8093400, -2.3845700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53336, 'Malesherbes', 'Malesherbes', 'Malesherbes', 48.2956600, 2.4093500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53337, 'Malemort-sur-Corrèze', 'Malemort-sur-Correze', 'Malemort,Malemort-sur-Correze,Malemort-sur-Corrèze', 45.1700900, 1.5619300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53338, 'Malemort-du-Comtat', 'Malemort-du-Comtat', 'Mal''mor-dju-Konta,Malamort dau Comtat,Malamort de la Comtat,Malamòrt dau Comtat,Malamòrt de la Comtat,Malemort,Malemort-du-Comtat,ma lai mo er di kong ta,Мальмор-дю-Конта,马莱莫尔迪孔塔', 44.0207000, 5.1599100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53339, 'Malay-le-Grand', 'Malay-le-Grand', 'Malay,Malay-le-Grand,Malay-le-Republicain,Malay-le-Républicain', 48.1758900, 3.3418900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53340, 'Malaunay', 'Malaunay', 'Malaunay', 49.5271000, 1.0429200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53341, 'Malaucène', 'Malaucene', 'Malaucena,Malaucene,Malaucène,Malosen,ma luo sai na,Малосен,马洛塞纳', 44.1724000, 5.1329400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53342, 'Malataverne', 'Malataverne', 'Malatavern,Malataverna,Malataverne,Malatavèrna,ma la ta wei er en,Малатаверн,马拉塔韦尔恩', 44.4872700, 4.7520700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53343, 'Malansac', 'Malansac', 'Malansac,Malansak,Malanseg,Malañseg,ma lang sa ke,Малансак,马朗萨克', 47.6772400, -2.2954300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53344, 'Malakoff', 'Malakoff', 'Malakoff', 48.8199900, 2.2999800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53345, 'Maizières-lès-Metz', 'Maizieres-les-Metz', 'Maizieres,Maizieres-les-Metz,Maizières,Maizières-lès-Metz,Mez''er-le-Mec,mai qi ai lai mei te,mzyr-lh-mts,Мезьер-ле-Мец,Мезьєр-ле-Мец,مزیر-له-متس,迈齐埃莱梅特', 49.2075400, 6.1605200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53346, 'Maizières-la-Grande-Paroisse', 'Maizieres-la-Grande-Paroisse', 'Maizieres,Maizieres-la-Grande-Paroisse,Maizières,Maizières-la-Grande-Paroisse,Mez''er-la-Grand-Paruas,Mez''er-la-Grand-Paruass,mai qi ai la-ge lang de pa lu wa si,Мезьер-ла-Гранд-Паруас,Мезьєр-ла-Гранд-Паруасс,迈齐埃拉-格朗德帕鲁瓦斯', 48.5101200, 3.7857300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53347, 'Maisse', 'Maisse', 'Maisse,Mess,mai si,Месс,迈斯', 48.3952500, 2.3790200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53348, 'Maisons-Laffitte', 'Maisons-Laffitte', 'Maisons-Laffitte,Mezon Lafit,Mezon-Laffit,Mezon-Laffitt,Mezon-Lafit,mejonglapiteu,mezon=rafitto,mzwn lfyt,Мезон Лафит,Мезон-Лафит,Мезон-Лаффит,Мезон-Лаффитт,Мезон-Лаффітт,مزون لفیت,メゾン＝ラフィット,메종라피트', 48.9526400, 2.1452100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53349, 'Maisons-Alfort', 'Maisons-Alfort', 'Maisons-Alfort,Mezon Alfor,Mezon-Al''for,Mezonz-Al''for,mai song a er fu,mejong-alpoleu,mezon=aruforu,myzwn alfwr,mzwn alfwr,mzwn-alfwr,Мезон Алфор,Мезон-Альфор,Мезонз-Альфор,مزون الفور,مزون-آلفور,ميزون ألفور,メゾン＝アルフォール,邁松阿爾福,메종알포르', 48.8117100, 2.4394500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53350, 'Maisnil-lès-Ruitz', 'Maisnil-les-Ruitz', 'Maisnil-d''Houdain,Maisnil-d’Houdain,Maisnil-les Ruitz,Maisnil-les-Ruitz,Maisnil-lès Ruitz,Maisnil-lès-Ruitz,Menij-le-Rjuic,mai si ni lei lai lu yi si,maysnsl lyh rwytz,Мений-ле-Рюиц,Меній-ле-Рюїц,مايسنسل ليه رويتز,迈斯尼勒莱吕伊斯', 50.4534200, 2.5899200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53351, 'Maisdon-sur-Sèvre', 'Maisdon-sur-Sevre', 'Maezon-ar-Gwini,Maisdon,Maisdon-sur-Sevre,Maisdon-sur-Sèvre,Medon-sjur-Sevr,mesudon=shuru=sevuru,sai fu er he pan mai si dong,Медон-сюр-Севр,メスドン＝シュル＝セーヴル,塞夫尔河畔迈斯东', 47.0971400, -1.3800000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53352, 'Mainvilliers', 'Mainvilliers', 'Mainvilliers', 48.4500300, 1.4560700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53353, 'Maintenon', 'Maintenon', 'Maintenon,Mentenon,man te nong,Ментенон,曼特农', 48.5870400, 1.5784700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53354, 'Maing', 'Maing', 'Maing,Men,Naing,man cun,Мен,曼村', 50.3079100, 3.4844700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53355, 'Maincy', 'Maincy', 'Maincy', 48.5497700, 2.7001700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53356, 'Mailly-le-Camp', 'Mailly-le-Camp', 'Mailly,Mailly-le-Camp', 48.6652600, 4.2130300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53357, 'Maillot', 'Maillot', 'Maillot', 48.1755700, 3.3078400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53358, 'Maillezais', 'Maillezais', 'Maillezais,Majze,Mal''eze,Malleacum,mai lei ze,Майзе,Мальезе,迈勒泽', 46.3726700, -0.7396300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53359, 'Maillane', 'Maillane', 'Maillane,Maillanne,Majan,Malhana,mai lang,maiyanu,Майан,Маян,マイヤーヌ,迈朗', 43.8311400, 4.7815200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53360, 'Maignelay-Montigny', 'Maignelay-Montigny', 'Men''ele-Montin''i,mai gai lai meng di ni,Меньеле-Монтиньи,Меньєле-Монтіньї,迈盖莱蒙蒂尼', 49.5500000, 2.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53361, 'Maidières', 'Maidieres', 'Maidieres,Maidières,Med''er,mai di ai,Медьер,Медьєр,迈迪埃', 48.9002900, 6.0398800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53362, 'Maîche', 'Maiche', 'Maiche,Maish,Maîche,mai ke,Маїш,迈克', 47.2516000, 6.8030900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53363, 'Magny-Vernois', 'Magny-Vernois', 'Magny-Vernois,Man''i-Vernua,Маньи-Вернуа,Маньї-Вернуа', 47.6699700, 6.4754500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53364, 'Magny-les-Hameaux', 'Magny-les-Hameaux', 'Magneio,Magny,Magny-l''Essart,Magny-les-Hameaux,Malliacum,Man''i-le-Amo,Port-de-la-Montagne,Маньи-ле-Амо,Маньї-ле-Амо', 48.7434500, 2.0615400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53365, 'Magny-le-Hongre', 'Magny-le-Hongre', 'Magny,Magny Le Hongre', 48.8632500, 2.8154600, 'FR', '2016-12-02', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53366, 'Magny-le-Désert', 'Magny-le-Desert', 'Magny,Man''i-le-Dezer,ma ni lai dai sai er,Маньи-ле-Дезер,Маньї-ле-Дезер,马尼莱代塞尔', 48.5701500, -0.3273200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53367, 'Magny-en-Vexin', 'Magny-en-Vexin', 'Magny,Magny-en-Vexin,Man''i-an-Veksen,fu ke sang de qu ma ni,Маньи-ан-Вексен,Маньї-ан-Вексен,弗克桑地区马尼', 49.1551500, 1.7866900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53368, 'Magny-Cours', 'Magny-Cours', 'Magny,Magny-Cours', 46.8833300, 3.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53369, 'Magné', 'Magne', 'Magne,Magné', 46.3154800, -0.5457500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53370, 'Magnanville', 'Magnanville', 'Magnanville,Man''janvil'',Маньянвиль,Маньянвіль', 48.9679800, 1.6784200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53371, 'Magnac-sur-Touvre', 'Magnac-sur-Touvre', 'Magnac,Magnac-sur-Touvre,Man''jak-sjur-Tuvr,tu fu er he pan ma ni ya ke,Маньяк-сюр-Тувр,图夫尔河畔马尼亚克', 45.6666700, 0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53372, 'Magnac-Laval', 'Magnac-Laval', 'Magnac-Laval,Magnac-la-Montagne', 46.2151400, 1.1672400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53373, 'Magland', 'Magland', 'Magland', 46.0197100, 6.6201500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53374, 'Magescq', 'Magescq', 'Magescq', 43.7820500, -1.2165200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53375, 'Magenta', 'Magenta', 'Magenta', 49.0489900, 3.9688200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53376, 'Magalas', 'Magalas', 'Magalas', 43.4709500, 3.2233800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53377, 'Maffliers', 'Maffliers', 'Mafflie,Maffliers,ma fu li ye er,Маффлие,Маффліє,马夫利耶尔', 49.0775800, 2.3076800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53378, 'Maël-Carhaix', 'Mael-Carhaix', 'Maehl''-Kare,Mael''-Kare,Mael-Carhaix,Maël-Carhaix,Mel-Karaez,Mêl-Karaez,ma e ka lai,Маель-Каре,Маэль-Каре,马厄卡赖', 48.2844400, -3.4232200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53379, 'Mâcot-la-Plagne', 'Macot-la-Plagne', 'Mako-la-Plan'',Мако-ла-Плань,میکوٹ-لا-پلاگنی', 45.5500000, 6.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53380, 'Mâcon', 'Macon', 'Grosne-les-Macon,Grosne-lès-Macon,Macon,Makon,Makonas,Matisco,Mâcon,ma gang,ma kng,ma kong,makn,makon,makong,mkn,mykwn,Макон,ماکن,مکن,میکون,มากง,マコン,馬岡,马孔,마콩', 46.3000000, 4.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53381, 'Maclas', 'Maclas', 'Maclas,Makla,myklas,Макла,میکلاس', 45.3652900, 4.6891200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53382, 'Macheren', 'Macheren', 'Macheren', 49.1004500, 6.7737900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53383, 'Machecoul', 'Machecoul', 'Machecoul,Machicolium,Machikoul,Mashkul'',ma xie ku,machykwl,mashukuru,Машкуль,ماچیکول,マシュクール,马谢库', 46.9935800, -1.8235200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53384, 'Maché', 'Mache', 'Mache,Maché', 46.7540500, -1.6869200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53385, 'Macau', 'Macau', 'Macau', 45.0067900, -0.6182100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53386, 'Mably', 'Mably', 'Mably', 46.0862300, 4.0660700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53387, 'Lys-lez-Lannoy', 'Lys-lez-Lannoy', 'Lannoy-du-Nord,Li-le-Lannua,Lis-le-Lannua,Lys,li si lai la nu wa,Ли-ле-Ланнуа,Лис-ле-Ланнуа,Ліс-ле-Ланнуа,利斯莱拉努瓦', 50.6666700, 3.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53388, 'Lyon', 'Lyon', 'Gorad Lijon,LYS,Leon do Roine,León do Roine,Lio,Lion,Liona,Lionas,Lione,Lioni,Liono,Liun,Liyon,Lió,Lión,Lugdunum,Lyon,Lyons,li ang,li yng,li''om,li''ona,lion,liong,lioni,liyon,lyom,lywn,riyon,Λυών,Горад Ліён,Лион,Ліон,Լիոն,ליאן,ליון,ليون,لیون,لیۆن,ल्यों,ਲਿਓਂ,ଲିଓନ,லியோன்,ลียง,ལི་ཡོང་།,လီယွန်းမြို့,ლიონი,ልዮን,リヨン,里昂,리옹', 45.7484600, 4.8467100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53389, 'Lyaud', 'Lyaud', 'Le Lyaud,Lio,Lyaud,Ліо', 46.3366200, 6.5286800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53390, 'Luzy', 'Luzy', 'Ljuzi,Lusiacum,Luzy,lu qi,Люзи,Люзі,吕齐', 46.7901100, 3.9703600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53391, 'Luz-Saint-Sauveur', 'Luz-Saint-Sauveur', 'Lju-Sen-Sover,Ljus-Sen-Sovjor,Lus e Sent Sauvaire,Luz,Luz-Saint-Sauveur,lu sheng suo fu,Лю-Сен-Совер,Люс-Сен-Совёр,吕圣索弗', 42.8719100, -0.0032300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53392, 'Luzinay', 'Luzinay', 'Luzinay', 45.5889500, 4.9582900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53393, 'Luzech', 'Luzech', 'Ljuzesh,Luseg,Lusèg,Luzech,lu ze ke,Люзеш,吕泽克', 44.4781800, 1.2870400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53394, 'Luzarches', 'Luzarches', 'Ljuzarsh,Luzarches,lu zha er she,lwzarsh,Люзарш,لوزارش,吕扎尔舍', 49.1131900, 2.4223000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53395, 'Luynes', 'Luynes', 'Luynes,Roche-sur-Loire', 47.3844100, 0.5547000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53396, 'Luxeuil-les-Bains', 'Luxeuil-les-Bains', 'Ljuksej-le-Ben,Ljuksjoj-le-Ben,Luxeuil,Luxeuil-les-Bains,Luxovium,ke se yi lai ban,Люксей-ле-Бен,Люксёй-ле-Бен,克瑟伊萊班', 47.8171000, 6.3650000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53397, 'Lutzelhouse', 'Lutzelhouse', 'Litzelhuese,Ljuceluz,Luetzelhausen,Lutzelhouse,Lítzelhüse,Lützelhausen,lu te ze you si,lwtslhaws,lwtzylhwas,Люцелуз,لوتزيلهواس,لوتسلهاوس,吕特泽尤斯', 48.5196300, 7.2860900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53398, 'Lutterbach', 'Lutterbach', 'Ljutterbak,Luetterbach,Lutterbach,Lütterbach,lu tai er ba ke,Люттербак,吕泰尔巴克', 47.7583500, 7.2769500, 'FR', '2016-02-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53399, 'Lussac-les-Châteaux', 'Lussac-les-Chateaux', 'Ljussak-le-Shato,Lussac,Lussac-les-Chateaux,Lussac-les-Châteaux,Lussac-sur-Vienne,lu sa lei sha tuo,Люссак-ле-Шато,吕萨勒沙托', 46.4032700, 0.7252400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53400, 'Lussac', 'Lussac', 'Lussac', 44.9500000, -0.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53401, 'Lusigny-sur-Barse', 'Lusigny-sur-Barse', 'Lusigny,Lusigny-sur-Barse', 48.2545100, 4.2689100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53402, 'Lusigny', 'Lusigny', 'Dorvalet,Lusigny', 46.5884900, 3.4900300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53403, 'Lusignan', 'Lusignan', 'Lusignan', 46.4359800, 0.1262000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53404, 'Lusanger', 'Lusanger', 'Ljuzanzhe,Lusanger,Luzevieg,lu sang re,Люзанже,吕桑热', 47.6815300, -1.5885700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53405, 'Lure', 'Lure', '', 47.6833300, 6.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53406, 'Lurcy-Lévis', 'Lurcy-Levis', 'Ljursi-Levi,Lurcy-Levis,Lurcy-Levy,Lurcy-Lévis,Lurcy-Lévy,Lurey-Levy,Lurey-Lévy,lu er xi lai wei,Люрси-Леви,Люрсі-Леві,吕尔西莱维', 46.7305600, 2.9387600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53407, 'Luray', 'Luray', 'Le Luat-Clairet,Luray', 48.7203500, 1.3988900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53408, 'L''Union', 'L''Union', 'L''Union', 43.6604200, 1.4826400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53409, 'Lunéville', 'Luneville', 'Linevil,Ljunevil'',Lunae Villa,Luneville,Lunéville,lu nei wei er,lunevili,lwinebil,ryunevu~iru,Линевил,Люневиль,Люневіль,ლუნევილი,リュネヴィル,吕内维尔,뤼네빌', 48.6000000, 6.5000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53410, 'Lunery', 'Lunery', 'Ljuneri,Ljunri,Lunery,lu na li,Люнері,Люнри,吕纳里', 46.9356900, 2.2689500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53411, 'Luneray', 'Luneray', 'Luneray', 49.8279500, 0.9158100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53412, 'Lunel-Viel', 'Lunel-Viel', 'Ljunel''-V''el'',Ljunel''-Vel'',Lo Vielh Lunel,Lo Vièlh Lunèl,Lunel Vielh,Lunel-Viel,Lunèl Vièlh,lu nei wei ye,Люнель-Вьель,Люнель-Вєль,吕内维耶', 43.6789000, 4.0925000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53413, 'Lunel', 'Lunel', 'Linel,Ljunel'',Lunel,Lunèl,lwinel,lwnl,lwnyl,ryuneru,Линел,Люнель,לוניל,لونل,リュネル,뤼넬', 43.6777800, 4.1361100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53414, 'Lunay', 'Lunay', 'Lunay', 47.8086400, 0.9149900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53415, 'Lumio', 'Lumio', 'Lumio,Lumiu,Lumjo,Лумио,Лумйо', 42.5759000, 8.8355000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53416, 'Lumigny-Nesles-Ormeaux', 'Lumigny-Nesles-Ormeaux', 'Ljumin''i-Nel''-Ormo,Люминьи-Нель-Ормо,Люміньї-Нель-Ормо', 48.7333300, 2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53417, 'Lumes', 'Lumes', 'Lumes', 49.7346100, 4.7861600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53418, 'Lumbres', 'Lumbres', 'Lembr,Linme,Ljombr,Lumbres,lan bu er,lwmbyrs,Лембр,Лёмбр,لومبيرس,兰布尔', 50.7069300, 2.1208100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53419, 'Lumbin', 'Lumbin', 'Lumbin', 45.3056800, 5.9113600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53420, 'Luitré', 'Luitre', 'Loezherieg,Luitre,Luitré', 48.2824700, -1.1186600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53421, 'Luisant', 'Luisant', 'Luisant', 48.4295000, 1.4738300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53422, 'Lugrin', 'Lugrin', 'Ljugren,Lugrin,Lugrinum,Люгрен', 46.4032900, 6.6674400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53423, 'Ludres', 'Ludres', 'Ljudr,Ludres,lu de lei,Людр,吕德雷', 48.6218100, 6.1618300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53424, 'Ludon-Médoc', 'Ludon-Medoc', 'Ljudon-Medok,Ludon,Ludon de Medoc,Ludon de Medòc,Ludon-Medoc,Ludon-Médoc,lu dong mei duo ke,Людон-Медок,吕东梅多克', 44.9811800, -0.6025400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53425, 'Luc-sur-Mer', 'Luc-sur-Mer', 'Ljuk-sjur-Mer,Luc,Luc-sur-Mer,bin hai lu ke,Люк-сюр-Мер,滨海吕克', 49.3145200, -0.3549900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53426, 'Lucq-de-Béarn', 'Lucq-de-Bearn', 'Ljuk-de-Bearn,Luc,Lucq,Lucq-de-Bearn,Lucq-de-Béarn,lu de bei a er en,Люк-де-Беарн,吕德贝阿尔恩', 43.3000000, -0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53427, 'Luçon', 'Lucon', 'Lucon,Luçon', 46.4577300, -1.1651200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53428, 'Lucinges', 'Lucinges', 'Lucinges', 46.1913600, 6.3173100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53429, 'Luché-Pringé', 'Luche-Pringe', 'Ljushe-Prenzhe,Luche,Luché,Люше-Пренже', 47.7032600, 0.0754900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53430, 'Lucéram', 'Luceram', 'Ljuseram,Luceram,Lucerames,Lucéram,lu sai lang,lwsyram,Люсерам,لوسيرام,吕塞朗', 43.8831200, 7.3599600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53431, 'Lucenay-lès-Aix', 'Lucenay-les-Aix', 'Bourg-la-Reunion,Bourg-la-Réunion,Ljusne-lez-Eks,Lucenay,Lucenay-les-Aix,Lucenay-lès-Aix,Luciniacum,lu se nai lai ai,Люсне-лез-Екс,吕瑟奈莱艾', 46.7027400, 3.4830800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53432, 'Lucenay', 'Lucenay', 'Lucenay', 45.9126300, 4.7027600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53433, 'Luceau', 'Luceau', 'Luceau', 47.7116700, 0.3973400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53434, 'Lucé', 'Luce', 'Luce,Lucé', 48.4368900, 1.4635900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53435, 'Lucciana', 'Lucciana', 'Lucciana,Luchchana,Luciana,Луччана', 42.5458900, 9.4185900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53436, 'Luçay-le-Mâle', 'Lucay-le-Male', 'Ljuse-le-Mal'',Lucay,Lucay-le-Male,Luçay,Luçay-le-Mâle,lu sai lai ma er,Люсе-ле-Маль,吕赛莱马尔', 47.1299600, 1.4417300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53437, 'Luc-la-Primaube', 'Luc-la-Primaube', '', 44.3143900, 2.5355200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53438, 'Lubersac', 'Lubersac', 'Libercac,Liberçac,Ljubersak,Lubercac,Lubersac,Luberçac,Luperciacum,lu bei er sa ke,Люберсак,吕贝尔萨克', 45.4439400, 1.4041800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53439, 'Luant', 'Luant', 'Ljuan,Luant,lu ang,Люан,吕昂', 46.7330000, 1.5579300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53440, 'Lozinghem', 'Lozinghem', 'Lozinghem', 50.5155400, 2.5020900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53441, 'Lozanne', 'Lozanne', 'Lozane,Lozanne', 45.8559100, 4.6859400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53442, 'Loyettes', 'Loyettes', 'Loyettes,Luaett,Luajet,Luayet,luo ye te,lwyyt,Луайет,Луаєтт,Լուայետ,لوييت,洛耶特', 45.7762000, 5.2074300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53443, 'Loyat', 'Loyat', 'Loiad,Louad,Loyat,Luaja,lu wa a,Луая,卢瓦阿', 47.9893300, -2.3834400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53444, 'Lovagny', 'Lovagny', 'Lovagny', 45.9042000, 6.0338700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53445, 'Louzy', 'Louzy', 'Louzy', 47.0120100, -0.1853700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53446, 'Louvroil', 'Louvroil', '', 50.2642700, 3.9627200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53447, 'Louvres', 'Louvres', 'Louvres,Luvr,lu fu er,Лувр,卢夫尔', 49.0446000, 2.5047900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53448, 'Louvigny', 'Louvigny', 'Louvigny', 49.1571500, -0.3937600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53449, 'Louvigné-du-Désert', 'Louvigne-du-Desert', 'Louvigne,Louvigne-du-Desert,Louvigneg-an-Dezerzh,Louvigné,Louvigné-du-Désert,Lupiniacum in Fulgeriensi,Luvin''e-dju-Dezer,lu wei nie di dai sai er,Лувинье-дю-Дезер,Лувіньє-дю-Дезер,卢维涅迪代塞尔', 48.4804700, -1.1253700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53450, 'Louvigné-de-Bais', 'Louvigne-de-Bais', 'Louvigne,Louvigne-de-Bais,Louvigneg-Baez,Louvigné,Louvigné-de-Bais,Lupiniacum prope Baiscum,Luvin''e-de-Be,lu wei nie de bai,Лувинье-де-Бе,Лувіньє-де-Бе,卢维涅德拜', 48.0489800, -1.3309100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53451, 'Louviers', 'Louviers', 'Louviers,Luv''e,Luve,lu wei ai,Лувье,Лувє,卢维埃', 49.2166700, 1.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53452, 'Louvie-Juzon', 'Louvie-Juzon', 'Lobier Jussan,Lobier de Baish,Lobièr de Baish,Louvie,Luvi-Zhjuzon,Luvi-Zhuzon,lu wei ye rui zong,Луви-Жузон,Луви-Жюзон,Луві-Жузон,卢维耶瑞宗', 43.0864600, -0.4192800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53453, 'Louverné', 'Louverne', 'Louverne,Louverné,Luverne,lu wei er nei,Луверне,卢韦尔内', 48.1217800, -0.7172100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53454, 'Louveciennes', 'Louveciennes', 'Louveciennes,Luves''en,Luves''enn,ruvushien''nu,Лувесьен,Лувесьенн,Лувесьєнн,ルーヴシエンヌ', 48.8611500, 2.1146300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53455, 'Loury', 'Loury', 'Loury,Luri,lu li,Лурі,卢里', 47.9994400, 2.0847400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53456, 'Lourmarin', 'Lourmarin', 'Lormarin,Lourmarin,Lurmaren,lu er ma lan,rurumaran,Лурмарен,ルールマラン,卢尔马兰', 43.7659900, 5.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53457, 'Lourdes', 'Lourdes', 'Gorad Lurd,La Montagne,Loerdes,Lorda,Lourd,Lourdes,Lurd,Lurda,Lurdas,Lurdy,lo''urdesa,lu er de,luleudeu,lwrd,lwrds,rurudo,Горад Лурд,Лурд,لورد,لوردس,লোউর্ডেস,ルルド,盧爾德,루르드', 43.1000000, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53458, 'Lourches', 'Lourches', 'Lourches', 50.3135400, 3.3525800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53459, 'Louplande', 'Louplande', 'Louplande', 47.9500000, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53460, 'Loupian', 'Loupian', 'Lopian,Loupian,Lup''jan,Lupjan,lu pi ang,Лупьян,Лупян,卢皮昂', 43.4488600, 3.6138100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53461, 'Loupiac', 'Loupiac', 'Loupiac-de-Cadillac', 44.6166700, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53462, 'Louhans', 'Louhans', 'Beaulieu,Louhans,Luan,lu ang,ruan,Луан,ルーアン,盧昂', 46.6333300, 5.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53463, 'Loué', 'Loue', 'Loue,Loué,Lue,Луе', 47.9957500, -0.1545000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53464, 'Loudun', 'Loudun', 'Laudun,Lodunum,Loudun,Luden,Ludjon,lu dan,Луден,Лудён,卢丹', 47.0078800, 0.0829600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53465, 'Loudéac', 'Loudeac', 'Lodeacum,Loudeac,Loudieg,Loudéac,Ludeak,lu dai a ke,rudeakku,Лудеак,ルデアック,卢代阿克', 48.1782600, -2.7543300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53466, 'Loubert', 'Loubert', '', 45.9142200, 0.5861700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53467, 'Louargat', 'Louargat', 'Louargat,Louergad,Luarga,Luargat,lu a er jia,Луарга,Луаргат,卢阿尔加', 48.5657600, -3.3375000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53468, 'Louannec', 'Louannec', 'Louaneg,Louannec', 48.7942300, -3.4120000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53469, 'Losne', 'Losne', 'Losne', 47.0985000, 5.2621600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53470, 'Lorris', 'Lorris', 'Lorri,Lorriacum,Lorris,luo er li,lwry,rorisu,Лоррі,لوری,ロリス,洛尔里', 47.8895000, 2.5147800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53471, 'Lorrez-le-Bocage-Préaux', 'Lorrez-le-Bocage-Preaux', 'Lorrez,Lorrez-le-Bokazh-Preo,Лоррез-ле-Бокаж-Прео', 48.2333300, 2.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53472, 'Lorquin', 'Lorquin', 'Lorquin', 48.6697200, 6.9957900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53473, 'Lormont', 'Lormont', 'Larmont,Lormon,Lormont,luo er meng,lwrmwn,rorumon,Лормон,لورمون,ロルモン,洛尔蒙', 44.8749500, -0.5178200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53474, 'Lormes', 'Lormes', 'Lorm,Lorma,Lormes,luo er mei,Лорм,洛尔梅', 47.2896400, 3.8171400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53475, 'Lormaison', 'Lormaison', 'Lormaison,Lormezon,luo er mai song,Лормезон,洛尔迈松', 49.2564700, 2.1057500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53476, 'Loriol-sur-Drôme', 'Loriol-sur-Drome', 'LAuriou de Droma,LAuriou de Liuron,LAuriòu de Droma,LAuriòu de Liuron,Loriol,Loriol-sur-Drome,Loriol-sur-Drôme,Lorjol''-sjur-Drom,de luo ne he pan luo li ao,Лорйоль-сюр-Дром,德罗讷河畔洛里奥', 44.7521400, 4.8254700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53477, 'Loriol-du-Comtat', 'Loriol-du-Comtat', 'LAuriou dau Comtat,LAuriou de la Comtat,LAuriòu dau Comtat,LAuriòu de la Comtat,Loriol,Loriol''-dju-Konta,Loriol-du-Comtat,Lorjol''-dju-Konta,luo li ao di kong ta,Лориоль-дю-Конта,Лорйоль-дю-Конта,洛里奥迪孔塔', 44.0762600, 4.9992200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53478, 'Lorient', 'Lorient', 'An Oriant,Gorad Larjan,LRT,Lor''jan,Lorian,Lorient,Lorjan,Lorjanas,Lorjen,Oriens,loliang,luo li ang,lwryan,rorian,Λοριάν,Горад Ларян,Лориан,Лорьян,Лорян,Лорјен,لوریان,ロリアン,洛里昂,로리앙', 47.7500000, -3.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53479, 'Lorgues', 'Lorgues', 'Lorg,Lorgas,Lorgues,Lòrgas,luo er ge,Лорг,洛尔格', 43.4936100, 6.3611000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53480, 'Lorgies', 'Lorgies', 'Lorgies', 50.5688000, 2.7903400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53481, 'Lorette', 'Lorette', 'Assailly,Lorette', 45.5061800, 4.5752200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53482, 'Loperhet', 'Loperhet', 'Locus Brigidae,Loperc''hed,Loperched,Lopere,Loperhet,luo po lei,Лопере,洛珀雷', 48.3772500, -4.3060800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53483, 'Lopérec', 'Loperec', 'Locus Petroci,Loperec,Lopereg,Loperek,Lopérec,luo pei lei ke,Лоперек,洛佩雷克', 48.2773400, -4.0475600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53484, 'Loos-en-Gohelle', 'Loos-en-Gohelle', 'Loo-in-Gohelle,Loos,Loos-an-Goel'',Loos-en-Gohelle,Los-an-Goehl'',luo sang ge ai lei,lws an jwhyl,Лоос-ан-Гоель,Лос-ан-Гоэль,لوس إن جوهيل,洛桑戈埃勒', 50.4578600, 2.7921500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53485, 'Loos', 'Loos', 'Loos', 50.6098200, 3.0187400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53486, 'Loon-Plage', 'Loon-Plage', 'Lon-Plazh,Loon,Loon-Plage,Loon-Plazh,luo weng pu la ri,Лон-Плаж,Лоон-Плаж,洛翁普拉日', 50.9964700, 2.2177000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53487, 'Looberghe', 'Looberghe', 'Looberghe', 50.9169400, 2.2743900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53488, 'Lons-le-Saunier', 'Lons-le-Saunier', 'Franciade,Ledo Salinarius,Lon-le-Son''e,Lons le Sonije,Lons-le-Saunier,Lons-le-Son''e,XLL,long lei suo nie,longleusonie,ron=ru=sonie,Лон-ле-Сонье,Лонс ле Соније,Лонс-ле-Соньє,ロン＝ル＝ソーニエ,隆勒索涅,롱르소니에', 46.6666700, 5.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53489, 'Lons', 'Lons', 'Lons,Loos,long zhen,Лонс,隆镇', 43.3166700, -0.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53490, 'Longwy', 'Longwy', 'Longovicum,Longvi,Longwy,Lonkech,long ge wei,long-wi,ron''u~i,Лонгви,Лонгві,ロンウィ,隆格维,롱위', 49.5193600, 5.7688200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53491, 'Longvic', 'Longvic', 'Longvic,Lonvi,Lonvik,lnwyk,long ge wei ke,Лонви,Лонвик,Лонві,لنویک,隆格维克', 47.2875400, 5.0634100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53492, 'Longuyon', 'Longuyon', 'Longjuion,Longjujon,Longuyon,long ji weng,Лонгюион,Лонгюйон,Лонгюїон,隆吉翁', 49.4454800, 5.6014500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53493, 'Longueville', 'Longueville', 'Longueville', 48.5150300, 3.2467700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53494, 'Longuenesse', 'Longuenesse', 'Longness,Longuenesse,long ge nei si,lwnjwynys,Лонгнесс,لونجوينيس,隆格内斯', 50.7339500, 2.2352000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53495, 'Longueil-Sainte-Marie', 'Longueil-Sainte-Marie', 'Longeij-Sent-Mari,Longueil-Sainte-Marie,Longueil-la-Montagne,long gai sheng ma li,Лонгеїй-Сент-Марі,隆盖圣玛丽', 49.3572300, 2.7184400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53496, 'Longueil-Annel', 'Longueil-Annel', 'Longeij-Annel'',Longueil-Annel,Longueil-sur-Oise,long gai a nei,Лонгеїй-Аннель,隆盖阿内', 49.4690800, 2.8646400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53497, 'Longueau', 'Longueau', 'Londjeu,Longo,Longueau,long ge,Лонго,隆戈', 49.8722600, 2.3588000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53498, 'Longpré-les-Corps-Saints', 'Longpre-les-Corps-Saints', 'Longpre,Longpre-ches-Corps-Saints,Longpre-les-Corps-Saints,Longprè-chés-Corps-Saints,Longpré,Longpré-les-Corps-Saints,Lonpre-le-Kor-Sen,long pu lei lai ke er sang,rongupure=re=koru=san,Лонпре-ле-Кор-Сен,ロングプレ＝レ＝コール＝サン,隆普雷莱科尔桑', 50.0123900, 1.9928700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53499, 'Longpont-sur-Orge', 'Longpont-sur-Orge', 'Longpont,Longpont sur Orge,Longpont-sur-Orge,Lonpon-sjur-Orzh,ao er ri he pan long ge peng,Лонпон-сюр-Орж,奥尔日河畔隆格蓬', 48.6417100, 2.2927800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53500, 'Longperrier', 'Longperrier', 'Longperrier,Lonperr''e,Lonperre,Лонперрє,Лонперр’е', 49.0484400, 2.6657100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53501, 'Longny-au-Perche', 'Longny-au-Perche', 'Longny,Longny-au-Perche,Longny-du-Perche,Lonni-o-Persh,long ni ao pei er ke,Лонни-о-Перш,Лонні-о-Перш,隆尼奥佩尔克', 48.5298400, 0.7523900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53502, 'Longnes', 'Longnes', 'Longnes', 48.9200200, 1.5870500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53503, 'Longlaville', 'Longlaville', 'Longlaville', 49.5345500, 5.8020300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53504, 'Longjumeau', 'Longjumeau', 'Longjumeau,Lonzhimo,Lonzhjumo,Lonzhumo,long ge rui mo,longjwimo,lwngzhwmw,lwnzhwmw,ronjumo,Лонжимо,Лонжумо,Лонжюмо,لونژومو,لونگژومو,ロンジュモー,隆格瑞莫,롱쥐모', 48.6950300, 2.3073500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53505, 'Longfossé', 'Longfosse', 'Longfosse,Longfossé', 50.6521700, 1.8069300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53506, 'Longeville-lès-Saint-Avold', 'Longeville-les-Saint-Avold', 'Longeville,Longeville-les-Saint-Avold,Longeville-lès-Saint-Avold,Lonzhevil''-le-Sent-Avol''d,Lonzhvil''-le-Sent-Avol''d,Lubeln,long re wei er lai sheng a wo er,lwngwyl-lh-sn-awl,Лонжвиль-ле-Сент-Авольд,Лонжвіль-ле-Сент-Авольд,Лонжевиль-ле-Сент-Авольд,لونگویل-له-سن-آول,隆热维尔莱圣阿沃尔', 49.1181100, 6.6416500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53507, 'Longeville-lès-Metz', 'Longeville-les-Metz', 'Longeville,Longeville-les-Metz,Longeville-lès-Metz,Lonzhvil''-le-Mec,long re wei er lai mei te,Лонжвиль-ле-Мец,Лонжвіль-ле-Мец,隆热维尔莱梅特', 49.1127700, 6.1353000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53508, 'Longeville-en-Barrois', 'Longeville-en-Barrois', 'Longeville,Longeville-en-Barrois', 48.7424200, 5.2090500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53509, 'Longeville-sur-Mer', 'Longeville-sur-Mer', 'Lonzhvil''-sjur-Mer,bin hai long re wei lei,Лонжвіль-сюр-Мер,滨海隆热维勒', 46.4166700, -1.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53510, 'Longecourt-en-Plaine', 'Longecourt-en-Plaine', 'Longecourt,Longecourt-en-Maine,Longecourt-en-Plaine,Lonzhkur-an-Plen,Lonzhkurt-an-Plen,pu lan de qu long re ku er,Лонжкур-ан-Плен,Лонжкурт-ан-Плен,普兰地区隆热库尔', 47.1978300, 5.1495600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53511, 'Longchaumois', 'Longchaumois', 'Longchaumois', 46.4622800, 5.9305200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53512, 'Longchamp', 'Longchamp', 'Longchamp', 47.2597300, 5.2869400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53513, 'Longages', 'Longages', 'Longages', 43.3539800, 1.2390500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53514, 'Londinières', 'Londinieres', 'Londin''er,Londinieres,Londinières,Лондиньер,Лондіньєр', 49.8318700, 1.4023200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53515, 'Lompret', 'Lompret', 'Lompret', 50.6693100, 2.9896800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53516, 'Lomme', 'Lomme', 'Lomm,Lomme,Ломм', 50.6435800, 2.9871500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53517, 'Lombron', 'Lombron', 'Lombron', 48.0787900, 0.4186900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53518, 'Lombez', 'Lombez', 'Lombarium,Lombers,Lombes,Lombez,Lombèrs,long bei,ronbezu,Ломбез,Ломбес,ロンベズ,隆贝', 43.4750100, 0.9111900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53519, 'Loivre', 'Loivre', 'Loivre,Luavr,lu wa fu er,Луавр,卢瓦夫尔', 49.3461900, 3.9797800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53520, 'Loison-sous-Lens', 'Loison-sous-Lens', 'Loison,Loison-sous-Lens', 50.4379600, 2.8532200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53521, 'Loisin', 'Loisin', '', 46.2922700, 6.3101000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53522, 'Loiron', 'Loiron', 'Loiron', 48.0666700, -0.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53523, 'Loire-sur-Rhône', 'Loire-sur-Rhone', '', 45.5500000, 4.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53524, 'Logonna-Daoulas', 'Logonna-Daoulas', 'Logonna,Logonna-Daoulas,Logonna-Daoulaz,Logonna-Daula,luo ge na duo la,rogona=daura,Логонна-Даула,ロゴナ＝ダウラ,洛戈纳多拉', 48.3230800, -4.2967500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53525, 'Lognes', 'Lognes', 'Lognes,Lon'',XLG,Лонь', 48.8354100, 2.6299800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53526, 'Lodève', 'Lodeve', 'Lodev,Lodeva,Lodeve,Lodève,Luteva,luo dai fu,rodevu,Лодев,ロデーヴ,洛代夫', 43.7166700, 3.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53527, 'Loctudy', 'Loctudy', 'Loctudy,Locus Tudini,Loktjudi,Loktudi,luo ke di di,lwktwdy,rokute~yudi,Локтюди,Локтюді,لوكتودي,ロクテュディ,洛克蒂迪', 47.8333300, -4.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53528, 'Locquirec', 'Locquirec', 'Locquirec,Locus Kireci,Lokireg,Lokirek,luo qu yi lei ke,rokirekku,Локирек,Локірек,ロキレック,洛屈伊雷克', 48.6924300, -3.6455400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53529, 'Locquémeau', 'Locquemeau', 'Locquemeau,Locquémeau', 48.7247400, -3.5627500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53530, 'Locon', 'Locon', 'Locon,Lokon,luo kong,lwkwn,Локон,لوكون,洛孔', 50.5702900, 2.6662900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53531, 'Locoal-Mendon', 'Locoal-Mendon', 'Locoal-Mendon,Locus Guduali,Lokoal''-Mandon,Lokoal-Mendon,luo ke a mang dong,Локоаль-Мандон,洛科阿芒东', 47.7052000, -3.1079600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53532, 'Locmiquélic', 'Locmiquelic', 'Locmiquelic,Locmiquélic,Lokmikaelig,Lokmikelik,luo ke mi qu ai li ke,Локмикелик,Локмікелік,洛克米屈埃利克', 47.7249900, -3.3415300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53533, 'Locminé', 'Locmine', 'Locmine,Locminé,Logunec''h,Logunech,Lokmine,luo ke mi nei,Локмине,Локміне,洛克米内', 47.8861900, -2.8353600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53534, 'Locmariaquer', 'Locmariaquer', 'Locmariaquer,Locmariaquerin menhir,Locmariaquermegalittene,Lokmaria-Kaer,Lokmariake,luo ke ma li a qu ai,rokumariakeru,Локмариаке,Локмаріаке,ロクマリアケール,洛克马里阿屈埃', 47.5691500, -2.9446800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53535, 'Loches', 'Loches', 'Castello di Loches,Chateau de Loches,Château de Loches,Loches,Losh,Schloss Loches,Shato d''o Losh,luo shen,roshu,Лош,Шато дьо Лош,ロシュ,洛什', 47.1333300, 1.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53536, 'Llupia', 'Llupia', 'Llupia', 42.6207400, 2.7692400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53537, 'Lizy-sur-Ourcq', 'Lizy-sur-Ourcq', 'Lizy,Lizy-sur-Ourcq', 49.0245400, 3.0217800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53538, 'Livry-sur-Seine', 'Livry-sur-Seine', 'Livry,Livry-sur-Seine', 48.5177100, 2.6787900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53539, 'Livry-Gargan', 'Livry-Gargan', 'Livri Gargan,Livri-Gargan,Livry,Livry-Gargan,Livry-en-Aulnoye,Livry-en-Launois,li fu li-jia er gang,libeuligaleugang,lywry-grgan,rivuri=garugan,Ливри Гарган,Ливри-Гарган,Ліврі-Гарган,لیوری-گرگان,リヴリー＝ガルガン,利夫里-加尔冈,리브리가르강', 48.9193000, 2.5430500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53540, 'Livron-sur-Drôme', 'Livron-sur-Drome', 'Liuron,Liuron de Droma,Livron,Livron-sjur-Drom,Livron-sur-Drome,Livron-sur-Drôme,de luo ne he pan li fu long,Ліврон-сюр-Дром,德罗讷河畔利夫龙', 44.7731000, 4.8470500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53541, 'Livré-sur-Changeon', 'Livre-sur-Changeon', 'Liverieg-Kenton,Livre,Livre-sjur-Shanzhon,Livre-sur-Changeon,Livre-sur-Chaugeon,Livreium,Livré,Livré-sur-Changeon,shang rong he pan li fu lei,Ливре-сюр-Шанжон,Лівре-сюр-Шанжон,尚容河畔利夫雷', 48.2193700, -1.3443800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53542, 'Livinhac-le-Haut', 'Livinhac-le-Haut', 'Livinhac,Livinhac-le-Haut', 44.5921200, 2.2311700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53543, 'Livet-et-Gavet', 'Livet-et-Gavet', 'Live-e-Gave,Live-eh-Gave,Livet,Livet-et-Gavet,li wei he jia wei,Ливе-э-Гаве,Ліве-е-Гаве,利韦和加韦', 45.1078200, 5.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53544, 'Liverdy-en-Brie', 'Liverdy-en-Brie', 'Liverdy,Liverdy-en-Brie', 48.6998700, 2.7760600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53545, 'Liverdun', 'Liverdun', 'Liverden,Liverdjon,Liverdun,li wei er dan,Ливерден,Ливердён,Ліверден,利韦尔丹', 48.7508400, 6.0642400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53546, 'Livarot', 'Livarot', 'Livaro,li wa luo,Ливаро,Ліваро,利瓦罗', 49.0050000, 0.1502000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53547, 'Lit-et-Mixe', 'Lit-et-Mixe', 'Li-e-Miks,Li-eh-Miks,Lit,Lit e Micse,Lit-et-Mixe,li he mi ke si,Ли-е-Микс,Ли-э-Микс,Лі-е-Мікс,利和米克斯', 44.0330800, -1.2533000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53548, 'Listrac-Médoc', 'Listrac-Medoc', 'Listrac,Listrac-Medoc,Listrac-Médoc', 45.0741000, -0.7913200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53549, 'Lissieu', 'Lissieu', 'Lissieu', 45.8642600, 4.7470300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53550, 'Lisses', 'Lisses', 'Liss,Lisses,li sai,Лисс,Лісс,利塞', 48.6022200, 2.4224500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53551, 'Lisle-sur-Tarn', 'Lisle-sur-Tarn', 'Lisle-du-Tarn,Lisle-sur-Tarn', 43.8524900, 1.8109900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53552, 'L’Isle-sur-la-Sorgue', 'L''Isle-sur-la-Sorgue', 'Isle sur Sorgue,L''Il''-sjur-la-Sorg,L''Illa de Sorga,L''Illa de Sòrga,L''Isle,L''Isle-sur-la-Sorgue,L’Isle,L’Isle-sur-la-Sorgue,la-suo er ju e he pan li si lei,Л''Іль-сюр-ла-Сорг,Л''Иль-сюр-ла-Сорг,拉-索尔居厄河畔利斯勒', 43.9191500, 5.0509200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53553, 'L’Isle-d’Abeau', 'L''Isle-d''Abeau', 'Ile d''Abeau,Ile d’Abeau,Isle-d''Abeau,Isle-d’Abeau,L''Isle-d''Abeau,L’Isle-d’Abeau', 45.6181300, 5.2354600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53554, 'L’Isle-Adam', 'L''Isle-Adam', 'L''Isle-Adam,L’Isle-Adam', 49.1074400, 2.2281800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53555, 'Lisieux', 'Lisieux', 'Lexovium,Lisieux,Liz''e,Liz''jo,Lizje,Lizjē,XLX,li xue,lijioe,lyzyw,riju,Лизье,Лизьё,Лизје,Лізьє,ليزيو,لیزیو,ሊዜ,リジュー,利雪,리지외', 49.1466000, 0.2292500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53556, 'Liré', 'Lire', 'Lire,Liré,li lei,Ліре,利雷', 47.3432200, -1.1653600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53557, 'Lipsheim', 'Lipsheim', '', 48.4916400, 7.6675100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53558, 'Lion-sur-Mer', 'Lion-sur-Mer', 'L''on-sjur-Mer,Lion,Lion-sjur-Mer,Lion-sur-Mer,bin hai li weng,Лион-сюр-Мер,Льон-сюр-Мер,Ліон-сюр-Мер,滨海利翁', 49.3001800, -0.3215700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53559, 'Linxe', 'Linxe', 'Linxe', 43.9198400, -1.2461900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53560, 'Linselles', 'Linselles', 'Lensel'',Linsele,Linselles,lan ze lei,Ленсель,兰泽勒', 50.7370800, 3.0787800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53561, 'Linguizzetta', 'Linguizzetta', 'Linguizetta,Linguizzetta', 42.2602400, 9.4733300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53562, 'Lingolsheim', 'Lingolsheim', 'Lengol''sajm,Lingelse,Lingolsheim,Língelse,lan ge er sang,lynghwlshym,lynglshaym,rangorusaimu,Ленгольсайм,لينغولشيم,لینگلسهایم,ランゴルサイム,兰戈尔桑', 48.5575200, 7.6825300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53563, 'Linas', 'Linas', 'Linas', 48.6304100, 2.2626600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53564, 'Linars', 'Linars', 'Linars', 45.6500000, 0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53565, 'Linards', 'Linards', 'Linards', 45.7008300, 1.5325900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53566, 'Limoux', 'Limoux', 'Limos,Limoux,Limu,Limós,li mu,rimu,Лиму,Ліму,リムー,利穆', 43.0548700, 2.2217300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53567, 'Limours', 'Limours', 'Limours,Limours-en-Hurepoix,Limur,li mu er,Лимур,Лімур,利穆尔', 48.6462500, 2.0768800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53568, 'Limonest', 'Limonest', 'Limone,Limonest,Лимоне,Лімоне', 45.8374400, 4.7718000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53569, 'Limoges', 'Limoges', 'Augustoritum,Gorad Limozh,LIG,Lemojez,Lemotges,Lemòtges,Limages,Limoges,Limogo,Limog·es,Limotges,Limoz,Limoza,Limozas,Limozh,Limoĝo,Limoža,Limožas,Limòtges,Llemotges,li meng,li mo ri,limoja,limoju,limozhi,lymwj,lymwz,lymwzh,rimoju,Λιμόζ,Горад Лімож,Лимож,Лімож,Լիմոժ,לימוז,ليموج,لیموژ,لیموگے,लिमोज,ლიმოჟი,リモージュ,利摩日,里蒙,리모주', 45.8315300, 1.2578100, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53570, 'Limetz-Villez', 'Limetz-Villez', 'Limets-Ville,Лиметс-Вилле,Ліметс-Вілле', 49.0666700, 1.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53571, 'Limésy', 'Limesy', 'Limesy,Limésy', 49.6127100, 0.9248300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53572, 'Limerzel', 'Limerzel', 'Ecclesia Martyrum,Limerzel,Limerzel'',Lizmerzher,li mei er ze,Лимерзель,Лімерзель,利梅尔泽', 47.6361900, -2.3544800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53573, 'Limeil-Brévannes', 'Limeil-Brevannes', 'Limeil,Limeil-Brevannes,Limeil-Breyannes,Limeil-Brévannes,Limej-Brevann,li mei bu lei wa na,Лимей-Бреванн,Лімей-Бреванн,利梅布勒瓦纳', 48.7448000, 2.4870500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53574, 'Limay', 'Limay', 'Limay', 48.9955300, 1.7408100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53575, 'Limas', 'Limas', 'Limas', 45.9789600, 4.7029200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53576, 'Lillers', 'Lillers', 'Lie,Liller,Lillers,li lai er,lylyrs,Лие,Лиллер,Ліє,ليليرس,利莱尔', 50.5634500, 2.4804200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53577, 'Lillebonne', 'Lillebonne', 'Lill''bonn,Lillebonne,Лилльбонн,Лілльбонн', 49.5203000, 0.5361700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53578, 'Lille', 'Lille', 'Gorad Lil'',Insula,LIL,Lil,Lila,Lile,Lilis,Lill,Lill'',Lilla,Lille,Lillo,Rijsel,Risel,Rysel,li er,lil,lil.,lila,lili,lly,lyl,riru,Λιλ,Горад Ліль,Лил,Лилль,Лілль,Լիլ,ליל,للی,ليل,لیل,लील,ਲੀਲ,லீல்,ลีล,ლილი,リール,里尔,里爾,릴', 50.6329700, 3.0585800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53579, 'L''Île-Rousse', 'L''Ile-Rousse', 'Ile Rousse,Isola Rossa,L''Il Rus,L''Il''-Ros,L''Il''-Rus,L''Il''-Russ,L''Ile-Rousse,L''Isula Rossa,L''Île-Rousse,Lisula,Lìsula,L’Île-Rousse,Île Rousse,Л''Іль-Русс,Л''Ил Рус,Л''Иль-Рус,Л''Иль-Русс,Л’Иль-Рос', 42.6337100, 8.9376400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53580, 'Ligugé', 'Liguge', 'Ligjuzhe,Liguge,Ligugé,Locociacum,li ju re,Лігюже,利居热', 46.5203500, 0.3261700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53581, 'Ligueil', 'Ligueil', 'Ligueil,Ligueuil', 47.0421000, 0.8189300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53582, 'Ligré', 'Ligre', 'Ligre,Ligré', 47.1118500, 0.2756200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53583, 'Ligny-le-Ribault', 'Ligny-le-Ribault', 'Ligny,Ligny-le-Ribault,Lin''i-le-Ribo,li ni lai li bo er,Ліньї-ле-Рибо,利尼莱里博尔', 47.6841900, 1.7815300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53584, 'Ligny-le-Châtel', 'Ligny-le-Chatel', 'Ligny,Ligny-le-Chatel,Ligny-le-Châtel', 47.9002200, 3.7576000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53585, 'Ligny-en-Cambrésis', 'Ligny-en-Cambresis', 'Ligny,Ligny-en-Cambresis,Ligny-en-Cambrésis,Lin''i-an-Kambrezi,li ni ang kang bu lei xi,Линьи-ан-Камбрези,Ліньї-ан-Камбрезі,利尼昂康布雷西', 50.1012300, 3.3784100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53586, 'Ligny-en-Barrois', 'Ligny-en-Barrois', 'Ligny,Ligny-en-Barrois,Lin''i-an-Barrua,ba er lu wa de qu li ni,Линьи-ан-Барруа,Ліньї-ан-Барруа,巴尔鲁瓦地区利尼', 48.6886100, 5.3254300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53587, 'Lignières', 'Lignieres', 'Lignieres,Lignières', 46.7515200, 2.1738100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53588, 'Ligné', 'Ligne', 'Legneg,Ligne,Ligné', 47.4109600, -1.3772600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53589, 'Lignan-sur-Orb', 'Lignan-sur-Orb', 'Lignan,Lignan-sur-Orb', 43.3846200, 3.1689100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53590, 'Liffré', 'Liffre', 'Liffre,Liffré,Liverieg,Livriacum,li fu lei,Лиффре,Ліффре,利夫雷', 48.2132400, -1.5083800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53591, 'Liffol-le-Grand', 'Liffol-le-Grand', 'Liffol''-le-Gran,Liffol-le-Grand,da li fu,Лиффоль-ле-Гран,Ліффоль-ле-Гран,大利福', 48.3177100, 5.5812500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53592, 'Liévin', 'Lievin', 'L''even,Levin,Lieven,Lievin,Lijeven,Liévin,Lévin,lie wan,liebaeng,lyfyn,lyywn,rievu~an,Лиевен,Лијевен,Льевен,Льєвен,ليفين,لیئون,リエヴァン,列萬,리에뱅', 50.4198000, 2.7806800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53593, 'Lieu-Saint-Amand', 'Lieu-Saint-Amand', 'Lieu-Saint-Amand', 50.2731800, 3.3462400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53594, 'Lieusaint', 'Lieusaint', 'Lieusaint', 48.6347600, 2.5480600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53595, 'Lieurey', 'Lieurey', 'L''ere,Lieurey,li ye yu lei,Льере,Льєре,利耶于雷', 49.2301900, 0.4987900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53596, 'Lieuran-lès-Béziers', 'Lieuran-les-Beziers', 'Lieuran,Lieuran-les-Beziers,Lieuran-lès-Béziers', 43.4186000, 3.2371900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53597, 'Liesse-Notre-Dame', 'Liesse-Notre-Dame', 'Notre Dame de Liesse', 49.6166700, 3.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53598, 'Liergues', 'Liergues', 'Liergues', 45.9713800, 4.6623100, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53599, 'Lièpvre', 'Liepvre', 'L''evr,Liepvre,Lièpvre,li ye pu fu er,Льевр,Льєвр,利耶普夫尔', 48.2703600, 7.2841400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53600, 'Licques', 'Licques', 'Licques,Lik,li ke,lyskyws,Лик,Лік,ليسكيوس,利克', 50.7841600, 1.9384400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53601, 'Libourne', 'Libourne', 'Liborna,Libourne,Liburn,XLR,li bu er ne,libuleun,lybwrn,riburunu,Либурн,Лібурн,ליבורן,لیبورن,リブルヌ,利布爾訥,리부른', 44.9166700, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53602, 'Libercourt', 'Libercourt', 'Libercourt,Liberkur,li bei er ku er,lybyrkwrt,Либеркур,Ліберкур,ليبيركورت,利贝尔库尔', 50.4832200, 3.0158400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53603, 'Liancourt', 'Liancourt', 'L''Unite-de-l''Oise,L''Unité-de-l''Oise,L''jankur,Liancourt,Liancourt-sous-Clermont,Liankur,Unite-sur-Oise,Unité-sur-Oise,li ang ku er,lyankwrt,Льянкур,Ліанкур,لیانکورت,利昂库尔', 49.3303400, 2.4659500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53604, 'Hôpital-Camfrout', 'Hopital-Camfrout', 'An Ospital,Hopital-Camfrout,Hôpital-Camfrout,L''Hopital,L''Hopital-Camfrout,L’Hôpital,L’Hôpital-Camfrout,Opital''-Kamfru,ao pi ta kang fu lu,opitaru=kanfuru,Опиталь-Камфру,Опіталь-Камфру,オピタル＝カンフルー,奥皮塔康夫鲁', 48.3278900, -4.2415500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53605, 'Lherm', 'Lherm', 'Lherm', 43.4312700, 1.2223900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53606, 'L''Haÿ-les-Roses', 'L''Hay-les-Roses', 'L''Hay,L''Hay-les-Roses,L''Haÿ-les-Roses', 48.7833300, 2.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53607, 'Lezoux', 'Lezoux', 'Ledos,Ledós,Lesos,Lesós,Lezu,lei zu,ruzu,Лезу,ルズー,勒祖', 45.8268900, 3.3792400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53608, 'Lézigneux', 'Lezigneux', 'Lezigneux,Lézigneux', 45.5670500, 4.0652400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53609, 'Lézignan-la-Cèbe', 'Lezignan-la-Cebe', 'Lesignan la Cebe,Lesinhan de la Ceba,Lesinhan la Ceba,Lezignan,Lezignan-la-Cebe,Lezin''jan-la-Seb,Lésignan la Cèbe,Lézignan,Lézignan-la-Cèbe,lai qi ni ang la sai bu,Лезиньян-ла-Себ,Лезіньян-ла-Себ,莱齐尼昂拉塞布', 43.4936800, 3.4370800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53610, 'Lézignan-Corbières', 'Lezignan-Corbieres', 'Lesinhan de las Corbieras,Lesinhan de las Corbièras,Lezicnan-Corbieres,Lezignan,Lezignan-Corbieres,Lezin''jan-Korb''er,Lezin''jan-Korber,Lézicnan-Corbieres,Lézignan,Lézignan-Corbières,lai qi ni ang ke er bi ai,Лезиньян-Корбьер,Лезіньян-Корбєр,莱齐尼昂科尔比埃', 43.1976500, 2.7614200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53611, 'Lezennes', 'Lezennes', 'Lezenn,Lezennes,lei cang ne,Лезенн,勒藏讷', 50.6155300, 3.1135400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53612, 'Lezay', 'Lezay', 'Lezay', 46.2643700, -0.0092500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53613, 'Lézat-sur-Lèze', 'Lezat-sur-Leze', 'Lezat,Lezat-sur-Leze,Lézat,Lézat-sur-Lèze', 43.2773400, 1.3468600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53614, 'Lézardrieux', 'Lezardrieux', 'Lezardrev,Lezardrie,Lezardrieux,Lezardrijo,Lézardrieux,lai zha er de li e,Лезардрие,Лезардриё,Лезардріє,莱扎尔德里厄', 48.7851000, -3.1058800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53615, 'Lézan', 'Lezan', '', 44.0166700, 4.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53616, 'Leyment', 'Leyment', 'Leyment', 45.9229400, 5.2947900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53617, 'Leymen', 'Leymen', 'Leymen', 47.4952200, 7.4842600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53618, 'Leyme', 'Leyme', 'Leyme', 44.7862200, 1.8989700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53619, 'Lexy', 'Lexy', 'Lexy', 49.5035600, 5.7338000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53620, 'Lewarde', 'Lewarde', 'Levard,Lewarde,Lwarte,lei wa er de,Левард,勒瓦尔德', 50.3417300, 3.1678200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53621, 'Levroux', 'Levroux', 'La Fontaine,Leprosium,Levroux,Levru,Richelaine,lai fu lu,Левру,莱夫鲁', 46.9786000, 1.6124300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53622, 'Le Vivier-sur-Mer', 'Le Vivier-sur-Mer', 'Gwiver,Le Vivier,Le Vivier-sur-Mer', 48.6016900, -1.7730300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53623, 'Viviers-du-Lac', 'Viviers-du-Lac', '', 45.6500000, 5.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53624, 'Lévis-Saint-Nom', 'Levis-Saint-Nom', 'L''Yvette,Levi-Sen-Nom,Levis,Levis-Saint-Nom,Lévis,Lévis-Saint-Nom,Леви-Сен-Ном,Леві-Сен-Ном', 48.7166700, 1.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53625, 'Lévignac', 'Levignac', 'Levignac-sur-Save,Lévignac-sur-Save', 43.6666700, 1.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53626, 'Le Vigen', 'Le Vigen', 'Le Vigen,Lo Vijan', 45.7514900, 1.2886500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53627, 'Le Vigan', 'Le Vigan', 'Le Vigan', 44.7407500, 1.4396300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53628, 'Le Vigan', 'Le Vigan', 'Commune-des-Monts,Le Vigan,Monts,Sablono:TabelKapoLauCarta,Ŝablono:TabelKapoLaŭĈarta', 43.9833300, 3.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53629, 'Levier', 'Levier', 'Levier', 46.9530200, 6.1205900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53630, 'Le Vieil-Baugé', 'Le Vieil-Bauge', 'Le Vieil-Bauge,Le Vieil-Baugé,Le-Vej-Bozhe,lei wei ye yi bo re,Ле-Вєй-Боже,勒维耶伊博热', 47.5319300, -0.1188800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53631, 'Levet', 'Levet', 'Levet', 46.9260500, 2.4073200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53632, 'Le Vésinet', 'Le Vesinet', 'Le Vesinet,Le Vésinet,Le-Vezine,leubejine,Ле-Везине,Ле-Везіне,ル・ヴェジネ,르베지네', 48.8928100, 2.1330800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53633, 'Lèves', 'Leves', 'Lev,Leves,Lèves,lai wei,Лев,莱韦', 48.4706500, 1.4819400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53634, 'Le Versoud', 'Le Versoud', 'Le Versoud,Le-Versu,l wrswd,lei wei er su,Ле-Версу,ل ورسود,勒韦尔苏', 45.2138600, 5.8581500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53635, 'Vernet', 'Vernet', '', 43.4333300, 1.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53636, 'Levens', 'Levens', 'Levans,Levenc,Levens,Leventum,Levenzo,Levenç,lei wang,lyfyns,ruvu~an,Леванс,Левенс,ليفينس,ルヴァン,勒旺', 43.8604300, 7.2265300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53637, 'Le Vaudreuil', 'Le Vaudreuil', 'Le Vaudreuil,Le-Vodrej,Le-Vodrjoj,Vaudreuil-les-Ponts,lei wo de lei yi,Ле-Водрей,Ле-Водрёй,勒沃德勒伊', 49.2540700, 1.2096000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53638, 'Le Val-Saint-Père', 'Le Val-Saint-Pere', 'Le Val-Pere,Le Val-Père,Le Val-Saint-Pere,Le Val-Saint-Père,Val Saint Pair', 48.6617700, -1.3765300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53639, 'Le Val-Saint-Germain', 'Le Val-Saint-Germain', 'Le Val-Saint-Germain,Le-Val''-Sen-Zhermen,Val-Libre,lei wa sheng re er man,Ле-Валь-Сен-Жермен,勒瓦圣热尔曼', 48.5660100, 2.0647100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53640, 'Levallois-Perret', 'Levallois-Perret', 'Levallois,Levallois-Perret,Levallua Pere,Levallua-Perre,Levaloa Pere,QBH,lei wa lu wa-pei lei,leuballuapele,lwalwa-prh,lwfalwa-byry,lwwlwa-prh,ruvu~arowa=pere,Леваллуа-Перре,Левалоа Пере,Լևալլուա Պերե,لوالوآ-پره,لوفالوا-بيري,لوولوآ-پره,ルヴァロワ＝ペレ,勒瓦卢瓦-佩雷,르발루아페레', 48.8938900, 2.2886400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53641, 'Valdahon', 'Valdahon', '', 47.1500000, 6.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53642, 'Leval', 'Leval', 'Leval', 50.1810600, 3.8309300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53643, 'Le Val', 'Le Val', 'Le Val,Le-Val'',Lo Vau,lh wal,Ле-Валь,له وال', 43.4386500, 6.0729500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53644, 'Leuville-sur-Orge', 'Leuville-sur-Orge', 'Leuville,Leuville-sur-Orge,Levil''-sjur-Orzh,ao er ri he pan lei wei er,levil-siur-orzhi,Левиль-сюр-Орж,Левіль-сюр-Орж,ლევილ-სიურ-ორჟი,奥尔日河畔勒维尔', 48.6173000, 2.2668500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53645, 'Leudeville', 'Leudeville', 'Ledevil'',Leudeville,lei de wei er,Ледевиль,Ледевіль,勒德维尔', 48.5659100, 2.3267600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53646, 'Leucate', 'Leucate', 'Lekat,Leucata,Leucate,Ljokat,lei ka te,rukato,Лекат,Лёкат,ルカート,勒卡特', 42.9105600, 3.0294400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53647, 'Le Trévoux', 'Le Trevoux', 'An Treou-Kerne,An Treou-Kernev,An Treoù-Kerne,An Treoù-Kernev,Le Trevoux,Le Trévoux,Le-Trevu,Trevoux,Trévoux,lei te lei wu,Ле-Треву,ル・トレヴー,勒特雷武', 47.8947800, -3.6408000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53648, 'Le Tréport', 'Le Treport', 'Le-Trepor,Ulterior Portus,Ле-Трепор', 50.0597900, 1.3758300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53649, 'Le Trait', 'Le Trait', 'Le Trait,Le-Tre,Ле-Тре', 49.4689500, 0.8163400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53650, 'Le Touvet', 'Le Touvet', 'Le Touvet,Le-Tuve,Touvet,lei tu wei,Ле-Туве,勒图韦', 45.3580900, 5.9488900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53651, 'Le Touquet-Paris-Plage', 'Le Touquet-Paris-Plage', 'Ech Toutchet-Paris-Plache,LTQ,Le Touquet,Le Touquet-Paris-Plage,Le Tourquet,Le Tourquet-Paris-Plage,Le-Tuke-Pari-Plazh,Paris-Plage,Tourquet,lei tu kai ba li pu la ri,lw twkh,ly twkywt,Ле-Туке-Пари-Плаж,Ле-Туке-Парі-Плаж,لو توکه,لي توكيوت,勒图凯巴黎普拉日', 50.5243200, 1.5857100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53652, 'Le Tignet', 'Le Tignet', 'Le Tignet', 43.6388700, 6.8417300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53653, 'Le Thuit-Signol', 'Le Thuit-Signol', 'Le Thuit-Signol', 49.2648700, 0.9391000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53654, 'Le Thou', 'Le Thou', 'Le Thou,Le-Tu,lw tw,Ле-Ту,لو تو', 46.0833300, -0.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53655, 'Le Thoronet', 'Le Thoronet', 'Le Thoronet,Le-Torone,Lo Toronet,lei tuo luo na,Ле-Тороне,勒托罗纳', 43.4525700, 6.3034300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53656, 'Le Thor', 'Le Thor', 'Le Thor,Le-Tor,Lo Tor,Lo Tòr,l twr,lai tuo,Ле-Тор,ل تور,莱托', 43.9294300, 4.9954300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53657, 'Le Tholy', 'Le Tholy', 'Le Tholy,Le-Toli,Tholy,lai tuo li,Ле-Толи,Ле-Толі,莱托利', 48.0822900, 6.7435100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53658, 'Le Tholonet', 'Le Tholonet', 'Le Tholonet,Le-Tolone,Lo Tolonet,Tholonet,lei tuo luo nei,Ле-Толоне,勒托洛内', 43.5217600, 5.5111500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53659, 'Le Thillot', 'Le Thillot', 'Le Thillot', 47.8794100, 6.7627900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53660, 'Le Thillay', 'Le Thillay', 'Le Thillay', 49.0065900, 2.4721800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53661, 'Le Theil-de-Bretagne', 'Le Theil-de-Bretagne', 'An Tilh,Le Theil,Le Theil-de-Bretagne,Le-Tej-de-Bretan'',Theil-de-Bretagne,Tilia,lei tai de bu lei ta ni,Ле-Тей-де-Бретань,勒泰德布雷塔尼', 47.9195000, -1.4297500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53662, 'Le Theil-Bocage', 'Le Theil-Bocage', '', 48.8833300, -0.7166700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53663, 'Le Temple-de-Bretagne', 'Le Temple-de-Bretagne', 'Le Temple,Le Temple-Maupertuis,Le Temple-de-Bretagne,Le-Tampl''-de-Bretan'',Templ-Breizh,lei tang pu er de bu lei ta ni,Ле-Тампль-де-Бретань,ル・タンプル＝ド＝ブルターニュ,勒唐普尔德布雷塔尼', 47.3273700, -1.7890400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53664, 'Le Teilleul', 'Le Teilleul', 'Le Teilleul,Le-Teel'',Teilleul,lei tai lei,Ле-Теель,Ле-Теєль,勒泰勒', 48.5375800, -0.8730400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53665, 'Le Teil', 'Le Teil', 'Le Teil,Le-Tej,Lo Telh,lei tai,Ле-Тей,勒泰', 44.5467900, 4.6816500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53666, 'Le Teich', 'Le Teich', 'Le Teich,Le-Tesh,Lo Teish,lei tai ke,Ле-Теш,勒泰克', 44.6317700, -1.0215500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53667, 'Le Tallud', 'Le Tallud', 'Le Tallud', 46.6291100, -0.2997900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53668, 'Le Taillan-Médoc', 'Le Taillan-Medoc', 'Autelhan,Le Taillan,Le Taillan-Medoc,Le Taillan-Médoc,Le-Tajan-Medok,Lo Talhan de Medoc,Lo Talhan de Medòc,lei tai lang mei duo ke,Ле-Таян-Медок,勒泰朗梅多克', 44.9052100, -0.6706000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53669, 'Le Syndicat', 'Le Syndicat', 'Le Syndicat,Le-Sindika,lai sang di ka,Ле-Синдика,Ле-Сіндіка,莱桑迪卡', 48.0173300, 6.6843600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53670, 'Les Vans', 'Les Vans', 'Le-Van,Les Vans,Los Vans,lai si wang,Ле-Ван,莱斯旺', 44.4061900, 4.1347100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53671, 'Lestrem', 'Lestrem', 'Lestrem,Letrin,Létrin,lai si te lang,lystrym,Лестрем,ليستريم,莱斯特朗', 50.6198700, 2.6864600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53672, 'Les Touches', 'Les Touches', 'An Dosenneg,Le-Tush,Les Touches,Tuschiis,lai si tu xie,Ле-Туш,レ・トゥーシュ,莱斯图谢', 47.4424900, -1.4309700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53673, 'Lestelle-Bétharram', 'Lestelle-Betharram', 'LEstela e Betharram,LEstela e Bètharram,LEstela-Betharram,LEstela-Bètharram,Lestel''-Betarram,Lestelle,Lestelle-Betharram,Lestelle-Bétharram,lai si tai er bei ta er lang,Лестель-Бетаррам,莱斯泰尔贝塔尔朗', 43.1333300, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53674, 'Les Sorinières', 'Les Sorinieres', 'Kersoren,Le-Sorin''er,Les Sorinieres,Les Sorinières,lai suo li ni ai,Ле-Сориньєр,莱索里尼埃', 47.1483100, -1.5293200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53675, 'Lessay', 'Lessay', 'Lessay,Lesse,lai sai,lsay,Лессе,لسای,莱赛', 49.2170300, -1.5308900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53676, 'Les Salles-du-Gardon', 'Les Salles-du-Gardon', 'Les Salles-du-Gardon', 44.2079000, 4.0368900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53677, 'Les Sables-d''Olonne', 'Les Sables-d''Olonne', 'LSO,Le-Sabl''-d''Olon,Le-Sabl''-d''Olonn,Les Sables d''Olonne,Les Sables-d''Olonne,Les Sables-d’Olonne,Sables-d''Olonne,lai sa bu lei duo luo ne,Ле-Сабль-д''Олонн,Ле-Сабль-д’Олон,レ・サーブル＝ドロンヌ,莱萨布勒多洛讷', 46.5000000, -1.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53678, 'Les Rousses', 'Les Rousses', 'Le-Russ,Les Rousses,lai si lu sai,Ле-Русс,莱斯鲁塞', 46.4841200, 6.0633000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53679, 'Les Rosiers-sur-Loire', 'Les Rosiers-sur-Loire', 'Le-Roz''e-sjur-Luar,Les Rosiers,lu wa er he pan lai si luo xie er,Ле-Розьє-сюр-Луар,卢瓦尔河畔莱斯罗谢尔', 47.3500000, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53680, 'Les Roches-de-Condrieu', 'Les Roches-de-Condrieu', 'Les Roches,Les Roches-de-Condrieu', 45.4510700, 4.7673800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53681, 'Les Riceys', 'Les Riceys', 'Les Riceys', 47.9939000, 4.3698600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53682, 'Lesquin', 'Lesquin', 'Lesken,Lesquin,lai si kan,Лескен,莱斯坎', 50.5823200, 3.1190000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53683, 'Les Ponts-de-Cé', 'Les Ponts-de-Ce', 'Le Pont de Ce,Le-Pon-de-Se,Ponts-Libres,lai si peng te de sai,Ле-Пон-де-Се,莱斯蓬特德塞', 47.4231500, -0.5247700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53684, 'Lespinasse', 'Lespinasse', 'Lespinasse', 43.7120600, 1.3846200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53685, 'Lespignan', 'Lespignan', 'Lespignan,Lespin''jan,Lespinhan,lai si pi ni ang,Леспиньян,Леспіньян,莱斯皮尼昂', 43.2736600, 3.1722400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53686, 'Les Pieux', 'Les Pieux', 'Les Pieux', 49.5128600, -1.8071400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53687, 'Les Pennes-Mirabeau', 'Les Pennes-Mirabeau', 'Le-Pen-Mirabo,Le-Penn-Mirabo,Lei Penas,Lei Penas de Mirabeu,Lei Penas de Mirabèu,Les Pennes,lai si pei ni si mi la bo,lepenmilabo,lpn myrbw,Ле-Пен-Мирабо,Ле-Пенн-Мірабо,لپن میربو,レ・ペンヌ＝ミラボー,萊斯佩尼斯米拉波,레펜미라보', 43.4102800, 5.3130600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53688, 'Les Peintures', 'Les Peintures', 'Les Peintures', 45.0666700, -0.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53689, 'Les Pavillons-sous-Bois', 'Les Pavillons-sous-Bois', 'Le Pavijon su Boa,Le-Pavijon-su-Bua,Les Pavillons-sous-Bois,Pavillons,Pavillons-sous-Bois,cong lin ge,lepabiyongsubua,les Pavillons,spwywn sw bwa,Ле Павијон су Боа,Ле-Павийон-су-Буа,Ле-Павійон-су-Буа,سپویون سو بوآ,レ・パヴィヨン＝スー＝ボワ,丛林阁,레파비용수부아', 48.9068300, 2.5064800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53690, 'Lesparre-Médoc', 'Lesparre-Medoc', 'L''Sparre,LEsparra,Lespar-Medok,Lesparr-Medok,Lesparre,Lesparre-Medoc,Lesparre-Médoc,Lesperre,lai si pa er mei duo ke,resuparu=medokku,Леспар-Медок,Леспарр-Медок,レスパール＝メドック,莱斯帕尔梅多克', 45.3000000, -0.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53691, 'Le Sourn', 'Le Sourn', 'Ar Sorn,Le Sourn', 48.0426200, -2.9879000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53692, 'Les Ormes', 'Les Ormes', 'Les Ormes', 46.9747800, 0.6048400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53693, 'Le Soler', 'Le Soler', 'El Soler,Le Soler,Le-Sole,Soler,el Soler,l swlr,lei suo lai,Ле-Соле,ل سولر,勒索莱', 42.6810100, 2.7933500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53694, 'Les Noës-près-Troyes', 'Les Noes-pres-Troyes', 'Les Noes,Les Noes-pres-Troyes,Les Noës,Les Noës-près-Troyes', 48.3035800, 4.0455200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53695, 'Lesneven', 'Lesneven', 'Lenevan,Lesneven,lai si na wang,lsnwn,resunevu~an,Леневан,Лесневен,لسنون,レスネヴァン,莱斯纳旺', 48.5723300, -4.3213300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53696, 'Les Mureaux', 'Les Mureaux', 'Le Miro,Le-Mjuro,Les Mureaux,lemwilo,lmwrw,miao luo,Ле Миро,Ле-Мюро,لمورو,レ・ミュロー,缪罗,레뮈로', 48.9917300, 1.9097200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53697, 'Moutiers-les-Mauxfaits', 'Moutiers-les-Mauxfaits', 'Les Moutiers,Les Moutiers-Fideles,Les Moutiers-Fidèles', 46.4833300, -1.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53698, 'Les Moutiers-en-Retz', 'Les Moutiers-en-Retz', 'Burgus Monasteriorum,Le-Mut''e-an-Re,Mousterou-Raez,Mousteroù-Raez,lei te de qu lai si mu di ye er,Ле-Мутьє-ан-Ре,雷特地区莱斯穆蒂耶尔', 47.0637500, -1.9990000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53699, 'Les Montils', 'Les Montils', 'Le-Monti,Les Montils,Montils,lai si meng di er,Ле-Монті,莱斯蒙蒂尔', 47.4949900, 1.2977500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53700, 'Les Molières', 'Les Molieres', 'Le-Mol''er,Les Molieres,Les Molières,lai si mo li ai,Ле-Мольер,Ле-Мольєр,莱斯莫利埃', 48.6730600, 2.0695900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53701, 'Les Mées', 'Les Mees', 'Les Mees,Les Mées', 44.0307100, 5.9768100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53702, 'Les Mathes', 'Les Mathes', 'Le-Mat,Les Mathes,Les Mathes - La Palmyre,lai si ma tai,Ле-Мат,莱斯马泰', 45.7139000, -1.1549700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53703, 'Les Matelles', 'Les Matelles', 'Las Matelas,Las Matèlas,Le-Matel'',Les Matelles,Matelles,lai si ma tai lai,Ле-Матель,莱斯马泰莱', 43.7290500, 3.8136000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53704, 'Les Marches', 'Les Marches', 'Le-Marsh,Les Marches,Ле-Марш', 45.4992100, 6.0008700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53705, 'Les Magnils-Reigniers', 'Les Magnils-Reigniers', 'Le-Manij-Ren''e,Les Magnils-Reigniers,lai si ma ni er lei nie er,Ле-Маній-Реньє,莱斯马尼尔雷涅尔', 46.4833300, -1.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53706, 'Les Mages', 'Les Mages', 'Le-Mazh,Les Mages,Los Mages,lai si ma re,Ле-Маж,莱斯马热', 44.2286200, 4.1694600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53707, 'Les Lucs-sur-Boulogne', 'Les Lucs-sur-Boulogne', 'Le-Ljuk-sjur-Bulon'',Les Lucs,Les Lucs-sur-Boulogne,bu luo ge he pan lai si lu ke,Ле-Люк-сюр-Булонь,布洛格河畔莱斯吕克', 46.8447800, -1.4944500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53708, 'Les Loges-Marchis', 'Les Loges-Marchis', 'Les Loges-Marchis', 48.5413200, -1.0875400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53709, 'Les Loges-en-Josas', 'Les Loges-en-Josas', 'Le-Lozh-an-Zhoza,Les Loges,Loges-en-Josas,Ле-Лож-ан-Жоза', 48.7637700, 2.1400200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53710, 'Les Loges', 'Les Loges', 'Les Loges', 49.6986000, 0.2840300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53711, 'Les Lilas', 'Les Lilas', 'Le Lilas,Le-Lila,Les Lilas,ding xiang zhen,lelilla,llyla,Ле Лилас,Ле-Лила,Ле-Ліла,للیلا,レ・リラ,丁香镇,레릴라', 48.8799200, 2.4205700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53712, 'Les Landes-Genusson', 'Les Landes-Genusson', 'Les Gats,Les Gâts,Les Landes,Les Landes-Cenusson', 46.9666700, -1.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53713, 'Lésigny', 'Lesigny', '', 48.7437400, 2.6151800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53714, 'Les Houches', 'Les Houches', 'Hoschae,Houches,Le-Ush,Les Houches,Lez-Ush,Ле-Уш,Лез-Уш,אוש', 45.8901100, 6.7961300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53715, 'Les Herbiers', 'Les Herbiers', 'Erbje,Herbiers,Le-Erbe,Les Herbiers,Les Petits-Herbiers,lai sai er bi ye er,Ербје,Ле-Ербє,莱塞尔比耶尔', 46.8666700, -1.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53716, 'Les Hautes-Rivières', 'Les Hautes-Rivieres', 'Hautes-Rivieres,Hautes-Rivières,Les Hautes-Rivieres,Les Hautes-Rivières', 49.8859500, 4.8418600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53717, 'Les Grandes-Ventes', 'Les Grandes-Ventes', 'Grandes-Ventes,Les Grandes-Ventes', 49.7854400, 1.2292100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53718, 'Les Gonds', 'Les Gonds', 'Les Gonds', 45.7143700, -0.6140800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53719, 'Les Gets', 'Les Gets', 'Gets,Iactus,Le-Zhe,Les Gets,Zhe,Же,Ле-Же', 46.1552200, 6.6649200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53720, 'Les Fourgs', 'Les Fourgs', 'Les Fourgs', 46.8345500, 6.3995300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53721, 'Les Forges', 'Les Forges', 'Les Forges', 48.1774700, 6.3884600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53722, 'Les Fins', 'Les Fins', 'Le-Fen,Les Fins,lai si fan,Ле-Фен,莱斯凡', 47.0776400, 6.6300200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53723, 'Les Essarts-le-Roi', 'Les Essarts-le-Roi', 'Esart le Roa,Essarts-le-Roi,Les Essarts,Les Essarts-la-Montagne,Les Essarts-le-Roi,Les Essarts-les-Bois,Lez-Essar-le-Rua,Montagne-des-Essarts,Есарт ле Роа,Лез-Ессар-ле-Руа', 48.7167300, 1.9008900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53724, 'Les Essarts', 'Les Essarts', 'Les Essarts', 46.7744000, -1.2283400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53725, 'Les Epesses', 'Les Epesses', 'Les Epesses,Les Épesses,Lez-Epess,lai se pei se,Лез-Епесс,莱瑟佩瑟', 46.8833300, -0.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53726, 'Les Églisottes-et-Chalaures', 'Les Eglisottes-et-Chalaures', 'Les Eglisottes,Les Eglisottes-et-Chalaures,Les Églisottes,Les Églisottes-et-Chalaures', 45.1000000, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53727, 'Les Échelles', 'Les Echelles', 'Les Echelles,Les Échelles,Lez-Eshel'',Лез-Ешель', 45.4348100, 5.7513300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53728, 'Les Contamines-Montjoie', 'Les Contamines-Montjoie', 'Condominium-Mons Iugi,Contamines-Montjoie,Kontamin Monzhoa,Le-Kontamin-Monzhua,Les Contamines,Les Contamines-Montjoie,Контамин Монжоа,Ле-Контамін-Монжуа', 45.8213600, 6.7281700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53729, 'Les Clouzeaux', 'Les Clouzeaux', 'Les Clouzeaux', 46.6288100, -1.5094700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53730, 'Les Clayes-sous-Bois', 'Les Clayes-sous-Bois', 'Clayes-sous-Bois,Klej su Boa,Le-Kle-su-Bua,Les Clayes,Les Clayes-sous-Bois,Клеј су Боа,Ле-Кле-су-Буа', 48.8220600, 1.9867700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53731, 'Les Chères', 'Les Cheres', 'Les Cheres,Les Chères,Les Echelles', 45.8897500, 4.7467000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53732, 'Les Champs-Géraux', 'Les Champs-Geraux', 'Les Champs-Geraud,Les Champs-Geraux,Les Champs-Géraud,Les Champs-Géraux,Maez-Geraod', 48.4164700, -1.9708700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53733, 'Lescar', 'Lescar', 'Lascurris,Lescar,Leskar,Leskarre,lai si ka,Лескар,莱斯卡', 43.3333300, -0.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53734, 'Les Brouzils', 'Les Brouzils', 'Brouzils,Bruzij,Le-Bruzij,Les Brouzils,lai si bu lu qi er,Брузиј,Ле-Брузій,莱斯布鲁齐尔', 46.8857100, -1.3209500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53735, 'Les Avenières', 'Les Avenieres', 'Avenieres,Avenières,Avnijer,Les Avenieres,Les Avenières,Lez Avenier,Lez-Aven''er,lai sa wei ni ai,Λεζ Αβενιέρ,Авнијер,Лез-Авеньер,Лез-Авеньєр,莱萨韦尼埃', 45.6315600, 5.5707400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53736, 'Les Authieux-sur-le-Port-Saint-Ouen', 'Les Authieux-sur-le-Port-Saint-Ouen', 'Authieux-sur-le-Port-des-Sans-Culottes,Les Authieux,Les Authieux-sur-le-Port-Saint-Ouen', 49.3410000, 1.1346500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53737, 'Les Attaques', 'Les Attaques', 'Atak,Attaques,Les Attaques,Lez-Attak,lai a ta ke,lyh atakywys,Атак,Лез-Аттак,ليه أتاكيويس,莱阿塔克', 50.9096200, 1.9296100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53738, 'Les Artigues-de-Lussac', 'Les Artigues-de-Lussac', 'Les Artigues,Les Artigues-de-Lussac,Les Artigues-la Foret,Les Artigues-la Forêt', 44.9666700, -0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53739, 'Les Arcs', 'Les Arcs', 'Les Arc-sur-Argens,Les Arcs,XRS', 43.4570200, 6.4790500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53740, 'Le Sappey-en-Chartreuse', 'Le Sappey-en-Chartreuse', 'Le Sappey,Le Sappey-en-Chartreuse,Le-Sappe-an-Shartrez,Le-Sappe-an-Shartrjoz,sha er te lei si de qu lei sa pei,Ле-Саппе-ан-Шартрез,Ле-Саппе-ан-Шартрёз,沙尔特勒斯地区勒萨佩', 45.2599800, 5.7772100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53741, 'Les Angles', 'Les Angles', 'Les Angles', 43.9580600, 4.7634200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53742, 'Les Andelys', 'Les Andelys', 'Andeliacum,Les Andelys,Lez Andeli,Lez-Andeli,lai sang dai li,re=zandori,Лез Андели,Лез-Андели,Лез-Анделі,レ＝ザンドリ,莱桑代利', 49.2500000, 1.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53743, 'Les Ancizes-Comps', 'Les Ancizes-Comps', 'Ancizes-Comps,Les Ancizes,Les Ancizes-Comps,Onsiz-Komp,Онсиз-Комп', 45.9253500, 2.8107400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53744, 'Les Alluets-le-Roi', 'Les Alluets-le-Roi', 'Alije le Roa,Alluets-la-Montagne,Alluets-le-Roi,Les Alluets,Les Alluets-le-Roi,Lez-Alljue-le-Rua,Алије ле Роа,Лез-Аллюе-ле-Руа', 48.9137900, 1.9181000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53745, 'Les Allues', 'Les Allues', 'Ali,Allodia,Lez-Allju,Valmineral,Valminéral,Али,Лез-Аллю', 45.4325500, 6.5555800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53746, 'Les Ageux', 'Les Ageux', 'Azhe,Les Ageux,Lez-Azhe,lai sa re,Аже,Лез-Аже,莱萨热', 49.3166700, 2.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53747, 'Les Abrets', 'Les Abrets', 'Les Abrets', 45.5370600, 5.5853500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53748, 'Léry', 'Lery', 'Lery,Léry', 49.2858500, 1.2076800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53749, 'Le Russey', 'Le Russey', 'Le Russey', 47.1605500, 6.7291200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53750, 'Le Rove', 'Le Rove', 'Le Rove,Le-Rov,Lo Rouve,Lo Rove,Lo Ròuve,Lo Ròve,lei luo fu,Ле-Ров,勒罗夫', 43.3698700, 5.2511200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53751, 'Lérouville', 'Lerouville', 'Lerouville,Lérouville', 48.7926100, 5.5406300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53752, 'Le Rouret', 'Le Rouret', 'Bergier,Le Rouret,Le-Rure,Lo Roret,lei lu lei,ly rwryt,Ле-Руре,لي روريت,勒鲁雷', 43.6787300, 7.0152100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53753, 'Le Rheu', 'Le Rheu', 'Le Rheu,Le-Re,Reuz,Rheu,Rodus,Ле-Ре', 48.1022800, -1.7973300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53754, 'Le Revest-les-Eaux', 'Le Revest-les-Eaux', 'Le Revest,Le-Revest-lez-O,Lo Revest,Lo Revest leis Aigas,Lo Revèst,Lo Revèst leis Aigas,lai lei fu si lei ao,Ле-Ревест-лез-О,莱勒弗斯勒奥', 43.1761200, 5.9266700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53755, 'Le Relecq-Kerhuon', 'Le Relecq-Kerhuon', 'Ar Releg-Kerhuon,Le Relecq,Le Relecq-Kerhuon,Le-Relek-Kerjuon,Relecq-Kerhuon,lei lei lai ke lu weng,Ле-Релек-Керюон,勒雷莱克吕翁', 48.4069100, -4.3935900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53756, 'Léré', 'Lere', 'Lere,Léré', 47.4686700, 2.8698100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53757, 'Le Raincy', 'Le Raincy', 'Le-Rensi,rnsy,Ле-Ренси,Ле-Ренсі,רנסי,ル・ランシー', 48.9000000, 2.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53758, 'Le Quesnoy', 'Le Quesnoy', 'Cassanetum,Le Quesnoy,Le-Kenua,lei kai nu wa,Ле-Кенуа,勒凯努瓦', 50.2479700, 3.6365600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53759, 'Le Puy-Sainte-Réparade', 'Le Puy-Sainte-Reparade', 'Le Puy,Le Puy-Sainte-Reparade,Le Puy-Sainte-Réparade,Le-Pjui-Sent-Reparad,Lo Pueg,Lo Pueg de Santa Reparada,lei pi yi sheng lei pa la de,Ле-Пюи-Сент-Репарад,Ле-Пюї-Сент-Репарад,勒皮伊圣雷帕拉德', 43.6631900, 5.4343400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53760, 'Le Puy-Notre-Dame', 'Le Puy-Notre-Dame', 'Le Puy-Notre-Dame,Le-Pjui-Notr-Dam,Puy-Notre-Dame,Puy-la-Montagne,lei pi yi nuo te er dang,Ле-Пюї-Нотр-Дам,勒皮伊诺特尔当', 47.1255100, -0.2357200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53761, 'Le Puy-en-Velay', 'Le Puy-en-Velay', 'Anicium Vellavorum,LPY,Le Pij an Vele,Le Piui en Veli,Le Puy,Le Puy-en-Velay,Le-Pjui,Le-Pjui-an-Vele,Lo Puei de Velai,Lo Puèi de Velai,Pjui-an-Vele,Puy-en-Velay,fu lai gu,lei pi,leupwiangbeolle,Ле Пиј ан Веле,Ле-Пюи,Ле-Пюи-ан-Веле,Ле-Пюї-ан-Веле,Пюи-ан-Веле,לה פוי-אן-ולה,เลอปุย-อ็อง-เวอแล,ལ་ཕུའི་ཨང་ཝ་ལེ།,ル・ピュイ＝アン＝ヴレ,佛來崮,勒皮,르퓌앙벌레', 45.0436600, 3.8852300, 'FR', '2016-12-11', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53762, 'Lepuix', 'Lepuix', 'Lepjui,Lepuix,Lepuix-Gy,lai pi yi,Лепюї,莱皮伊', 47.7599700, 6.8165000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53763, 'Le Pré-Saint-Gervais', 'Le Pre-Saint-Gervais', 'Le Pre-Saint-Gervais,Le Pré-Saint-Gervais,Le-Pre-Sen-Zherve,Les Pres-le-Peletier,Les Prés-le-Peletier,Pre Saint Gervais,Pre-Saint-Gervais,Pré Saint Gervais,Pré-Saint-Gervais,Ле-Пре-Сен-Жерве', 48.8854900, 2.4042200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53764, 'Le Pradet', 'Le Pradet', 'Le Pradet,Le-Prade,Lo Pradet,lei pu la dai,Ле-Праде,勒普拉代', 43.1066100, 6.0171800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53765, 'Le Pouzin', 'Le Pouzin', 'Le Pouzin,Le-Puzen,Lo Polzin,lei pu zan,Ле-Пузен,勒普赞', 44.7517300, 4.7479800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53766, 'Le Pouliguen', 'Le Pouliguen', 'Ar Poulgwenn,Le Pouliguen,Le-Puligan,lei pu li gai en,Ле-Пуліган,ル・プリガン,勒普利盖恩', 47.2697300, -2.4278000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53767, 'Le Poujol-sur-Orb', 'Le Poujol-sur-Orb', 'Le Poujol,Le Poujol-sur-Orb', 43.5791900, 3.0615600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53768, 'Le Pouget', 'Le Pouget', 'Le Pouget', 43.5919500, 3.5242300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53769, 'Le Port-Marly', 'Le Port-Marly', 'Le Port-Marly,Le-Por-Marli,Port-Marly,Ле-Пор-Марли,Ле-Пор-Марлі', 48.8901600, 2.1113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53770, 'Le Portel', 'Le Portel', 'L''Porte,Le Portel,Le-Portel'',L’Porté,lei bo tai lei,ly bwrtyl,Ле-Портель,لي بورتيل,勒波泰勒', 50.7055900, 1.5757400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53771, 'Port-des-Barques', 'Port-des-Barques', '', 45.9476300, -1.0779500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53772, 'Le Porge', 'Le Porge', 'Le Porge', 44.8727700, -1.0888900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53773, 'Le Pontet', 'Le Pontet', 'Le Pontet', 43.9611900, 4.8600800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53774, 'Le Pont-de-Claix', 'Le Pont-de-Claix', 'Le Pont-de-Claix,Pont-de-Claix', 45.1244300, 5.7064000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53775, 'Le Pont-de-Beauvoisin', 'Le Pont-de-Beauvoisin', 'Le Pont-de-Beauvoisin,Le-Pon-de-Bovuazen,Ле-Пон-де-Бовуазен', 45.5369400, 5.6733300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53776, 'Le Poiré-sur-Vie', 'Le Poire-sur-Vie', 'Le Poire,Le Poire-sur-Vie,Le Poiré,Le Poiré-sur-Vie', 46.7692100, -1.5093800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53777, 'Le Poinçonnet', 'Le Poinconnet', 'Le Poinconnet,Le Poinçonnet,Le-Puehnsone,Le-Puensonne,Poinconnet,Poinçonnet,lei pu an suo nei,Ле-Пуенсонне,Ле-Пуэнсоне,勒普安索内', 46.7641000, 1.7179000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53778, 'Le Plessis-Trévise', 'Le Plessis-Trevise', 'Le Plessis-Trevise,Le Plessis-Trévise,Le-Plessi-Treviz,Plessis-Trevise,Plessis-Trévise,lai pu lai xi te lei wei si,Ле-Плесси-Тревиз,Ле-Плессі-Тревіз,莱普莱西特勒维斯', 48.8107400, 2.5736300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53779, 'Le Plessis-Robinson', 'Le Plessis-Robinson', 'Le Plesi Robenson,Le Plessis-Robinson,Le-Plessi-Robenson,Le-Plessi-Robinson,Plessis-Robinson,lei pu lai xi luo ban song,leupeullesilobaengsong,lw plsy rwbnswn,Ле Плеси Робенсон,Ле-Плесси-Робенсон,Ле-Плесси-Робинсон,Ле-Плессі-Робенсон,لو پلسی روبنسون,ル・プレシ＝ロバンソン,勒普莱西罗班松,르플레시로뱅송', 48.7888900, 2.2707800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53780, 'Le Plessis-Pâté', 'Le Plessis-Pate', 'Le Plessis-Paste,Le Plessis-Pasté,Le Plessis-Pate,Le Plessis-Pâté,Le-Plessi-Pate,Plessis-Pate,Plessis-Paté,lai pu lai xi pa te,Ле-Плесси-Пате,Ле-Плессі-Пате,莱普莱西帕特', 48.6107800, 2.3231800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53781, 'Le Plessis-Macé', 'Le Plessis-Mace', 'Le Plessis-Mace,Le Plessis-Macé,Le-Plessi-Mase,lei pu lai xi ma sai,Ле-Плессі-Масе,勒普莱西马塞', 47.5430400, -0.6743600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53782, 'Le Plessis-Grammoire', 'Le Plessis-Grammoire', 'Le Plessis,Le Plessis-Grammoire,Le-Plessi-Grammuar,lei pu lai xi ge la mu wa er,Ле-Плессі-Граммуар,勒普莱西格拉穆瓦尔', 47.4988400, -0.4302100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53783, 'Le Plessis-Brion', 'Le Plessis-Brion', 'Le Plessis-Brion,Le-Plessi-Brion,lei pu lai xi bu li weng,Ле-Плессі-Бріон,勒普莱西布里翁', 49.4641900, 2.8909600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53784, 'Le Plessis-Bouchard', 'Le Plessis-Bouchard', 'Le Plessis-Bouchard,Le-Plessi-Bushar,Plessis-Bouchard,lei pu lai xi bu sha er,Ле-Плесси-Бушар,Ле-Плессі-Бушар,勒普莱西布沙尔', 49.0000000, 2.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53785, 'Le Plessis-Belleville', 'Le Plessis-Belleville', '', 49.0950100, 2.7561400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53786, 'Le Pizou', 'Le Pizou', 'Le Pizou,Le-Pizu,Lo Pison,Pizou,lei pi zu,Ле-Пизу,Ле-Пізу,勒皮祖', 45.0166700, 0.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53787, 'Le Pin-en-Mauges', 'Le Pin-en-Mauges', 'Le Pin,Le Pin-en-Mauges,Le-Pen-an-Mozh,mo re de qu lei pan,Ле-Пен-ан-Мож,ル・パン＝アン＝モージュ,莫热地区勒潘', 47.2535700, -0.8991700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53788, 'Le Pin', 'Le Pin', 'Le Pin', 48.9152300, 2.6284100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53789, 'Le Pin', 'Le Pin', 'Le Pin', 46.8617900, -0.6544000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53790, 'Le Pin', 'Le Pin', 'Le Pin', 45.4558200, 5.5049700, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53791, 'Le Pian-Médoc', 'Le Pian-Medoc', 'Le Pian,Le Pian-Medoc,Le Pian-Médoc,Le Pian-en-Medoc,Le Pian-en-Médoc', 44.9553700, -0.6622700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53792, 'Le Petit-Quevilly', 'Le Petit-Quevilly', 'Le Peti Keviji,Le Petit-Quevilly,Le Pti Keviji,Le-Peti-Kevilli,Petit-Quevilly,Quevilly le Petit,leupeutikebi,lw pwty kwwyyy,Ле Пти Кевији,Ле-Пети-Кевилли,Ле-Петі-Кевіллі,لو پوتی کووییی,ル・プティ＝ケヴィイー,르프티케비', 49.4133800, 1.0615500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53793, 'Petit-Couronne', 'Petit-Couronne', 'La Fraternite,La Fraternité', 49.3833300, 1.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53794, 'Le Pertre', 'Le Pertre', 'Ar Perzh,Le Pertre,Le-Pertr,Pertre,Pertrum,lei pei er te er,Ле-Пертр,勒佩尔特尔', 48.0337300, -1.0373500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53795, 'Le Perrier', 'Le Perrier', 'Le Perrier', 46.8193200, -1.9930600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53796, 'Le Perreux-sur-Marne', 'Le Perreux-sur-Marne', 'Le Pere sir Marn,Le-Perre-sjur-Marn,Perreux-Sur-Marne,le Perreux,leupeloeswileumaleun,lw prw-swr-mrn,lw pwrw swr mrn,ma en he pan lai pei er lei,Ле Пере сир Марн,Ле-Перре-сюр-Марн,לה-פרו-סור-מארן,لو پرو-سور-مرن,لو پورو سور مرن,ル・ペルー＝シュル＝マルヌ,马恩河畔莱佩尔勒,르페뢰쉬르마른', 48.8500000, 2.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53797, 'Le Perréon', 'Le Perreon', 'Le Perreon,Le Perréon', 46.0631200, 4.6020500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53798, 'Le Perray-en-Yvelines', 'Le Perray-en-Yvelines', 'Le Perray,Le Perray-en-Yvelines,Le-Perre-an-Ivelin,Le-Perre-an-Ivlin,Ле-Перре-ан-Івлін,Ле-Перре-ан-Ивелин', 48.6944100, 1.8564300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53799, 'Le Pellerin', 'Le Pellerin', 'Le Pellerin,Le-Pel''ren,Pentellou,Pentelloù,Pontellus,Port-Brutus,lei pei lei lan,Ле-Пельрен,ル・ペルラン,勒佩勒兰', 47.1991500, -1.7551400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53800, 'Le Pecq', 'Le Pecq', 'Le Pecq,Le Pecq-sur-Seine,Le-Pek,Pecq,Ле-Пек,ル・ペック', 48.8931700, 2.1037100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53801, 'Le Pêchereau', 'Le Pechereau', 'Le Pechereau,Le Pêchereau,Le-Peshero,Pechereau,Pêchereau,lei pei xie luo,Ле-Пешеро,勒佩谢罗', 46.5767700, 1.5474300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53802, 'Le Péage-de-Roussillon', 'Le Peage-de-Roussillon', 'Franc-Passage,Franc-Peage,Franc-Péage,Le Peage,Le Peage-de-Roussillon,Le Péage,Le Péage-de-Roussillon', 45.3717900, 4.7979100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53803, 'Le Passage', 'Le Passage', 'Le Passage,Passage,Passage d''Agen,Passage d’Agen', 44.2014300, 0.6027500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53804, 'Le Pallet', 'Le Pallet', 'Ar Palez,Le Pallet,Le-Palle,Palacium,l barkf,lei pa lai,Ле-Палле,ل بارکف,勒帕莱', 47.1380900, -1.3347600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53805, 'Le Palais-sur-Vienne', 'Le Palais-sur-Vienne', 'Le Palais,Le Palais-sur-Vienne,Lu Palaic,Lu Palaiç', 45.8638000, 1.3220700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53806, 'Le Palais', 'Le Palais', 'Le Palais,Le-Pale,Palais,Porzh-Lae,lei pa lai,Ле-Пале,ル・パレ,勒帕莱', 47.3455700, -3.1541100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53807, 'Léon', 'Leon', 'Leon,Léon', 43.8767600, -1.3005700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53808, 'Léognan', 'Leognan', 'Leognan,Leon''jan,Leonhan,Leunhan,Léognan,lai ao ni ang,Леоньян,莱奥尼昂', 44.7354800, -0.5973800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53809, 'Lentilly', 'Lentilly', 'Lantii,Lentilly,Лантії', 45.8198400, 4.6635200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53810, 'Lentigny', 'Lentigny', 'Lentigny', 45.9959600, 3.9816300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53811, 'Lent', 'Lent', 'Lent', 46.1203200, 5.1936900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53812, 'Lens', 'Lens', 'Lens,XLE,lans,ransu,Ланс,ランス', 50.4330200, 2.8279100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53813, 'Le Nouvion-en-Thiérache', 'Le Nouvion-en-Thierache', 'Le Nouvion,Le Nouvion-en-Thierache,Le Nouvion-en-Thiérache,Le Nouvion-le-Franc', 50.0162500, 3.7850900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53814, 'Le Neubourg', 'Le Neubourg', 'Le Neubourg,Le-Nebur,lei na bu er,Ле-Небур,勒纳布尔', 49.1504800, 0.9102000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53815, 'Lencloître', 'Lencloitre', 'Lankluatr,Lencloitre,Lencloître,lang ke lu wa te lei,Ланклуатр,朗克卢瓦特勒', 46.8162200, 0.3282700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53816, 'Le Muy', 'Le Muy', 'Le Muy,Le-Mjui,Lo Mueg,Lo Muei,l mwyy,lei mi yi,Ле-Мюи,Ле-Мюї,ل مویی,勒米伊', 43.4738100, 6.5645200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53817, 'Lempdes-sur-Allagnon', 'Lempdes-sur-Allagnon', '', 45.3833300, 3.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53818, 'Mont-Dore', 'Mont-Dore', 'Le Mont-Dore,Les Bains-du-Mont-Dore,Les Bains-du-Montdor,Mon-Dor,Mont-Dore,Mont-Dore-les-Bains,Montdaur,meng duo er,mon=doru,Мон-Дор,モン＝ドール,蒙多尔', 45.5666700, 2.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53819, 'Le Monêtier-les-Bains', 'Le Monetier-les-Bains', 'Le Monetier,Le Monetier-les-Bains,Le Monétier,Le Monêtier,Le Monêtier-les-Bains,Le-Monet''e-le-Ben,Lo Monastier,Lo Monastièr,Lo Monestier de Briancon,Lo Monestièr de Briançon,lei mo nei di ye lai ban,Ле-Монетье-ле-Бен,Ле-Монетьє-ле-Бен,勒莫内蒂耶莱班', 44.9756500, 6.5067100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53820, 'Le Monastier-sur-Gazeille', 'Le Monastier-sur-Gazeille', 'Le-Monast''e-sjur-Gazej,Lo Monestier,Lo Monestier de Gaselha,Monastier,Mont-Breysse,jia ze er he pan lei mo na si di ye,Ле-Монастье-сюр-Газей,Ле-Монастьє-сюр-Газей,ル・モナスティエ＝シュル＝ガゼイユ,加泽尔河畔勒莫纳斯蒂耶', 44.9333300, 4.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53821, 'Le Monastère', 'Le Monastere', 'Bourg-la-Briane,Le Monastere,Le Monastère', 44.3416500, 2.5795600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53822, 'Le Molay-Littry', 'Le Molay-Littry', 'La Molay,Le Molay,Le Molay-Littry,Le-Mole-Litri,Le-Mole-Littri,Littry,lei mo lai li te li,Ле-Моле-Литри,Ле-Моле-Литтри,Ле-Моле-Літтрі,勒莫莱利特里', 49.2426500, -0.8723800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53823, 'Le Minihic-sur-Rance', 'Le Minihic-sur-Rance', 'Le Minihic,Le Minihic-sur-Rance,Le-Miniik-sjur-Rans,Minic''hi-Poudour,Minichi-Poudour,lang ke he pan lei mi ni yi ke,Ле-Миниик-сюр-Ранс,Ле-Мініїк-сюр-Ранс,朗克河畔勒米尼伊克', 48.5783500, -2.0087600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53824, 'Le Meux', 'Le Meux', 'Le Meux,Le-Me,Meux,lei mo,Ле-Ме,勒默', 49.3671800, 2.7437400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53825, 'Le Mesnil-sur-Oger', 'Le Mesnil-sur-Oger', 'Le Mesnil,Le Mesnil-sur-Oger,Le-Menij-sjur-Ozhe,Mesnil-sur-Oger,ao re he pan lei mei si ni,Ле-Меній-сюр-Оже,奥热河畔勒梅斯尼', 48.9470800, 4.0226300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53826, 'Le Mesnil-Saint-Denis', 'Le Mesnil-Saint-Denis', 'Le Mesnil-Saint-Denis,Le-Menij-Sen-Deni,Ле-Меній-Сен-Дені', 48.7448500, 1.9559400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53827, 'Le Mesnil-le-Roi', 'Le Mesnil-le-Roi', 'Le Mesnil,Le Mesnil-le-Roi,Le-Menij-le-Rua,Mesnil-Carrieres,Mesnil-Carrières,Ле-Мений-ле-Руа,Ле-Меній-ле-Руа', 48.9382500, 2.1255400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53828, 'Le Mesnil-Esnard', 'Le Mesnil-Esnard', 'Le Mesnil-Esnard,Le-Menij-Enar,Mesnil-Esnard,Ле-Мений-Енар,Ле-Меній-Енар', 49.4131900, 1.1452100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53829, 'Le Mesnil-en-Vallée', 'Le Mesnil-en-Vallee', 'Le Mesnil,Le Mesnil-en-Vallee,Le Mesnil-en-Vallée,Le-Menij-an-Valle,wa lai ai de qu lei mei si ni,Ле-Меній-ан-Валле,瓦莱埃地区勒梅斯尼', 47.3655100, -0.9348500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53830, 'Le Mesnil-en-Thelle', 'Le Mesnil-en-Thelle', 'Le Mesnil,Le Mesnil-en-Thelle', 49.1783000, 2.2857300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53831, 'Le Ménil', 'Le Menil', 'Le Menil,Le Ménil,Le-Menij,Menil-Thillot,Ménil-Thillot,lai mo ni,Ле-Мений,Ле-Меній,莱默尼', 47.9047700, 6.7820900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53832, 'Le Mée-sur-Seine', 'Le Mee-sur-Seine', 'Le Me sir Sen,Le Mee,Le Mee-sur-Seine,Le Mée,Le Mée-sur-Seine,Le-Me-sjur-Sen,Mee-sur-Seine,Mée-sur-Seine,leumeswileusen,lwmh swr sn,Ле Ме сир Сен,Ле-Ме-сюр-Сен,لومه سور سن,ル・メ＝シュル＝セーヌ,르메쉬르센', 48.5315700, 2.6282900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53833, 'Lembras', 'Lembras', 'Lembras', 44.8843100, 0.5265700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53834, 'Lemberg', 'Lemberg', 'Lemberg', 49.0027800, 7.3797600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53835, 'Lembach', 'Lembach', 'Laembach,Lambak,Lembach,Lämbàch,lang ba ke,lmbakh,lymbatsh,Ламбак,لمباخ,ليمباتش,朗巴克', 49.0036200, 7.7898600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53836, 'Le May-sur-Èvre', 'Le May-sur-Evre', 'Le May,Le May-sur-Evre,Le May-sur-Èvre,Le-Me-sjur-Evr,May-sur-Evre,May-sur-Èvre,ai fu er he pan lei mai,Ле-Ме-сюр-Евр,埃夫尔河畔勒迈', 47.1371400, -0.8922700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53837, 'Le Mayet-de-Montagne', 'Le Mayet-de-Montagne', 'Le Mayet-de-Montagne,Le-Mae-de-Montan'',Le-Maje-de-Montan'',Lo Maiet de Montanha,Mayet-de-Montagne,lei mai ai de meng ta ni,Ле-Мае-де-Монтань,Ле-Майе-де-Монтань,Ле-Має-де-Монтань,勒迈埃德蒙塔尼', 46.0725100, 3.6665100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53838, 'Le Mans', 'Le Mans', 'Ar Mans,Ar Mañs,Cenomanum,L''Unite-sur-Sarthe,L''Unité-sur-Sarthe,L''o Man,LME,Le Man,Le Manas,Le Mans,Le-Man,Lemana,Lemāna,Lo Mans,le mam,le-mani,lei mang,leumang,lw man,lwman,ly mans,lya mamsa,Ле Ман,Ле-Ман,Льо Ман,לה מאן,لو مان,لومان,لی مانس,ले मां,ল্য মঁস,ლე-მანი,ル・マン,勒芒,르망', 48.0000000, 0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53839, 'Le Manoir', 'Le Manoir', 'Le Manoir', 49.3135500, 1.2045500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53840, 'Le Malzieu-Ville', 'Le Malzieu-Ville', 'Le Malzieu,Le Malzieu-Ville,Le-Mal''z''e-Vil'',Lo Malasiu,Malzieu,Malzieu-Ville,lei ma er qi e wei er,Ле-Мальзье-Виль,Ле-Мальзьє-Віль,勒马尔齐厄维尔', 44.8569900, 3.3330200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53841, 'Le Lude', 'Le Lude', 'Le-Ljud,Ле-Люд', 47.6464800, 0.1566400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53842, 'Le Luc', 'Le Luc', 'Le Luc,Le-Ljuk,Lo Luc,l lwk,lei lu ke,Ле-Люк,ل لوک,勒吕克', 43.3931800, 6.3147400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53843, 'Le Luart', 'Le Luart', 'Le Luart', 48.0705300, 0.5856400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53844, 'Le Louroux-Béconnais', 'Le Louroux-Beconnais', 'Le Louroux,Le Louroux-Beconnais,Le Louroux-Béconnais,Le-Luru-Bekonne,lei lu lu bei ke nai,Ле-Луру-Беконне,勒卢鲁贝科奈', 47.5221100, -0.8866300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53845, 'Le Loroux-Bottereau', 'Le Loroux-Bottereau', 'Al Lavreer-Botorel,Lavreer-Botorel,Le Loroux-Bottereau,Le Louroux-Bottereau,Le-Loru-Bottero,Oratorium Boterelli,lei luo lu bo te luo,Ле-Лору-Боттеро,勒洛鲁博特罗', 47.2376300, -1.3495200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53846, 'Le Longeron', 'Le Longeron', 'Le Longeron', 47.0184500, -1.0576300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53847, 'Le Lavandou', 'Le Lavandou', 'Le-Lavandu,Lo Lavandor,lai la wang du,Ле-Лаванду,莱拉旺杜', 43.1370000, 6.3660000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53848, 'Le Langon', 'Le Langon', 'Le Langon', 46.4385000, -0.9476700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53849, 'Le Landreau', 'Le Landreau', 'Lannerell,Le Landreau,Le-Landro,lei lang de luo,Ле-Ландро,勒朗德罗', 47.2051200, -1.3045200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53850, 'Le Kremlin-Bicêtre', 'Le Kremlin-Bicetre', 'Kremlin-Bicetre,Kremlin-Bicêtre,La Kremlen Bisetr,Le Kremlin-Bicetre,Le Kremlin-Bicêtre,Le-Kremlen-Bisetr,lai ke lang lan bi sai te er,leukeulemeullaengbiseteuleu,lw krmln-bystr,lw krwln-bystr,Ла Кремлен Бисетр,Ле-Кремлен-Бисетр,Ле-Кремлен-Бісетр,لو کرملن-بیستر,لو کرولن-بیستر,ル・クレムラン＝ビセートル,莱克朗兰比塞特尔,르크레믈랭비세트르', 48.8147100, 2.3607300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53851, 'Le Houlme', 'Le Houlme', 'Le Houlme', 49.5097200, 1.0353700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53852, 'Le Houga', 'Le Houga', 'La Moule,Le Houga', 43.7746400, -0.1783300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53853, 'Léhon', 'Lehon', 'Lehon,Lehonium,Leon,Léhon,lai weng,Леон,莱翁', 48.4443200, -2.0457800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53854, 'Le Havre', 'Le Havre', 'An Havr Nevez,An Havr-Nevez,Avr,Chabre,El Havre,Franciscopolis,Gavr,Gorad Gaur,Grasville-Lheure,Havr,Havra,Havras,Havre,Havro,Hawr,Khavur,LEH,La Havro,Le Havre,Le port de Grace,Le port de Grâce,Lé Hâvre,O Havre,Saint-Jean-sur-Mer,havri,la avra,le avar,lei a fu er,leuabeuleu,lex xafwr,lh hbr,lw awr,lw hafr,xia hua,Χάβρη,Авр,Гавр,Горад Гаўр,Хавър,Հավր,לה הבר,لو آور,لو اور,لو هافر,لی ہاور,ला आव्र,லே ஆவர்,เลออาฟวร์,ჰავრი,ル・アーヴル,勒阿弗尔,夏華,르아브르', 49.4938000, 0.1076700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53855, 'Le Haillan', 'Le Haillan', 'Halhan,Le Haillan,Le-Ajan,lei ai lang,Ле-Аян,勒艾朗', 44.8722500, -0.6796500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53856, 'Léguevin', 'Leguevin', 'Legavin,Legeven,Leguevin,Léguevin,lai gai wan,Легевен,莱盖万', 43.6002800, 1.2323600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53857, 'Le Gua', 'Le Gua', 'Le Gua', 45.7261400, -0.9446800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53858, 'Le Gua', 'Le Gua', '', 45.0166700, 5.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53859, 'Le Grau-du-Roi', 'Le Grau-du-Roi', 'Grau-le-Peletier,La Grau du Roi,Le Grau-du-Roi,Le-Gro-dju-Rua,Lo Grau dau Rei,Lo Grau dau Rèi,lei ge luo di lu wa,Ле-Гро-дю-Руа,勒格罗迪鲁瓦', 43.5388100, 4.1355900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53860, 'Le Grand-Quevilly', 'Le Grand-Quevilly', 'Gran-Kevilli,Grand-Quevilly,Le Gran Keviji,Le Grand-Quevilly,Le-Gran-Kevilli,Quevilly le Grand,leugeulangkebi,lw grand kwyy,Гран-Кевилли,Ле Гран Кевији,Ле-Гран-Кевилли,Ле-Гран-Кевіллі,لو گراند کویی,ル・グラン＝ケヴィイー,르그랑케비', 49.4007600, 1.0458200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53861, 'Le Grand-Pressigny', 'Le Grand-Pressigny', 'Grand-Pressigny,Le Grand,Le Grand-Pressigny,Le-Gran-Presin''i,Le-Gran-Pressin''i,Prisciniacus,lei ge lang pu lei xi ni,Ле-Гран-Пресиньи,Ле-Гран-Прессіньї,勒格朗普雷西尼', 46.9201700, 0.8038000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53862, 'Le Grand-Lucé', 'Le Grand-Luce', 'Grand-Luce,Le Grand-Luce,Le Grand-Lucé', 47.8661800, 0.4691900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53863, 'Le Grand-Lemps', 'Le Grand-Lemps', 'Grand-Lemps,Le Grand-Lemps,Le-Gran-Lan,Le-Gran-Lem,lei ge lang lang pu,Ле-Гран-Лан,Ле-Гран-Лем,勒格朗朗普', 45.3978900, 5.4221500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53864, 'Le Grand-Bourg', 'Le Grand-Bourg', 'Grand Bourg,Le Borg,Le Grand-Bourg,Le-Gran-Bur,Salanhac,lei ge lang bu er,Ле-Гран-Бур,勒格朗布尔', 46.1601800, 1.6446500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53865, 'Le Grand-Bornand', 'Le Grand-Bornand', 'Bornantium Anniciense,Grand Bornand,Grand-Bornand,Le Grand-Bornand,Le-Gran-Bornan,Ле-Гран-Борнан', 45.9434600, 6.4411100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53866, 'Gond-Pontouvre', 'Gond-Pontouvre', 'Gon Pontuvr,Gon-Pontuvr,Gond-Pontuvr,Le Gond,gong peng tu fu er,Гон Понтувр,Гон-Понтувр,Гонд-Понтувр,贡蓬图夫尔', 45.6833300, 0.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53867, 'Legé', 'Lege', 'Lege,Legé,Levieg,Lezhe,lai re,ruje,Леже,ルジェ,莱热', 46.8848400, -1.6012700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53868, 'Le Gâvre', 'Le Gavre', 'Ar Chavr,Gavr,Gavre,Gâvre,Le Gavre,Le Gâvre,Le-Gavr,lei jia fu er,Гавр,Ле-Гавр,勒加夫尔', 47.5213100, -1.7490500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53869, 'Le Garric', 'Le Garric', 'Le Garric', 44.0093200, 2.1643100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53870, 'Le Fuilet', 'Le Fuilet', 'Faiacus,Le Fuilet,Le Fuillet,Le-Fjuie,lei fei yi lai,Ле-Фюїє,ル・フュイレ,勒菲伊莱', 47.2834500, -1.1131000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53871, 'Le Fousseret', 'Le Fousseret', 'Le Fousseret', 43.2820500, 1.0662400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53872, 'Leforest', 'Leforest', 'Lefore,Lefores,Leforest,lei fu lei,lyfwryst,Лефоре,Лефорес,ليفوريست,勒福雷', 50.4386600, 3.0648000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53873, 'Le Folgoët', 'Le Folgoet', 'Ar Folgoad,Folgoet,Folgoët,Le Folgoet,Le Folgoët,Le-Fol''goe,lei fu er ge e,Ле-Фольгое,勒福尔戈厄', 48.5635900, -4.3364100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53874, 'Le Fœil', 'Le Foeil', 'Ar Fouilh,Le Foeil', 48.4333300, -2.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53875, 'Le Fleix', 'Le Fleix', 'Fleix,Le Fleix,Le-Fle,Lo Fleis,Lo Flèis,lei fu lai,Ле-Фле,勒夫莱', 44.8666700, 0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53876, 'Le Fief-Sauvin', 'Le Fief-Sauvin', 'Fief Sauvin,Le Fief-Sauvin,Le-Fef-Soven,lei fei ye suo wan,Ле-Фєф-Совен,勒菲耶索万', 47.2214300, -1.0421400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53877, 'Leffrinckoucke', 'Leffrinckoucke', 'Leffrenkuk,Leffrinckoucke,Leffrinkhoeke,Leffrinkhoucke,Leffrinkoeke,lai fu lan ke wu ke,Леффренкук,莱夫兰克乌克', 51.0345700, 2.4645200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53878, 'Le Fenouiller', 'Le Fenouiller', 'Le Fenouiller,Le-Fenue,lei fang wu yi lai,Ле-Фенує,勒方乌伊莱', 46.7190100, -1.9017500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53879, 'Le Fauga', 'Le Fauga', 'Fauga,La Fauga,Le Fauga', 43.3961900, 1.2957100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53880, 'Le Faouët', 'Le Faouet', 'Ar Faoued,Le Faouet,Le Faouët', 48.0329900, -3.4904800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53881, 'Le Faou', 'Le Faou', 'Ar Faou,Faou,Le Faou', 48.2945600, -4.1792700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53882, 'Leers', 'Leers', 'Leer,Leers,Lers,lai er,Леер,Лерс,莱尔', 50.6821700, 3.2442900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53883, 'Le Drennec', 'Le Drennec', 'An Dreneg,Dranak,Drennec,Le Drennec,Le-Drennek,lei de lei nei ke,Дранак,Ле-Дреннек,勒德雷内克', 48.5347500, -4.3700800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53884, 'Le Doulieu', 'Le Doulieu', 'Le Doulieu', 50.6819400, 2.7174100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53885, 'Le Dorat', 'Le Dorat', 'Dora,Dorat,Le Daurat,Le Dorat,Le-Dora,Lo Daurat,lei duo la,Дора,Ле-Дора,勒多拉', 46.2151400, 1.0815300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53886, 'Le Donjon', 'Le Donjon', 'Donjon,Donzhon,Le Donjon,Le-Donzhon,Val-libre,lei dong rong,Донжон,Ле-Донжон,勒东容', 46.3506200, 3.7950600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53887, 'Lédignan', 'Ledignan', 'Ledignan,Ledin''jan,Ledinhan,Lédignan,lai di ni ang,Лединьян,Ледіньян,莱迪尼昂', 43.9869000, 4.1064400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53888, 'Ledeuix', 'Ledeuix', 'Laduish,Ledeiks,Ledeuix,Ledjoish,lei de yi,Ледеикс,Ледеікс,Ледёиш,勒德伊', 43.2166700, -0.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53889, 'Lédenon', 'Ledenon', 'Ledenon,Lédenon,lai dang weng,Леденон,莱当翁', 43.9134900, 4.5144400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53890, 'Lectoure', 'Lectoure', 'Lactora,Lectoure,Leitora,Lektur,lai ke tu er,Лектур,莱克图尔', 43.9346400, 0.6210700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53891, 'Le Crotoy', 'Le Crotoy', 'Corocotinum,Crotoy,Krotoa,L''Crotoe,Le-Krotua,L’Crotoé,lei ke luo tu wa,Кротоа,Ле-Кротуа,ル・クロトワ,勒克罗图瓦', 50.2160000, 1.6250000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53892, 'Le Croisic', 'Le Croisic', 'Ar Groazig,Crociciacum,Croisic,Kroazik,Le Croisic,Le-Kruazik,krwasyk,lei ke lu wa xi ke,Кроазик,Ле-Круазік,کرواسیک,勒克鲁瓦西克', 47.2918900, -2.5138000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53893, 'Le Creusot', 'Le Creusot', 'Creusot,Kryozo,Le Creusot,Le Krezo,Le-Krezo,Le-Krjozo,lei ke lei zuo,leukeuloejo,lw krwzw,ru・kuruzo,Ле Крезо,Ле-Крезо,Ле-Крёзо,Կրյոզո,لو کروزو,ル・クルーゾ,勒克勒佐,르크뢰조', 46.8071400, 4.4163200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53894, 'Le Crest', 'Le Crest', 'Le Crest', 45.6868700, 3.1284400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53895, 'Le Crès', 'Le Cres', 'Le Cres,Le Crès', 43.6480700, 3.9397600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53896, 'Lécousse', 'Lecousse', 'Eskuz,Lecousse,Lécousse', 48.3645800, -1.2128900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53897, 'Le Coudray-Montceaux', 'Le Coudray-Montceaux', 'Coudray-Montceaux,Le Coudray-Montceaux,Le-Kudre-Monso,lei ku de lai meng te ke,Ле-Кудре-Монсо,勒库德赖蒙特科', 48.5637600, 2.5001300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53898, 'Le Coudray', 'Le Coudray', 'Le Coudray', 48.4211500, 1.5005700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53899, 'Le Coteau', 'Le Coteau', 'Le Coteau,Le-Koto,l kwtaw,lei ke tuo,lwkwtw,Ле-Кото,ل کوتاو,لوكوتو,勒科托', 46.0270600, 4.0869000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53900, 'Le Conquet', 'Le Conquet', 'Concue,Conquestus,Conquet,Konge,Konk-Leon,Le Concue,Le Conque,Le Conquet,Le-Konke,lei kong qu ai,Конге,Ле-Конке,ル・コンケ,勒孔屈埃', 48.3605300, -4.7708600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53901, 'Lécluse', 'Lecluse', 'Lecluse,Lécluse', 50.2767100, 3.0404500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53902, 'Le Cheylas', 'Le Cheylas', 'Cheylas,Le Cheylas,Le-Shejla,Le-Shelas,Shela,lei xie la,Ле-Шейла,Ле-Шелас,Шела,勒谢拉', 45.3736900, 5.9937600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53903, 'Le Cheylard', 'Le Cheylard', 'Cheylard,Le Cheylard,Le-Shejlar,Le-Shelar,Lo Chailar,Shelar,lei xie la er,Ле-Шейлар,Ле-Шелар,Шелар,勒谢拉尔', 44.9062300, 4.4240600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53904, 'Le Chesnay', 'Le Chesnay', 'Le Chesnay,Le Chesney,Le Shene,Le-Shene,lei xie nai,leusyene,lw shznh,Ле Шене,Ле-Шене,لو شزنه,ル・シェネ,勒謝奈,르셰네', 48.8222000, 2.1221300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53905, 'Le Châtelet-en-Brie', 'Le Chatelet-en-Brie', 'Le Chatelet,Le Chatelet-en-Brie,Le Châtelet,Le Châtelet-en-Brie', 48.5069500, 2.7916300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53906, 'Le Châtelet', 'Le Chatelet', 'Le Chatelet,Le Châtelet,Librefeuille', 46.6424700, 2.2822900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53907, 'Le Champ-Saint-Père', 'Le Champ-Saint-Pere', 'Champ-Perdu,Champ-Saint-Pere,Champ-Saint-Père,Le Champ,Le Champ-Saint-Pere,Le Champ-Saint-Père,Le-Sham-Sen-Per,Shan Sen Per,lei shang sheng pei lei,Ле-Шам-Сен-Пер,Шан Сен Пер,勒尚圣佩勒', 46.5077300, -1.3472600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53908, 'Le Champ-près-Froges', 'Le Champ-pres-Froges', 'Champ-pres-Froges,Champ-près-Froges,Le Champ,Le Champ-Pres Forges,Le Champ-Près Forges,Le Champ-pres-Froges,Le Champ-près-Froges,Le-Sham-pre-Frozh,Shan pre Frozh,lei shang pu lei fu luo re,Ле-Шам-пре-Фрож,Шан пре Фрож,勒尚普雷弗罗热', 45.2810500, 5.9396600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53909, 'Le Chambon-sur-Lignon', 'Le Chambon-sur-Lignon', 'Chambon-sur Lignon,Chambon-sur-Lignon,Le Chambon,Le Chambon-sur-Lignon,Le-Shambon-sjur-Lin''on,Lo Chambon,Shambon sir Linon,Shambon-sjur-Lin''on,lh smbwn-swr-lynywn,li ni weng he pan lei shang bang,Ле-Шамбон-сюр-Линьон,Ле-Шамбон-сюр-Ліньон,Шамбон сир Лињон,Шамбон-сюр-Линьон,לה שמבון-סור-ליניון,利尼翁河畔勒尚邦', 45.0607900, 4.3031400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53910, 'Le Chambon-Feugerolles', 'Le Chambon-Feugerolles', 'Chambon-Feugerolles,Le Chambon,Le Chambon-Feugerolles,Le-Shambon-Fezherol'',Shambon Fezherol,lei shang bang fu re luo lai,Ле-Шамбон-Фежероль,Шамбон Фежерол,勒尚邦弗热罗莱', 45.3968900, 4.3259200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53911, 'Le Chambon', 'Le Chambon', '', 44.8666700, 4.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53912, 'Le Cendre', 'Le Cendre', 'Au Sandre,Cendre,Le Cendre,Le-Sandr,Sandr,lei sang de er,Ле-Сандр,Сандр,勒桑德尔', 45.7211800, 3.1883900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53913, 'Le Cellier', 'Le Cellier', 'Cellarium,Cellier,Keller,Le Cellier,Le-Sel''e,Selije,lei se li ye,Ле-Сельє,Селије,勒瑟利耶', 47.3198800, -1.3458400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53914, 'Lecelles', 'Lecelles', 'Lecelles', 50.4677900, 3.4009600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53915, 'Le Castellet', 'Le Castellet', 'CTT,Le Castellet', 43.2028500, 5.7764200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53916, 'Le Cap d''Agde', 'Le Cap d''Agde', 'Kap D Agd,Le Cap D''Agde,Кап Д Агд', 43.2779600, 3.5135700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53917, 'Le Cannet-des-Maures', 'Le Cannet-des-Maures', 'Cannet-des-Maures,Kane de Mor,Le Cannet,Le Cannet-des-Maures,Le-Kanne-de-Mor,Lo Canet dau Luc,Lo Canet dei Mauras,lai ka na dai mo lei,Кане де Мор,Ле-Канне-де-Мор,莱卡纳代莫勒', 43.3927200, 6.3416500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53918, 'Le Cannet', 'Le Cannet', 'Cannet,Kane,Le Cannet,Le-Kanne,Lo Canet,lei ka nei,lw knh,Кане,Ле-Канне,لو کنه,ル・カネ,勒卡內', 43.5766200, 7.0191200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53919, 'Le Cailar', 'Le Cailar', 'Cailar,Kajar,Le Cailar,Le-Kajar,Lo Cailar,lei kai la,Кајар,Ле-Каяр,勒凯拉', 43.6792300, 4.2357600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53920, 'Le Bugue', 'Le Bugue', 'Albuga,Aubuga,Le-Bjug,lei bi gai,Ле-Бюг,勒比盖', 44.9184700, 0.9271400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53921, 'Le Brusquet', 'Le Brusquet', 'Le Brusquet,Le-Brjuske,Lo Brusquet,lei bu lu si qu ai,Ле-Брюске,勒布吕斯屈埃', 44.1614300, 6.3114300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53922, 'Le Broc', 'Le Broc', 'Le Broc', 43.8084300, 7.1692800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53923, 'Le Breuil-sur-Couze', 'Le Breuil-sur-Couze', 'Le Breuil,Le Breuil-sur-Couze', 45.4688600, 3.2634400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53924, 'Le Breuil', 'Le Breuil', 'Le Breuil', 46.8065400, 4.4695300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53925, 'Le Breil-sur-Mérize', 'Le Breil-sur-Merize', 'Le Breil,Le Breil-sur-Merize,Le Breil-sur-Mérize', 48.0075500, 0.4780800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53926, 'Le Bouscat', 'Le Bouscat', 'Bouscat,Le Bouscat,Le Buka,Le-Buska,Le-Buskat,Lo Boscat,lei bu si ka,leubuseuka,lw bwska,Ле Бука,Ле-Буска,Ле-Бускат,لو بوسکا,ル・ブスカ,勒布斯卡,르부스카', 44.8660000, -0.5941100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53927, 'Le Bourgneuf-la-Forêt', 'Le Bourgneuf-la-Foret', 'Le Bourgneuf,Le Bourgneuf-la-Foret,Le Bourgneuf-la-Forêt', 48.1632500, -0.9696300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53928, 'Le Bourget-du-Lac', 'Le Bourget-du-Lac', 'Bourget-du-Lac,Burzhe di Lak,Le Bourget,Le Bourget-du-Lac,Le-Burzhe-dju-Lak,Monterminod,Бурже ди Лак,Ле-Бурже-дю-Лак', 45.6475600, 5.8608500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53929, 'Le Bourget', 'Le Bourget', 'Bourget,Le Bourget', 48.9340500, 2.4358400, 'FR', '2016-03-30', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53930, 'Le Boupère', 'Le Boupere', 'Boupere,Boupère,Buper,Le Boupere,Le Boupère,Le-Buper,lai bu pei lei,Бупер,Ле-Бупер,莱布佩勒', 46.7959500, -0.9265400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53931, 'el Voló', 'el Volo', 'Le Boulou,el Volo,el Voló', 42.5242400, 2.8333600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53932, 'Le Bosc-Roger-en-Roumois', 'Le Bosc-Roger-en-Roumois', 'Bosc-Roger-en-Roumois,Boscroger,Le Bosc-Roger,Le Bosc-Roger-en-Roumois', 49.2833300, 0.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53933, 'Le Bono', 'Le Bono', 'Ar Bonou,Ar Bonoù,Bono,Le Bono', 47.6412900, -2.9490200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53934, 'Le Bois-Plage-en-Ré', 'Le Bois-Plage-en-Re', 'Boa Plazh an Re,Bois-Plage-en-Re,Bois-Plage-en-Ré,La Verite,La Vérité,Le Bois,Le Bois Plage,Le Bois-Plage-en-Re,Le Bois-Plage-en-Ré,Le Bua Plaz an Re,Le-Bua-Plazh-an-Re,lei de qu lei bu wa si-pu la ge,Боа Плаж ан Ре,Ле-Буа-Плаж-ан-Ре,Լե Բուա Պլաժ ան Ռե,雷地区勒布瓦斯-普拉格', 46.1865900, -1.3926700, 'FR', '2017-05-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53935, 'Le Blanc-Mesnil', 'Le Blanc-Mesnil', 'Le Blan Menil,Le Blanc-Mesnil,Le-Blan-Menij,Le-Blan-Menil'',lei bu lang-mei ni er,lw blan mznyl,lw blan-mnyl,Ле Блан Менил,Ле-Блан-Мений,Ле-Блан-Мениль,Ле-Блан-Меній,لو بلان مزنیل,لو بلان-منیل,ル・ブラン＝メニル,勒布朗-梅尼尔', 48.9387200, 2.4613800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53936, 'Le Blanc', 'Le Blanc', 'Blanc,Le Blanc', 46.6333300, 1.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53937, 'Le Bignon', 'Le Bignon', 'Bignon,Binon,Bugnonium,Le Bignon,Le-Bin''on,lei bi ni weng,Бињон,Ле-Біньон,勒比尼翁', 47.0972200, -1.4916700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53938, 'Le Beausset', 'Le Beausset', 'Le Beausset,Le-Bose,Le-Bosse,Lo Baucet,lei bo sai,Ле-Босе,Ле-Боссе,勒博塞', 43.1985300, 5.8015500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53939, 'Le Barp', 'Le Barp', 'Le Barp', 44.6083300, -0.7694800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53940, 'Le Barcarès', 'Le Barcares', 'Barcares-de-Saint-Laurent,Barcarès-de-Saint-Laurent,El Barcares,El Barcarès,Le Barcares,Le Barcarès', 42.7877300, 3.0365600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53941, 'Lay-Saint-Christophe', 'Lay-Saint-Christophe', 'Lay,Lay-Saint-Christophe', 48.7486700, 6.1977600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53942, 'Layrac', 'Layrac', 'Layrac', 44.1344900, 0.6617600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53943, 'Laxou', 'Laxou', 'Laksu,Laxou,la ke su,Лаксу,拉克苏', 48.6831500, 6.1479900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53944, 'La Wantzenau', 'La Wantzenau', 'D Wanzenoei,D Wànzenöi,La-Vanceno,Wantzenau,Wanzenau,la wang te ze nuo,la wantzynaw,lawantsnaw,Ла-Ванцено,لا وانتزيناو,لا وانٹزینو,لاوانتسناو,ラ・ヴァンツェノー,拉旺特泽诺', 48.6578600, 7.8306800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53945, 'La Vraie-Croix', 'La Vraie-Croix', 'La Vraie-Croix,La-Vre-Krua,Langroez,Vraie-Croix,la fu lai ai ke lu wa,la wray-krwyy,Ла-Вре-Круа,لا ورای-کروئی,拉夫赖埃克鲁瓦', 47.6895400, -2.5427400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53946, 'Lavoux', 'Lavoux', 'Lavoux', 46.5956600, 0.5301200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53947, 'La Voulte-sur-Rhône', 'La Voulte-sur-Rhone', 'La Voulte,La Voulte-sur-Rhone,La Voulte-sur-Rhône,La Vouta,La Vòuta,La-Vul''t-sjur-Ron,luo ne he pan la wu er te,Ла-Вульт-сюр-Рон,لا وولٹی-سور-رہونی,罗讷河畔拉武尔特', 44.8007200, 4.7716000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53948, 'Lavit', 'Lavit', 'Lavit', 43.9567400, 0.9201000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53949, 'Lavilleneuve-au-Roi', 'Lavilleneuve-au-Roi', 'Lavilleneuve,Lavilleneuve-au-Roi', 48.1599500, 4.9261900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53950, 'La Ville-du-Bois', 'La Ville-du-Bois', 'La Ville-du-Bois,La-Vil''-dju-Bua,Ville-du-Bois,la wei er di bu wa,la wyl-dw-bwyy,Ла-Виль-дю-Буа,Ла-Віль-дю-Буа,لا ویل-دو-بوئی,拉维尔迪布瓦', 48.6552100, 2.2683300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53951, 'La Villedieu-du-Clain', 'La Villedieu-du-Clain', 'La Villedieu,La Villedieu-du-Clain,La-Vil''d''e-dju-Klen,la wei lai di e di ke lan,la wyl dyw-dw-klayn,Ла-Вільдьє-дю-Клен,لا ویل دیو-دو-کلاین,拉维莱迪厄迪克兰', 46.4555900, 0.3691700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53952, 'Lavilledieu', 'Lavilledieu', 'Lavilledieu', 44.5745600, 4.4547000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53953, 'La Ville-aux-Dames', 'La Ville-aux-Dames', 'La Ville,La Ville-aux-Dames,Les Sables', 47.3955100, 0.7683700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53954, 'La Ville-aux-Clercs', 'La Ville-aux-Clercs', 'La Ville,La Ville-Aux-Cleres,La Ville-Aux-Clères,La Ville-aux-Clercs,La Ville-aux-Clers,La-Vil''-o-Kler,la wei er ao ke lai er ke,la wyl-a-klyrks,Ла-Віль-о-Клер,لا ویل-آ-کلیرکس,拉维尔奥克莱尔克', 47.9183500, 1.0852100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53955, 'La Vespière', 'La Vespiere', 'La Vespiere,La Vespière', 49.0197500, 0.4125000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53956, 'Lavérune', 'Laverune', 'La Veruna,Laverjun,Laverune,Lavérune,la wei lan,Лаверюн,拉韦兰', 43.5863900, 3.8061100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53957, 'La Verrière', 'La Verriere', 'La Verriere,La Verrière,La-Verr''er,La-Verrer,Verriere,Verrière,Ла-Веррьер,Ла-Веррєр,لا ویریرے', 48.7520000, 1.9464900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53958, 'La Verrie', 'La Verrie', 'La Verrie', 46.9613100, -0.9959600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53959, 'La Verpillière', 'La Verpilliere', 'La Verpilliere,La Verpillière,La-Verpijer,la wei er pi li ai,Ла-Верпийер,Ла-Верпійєр,拉韦尔皮利埃', 45.6364700, 5.1415100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53960, 'Laventie', 'Laventie', 'L''Vintille,Lavanti,Laventie,L’Vintille,Wentie,la wang di,lafynty,Лаванти,Лаванті,لافينتي,拉旺蒂', 50.6281800, 2.7707600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53961, 'Lavelanet', 'Lavelanet', 'Avellanetum,LAvelhanet,Lavelane,Lavelanet,Lavelanetas,Lavlane,la wei la nei,Лавелане,Лавлане,拉韦拉内', 42.9312700, 1.8465600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53962, 'Lavaur', 'Lavaur', 'Lavaur', 43.6984700, 1.8185800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53963, 'La Vaupalière', 'La Vaupaliere', 'La Vaupaliere,La Vaupalière', 49.4878900, 0.9963000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53964, 'Lavault-Sainte-Anne', 'Lavault-Sainte-Anne', 'Lavault,Lavault-Sainte-Anne,Le Vau-sur-Cher', 46.3166700, 2.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53965, 'La Varenne', 'La Varenne', 'La Varenne,La-Varenn,la wa lei ne,Ла-Варенн,لا وارین، مینے-اے-لوئر,ラ・ヴァレンヌ,拉瓦雷讷', 47.3110700, -1.3197600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53966, 'Lavardac', 'Lavardac', 'Lavardac', 44.1778500, 0.2982500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53967, 'Lavans-lès-Saint-Claude', 'Lavans-les-Saint-Claude', 'Lavans,Lavans-les-Louvieres,Lavans-les-Louvières,Lavans-les-Saint-Claude,Lavans-lès-Saint-Claude', 46.3848400, 5.7817200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53968, 'Laval-Pradel', 'Laval-Pradel', 'La Val,Laval,Laval''-Pradel'',Laval-Pradel,Le Pradel,la wa pu la dai,Лаваль-Прадель,拉瓦普拉代', 44.2066500, 4.0659100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53969, 'La Valette-du-Var', 'La Valette-du-Var', 'La Valet di Var,La Valeta,La Valette,La Valette-du-Var,La-Valet-dju-Var,La-Valett-dju-Var,la wa lei te di wa,la wylyt-dw-war,laballeteudwibaleu,lwlt dw wr,Ла Валет ди Вар,Ла-Валет-дю-Вар,Ла-Валетт-дю-Вар,لا ویلیت-دو-وار,لولت دو ور,ラ・ヴァレット＝デュ＝ヴァール,拉瓦勒特迪瓦,라발레트뒤바르', 43.1374100, 5.9831400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53970, 'Lavalette', 'Lavalette', 'Lavalette', 43.1842800, 2.2682500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53971, 'Laval', 'Laval', 'LVA,Laval'',Лаваль', 48.0666700, -0.7666700, 'FR', '2017-01-16', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53972, 'Lauzerte', 'Lauzerte', 'Lauserta,Lausèrta,Lauzerte,Lozert,luo ze er te,Лозерт,洛泽尔特', 44.2553500, 1.1381700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53973, 'Lauwin-Planque', 'Lauwin-Planque', 'Lauwin,Lauwin-Planque', 50.3902400, 3.0451000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53974, 'Lautrec', 'Lautrec', 'Lautrec', 43.7059100, 2.1392500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53975, 'Lautenbachzell', 'Lautenbachzell', 'Lotenbakzel'',luo tang ba ke ze,Лотенбакзель,洛唐巴克泽', 47.9412400, 7.1464300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53976, 'Lautenbach', 'Lautenbach', '', 47.9405500, 7.1576800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53977, 'Laussonne', 'Laussonne', 'Laussonne', 44.9694100, 4.0527200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53978, 'Lauris', 'Lauris', 'Laurias,Lauris,Lauris-sur-Durance,Loris,Làurias,luo li,Лорис,洛里', 43.7479900, 5.3151800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53979, 'Laurens', 'Laurens', 'Laurens', 43.5223800, 3.1971400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53980, 'Laure-Minervois', 'Laure-Minervois', 'Lauran,Lauranum,Laure,Laure-Minervois,Lor-Minervua,Loura,Lòura,luo er mi nei er wa,Лор-Минервуа,Лор-Мінервуа,洛尔米内尔瓦', 43.2710600, 2.5203100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53981, 'Launaguet', 'Launaguet', 'Launaguet', 43.6781800, 1.4560300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53982, 'Launac', 'Launac', 'Launac,Lonak,luo na ke,Лонак,洛纳克', 43.7435700, 1.1817200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53983, 'Laudun-l''Ardoise', 'Laudun-l''Ardoise', 'Laudun,Laudun-l''Ardoise,Laudun-lArdoise,Laudun-l’Ardoise,luo dan la er du wa si,洛丹拉尔杜瓦斯', 44.1000000, 4.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53984, 'La Turbie', 'La Turbie', 'La Turbia,La Turbie,La Túrbia,La-Tjurbi,Trophaea Augusti,la di er bi ye,la twrby,Ла-Тюрби,Ла-Тюрбі,لا توربي,ラ・テュルビー,拉蒂尔比耶', 43.7451400, 7.4010100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53985, 'La Turballe', 'La Turballe', 'An Turball,La Turballe,La-Tjurbal'',la di er ba er,Ла-Тюрбаль,لا ٹوربالی,ラ・テュルバル,拉蒂尔巴尔', 47.3468600, -2.5073400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53986, 'Lattes', 'Lattes', 'Lat,Lattes,Лат', 43.5675200, 3.9046000, 'FR', '2017-05-19', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53987, 'La Tronche', 'La Tronche', 'La Tronche,La-Tronsh,la te long ke,la thrng ch,la trwnsh,Ла-Тронш,لا ترونش,ลาทรงช์,拉特龙克', 45.2042900, 5.7364500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53988, 'La Trinité-sur-Mer', 'La Trinite-sur-Mer', 'An Drinded-Karnag,La Trinite,La Trinite-sur-Mer,La Trinité,La Trinité-sur-Mer,La-Trinite-sjur-Mer,Trinite-sur-Mer,Trinité-sur-Mer,bin hai la te li ni tai,Ла-Трините-сюр-Мер,Ла-Триніте-сюр-Мер,لا ترینیتے-سور-میر,滨海拉特里尼泰', 47.5868000, -3.0299400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53989, 'La Trinité', 'La Trinite', 'La Trinite,La Trinite-Victor,La Trinité,La Trinité-Victor', 43.7414900, 7.3135300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53990, 'Latresne', 'Latresne', 'La Trena,La Trèna,Latren,Latresne,la te lei si en,Латрен,拉特雷斯恩', 44.7860100, -0.4899400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53991, 'La Tremblade', 'La Tremblade', 'La Tramblad,La Tremblade,La-Tramblad,Reunion-sur-Seudre,Réunion-sur-Seudre,la te lang bu la de,Ла-Трамблад,Լա Տրամբլադ,لا ٹریمبلاڈی,拉特朗布拉德', 45.7680600, -1.1426500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53992, 'La Tranche-sur-Mer', 'La Tranche-sur-Mer', 'La Tranche,La-Transh-sjur-Mer,bin hai la te lang she,Ла-Транш-сюр-Мер,لا ترانشے-سور-میر,滨海拉特朗舍', 46.3430000, -1.4370000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53993, 'La Tour-sur-Orb', 'La Tour-sur-Orb', 'La Torre dOrb,La Torre dÒrb,La Tour,La Tour-sur-Orb,La-Tur-sjur-Orb,ao er he pan la tu,Ла-Тур-сюр-Орб,奥尔河畔拉图', 43.6518600, 3.1507100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53994, 'La Tourlandry', 'La Tourlandry', 'La Tourlandry,La-Turlandri,la tu er lang de li,Ла-Турландрі,لا ٹورلانڈری,ラ・トゥールランドリー,拉图尔朗德里', 47.1437500, -0.6968800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53995, 'La Tour-en-Jarez', 'La Tour-en-Jarez', 'La Tour,La Tour-en-Jarez', 45.4852300, 4.3875900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53996, 'La Tour-du-Pin', 'La Tour-du-Pin', 'La Tour,La Tour de Pin,La Tour-du-Pin,La-Tur-dju-Pen,Tour-du-Pin,Val-du-Pin,la tu di pan,Ла-Тур-дю-Пен,ラ・トゥール＝デュ＝パン,拉图迪潘', 45.5666700, 5.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53997, 'La Tour-du-Crieu', 'La Tour-du-Crieu', 'La Tor del Criu,La Tour,La Tour-du-Crieu,La-Tur-dju-Krie,La-Tur-dju-Krijo,Les Alamands,la tu di ke li e,Ла-Тур-дю-Криё,Ла-Тур-дю-Кріє,لا ٹور-دو-کریو,拉图迪克里厄', 43.1047100, 1.6527500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53998, 'La Tour-de-Salvagny', 'La Tour-de-Salvagny', 'La Tour,La Tour-de-Salvagny,La-Tur-de-Sal''van''i,Salvagny,Ла-Тур-де-Сальваньї,لا ٹور-دے-سالواگنی', 45.8123300, 4.7162600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(53999, 'Latour-Bas-Elne', 'Latour-Bas-Elne', 'Latour,Latour-Bas-Elne,Tour-bas-Elne', 42.6064600, 3.0020100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54000, 'La Tour', 'La Tour', 'La Tour', 46.1344800, 6.4293300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54001, 'Latillé', 'Latille', 'Latil''e,Latille,Latillé,la di lei,latyly,Латільє,لاتیلی,拉蒂勒', 46.6181800, 0.0763000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54002, 'Lathus-Saint-Rémy', 'Lathus-Saint-Remy', 'Lathus,Latju-Sen-Remi,la di sheng lei mi,Латю-Сен-Ремі,لاتہوس-سین-ریمی,拉蒂圣雷米', 46.3333300, 0.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54003, 'La Teste-de-Buch', 'La Teste-de-Buch', 'La Test de Bish,La Testa,La Testa de Bug,La Teste,La Teste-de-Buch,La Tèsta,La Tèsta de Bug,La-Test-de-Bjush,La-Test-de-Bukha,la tai si te de bi ke,lateseuteudeubwikeu,ltst dw bwk,Ла Тест де Биш,Ла-Тест-де-Буха,Ла-Тест-де-Бюш,لا ٹیسٹی-دے-بوچ,لتست دو بوک,ラ・テスト＝ド＝ビュック,拉泰斯特德比克,라테스트드뷔크', 44.6287500, -1.1405900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54004, 'La Tessoualle', 'La Tessoualle', 'La Tessoualle,La-Tessual'',la tai su a er,Ла-Тессуаль,لا ٹیسوالی,拉泰苏阿尔', 47.0047600, -0.8511900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54005, 'La Terrasse', 'La Terrasse', 'La Terrasse', 45.3263400, 5.9327700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54006, 'La Tardière', 'La Tardiere', 'La Tardiere,La Tardière,La-Tard''er,la ta er di ai,Ла-Тардьєр,لا ٹارڈیری,拉塔尔迪埃', 46.6609600, -0.7314300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54007, 'La Talaudière', 'La Talaudiere', 'La Talaudiere,La Talaudière,La-Talod''er,la ta luo di ai,Ла-Талодьєр,لا ٹالوڈیری,拉塔洛迪埃', 45.4809400, 4.4317300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54008, 'La Suze-sur-Sarthe', 'La Suze-sur-Sarthe', 'La Suze,La Suze-sur-Sarthe', 47.8875300, 0.0251900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54009, 'Lassy', 'Lassy', 'Lassy,Lazig', 47.9782900, -1.8719000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54010, 'Lassigny', 'Lassigny', 'Lassigny', 49.5882800, 2.8428900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54011, 'Lasseube', 'Lasseube', 'La Seuva,Lasjob,Lasseb,Lasseube,la se bu,lasywby,Лассеб,Ласёб,لاسیوبی,拉瑟布', 43.2333300, -0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54012, 'Lassay-les-Châteaux', 'Lassay-les-Chateaux', 'Lasse-le-Shato,la sai lai sha tuo,lasay-lys-shatyw,Лассе-ле-Шато,لاسای-لیس-شاتیو,拉赛莱沙托', 48.4383500, -0.4975800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54013, 'La Souterraine', 'La Souterraine', 'La Sostrana,La Sotarrana,La Souterraine,La-Suterren,la su tai er lan,Ла-Сутеррен,拉苏泰尔兰', 46.2371400, 1.4870100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54014, 'La Seyne-sur-Mer', 'La Seyne-sur-Mer', 'La Sanha,La Sen sir Mer,La Seyne,La Seyne sur Mer,La Seyne-sur-Mer,La-Sejn-sjur-Mer,La-Sen-sjur-Mer,bin hai la sai ne,la syny-swr-myr,lasenswileumeleu,lsn swr mr,Ла Сен сир Мер,Ла-Сейн-сюр-Мер,Ла-Сен-сюр-Мер,لا سینی-سور-میر,لسن سور مر,ラ・セーヌ＝シュル＝メール,濱海拉塞訥,라센쉬르메르', 43.0981800, 5.8847100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54015, 'La Sentinelle', 'La Sentinelle', 'La Sentinelle', 50.3511500, 3.4842500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54016, 'La Selle-la-Forge', 'La Selle-la-Forge', 'La Selle,La Selle-la-Forge', 48.7329500, -0.5410300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54017, 'La Séguinière', 'La Seguiniere', 'La Seguiniere,La Séguinière,La-Segin''er,la sai ji ni ai,la sygwynyry,Ла-Сегіньєр,لا سیگوینیری,拉塞吉尼埃', 47.0635700, -0.9385700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54018, 'La Séauve-sur-Semène', 'La Seauve-sur-Semene', 'La Seauve,La Seauve-sur-Semene,La Séauve,La Séauve-sur-Semène,Mont-Franc,Seauve-sur-Semene,Séauve-sur-Semène', 45.2970200, 4.2531800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54019, 'La Sauve', 'La Sauve', 'La Sauve-Majeure', 44.7666700, -0.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54020, 'La Saussaye', 'La Saussaye', 'La Saussaye', 49.2593600, 0.9809400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54021, 'La Salvetat-Peyralès', 'La Salvetat-Peyrales', 'La Salvetat,La Salvetat-Payrales,La Salvetat-Payralès,La Salvetat-Peyrales,La Salvetat-Peyralès', 44.2194000, 2.2029700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54022, 'La Salvetat-sur-Agout', 'La Salvetat-sur-Agout', 'La Salvetat,La-Sal''vetat-sjur-Agu,Salvetat-sur-Agout,a gu he pan la sa er wei ta,Ла-Сальветат-сюр-Агу,阿古河畔拉萨尔韦塔', 43.6000000, 2.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54023, 'La Salvetat-Saint-Gilles', 'La Salvetat-Saint-Gilles', 'La Salvetat,La Sauvetat de Sent Gili,La-Sal''vetat-Sen-Zhil'',la sa er wei ta sheng ji lai,Ла-Сальветат-Сен-Жиль,拉萨尔韦塔圣吉莱', 43.5762200, 1.2719200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54024, 'La Salle-et-Chapelle-Aubry', 'La Salle-et-Chapelle-Aubry', 'La Salle,La Salle-et-Chapelle-Aubry,La-Sal''-e-Shapel''-Obri,la sa er he sha pei lai-ao bu li,Ла-Саль-е-Шапель-Обрі,لا سالی-اے-شاپیل-وبری,拉萨尔和沙佩莱-奥布里', 47.2501300, -0.9751200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54025, 'Lasalle', 'Lasalle', 'Lasalle', 44.0453000, 3.8547700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54026, 'Laruscade', 'Laruscade', 'Laruscade', 45.1166700, -0.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54027, 'Laruns', 'Laruns', 'Larens,Larjons,Laruentze,Laruns,Laruntz,Larüntze,la lan,larwns,Ларенс,Ларёнс,لارونس,拉兰', 42.9882600, -0.4265800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54028, 'Larringes', 'Larringes', 'Larrenzh,Larringes,Larringia,laryngys,Ларренж,لارینگیس', 46.3673700, 6.5731800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54029, 'Larressore', 'Larressore', 'Larresor,Larresoro,Larressor,Larressore,la er lei suo er,laryswry,Ларресор,Ларрессор,لاریسوری,拉尔雷索尔', 43.3679200, -1.4397600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54030, 'La Roquette-sur-Siagne', 'La Roquette-sur-Siagne', 'La Roquette,La Roquette-sur-Siagne', 43.5994800, 6.9570500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54031, 'Laroque-Timbaut', 'Laroque-Timbaut', 'La Roca Timbaut,La Roca de Timbaut,La Ròca Timbaut,La Ròca de Timbaut,Larok-Tembo,Laroque,Laroque-Timbaut,la luo ke tan bo,Ларок-Тембо,لاروقوی-ٹیمبوٹ,拉罗克坦博', 44.2823800, 0.7627400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54032, 'la Roca d''Albera', 'la Roca d''Albera', 'Laroque-des-Alberes,Laroque-des-Albères,la Roca d''Albera', 42.5213000, 2.9337400, 'FR', '2016-08-22', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54033, 'La Roquebrussanne', 'La Roquebrussanne', 'La Roquebrussanne,Roquebrussanne,Roquelibre', 43.3398900, 5.9761800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54034, 'Laroquebrou', 'Laroquebrou', 'Laroquebrou', 44.9672800, 2.1939300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54035, 'Laroque', 'Laroque', 'Laroque', 43.9232000, 3.7239700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54036, 'La Romagne', 'La Romagne', 'La Romagne', 47.0611900, -1.0200000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54037, 'La Roche-Vineuse', 'La Roche-Vineuse', 'La Roche-Vineuse,La Vineuse,La-Rosh-Vinez,Roche-Vineuse,Ла-Рош-Винез,Ла-Рош-Вінез,لا روشے-وینیوسی', 46.3452400, 4.7202300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54038, 'La Rochette', 'La Rochette', 'La Rochette', 48.5088200, 2.6635700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54039, 'La Rochette', 'La Rochette', 'La Rochette', 45.4602500, 6.1206500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54040, 'La Roche-sur-Yon', 'La Roche-sur-Yon', 'EDM,La Roche-sur-Yon,La Rosh sir Jon,La-Roche-sur-Yon,La-Rosh-sjur-Ion,La-Rosh-sjur-Jon,Les Fromages,Les Mineraux,Les Minéraux,Roche-sur-Yon,Rupes ad Yonem,la rwsh-swr-ywn,lalosyuswileuyong,larwsh swr ywn,lh rws-swr-ywn,lrwsh swr ywn,yong he pan la luo shen,Ла Рош сир Јон,Ла-Рош-сюр-Іон,Ла-Рош-сюр-Йон,לה רוש-סור-יון,لا روش-سور-یون,لا روشے-سور-یون,لاروش سور يون,لروش سور یون,ラ・ロッシュ＝シュル＝ヨン,永河畔拉罗什,라로슈쉬르용', 46.6666700, -1.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54041, 'La Roche-sur-Foron', 'La Roche-sur-Foron', 'La Roche,La Roche-sur-Foron,La-Rosh-sjur-Foron,Rocha Fulciniensium,Ла-Рош-сюр-Форон,لا روشے-سور-فورون', 46.0666000, 6.3122400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54042, 'Laroche-Saint-Cydroine', 'Laroche-Saint-Cydroine', 'La Roche-sur-Yonne,Laroche,Laroche-Saint-Cydroine', 47.9680100, 3.4846700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54043, 'La Roche-Posay', 'La Roche-Posay', 'La Roche-Posay,La-Rosh-Poze,la luo she bo sai,Ла-Рош-Позе,لا روشے-پوسائے,ラ・ロッシュ＝ポゼ,拉罗舍波赛', 46.7865400, 0.8135400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54044, 'La Roche-Maurice', 'La Roche-Maurice', 'Ar Roc''h-Morvan,Ar Roch-Morvan,La Roche,La Roche-Maurice,La-Rosh-Moris,Rocha Morvani,Roche-Maurice,la luo ke mo li ke,Ла-Рош-Морис,ラ・ロッシュ＝モーリス,拉罗克莫里克', 48.4745500, -4.2021100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54045, 'La Rochelle', 'La Rochelle', 'Ar Rochell,Arroxela,Gorad La-Rashehl'',LRH,La Cote,La Côte,La Rochela,La Rochelle,La Rochèla,La Rosel,La Roselis,La Roshel,La Roşel,La Rošelis,La-Rosel,La-Roshel'',La-Rošel,Larosela,Larošela,Proclamation,Rupella,la luo xie er,la rocyala,la rwshl,la rwshyl,la-rosheli,lalosyel,lh rwsl,lrwshl,Λα Ροσέλ,Горад Ла-Рашэль,Ла Рошел,Ла-Рошель,Լա Ռոշել,לה רושל,لا روشل,لا روشيل,لا روشیل,لروشل,লা রোচ্যাল,ลารอแชล,ལ་རོ་ཅེ་ལེ།,ლა-როშელი,ラ・ロシェル,拉罗歇尔,라로셸', 46.1666700, -1.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54046, 'La Rochefoucauld', 'La Rochefoucauld', 'La Roche-Tardoire,La Rochefoucauld', 45.7404800, 0.3856400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54047, 'La Roche-des-Arnauds', 'La Roche-des-Arnauds', 'La Roche,La Roche-des-Arnauds', 44.5613400, 5.9551900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54048, 'La Roche-Derrien', 'La Roche-Derrien', 'Ar Roc''h-Derrien,Ar Roch-Derrien,La Roche-Derrien,La-Rosh-Der''en,La-Rosh-Derrijan,Rupes Deriani,la luo ke dai er li an,Ла-Рош-Дерриян,Ла-Рош-Дерріян,Ла-Рош-Дерьен,لا روشے-ڈیرین,ラ・ロッシュ＝デリアン,拉罗克代尔里安', 48.7462700, -3.2614200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54049, 'La Roche-de-Glun', 'La Roche-de-Glun', 'La Roche,La Roche-de-Glun', 45.0133600, 4.8448800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54050, 'La Roche-Chalais', 'La Roche-Chalais', 'La Rocha Chales,La Ròcha Chalés,La-Rosh-Shale,Lonchement,la luo ke sha lai,Ла-Рош-Шале,لا روشے-چالایس,拉罗克沙莱', 45.1500000, 0.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54051, 'La Roche-Blanche', 'La Roche-Blanche', 'La Roche,La Roche-Blanche', 45.7006400, 3.1264800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54052, 'Larmor-Plage', 'Larmor-Plage', 'An Arvor,Larmor,Larmor-Plage,Larmor-Plazh,la er mo pu la ge,larmwr-plagy,Лармор-Плаж,لارمور-پلاگی,拉尔莫普拉格', 47.7064600, -3.3833900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54053, 'Larmor-Baden', 'Larmor-Baden', 'An Arvor-Baden,Larmor,Larmor-Badan,Larmor-Baden,la er mo ba dang,larmwr-badyn,Лармор-Бадан,لارمور-بادین,拉尔莫巴当', 47.5834100, -2.8944000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54054, 'La Rivière-Saint-Sauveur', 'La Riviere-Saint-Sauveur', 'La Riviere,La Riviere-Saint-Sauveur,La Rivière,La Rivière-Saint-Sauveur', 49.4082100, 0.2703000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54055, 'La Rivière-de-Corps', 'La Riviere-de-Corps', 'La Riviere,La Riviere-de-Corps,La Rivière,La Rivière-de-Corps', 48.2884000, 4.0194700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54056, 'La Riche', 'La Riche', 'La Riche,La Riche-Extra,La-Rish,la li shen,Ла-Риш,拉里什', 47.3899600, 0.6707200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54057, 'La Richardais', 'La Richardais', 'Kerricharzh-an-Arvor,La Richardais', 48.6064100, -2.0363900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54058, 'La Ricamarie', 'La Ricamarie', 'La Ricamarie,La Ricamene,La Ricamerie,La-Rikamari,Ricamarie,la li ka ma li ye,la rykamary,Ла-Рикамарі,لا ریکاماری,拉里卡马里耶', 45.4168400, 4.3119900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54059, 'Largentière', 'Largentiere', 'LArgenteira,LArgentieira,LArgentièira,LArgentèira,Largentiere,Largentière,Larzhant''er,la er rang di ai,rarujantieru,Ларжантьер,Ларжантьєр,لارگینٹیری,ラルジャンティエール,拉尔让蒂埃', 44.5333300, 4.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54060, 'La Réole', 'La Reole', 'La Reole,La Reula,La Rèula,La Réole,La-Reol'',Reole,Réole,la lei ao er,la rywly,Ла-Реоль,لا ریولی,拉雷奥尔', 44.5820100, -0.0369100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54061, 'La Remuée', 'La Remuee', 'La Fraternite,La Fraternité,La Remuee,La Remuée', 49.5277300, 0.4028300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54062, 'La Remaudière', 'La Remaudiere', 'Kerravaot,La Remaudiere,La Remaudière,La-Remod''er,Ramauderia,la lei mo di ai,Ла-Ремодьєр,لا ریموڈیری,拉雷莫迪埃', 47.2376200, -1.2435800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54063, 'La Regrippière', 'La Regrippiere', 'La Regrippiere,La Regrippière,Skouvlant', 47.1816700, -1.1762000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54064, 'Lardy', 'Lardy', 'Lardi,Lardy,la er di,Ларди,Ларді,لارڈی,拉尔迪', 48.5184700, 2.2736000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54065, 'Larche', 'Larche', 'Larche', 45.1229100, 1.4141900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54066, 'Larchamp', 'Larchamp', 'Larchamp', 48.3613100, -0.9990000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54067, 'Larçay', 'Larcay', 'Larcay,Larçay', 47.3664900, 0.7814500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54068, 'La Ravoire', 'La Ravoire', 'La Ravoire,La-Ravuar,Ravoire,la rawwyry,Ла-Равуар,لا راوویری', 45.5597800, 5.9687100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54069, 'Larajasse', 'Larajasse', 'Larajasse', 45.6125200, 4.5002800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54070, 'Laragne-Montéglin', 'Laragne-Monteglin', 'LAranha Montaiglin,LAranha e Montaiglin,Laran''-Monteglen,la la ni meng tai ge lan,Ларань-Монтеглен,拉拉尼蒙泰格兰', 44.3166700, 5.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54071, 'La Queue-les-Yvelines', 'La Queue-les-Yvelines', 'La Queue,La Queue-lez-Yvelines,La-Ke-lez-Ivelin,La-Ke-lez-Ivlin,Ла-Ке-лез-Івлін,Ла-Ке-лез-Ивелин,لا کیو-لے-یویلینیس', 48.8000000, 1.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54072, 'La Queue-en-Brie', 'La Queue-en-Brie', 'La Queue,La Queue-en-Brie,La Queue-le-Peletier,La-Ke-an-Bri,bu li ye de qu la ke,la kyw-ayn-bry,Ла-Ке-ан-Бри,Ла-Ке-ан-Брі,لا کیو-این-بری,布里耶地区拉克', 48.7852000, 2.5811200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54073, 'Lapugnoy', 'Lapugnoy', 'L''Puno,Lapjunjua,Lapjunua,Lapugnoy,L’Puno,la pi ni wa,labwjnwy,Лапюнуа,Лапюнюа,لابوجنوي,拉皮尼瓦', 50.5163500, 2.5346000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54074, 'Lapte', 'Lapte', 'Lapte', 45.1856200, 4.2170500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54075, 'Lapoutroie', 'Lapoutroie', 'La Poutroye,Lapoutroie,Laputrua,Schnierlach,la pu te lu wa,Лапутруа,لاپوٹروی,拉普特鲁瓦', 48.1532300, 7.1669600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54076, 'La Pouëze', 'La Poueze', 'La Poueze,La Pouëze,La-Puez,la pu e ci,la pwyzy,Ла-Пуез,لا پویزی,拉普厄兹', 47.5535700, -0.8092800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54077, 'La Possonnière', 'La Possonniere', 'La Possonniere,La Possonnière,La-Posson''er,la bo suo ni ai,la pwswnyry,Ла-Поссоньєр,لا پوسونیری,拉波索尼埃', 47.3748500, -0.6853900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54078, 'La Pommeraye', 'La Pommeraye', 'La Pommeraye', 47.3556200, -0.8589200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54079, 'La Pommeraie-sur-Sèvre', 'La Pommeraie-sur-Sevre', 'La Pommeraie,La Pommeraie-sur-Sevre,La Pommeraie-sur-Sèvre', 46.8353500, -0.7778500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54080, 'Laplume', 'Laplume', '', 44.1129200, 0.5297500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54081, 'La Planche', 'La Planche', 'Ar Plank,La Planche,La-Plansh,la pu lang ke,Ла-Планш,لا پلانچے,拉普朗克', 47.0161900, -1.4315900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54082, 'La Plaine-sur-Mer', 'La Plaine-sur-Mer', 'La Plaine,La Plaine-sur-Mer,La-Plen-sjur-Mer,Plaen-Raez,bin hai la pu lan,la playny-swr-myr,Ла-Плен-сюр-Мер,لا پلاینی-سور-میر,滨海拉普兰', 47.1361900, -2.1918200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54083, 'Lapeyrouse-Fossat', 'Lapeyrouse-Fossat', 'Lapeyrouse,Lapeyrouse-Fossat', 43.6997300, 1.5104900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54084, 'La Peyratte', 'La Peyratte', 'La Peyratte', 46.6745300, -0.1491200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54085, 'La Penne-sur-Huveaune', 'La Penne-sur-Huveaune', 'La Pena,La Pena dEveuna,La Pena dEvèuna,La Penne,La Penne-sur-Huveaune,La-Pen-sjur-Juvon,La-Penn-sjur-Juvon,yu wo en he pan la pang,Ла-Пен-сюр-Ювон,Ла-Пенн-сюр-Ювон,لا پینی-سور-ہوویون,于沃恩河畔拉庞', 43.2820800, 5.5164200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54086, 'Lapalud', 'Lapalud', 'La Palu,La Palus,La Palú,La Palús,Lapalju,Lapalud,la pa lu,raparyu,Лапалю,لاپالیوڈ,ラパリュー,拉帕吕', 44.3044600, 4.6895300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54087, 'Lapalisse', 'Lapalisse', 'La Palica,La Paliça,Lapalis,Lapaliss,la pa li si,Лапалис,Лапалисс,Лапалісс,拉帕利斯', 46.2483500, 3.6360500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54088, 'La Pacaudière', 'La Pacaudiere', 'La Pacaudiere,La Pacaudière', 46.1754500, 3.8719600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54089, 'Laon', 'Laon', 'Gorad Lan,Lan,Lana,Laon,Laudunum,Lāna,XLN,l xng,la ang,laawn,lang,lawn,ran,Горад Лан,Лан,Лана,Лаон,לאן,لااون,لاون,ล็อง,ラン,拉昂,랑', 49.5666700, 3.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54090, 'Lanvollon', 'Lanvollon', 'Lannolon,Lanvollon,lang wo long,lanwwlwn,Ланволлон,لانوولون,朗沃隆', 48.6311700, -2.9864100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54091, 'Lanvéoc', 'Lanveoc', 'Lanveoc,Lanveog,Lanvéoc,Lañveog', 48.2879900, -4.4627700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54092, 'Lanvénégen', 'Lanvenegen', 'Lannejenn,Lanvenegen,Lanvenezhan,Lanvénégen,lang wei nei rang,lanwynygyn,Ланвенежан,لانوینیگین,朗韦内让', 47.9981100, -3.5413400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54093, 'Lanvallay', 'Lanvallay', 'Lanvalae,Lanvallay', 48.4554300, -2.0280300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54094, 'Lantriac', 'Lantriac', 'Lantriac', 45.0005000, 4.0044400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54095, 'Lantosque', 'Lantosque', 'Lantosca,Lantosk,Lantosque,Lantusca,lang tuo si qu ai,lantwskyw,Лантоск,لانتوسكيو,朗托斯屈埃', 43.9740600, 7.3116600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54096, 'Lanton', 'Lanton', 'Lanton', 44.7047800, -1.0356200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54097, 'Lantic', 'Lantic', 'Lannidig,Lantic', 48.6064100, -2.8820000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54098, 'Lanta', 'Lanta', 'Lanta', 43.5666700, 1.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54099, 'Lans-en-Vercors', 'Lans-en-Vercors', 'Lan-an-Verkor,Lans,Lans-an-Verkor,Lans-en-Vercors,lans-ayn-wyrkwrs,wei er ke er de qu lang,Лан-ан-Веркор,Ланс-ан-Веркор,لانس-این-ویرکورس,韦尔科尔地区朗', 45.1279300, 5.5857200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54100, 'Lansargues', 'Lansargues', 'Lansargues', 43.6515700, 4.0749500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54101, 'Lanrodec', 'Lanrodec', 'Lanrodec,Lanrodeg,Lanrodek,lang luo dai ke,Ланродек,لانروڈیک,朗罗代克', 48.5162200, -3.0312200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54102, 'Lanrivoaré', 'Lanrivoare', 'Lanrivoare,Lanrivoaré,Lanriware,lang li wo a lei,lanrywwary,Ланривоаре,لانریوواری,朗里沃阿雷', 48.4731000, -4.6387000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54103, 'Lanquetot', 'Lanquetot', 'Lanquetot', 49.5852700, 0.5263700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54104, 'Lanouée', 'Lanouee', 'Lannoez,Lanouee,Lanouée,Lanue,lang wu ai ai,lanwy,Лануе,لانوی,朗乌埃埃', 48.0022500, -2.5815700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54105, 'Lanouaille', 'Lanouaille', 'La Noalha,Lanouaille,Lanuaj,lang wu ai er,lanwayly,Лануай,لانوایلی,朗乌艾尔', 45.3951700, 1.1396800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54106, 'La Norville', 'La Norville', 'La Norville,La-Norvil'',Norville,la nwrwyl,lang ao er wei er,Ла-Норвиль,Ла-Норвіль,لا نورویل,朗奥尔维尔', 48.5824300, 2.2618000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54107, 'Lanobre', 'Lanobre', 'Lanobre', 45.4333300, 2.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54108, 'Lannoy', 'Lannoy', 'Lannoy,Lannoy-du-Nord', 50.6667400, 3.2101200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54109, 'Lannion', 'Lannion', 'LAI,Lan''on,Lannion,Lannuon,Lanon,la ni weng,lanywn,ran''nion,Ланнион,Ланніон,Ланьон,Лањон,لانيون,لانیون,ランニオン,拉尼翁', 48.7333300, -3.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54110, 'Lannilis', 'Lannilis', 'Lannili,Lannilis,Lanniliz,la ni li,lanylys,ran''nirisu,Ланнили,Ланнілі,لانیلیس,ランニリス,拉尼利', 48.5709100, -4.5223300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54111, 'Lannemezan', 'Lannemezan', 'Lanamesa,Lanamesan,Lanamesán,Lanmezan,Lannemezan,la nei mo cang,lanymyzan,Ланмезан,Ланнемезан,لانیمیزان,拉内默藏', 43.1251700, 0.3840100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54112, 'Lanmeur', 'Lanmeur', 'Lanmer,Lanmeur,Lanneur,lang mo,lanmywr,ranmuru,Ланмер,لانمیور,ランムール,朗默', 48.6473300, -3.7164500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54113, 'Lanmeur', 'Lanmeur', '', 47.8333300, -3.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54114, 'Languidic', 'Languidic', 'Langedig,Langidik,Languidic,lang ji di ke,Лангидик,Лангідік,لانگویڈیک,朗吉迪克', 47.8326600, -3.1582100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54115, 'Langueux', 'Langueux', 'Langaeg,Lange,Langjo,Langueux,lang gai yu,langwywks,Ланге,Лангё,لانگویوکس,朗盖于', 48.4950000, -2.7185000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54116, 'Langrune-sur-Mer', 'Langrune-sur-Mer', 'Langrjun-sjur-Mer,Langrune,Langrune-sur-Mer,bin hai lang ge lan,langrwny-swr-myr,Лангрюн-сюр-Мер,لانگرونی-سور-میر,滨海朗格兰', 49.3234600, -0.3734600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54117, 'Langres', 'Langres', 'Langr,Langres,Langur,lang ge lei,langrys,ranguru,Лангр,Лангър,לאנגר,لانگریس,ላንግረ,ラングル,朗格勒', 47.8666700, 5.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54118, 'Langonnet', 'Langonnet', 'Langoned,Langonetum,Langonne,Langonnet,lang ge nei,Лангонне,لانگونیٹ,朗戈内', 48.1051100, -3.4935600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54119, 'Langon', 'Langon', 'Landegon,Langon', 47.7205700, -1.8501000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54120, 'Langon', 'Langon', '', 44.5500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54121, 'Langoiran', 'Langoiran', 'Langoiran,Languaran,lang gua lang,Лангуаран,朗瓜朗', 44.7086900, -0.3936800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54122, 'Langogne', 'Langogne', 'Langon'',Langonha,Langònha,lang ge ni,langwgny,rangonyu,Лангонь,لانگوگنی,ランゴーニュ,朗戈尼', 44.7272600, 3.8553900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54123, 'Langoat', 'Langoat', 'Langoad,Langoat', 48.7506100, -3.2812100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54124, 'Langlade', 'Langlade', 'Langlade', 43.8028400, 4.2523200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54125, 'Langeais', 'Langeais', 'Langeais,Lanzhe,lang re,Ланже,朗热', 47.3258700, 0.4013600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54126, 'Langeac', 'Langeac', 'Langeac', 45.1033100, 3.4932000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54127, 'Laneuville-à-Rémy', 'Laneuville-a-Remy', 'Laneuville,Laneuville-a-Remy,Laneuville-à-Rémy', 48.4739500, 4.8836800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54128, 'Laneuveville-devant-Nancy', 'Laneuveville-devant-Nancy', 'Laneuveville,Laneuveville-devant-Nancy', 48.6562800, 6.2317000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54129, 'Lanester', 'Lanester', 'Laneste,Lanester,Lannarster,Lannarstêr,Lanster,la nei si tai,laneseuteleu,lansth,ranesuteru,Ланесте,Ланстер,لانسته,لانیسٹیر,ラネステール,拉内斯泰,라네스테르', 47.7613200, -3.3396500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54130, 'Landunvez', 'Landunvez', 'Landenve,Landunvez,lang dan wei,Ланденве,لینڈونویز,朗丹韦', 48.5346600, -4.7254500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54131, 'Landudec', 'Landudec', 'Landjudek,Landudec,Landudeg,lang di dai ke,rande~yudekku,Ландюдек,لینڈوڈیک,ランデュデック,朗迪代克', 47.9998300, -4.3364100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54132, 'Landser', 'Landser', 'Landser', 47.6838700, 7.3940000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54133, 'Landrévarzec', 'Landrevarzec', 'Landrevarzec,Landrevarzeg,Landrévarzec', 48.0917700, -4.0604400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54134, 'Landres', 'Landres', 'Landr,Landres,lang de lei,Ландр,لانڈریس,朗德雷', 49.3207500, 5.8057800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54135, 'Landrecies', 'Landrecies', 'Landrecies,Landresi,lang de lei xi,Ландреси,Ландресі,朗德勒西', 50.1249900, 3.6917100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54136, 'Landivy', 'Landivy', 'Landivi,Landivy,lang di wei,Ландіві,لانڈیوی,朗迪维', 48.4786800, -1.0332000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54137, 'Landivisiau', 'Landivisiau', 'LDV,Landivisiau,Landiviz''jo,Landivizio,lang di wei xi ao,randivu~ijio,Ландивизьйо,Ландівізьйо,لانڈیویسیو,ランディヴィジオ,朗迪维西奥', 48.5078400, -4.0683300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54138, 'Landiras', 'Landiras', 'Landiras,Landiràs,lang di la,Ландирас,Ландірас,朗迪拉', 44.5670200, -0.4153600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54139, 'Landévant', 'Landevant', 'Landevan,Landevant,Landévant,lang dai wang,Ландеван,لانڈیوانٹ,朗代旺', 47.7649900, -3.1222100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54140, 'Landeronde', 'Landeronde', 'Bonne-Lande,Landeronde', 46.6572200, -1.5695300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54141, 'Landerneau', 'Landerneau', 'Landernacum,Landerne,Landerneau,Landerno,XLD,lang dai er nuo,randeruno,Ландерно,ランデルノー,朗代尔诺', 48.4525200, -4.2525200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54142, 'Landemont', 'Landemont', 'Landemont', 47.2653600, -1.2398900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54143, 'Landeleau', 'Landeleau', 'Landeleau,Landelo,Lanna Teliavi,lang dai luo,Ландело,لانڈیلیو,朗代洛', 48.2273400, -3.7285000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54144, 'Landéhen', 'Landehen', 'Landehen,Landéhen', 48.4302200, -2.5399900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54145, 'Landéda', 'Landeda', 'Landeda,Landéda,lang dai da,randeda,Ландеда,لانڈیڈا,ランデダ,朗代达', 48.5873300, -4.5710000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54146, 'Landéan', 'Landean', 'Landean,Landeanium,Landéan,lang dai ang,Ландеан,لانڈیان,朗代昂', 48.4125300, -1.1524500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54147, 'Landaul', 'Landaul', 'Landaol,Landaul,Landol'',lang duo,Ландоль,لینڈول,朗多', 47.7478500, -3.0769400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54148, 'Landas', 'Landas', 'Landas', 50.4726900, 3.3036700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54149, 'Lancrans', 'Lancrans', 'Lancrans', 46.1272900, 5.8327700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54150, 'Lançon-Provence', 'Lancon-Provence', 'Lancon,Lancon de Provenca,Lancon-Provence,Lanson-Provans,Lançon,Lançon de Provença,Lançon-Provence,lang song pu luo wang si,lanswn-prwwyns,Лансон-Прованс,لانسون-پرووینس,朗松普罗旺斯', 43.5923700, 5.1316700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54151, 'Lancieux', 'Lancieux', 'Lancieux,Lans''e,Lans''jo,Lanseeg,Lansiocus,lang xi e,lansyw,Лансье,Лансьё,Лансьє,لانسیو,朗西厄', 48.6076700, -2.1503000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54152, 'La Murette', 'La Murette', 'La Murette', 45.3809700, 5.5402800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54153, 'La Mure', 'La Mure', 'La Mjur,La Mure,La Mure-d''Isere,La Mure-d’Isère,La-Mjur,Mure-la-Fontaine,la mi er,la mwr,Ла Мюр,Ла-Мюр,لا مور,拉米尔', 44.9025700, 5.7865900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54154, 'La Mulatière', 'La Mulatiere', 'La Mulatiere,La Mulatière,La-Mjulat''er,Ла-Мюлатьєр,لا مولاٹیری', 45.7259000, 4.8071200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54155, 'Lampertheim', 'Lampertheim', 'Lampertheim', 48.6517100, 7.6991300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54156, 'Lampaul-Plouarzel', 'Lampaul-Plouarzel', 'Lambaol-Blouarzhel,Lampaul-Plouarzel,Lampol''-Pluarzel'',lang bo pu lu a er ze,lympwl-plwarzyl,Ламполь-Плуарзель,لیمپول-پلوارزیل,朗波普卢阿尔泽', 48.4472700, -4.7604500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54157, 'Lampaul-Guimiliau', 'Lampaul-Guimiliau', 'Lambaol-Gwimilio,Lampaul,Lampaul-Guimiliau,Lampol''-Gimil''jo,lang bo ji mi li ao,lympwl-gwymylyw,Ламполь-Гимильйо,Ламполь-Гімільйо,لیمپول-گویمیلیو,朗波吉米利奥', 48.4915600, -4.0414400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54158, 'La Motte-Servolex', 'La Motte-Servolex', 'La Mota-Servolex,La Mota-Servolêx,La Motte,La Motte-Servolen,La Motte-Servolex,La-Mot-Servole,La-Mott-Servole,Ла-Мот-Серволе,Ла-Мотт-Серволе,لا موت-سیروولے', 45.5941600, 5.8757500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54159, 'La Motte-Saint-Martin', 'La Motte-Saint-Martin', 'La Motte,La Motte-Saint-Martin,La Motte-sur-Eaux', 44.9513100, 5.7181400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54160, 'La Motte-Saint-Jean', 'La Motte-Saint-Jean', 'La Motte,La Motte-Saint-Jean,Montfleury', 46.4959400, 3.9639600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54161, 'Lamotte-Beuvron', 'Lamotte-Beuvron', 'Lamot-Bjovron,Lamott-Bevron,Lamotte-Beuvron,la mo te bo fu long,Ламот-Бёврон,Ламотт-Беврон,لاموٹی-بیوورون,拉莫特伯夫龙', 47.6020000, 2.0283700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54162, 'La Motte', 'La Motte', 'La Motte', 43.4914200, 6.5368900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54163, 'La Mothe-Saint-Héray', 'La Mothe-Saint-Heray', 'La Mothe,La Mothe-Saint-Heray,La Mothe-Saint-Héray,La Mothe-Sainte-Heraye,La Mothe-Sainte-Héraye,La Mothe-sur-Sevre,La Mothe-sur-Sèvre,La-Mot-Sen-Ere,Ла-Мот-Сен-Ере', 46.3593400, -0.1123600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54164, 'Lamothe-Montravel', 'Lamothe-Montravel', 'La Mota de Mont Ravel,La Mota de Mont-ravel,La Mòta de Mont Ravèl,La Mòta de Mont-ravèl,Lamot-Monravel'',Lamothe,Lamothe-Montravel,la mo te meng te la wei,Ламот-Монравель,لاموتھ-مونٹراویل,拉莫特蒙特拉韦', 44.8500000, 0.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54165, 'La Mothe-Achard', 'La Mothe-Achard', 'La Mothe-Achard', 46.6158600, -1.6593800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54166, 'Lamorlaye', 'Lamorlaye', 'Lamorlaye,Lamorle,la mo er lai ai,lamwrlay,Ламорле,لامورلای,拉莫尔莱埃', 49.1624600, 2.4468700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54167, 'Lamonzie-Saint-Martin', 'Lamonzie-Saint-Martin', 'La Mongia e Sent Martin,La Mongiá e Sent Martin,La Móngia e Sent Martin,Lamonzi-Sen-Marten,Lamonzie,Lamonzie-Saint-Martin,la meng qi ye sheng ma er tan,Ламонзи-Сен-Мартен,Ламонзі-Сен-Мартен,لامونزی-سین-مارٹین,拉蒙齐耶圣马尔坦', 44.8471300, 0.3910200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54168, 'La Montagne', 'La Montagne', 'Ar Menez,La Montagne', 47.1865100, -1.6827200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54169, 'La Monnerie-le-Montel', 'La Monnerie-le-Montel', '', 45.8666700, 3.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54170, 'La Milesse', 'La Milesse', 'La Milesse', 48.0631400, 0.1342800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54171, 'La Mézière', 'La Meziere', 'La Meziere,La Mézière,La-Mez''er,Maceria,Magoer,Meziere,Mézière,la mei qi ai,la myzyry,Ла-Мезьер,Ла-Мезьєр,لا میزیری,拉梅齐埃', 48.2182900, -1.7551400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54172, 'La Ménitré', 'La Menitre', 'La-Menitre,la mei ni te lei,Ла-Менітре,لا مینیٹری,拉梅尼特雷', 47.4000000, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54173, 'La Membrolle-sur-Longuenée', 'La Membrolle-sur-Longuenee', 'La Membrolle,La Membrolle-sur-Longuenee,La Membrolle-sur-Longuenée,La-Mambrol''-sjur-Longne,la mymbrwl-swr-lwngwyny,long gai nei ai he pan la mang bu luo er,Ла-Мамброль-сюр-Лонгне,لا میمبرول-سور-لونگوینی,隆盖内埃河畔拉芒布罗尔', 47.5599100, -0.6723600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54174, 'La Membrolle-sur-Choisille', 'La Membrolle-sur-Choisille', 'La Membrolle,La Membrolle-sur-Choisille', 47.4371900, 0.6316300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54175, 'La Meilleraye-de-Bretagne', 'La Meilleraye-de-Bretagne', 'La Meilleraye,La Meilleraye-de-Bretagne,Melereg-Breizh', 47.5594100, -1.4020000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54176, 'La Meilleraie-Tillay', 'La Meilleraie-Tillay', 'La Meilleraie,La Meilleraie-Tillay', 46.7405900, -0.8450000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54177, 'La Meignanne', 'La Meignanne', 'La Meignanne,La-Men''jann,la mei ni ang,la mygnany,Ла-Меньянн,لا میگنانی,拉梅尼昂', 47.5170000, -0.6686100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54178, 'La Méaugon', 'La Meaugon', 'La Meaugon,La Méaugon,La-Meogon,Lanvealgon,Meaugon,la mei ao gong,la mywgwn,Ла-Меогон,لا میوگون,拉梅奥贡', 48.4993300, -2.8385000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54179, 'La Meauffe', 'La Meauffe', 'La Meauffe,La-Moff,Meauffe,la mo fu,la mywfy,Ла-Мофф,لا میوفی,拉莫夫', 49.1764300, -1.1111900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54180, 'Lambres-lez-Douai', 'Lambres-lez-Douai', 'Lambr-le-Due,Lambr-le-Dueh,Lambres,Lambres-lez-Douai,lang bu er lai du ai,Ламбр-ле-Дуе,Ламбр-ле-Дуэ,朗布尔莱杜埃', 50.3500000, 3.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54181, 'Lambesc', 'Lambesc', 'Lambesc,Lambesk,lambysk,lang bei si ke,Ламбеск,لامبیسک,朗贝斯克', 43.6531100, 5.2628200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54182, 'Lambersart', 'Lambersart', 'Lambersar,Lambersart,lambrsar,lang bei sa er,langbeuleusaleu,ranburusaru,Ламберсар,لامبرسار,ランブルサール,朗贝萨尔,랑브르사르', 50.6500000, 3.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54183, 'Lamballe', 'Lamballe', 'Lambal,Lambal'',Lamballe,Lampaulium,lambaly,lang ba er,ranbaru,Ламбаль,لامبالی,ランバル,朗巴尔', 48.4676200, -2.5143600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54184, 'Lamastre', 'Lamastre', 'La Mastra,Lamastr,Lamastre,la ma si te er,Ламастр,لاماسٹری,拉马斯特尔', 44.9867200, 4.5797500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54185, 'Lamarque', 'Lamarque', 'Lamarque', 45.0953600, -0.7189200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54186, 'Lamarche-sur-Saône', 'Lamarche-sur-Saone', 'Lamarche,Lamarche-sur-Saone,Lamarche-sur-Saône,Lamarsh-sjur-Son,suo en he pan la ma shen,Ламарш-сюр-Сон,索恩河畔拉马什', 47.2694600, 5.3858900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54187, 'Lamarche', 'Lamarche', 'Lamarche', 48.0696700, 5.7814100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54188, 'Lamanon', 'Lamanon', 'Lamanon,la mang weng,lamanwn,ramanon,Ламанон,لامانون,ラマノン,拉芒翁', 43.7006000, 5.0885700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54189, 'Lamalou-les-Bains', 'Lamalou-les-Bains', 'Lamalou,Lamalou-les-Bains', 43.5978600, 3.0805200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54190, 'La Mailleraye-sur-Seine', 'La Mailleraye-sur-Seine', 'La Mailleraye,La Mailleraye-sur-Seine,Mailleraye-sur-Seine', 49.4830800, 0.7703000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54191, 'Lamagistère', 'Lamagistere', 'Lamagistere,Lamagistère', 44.1248800, 0.8248600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54192, 'La Madeleine-de-Nonancourt', 'La Madeleine-de-Nonancourt', 'La Madeleine,La Madeleine-de Nonencourt,La Madeleine-de-Nonancourt', 48.7729800, 1.2025300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54193, 'La Madeleine', 'La Madeleine', 'La Madeleine,La Madeleine-les-Lille,Madeleine,Madlen,Мадлен', 50.6460300, 3.0758500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54194, 'La Machine', 'La Machine', 'La Machine', 46.8922600, 3.4642600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54195, 'La Loupe', 'La Loupe', 'La Loupe,La-Lup,Loupe,la lu pu,Ла-Луп,拉卢普', 48.4732000, 1.0158500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54196, 'La Loubière', 'La Loubiere', 'La Loubiere,La Loubière', 44.3714300, 2.6682500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54197, 'Laloubère', 'Laloubere', 'Laloubere,Laloubère', 43.2043000, 0.0729600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54198, 'La Longueville', 'La Longueville', 'La-Longvil'',la long ge wei er,Ла-Лонгвиль,Ла-Лонгвіль,拉隆格维尔', 50.2893900, 3.8567200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54199, 'La Londe-les-Maures', 'La Londe-les-Maures', 'La Londa,La Londa dei Mauras,La Londe,La Londe-les-Maures,La Lònda,La Lònda dei Mauras,La-Lond-le-Mor,la long dai lei mo lei,Ла-Лонд-ле-Мор,لا لوندی-لے-موریس,拉隆代勒莫勒', 43.1371400, 6.2349900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54200, 'Lallaing', 'Lallaing', 'Lallaing', 50.3901200, 3.1694900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54201, 'Lalinde', 'Lalinde', 'La Linda,Lalend,Lalinde,la lan de,Лаленд,لالینڈی,拉兰德', 44.8362100, 0.7307500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54202, 'La Limouzinière', 'La Limouziniere', 'Kerlouevig,La Limouziniere,La Limouzinière,La-Limuzin''er,la li mu qi ni ai,la lymwzynyry,Ла-Лімузіньєр,لا لیموزینیری,拉利穆齐尼埃', 46.9927400, -1.5972200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54203, 'Lalbenque', 'Lalbenque', 'LAlbenca,Lal''benk,Lalbenque,la er bang qu ai,lalbynqwy,Лальбенк,لالبینقوی,拉尔邦屈埃', 44.3392900, 1.5450100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54204, 'La Lande-Patry', 'La Lande-Patry', 'La Lande,La Lande-Patry,La-Land-Patri,la lang de pa te li,Ла-Ланд-Патри,Ла-Ланд-Патрі,拉朗德帕特里', 48.7620200, -0.5987600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54205, 'La Lande-de-Fronsac', 'La Lande-de-Fronsac', 'La Lande,La Lande-de-Fronsac', 44.9803600, -0.3804800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54206, 'La Jumellière', 'La Jumelliere', 'La Jumeliere,La Jumelière,La Jumelliere,La Jumellière,La-Zhumel''er,la jwmylyry,la rui mei li ai,Ла-Жумельєр,لا جومیلیری,ラ・ジュメリエール,拉瑞梅利埃', 47.2797600, -0.7295200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54207, 'La Jubaudière', 'La Jubaudiere', 'La Jubaudiere,La Jubaudière', 47.1720200, -0.8921500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54208, 'La Jarrie', 'La Jarrie', 'La Jarrie,La Zari,La-Zharri,la jary,la ya er li ye,Ла-Жарри,Ла-Жаррі,Լա Ժառի,لا جاری,拉雅尔里耶', 46.1287900, -1.0089600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54209, 'La Jarne', 'La Jarne', 'La Jarne,La Jarrie,La Zarn,La-Zharn,la jarny,la ya er en,Ла-Жарн,Լա Ժարն,لا جارنی,拉雅尔恩', 46.1277300, -1.0725900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54210, 'Laiz', 'Laiz', 'Laiz', 46.2475800, 4.8920300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54211, 'Laissac', 'Laissac', 'Laissac', 44.3808500, 2.8215400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54212, 'Lailly-en-Val', 'Lailly-en-Val', 'Lai-an-Val'',Lailly,Lailly-en-Val,laylayy-ayn-wal,wa de qu lai li,Лаї-ан-Валь,لائلائی-این-وال,瓦地区莱利', 47.7696200, 1.6865700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54213, 'Laillé', 'Laille', 'Lae,Laille,Laillé,Lalieg,Lalleium,lai lai,layly,Лае,Лає,لائلی,莱莱,', 47.9784800, -1.7167600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54214, 'Laigneville', 'Laigneville', 'Laigneville,Len''evil'',lai gai wei er,laygnywyl,Леньєвіль,لائگنیویل,莱盖维尔', 49.2914900, 2.4458100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54215, 'Laigné-en-Belin', 'Laigne-en-Belin', 'Laigne,Laigne-en-Belin,Laigné,Laigné-en-Belin', 47.8770600, 0.2279500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54216, 'La Houssaye-en-Brie', 'La Houssaye-en-Brie', 'La Houssaye,La Houssaye-en-Brie,La-Usse-an-Bri,Ла-Уссе-ан-Бри,Ла-Уссе-ан-Брі,لا ہوسائے-این-بری', 48.7538100, 2.8655200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54217, 'Lahonce', 'Lahonce', 'Lahonca,Lahonce,Lahonça,Laons,Lehuntze,lang ke,Лаонс,لاہونکی,朗克', 43.4824800, -1.3910100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54218, 'La Haye-Pesnel', 'La Haye-Pesnel', 'E Penel,Haye-Pesnel,La Haye-Libre,La Haye-Pesnel,La-E-Penel'',la ai ai pei si nei,Е Пенел,Ла-Е-Пенель,لا ہائے-پیسنیل,拉艾埃佩斯内', 48.7956100, -1.3965500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54219, 'La Haye-Malherbe', 'La Haye-Malherbe', 'La Haye-Malherbe', 49.2255300, 1.0677400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54220, 'La Haye-du-Puits', 'La Haye-du-Puits', 'E di Pit,Haye-du-Puits,La Haye-du-Puits,La-E-dju-Pjui,la ai ai di pi yi te,Е ди Пит,Ла-Е-дю-Пюи,Ла-Е-дю-Пюї,لا ہائے-دو-پویٹس,拉艾埃迪皮伊特', 49.2897300, -1.5432400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54221, 'Descartes', 'Descartes', 'La Haye-Descartes', 46.9666700, 0.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54222, 'La Haie-Fouassière', 'La Haie-Fouassiere', 'An Hae-Foazer,Haya,La Haie-Fouassiere,La Haie-Fouassière,La-E-Fuas''er,la ai ai fu a xi ai,Ла-Е-Фуасьєр,لا ہائے-فواسیری,拉艾埃富阿西埃', 47.1549200, -1.3979400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54223, 'La Guyonnière', 'La Guyonniere', 'La Guyonniere,La Guyonnière,La-Gjuion''er,la gwywnyry,la ju yi ao ni ai,Ла-Гюїоньєр,لا گویونیری,拉居伊奥尼埃', 46.9647600, -1.2505900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54224, 'Laguiole', 'Laguiole', 'Laguiole', 44.6846500, 2.8466600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54225, 'La Guérinière', 'La Gueriniere', 'La Gaudiniere,La Gueriniere,La Guérinière,la gueriniere', 46.9666700, -2.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54226, 'La Guerche-de-Bretagne', 'La Guerche-de-Bretagne', 'Guerche-de-Bretagne,Guirchia,Gwerc''h-Breizh,Gwerch-Breizh,La Guerche,La Guerche-de-Bretagne,La-Gersh-de-Bretan'',Montagne-de-la-Guerche,la gai er ke de bu lei ta ni,la gwyrshy-dy-brytagny,Ла-Герш-де-Бретань,لا گویرشی-دی-بریتاگنی,拉盖尔克德布雷塔尼', 47.9411200, -1.2286900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54227, 'Laguenne', 'Laguenne', 'Laguemie,Laguenne', 45.2425700, 1.7809600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54228, 'La Grigonnais', 'La Grigonnais', 'Kerrigon,La Grigonnais', 47.5272400, -1.6678100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54229, 'Lagrave', 'Lagrave', 'Lagrave', 43.8973400, 1.9926800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54230, 'La Grande-Paroisse', 'La Grande-Paroisse', 'La Grande-Paroisse', 48.3868200, 2.9015700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54231, 'La Grande-Motte', 'La Grande-Motte', 'La Mota Granda,La-Grand-Mott,la ge lang de mo te,la grandy-mwty,Ла-Гранд-Мотт,لا گراندی-موتی,拉格朗德默特', 43.5666700, 4.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54232, 'La Grand-Croix', 'La Grand-Croix', '', 45.5000000, 4.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54233, 'La Gouesnière', 'La Gouesniere', 'Gouenaer,La Gouesniere,La Gouesnière', 48.6046700, -1.8940000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54234, 'La Gorgue', 'La Gorgue', 'De Gorge,Gorg,Gorgue,La Gorgue,La-Gorg,la ge er ge,Горг,Ла-Горг,拉戈尔格', 50.6379000, 2.7150200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54235, 'Lagord', 'Lagord', 'Lagord', 46.1882200, -1.1535500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54236, 'Lagorce', 'Lagorce', 'Lagorce', 45.0666700, -0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54237, 'Lagor', 'Lagor', 'Lagor,Lagòr,la ge er,lagwr,Лагор,لاگور,拉戈尔', 43.3833300, -0.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54238, 'Lagny-le-Sec', 'Lagny-le-Sec', 'Lagny', 49.0874400, 2.7450200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54239, 'Lagny-sur-Marne', 'Lagny-sur-Marne', 'Lan''i-sjur-Marn,Lani na Marna,Lani sir Marn,lagny-swr-marny,laniswileumaleun,lnyy swr mrn,rani=shuru=marunu,Ланьи-сюр-Марн,Ланьї-сюр-Марн,Лањи на Марна,Лањи сир Марн,لاگنی-سور-مارنی,لنیی سور مرن,ラニー＝シュル＝マルヌ,라니쉬르마른', 48.8666700, 2.7166700, 'FR', '2017-04-03', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54240, 'Lagnieu', 'Lagnieu', 'Fontaine-d''Or,Lagnieu,Lagnioe,Lagniœ,Lan''e,Lan''jo,Lanio,la ni e,lanyw,Ланьё,Ланьє,Լանիո,لانيو,لانیو,拉尼厄', 45.9003800, 5.3466000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54241, 'Lagnes', 'Lagnes', 'Lagnes,Lan'',Lanhas,la ge,lagnys,Лань,لاگنیس,拉格', 43.8932500, 5.1134600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54242, 'La Glacerie', 'La Glacerie', 'Glacerie,Glaseri,La Glacerie,La-Glaseri,jing cheng,la glakyry,Гласери,Ла-Гласери,Ла-Гласері,لا گلاکیری,镜城', 49.6051700, -1.5818500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54243, 'La Génétouze', 'La Genetouze', '', 46.7333300, -1.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54244, 'La Gaude', 'La Gaude', 'La Gauda,La Gaude,La-God,la ge de,la jawd,Ла-Год,لا جاود,拉戈德', 43.7223500, 7.1508300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54245, 'La Gaubretière', 'La Gaubretiere', 'La Gaubretiere,La Gaubretière', 46.9414300, -1.0621500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54246, 'Lagarrigue', 'Lagarrigue', 'Lagarrigue', 43.5776500, 2.2778400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54247, 'La Garnache', 'La Garnache', 'La Garnache,La-Garnash,la garnashy,la jia er na she,Ла-Гарнаш,لا گارناشی,拉加尔纳舍', 46.8917600, -1.8316300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54248, 'La Garenne-Colombes', 'La Garenne-Colombes', 'Garenna Columbae,La Garan Kolomb,La Garenne,La Garenne-Colombes,La-Garenn-Kolomb,la garyny-kwlwmbys,la jia lei ne bai ge cheng,lagalenkollongbeu,lgrn kwlmb,Ла Гаран Коломб,Ла-Гаренн-Коломб,لا گارینی-کولومبیس,لگرن کولمب,ラ・ガレンヌ＝コロンブ,拉加雷訥白鴿城,라가렌콜롱브', 48.9047200, 2.2469000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54249, 'Lagardelle-sur-Lèze', 'Lagardelle-sur-Leze', 'La Gardela de Lesa,La Gardèla de Lesa,Lagardel''-sjur-Lez,Lagardelle,Lagardelle-sur-Leze,Lagardelle-sur-Lèze,lai ci he pan la jia er dai er,Лагардель-сюр-Лез,لاگارڈیلی-سور-لیزی,莱兹河畔拉加尔代尔', 43.4114300, 1.3892000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54250, 'La Garde-Freinet', 'La Garde-Freinet', 'Garde-Freinet,La Garde-Freinet,La Gardia Frainet,La Gardia de Grimaud,La Gàrdia Frainet,La Gàrdia de Grimaud,La-Gard-Frene,la jia er dai fu lei na,Ла-Гард-Френе,لا گاردے-فرینیٹ,拉加尔代弗雷纳', 43.3170900, 6.4688100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54251, 'La Garde-Adhémar', 'La Garde-Adhemar', 'La Garda dAimar,La Garde-Adhemar,La Garde-Adhémar,La-Gard-Ademar,la jia er de a dai ma,Ла-Гард-Адемар,拉加尔德阿代马', 44.3955300, 4.7577600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54252, 'La Garde', 'La Garde', 'La Garde,La Garde-pres-Toulon,La Garde-près-Toulon', 43.1227700, 6.0074500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54253, 'La Gacilly', 'La Gacilly', 'Gacilly,Gazilieg,La Gacilly,La-Gasii,La-Gasiji,Villa de Lagacille,la gasyly,la jia xi li,Ла-Гасии,Ла-Гасийи,Ла-Гасії,لا گاسیلی,拉加西利', 47.7656200, -2.1322000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54254, 'La Frette-sur-Seine', 'La Frette-sur-Seine', 'Frette-sur-Seine,La Frette,La Frette-sur-Seine,La-Frett-sjur-Sen,la fryty-swr-syny,sai na he pan la fu lei te,Ла-Фретт-сюр-Сен,لا فریتی-سور-سینی,塞纳河畔拉夫雷特', 48.9805700, 2.1786600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54255, 'La Fresnais', 'La Fresnais', 'An Onneg,La Fresnais', 48.5947800, -1.8418600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54256, 'La Francheville', 'La Francheville', 'Francheville,Franshvil,La Francheville,La-Franshvil'',la franshywyl,la fu lang she wei er,Ла-Франшвиль,Ла-Франшвіль,Франшвил,لا فرانشیویل,拉弗朗舍维尔', 49.7292300, 4.7127300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54257, 'Lafrançaise', 'Lafrancaise', 'La Francesa,Lafrancaise,Lafransez,Lafrançaise,la fu lang sai se,lafranchays,Лафрансез,لافرانچائس,拉夫朗赛瑟', 44.1279100, 1.2414100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54258, 'La Fouillouse', 'La Fouillouse', 'La Fouillouse', 45.5020000, 4.3121300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54259, 'La Fouillade', 'La Fouillade', 'La Fouillade', 44.2307200, 2.0398900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54260, 'La Forêt-sur-Sèvre', 'La Foret-sur-Sevre', 'Fore sir Sevr,Foret-sur-Sevre,Forêt-sur-Sèvre,La Foret,La Foret-sur-Sevre,La Forêt,La Forêt-sur-Sèvre,La-Fore-sjur-Sevr,Ла-Форе-сюр-Севр,Форе сир Севр', 46.7690500, -0.6496400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54261, 'La Forêt-Fouesnant', 'La Foret-Fouesnant', 'Ar Forest-Fouenant,Fore Funan,Foret-Fouesnant,Forêt-Fouesnant,La Foret,La Foret-Fouesnant,La Forêt,La Forêt-Fouesnant,La-Fore-Fuenan,la fu lei fu ai si nan,Ла-Форе-Фуенан,Форе Фунан,لا فوریٹ-فویسنانٹ,拉福雷富埃斯南', 47.9101000, -3.9785800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54262, 'La Forest-Landerneau', 'La Forest-Landerneau', 'Ar Forest-Landerne,Fore Landerno,Forest-Landerneau,La Forest,La Forest-Landerneau,La-Fore-Landerno,la fu lei si lang dai er nuo,Ла-Форе-Ландерно,Форе Ландерно,لا فوریسٹ-لاندیرنیو,拉福雷斯朗代尔诺', 48.4258900, -4.3157800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54263, 'La Force', 'La Force', 'La Force', 44.8690200, 0.3754100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54264, 'La Flotte', 'La Flotte', 'La Flot,La Flotte,La-Flot,La-Flott,la flwty,la fu luo te,Ла-Флот,Ла-Флотт,Լա Ֆլոտ,لا فلوتی,拉夫洛特', 46.1877100, -1.3281500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54265, 'La Flocellière', 'La Flocelliere', 'La Flocelliere,La Flocellière', 46.8320200, -0.8621500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54266, 'La Flèche', 'La Fleche', 'Flexia,La-Flesh,la flyshy,laflsh,Ла-Флеш,لا فلیشی,لافلش,ラ・フレーシュ', 47.6981500, -0.0755300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54267, 'La Flamengrie', 'La Flamengrie', 'La Flamengrie', 50.0017500, 3.9208100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54268, 'La Feuillie', 'La Feuillie', 'La Feuillie', 49.4641500, 1.5146300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54269, 'La Ferté-sous-Jouarre', 'La Ferte-sous-Jouarre', 'Jouarre-la-Montagne,La Ferte,La Ferte-sous-Jouarre,La Ferte-sur-Marne,La Ferté,La Ferté-sous-Jouarre,La Ferté-sur-Marne,La-Ferte-su-Zhuarr,la fei tai su ru wa er,Ла-Ферте-су-Жуарр,لا فیرتے-سوس-جواری,拉費泰蘇茹瓦爾', 48.9514000, 3.1272400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54270, 'La Ferté-Saint-Aubin', 'La Ferte-Saint-Aubin', 'Ferte-Saint-Aubin,Ferté-Saint-Aubin,La Ferte-Cosson,La Ferte-Saint-Aubin,La Ferté-Cosson,La Ferté-Saint-Aubin,La-Ferte-Sent-Oben,la fu er tai sheng ao ban,Ла-Ферте-Сент-Обен,لا فیرتے-سین-وبین,拉弗尔泰圣奥班', 47.7169500, 1.9390400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54271, 'La Ferté-Milon', 'La Ferte-Milon', 'Feritas Milonis,La Ferte Milon,La Ferte-Milon,La Ferte-sur-Ourcq,La Ferté-Milon,La Ferté-sur-Ourcq,La-Ferte-Milon,la ferte Milon,la ferté Milon,mi long bao,Ла Ферте Милон,Ла-Ферте-Милон,Ла-Ферте-Мілон,米隆堡', 49.1745300, 3.1288500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54272, 'La Ferté-Macé', 'La Ferte-Mace', 'La-Ferte-Mase,ma sai bao,Ла-Ферте-Масе,马塞堡', 48.5899900, -0.3580000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54273, 'La Ferté-Imbault', 'La Ferte-Imbault', 'La Ferte-Imbault,La Ferté-Imbault,La-Ferte-Embo,la fu er tai yi mu bo er,Ла-Ферте-Ембо,لا فیرتے-امبولٹ,拉弗尔泰伊姆博尔', 47.3846700, 1.9534400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54274, 'La Ferté-Gaucher', 'La Ferte-Gaucher', 'La Ferte-Gaucher,La Ferte-sur-Morin,La Ferté-Gaucher,La Ferté-sur-Morin,La-Ferte-Goshe,ge xie bao,Ла-Ферте-Гоше,لا فیرتے-گوشیر,戈謝堡', 48.7831000, 3.3067800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54275, 'La Ferté-Bernard', 'La Ferte-Bernard', 'La Ferte-Bernard,La Ferte-les-Pres,La Ferte-sur-Huisne,La Ferté-Bernard,La Ferté-les-Prés,La Ferté-sur-Huisne,La-Ferte-Bernar,Ла-Ферте-Бернар,لا فیرتے-بیرنارڈ', 48.1863300, 0.6535700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54276, 'La Ferté-Alais', 'La Ferte-Alais', 'Firmitas Adelaidis,La Ferte-Alais,La Ferté-Alais,La-Ferte-Ale,la fu er te a lai,Ла-Ферте-Але,لا فیرتے-الایس,拉弗尔特阿莱', 48.4830600, 2.3480200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54277, 'La Ferrière-aux-Étangs', 'La Ferriere-aux-Etangs', 'La Ferriere,La Ferrière,La-Ferrier-oz-Etan,la fu er li ai ao ai tang ge,la fyryry-a-aytang,Ла-Ферриер-оз-Етан,Ла-Феррієр-оз-Етан,لا فیریری-آ-ایتانگ,拉弗尔里埃奥埃唐格', 48.6622700, -0.5195500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54278, 'La Ferrière', 'La Ferriere', 'La Ferriere,La Ferrière', 46.7145300, -1.3141700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54279, 'La Fère', 'La Fere', 'Fara,La Fere,La Fère,La-Fer,la fei er,Ла-Фер,拉费尔', 49.6628600, 3.3663100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54280, 'La Farlède', 'La Farlede', 'La Farlade,La Farlede,La Farlède,Sollies Farlede,Solliés Farlède', 43.1677000, 6.0426600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54281, 'La Fare-les-Oliviers', 'La Fare-les-Oliviers', 'Far lez Olivie,Fare-les-Oliviers,La Fara,La Fara deis Oliviers,La Fare,La Fare-les-Oliviers,La-Far-lez-Oliv''e,La-Far-lez-Olive,la fa er lai ao li wei ye er,Ла-Фар-лез-Оливье,Ла-Фар-лез-Олівє,Фар лез Оливие,لا فاری-لے-ولیویرس,拉法尔莱奥利维耶尔', 43.5510400, 5.1943000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54282, 'Ladon', 'Ladon', 'Ladon', 48.0025900, 2.5372400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54283, 'La Dominelais', 'La Dominelais', 'Doveneleg,La Dominelais', 47.7622900, -1.6881900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54284, 'Ladignac-le-Long', 'Ladignac-le-Long', 'Ladignac,Ladignac-le-Long', 45.5825600, 1.1135900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54285, 'La Destrousse', 'La Destrousse', 'Destrousse,Destrus,La Destroca,La Destrousse,La Destroça,La-Destrus,La-Detruss,la dai si te lu si,Деструс,Ла-Деструс,Ла-Детрусс,لا دیسٹروسی,拉代斯特鲁斯', 43.3750500, 5.6056000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54286, 'La Daguenière', 'La Dagueniere', 'Dagnijer,Dagueniere,Daguenière,La Dagueniere,La Daguenière,La-Dagen''er,la da gai ni ai,Дагнијер,Ла-Дагеньєр,لا ڈاگوینیری,拉达盖尼埃', 47.4193400, -0.4312800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54287, 'Lacrouzette', 'Lacrouzette', 'Lacrouzette', 43.6603000, 2.3483800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54288, 'La Croix-Valmer', 'La Croix-Valmer', 'Croix-Valmer,La Croix,La Croix-Valmer', 43.2079500, 6.5669600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54289, 'Lacroix-Saint-Ouen', 'Lacroix-Saint-Ouen', 'La Croix Saint Ouen,Lacroix-Saint-Ouen,Lakrua-Sent-Uan,la ke lu wa sheng wu ang,lakrwyy-syn-wyn,Лакруа-Сент-Уан,لاکروئی-سین-وین,拉克鲁瓦圣乌昂', 49.3568500, 2.7880300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54290, 'Lacroix-Falgarde', 'Lacroix-Falgarde', 'La Crotz e Falgarda,Lacroix-Falgarde,Lakrua-Fal''gard,la ke lu wa fa er jia er de,Лакруа-Фальгард,لاکروئی-فالگارڈی,拉克鲁瓦法尔加尔德', 43.4996800, 1.4098500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54291, 'La Croix-en-Touraine', 'La Croix-en-Touraine', 'Croix-en-Touraine,La Croix,La Croix-en-Touraine', 47.3403100, 0.9902400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54292, 'La Crau', 'La Crau', 'Crau,Kro,La Crau,La Crau dIeras,La-Kro,la ke luo,la krw,Кро,Ла-Кро,لا کرو,拉克罗', 43.1498100, 6.0742500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54293, 'La Couture-Boussey', 'La Couture-Boussey', 'La Couture,La Couture-Boussey', 48.8958100, 1.4049100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54294, 'La Couture', 'La Couture', 'La Couture', 50.5821200, 2.7071000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54295, 'La Courtine', 'La Courtine', 'La Courtine', 45.7000000, 2.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54296, 'La Couronne', 'La Couronne', 'La Palud', 45.6112800, 0.0994800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54297, 'La Courneuve', 'La Courneuve', 'La Courneuve,La Kurnev,La-Kurnev,La-Kurnjov,la kwrnywwy,lakuleunoebeu,lkwrnw,xin ting,Ла Курнев,Ла-Курнев,Ла-Курнёв,لا کورنیووی,لکورنو,ラ・クールヌーヴ,新庭,라쿠르뇌브', 48.9280500, 2.3962700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54298, 'La Couarde-sur-Mer', 'La Couarde-sur-Mer', 'La Couarde,La Couarde-sur-Mer,La Fraternite,La Fraternité', 46.1941100, -1.4252200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54299, 'La Côte-Saint-André', 'La Cote-Saint-Andre', 'Cote-Andre,Cote-Bonne-Eau,Cote-Eau-Bonne,Cote-Saint-Andre,Côte-André,Côte-Bonne-Eau,Côte-Eau-Bonne,Côte-Saint-André,Kot Sent Andre,La Cote-Saint-Andre,La Côte-Saint-André,La-Kot-Sent-Andre,la ke te sheng ang de lei,Кот Сент Андре,Ла-Кот-Сент-Андре,لا کوٹی-سین-انڈری,拉科特圣昂德雷', 45.3935700, 5.2605500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54300, 'La Coquille', 'La Coquille', 'La Coquille', 45.5420100, 0.9767500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54301, 'La Colle-sur-Loup', 'La Colle-sur-Loup', 'Colle-sur-Loup,Kol sir Lup,La Colle,La Colle-sur-Loup,La-Kol''-sjur-Lu,Sa Cola,Sa Cola de Lop,Sa Còla,Sa Còla de Lop,la kwl swr lwb,lu he pan la ke er,Кол сир Луп,Ла-Коль-сюр-Лу,لا كول سور لوب,ラ・コル＝シュル＝ルー,卢河畔拉科尔', 43.6875000, 7.1026800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54302, 'La Cluse-et-Mijoux', 'La Cluse-et-Mijoux', 'Cluse et Mijoux', 46.8833300, 6.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54303, 'La Clusaz', 'La Clusaz', 'La Clusac,La Clusaz', 45.9052000, 6.4237600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54304, 'La Clayette', 'La Clayette', 'La Clayette', 46.2900200, 4.3042200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54305, 'La Ciotat', 'La Ciotat', 'Cytharista parrochia,La Ciotat,La Ciutat,La Sjota,La-S''jota,La-S''ota,Sans-Nom,Ville-sans-Nom,XCT,la xi ao ta,lasiota,lsywth,Ла Сјота,Ла-Сьйота,Ла-Сьота,لا کیوتاٹ,لسیوته,ラ・シオタ,拉西奥塔,라시오타', 43.1747600, 5.6044900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54306, 'La Chevrolière', 'La Chevroliere', 'Caprioleria,Chevroliere,Chevrolière,Kerc''hevrel,Kerchevrel,La Chevroliere,La Chevrolière,La-Shevrol''er,Shevrolijer,la shywrwlyry,la xie fu luo li ai,Ла-Шеврольєр,Шевролијер,لا شیورولیری,拉谢夫罗利埃', 47.0912400, -1.6097300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54307, 'La Chaussée-Saint-Victor', 'La Chaussee-Saint-Victor', 'La Chaussee,La Chaussee-Saint-Victor,La Chaussée,La Chaussée-Saint-Victor,La-Shosse-Sen-Viktor,Victoire,Victor,Victor-la-Chaussee,Victor-la-Chaussée,la shao sai ai sheng wei ke tuo,Ла-Шоссе-Сен-Віктор,لا شوسی-سین-ویکٹور,拉绍塞埃圣维克托', 47.6162100, 1.3676500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54308, 'La Châtre', 'La Chatre', 'Chatre,Châtre,La Chatre,La Châtre,La-Shatr,Shatr,la sha te er,la shatr,Ла-Шатр,Шатр,لا شاتر,لا شاٹرے,ラ・シャトル,拉沙特尔', 46.5833300, 1.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54309, 'La Châtaigneraie', 'La Chataigneraie', 'Chataigneraie,Châtaigneraie,La Chataigneraie,La Châtaigneraie,La-Shaten''ere,Shatenere,la sha tai ge lai e,Ла-Шатеньєре,Шатењере,لا شاتائے گنیرائے,拉沙泰格赖厄', 46.6478600, -0.7391600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54310, 'La Chartre-sur-le-Loir', 'La Chartre-sur-le-Loir', 'La Chartre,La Chartre-sur-le-Loir', 47.7311700, 0.5685200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54311, 'La Charité-sur-Loire', 'La Charite-sur-Loire', 'La Charite,La Charite-sur-Loire,La Charité,La Charité-sur-Loire,La-Sharite-sjur-Luar,Lja-Sharite-sjur-Luar,Sharite na Loari,lu wa er he pan la sha li tai,Ла-Шарите-сюр-Луар,Ля-Шарите-сюр-Луар,Шарите на Лоари,لا شاریٹی-سور-لویری,卢瓦尔河畔拉沙里泰', 47.1833300, 3.0166700, 'FR', '2016-12-17', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54312, 'La Chapelle-Thouarault', 'La Chapelle-Thouarault', 'Bredual,La Chapelle-Thouarault,La-Shapel''-Tuaro,la sha pei lei tu a luo er,Ла-Шапель-Туаро,لا شاپیل-تھوارالٹ,拉沙佩勒图阿罗尔', 48.1248600, -1.8661900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54313, 'La Chapelle-sur-Loire', 'La Chapelle-sur-Loire', 'La Chapelle,Les Trois-Volets', 47.2506300, 0.2188700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54314, 'La Chapelle-sur-Erdre', 'La Chapelle-sur-Erdre', 'Chapel-Erzh,Chapelle-sur-Erdre,La Chapelle-sur-Erdre,La-Shapel''-sjur-Erdr,Shapel sir Erdr,ai er de er he pan la sha pei lei,Ла-Шапель-сюр-Ердр,Шапел сир Ердр,لا شاپیل-سور-یرڈری,ラ・シャペル＝シュル＝エルドル,埃尔德尔河畔拉沙佩勒', 47.2958300, -1.5530900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54315, 'La Chapelle-sur-Crécy', 'La Chapelle-sur-Crecy', 'La Chapelle', 48.8587900, 2.9259700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54316, 'Lachapelle-sous-Aubenas', 'Lachapelle-sous-Aubenas', 'Lachapelle,Lachapelle-sous-Aubenas', 44.5641700, 4.3639200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54317, 'La Chapelle-Saint-Ursin', 'La Chapelle-Saint-Ursin', 'La Chapelle-Saint-Ursin', 47.0624800, 2.3244700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54318, 'La Chapelle-Saint-Mesmin', 'La Chapelle-Saint-Mesmin', 'Chapelle-Saint-Mesmin,La Chapelle,La Chapelle-Saint-Mesmin,La-Shapel''-Sen-Memen,Shapel-Sen-Mezmin,la sha pei lei sheng mei si man,la shapyl-syn-mysmyn,Ла-Шапель-Сен-Мемен,Шапел-Сен-Мезмин,لا شاپیل-سین-میسمین,拉沙佩勒圣梅斯曼', 47.8864800, 1.8345000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54319, 'La Chapelle-Saint-Luc', 'La Chapelle-Saint-Luc', 'Chapelle-Saint-Luc,La Chapelle,La Chapelle-Saint-Luc,La-Shapel''-Sen-Ljuk,Shapel Sen Lik,la sha pei lei sheng lu ke,la shapyl-syn-lywk,syapelsaenglwikeu,Ла-Шапель-Сен-Люк,Шапел Сен Лик,لا شاپیل-سین-لیوک,拉沙佩勒圣吕克,샤펠생뤼크', 48.3173400, 4.0398800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54320, 'La Chapelle-Saint-Laurent', 'La Chapelle-Saint-Laurent', 'Chapelle-Saint-Laurent,La Chapelle-Saint-Laurent,La-Shapel''-Sen-Loran,Shapel Sen Loran,la sha pei lei sheng luo lang,Ла-Шапель-Сен-Лоран,Шапел Сен Лоран,拉沙佩勒聖洛朗', 46.7464300, -0.4764300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54321, 'La Chapelle-Saint-Florent', 'La Chapelle-Saint-Florent', 'Chapelle-Saint-Florent,La Chapelle,La Chapelle-Saint-Florent,La-Shapel''-Sen-Floran,Shapel Sen Floran,la sha pei lei sheng fu luo lang,Ла-Шапель-Сен-Флоран,Шапел Сен Флоран,لا شاپیل-سین-فلورینٹ,拉沙佩勒圣夫洛朗', 47.3339300, -1.0563100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54322, 'La Chapelle-Saint-Aubin', 'La Chapelle-Saint-Aubin', 'La Chapelle-Saint-Aubin', 48.0359500, 0.1562400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54323, 'La Chapelle-Réanville', 'La Chapelle-Reanville', 'La Chapelle-Reanville,La Chapelle-Réanville,La-Shapel''-Reanvil'',la Chapelle,la sha pei lei lei ang wei er,Ла-Шапель-Реанвиль,Ла-Шапель-Реанвіль,拉沙佩勒雷昂维尔', 49.0975200, 1.3820900, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54324, 'La Chapelle-Launay', 'La Chapelle-Launay', 'Chapel-ar-Wern,La Chapelle,La Chapelle-Launay,La-Shapel''-Lone,la sha pei lei luo nai,la shapyl-lwnay,Ла-Шапель-Лоне,لا شاپیل-لونای,拉沙佩勒洛奈', 47.3722600, -1.9707100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54325, 'La Chapelle-la-Reine', 'La Chapelle-la-Reine', 'Chapelle-la-Reine,La Chapelle-Sainte-Genevieve,La Chapelle-Sainte-Geneviève,La Chapelle-l''Egalite,La Chapelle-l''Egalité,La Chapelle-la-Reine,La-Shapel''-la-Ren,Shapel la Ren,la shapyl-la-ryyny,Ла-Шапель-ла-Рен,Шапел ла Рен,لا شاپیل-لا-ریینی', 48.3181300, 2.5715200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54326, 'La Chapelle-Janson', 'La Chapelle-Janson', 'Chapel-Yent,La Chapelle-Janson', 48.3477500, -1.1020900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54327, 'La Chapelle-Heulin', 'La Chapelle-Heulin', 'Chapel-Huelin,Chapelle-Heulin,La Chapelle-Heulin,La-Shapel''-Elen,Shapel Elen,la sha pei lei e lan,Ла-Шапель-Елен,Шапел Елен,لا شاپیل-ہیولین,ラ・シャペル＝ウラン,拉沙佩勒厄兰', 47.1766700, -1.3400000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54328, 'La Chapelle-Gauthier', 'La Chapelle-Gauthier', 'La Chapelle-Gauthier,La Chapelle-en-Brie', 48.5494700, 2.8977600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54329, 'La Chapelle-en-Serval', 'La Chapelle-en-Serval', 'Chapelle-en-Serval,La Chapelle,La Chapelle-en-Serval,La-Shapel''-an-Serval'',Pierre-la-Montagne,Rameuse,Shapel an Serval,la shapyl-ayn-syrwal,sai er wa de qu la sha pei lei,Ла-Шапель-ан-Серваль,Шапел ан Сервал,لا شاپیل-این-سیروال,塞尔瓦地区拉沙佩勒', 49.1284200, 2.5340500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54330, 'La Chapelle-du-Noyer', 'La Chapelle-du-Noyer', 'La Chapelle,La Chapelle-du-Noyer', 48.0319100, 1.3095300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54331, 'La Chapelle-du-Genêt', 'La Chapelle-du-Genet', 'La Chapelle,La Chapelle-du-Genet,La Chapelle-du-Genêt', 47.1820300, -1.0185700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54332, 'La Chapelle-des-Marais', 'La Chapelle-des-Marais', 'Chapel-ar-Geuniou,Chapel-ar-Geunioù,Chapelle-des-Marais,La Chapelle,La Chapelle-des-Marais,La Reunion,La Réunion,La-Shapel''-de-Mare,Shapel de Mare,la sha pei lei dai ma lai,Ла-Шапель-де-Маре,Шапел де Маре,لا شاپیل-ڈیس-مارایس,ラ・シャペル＝デ＝マレ,拉沙佩勒代马赖', 47.4484500, -2.2383400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54333, 'La Chapelle-des-Fougeretz', 'La Chapelle-des-Fougeretz', 'Chapel-Felgeriz,Chapelle-des-Fougeretz,La Chapelle,La Chapelle-des-Fougeretz,La-Shapel''-de-Fuzhere,la sha pei lei dai fu re lei te,Ла-Шапель-де-Фужере,لا شاپیل-ڈیس-فوگیریٹز,拉沙佩勒代富热雷特', 48.1770500, -1.7314300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54334, 'La Chapelle-de-la-Tour', 'La Chapelle-de-la-Tour', 'Chapelle-de-la-Tour,La Chapelle-de-la-Tour,Val-sur-Sonne,la Chapelle', 45.5842200, 5.4661100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54335, 'La Chapelle-de-Guinchay', 'La Chapelle-de-Guinchay', 'Chapelle-de-Guinchay,La Chapelle,La Chapelle-de-Guinchay,La-Shapel''-de-Ginshe,Shapel de Ginshe,Ла-Шапель-де-Гинше,Ла-Шапель-де-Гінше,Шапел де Гинше,لا شاپیل-ڈی-گوینشائ', 46.2084100, 4.7624500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54336, 'La Chapelle-Basse-Mer', 'La Chapelle-Basse-Mer', 'Capella Bassameri,Chapel-Baz-Meur,La Chapelle,La Chapelle-Basse-Mer,La-Shapel''-Bass-Mer,la sha pei lei ba si mei,la shapyl-basy-myr,Ла-Шапель-Басс-Мер,لا شاپیل-باسی-میر,ラ・シャペル＝バス＝メール,拉沙佩勒巴斯梅', 47.2708600, -1.3391300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54337, 'Lachapelle-aux-Pots', 'Lachapelle-aux-Pots', 'Lachapelle,Lachapelle-aux-Pots', 49.4490500, 1.9022800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54338, 'La Chapelle-Achard', 'La Chapelle-Achard', 'Belle-Chasse,La Chapelle-Achard', 46.5886200, -1.6475700, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54339, 'La Chambre', 'La Chambre', 'La Chambre', 45.3586600, 6.3024900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54340, 'La Chaize-le-Vicomte', 'La Chaize-le-Vicomte', 'Basse-Chaize,Chaize-le-Vicomte,Haute-Chaize,La Chaize,La Chaize-le-Vicomte,La-Shez-le-Vikont,Shez le Vikont,la xie ze lei wei kong te,Ла-Шез-ле-Віконт,Шез ле Виконт,لا شائزی-لی-ویکومٹی,拉谢泽勒维孔特', 46.6716600, -1.2908400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54341, 'La Cerlangue', 'La Cerlangue', 'La Cerlangue', 49.5059200, 0.4133200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54342, 'La Celle-sur-Morin', 'La Celle-sur-Morin', 'Celle-sur-Morin,La Celle,La Celle-sur-Morin,La-Sel''-sjur-Moren,Sel sir Moren,la syl-swr-mwryn,Ла-Сель-сюр-Морен,Сел сир Морен,لا سیل-سور-مورین', 48.8114600, 2.9692100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54343, 'La Celle-Saint-Cloud', 'La Celle-Saint-Cloud', 'La Celle,La Celle Saint-Cloud,La Celle-Saint-Cloud,La Celle-les-Bruyeres,La Celle-les-Bruyères,La Sel Sen Klu,La-Sel''-Sen-Klu,laselsaengkeullu,lsl sn klw,Ла Сел Сен Клу,Ла-Сель-Сен-Клу,لا سیل-سین-کلوڈ,لسل سن کلو,ラ・セル＝サン＝クルー,라셀생클루', 48.8502900, 2.1452300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54344, 'La Celle-Saint-Avant', 'La Celle-Saint-Avant', 'Celle-Saint-Avant,La Celle,La Celle-Saint-Avant,La Selle-Avant,La-Sel''-Sent-Avan,Lasselle-Avant,Sel Sent Avan,la sai er sheng a wang,Ла-Сель-Сент-Аван,Сел Сент Аван,لا سیل-سین-اوانٹ,拉塞尔圣阿旺', 47.0220000, 0.6048800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54345, 'La Celle', 'La Celle', 'La Celle', 43.3939100, 6.0348400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54346, 'La Cavalerie', 'La Cavalerie', 'Cavalerie,Kavalri,La Cavalaria,La Cavalariá,La Cavalerie,La-Kaval''ri,la ka wa lei li ye,la kawalyryy,Кавалри,Ла-Кавальри,Ла-Кавальрі,لا کاوالیریی,拉卡瓦勒里耶', 44.0096100, 3.1584000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54347, 'Lacaune', 'Lacaune', 'Lacaune', 43.7066000, 2.6929300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54348, 'Lacasse', 'Lacasse', '', 43.3987300, 1.2695100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54349, 'Lacapelle-Marival', 'Lacapelle-Marival', 'La Capela de Marival,La Capèla de Marival,Lacapelle-Marival,Lakapel''-Marival'',la ka pei er ma li wa,lakyply-marywal,Лакапель-Мариваль,لاکیپلی-ماریوال,拉卡佩尔马里瓦', 44.7277300, 1.9246500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54350, 'La Capelle-lès-Boulogne', 'La Capelle-les-Boulogne', 'Capelle-les-Boulogne,Capelle-lès-Boulogne,Kapel le Bulon,La Capelle,La Capelle-les-Boulogne,La Capelle-lès-Boulogne,La-Kapel''-le-Bulon'',Lacapele-les-Boulonne,Lacapèle-lès-Boulonne,la ka pei lei lai bu luo nie,la kabyl lyh bwlwjn,Капел ле Булоњ,Ла-Капель-ле-Булонь,لا كابيل ليه بولوجن,拉卡佩勒莱布洛涅', 50.7330200, 1.7014700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54351, 'La Capelle', 'La Capelle', 'Capelle,Kapel,La Capelle-en-Thierache,La Capelle-en-Thiérache,La-Kapel'',la ka pei lei,la kaplh,Капел,Ла-Капель,لا کاپله,拉卡佩勒', 49.9666700, 3.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54352, 'La Canourgue', 'La Canourgue', 'La Canourgue', 44.4313300, 3.2158400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54353, 'Lacanau', 'Lacanau', 'La Canau,Lacanau,Lacanau-Medoc,Lacanau-Médoc,Lacanau-Ville,Lakano,la ka nuo,Лакано,拉卡诺', 44.9777900, -1.0762100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54354, 'La Calmette', 'La Calmette', 'La Calmette', 43.9228300, 4.2661700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54355, 'La Buisse', 'La Buisse', 'La Buisse', 45.3354000, 5.6228200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54356, 'Labry', 'Labry', 'Labry', 49.1712600, 5.8800300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54357, 'Labruguière', 'Labruguiere', 'La Bruguieira,La Bruguièira,Labrjug''er,Labrjugier,Labruguiere,Labruguière,la bu lu ji ai,labrwgwyry,Лабрюгьер,Лабрюгієр,لابروگویری,拉布吕吉埃', 43.5385800, 2.2639200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54358, 'La Bruffière', 'La Bruffiere', 'Brifjer,Brufer,Bruffiere,Bruffière,La Bruffiere,La Bruffière,La-Brjuffer,la brwffyyry,la bu lu fei ai,Брифјер,Ла-Брюффєр,لا بروففییری,拉布吕菲埃', 47.0149200, -1.1973000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54359, 'La Broque', 'La Broque', 'Broque,La-Brok,la brwkwy,la brwkyw,la bu luo qu ai,Ла-Брок,لا بروكيو,لا بروکوی,拉布罗屈埃', 48.4729800, 7.2163900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54360, 'La Bridoire', 'La Bridoire', '', 45.5250400, 5.7407300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54361, 'La Bresse', 'La Bresse', 'Bres,Bresse,La Bresse,La-Bress,la brysy,la bu lei si,Брес,Ла-Бресс,لا بریسی,拉布雷斯', 47.9997400, 6.8649900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54362, 'La Boussac', 'La Boussac', 'La Boussac,Labouseg', 48.5126000, -1.6608800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54363, 'Labourse', 'Labourse', 'Labourse,Laburs,la bu er si,labwrs,Лабурс,لابورس,拉布尔斯', 50.4988300, 2.6812100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54364, 'La Bourboule', 'La Bourboule', 'Bourboule,Burbul,La Borbola,La Bourboule,La-Burbul'',la bu er bu er,la bwrbwly,Бурбул,Ла-Бурбуль,لا بوربولی,拉布尔布尔', 45.5883700, 2.7395600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54365, 'La Bouilladisse', 'La Bouilladisse', 'La Bouilladisse', 43.3961900, 5.5930700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54366, 'Labouheyre', 'Labouheyre', 'La Boheira,La Bohèira,Labuer,la bu ai er,Лабуер,لابوہیری,拉布埃尔', 44.2129700, -0.9206200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54367, 'La Bouëxière', 'La Bouexiere', 'Beuzid-ar-C''hoadou,Beuzid-ar-C''hoadoù,Beuzid-ar-Choadou,Beuzid-ar-Choadoù,Bouexiere,Bouëxière,Buxeria,La Bouexiere,La Bouëxière,La-Bueks''er,la bu e ke xi ai,la bwyksyyry,Ла-Буексьер,Ла-Буексьєр,لا بویکسییری,拉布厄克西埃', 48.1833300, -1.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54368, 'Laboissière-en-Thelle', 'Laboissiere-en-Thelle', 'Laboissiere,Laboissiere-en-Thelle,Laboissière,Laboissière-en-Thelle,Labuas''er-an-Tel'',tai er de qu la bu wa xi ai,Лабуасьєр-ан-Тель,لابوئییری-این-تھیل,泰尔地区拉布瓦西埃', 49.2932900, 2.1615000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54369, 'La Boissière-des-Landes', 'La Boissiere-des-Landes', 'La Boissiere,La Boissiere-des-Landes,La Boissière,La Boissière-des-Landes', 46.5639800, -1.4617200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54370, 'La Boissière-de-Montaigu', 'La Boissiere-de-Montaigu', 'Boasjer de Montegi,Boissiere-de-Montaigu,Boissière-de-Montaigu,La Boissiere,La Boissiere-de-Montaigu,La Boissière,La Boissière-de-Montaigu,La-Buasser-de-Montegju,la bu wa xi ai de meng tai ju,Боасјер де Монтеги,Ла-Буассєр-де-Монтегю,لا بویسییری-ڈی-مونتایگو,拉布瓦西埃德蒙泰居', 46.9501200, -1.1904700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54371, 'La Boisse', 'La Boisse', 'Boas,Boisse,La Buas,La-Buas,La-Buass,la bu wa si,la bwas,la bwysy,Боас,Ла-Буас,Ла-Буасс,Լա Բուաս,لا بواس,لا بویسی,拉布瓦斯', 45.8427800, 5.0363900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54372, 'La Bohalle', 'La Bohalle', 'Boal,Bohalle,La Bohalle,La-Boal'',la bo a er,Боал,Ла-Боаль,لا بوہالی,拉博阿尔', 47.4209500, -0.3972300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54373, 'Lablachère', 'Lablachere', 'La Blachera,Lablachere,Lablachère,Lablasher,la bu la xie er,lablachyry,Лаблашер,لابلاچیری,拉布拉谢尔', 44.4659500, 4.2165000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54374, 'La Biolle', 'La Biolle', 'La Biolle', 45.7591600, 5.9307000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54375, 'Labeuvrière', 'Labeuvriere', 'L''breuviere,Labeuvriere,Labeuvrière,Labevrier,L’breuvière,la bo fu li ye er,labywfryr,Лабевриер,Лабеврієр,لابيوفرير,拉伯夫里耶尔', 50.5191500, 2.5626800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54376, 'La Bernerie-en-Retz', 'La Bernerie-en-Retz', 'Berneri an Rec,Bernerie-en-Retz,Kerverner-Raez,La Bernerie,La Bernerie-en-Retz,La-Berneri-an-Re,lei te de qu la bei er na li ye,Бернери ан Рец,Ла-Бернері-ан-Ре,لا بیرنیریی-این-ریٹز,雷特地区拉贝尔纳里耶', 47.0804000, -2.0364200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54377, 'La Bernardière', 'La Bernardiere', 'Bernardiere,Bernardière,Bernardjer,Kervernarzh,La Bernardiere,La Bernardière,La-Bernard''er,la bei er na er di ai,Бернардјер,Ла-Бернардьєр,لا بیرنارڈییری,拉贝尔纳尔迪埃', 47.0495200, -1.2658700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54378, 'Labenne', 'Labenne', 'La Vena,Labenn,Labenne,la bang,labyny,Лабенн,لابینی,拉邦', 43.5946400, -1.4255900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54379, 'La Bégude-de-Mazenc', 'La Begude-de-Mazenc', 'Begid de Mazan,Begude-de-Mazenc,Bégude-de-Mazenc,Chastelnou de Masenc,Chastelnòu de Masenc,La Beguda de Masenc,La Begude,La Begude-de-Mazenc,La Bégude,La Bégude-de-Mazenc,La-Begjud-de-Mazank,Neuf-Mazenc,la bei ju de de ma cang ke,Бегид де Мазан,Ла-Бегюд-де-Мазанк,拉贝居德德马藏克', 44.5457300, 4.9360800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54380, 'Labégude', 'Labegude', 'Labegude,Labégude', 44.6465700, 4.3690000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54381, 'Labège', 'Labege', 'Labege,Labeja,Labezh,Labège,la bei ge,labygy,Лабеж,لابیگی,拉贝格', 43.5303900, 1.5359600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54382, 'La Bazoge', 'La Bazoge', 'La Bazoge', 48.0968900, 0.1553400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54383, 'La Bazoche-Gouet', 'La Bazoche-Gouet', 'La Bazoche,La Bazoche-Gouet', 48.1398500, 0.9816300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54384, 'Labatut', 'Labatut', 'Labatut', 43.5500000, -0.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54385, 'La Bâtie-Neuve', 'La Batie-Neuve', 'Bati Nev,Batie-Neuve,Bâtie-Neuve,La Bastia Nova,La Bastia Nòva,La Batie-Neuve,La Bâtie-Neuve,La-Bati-Nev,La-Bati-Njov,la ba di ye na fu,Бати Нев,Ла-Бати-Нёв,Ла-Баті-Нев,لا باٹیی-نیووی,拉巴蒂耶纳夫', 44.5666700, 6.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54386, 'La Bâtie-Montgascon', 'La Batie-Montgascon', 'La Batie,La Batie-Montgascon,La Bâtie,La Bâtie-Montgascon', 45.5780900, 5.5302400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54387, 'La Bâthie', 'La Bathie', 'Albine,La Bathie,La Bâthie', 45.6281300, 6.4510600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54388, 'Labastidette', 'Labastidette', 'Labastidette', 43.4595200, 1.2452500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54389, 'Labastide-Saint-Sernin', 'Labastide-Saint-Sernin', 'Labastide,Labastide-Saint-Sernin', 43.7374300, 1.4698500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54390, 'Labastide-Saint-Pierre', 'Labastide-Saint-Pierre', 'La Bastida de Sent Peire,La Bastida de Sent Pèire,Labastid-Sen-Perr,Labastide,Labastide-Saint-Pierre,Labastide-du-Tarn,la ba si di de sheng pi ye er lei,Лабастід-Сен-Пєрр,لاباسٹیڈ-سین-پیری,拉巴斯蒂德圣皮耶尔勒', 43.9176900, 1.3662800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54391, 'Labastide-Saint-Georges', 'Labastide-Saint-Georges', 'Labastide,Labastide-Saint-Georges', 43.6996200, 1.8458500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54392, 'Labastide-Rouairoux', 'Labastide-Rouairoux', 'Labasdite-Rouairoux,Labastide,Labastide-Rouairoux', 43.4756600, 2.6392900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54393, 'La Bastide-des-Jourdans', 'La Bastide-des-Jourdans', 'Bastid de Zhurdan,Bastide-des-Jourdans,La Bastida dei Jordans,La Bastide,La Bastide-des-Jourdans,La-Bastid-de-Zhurdan,la ba si di dai dai ru er dang,Бастид де Журдан,Ла-Бастид-де-Журдан,Ла-Бастід-де-Журдан,لا باسٹیڈی-ڈیس-جورڈانس,拉巴斯蒂代代茹尔当', 43.7870700, 5.6346800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54394, 'Labastide-Beauvoir', 'Labastide-Beauvoir', 'La Bastide-de-Beauvoir,Labastide,Labastide-Beauvoir', 43.4814800, 1.6654300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54395, 'La Bassée', 'La Bassee', 'Base,Bassee,Bassée,La Bassee,La Bassée,La-Basse,Lja-Base,Lja-Baseh,la ba sai,Басе,Ла-Бассе,Ля-Басе,Ля-Басэ,拉巴塞', 50.5342400, 2.8062000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54396, 'Labarthe-sur-Lèze', 'Labarthe-sur-Leze', 'La Barta de Lesa,La Barta de Lesat,Labart-sjur-Lez,Labarthe,Labarthe-sur-Leze,Labarthe-sur-Lèze,labardy-swr-lyzy,lai ci he pan la ba er te,Лабарт-сюр-Лез,لاباردی-سور-لیزی,莱兹河畔拉巴尔特', 43.4520600, 1.3996800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54397, 'Labarthe-Rivière', 'Labarthe-Riviere', 'Era Barta dArribera,Era Barta dArribèra,Labart-Riv''er,Labart-River,Labarthe,Labarthe-Riviere,Labarthe-Rivière,la ba er te li wei ai,labardy-rywyry,Лабарт-Ривьер,Лабарт-Ривєр,لاباردی-ریویری,拉巴尔特里维埃', 43.0810000, 0.6713400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54398, 'La Barthe-de-Neste', 'La Barthe-de-Neste', 'La Barthe,La Barthe-de-Neste', 43.0812300, 0.3843800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54399, 'La Barre-de-Monts', 'La Barre-de-Monts', 'La Barre,La Barre-de-Monts', 46.8805900, -2.1216800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54400, 'Labaroche', 'Labaroche', 'La Broche,Labarosh,la ba luo ke,labarwchy,Лабарош,لاباروچی,拉巴罗克', 48.1107600, 7.1924400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54401, 'La Balme-de-Sillingy', 'La Balme-de-Sillingy', 'La Balme,La Balme-de-Sillingy', 45.9611000, 6.0425100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54402, 'La Baconnière', 'La Baconniere', 'La Baconniere,La Baconnière,La Braconniere,La Braconnière', 48.1801200, -0.8920200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54403, 'Kuntzig', 'Kuntzig', 'Kuntzig', 49.3486700, 6.2338100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54404, 'Kunheim', 'Kunheim', 'Kjunajm,Kuenheim,Kunheim,Kunkhajm,Künheim,qu nan,Кунхајм,Кюнайм,屈南', 48.0768100, 7.5343000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54405, 'Kruth', 'Kruth', 'Krjut,Kruet,Krut,Kruth,Krüt,ke lu,Крут,Крют,克吕', 47.9307900, 6.9647500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54406, 'Krautergersheim', 'Krautergersheim', 'Krautergersheim,Krautergerskhajm,Krotergersajm,Krueterrische,Krüterrische,ke luo tai er re er sang,krawtrghyrshym,krawtrgrshaym,Краутергерсхајм,Кротергерсайм,كراوترغيرشيم,کراوترگرسهایم,克罗泰尔热尔桑', 48.4763400, 7.5671800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54407, 'Kœnigsmacker', 'Koenigsmacker', 'Freimacker,Kenigsmaker,Kenigzmaker,Koenigsmacher,Koenigsmachern,Koenigsmacker,Königsmachern,ke ai ni ge si ma kai,kwnygsmakr,Кенигзмакер,Кенигсмакер,Кенігсмакер,کونیگسماکر,科埃尼格斯马凯', 49.4000000, 6.2833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54408, 'Knutange', 'Knutange', 'Knutange', 49.3430700, 6.0329700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54409, 'Kintzheim', 'Kintzheim', 'Kencajm,Kinckhajm,Kinze,Kinzheim,Kínze,kan te zan,kyntshaym,kyntzhym,Кенцайм,Кинцхайм,Кинцхајм,كينتزهيم,کینتسهایم,坎特赞', 48.2548000, 7.3949100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54410, 'Kingersheim', 'Kingersheim', 'Kingersheim', 47.7925900, 7.3349100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54411, 'Kilstett', 'Kilstett', 'Kil''stet,Kilshtet,ji er si tai,kylshtt,kylstyt,Килштет,Кильстет,Кільстет,كيلستيت,کیلشتت,基尔斯泰', 48.6760000, 7.8547100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54412, 'Killem', 'Killem', 'Killem', 50.9577900, 2.5606800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54413, 'Keskastel', 'Keskastel', 'Keskastel', 48.9713200, 7.0441200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54414, 'Kervignac', 'Kervignac', 'Kervignac,Kervignag,Kervin''jak,Kervinak,kai er wei ni ya ke,Кервиньяк,Кервињак,Кервіньяк,凯尔维尼亚克', 47.7628900, -3.2377800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54415, 'Kertzfeld', 'Kertzfeld', 'Kercfeld,Kertzfeld,Керцфелд', 48.3793400, 7.5708200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54416, 'Kersaint-Plabennec', 'Kersaint-Plabennec', 'Kersaint,Kersaint-Plabennec,Kersen Plabenek,Kersen-Plabennek,Kersent-Plabenneg,kai er sang pu la bo nei ke,Керсен Плабенек,Керсен-Плабеннек,凯尔桑普拉伯内克', 48.4716600, -4.3723300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54417, 'Kernilis', 'Kernilis', 'Kernili,Kernilis,Kerniliz,kai er ni li,Кернили,Кернілі,凯尔尼利', 48.5707500, -4.4180000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54418, 'Kerlouan', 'Kerlouan', 'Kerlouan,Kerluan,kai er lu ang,Керлуан,凯尔卢昂', 48.6450000, -4.3655600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54419, 'Kerbach', 'Kerbach', 'Kerbach', 49.1662700, 6.9674400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54420, 'Kembs', 'Kembs', 'Cambetis,Kembs,kang bu,Кембс,康布', 47.6894800, 7.5032300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54421, 'Kédange-sur-Canner', 'Kedange-sur-Canner', 'Kedange,Kedange-sur-Camer,Kedange-sur-Canner,Kédange-sur-Camer,Kédange-sur-Canner', 49.3079100, 6.3372000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54422, 'Kaysersberg', 'Kaysersberg', 'Caesaris Mons,Kajzersberg,Kayserberg,Kaysersberg,Kezersberg,Mont-Libre,kai sai er si bei er,kezerusuberu,qyysrsbrg,Кайзерсберг,Кајзерсберг,Кезерсберг,קייסרסברג,ケゼルスベール,凯塞尔斯贝尔', 48.1380300, 7.2638500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54423, 'Kaltenhouse', 'Kaltenhouse', 'Kaltenhausen,Kaltenhouse', 48.7910200, 7.8332900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54424, 'Juziers', 'Juziers', 'Juziers,Zhuz''er,Жузьер,Жузьєр', 48.9913700, 1.8476000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54425, 'Juvisy-sur-Orge', 'Juvisy-sur-Orge', 'Juvisy,Juvisy-sur-Orge,Zhuvizi-sjur-Orzh,ao er ri he pan yu wei xi,Жувизи-сюр-Орж,Жувізі-сюр-Орж,奥尔日河畔于维西', 48.6833300, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54426, 'Juvigny-sous-Andaine', 'Juvigny-sous-Andaine', 'Juvigny,Zhuvin''i-su-Anden,rui wei ni su sang dai ne,Жувиньи-су-Анден,Жувіньї-су-Анден,瑞维尼苏桑代讷', 48.5519400, -0.5087800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54427, 'Juvigné', 'Juvigne', 'Juvigne,Juvigné', 48.2289100, -1.0340800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54428, 'Juvignac', 'Juvignac', 'Juvignac,Juvinhac,Zhjuvin''jak,Zhuvin''jak,rui wei ni ya ke,Жувиньяк,Жувіньяк,Жювиньяк,瑞维尼亚克', 43.6138900, 3.8105600, 'FR', '2017-05-19', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54429, 'Jussy', 'Jussy', 'Jussy', 49.7198400, 3.2327000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54430, 'Jussey', 'Jussey', 'Jussey', 47.8253600, 5.9019300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54431, 'Jussac', 'Jussac', 'Jussac', 44.9880400, 2.4244500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54432, 'Jurançon', 'Jurancon', 'Jurancon,Juranson,Jurançon,Zhjuranson,Zhuranson,juranson,zhu lang song,Журансон,Жюрансон,ジュランソン,朱朗松', 43.2883000, -0.3869400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54433, 'Jumilhac-le-Grand', 'Jumilhac-le-Grand', 'Jumilhac,Jumilhac lo Grand,Jumilhac lu Grand,Jumilhac-le-Grand,Zhumiak-le-Gran,da rui mi ya ke,Жумиак-ле-Гран,Жуміак-ле-Гран,大瑞米亚克', 45.4943200, 1.0633900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54434, 'Jumièges', 'Jumieges', 'Gemeticum,Jumieges,Jumièges,Zhum''ezh,Zhumezh,Жумьеж,Жумєж', 49.4332400, 0.8191800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54435, 'Jumelles', 'Jumelles', '', 47.4351100, -0.1037000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54436, 'Jullouville', 'Jullouville', 'Julloville,Julouville-les-Pins,Zhulluvil'',rui lu wei er,Жуллувиль,Жуллувіль,瑞卢维尔', 48.7757600, -1.5636600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54437, 'Jujurieux', 'Jujurieux', 'Jujurieux', 46.0397600, 5.4132800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54438, 'Juilly', 'Juilly', 'Juilly', 49.0137500, 2.7056300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54439, 'Juillan', 'Juillan', 'Juillan,Julhan,Zhjujan,Zhujan,rui yi lang,Жуян,Жюйан,瑞伊朗', 43.1993700, 0.0257000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54440, 'Juillac', 'Juillac', 'Juillac', 45.3187500, 1.3228200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54441, 'Juigné-sur-Sarthe', 'Juigne-sur-Sarthe', 'Juigne-sur-Sarthe,Juigné-sur-Sarthe', 47.8649900, -0.2862400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54442, 'Juigné-sur-Loire', 'Juigne-sur-Loire', 'Juigne,Juigne-sur-Loire,Juigné,Juigné-sur-Loire', 47.4074100, -0.4768200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54443, 'Juigné', 'Juigne', '', 47.7187800, -0.3940500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54444, 'Jugon-les-Lacs', 'Jugon-les-Lacs', '', 48.4166700, -2.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54445, 'Joyeuse', 'Joyeuse', 'Joyeuse', 44.4797200, 4.2378100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54446, 'Jouy-sur-Morin', 'Jouy-sur-Morin', 'Jouy,Jouy-sur-Morin,Zhui-sjur-Moren,Жуи-сюр-Морен,Жуї-сюр-Морен', 48.7950000, 3.2723800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54447, 'Jouy-le-Potier', 'Jouy-le-Potier', 'Jouy,Jouy-le-Potier,Zhui-le-Pot''e,ru yi lai bo di ye,Жуї-ле-Потьє,茹伊莱波蒂耶', 47.7455300, 1.8111500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54448, 'Jouy-le-Moutier', 'Jouy-le-Moutier', 'Jouy,Jouy-le-Moutier,Zhui-le-Mut''e,ru yi lei mu di ye,Жуи-ле-Мутье,Жуї-ле-Мутьє,茹伊勒穆蒂耶', 49.0106800, 2.0402800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54449, 'Jouy-le-Châtel', 'Jouy-le-Chatel', 'Jouy,Jouy-le-Chatel,Jouy-le-Châtel,Zhui-le-Shatel'',Жуи-ле-Шатель,Жуї-ле-Шатель', 48.6665100, 3.1303600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54450, 'Jouy-en-Josas', 'Jouy-en-Josas', 'Jouy,Jouy-en-Josas,Jouy-le-Peuple,Zhui-an-Zhozas,Жуи-ан-Жозас,Жуї-ан-Жозас', 48.7590900, 2.1696600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54451, 'Jouy-aux-Arches', 'Jouy-aux-Arches', 'Gaudiacum,Jouy,Jouy-aux-Arches,Zhui-oz-Arsh,ru yi ao a er xie,Жуи-оз-Арш,Жуї-оз-Арш,茹伊奥阿尔谢', 49.0630800, 6.0802300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54452, 'Jouy', 'Jouy', 'Jouy', 48.5100500, 1.5450100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54453, 'Joux-la-Ville', 'Joux-la-Ville', 'Joux,Joux-la-Ville', 47.6224100, 3.8621700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54454, 'Jouques', 'Jouques', 'Jocas,Jouques,Zhuk,ru qu ai,Жук,茹屈埃', 43.6375000, 5.6400600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54455, 'Jougne', 'Jougne', 'Jougne,Zhun'',ru ni,Жунь,茹尼', 46.7629100, 6.3883800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54456, 'Jouet-sur-l''Aubois', 'Jouet-sur-l''Aubois', 'Jouet,Jouet-sur-l''Aubois,Jouet-sur-lAubois,Zhueh-sjur-l''Obua,Жуэ-сюр-л’Обуа', 47.0456200, 2.9872500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54457, 'Joué-sur-Erdre', 'Joue-sur-Erdre', 'Ioseium,Joue,Joue-sur-Erdre,Joué,Joué-sur-Erdre,Yaoued,Zhue-sjur-Erdr,Zhueh-sjur-Ehrdr,ai er de er he pan ru ai,Жуе-сюр-Ердр,Жуэ-сюр-Эрдр,埃尔德尔河畔茹埃', 47.4959600, -1.4204700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54458, 'Joué-lés-Tours', 'Joue-les-Tours', 'Joue,Joue-les-Tours,Joué,Joué-lès-Tours,Joué-lés-Tours,Zhu-le-Tur,Жу-ле-Тур', 47.3522300, 0.6690500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54459, 'Joudreville', 'Joudreville', 'Joudreville', 49.2856000, 5.7783200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54460, 'Jouars-Pontchartrain', 'Jouars-Pontchartrain', 'Jouars,Jouars-Pontchartrain,Zhuar-Ponshartren,Жуар-Поншартрен', 48.7888800, 1.8989800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54461, 'Jouarre', 'Jouarre', 'Jouarre,Zhuarr,ru a er,Жуарр,茹阿爾', 48.9266100, 3.1316800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54462, 'Josselin', 'Josselin', 'Iosselina,Josilin,Josselin,Zhoslen,Zhosselen,josuran,ruo se lan,Жослен,Жосселен,ジョスラン,若瑟兰', 47.9572000, -2.5471300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54463, 'Jonzieux', 'Jonzieux', 'Jonzieux', 45.3158200, 4.3604100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54464, 'Jonzac', 'Jonzac', 'Zhonzak,Zonzak,jonzakku,rong zha ke,Жонзак,Ժոնզակ,ジョンザック,容扎克', 45.4500000, -0.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54465, 'Jons', 'Jons', 'Jons,Zhon,Жон', 45.8079700, 5.0803200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54466, 'Jonquières-Saint-Vincent', 'Jonquieres-Saint-Vincent', 'Jonquiera de Sent Vincenc,Jonquieres,Jonquièra de Sent Vincenç,Jonquières,Vincent-du-Gard,Zhonk''er-Sen-Vensan,Zhonker-Sen-Vensan,rong ji ai sheng wan sang,Жонкьер-Сен-Венсан,Жонкєр-Сен-Венсан,容基埃圣万桑', 43.8280900, 4.5632700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54467, 'Jonquières', 'Jonquieres', 'Joncquieres,Joncquières,Jonquieres,Jonquières', 44.1143100, 4.9000300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54468, 'Jonquerettes', 'Jonquerettes', 'Joncairetas,Jonquerettes,Zhonkerett,rong qu ai lei te,Жонкеретт,容屈埃雷特', 43.9465500, 4.9328600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54469, 'Jonchery-sur-Vesle', 'Jonchery-sur-Vesle', 'Jonchery,Jonchery-sur-Vesle,Zhonsheri-sjur-Vel'',wei si er he pan rong xie li,Жоншері-сюр-Вель,韦斯尔河畔容谢里', 49.2895200, 3.8134500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54470, 'Joncherey', 'Joncherey', 'Joncherey,Zhonshere,rong she lei,Жоншере,容舍雷', 47.5261600, 7.0015800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54471, 'Jonage', 'Jonage', 'Jonage', 45.7964000, 5.0453000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54472, 'Joinville-le-Pont', 'Joinville-le-Pont', 'Joinville,Joinville-le-Pont,La Branche-du-Pont-de-Saint-Maur,Zhoanvil l''o Pon,Zhuenvil''-le-Pon,joan''vu~iru=ru=pon,qiao lian cheng,Жоанвил льо Пон,Жуенвиль-ле-Пон,Жуенвіль-ле-Пон,ジョアンヴィル＝ル＝ポン,桥连城', 48.8253800, 2.4745800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54473, 'Joinville', 'Joinville', 'Joinville,Joinville-en-Vallage', 48.4436300, 5.1414400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54474, 'Joigny', 'Joigny', 'Ioviniacum,Joigny,Zhuan''i,jowani,ru wa ni,Жуаньи,Жуаньї,ジョワニー,茹瓦尼', 47.9828800, 3.4009600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54475, 'Jœuf', 'Joeuf', 'Zh''of,Zhef,Zhjof,Ziofas,re fu,Žiofas,Жеф,Жьоф,Жёф,熱夫', 49.2333300, 6.0166700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54476, 'Job', 'Job', 'Job', 45.6177600, 3.7460200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54477, 'Jeumont', 'Jeumont', 'Jeumont,Zhemon,Zhjomon,re meng,Жемон,Жёмон,热蒙', 50.2965800, 4.1010800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54478, 'Jenlain', 'Jenlain', 'Jenlain,Zhanlen,rang lan,Жанлен,让兰', 50.3116400, 3.6287200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54479, 'Jegun', 'Jegun', '', 43.7666700, 0.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54480, 'Jebsheim', 'Jebsheim', 'Jebsheim', 48.1234500, 7.4754900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54481, 'Jeanménil', 'Jeanmenil', 'Jeanmenil,Jeanménil', 48.3356000, 6.6876900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54482, 'Javené', 'Javene', 'Javene,Javené,Yaoueneg', 48.3193300, -1.2163000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54483, 'Jaux', 'Jaux', 'Jaux,Zho,ruo zhen,Жо,若镇', 49.3912000, 2.7780900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54484, 'Jausiers', 'Jausiers', 'Gauserium,Jausier,Jausiers,Jausièr,Zhoz''e,ruo xie er,Жозье,Жозьє,若谢尔', 44.4170500, 6.7294700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54485, 'Jaunay-Clan', 'Jaunay-Clan', 'Jaunay,Jaunay-Clan,Zhone-Klan,ruo nai ke lang,Жоне-Клан,若奈克朗', 46.6845300, 0.3712800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54486, 'Jaujac', 'Jaujac', 'Jaujac,Zhozhak,ruo ya ke,Жожак,若雅克', 44.6354000, 4.2573000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54487, 'Jasseron', 'Jasseron', 'Jasseron', 46.2131600, 5.3257900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54488, 'Jassans-Riottier', 'Jassans-Riottier', 'Jassans,Jassans-Riottier,Zasan Riotie,Zhassan-Riot''e,jasan-ghywtyyr,ya sang-li ao di ye,Жассан-Риотье,Жассан-Ріотьє,Ժասան Ռիոտիե,جاسان-غيوتيير,جسسانس-ریوتٹیر,雅桑－里奥蒂耶', 45.9835200, 4.7600400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54489, 'Jarzé', 'Jarze', 'Jarze,Jarze-Marat,Jarzé,Jarzé-Marat', 47.5556300, -0.2318300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54490, 'Jarville-la-Malgrange', 'Jarville-la-Malgrange', 'Jarville,Jarville-la-Malgrange', 48.6690700, 6.2063600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54491, 'Jarrie', 'Jarrie', 'Jarrie', 45.1173200, 5.7595700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54492, 'Jarny', 'Jarny', 'Jarny,Zharni,ya er ni,Жарни,Жарні,جڑنے,雅尔尼', 49.1573600, 5.8787700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54493, 'Jarnac', 'Jarnac', 'Gorad Zharnak,Iarnacum,Jarnac,Zharnak,jrnak,ya er na ke,Горад Жарнак,Жарнак,جرناک,雅尔纳克', 45.6816000, -0.1732900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54494, 'Jargeau', 'Jargeau', 'Jargeau,Jargolium,Zharzho,jrgw,ya er ruo,Жаржо,جرگو,雅尔若', 47.8631600, 2.1264800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54495, 'Jard-sur-Mer', 'Jard-sur-Mer', 'Jard,Jard-la-Montagne,Jard-sur-Mer,Zhar-sjur-Mer,bin hai ya er,jrd-sr-mr,Жар-сюр-Мер,جرد-سر-مر,滨海雅尔', 46.4145100, -1.5763900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54496, 'Jardin', 'Jardin', 'Jardin', 45.4961700, 4.9064100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54497, 'Janzé', 'Janze', 'Gentieg,Ianzeium,Janze,Janzé,Zhanze,rang ze,Жанзе,جانزے,让泽', 47.9591500, -1.4982900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54498, 'Janville-sur-Juine', 'Janville-sur-Juine', 'Janville,Janville-sur-Juine,Zhanvil''-sjur-Zhuin,rui ne he pan rang wei er,Жанвиль-сюр-Жуин,Жанвіль-сюр-Жуїн,جنویل-سر-جینے,瑞讷河畔让维尔', 48.5135200, 2.2706400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54499, 'Janville', 'Janville', 'Janville', 48.2028400, 1.8802000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54500, 'Jans', 'Jans', 'Hentieg,Jans', 47.6202900, -1.6143800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54501, 'Janneyrias', 'Janneyrias', 'Janneyrias,Zhannejrja,Zhanner''jas,ya nei li a,Жаннейря,Жаннерьяс,جننےریاس,雅内里阿', 45.7534600, 5.1102700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54502, 'Jallais', 'Jallais', 'Jallais,Zhalle,jare,jllyth,Жалле,جللیث,ジャレ', 47.1969100, -0.8673800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54503, 'Jacou', 'Jacou', 'Jacon,Jacou,Zhaku,jkw,ya ku,Жаку,جکو,雅库', 43.6613900, 3.9122200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54504, 'Jacob-Bellecombette', 'Jacob-Bellecombette', 'Jacob,Jacob-Bellecombette,Zhakob-Bel''kombett,Жакоб-Белькомбетт,جیکب-بللکومبٹتے', 45.5527500, 5.9116000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54505, 'Izon', 'Izon', 'Izon', 44.9241600, -0.3632200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54506, 'Izernore', 'Izernore', 'Izernor,Izernore,Ysernodurum,azyrnwr,yi ze er nuo er,Ізернор,Изернор,Իզերնոր,إزيرنور,伊泽尔诺尔', 46.2168600, 5.5536600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54507, 'Izeaux', 'Izeaux', 'Izeaux,Izeaux-aux Bois,Izo,yi zuo,Ізо,Изо,伊佐', 45.3351500, 5.4250900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54508, 'Iwuy', 'Iwuy', 'Ivjui,Iwuy,yi wei,Івюї,Ивюи,伊维', 50.2330000, 3.3205800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54509, 'Ivry-sur-Seine', 'Ivry-sur-Seine', 'Ivri sir Sen,Ivri sjur Sen,Ivri-sjur-Sen,Ivry,Ivry sobre Sena,Ivry-sur-Seine,ayfry swr syn,aywry swr sn,aywry-swr-sn,ibeuliswileusen,ivuri=shuru=senu,sai na he pan yi fu li,ʼybry-syr-sn,Іврі-сюр-Сен,Иври сир Сен,Иври сюр Сен,Иври-сюр-Сен,איברי-סיר-סן,إيفري سور سين,ایوری سور سن,ایوری-سور-سن,イヴリー＝シュル＝セーヌ,塞纳河畔伊夫里,이브리쉬르센', 48.8156800, 2.3848700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54510, 'Ivry-la-Bataille', 'Ivry-la-Bataille', 'Ivri-la-Bataj,Ivry,Ivry-la-Bataille,Ivry-la-Hauteur,ivuri=ra=bataiyu,yi fu li la ba tai er,Іврі-ла-Батай,Иври-ла-Батай,イヴリー＝ラ＝バタイユ,伊夫里拉巴泰尔', 48.8833300, 1.4594800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54511, 'Itxassou', 'Itxassou', 'Itksassu,Itksasu,Itsasou,Itsasu,Itxassou,Union,ichasu,yi te sa su,Ітксассу,Итксассу,Итксасу,イチャスー,伊特萨苏', 43.3289300, -1.4061700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54512, 'Itteville', 'Itteville', 'Itteville,Ittvil'',yi te wei er,Іттвіль,Иттвиль,伊特维尔', 48.5153600, 2.3437700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54513, 'Ittenheim', 'Ittenheim', 'Ittenheim', 48.6044700, 7.5947100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54514, 'Iteuil', 'Iteuil', 'Itej,Iteuil,yi te yi,Ітей,伊特伊', 46.4880800, 0.3121200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54515, 'Itancourt', 'Itancourt', 'Itancourt', 49.8066400, 3.3442700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54516, 'Istres', 'Istres', 'Istr,Istra,Istras,Istre,Istres,QIE,aystr,iseuteuleu,isutoru,yi si te er,Істр,Истр,Истра,ایستر,イストル,伊斯特爾,이스트르', 43.5166700, 4.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54517, 'Issy-les-Moulineaux', 'Issy-les-Moulineaux', 'Isi le Mulino,Issi-le-Mulino,Issy,Issy-les-Moulineau,Issy-les-Moulineaux,L''Union,aysy-lh-mwlynw,aysy-lmwlynw,ishi=re=murino,isilemollino,yi xi lai mu li nuo,Іссі-ле-Муліно,Иси ле Мулино,Исси-ле-Мулино,ایسی-لمولینو,ایسی-له-مولینو,イシー＝レ＝ムリノー,伊西萊穆利諾,이시레몰리노', 48.8210400, 2.2771800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54518, 'Is-sur-Tille', 'Is-sur-Tille', 'I-sjur-Tij,Is,Is-sjur-Tij,Is-sur-Tille,di er he pan yi,І-сюр-Тій,И-сюр-Тий,Ис-сюр-Тий,蒂尔河畔伊', 47.5267000, 5.1064900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54519, 'Issoudun', 'Issoudun', 'Essaudun,Exoldunum,Issoudun,Issuden,Isudjon,Uxellodunum,ayswdn,isudan,yi su dan,Іссуден,Исудён,ایسودن,イスーダン,伊苏丹', 46.9500000, 2.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54520, 'Issou', 'Issou', 'Issou,Issu,Іссу,Иссу', 48.9899400, 1.7929200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54521, 'Issoire', 'Issoire', 'Iciodurum,Issoire,Issuar,Soire,isowaru,xisawr,yi su wa er,Іссуар,Иссуар,อีซัวร์,イソワール,伊苏瓦尔', 45.5500000, 3.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54522, 'Issenheim', 'Issenheim', 'Isenheim,Issenajm,yi se nan,Іссенайм,Иссенайм,伊瑟南', 47.9035700, 7.2523500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54523, 'Issé', 'Isse', 'Isse,Issé,Izeg', 47.6241900, -1.4515200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54524, 'Isques', 'Isques', 'Isk,Isques,askywys,yi si ke,Іск,Иск,إسكيويس,伊斯克', 50.6739100, 1.6544500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54525, 'Isneauville', 'Isneauville', 'Isneauville', 49.4983200, 1.1543100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54526, 'Isle', 'Isle', 'Isla,Isle', 45.8027200, 1.2121300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54527, 'Isigny-sur-Mer', 'Isigny-sur-Mer', 'Isigny,Isigny-sur-Mer,Izin''i-sjur-Mer,bin hai yi xi ni,Ізіньї-сюр-Мер,Изиньи-сюр-Мер,滨海伊西尼', 49.3160400, -1.1038400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54528, 'Isigny-le-Buat', 'Isigny-le-Buat', 'Isigny,Isigny-le-Buat,Izin''i-le-Bjua,yi xi ni lai bi a,Ізіньї-ле-Бюа,Изиньи-ле-Бюа,伊西尼莱比阿', 48.6170500, -1.1699300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54529, 'Isbergues', 'Isbergues', 'Iberque,Isberg,Isbergues,asbyrjws,yi si bei ge,Ісберг,Исберг,إسبيرجوس,伊斯贝格', 50.6232800, 2.4590200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54530, 'Irvillac', 'Irvillac', 'Irvijak,Irvilhag,Irvillac,Irvillak,yi er wei la ke,Ірвіллак,Ирвийак,Ирвиллак,伊尔维拉克', 48.3701100, -4.2122300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54531, 'Irodouër', 'Irodouer', 'Irodouer,Irodouër', 48.2493200, -1.9495900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54532, 'Irmstett', 'Irmstett', 'Irmstett', 48.5885600, 7.4774700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54533, 'Irigny', 'Irigny', 'Irigny,Irin''i,L''Union-sur-Rhone,L''Union-sur-Rhône,Іриньї', 45.6736200, 4.8175300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54534, 'Innenheim', 'Innenheim', 'Innenheim', 48.4965900, 7.5743900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54535, 'Ingwiller', 'Ingwiller', 'Ingeweiler,Ingweiler', 48.8728400, 7.4798000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54536, 'Inguiniel', 'Inguiniel', 'An Ignel,Engin''el'',Inguiniel,an ji nie,Енгиньель,Енгіньєль,安吉涅', 47.9765800, -3.2807200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54537, 'Ingré', 'Ingre', 'Engre,Ingre,Ingré,an ge lei,Енгре,安格雷', 47.9199500, 1.8277800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54538, 'Ingrandes', 'Ingrandes', 'Ingrandes,Ingrandes-sur-Loire', 47.4050000, -0.9233600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54539, 'Ingersheim', 'Ingersheim', '', 48.0980300, 7.3030800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54540, 'Incheville', 'Incheville', 'Incheville', 50.0123900, 1.4943800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54541, 'Imphy', 'Imphy', 'Imphy', 46.9361900, 3.2603700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54542, 'Illzach', 'Illzach', 'Il''zak,Illzach,iruzakku,yi er zha ke,Ільзак,Ильзак,イルザック,伊尔扎克', 47.7808800, 7.3466200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54543, 'Illkirch-Graffenstaden', 'Illkirch-Graffenstaden', 'Il''kirsh-Graffenshtaden,Il''kirsh-Graffenstaden,Ilkirkh Grafenshtaden,Illkirch,Illkirch-Grafenstaden,Illkirch-Graffenshaharen,Illkirch-Graffenstaden,Illkirich-Graffestade,akyrtsh,aylykyr  grfanstdan,ilkileusyugeulapenseutaden,irukirushu=gurafensutaden,yi er ji er ke ge la fang si ta dang,Íllkírich-Gràffestàde,Ількірш-Граффенстаден,Илкирх Графенштаден,Илькирш-Граффенстаден,Илькирш-Граффенштаден,إكيرتش,ایلکیرش-گرافن‌شتادن,ایلیکیر، گرفانستدان,イルキルシュ＝グラフェンスタデン,伊尔基尔克格拉方斯塔当,일키르슈그라펜스타덴', 48.5289400, 7.7152300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54544, 'Illies', 'Illies', 'Illies', 50.5614400, 2.8301100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54545, 'Illfurth', 'Illfurth', 'Illfurth', 47.6729100, 7.2653900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54546, 'Ille-sur-Têt', 'Ille-sur-Tet', 'Il''-sjur-Tet,Illa,Ille,Ille-sur-Tet,Ille-sur-Têt,Ille-sur-la-Tet,tai he pan yi er,Іль-сюр-Тет,Иль-сюр-Тет,泰河畔伊尔', 42.6706900, 2.6216200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54547, 'Illats', 'Illats', 'Illats', 44.5971400, -0.3723800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54548, 'Illange', 'Illange', 'Illange', 49.3308400, 6.1816600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54549, 'Igoville', 'Igoville', 'Igoville', 49.3199000, 1.1483200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54550, 'Igon', 'Igon', 'Aigon,Igon,yi gong,Ігон,Игон,伊贡', 43.1666700, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54551, 'Igny', 'Igny', 'Igny', 48.7443700, 2.2242800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54552, 'Igney', 'Igney', 'Igney', 48.2735800, 6.3966400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54553, 'Ifs', 'Ifs', 'Ifs', 49.1400000, -0.3489900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54554, 'Iffendic', 'Iffendic', 'Iffandik,Iffendic,Ilfentig,yi fang di ke,Іффандік,Иффандик,伊方迪克', 48.1298100, -2.0348600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54555, 'Idron', 'Idron', 'Idron,Idron-Ousse-Sendets,yi de long,Ідрон,Идрон,伊德龙', 43.2833300, -0.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54556, 'Ibos', 'Ibos', 'Ibos', 43.2333300, 0.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54557, 'Hyères', 'Hyeres', 'Er,Hyeres,Hyerès,Hyères,Ier,Ieras,Jer,ayyr,hyyrys,ieru,yeleu,yi ai lei,Єр,Јер,Иер,Йер,ایئر,هييريس,イエール,伊埃雷,예르', 43.1203800, 6.1285700, 'FR', '2017-05-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54558, 'Huttenheim', 'Huttenheim', '', 48.3586400, 7.5783300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54559, 'Hussigny-Godbrange', 'Hussigny-Godbrange', 'Hussigny,Hussigny-Godbrange', 49.4911900, 5.8668300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54560, 'Husseren-Wesserling', 'Husseren-Wesserling', 'Husseren,Husseren-Wesserling,Hüsseren', 47.8829700, 6.9938800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54561, 'Hurigny', 'Hurigny', 'Hurigny', 46.3472200, 4.7967600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54562, 'Huriel', 'Huriel', 'Huriel,Jur''el'',Jurel'',Uriac,Uriat,yu li ye,Юрьель,Юрєль,于里耶', 46.3736800, 2.4779300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54563, 'Huningue', 'Huningue', 'Hueningen,Hüningen,Juneng,Uning,yu nan gai,yunangu,Унинг,Унінг,Юненг,ユナング,于南盖', 47.6047700, 7.5778200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54564, 'Hundling', 'Hundling', 'Hundling', 49.1081500, 6.9780900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54565, 'Hulluch', 'Hulluch', 'Hulluch,Julljush,hwlwtsh,yu lu shen,Юллюш,هولوتش,于吕什', 50.4896100, 2.8123200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54566, 'Huisseau-sur-Mauves', 'Huisseau-sur-Mauves', 'Huisseau-sur-Mauve,Huisseau-sur-Mauves,Juisso-sjur-Mov,mo wei he pan yu yi suo,Юїссо-сюр-Мов,莫韦河畔于伊索', 47.8931900, 1.7027400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54567, 'Huisseau-sur-Cosson', 'Huisseau-sur-Cosson', 'Huisseau,Huisseau-sur-Cosson,Huisseaux-sur-Cosson', 47.5933500, 1.4533300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54568, 'Huismes', 'Huismes', 'Huismes,Juim,yu yi si mei,Юїм,于伊斯梅', 47.2331900, 0.2511600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54569, 'Huez', 'Huez', 'Huez,L''Huez,L’Huez', 45.0825200, 6.0584800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54570, 'Huelgoat', 'Huelgoat', 'An Uhelgoad,Huelgoat,Juel''goa,yu ai er ge a,Юельгоа,于埃尔戈阿', 48.3611100, -3.7457800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54571, 'Hoymille', 'Hoymille', 'Hooimille,Hoymille,Ooimille,Uamil'',ao mi ye,Уамиль,Уаміль,奥米耶', 50.9718700, 2.4473800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54572, 'Houssen', 'Houssen', 'Gasen,Haussen,Houssen,Ussen,wu sang,Гасен,Уссен,乌桑', 48.1258100, 7.3784100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54573, 'Hourtin', 'Hourtin', 'Hourtin', 45.1857000, -1.0571900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54574, 'Houppeville', 'Houppeville', 'Houppeville', 49.5125900, 1.0796200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54575, 'Houplines', 'Houplines', 'Houplines,Opline,Uplin,wu pu li ne,Уплин,Уплін,乌普利讷', 50.6949900, 2.9151800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54576, 'Houplin-Ancoisne', 'Houplin-Ancoisne', 'Houplin,Houplin-Ancoisne,Uplen-Ankuan,wu pu lan ang kuan ne,Уплен-Анкуан,乌普兰昂宽讷', 50.5628400, 3.0025100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54577, 'Houlgate', 'Houlgate', 'Houlgate,Ul''gat,wu er jia te,Ульгат,乌尔加特', 49.2990000, -0.0815300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54578, 'Houlbec-Cocherel', 'Houlbec-Cocherel', 'Houlbec,Houlbec-Cocherel,Ul''bek-Kosherel'',wu er bei ke ke xie lei,Ульбек-Кошерель,乌尔贝克科谢雷', 49.0735000, 1.3656300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54579, 'Houilles', 'Houilles', 'Houilles,Uj,awy,awy  aywlyn,u-il,uiyu,Уй,Уј,اوی,اوی، ایولین,ウイユ,우일', 48.9216100, 2.1926300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54580, 'Houdemont', 'Houdemont', 'Hondimont', 48.6500000, 6.1833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54581, 'Houdan', 'Houdan', 'Houdan,Udan,Удан', 48.7904400, 1.6000700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54582, 'Houdain', 'Houdain', 'Houdain,Uden,hwdayn,wu dan,Уден,هوداين,乌丹', 50.4504000, 2.5377700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54583, 'Hornoy-le-Bourg', 'Hornoy-le-Bourg', 'Hornoe-l''Bourq,Hornoè-l’Bourq,Ornua-le-Bur,ao er nu wa bao,Орнуа-ле-Бур,奥尔努瓦堡', 49.8500000, 1.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54584, 'Hornaing', 'Hornaing', 'Hornaing,Ornen,ao er nan,Орнен,奥尔南', 50.3683500, 3.3370700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54585, 'Horgues', 'Horgues', 'Horgues', 43.1886500, 0.0873300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54586, 'Hordain', 'Hordain', 'Hordain,Orden,ao er dan,Орден,奥尔丹', 50.2630600, 3.3135800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54587, 'Horbourg-Wihr', 'Horbourg-Wihr', '', 48.0810600, 7.3938000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54588, 'Honfleur', 'Honfleur', 'Anfljor,Honfleur,Honnefluctus,Onfler,Onfljor,awnflwr,onfururu,ongpeulloeleu,weng fu lei,Ονφλέρ,Анфлёр,Онфлер,Онфлёр,אונפלר,اونفلور,オンフルール,翁夫勒,옹플뢰르', 49.4198500, 0.2329400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54589, 'Hondschoote', 'Hondschoote', 'Hondschoote,Hondschote,Ondshoot,Ondskot,Oundschote,weng si ke te,Ондскот,Ондшоот,翁斯科特', 50.9780000, 2.5837200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54590, 'Homécourt', 'Homecourt', 'Homecourt,Homécourt,Omekur,ao mei ku er,Омекур,奥梅库尔', 49.2211100, 5.9844500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54591, 'Hombourg-Haut', 'Hombourg-Haut', 'Hombourg-Haut,Hombourg-l''Eveque,Hombourg-le-Haut,Hombourg-l’Évéque,Oberhomburg,Ombur-O,Ombur-Ot,weng bu er ao,Омбур-О,Омбур-От,翁布尔奥', 49.1235900, 6.7739700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54592, 'Homblières', 'Homblieres', 'Homblieres,Homblières', 49.8503100, 3.3645600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54593, 'Hombleux', 'Hombleux', 'Hombleux', 49.7394200, 2.9857400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54594, 'Holving', 'Holving', 'Holving,Holvingen', 49.0096500, 6.9652900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54595, 'Holtzwihr', 'Holtzwihr', 'Holtzwihr,Holzweier,Khol''cvir,Ol''cvir,ao er te ci wei,Ольцвир,Ольцвір,Хольцвир,奥尔特兹维', 48.1127800, 7.4204600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54596, 'Holtzheim', 'Holtzheim', 'Holtzheim', 48.5582000, 7.6443400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54597, 'Holnon', 'Holnon', 'Holnon', 49.8608600, 3.2150900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54598, 'Hœrdt', 'Hoerdt', 'Erdt,Herdt,Hoerdt,Hördt,hwrdt,Ердт,هوردت', 48.7000000, 7.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54599, 'Hœnheim', 'Hoenheim', '', 48.6222400, 7.7554900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54600, 'Hochstatt', 'Hochstatt', 'Hochstatt', 47.7034300, 7.2758300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54601, 'Hochfelden', 'Hochfelden', '', 48.7573800, 7.5676900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54602, 'Hirtzfelden', 'Hirtzfelden', 'Hirtzfelden,Hirzfelden', 47.9107900, 7.4466900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54603, 'Hirtzbach', 'Hirtzbach', 'Hirtzbach', 47.5961800, 7.2204300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54604, 'Hirson', 'Hirson', 'Hirson,Irson,Urchon,yi er song,Ірсон,Ирсон,伊尔松', 49.9226200, 4.0825900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54605, 'Hirsingue', 'Hirsingue', 'Hirsingen,Hirsingue,Irseng,yi er sang ge,Ірсенг,Ирсенг,伊尔桑格', 47.5865500, 7.2513000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54606, 'Hirel', 'Hirel', 'Hirel,Irel'',Ірель,Ирель', 48.6050200, -1.8022400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54607, 'Hinx', 'Hinx', 'Hinx', 43.7019000, -0.9259100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54608, 'Hinges', 'Hinges', 'Hinges', 50.5667400, 2.6216000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54609, 'Hindisheim', 'Hindisheim', 'Endisajm,Hindisheim,Hindse,Híndse,an di sang,hyndyshaym,hyndyshym,Ендисайм,Ендісайм,هينديشيم,هیندیسهایم,安迪桑', 48.4683700, 7.6385900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54610, 'Hilsenheim', 'Hilsenheim', 'Hilse,Hilsenheim,Hílse,Il''senajm,hylsynhym,hylznhaym,yi er se nan,Ільсенайм,Ильсенайм,هيلسينهيم,هیلزنهایم,伊尔瑟南', 48.2875600, 7.5652200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54611, 'Hillion', 'Hillion', 'Hilion,Hillion', 48.5142900, -2.6663400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54612, 'Hiersac', 'Hiersac', 'Ersak,Hiersac,Jersak,ye er sa ke,Єрсак,Йерсак,耶尔萨克', 45.6666700, 0.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54613, 'Hières-sur-Amby', 'Hieres-sur-Amby', 'Hieres,Hieres-sur-Amby,Hières,Hières-sur-Amby,Ier-sjur-Ambi,ang bi he pan ai,Ієр-сюр-Амбі,Иер-сюр-Амби,昂比河畔埃', 45.7978300, 5.2946700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54614, 'Heyrieux', 'Heyrieux', 'Heyrieux', 45.6285300, 5.0584900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54615, 'Heuringhem', 'Heuringhem', 'Erengem,Heuringhem,e lan gai mu,hywrynhym,Еренгем,هيورينهيم,厄兰盖姆', 50.6963800, 2.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54616, 'Heugas', 'Heugas', 'Heugas', 43.6433400, -1.0814300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54617, 'Heudreville-sur-Eure', 'Heudreville-sur-Eure', 'Heudreville,Heudreville-sur-Eure', 49.1408900, 1.1881300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54618, 'Hettange-Grande', 'Hettange-Grande', 'Ettanzh-Grand,Grosshettingen,Grouss-Hetteng,Großhettingen,Hettange-Grande,Hettange-la-Grande,ai tang ge ge lang de,Еттанж-Гранд,埃唐格格朗德', 49.4063900, 6.1505700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54619, 'Hésingue', 'Hesingue', 'Hesingen,Hesingue,Hésingue', 47.5762100, 7.5224400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54620, 'Hesdin', 'Hesdin', 'Eden,Ehden,Hesdin,Hesdinum,ai dan,hysdyn,Еден,Эден,هيسدين,埃丹', 50.3734900, 2.0382000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54621, 'Herzeele', 'Herzeele', 'Herzeele', 50.8858400, 2.5351000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54622, 'Héry', 'Hery', 'Hery,Héry', 47.9014600, 3.6286800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54623, 'Hersin-Coupigny', 'Hersin-Coupigny', 'Hersin,Hersin-Coupigny', 50.4479600, 2.6494000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54624, 'Herserange', 'Herserange', 'Herserange', 49.5175800, 5.7816300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54625, 'Herry', 'Herry', 'Herry', 47.2166700, 2.9538500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54626, 'Herrlisheim-près-Colmar', 'Herrlisheim-pres-Colmar', 'Ehrlisajm-pre-Kol''mar,Errlisajm-pre-Kol''mar,Herrlisheim,ai er li sang pu lei ke er ma,Еррлисайм-пре-Кольмар,Еррлісайм-пре-Кольмар,Эрлисайм-пре-Кольмар,埃尔利桑普雷科尔马', 48.0183500, 7.3266800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54627, 'Herrlisheim', 'Herrlisheim', 'Herrlisheim-pres-Colmar,Herrlisheim-près-Colmar', 48.7304900, 7.9053500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54628, 'Hérouvillette', 'Herouvillette', 'Herouvillette,Hérouvillette', 49.2213000, -0.2434800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54629, 'Hérouville-Saint-Clair', 'Herouville-Saint-Clair', 'Ehruvil''-Sen-Kler,Eruvil Sen Kler,Eruvil''-Sen-Kler,Herouville,Herouville Saint-Clair,Herouville-Saint-Clair,Hérouville,Hérouville Saint-Clair,Hérouville-Saint-Clair,ai lu wei er sheng ke lai,arwwy sn klr,arwwyl-sn-klr,elubilsaengkeulleleu,eruvu~iru=san=kureru,Ерувил Сен Клер,Ерувиль-Сен-Клер,Ерувіль-Сен-Клер,Эрувиль-Сен-Клер,ارووی سن کلر,اروویل-سن-کلر,エルヴィル＝サン＝クレール,埃鲁维尔圣克莱,에루빌생클레르', 49.2108800, -0.3065300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54630, 'Hermonville', 'Hermonville', 'Ermonvil'',Hermonville,ai er meng wei er,Ермонвіль,埃尔蒙维尔', 49.3365500, 3.9101100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54631, 'Hermies', 'Hermies', 'Hermies', 50.1112600, 3.0420200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54632, 'Hermes', 'Hermes', 'Hermes', 49.3603200, 2.2446100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54633, 'Hermanville-sur-Mer', 'Hermanville-sur-Mer', 'Ehrmanvil''-sjur-Mer,Ermanvil''-sjur-Mer,Hermanville,Hermanville-sur-Mer,bin hai ai er mang wei er,Ерманвиль-сюр-Мер,Ерманвіль-сюр-Мер,Эрманвиль-сюр-Мер,滨海埃尔芒维尔', 49.2846400, -0.3154400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54634, 'Herlies', 'Herlies', 'Herlies', 50.5775300, 2.8528500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54635, 'Hérin', 'Herin', 'Eren,Herin,Hérin,ai lan,Ерен,埃兰', 50.3555700, 3.4530900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54636, 'Hérimoncourt', 'Herimoncourt', 'Herimoncourt,Hérimoncourt', 47.4428400, 6.8824200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54637, 'Héricy', 'Hericy', 'Erisi,Hericy,Hericy-sur Seine,Héricy,Héricy-sur Seine,Ериси,Ерисі', 48.4484800, 2.7644500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54638, 'Héricourt', 'Hericourt', 'Hericourt,Héricourt', 47.5730500, 6.7613900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54639, 'Héric', 'Heric', 'Erik,Heric,Hierig,Héric,Ерик', 47.4141700, -1.6530900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54640, 'Hergnies', 'Hergnies', 'Hergines,Hergnies', 50.4728700, 3.5261200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54641, 'Hérépian', 'Herepian', 'Herepian,Hérépian', 43.5930000, 3.1159500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54642, 'Herblay', 'Herblay', 'Ehrble,Erble,Herblay,ai er bu lai,arblh,eleubeulle,erubure,Ербле,Эрбле,اربله,エルブレ,埃尔布莱,에르블레', 48.9899400, 2.1699000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54643, 'Herbitzheim', 'Herbitzheim', 'Erbicajm,Herbitzheim,Herzum,ai er bi te zan,hrbytshaym,hyrbtzhym,Ербицайм,Ербіцайм,هربیتسهایم,هيربتزهيم,埃尔比特赞', 49.0140700, 7.0902200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54644, 'Herbignac', 'Herbignac', 'Erbigneg,Erbin''jak,Herbignac,ai er bi ni ya ke,erubinyakku,Ербіньяк,エルビニャック,埃尔比尼亚克', 47.4482200, -2.3181000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54645, 'Herbeys', 'Herbeys', 'Herbey,Herbeys', 45.1373500, 5.7959200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54646, 'Herbault', 'Herbault', 'Erbo,Herbault,ai er bo er,Ербо,埃尔博尔', 47.6050100, 1.1393400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54647, 'Henvic', 'Henvic', 'Anvik,Envik,Henvic,Henvig,ang wei ke,Анвик,Анвік,Енвик,昂维克', 48.6325600, -3.9262300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54648, 'Henrichemont', 'Henrichemont', 'Anrishmon,Henrichement,Henrichemont,ang li shang weng,Анришмон,昂里尚翁', 47.3033300, 2.5245800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54649, 'Hénouville', 'Henouville', 'Enuvil'',Henouville,Hénouville,Енувиль,Енувіль', 49.4789000, 0.9636700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54650, 'Hénon', 'Henon', 'Henon,Hénon', 48.3843300, -2.6833400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54651, 'Hennebont', 'Hennebont', 'Anbon,Ehnbon,Ennbon,Hannebotum,Henbont,Hennebont,ai nei bang,en''nubon,Анбон,Еннбон,Энбон,エンヌボン,埃内邦', 47.8051200, -3.2733700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54652, 'Hénin-Beaumont', 'Henin-Beaumont', 'Ehnen-Bomon,Enen Bomon,Enen-Bomon,Henin-Beaumont,Henin-Lietard,Hinnin-Biaumont,Hénin-Beaumont,Hénin-Liétard,L''Humanite,L''Humanité,ai nan bo meng,ann bwmwn,ann-bwmwn,enaengbomong,enan=bomon,hynan bwmwnt,Енен Бомон,Енен-Бомон,Энен-Бомон,انن بومون,انن-بومون,هينان بومونت,エナン＝ボーモン,埃南博蒙,에냉보몽', 50.4135900, 2.9648500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54653, 'Hendaye', 'Hendaye', 'Andaj,Andej,Hendaia,Hendaya,Hendaye,XHY,andaie,ang dai yi,Андай,Андеј,アンダイエ,昂代伊', 43.3717200, -1.7738200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54654, 'Hénanbihen', 'Henanbihen', 'Henanbihen,Henant-Bihan,Hénanbihen', 48.5607200, -2.3760200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54655, 'Hem', 'Hem', '', 50.6525600, 3.1868100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54656, 'Helfaut', 'Helfaut', 'Ehl''fo,El''fo,Elfo,Helfaut,Helfaut-Bliques,ai er fu,hylfawt,Елфо,Ельфо,Эльфо,هيلفاوت,埃尔福', 50.6978300, 2.2423400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54657, 'Hélesmes', 'Helesmes', 'Helesmes,Hélesmes', 50.3703600, 3.3591800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54658, 'Heimsbrunn', 'Heimsbrunn', 'Heimsbrunn', 47.7264700, 7.2263800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54659, 'Heillecourt', 'Heillecourt', 'Heillecourt', 48.6585400, 6.2071100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54660, 'Hégenheim', 'Hegenheim', 'Egenajm,Ehgenajm,Hegenheim,Hégenheim,ai re nan,Егенайм,Эгенайм,埃热南', 47.5625100, 7.5268400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54661, 'Hédé-Bazouges', 'Hede-Bazouges', 'Ede,Hazhou,Hazhou-Bazeleg,Hazhoù,Hazhoù-Bazeleg,Hede-Bazouges,Hédé-Bazouges,ai dai,Еде,埃代', 48.3000000, -1.8000000, 'FR', '2016-05-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54662, 'Hazebrouck', 'Hazebrouck', 'Azbruk,Azebruk,HZB,Hazebroek,Hazebrouck,Oazebroeke,a ci bu lu ke,ajeubeulukeu,azbrwk,azuburukku,Азбрук,Азебрук,ازبروک,アーズブルック,阿兹布鲁克,아즈브루크', 50.7237400, 2.5372900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54663, 'Haybes', 'Haybes', 'Eb,Ehb,Haybes,Haybes-sur-Meuse,ai bu,Еб,Эб,艾布', 50.0045800, 4.7049600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54664, 'Hayange', 'Hayange', 'Ajanzh,Eanzh,Hayange,Hyange,ai ang ge,hyanzh,Ајанж,Еанж,هیانژ,艾昂格', 49.3342800, 6.0526700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54665, 'Haverskerque', 'Haverskerque', 'Avekerk,Averskerk,Haverskerke,Haverskerque,Oaverskerke,a wei er kai er ke,Авекерк,Аверскерк,阿韦尔凯尔克', 50.6408900, 2.5416200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54666, 'Haveluy', 'Haveluy', 'Aveljui,Avlij,Haveluy,a wei lu yi,Авелюи,Авелюї,Авлиј,阿韦吕伊', 50.3528900, 3.4038900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54667, 'Hauville', 'Hauville', 'Hauville,Ovil,Ovil'',Овил,Овиль,Овіль', 49.3964500, 0.7723200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54668, 'Hautot-sur-Mer', 'Hautot-sur-Mer', 'Hautot,Hautot-sur-Mer', 49.8978900, 1.0288400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54669, 'Hautmont', 'Hautmont', 'Omon,Otmon,ou meng,Омон,Отмон,欧蒙', 50.2507700, 3.9214300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54670, 'Yutz', 'Yutz', 'Jeutz,Jjus,Juc,Yutz Haute,yi yu te,ywts,Йюс,Юц,یوتس,یوٹز,伊于特', 49.3557100, 6.1926000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54671, 'Hauteville-Lompnes', 'Hauteville-Lompnes', 'Hauteville,Hauteville-Lompnes,Hauteville-Lompnès,Hotvil Lonnes,Otvil Lon,Otvil''-Lomne,Otvil''-Lones,ao te wei ye-long nei si,hwtfyl-lwmny,Отвил Лон,Отвиль-Лонес,Отвіль-Ломне,Հոտվիլ Լոննես,هوتفيل-لومني,奥特维耶－隆内斯', 45.9779400, 5.6011400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54672, 'Hauteville-lès-Dijon', 'Hauteville-les-Dijon', 'Hauteville,Hauteville-les-Dijon,Hauteville-lès-Dijon,Otvil le Dizhon,Otvil''-le-Dizhon,ao te wei er lai di rong,Отвил ле Дижон,Отвиль-ле-Дижон,Отвіль-ле-Діжон,奥特维尔莱迪容', 47.3660200, 4.9937500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54673, 'Haute-Rivoire', 'Haute-Rivoire', 'Haute-Rivoire', 45.7152600, 4.3966200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54674, 'Hauterives', 'Hauterives', 'Hauterives,Otriv,ao te li wei,Отрив,奥特里韦', 45.2562000, 5.0257200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54675, 'Hauterive', 'Hauterive', 'Hauterive', 46.0900500, 3.4459300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54676, 'Haute-Goulaine', 'Haute-Goulaine', 'Gorre-Goulen,Haute-Goulaine,Ot Gulen,Ot-Gulen,Sancta Radegundis de Golena,ao te gu lan,oto=gurenu,От Гулен,От-Гулен,オート＝グレーヌ,奥特古兰', 47.1990500, -1.4294100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54677, 'Hautefort', 'Hautefort', 'Aignan-Haute-Vue,Autafort,Autafòrt,Hautefort,Otfor,ao tai fu er,Отфор,奥泰福尔', 45.2595300, 1.1487900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54678, 'Haussy', 'Haussy', 'Haussy,Osi,Ossi,ou xi,Оси,Осси,Оссі,欧西', 50.2183000, 3.4768300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54679, 'Haulchin', 'Haulchin', 'Haulchin', 50.3172000, 3.4359900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54680, 'Haucourt-Moulaine', 'Haucourt-Moulaine', 'Haucourt,Haucourt-Moulaine', 49.4902200, 5.8028300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54681, 'Haubourdin', 'Haubourdin', 'Haubourdin,Oburden,ou bu er dan,Обурден,欧布尔丹', 50.6082600, 2.9914300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54682, 'Haspres', 'Haspres', 'Aspr,Aspre,Haspres,a si pu er,Аспр,Аспре,阿斯普尔', 50.2582900, 3.4169500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54683, 'Hasparren', 'Hasparren', 'Asparan,Asparran,Hasparn,Hasparren,Hazparne,a si pa lang,Аспаран,Аспарран,阿斯帕朗', 43.3837700, -1.3049900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54684, 'Hasnon', 'Hasnon', 'Anon,Hasnon,a nong,Анон,阿农', 50.4247200, 3.3865700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54685, 'Harnes', 'Harnes', 'Arn,Harnes,a er ne,harnys,Арн,هارنيس,阿尔讷', 50.4464300, 2.9048100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54686, 'Harly', 'Harly', 'Harly', 49.8376600, 3.3100100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54687, 'Hargarten-aux-Mines', 'Hargarten-aux-Mines', 'Hargarten,Hargarten-aux-Mines', 49.2242900, 6.6094200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54688, 'Harfleur', 'Harfleur', 'Arfler,Arfljor,Harfleur,Port de Harfleur,harflwr,Арфлер,Арфлёр,ארפלור,هارفلور', 49.5066000, 0.1982700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54689, 'Hardricourt', 'Hardricourt', 'Ardrikur,Hardricourt,Ардрикур', 49.0077900, 1.8938900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54690, 'Hardinghen', 'Hardinghen', 'Ardengan,Hardinghen,Hardinghin,a er dan gang,hardynhyn,Арденган,هاردينهين,阿尔丹冈', 50.8041400, 1.8212200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54691, 'Harbonnières', 'Harbonnieres', 'Arbon''er,Arbonijer,Harbonnieres,Harbonnières,Harbouniere,Harbounière,a er bo ni ye er,Арбонијер,Арбоньєр,阿尔博尼耶尔', 49.8495800, 2.6681200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54692, 'Hanvec', 'Hanvec', 'Anvek,Hanvec,Hanveg,Hañveg,ang wei ke,Анвек,昂韦克', 48.3269200, -4.1595100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54693, 'Hangenbieten', 'Hangenbieten', 'Hangenbieten', 48.5598500, 7.6146400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54694, 'Hanches', 'Hanches', 'Hanches', 48.6011500, 1.6513700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54695, 'Ham-sous-Varsberg', 'Ham-sous-Varsberg', 'Ham,Ham-sous-Varsberg', 49.1803100, 6.6462600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54696, 'Hames-Boucres', 'Hames-Boucres', 'Am Bukr,Am-Bukr,Hames,Hames-Boucres,a mu bu ke er,hamys bwsrys,Ам Букр,Ам-Букр,هاميس بوسريس,阿姆布克尔', 50.8817800, 1.8433800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54697, 'Hambye', 'Hambye', 'Ambi,Hambye,ang bi ai,Амби,Амбі,昂比埃', 48.9479800, -1.2641700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54698, 'Hambach', 'Hambach', 'Hambach', 49.0626300, 7.0424600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54699, 'Ham', 'Ham', 'Ham,Sparte', 49.7472100, 3.0730100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54700, 'Halluin', 'Halluin', 'Alijen,Alljuehn,Alljuen,Halewijn,Halluin,Oalewyne,a lu an,Алијен,Аллюен,Аллюэн,阿吕安', 50.7862800, 3.1261100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54701, 'Hallines', 'Hallines', 'Alin,Allin,Hallines,a li ne,halyns,Алин,Аллин,Аллін,هالينس,阿利讷', 50.7108700, 2.2262900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54702, 'Hallennes-lez-Haubourdin', 'Hallennes-lez-Haubourdin', 'Alan le Oburden,Allenn-le-Oburden,Hallennes,Hallennes-lez-Haubourdin,a lai ne lai ou bu er dan,Алан ле Обурден,Алленн-ле-Обурден,阿莱讷莱欧布尔丹', 50.6166700, 2.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54703, 'Hallencourt', 'Hallencourt', 'Alankur,Allankur,Hallencourt,a lang ku er,arankuru,Аланкур,Алланкур,アランクール,阿朗库尔', 49.9920100, 1.8764900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54704, 'Haisnes', 'Haisnes', 'Haisnes,Haisnes-lez la Bassee,Haisnes-lez la Bassée', 50.5077600, 2.7941600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54705, 'Haillicourt', 'Haillicourt', 'Aikur,Ajikur,Haillicourt,a yi ku er,haylykwrt,Аикур,Айикур,Аїкур,Ајикур,هايليكورت,阿伊库尔', 50.4751900, 2.5745800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54706, 'Haguenau', 'Haguenau', 'Ageno,Agenu,Agijeno,Agno,Ankno,Hagenau,Haguenau,Hawenau,Hàwenau,a gai nuo,ageuno,agno,agnw,aguno,haghwynaw,Αγκνώ,Агено,Агену,Агијено,Агно,אגנו,اگنو,هاغويناو,აგნო,アグノー,阿盖诺,아그노', 48.8155700, 7.7905100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54707, 'Hagondange', 'Hagondange', 'Agondanzh,Hagendingen,Hagondange,a gong dang ge,hagndanzh,Агонданж,هاگندانژ,阿贡当格', 49.2513400, 6.1681200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54708, 'Hagetmau', 'Hagetmau', 'Azhemo,Azhetmo,a re te mo,Ажемо,Ажетмо,阿热特莫', 43.6589300, -0.5917200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54709, 'Hagenthal-le-Bas', 'Hagenthal-le-Bas', '', 47.5249700, 7.4778300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54710, 'Hadol', 'Hadol', 'Adol,Adol'',Hadol,a duo,Адол,Адоль,阿多', 48.0898300, 6.4766200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54711, 'Habsheim', 'Habsheim', 'Habsheim', 47.7308700, 7.4185500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54712, 'Habas', 'Habas', 'Habas', 43.5718000, -0.9297600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54713, 'Gy', 'Gy', 'Gy', 47.4058800, 5.8122600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54714, 'Guyancourt', 'Guyancourt', 'Gijankur,Gjujankur,Guyancourt,giangkuleu,gwyankwr,gyuiyankuru,ji yang gu er,Гиянкур,Гијанкур,Гюйанкур,Гіянкур,گویانکور,ギュイヤンクール,基揚古爾,기앙쿠르', 48.7733400, 2.0739300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54715, 'Gurgy', 'Gurgy', 'Gurgy', 47.8671200, 3.5634100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54716, 'Gundershoffen', 'Gundershoffen', 'Gundershoffen', 48.9064800, 7.6609600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54717, 'Gumbrechtshoffen', 'Gumbrechtshoffen', 'Niederbronn', 48.9058000, 7.6291500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54718, 'Gujan-Mestras', 'Gujan-Mestras', 'Gjuzhan-Mestras,Gujan,Gujan e Mestras,Gujan e Mestràs,Gujan-Mestras,Gujan-et-Mestras,ju rang mei si te la,Гюжан-Местрас,居让梅斯特拉', 44.6333300, -1.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54719, 'Guîtres', 'Guitres', 'Gitr,Gjuitr,Guitres,Guîtres,ji te lei,Гитр,Гюитр,Гюїтр,吉特雷', 45.0333300, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54720, 'Guissény', 'Guisseny', 'Gisseni,Guisseny,Guissény,Gwiseni,Гиссени,Гіссені', 48.6329200, -4.4088400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54721, 'Guise', 'Guise', 'Beaupre,Beaupré,Giz,Gjuiz,Guisa,Guise,Reunion-sur-Oise,Réunion-sur-Oise,ji si,Гиз,Гюиз,Гіз,吉斯', 49.9005500, 3.6280100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54722, 'Guiscriff', 'Guiscriff', 'Giskriff,Guiscriff,Guiseriff,Gwiskri,ji si ke li,Гискрифф,Гіскрифф,吉斯克里', 48.0494400, -3.6435600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54723, 'Guiscard', 'Guiscard', 'Guiscard', 49.6566000, 3.0512700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54724, 'Guipry', 'Guipry', 'Gipri,Guipry,Gwipri,Wippericum,ji pu li,Гипри,Гіпрі,吉普里', 47.8263700, -1.8421800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54725, 'Guipel', 'Guipel', 'Guipel,Gwipedel', 48.2993700, -1.7186600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54726, 'Guipavas', 'Guipavas', 'Gipava,Guipavas,Gwipavaz,ji pa wa,Гипава,Гіпава,吉帕瓦', 48.4352200, -4.3972200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54727, 'Guingamp', 'Guingamp', 'Gengam,Gengan,Genganas,Gingam,Guengampum,Guingamp,Gwengamp,gaeng-gang,gan gang,gangan,ghanghan,gngamn,gngamp,Генгам,Генган,Гингам,غانغان,گنگامن,گنگامپ,ガンガン,甘岡,갱강', 48.5500000, -3.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54728, 'Guînes', 'Guines', 'Gin,Gjuin,Guines,Guines-en-Calaisis,Guinne,Guînes,Guînes-en-Calaisis,ji ne,jwynys,Гин,Гюин,Гюїн,جوينيس,吉讷', 50.8670800, 1.8702500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54729, 'Guilvinec', 'Guilvinec', 'Ar Gelveneg,Gil''vinek,Le Guilvinec,ji er wei nei ke,Гильвинек,Гільвінек,吉尔维内克', 47.7986100, -4.2811100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54730, 'Guilliers', 'Guilliers', 'Guilliers,Gwiler-Porc''hoed', 48.0428600, -2.4056200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54731, 'Guillestre', 'Guillestre', 'Gijestr,Gillestr,Guilhestra,Guilhèstra,ji lai si te er,Гийестр,Гіллестр,吉莱斯特尔', 44.6595000, 6.6494800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54732, 'Guillac', 'Guillac', 'Gilieg,Guillac', 47.9109600, -2.4657100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54733, 'Guilherand-Granges', 'Guilherand-Granges', 'Granges-les-Valence,Granges-lès-Valence', 44.9327800, 4.8737200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54734, 'Guilers', 'Guilers', 'Gile,Guilers,Gwiler-Leon,ji lai er,Гиле,Гіле,吉莱尔', 48.4254500, -4.5580100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54735, 'Guignicourt', 'Guignicourt', 'Gin''ikur,Guignicourt,ji ni ku er,Гиньикур,Гіньїкур,吉尼库尔', 49.4371400, 3.9675500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54736, 'Guignes', 'Guignes', 'Gin'',Guignes-Libre,Guignes-Rabutin,Гинь,Гінь', 48.6333300, 2.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54737, 'Guignen', 'Guignen', 'Gin''jan,Guignen,Gwinien,ji gai en,Гиньян,Гіньян,吉盖恩', 47.9200900, -1.8616100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54738, 'Guiclan', 'Guiclan', 'Giklan,Guiclan,Gwiglann,ji ke lang,Гиклан,Гіклан,吉克朗', 48.5496700, -3.9621100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54739, 'Guichen', 'Guichen', 'Gishan,Guichen,Gwizien,ji shang,Гишан,Гішан,吉尚', 47.9676200, -1.7953400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54740, 'Guichainville', 'Guichainville', 'Gishenvil'',ji shang wei er,Гишенвиль,Гішенвіль,吉尚维尔', 49.0013900, 1.1930500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54741, 'Guewenheim', 'Guewenheim', '', 47.7528300, 7.0925300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54742, 'Gueux', 'Gueux', 'Gueux', 49.2504800, 3.9102400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54743, 'Gueugnon', 'Gueugnon', 'Gen''on,Genjonas,Gueugnon,Геньон', 46.6035700, 4.0628600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54744, 'Guéthary', 'Guethary', 'Cetaria,Getari,Getaria,Guetaria,Guethary,Guéthary,gai ta li,getari,Гетари,Гетарі,ゲタリー,盖塔里', 43.4228500, -1.6107300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54745, 'Guesnain', 'Guesnain', 'Djesnain,Djésnain,Genen,Guesnain,ge si nan,Генен,格斯南', 50.3500000, 3.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54746, 'Guerville', 'Guerville', 'Guerville', 48.9438800, 1.7342900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54747, 'Guern', 'Guern', 'Guern,Gwern', 48.0296400, -3.0914500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54748, 'Guermantes', 'Guermantes', 'Germant,Германт', 48.8530300, 2.7049500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54749, 'Guerlesquin', 'Guerlesquin', 'Guerlesquin,Gwerliskin', 48.5175800, -3.5858300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54750, 'Guérigny', 'Guerigny', 'Garigniacum,Gerin''i,Guerigny,Guérigny,gai li ni,Гериньи,Гериньї,盖里尼', 47.0870300, 3.2018200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54751, 'Guéret', 'Gueret', 'Garait,Gere,Gueretum,gai lei,gele,gere,ghwyryt,grh,zhwyr,Гере,גרה,غويريت,ژوئر,ゲレ,盖雷,게레', 46.1666700, 1.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54752, 'Guéreins', 'Guereins', 'Guereins,Guéreins', 46.1062800, 4.7790200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54753, 'Guérard', 'Guerard', 'Guerard,Guérard', 48.8208600, 2.9596900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54754, 'Guérande', 'Guerande', 'Gerand,Guerande,Guerrandia,Guérande,Gwenrann,gai lang de,gerando,Геранд,ゲランド,蓋朗德', 47.3291100, -2.4282900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54755, 'Guer', 'Guer', 'Ger,Guer,Gwern-Porc''hoed,Gwern-Porchoed,Pagus Guernius,gai zhen,Гер,盖镇', 47.9061900, -2.1231400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54756, 'Guenrouet', 'Guenrouet', 'Genrue,Guenrouet,Guenrouët,Gwenred,gai en lu ai,ganrue,Генруе,ガンルエ,盖恩鲁埃', 47.5188100, -1.9538100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54757, 'Guénin', 'Guenin', 'Genen,Guenin,Guénin,Gwennin,gai nan,Генен,盖南', 47.9075700, -2.9794100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54758, 'Guengat', 'Guengat', 'Genga,Guengat,Gwengad,gai en jia,Генга,盖恩加', 48.0419300, -4.2047000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54759, 'Guénange', 'Guenange', 'Genanzh,Guenange,Guénange,Niederginingen,gai nan ge,Генанж,盖南格', 49.2994600, 6.2075200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54760, 'Guémené-sur-Scorff', 'Guemene-sur-Scorff', 'Ar Gemene,Gemene-sjur-Skorff,Gemne-sjur-Skorf,Guemene,Guémene,gemune=shuru=sukorufu,si ke er he pan gai mei nei,Гемене-сюр-Скорфф,Гемне-сюр-Скорф,ゲムネ＝シュル＝スコルフ,斯科尔河畔盖梅内', 48.0666700, -3.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54761, 'Guémené-Penfao', 'Guemene-Penfao', 'Gemene-Panfao,Guemene,Guemene-Pentao,Guéméne,Guéméné-Pentao,Gwenvenez-Penfaou,Mons Candidus,gai mei nei pang fu,gemune=panfo,Гемене-Панфао,ゲムネ＝パンフォ,盖梅内庞福', 47.6333300, -1.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54762, 'Guémar', 'Guemar', 'Gemar,Guemer,gai ma,Гемар,盖马', 48.1886900, 7.3970600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54763, 'Guégon', 'Guegon', 'Gegon,Guegon,Guégon,Gwegon,gai gong,Гегон,盖贡', 47.9370700, -2.5645000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54764, 'Guécélard', 'Guecelard', 'Geselar,Guecelard,Guécélard,Геселар', 47.8775100, 0.1293000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54765, 'Guebwiller', 'Guebwiller', 'Gebviller,Gebweiler,Guebwiller,gai bu wei lai,gebuvu~ireru,Гебвиллер,Гебвіллер,ゲブヴィレール,盖布维莱', 47.9166700, 7.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54766, 'Guarbecque', 'Guarbecque', 'Gjuarbek,Guarbecque,Guerbecque,Guérbécque,gua er bei ke,jwabysykyw,Гюарбек,جوابيسيكيو,瓜尔贝克', 50.6116200, 2.4889500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54767, 'Gruson', 'Gruson', 'Gruson', 50.5958300, 3.2077700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54768, 'Gruissan', 'Gruissan', 'Grjuissan,Grussan,ge lu yi sang,Грюиссан,Грюїссан,格吕伊桑', 43.1075900, 3.0865100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54769, 'Gruffy', 'Gruffy', 'Grjuffi,Grofi,Gruffium,Gruffy,Grôfi,Грюффі', 45.7871700, 6.0550400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54770, 'Gruchet-le-Valasse', 'Gruchet-le-Valasse', 'Gruchet,Gruchet-le-Valass,Gruchet-le-Valasse', 49.5546600, 0.4868400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54771, 'Grosseto-Prugna', 'Grosseto-Prugna', 'Grosseto,Grosseto-Prugna,Grosseto-Prun''ja,U Grussetu,Гроссето-Прунья', 41.8709700, 8.9640300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54772, 'Gros-Réderching', 'Gros-Rederching', 'Gros-Rederching,Gros-Réderching,Gross Rederchingen,Gross Réderchingen', 49.0678700, 7.2188900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54773, 'Groslay', 'Groslay', 'Grole,Groslay,Grosle,ge luo si lai,Гроле,Гросле,格罗斯莱', 48.9856100, 2.3473600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54774, 'Grosbreuil', 'Grosbreuil', 'Grosbreuil', 46.5394600, -1.6165500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54775, 'Grosbliederstroff', 'Grosbliederstroff', 'Grosbliderstroff,Gross-Blittersdorf,Grossbliederstroff,Grossblittersdorf,Großblittersdorf,ge luo si bu li ye dai er si te luo,Гросблидерстрофф,Гросблідерстрофф,格罗斯布利耶代尔斯特罗', 49.1580800, 7.0241300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54776, 'Gron', 'Gron', 'Gron', 48.1596700, 3.2634500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54777, 'Groix', 'Groix', 'Enez-Groe,Groe,Groia insula,Groix,Grua,Ile de Groix,Nkroua,ge lu wa,gurowa dao,Île de Groix,Γκρουά,Груа,Գրուա,グロワ島,格鲁瓦', 47.6388700, -3.4543000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54778, 'Groisy', 'Groisy', 'Groisium,Groisy,Gruazi,Груазі', 46.0183500, 6.1708300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54779, 'Groissiat', 'Groissiat', 'Groissiat', 46.2221300, 5.6077500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54780, 'Groffliers', 'Groffliers', 'Groffliers', 50.3844400, 1.6147400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54781, 'Grisy-Suisnes', 'Grisy-Suisnes', 'Grisy,Grisy-Suisnes', 48.6853800, 2.6678100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54782, 'Grisolles', 'Grisolles', 'Grisolles', 43.8292000, 1.2967300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54783, 'Grimaud', 'Grimaud', 'Athenople,Athènople,Athénople,Grimaud,Port Grimaud', 43.2704900, 6.5249100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54784, 'Grillon', 'Grillon', 'Grillon', 44.3915200, 4.9304000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54785, 'Grigny', 'Grigny', 'Grigny', 48.6541200, 2.3934300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54786, 'Grigny', 'Grigny', 'Grigny,Grin''i,Гриньї', 45.6112800, 4.7958900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54787, 'Grignon', 'Grignon', 'Brumaire,Grignon', 45.6512200, 6.3779500, 'FR', '2016-11-26', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54788, 'Grignols', 'Grignols', 'Grignols', 44.3884200, -0.0428700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54789, 'Grignan', 'Grignan', 'Grignan,Grin''jan,Grinhan,ge li ni ang,Гриньян,格里尼昂', 44.4197600, 4.9082600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54790, 'Griesheim-près-Molsheim', 'Griesheim-pres-Molsheim', 'Griesheim,Griesheim-pres-Molsheim,Griesheim-près-Molsheim', 48.5029600, 7.5302700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54791, 'Gries', 'Gries', '', 48.7537000, 7.8140300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54792, 'Grièges', 'Grieges', 'Grieges,Grièges', 46.2558300, 4.8513400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54793, 'Grez-sur-Loing', 'Grez-sur-Loing', 'Gre-sjur-Luehn,Grez,Grez-sjur-Luen,Grez-sur-Loing,gure=shuru=rowan,Гре-сюр-Луэн,Грез-сюр-Луен,グレ＝シュル＝ロワン', 48.3175400, 2.6884800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54794, 'Grez-Neuville', 'Grez-Neuville', 'Gre-Nevil'',Grez,Grez-Neuville,ge lei na wei er,gure=nuvu~iru,Гре-Невіль,グレ＝ヌヴィル,格雷纳维尔', 47.6028800, -0.6819300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54795, 'Grézieu-la-Varenne', 'Grezieu-la-Varenne', 'Grez''e-la-Varenn,Grezieu,Grezieu-et-Craponne,Grezieu-la-Varenne,Grézieu,Grézieu-et-Craponne,Grézieu-la-Varenne,Грезьє-ла-Варенн', 45.7483300, 4.6901600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54796, 'Gretz-Armainvilliers', 'Gretz-Armainvilliers', 'Gretz,Gretz-Armainvilliers', 48.7412000, 2.7310500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54797, 'Grésy-sur-Isère', 'Gresy-sur-Isere', 'Gresy,Gresy-sur-Isere,Grésy,Grésy-sur-Isère', 45.6017200, 6.2550900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54798, 'Grésy-sur-Aix', 'Gresy-sur-Aix', 'Gresy,Gresy-sur-Aix,Grezi-sjur-Eks,Grésy,Grésy-sur-Aix,Грезі-сюр-Екс', 45.7230100, 5.9341200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54799, 'Gresswiller', 'Gresswiller', 'Gresswiller', 48.5354200, 7.4325100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54800, 'Gréoux-les-Bains', 'Greoux-les-Bains', 'Greoux,Greoux-les-Bains,Greu-le-Ben,Greus,Grèus,Gréoux,Gréoux-les-Bains,ge lei wu lai ban,Греу-ле-Бен,格雷乌莱班', 43.7575300, 5.8816900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54801, 'Grenoble', 'Grenoble', 'GNB,Gorad Grehnobl'',Gratianopolis,Grelibre,Grenobel,Grenobl,Grenobl'',Grenoble,Grenoblis,Grenoblo,Grenobul,Grenòble,Nkrenompl,Qroenobl,Qrönobl,ge lei nuo bu er,geuleunobeul,ghrwnwbl,granobala,grenobala,grenobla,grenobli,grnwbl,grwnwbl,grynwbl,gurunoburu,kiranopil,Γκρενόμπλ,Горад Грэнобль,Грeнобль,Гренобл,Гренобль,Гренобъл,Գրենոբլ,גרנובל,גרענאבלע,غرونوبل,گرونوبل,گرینوبل,ग्रेनोबल,ग्रेनोब्ल,গ্রনোবল,கிரனோபிள்,გრენობლი,グルノーブル,格勒诺布尔,그르노블', 45.1666700, 5.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54802, 'Grendelbruch', 'Grendelbruch', 'Grandelbrueech,Grandelbrüech,Grendel''bruk,Grendelbruch,ge lang dai er bu lu ke,ghryndlbrwsh,grndlbrwkh,Грендельбрук,غريندلبروش,گرندلبروخ,格朗代尔布吕克', 48.4927200, 7.3223900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54803, 'Grenay', 'Grenay', 'Grenay', 50.4496200, 2.7516800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54804, 'Grenay', 'Grenay', 'Grenay', 45.6631700, 5.0798700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54805, 'Grenade', 'Grenade', 'Grenade-sur-Garonne', 43.7666700, 1.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54806, 'Gréasque', 'Greasque', 'Greask,Greasque,Griasca,Gréasque,ge lei a si qu ai,Греаск,格雷阿斯屈埃', 43.4331000, 5.5444900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54807, 'Gray-la-Ville', 'Gray-la-Ville', 'Gray-la-Ville', 47.4393200, 5.5725200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54808, 'Gray', 'Gray', 'Gray', 47.4457500, 5.5921500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54809, 'Gravigny', 'Gravigny', 'Gravigny', 49.0531000, 1.1696200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54810, 'Graveson', 'Graveson', 'Graveson,Gravzon,ge la wei song,Гравзон,格拉韦松', 43.8513400, 4.7718900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54811, 'Gravelines', 'Gravelines', 'Graelines,Gravelina,Gravelinas,Gravelines,Gravelingen,Gravlin,Grevelingen,Grevelingn,Port-d''Aa,ge la wo li ne,guravurinu,Гравлин,Гравлін,グラヴリーヌ,格拉沃利讷', 50.9865100, 2.1280700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54812, 'Graulhet', 'Graulhet', 'Graulhe,Graulhet,Groe,Grole,ge luo ye,Гроле,Гроє,格罗耶', 43.7668800, 1.9893800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54813, 'Gratentour', 'Gratentour', 'Cratentour,Gratantur,Gratenteur,Gratentorn,Gratentour,ge la tang tu,Гратантур,格拉唐图', 43.7236000, 1.4323400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54814, 'Grasse', 'Grasse', 'Gorad Gras,Gras,Grasas,Grass,Grassa,Grasse,Nkras,ge la si,geulaseu,ghras,grs,gurasu,Γκρας,Горад Грас,Грас,Грасс,גראס,غراس,گرس,グラース,格拉斯,그라스', 43.6666700, 6.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54815, 'Granville', 'Granville', 'GFR,Granvil'',Granville,Granville-la-Victoire,Graunville,Nkranvil,ge lan fu,guran''vu~iru,Γκρανβίλ,Гранвиль,Гранвіль,グランヴィル,格蘭佛', 48.8379200, -1.5971400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54816, 'Grans', 'Grans', 'Gran,Grans,ge lang,Гран,Гранс,格朗', 43.6035700, 5.0688100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54817, 'Granges-sur-Vologne', 'Granges-sur-Vologne', 'Granges,Granges-sur-Vologne', 48.1451700, 6.7909500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54818, 'Grane', 'Grane', '', 44.7333300, 4.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54819, 'Grandvilliers', 'Grandvilliers', 'Grandvilliers', 49.6654700, 1.9408800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54820, 'Grandvillars', 'Grandvillars', 'Grandvillars', 47.5392100, 6.9642400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54821, 'Grandris', 'Grandris', 'Grandris,Granri,grandry,Гранрі,گراندری', 46.0387100, 4.4748600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54822, 'Gallargues-le-Montueux', 'Gallargues-le-Montueux', 'Galargues,Gallarg-le-Montjue,jia la er gai lai meng di e,Галларг-ле-Монтюе,加拉尔盖莱蒙蒂厄', 43.7166700, 4.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54823, 'Grandfresnoy', 'Grandfresnoy', 'Grandfresnoy', 49.3721800, 2.6521600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54824, 'Grand-Fougeray', 'Grand-Fougeray', 'Felgeriacum,Felgerieg-Veur,Fougeray,Gran-Fuzhere,Grand-Fougeray,Le Grand-Fougeray,ge lang fu re lai,guran=fujure,Гран-Фужере,グラン＝フジュレ,格朗富热赖', 47.7239000, -1.7321000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54825, 'Grand-Fort-Philippe', 'Grand-Fort-Philippe', 'Gran-For-Filipp,Grand-Fort-Philippe,Groot-Filipsfort,Groot-Fort-Filips,fei li pu da bao,Гран-Фор-Филипп,Гран-Фор-Філіпп,菲利普大堡', 50.9996100, 2.1078400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54826, 'Grandfontaine', 'Grandfontaine', 'Grandfontaine', 47.1976300, 5.9007900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54827, 'Grande-Synthe', 'Grande-Synthe', 'Gran Sint,Grand-Sent,Grand-Sint,Grande-Synthe,Groot-Sinten,Groot-Sintn,ge lang de sang te,geulangdeusaengteu,grand snt,gurando=shinto,Гран Синт,Гранд-Сент,Гранд-Синт,Гранд-Сінт,گراند سنت,グランド＝シント,格朗德桑特,그랑드생트', 51.0154000, 2.2997500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54828, 'Grand-Couronne', 'Grand-Couronne', 'Grand-Couronne,La Reunion,La Réunion', 49.3556300, 1.0064700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54829, 'Grand-Charmont', 'Grand-Charmont', 'Grand-Charmont', 47.5267400, 6.8260400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54830, 'Grand-Champ', 'Grand-Champ', 'Gran-Sham,Grand-Champ,Gregam,ge lang shang,Гран-Шам,格朗尚', 47.7580400, -2.8463500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54831, 'Grandcamp-Maisy', 'Grandcamp-Maisy', 'Grandcamp,Grandcamp-les-Bains,Grankam-Mezi,Grankan-Mezi,ge lang de kang mai xi,Гранкам-Мези,Гранкам-Мезі,Гранкан-Мези,格朗德康迈西', 49.3833300, -1.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54832, 'Grambois', 'Grambois', 'Gramboes,Grambois,Gramboès,Grambua,ge lang bu wa,Грамбуа,格朗布瓦', 43.7618700, 5.5872500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54833, 'Gramat', 'Gramat', 'Gramat,ge la ma,Грамат,格拉马', 44.7807500, 1.7195700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54834, 'Grainville-sur-Odon', 'Grainville-sur-Odon', 'Grainville,Grainville-sur-Odon', 49.1393600, -0.5304600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54835, 'Grainville-la-Teinturière', 'Grainville-la-Teinturiere', 'Grainville,Grainville-la-Teinturiere,Grainville-la-Teinturière', 49.7477300, 0.6404800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54836, 'Gragnague', 'Gragnague', 'Gragnague,Grapnague', 43.6809100, 1.5846100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54837, 'Gradignan', 'Gradignan', 'Gradignan,Gradin''jan,Gradinan,Gradinhan,ge la di ni ang,geuladinyang,grdynyan,guradinyan,Градиньян,Градињан,Градіньян,گردینیان,グラディニャン,格拉迪尼昂,그라디냥', 44.7726200, -0.6139300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54838, 'Grâces', 'Graces', 'Graces,Gras-Gwengamp,Grâces', 48.5565100, -3.1853300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54839, 'Graçay', 'Gracay', 'Gracay,Grase,Graçay,La Liberte,La Liberté,ge la sai,Грасе,格拉赛', 47.1437100, 1.8473300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54840, 'Grabels', 'Grabels', 'Grabel'',Grabels,Грабель', 43.6479700, 3.7986500, 'FR', '2017-04-27', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54841, 'Goven', 'Goven', 'Govan,Goven,ge wang,Гован,戈旺', 48.0063800, -1.8462900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54842, 'Gouzon', 'Gouzon', 'Gouzon', 46.1928600, 2.2387600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54843, 'Gouzeaucourt', 'Gouzeaucourt', 'Gouzeaucourt', 50.0560600, 3.1235100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54844, 'Gouy-sous-Bellonne', 'Gouy-sous-Bellonne', 'Gouy,Gouy-sous-Bellonne', 50.3113900, 3.0565700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54845, 'Gouville-sur-Mer', 'Gouville-sur-Mer', 'Gouville,Gouville-sur-Mer', 49.0961100, -1.5790800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54846, 'Gouvieux', 'Gouvieux', 'Gouvieux,Guv''jo,Guve,gu wei e,Гувьё,Гувє,古维厄', 49.1870500, 2.4143900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54847, 'Gouvernes', 'Gouvernes', 'Gouvernes,Guvern,Гуверн', 48.8600700, 2.6907400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54848, 'Goussainville', 'Goussainville', 'Goussainville', 49.0136700, 2.4659500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54849, 'Gournay-sur-Marne', 'Gournay-sur-Marne', 'Gournay,Gournay-sur-Marne,Gurne-sjur-Marn,ma en he pan gu er nai,Гурне-сюр-Марн,马恩河畔古尔奈', 48.8622300, 2.5845200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54850, 'Gournay-en-Bray', 'Gournay-en-Bray', 'Consolation,Gournay,Gournay-en-Bray,Gurne-an-Bre,Гурне-ан-Бре', 49.4828500, 1.7247100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54851, 'Gourin', 'Gourin', 'Gourin,Guren,gu lan,guran,Гурен,グラン,古兰', 48.1386600, -3.6075500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54852, 'Gourdon', 'Gourdon', 'Courdon,Gordon,Gourdon', 44.7333300, 1.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54853, 'Gourdan-Polignan', 'Gourdan-Polignan', 'Gourdan-Polignan', 43.0709200, 0.5748200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54854, 'Goult', 'Goult', 'Goud,Goult,Gu,Gul''t,Gòud,gu er,Гу,Гульт,古尔', 43.8608000, 5.2424700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54855, 'Gouézec', 'Gouezec', 'Gouezec,Gouezeg,Gouézec,Guezek,gu ai ze ke,Гуезек,古埃泽克', 48.1691100, -3.9727700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54856, 'Gouesnou', 'Gouesnou', 'Goeznoveus,Gouenou,Gouenoù,Gouesnou,Guenu,gu ai si nu,Гуену,古埃斯努', 48.4526700, -4.4645600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54857, 'Gouesnach', 'Gouesnach', 'Gouenac''h,Gouesnac''h,Gouesnach', 47.9104000, -4.1145000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54858, 'Goudelin', 'Goudelin', 'Goudelin', 48.6037500, -3.0184200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54859, 'Goudargues', 'Goudargues', 'Goudargues', 44.2137600, 4.4665200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54860, 'Gouarec', 'Gouarec', 'Gouarec,Guarek,Gwareg,gu a lei ke,Гуарек,古阿雷克', 48.2272500, -3.1799400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54861, 'Gouaix', 'Gouaix', 'Gouaix', 48.4853900, 3.2933600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54862, 'Gosné', 'Gosne', 'Cosne,Cosné,Goneg,Gosne,Gosné', 48.2467400, -1.4655800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54863, 'Gosnay', 'Gosnay', 'Gonaye,Gone,Gosnay,ge nai,jwznay,Гоне,جوزناي,戈奈', 50.5062200, 2.5890400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54864, 'Gorze', 'Gorze', 'Gorz,Gorze,Gorzia,ge er ci,gwrz,Горз,گورز,戈尔兹', 49.0533500, 6.0014100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54865, 'Gorron', 'Gorron', 'Goron,Gorron,ge er long,Горон,Горрон,戈尔龙', 48.4109500, -0.8126700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54866, 'Gorges', 'Gorges', 'Gored,Gorge,Gorges', 47.0991700, -1.3002400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54867, 'Gordes', 'Gordes', 'Gord,Gorda,Gordes,Gòrda,ge er dai,gorudo,Горд,ゴルド,戈尔代', 43.9123700, 5.2008900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54868, 'Gorcy', 'Gorcy', 'Gorcy-Cussigny,Gorsi,ge er xi,Горси,Горсі,戈尔西', 49.5333300, 5.7000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54869, 'Gorbio', 'Gorbio', 'Gorbio', 43.7868100, 7.4426000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54870, 'Gontaud-de-Nogaret', 'Gontaud-de-Nogaret', 'Gontaut de Nogaret,Gontaut e Sent Peir de Nogaret,Gontaut e Sent Pèir de Nogaret,Gonto de Nogare,Gonto-de-Nogare,gong tuo de nuo jia lei,Гонто де Ногаре,Гонто-де-Ногаре,贡托德诺加雷', 44.4500000, 0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54871, 'Gonneville-la-Mallet', 'Gonneville-la-Mallet', 'Gonneville,Gonneville-la-Mallet', 49.6395000, 0.2224500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54872, 'Gonnehem', 'Gonnehem', 'Gonam,Gonhin,Gonneem,Gonnehem,ge ne mu,jwnyhym,Гонам,Гоннеем,جونيهيم,戈讷姆', 50.5606100, 2.5727700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54873, 'Gonfaron', 'Gonfaron', 'Gonfaron,gong fa long,Гонфарон,贡法龙', 43.3206700, 6.2880600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54874, 'Gonesse', 'Gonesse', 'Gones,Goness,Gonesse,ge nei si,goneseu,gonesu,gwns,Гонес,Гонесс,גאנס,گونس,ゴネス,戈內斯,고네스', 48.9869300, 2.4489200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54875, 'Gondrin', 'Gondrin', 'Gondrin', 43.8846600, 0.2373700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54876, 'Gondreville', 'Gondreville', 'Gondreville,Gondreville-sur-Moselle', 48.6943600, 5.9655100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54877, 'Gondrecourt-le-Château', 'Gondrecourt-le-Chateau', 'Gondrecourt,Gondrecourt-le-Chateau,Gondrecourt-le-Château,Gondrekur le Shato,Gondrekur-le-Shato,gong de lei ku er lai sha tuo,Гондрекур ле Шато,Гондрекур-ле-Шато,贡德雷库尔莱沙托', 48.5136600, 5.5105800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54878, 'Gondecourt', 'Gondecourt', 'Gondecourt,Gondekur,Gondkur,gong de ku er,Гондекур,Гондкур,贡德库尔', 50.5446900, 2.9837800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54879, 'Goncelin', 'Goncelin', 'Goncelin,Gonselen,gong se lan,Гонселен,贡瑟兰', 45.3445300, 5.9789200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54880, 'Gommegnies', 'Gommegnies', 'Gomeni,Gommegnies,Gommeni,ge mo ni,Гомењи,Гоммени,Гоммені,戈默尼', 50.2715500, 3.7062500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54881, 'Gometz-le-Châtel', 'Gometz-le-Chatel', 'Gomec le Shatel,Gomets-le-Shatel'',Gometz-le-Chatel,Gometz-le-Châtel,Saint-Clair,ge mei te lei sha te,Гометс-ле-Шатель,Гомец ле Шател,戈梅特勒沙特', 48.6783700, 2.1379200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54882, 'Gometz-la-Ville', 'Gometz-la-Ville', 'Gomec la Vil,Gomets-la-Vil'',Gometz-la-Ville,ge mei te la wei er,Гометс-ла-Виль,Гометс-ла-Віль,Гомец ла Вил,戈梅特拉维尔', 48.6721900, 2.1286800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54883, 'Golbey', 'Golbey', 'Gol''be,Golbe,Golbey,ge er bei,Голбе,Гольбе,戈尔贝', 48.1976400, 6.4396600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54884, 'Goincourt', 'Goincourt', 'Goincourt', 49.4261400, 2.0362100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54885, 'Gœulzin', 'Goeulzin', '', 50.3166700, 3.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54886, 'Goetzenbruck', 'Goetzenbruck', 'Gecenbruk,Getsanbrjuk,Goetzenbruck,Gotzenbruck,Götzenbrück,Gœtzenbruck,ge ai te cang bu lu,Гетсанбрюк,Геценбрук,戈埃特藏布吕', 48.9777800, 7.3796000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54887, 'Gœrsdorf', 'Goersdorf', '', 48.9500000, 7.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54888, 'Godewaersvelde', 'Godewaersvelde', 'Godeversvel''d,Godewaarsvelde,Godewaersvelde,Godsvelde,Godverveld,ge de wa er si fei er de,gwdwrswldh,Годвервелд,Годеверсвельд,گودور سولدے,گودورسولده,戈德瓦尔斯费尔德', 50.7939900, 2.6445600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54889, 'Goderville', 'Goderville', 'Goderville', 49.6456600, 0.3659300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54890, 'Glomel', 'Glomel', 'Glomel,Glomel'',Gronvel,Gronwel,Groñvel,Groñwel,ge luo mei,Гломел,Гломель,格洛梅', 48.2230000, -3.3969600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54891, 'Gleizé', 'Gleize', 'Gleize,Gleizé', 45.9908200, 4.7007100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54892, 'Glandon', 'Glandon', 'Glandon', 45.4797800, 1.2257300, 'FR', '2017-05-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54893, 'Givry', 'Givry', 'Givry', 46.7820200, 4.7426200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54894, 'Givrand', 'Givrand', 'Givrand,Zhivran,ji fu lang,Живран,吉夫朗', 46.6708300, -1.8861200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54895, 'Givors', 'Givors', 'Givors,Zhivor,ghyfwrz,ji hua he,zhywwr,Живор,غيفورز,ژیوور,疾画合', 45.5841500, 4.7725600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54896, 'Givet', 'Givet', 'Djivet,Fort-la-Montagne,Givet,Zhive,jivu~e,ri wei,zhywh,Живе,ژیوه,ジヴェ,日韦', 50.1379600, 4.8254500, 'FR', '2017-07-24', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54897, 'Givenchy-en-Gohelle', 'Givenchy-en-Gohelle', 'Givenchy,Givenchy-en-Gohelle,Givinchy-in-Gohelle,Zhivanshi an Goel,Zhivanshi-an-Goehl'',Zhivanshi-an-Goel'',ji wang xi ang ge ai lei,jyfnshy an jwhyl,zhywanshy-an-gwyl,Живанши ан Гоел,Живанши-ан-Гоель,Живанши-ан-Гоэль,Живанші-ан-Гоель,جيفنشي إن جوهيل,ژیوانشی-آن-گوئل,吉旺希昂戈埃勒', 50.3908000, 2.7732000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54898, 'Gisors', 'Gisors', 'Gisors,Gisortium,Zhizor,ji suo er,jyzwr,Жизор,جيزور,吉索尔', 49.2817800, 1.7801000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54899, 'Giroussens', 'Giroussens', 'Giroussens', 43.7619900, 1.7760800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54900, 'Gironde-sur-Dropt', 'Gironde-sur-Dropt', 'Gironda sau Drot,Gironda sau Dròt,Senta Peironelha de la Reula,Senta Peironelha de la Rèula,Zhirond sir Drot,Zhirond-sjur-Dro,de luo pu he pan ji long de,Жиронд сир Дрот,Жиронд-сюр-Дро,德罗普河畔吉龙德', 44.5833300, -0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54901, 'Giromagny', 'Giromagny', 'Giromagny,Zhiroman''i,Zhiromani,ji luo ma ni,jiromani,Жироманьї,Жиромањи,ジロマニー,吉罗马尼', 47.7414600, 6.8267100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54902, 'Giraumont', 'Giraumont', 'Giraumont', 49.1731300, 5.9115900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54903, 'Ginestas', 'Ginestas', 'Ginestas', 43.2664500, 2.8703800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54904, 'Ginasservis', 'Ginasservis', 'Ginacervias,Ginacèrvias,Ginasservis,Zhinaservi,Zhinaservis,Zhinasservis,ji na sai er wei,Жинасерви,Жинасервис,Жинассервіс,吉纳塞尔维', 43.6711300, 5.8492500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54905, 'Gimont', 'Gimont', 'Gimont,Zhimon,ji meng,Жимон,吉蒙', 43.6262700, 0.8765500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54906, 'Gilly-sur-Isère', 'Gilly-sur-Isere', 'Gilly,Zhii-sjur-Izer,Zhiji sir Izer,Жији сир Изер,Жії-сюр-Ізер', 45.6591700, 6.3509600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54907, 'Gillonnay', 'Gillonnay', 'Gillonnay', 45.3937000, 5.2958600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54908, 'Gilley', 'Gilley', 'Gilley,Gilley-Gare', 47.0474000, 6.4825700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54909, 'Gilette', 'Gilette', 'Gilette', 43.8478800, 7.1634900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54910, 'Gignac-la-Nerthe', 'Gignac-la-Nerthe', 'Gignac,Gignac-la-Nerthe,Ginhac,Ginhac de la Nerta,Zhin''jak-la-Nert,Zhinak la Nert,ji ni ya ke la nei er te,Жиньяк-ла-Нерт,Жињак ла Нерт,吉尼亚克拉内尔特', 43.3914500, 5.2334800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54911, 'Gignac', 'Gignac', 'Gignac', 43.6520000, 3.5509000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54912, 'Gigean', 'Gigean', 'Gigean', 43.5002800, 3.7116700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54913, 'Gif-sur-Yvette', 'Gif-sur-Yvette', 'Gif,Gif-sur-Yvette,Zhif sir Ivet,Zhif-sjur-Ivett,Zifa pie Ivetas,jifu=shuru=ivu~etto,jipeuswileu-ibeteu,yi wei te he pan ji fu,zhyf swr aywt,Žifa pie Ivetas,Жиф сир Ивет,Жиф-сюр-Іветт,Жиф-сюр-Иветт,ژیف سور ایوت,ジフ＝シュル＝イヴェット,伊维特河畔吉夫,지프쉬르이베트', 48.6833300, 2.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54914, 'Gièvres', 'Gievres', 'Gievres,Gièvres,Zhevr,Zhjevr,Жєвр,Жјевр', 47.2784700, 1.6694300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54915, 'Gières', 'Gieres', 'Gieres,Gières,Zh''er,Zher,Zhjer,ge ai,Жьер,Жєр,Жјер,格埃', 45.1827300, 5.7917900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54916, 'Gien', 'Gien', 'Gien,Zhian,Zhijan,Zhjen,jian,ran zhen,Жиан,Жијан,Жіан,Жјен,ジアン,然镇', 47.6933200, 2.6309400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54917, 'Gidy', 'Gidy', 'Gidy,Zhidi,Жиди,Жиді', 47.9853900, 1.8381600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54918, 'Giberville', 'Giberville', 'Giberville', 49.1815800, -0.2838600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54919, 'Ghyvelde', 'Ghyvelde', 'Ghyvelde,Gijvelde', 51.0527500, 2.5264200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54920, 'Ghisonaccia', 'Ghisonaccia', 'Ghisonaccia,Ghisunaccia,Gizonacha,Gizonachcha,gyzwnasa,Гизонача,Гизоначча,Гізоначча,گیزوناسا', 42.0162100, 9.4041200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54921, 'Gex', 'Gex', 'Gex', 46.3333300, 6.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54922, 'Gevrey-Chambertin', 'Gevrey-Chambertin', 'Gevrey-Chambertin,Zhevre Shamberten,Zhevre-Shamberten,juvure=shanberutan,re fu lei shang bei er tan,xie fei xiang bei dan,zhwrh-shanbrtn,Жевре Шамбертен,Жевре-Шамбертен,ژوره-شانبرتن,ジュヴレ＝シャンベルタン,榭斐香貝丹,热夫雷尚贝尔坦', 47.2261400, 4.9680600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54923, 'Gévezé', 'Geveze', 'Geveseium,Geveze,Gevrezeg,Gévezé,Zheveze,re wei ze,Жевезе,热韦泽', 48.2193300, -1.7895200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54924, 'Geudertheim', 'Geudertheim', '', 48.7241500, 7.7518800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54925, 'Gétigné', 'Getigne', 'Gestiniacum,Getigne,Gétigné,Yestinieg,Zhetin''e,Zhetine,re di nie,Жетиње,Жетіньє,热蒂涅', 47.0765000, -1.2481000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54926, 'Gestel', 'Gestel', 'Gestel,Yestael', 47.8036100, -3.4424500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54927, 'Gesté', 'Geste', 'Geste,Gesté', 47.1817900, -1.1091700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54928, 'Gespunsart', 'Gespunsart', 'Gesponsart,Gespunsart,Zhepensar,Zhespensar,Zhespjonsar,re si pan sa er,Жепенсар,Жеспенсар,Жеспёнсар,热斯潘萨尔', 49.8214300, 4.8292600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54929, 'Gerzat', 'Gerzat', 'Gerzac,Gerzat,Zherza,re er zha,Жерза,热尔扎', 45.8243200, 3.1440400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54930, 'Gerstheim', 'Gerstheim', 'Gerstheim', 48.3814200, 7.7030800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54931, 'Gergy', 'Gergy', 'Gergy,Zherzhi,Жержи,Жержі', 46.8755700, 4.9452700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54932, 'Gerde', 'Gerde', 'Gerde', 43.0556700, 0.1668800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54933, 'Gerbéviller', 'Gerbeviller', 'Gerbeviller,Gerbéviller,Zherbevil'',Zherbeviller,re er bei wei lai,Жербевиллер,Жербевиль,Жербевіль,热尔贝维莱', 48.4946200, 6.5100600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54934, 'Gérardmer', 'Gerardmer', 'Gerardmer,Gérardmer,Ormont,Zherardmer,Zherarme,Zherarmer,jerarume,re la er de mei,Жерардмер,Жерарме,Жерармер,ジェラールメ,热拉尔德梅', 48.0734600, 6.8778700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54935, 'Ger', 'Ger', 'Ger', 43.2500000, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54936, 'Gentilly', 'Gentilly', 'Gentilly', 48.8129400, 2.3417000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54937, 'Gensac-la-Pallue', 'Gensac-la-Pallue', 'Gensac,Gensac-la-Pallue', 45.6500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54938, 'Gennevilliers', 'Gennevilliers', 'Genneville,Gennevillers,Gennevilliers,Zhanvilije,Zhennvil''e,Zhenvil''e,jenbillie,junuvu~irie,re ne wei ye,zhnwylyh,Жанвилије,Женвилье,Женнвилье,Женнвільє,ژنویلیه,ジュヌヴィリエ,热讷维耶,젠빌리에', 48.9333300, 2.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54939, 'Gennes', 'Gennes', '', 47.3401000, -0.2314900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54940, 'Genlis', 'Genlis', 'Genlis,Zhanli,Zhanlis,rang li,Жанли,Жанлис,Жанлі,让利', 47.2420300, 5.2241500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54941, 'Génissieux', 'Genissieux', 'Genissieux,Génissieux', 45.0842600, 5.0833700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54942, 'Génissac', 'Genissac', 'Genissac,Génissac', 44.8500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54943, 'Genillé', 'Genille', 'Zhenie,re ni lai,Женіє,热尼莱', 47.1833300, 1.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54944, 'Générac', 'Generac', 'Generac,Générac', 43.7283000, 4.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54945, 'Génelard', 'Genelard', 'Genelard,Génelard', 46.5811900, 4.2361900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54946, 'Genech', 'Genech', 'Genech,Zhenesh,re nei shen,Женеш,热内什', 50.5312200, 3.2165100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54947, 'Genay', 'Genay', 'Genay', 45.8976400, 4.8372900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54948, 'Genas', 'Genas', 'Genas,Zhena,Жена', 45.7321500, 4.9994300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54949, 'Gémozac', 'Gemozac', 'Gemozac,Gemozak,Gémozac,Zemozak,Zhemozak,re mo zha ke,Гемозак,Жемозак,Ժեմոզակ,热莫扎克', 45.5689600, -0.6757400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54950, 'Gémenos', 'Gemenos', 'Gemas,Gemenos,Gèmas,Gémenos,Zhemenos,Zhemno,Zhemnos,re mang ao,Жеменос,Жемно,Жемнос,热芒奥', 43.2975100, 5.6284300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54951, 'Gelos', 'Gelos', 'Gelos,Gelòs,Zhelos,re luo,Желос,热洛', 43.2833300, -0.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54952, 'Gelles', 'Gelles', 'Gelles', 45.7693700, 2.7634700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54953, 'Geispolsheim', 'Geispolsheim', 'Gaispitze,Gaispítze,Gajspol''sajm,Geispolsheim,ghysbwlshym,re si bo er sang,Гайспольсайм,Геисполсһеим,غيسبولشيم,热斯波尔桑', 48.5165800, 7.6466700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54954, 'Gazeran', 'Gazeran', 'Gazeran,Газеран', 48.6326400, 1.7714900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54955, 'Gavray', 'Gavray', 'Gavray,Gavre,jia fu lai,Гавре,加夫赖', 48.9110800, -1.3505900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54956, 'Gauriaguet', 'Gauriaguet', 'Gauriaguet', 45.0390400, -0.3919100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54957, 'Gauchy', 'Gauchy', 'Gauchy', 49.8276500, 3.2737100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54958, 'Gattières', 'Gattieres', 'Gat''er,Gatieras,Gatièras,Gattieres,Gattières,jatyrys,jia di ai,Гатьер,Гатьєр,جاتيريس,加蒂埃', 43.7603700, 7.1779900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54959, 'Gasville-Oisème', 'Gasville-Oiseme', 'Gasvil''-Uazem,jia si wei er wa sai mu,Гасвіль-Уазем,加斯维尔瓦塞姆', 48.4697300, 1.5384300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54960, 'Gassin', 'Gassin', 'Gassin', 43.2287400, 6.5848100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54961, 'Gasny', 'Gasny', 'Gani,Gasny,jia si ni,Гани,Гані,加斯尼', 49.0918400, 1.6033600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54962, 'Garons', 'Garons', 'Garon,Garons,jia long,Гарон,加龙', 43.7686100, 4.4275300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54963, 'Garnay', 'Garnay', 'Garnay', 48.7048900, 1.3370600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54964, 'Garlin', 'Garlin', 'Garlen,Garlin,jia er lan,Гарлен,加尔兰', 43.5592700, -0.2732100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54965, 'Garidech', 'Garidech', 'Caridech,Garidech,Garideit,Garidesh,Garidèit,jia li dai ke,Гаридеш,加里代克', 43.7107600, 1.5603600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54966, 'Garges-lès-Gonesse', 'Garges-les-Gonesse', 'Garges,Garges-les-Gonesse,Garges-lès-Gonesse,Garzh le Gones,Garzh-le-Goness,galeujulegoneseu,garuju=re=gonesu,grzh lgwns,jia er re lai ge nei sai,Гарж ле Гонес,Гарж-ле-Гонесс,گرژ لگونس,ガルジュ＝レ＝ゴネス,加尔热莱戈内塞,가르주레고네스', 48.9679100, 2.3978100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54967, 'Gargenville', 'Gargenville', 'Gargenville,Garzhanvil'',Гаржанвиль,Гаржанвіль', 48.9880200, 1.8117600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54968, 'Gargas', 'Gargas', 'Gargas', 43.9019900, 5.3578100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54969, 'Garéoult', 'Gareoult', 'Gareoult,Gareu,Gareud,Gareut,Garéoult,jia lei wu er,Гареу,加勒乌尔', 43.3285800, 6.0459400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54970, 'Garennes-sur-Eure', 'Garennes-sur-Eure', 'Garennes,Garennes-sur-Eure', 48.9111600, 1.4383600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54971, 'Gardouch', 'Gardouch', 'Gardouch', 43.3909600, 1.6831300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54972, 'Gardonne', 'Gardonne', 'Gardon,Gardona,Gardonn,Gardonne,jia er dong,Гардон,Гардонн,加尔东', 44.8333300, 0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54973, 'Gardanne', 'Gardanne', 'Gardan,Gardana,Gardann,Gardanne,galeudan,garudan''nu,ghardan,grdn  fransh,jia er da na,Гардан,Гарданн,غاردان,گردن، فرانسه,ガルダンヌ,加爾達納,가르단', 43.4549100, 5.4691300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54974, 'Garchizy', 'Garchizy', 'Garchizy', 47.0478600, 3.0962500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54975, 'Garches', 'Garches', 'Garches,Garsh,Garziachus,gyarushu,jia er she,Гарш,ギャルシュ,加尔舍', 48.8422600, 2.1823200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54976, 'Garat', 'Garat', 'Garat', 45.6333300, 0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54977, 'Garancières', 'Garancieres', 'Garancieres,Garancières,Garans''er,Гарансьер,Гарансьєр', 48.8227100, 1.7551200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54978, 'Gap', 'Gap', 'GAT,Gap,Vapincum,gap,gapeu,ghb brwans alb kwt dazwr,gp  prwans alp-kwt dazwr,gyappu,jia pu,Гап,غب بروانس آلب كوت دازور,گاپ,گپ، پروانس آلپ-کوت دازور,ギャップ,加普,가프', 44.5666700, 6.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54979, 'Gannat', 'Gannat', 'Gana,Ganna,Gannat,Gatnac,Gatnat,Гана,Ганна', 46.1001500, 3.1988600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54980, 'Ganges', 'Ganges', 'Ganges', 43.9338000, 3.7078400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54981, 'Gandrange', 'Gandrange', 'Gandrange', 49.2707100, 6.1224900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54982, 'Gan', 'Gan', 'Gan', 43.2333300, -0.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54983, 'Gambsheim', 'Gambsheim', 'Cambsheim,Gambsajm,Gambse,Gàmbse,gambshaym,gang bu sang,ghambshym,Гамбсайм,غامبشيم,گامبسهایم,冈布桑', 48.6920900, 7.8828600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54984, 'Gambais', 'Gambais', 'Gambais,Gambe,Гамбе', 48.7735100, 1.6719600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54985, 'Gamaches', 'Gamaches', 'Gamaches,Gamapium,Gamash,gamashu,jia ma shen,Гамаш,ガマシュ,加马什', 49.9861500, 1.5562400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54986, 'Galluis', 'Galluis', 'Galljui,Galluis,Галлюи,Галлюї', 48.7965700, 1.7941400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54987, 'Gallardon', 'Gallardon', 'Gallardon', 48.5262200, 1.6930700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54988, 'Galgon', 'Galgon', 'Galgon-et-Queyrac,Galgor', 44.9833300, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54989, 'Gainneville', 'Gainneville', 'Gainneville', 49.5184500, 0.2616400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54990, 'Gaillon', 'Gaillon', 'Gaillon,Gajon,gai long,Гайон,盖隆', 49.1610400, 1.3401600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54991, 'Gaillefontaine', 'Gaillefontaine', 'Gaillefontaine', 49.6537100, 1.6154700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54992, 'Gaillard', 'Gaillard', '', 46.1853000, 6.2069300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54993, 'Gaillan-en-Médoc', 'Gaillan-en-Medoc', 'Gaillan,Gaillan-en-Medoc,Gaillan-en-Médoc', 45.3213300, -0.9579400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54994, 'Gaillac-Toulza', 'Gaillac-Toulza', 'Gaillac-Toulza,Gaillac-la-Montagne', 43.2553600, 1.4714100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54995, 'Gaillac', 'Gaillac', 'Gaillac,Gajak,Galhac,gai la ke,gayakku,Гайак,Гаяк,ガヤック,盖拉克', 43.9016000, 1.8968600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54996, 'Gagny', 'Gagny', 'Gagny,Gan''i,Gani,gani,gny,gnyy,jia ni,Ганьи,Ганьї,Гањи,גני,گنیی,ガニー,加尼,가니', 48.8833300, 2.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54997, 'Gagnac-sur-Garonne', 'Gagnac-sur-Garonne', 'Gagnac,Gagnac-sur-Garonne', 43.6999000, 1.3753500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54998, 'Gaël', 'Gael', 'Gael,Gaël,Gwazel', 48.1320900, -2.2226700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(54999, 'Gacé', 'Gace', '', 48.7934400, 0.2962400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55000, 'Gabarret', 'Gabarret', 'Gabarre,Gabarret,Gavarret,jia ba er lei,Габарре,加巴尔雷', 43.9877900, 0.0097800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55001, 'Fuveau', 'Fuveau', 'Fjuvo,Fuveau,Fuveu,Fuvèu,fei wo,Фюво,菲沃', 43.4557800, 5.5614900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55002, 'Fussy', 'Fussy', 'Fussy', 47.1437200, 2.4295300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55003, 'Furiani', 'Furiani', 'Furiani,Фуриани,Фуріані', 42.6581400, 9.4146900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55004, 'Furdenheim', 'Furdenheim', '', 48.6112900, 7.5610000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55005, 'Fumel', 'Fumel', 'Fjumel'',Fumel,Fumellum,Fumèl,fei mei lei,Фюмель,菲梅勒', 44.4986200, 0.9650600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55006, 'Fumay', 'Fumay', 'Fjume,Fumaeum,Fumay,Fumwe,Fumwè,fei mai,Фюме,菲迈', 49.9913200, 4.7077100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55007, 'Fublaines', 'Fublaines', 'Fublaines', 48.9381600, 2.9365500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55008, 'Fruges', 'Fruges', 'Frjuzh,Fruche,Fruges,frwjys,fu lu ri,Фрюж,فروجيس,弗吕日', 50.5150100, 2.1329200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55009, 'Frouzins', 'Frouzins', 'Frollzins,Frosins,Fruzen,fu lu zan,Фрузен,弗鲁赞', 43.5148200, 1.3252300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55010, 'Frouard', 'Frouard', 'Frouard,Fruar,fu lu a er,Фруар,弗鲁阿尔', 48.7599800, 6.1316300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55011, 'Frotey-lès-Vesoul', 'Frotey-les-Vesoul', 'Frotey,Frotey-les-Vesoul,Frotey-lès-Vesoul', 47.6207800, 6.1883100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55012, 'Frossay', 'Frossay', 'Frossay,Frosse,Frozieg,Fruzaium,Mont-Vineux,fu luo sai,Фроссе,弗罗赛', 47.2445100, -1.9355700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55013, 'Frontonas', 'Frontonas', 'Frontas,Frontonas', 45.6478200, 5.1834100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55014, 'Fronton', 'Fronton', 'Fronton', 43.8393100, 1.3893100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55015, 'Frontignan', 'Frontignan', 'Frontignan,Frontin''jan,Frontinan,Frontinhan,Frontinianum,frwntynyan,fu long di ni ang,furontinyan,Фронтиньян,Фронтињан,Фронтіньян,فرونتینیان,フロンティニャン,弗龙蒂尼昂', 43.4484800, 3.7540000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55016, 'Frontenex', 'Frontenex', 'Frontenex-Villard-Rosset', 45.6333300, 6.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55017, 'Frontenay-Rohan-Rohan', 'Frontenay-Rohan-Rohan', 'Frontenay,Frontenay Rohan-Rohan,Frontene-Roan-Roan,Fronteniacum,Фронтене-Роан-Роан', 46.2527600, -0.5383300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55018, 'Fronsac', 'Fronsac', 'Fronsac', 44.9166700, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55019, 'Froncles', 'Froncles', 'Froncles,Fronkl'',fu long ke lai,Фронкль,弗龙克莱', 48.2975600, 5.1458600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55020, 'Fromelennes', 'Fromelennes', 'Fromelennes', 50.1233300, 4.8595200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55021, 'Froidfond', 'Froidfond', 'Froidfond', 46.8689800, -1.7574000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55022, 'Froideconche', 'Froideconche', 'Froideconche', 47.8212100, 6.4152300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55023, 'Froges', 'Froges', 'Froges', 45.2735900, 5.9215900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55024, 'Friville-Escarbotin', 'Friville-Escarbotin', 'Freuvile-Esquerbotin,Freuvile-Ésquérbotin,Frivil''-Ehskarboten,Frivil''-Eskarboten,Friville,Friville-Escarbotin,fu li wei er-ai si ka bo tan,furivu~iru=esukarubotan,Фривиль-Эскарботен,Фривіль-Ескарботен,フリヴィル＝エスカルボタン,弗里维尔-埃斯卡博坦', 50.0860200, 1.5456000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55025, 'Frignicourt', 'Frignicourt', 'Frignicourt', 48.6996600, 4.5915300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55026, 'Freyming-Merlebach', 'Freyming-Merlebach', 'Freyming,Merlebach', 49.1500000, 6.7833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55027, 'Frévent', 'Frevent', 'Freuvint,Frevan,Frevent,Frévent,fryfynt,fu lei wang,Фреван,فريفينت,弗雷旺', 50.2760800, 2.2872500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55028, 'Fretin', 'Fretin', 'Fretin', 50.5574500, 3.1366800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55029, 'Fréthun', 'Frethun', 'Freten,Frethun,Fréthun,frythwn,fu lei tan,Фретен,فريثون,弗雷坦', 50.9172900, 1.8250500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55030, 'Fresse-sur-Moselle', 'Fresse-sur-Moselle', 'Fress-sjur-Mozel'',Fresse,Fresse-sur-Moselle,mo ze er he pan fu lei sai,Фресс-сюр-Мозель,摩泽尔河畔弗雷塞', 47.8758900, 6.7858900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55031, 'Fressenneville', 'Fressenneville', 'Fressenneville', 50.0683800, 1.5781600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55032, 'Fresnoy-le-Grand', 'Fresnoy-le-Grand', 'Frenua-le-Gran,Fresnot-el-Grind,Fresnoy,Fresnoy-le-Grand,Frésnot-él-Grind,da fu lei nu wa,Френуа-ле-Гран,大弗雷努瓦', 49.9475700, 3.4184100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55033, 'Fresnes-sur-Escaut', 'Fresnes-sur-Escaut', 'Fren-sjur-Ehsko,Fren-sjur-Esko,Fresnes,Fresnes-sur-Escaut,ai si ke he pan fu lei ne,Френ-сюр-Еско,Френ-сюр-Эско,埃斯科河畔弗雷讷', 50.4338200, 3.5775200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55034, 'Fresnes', 'Fresnes', 'Fren,Френ', 48.7556800, 2.3224100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55035, 'Fresnay-sur-Sarthe', 'Fresnay-sur-Sarthe', 'Frene-sjur-Sart,Fresnay,Fresnay-sur-Sarthe,Френе-сюр-Сарт', 48.2819900, 0.0228800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55036, 'Frépillon', 'Frepillon', 'Frepillon,Frépillon', 49.0521600, 2.2052800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55037, 'Freneuse', 'Freneuse', 'Freneuse', 49.0483200, 1.6016800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55038, 'Frelinghien', 'Frelinghien', 'Freleng''jan,Frelengjan,Verlegem,fu lei lan ji an,Фреленгьян,Фреленгян,弗雷蘭吉安', 50.7166700, 2.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55039, 'Fréland', 'Freland', 'Frelan,fu lei lang,Фрелан,弗雷朗', 48.1721500, 7.1916700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55040, 'Fréjus', 'Frejus', 'FRJ,Forum Iulii,Frejus,Frejús,Frezhis,Frezhjus,Frezhus,Fréjus,frzhw,fu lei rui si,furejusu,peulejwiseu,Фрежис,Фрежус,Фрежюс,فرژو,フレジュス,弗雷瑞斯,프레쥐스', 43.4328600, 6.7352400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55041, 'Fréjairolles', 'Frejairolles', 'Frejairolles,Fréjairolles', 43.8809400, 2.2315100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55042, 'Freigné', 'Freigne', 'Freigne,Freigné,Fren''e,fu lei nie,Френьє,弗雷涅', 47.5485800, -1.1227400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55043, 'Frasne', 'Frasne', 'Fran,Frasne,fu la si en,Фран,弗拉斯恩', 46.8564100, 6.1594000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55044, 'Frans', 'Frans', 'Frans', 45.9922800, 4.7758200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55045, 'Franois', 'Franois', 'Franois', 47.2305500, 5.9286900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55046, 'Frangy', 'Frangy', 'Frangy,Franzhi,Franzi,Franži,Frengi,Fringiacum,Франжи,Франжі', 46.0187000, 5.9331300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55047, 'Franconville', 'Franconville', 'Franconville,Franconville-la-Garenne,Franconville-la-Libre', 48.9833300, 2.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55048, 'Francheville', 'Francheville', 'Francheville', 48.7864700, 0.8496200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55049, 'Francheville', 'Francheville', 'Franche-Commune,Francheville', 45.7387900, 4.7721900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55050, 'Francheleins', 'Francheleins', 'Francheleins', 46.0744000, 4.8092000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55051, 'Fraize', 'Fraize', 'Fraize,Fraze,Frez,Traize,fu lai ci,Фрез,弗赖兹', 48.1866000, 6.9978700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55052, 'Fraisses', 'Fraisses', 'Fres,Fress,fu lai sai,Фрес,Фресс,弗赖塞', 45.3833300, 4.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55053, 'Fraisans', 'Fraisans', 'Fraisans', 47.1485700, 5.7605100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55054, 'Frahier-et-Chatebier', 'Frahier-et-Chatebier', 'Fraer-e-Shatebe,Fraje-eh-Shatb''e,Frajer et Shatebje,Фрайе-э-Шатбье,Фраєр-е-Шатебє,Фрајер ет Шатебје', 47.6666700, 6.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55055, 'Foussais-Payré', 'Foussais-Payre', '', 46.5333300, -0.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55056, 'Fourqueux', 'Fourqueux', 'Fourqueux', 48.8869300, 2.0636700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55057, 'Fourques-sur-Garonne', 'Fourques-sur-Garonne', 'Fourques,Fourques-sur-Garonne', 44.4479800, 0.1570300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55058, 'Fourques', 'Fourques', 'Fourques', 43.6945000, 4.6093200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55059, 'Fournes-en-Weppes', 'Fournes-en-Weppes', 'Fournes,Fournes-en-Weppes', 50.5849700, 2.8879300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55060, 'Fourmies', 'Fourmies', 'Fourmies', 50.0153200, 4.0478400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55061, 'Fourchambault', 'Fourchambault', 'Fourchambau,Fourchambault', 47.0166700, 3.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55062, 'Fouras', 'Fouras', 'Fouras,Fura,fu la,Фура,富拉', 45.9873600, -1.0927500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55063, 'Fouquières-lès-Lens', 'Fouquieres-les-Lens', 'Foukere-lez-Linse,Foukère-lez-Linse,Fouquieres,Fouquieres-les-Lens,Fouquieres-lez-Lens,Fouquières,Fouquières-lez-Lens,Fouquières-lès-Lens,Fuk''er-le-Lan,Fuk''er-le-Lans,Fuker-le-Lan,Fukjer le Lan,fu ji ye er lai lang si,fwkywyrys lyh lyns,Фукьер-ле-Лан,Фукьер-ле-Ланс,Фукєр-ле-Лан,Фукјер ле Лан,فوكيويريس ليه لينس,富基耶尔莱朗斯', 50.4284200, 2.9132100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55064, 'Fouquières-lès-Béthune', 'Fouquieres-les-Bethune', 'Foukere-les-Betheune,Foukère-lès-Bétheune,Fouquieres,Fouquieres-les-Bethune,Fouquières,Fouquières-lès-Béthune,Fuk''er-le-Betjun,Fuker-le-Betjun,Fukjer le Beten,fu ji ye er lai bei di ne,fwkywyrys lyh bythwn,Фукьер-ле-Бетюн,Фукєр-ле-Бетюн,Фукјер ле Бетен,فوكيويريس ليه بيثون,富基耶尔莱贝蒂讷', 50.5153400, 2.6099900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55065, 'Fouquereuil', 'Fouquereuil', 'Fouquereuil', 50.5188500, 2.6002400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55066, 'Foulayronnes', 'Foulayronnes', 'Folaironas,Foulayronnes,Fuleron,Fuleronn,fu lai luo nei,Фулерон,Фулеронн,富莱罗内', 44.2402900, 0.6451600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55067, 'Fouillard', 'Fouillard', 'Fouillard,Fouillard-Thorigne,Fouillard-Thorigné', 48.1582000, -1.5791500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55068, 'Fougerolles-du-Plessis', 'Fougerolles-du-Plessis', 'Fougerolles,Fougerolles-du-Plessis,Fuzherol di Plesi,Fuzherol''-dju-Plessi,fu re luo lai di pu lai xi,Фужерол ди Плеси,Фужероль-дю-Плесси,Фужероль-дю-Плессі,富热罗莱迪普莱西', 48.4742400, -0.9725500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55069, 'Fougerolles', 'Fougerolles', 'Fougerolles', 47.8854200, 6.4045400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55070, 'Fougères', 'Fougeres', 'Felger,Filiceriae,Fougeres,Fougères,Fuzher,Gorad Fuzhehr,fu re er,fujeru,fwzhr,pujeleu,Горад Фужэр,Фужер,فوژر,フージェール,富热尔,푸제르', 48.3500000, -1.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55071, 'Foug', 'Foug', 'Foug', 48.6837500, 5.7869100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55072, 'Fouesnant', 'Fouesnant', 'Fouen,Fouenant,Fouesnant,Fuehnan,Fuenan,fu ai si nan,fuenan,Фуенан,Фуэнан,フエナン,富埃斯南', 47.8918700, -4.0148400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55073, 'Foucherans', 'Foucherans', 'Foucherans', 47.0809400, 5.4550300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55074, 'Foucarmont', 'Foucarmont', 'Foucarmont', 49.8468200, 1.5689900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55075, 'Fos-sur-Mer', 'Fos-sur-Mer', 'Fo na Moru,Fo-sjur-Mer,Fos,Fos-sjur-Mer,Fos-sur-Mer,Fòs,Pajurio Fosas,Pajūrio Fosas,bin hai fu si,fosu=shuru=meru,poswileumeleu,Фо на Мору,Фо-сюр-Мер,Фос-сюр-Мер,フォス＝シュル＝メール,濱海福斯,포쉬르메르', 43.4377400, 4.9445700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55076, 'Fosses', 'Fosses', 'Fos,Foss,Fosses,fu sai,Фос,Фосс,福塞', 49.0980800, 2.5095700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55077, 'Fortschwihr', 'Fortschwihr', 'Forshvir,Fortschweier,Fortschwihr,Fortshvir,fu er te si ke wei,Фортшвир,Форшвир,Форшвір,福尔特斯克维', 48.0864700, 7.4505400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55078, 'Fort-Mardyck', 'Fort-Mardyck', 'For Mardik,For-Mardik,Fort-Mardijk,Fort-Mardyck,Fort-Mardyk,Фор Мардик,Фор-Мардик,Фор-Мардік', 51.0289900, 2.3072400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55079, 'Fort-Mahon-Plage', 'Fort-Mahon-Plage', 'For Maon Plazh,For-Maon-Plazh,Fort-Mahon,Fort-Mahon-Plage,foru=maon=puraju,ma weng pu la ri bao,Фор Маон Плаж,Фор-Маон-Плаж,フォール＝マオン＝プラージュ,马翁普拉日堡', 50.3395500, 1.5598400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55080, 'Fors', 'Fors', 'Fors', 46.2357000, -0.4090400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55081, 'Formerie', 'Formerie', 'Formeri,Formerie,fu er mo li ye,Формери,Формері,福尔默里耶', 49.6492800, 1.7310600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55082, 'Forges-les-Eaux', 'Forges-les-Eaux', 'Forges,Forges-les-Eaux,Forzh lez O,Forzh-lez-O,Форж лез О,Форж-лез-О', 49.6139100, 1.5444900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55083, 'Forges-les-Bains', 'Forges-les-Bains', 'Forges,Forges-les-Bains,Forzh le Ben,Forzh-le-Ben,fu er re lai ban,Форж ле Бен,Форж-ле-Бен,福尔热莱班', 48.6294200, 2.1026400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55084, 'Forest-sur-Marque', 'Forest-sur-Marque', 'Forest,Forest-sur-Marque', 50.6334100, 3.1893900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55085, 'Forcalquier', 'Forcalquier', 'Folcalquer,Forcalquier,Forcauquier,Forkal''k''e,Forkal''ke,Forkalkje,Forkalkjė,Forncauquier,Forncauquièr,Forum Calcorium,forukarukie,fu ka er ji ye,fwrkalkywr,Форкалкје,Форкалькье,Форкалькє,فورکالکیور,フォルカルキエ,福卡尔基耶', 43.9666700, 5.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55086, 'Forcalqueiret', 'Forcalqueiret', 'Forcalqueiret', 43.3347100, 6.0823800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55087, 'Forbach', 'Forbach', 'Forbach,Forbak,Forbakh,forubakku,fu er ba ke,fwrbk,Форбак,Форбах,فوربک,フォルバック,福尔巴克', 49.1833300, 6.9000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55088, 'Fontvieille', 'Fontvieille', 'Fontvieille', 43.7280600, 4.7095300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55089, 'Fontoy', 'Fontoy', 'Fensch,Fontoa,Fontoy,Fontua,feng tu wa,fwntway,Фонтоа,Фонтуа,فونتوای,丰图瓦', 49.3562400, 5.9993600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55090, 'Fontevraud-l''Abbaye', 'Fontevraud-l''Abbaye', 'Fontevraud,Fontevrault,Fontevro,Фонтевро', 47.1833300, 0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55091, 'Fontenilles', 'Fontenilles', 'Fontenilles', 43.5528600, 1.1909600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55092, 'Fontenay-Trésigny', 'Fontenay-Tresigny', 'Fontenay-Tresigny,Fontenay-Trésigny,Fontene-Trezin''i,Fontne Trezini,Фонтене-Трезиньи,Фонтене-Трезіньї,Фонтне Трезињи', 48.7064700, 2.8704700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55093, 'Fontenay-sur-Loing', 'Fontenay-sur-Loing', 'Fontanetum ad Luvam,Fontenay,Fontene-sjur-Luen,Fontne sir Loan,lu wan he pan feng te nai,Фонтене-сюр-Луен,Фонтне сир Лоан,卢万河畔丰特奈', 48.1036500, 2.7754200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55094, 'Fontenay-sous-Bois', 'Fontenay-sous-Bois', 'Fontenay,Fontenay-sous-Bois,Fontene su Bua,Fontene-su-Bua,Fontenė su Bua,Fontne su Boa,fontone=su=bowa,fwntnh-sw-bwa,fwntny sw bwa,fwntwny sw bwa,lin pan feng te nai,pongteunesubua,Фонтене-су-Буа,Фонтне су Боа,فونتنه-سو-بوآ,فونتنی سو بوآ,فونتوني سو بوا,フォントネー＝スー＝ボワ,林畔丰特奈,퐁트네수부아', 48.8544200, 2.4826800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55095, 'Fontenay-lès-Briis', 'Fontenay-les-Briis', 'Fontenay,Fontenay-les-Briis,Fontenay-lès-Briis,Fontene-le-Bri,Fontene-le-Brii,Fontne le Bri,feng te nai lai bu li yi,Фонтене-ле-Брии,Фонтене-ле-Брі,Фонтне ле Бри,丰特奈莱布里伊', 48.6196200, 2.1527600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55096, 'Fontenay-le-Marmion', 'Fontenay-le-Marmion', 'Fontenay,Fontenay-le-Marmion', 49.0934600, -0.3529400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55097, 'Fontenay-le-Fleury', 'Fontenay-le-Fleury', 'Fontenay,Fontenay-le-Fleury,Fontene-le-Fleri,Fontne le Fleri,Фонтене-ле-Флери,Фонтене-ле-Флері,Фонтне ле Флери', 48.8125300, 2.0486300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55098, 'Fontenay-le-Comte', 'Fontenay-le-Comte', 'Fontenay-le-Peuple,Fontene-le-Kont,Fontne le Kont,feng te nai lei kong te,fontone=ru=konto,Фонтене-ле-Конт,Фонтне ле Конт,フォントネー＝ル＝コント,丰特奈勒孔特', 46.4666700, -0.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55099, 'Fontenay-en-Parisis', 'Fontenay-en-Parisis', 'Fontenay,Fontenay-en-Parisis,Fontene-an-Parizi,Fontnaj an Parizi,pa li xi de qu feng te nai,Фонтене-ан-Паризи,Фонтене-ан-Паризі,Фонтнај ан Паризи,帕里西地区丰特奈', 49.0537100, 2.4515600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55100, 'Fontenay-aux-Roses', 'Fontenay-aux-Roses', 'Fontenay,Fontenay-aux-Roses,Fontene-o-Roz,Fontne o Roz,feng te nai-mei gui,fontone=o=rozu,fwntnh-aw-rz,fwntny aw rwz,pongteune-olojeu,Фонтене-о-Роз,Фонтне о Роз,فونتنه-او-رز,فونتنی او روز,フォントネー＝オー＝ローズ,丰特奈-玫瑰,퐁트네오로즈', 48.7932500, 2.2927500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55101, 'Fontenay', 'Fontenay', 'Fontenay', 49.5599300, 0.1839100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55102, 'Fontenailles', 'Fontenailles', '', 47.5498800, 3.4621500, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55103, 'Fontcouverte', 'Fontcouverte', 'Fontcouverte', 45.7670800, -0.5868200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55104, 'Fontannes', 'Fontannes', 'Fontanes,Fontannes', 45.3014900, 3.7636600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55105, 'Fontanil-Cornillon', 'Fontanil-Cornillon', 'Fontanil,Fontanil-Cornillon', 45.2480800, 5.6643400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55106, 'Fontaines-sur-Saône', 'Fontaines-sur-Saone', 'Fontaine,Fontaines,Fontaines-sur-Saone,Fontaines-sur-Saône,Fonten na Saoni,Fonten-sjur-Son,Фонтен на Саони,Фонтен-сюр-Сон', 45.8337700, 4.8483400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55107, 'Fontaines-Saint-Martin', 'Fontaines-Saint-Martin', 'Brutus-la-Fontaine,Fontaines-Saint-Martin,Fonten Sen Marten,Fonten-Sen-Marten,Фонтен Сен Мартен,Фонтен-Сен-Мартен', 45.8447800, 4.8548900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55108, 'Fontaines', 'Fontaines', 'Fontaines', 46.8490500, 4.7703600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55109, 'Fontaine-Notre-Dame', 'Fontaine-Notre-Dame', 'Cailloux-la-Montagne,Fontaine,Fontaine-Notre-Dame,Fontaine-la-Montagne', 50.1668100, 3.1581200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55110, 'Fontaine-lès-Luxeuil', 'Fontaine-les-Luxeuil', 'Fontaine,Fontaine-les-Luxeuil,Fontaine-lès-Luxeuil', 47.8559200, 6.3348200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55111, 'Fontaine-lès-Dijon', 'Fontaine-les-Dijon', 'Fontaine,Fontaine-les-Dijon,Fontaine-lès-Dijon,Fonten le Dizhon,Fonten-le-Dizhon,feng tan lai di rong,Фонтен ле Дижон,Фонтен-ле-Дижон,Фонтен-ле-Діжон,丰坦莱迪容', 47.3423800, 5.0200700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55112, 'Fontaine-le-Dun', 'Fontaine-le-Dun', 'Fontaine,Fontaine-le-Dun', 49.8118200, 0.8509500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55113, 'Fontaine-le-Comte', 'Fontaine-le-Comte', 'Fontaine,Fontaine-l''Egalite,Fontaine-l''Egalité,Fontaine-le-Comte,Fonten-le-Kont,feng tai na lei kong te,Фонтен-ле-Конт,丰泰纳勒孔特', 46.5321700, 0.2617600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55114, 'Fontaine-le-Bourg', 'Fontaine-le-Bourg', 'Fontaine,Fontaine-le-Bourg', 49.5645100, 1.1639100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55115, 'Fontaine-la-Mallet', 'Fontaine-la-Mallet', 'Fontaine,Fontaine-la-Mallet', 49.5360000, 0.1462500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55116, 'Fontaine-la-Guyon', 'Fontaine-la-Guyon', 'Fontaine,Fontaine-la-Guyon', 48.4727000, 1.3141700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55117, 'Fontaine-Étoupefour', 'Fontaine-Etoupefour', 'Fontaine,Fontaine-Etoupefour,Fontaine-Étoupefour', 49.1460000, -0.4552200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55118, 'Fontainebleau', 'Fontainebleau', 'Fons Bleaudi,Fontaine-la-Montagne,Fontaine-le-Vallon,Fontainebleau,Fontainemplo,Fontenblo,XFB,feng dan bai lu,fontenuburo,pongtenbeullo,Φονταινεμπλώ,Фонтенбло,フォンテヌブロー,フォンテーヌブロー,枫丹白露,퐁텐블로', 48.4000000, 2.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55119, 'Fontaine-au-Pire', 'Fontaine-au-Pire', 'Fontaine,Fontaine-au-Pire,Fonten-o-Pir,fang dan ou pi er,Фонтен-о-Пир,Фонтен-о-Пір,方丹欧皮尔', 50.1325000, 3.3766700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55120, 'Fontaine', 'Fontaine', 'Fontaine,Fontejn,Фонтейн', 45.1983900, 5.6826500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55121, 'Fonsorbes', 'Fonsorbes', 'Fonsorbes', 43.5352400, 1.2293700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55122, 'Fondettes', 'Fondettes', 'Fondett,Fondettes,feng dai tai,Фондетт,丰代泰', 47.4035000, 0.5968600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55123, 'Fonbeauzard', 'Fonbeauzard', 'Fombeauzard,Fonbeauzard', 43.6783000, 1.4344000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55124, 'Folschviller', 'Folschviller', 'Fol''shviller,Folschviller,Folschweiler,Folschwiller,fu er si ke wei lai,fwlshwylr,Фольшвиллер,Фольшвіллер,فولشویلر,福尔斯克维莱', 49.0706200, 6.6894800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55125, 'Follainville-Dennemont', 'Follainville-Dennemont', 'Follainville,Follainville-Dennemont,Follenvil''-Dennmon,Фолленвиль-Деннмон,Фолленвіль-Деннмон', 49.0219400, 1.7133100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55126, 'Folkling', 'Folkling', 'Folckling,Folkling', 49.1472000, 6.8950000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55127, 'Folembray', 'Folembray', 'Folembray', 49.5433400, 3.2911900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55128, 'Foix', 'Foix', 'Foa,Fois,Foix-sur-Ariege,Foix-sur-Ariège,Fua,Fuxium,Fuā,fowa,fu wa,pua,Фоа,Фуа,פואה,フォワ,富瓦,푸아', 42.9666700, 1.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55129, 'Foissiat', 'Foissiat', 'Foissiat', 46.3700800, 5.1757300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55130, 'Foëcy', 'Foecy', 'Foecy,Foëcy', 47.1761800, 2.1625700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55131, 'Flourens', 'Flourens', 'Flourens', 43.5927300, 1.5625900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55132, 'Florensac', 'Florensac', 'Floransak,Florecac,Florensac,Floreçac,fu luo lang sa ke,Флорансак,弗洛朗萨克', 43.3830100, 3.4663800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55133, 'Florange', 'Florange', 'Florange', 49.3237300, 6.1212000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55134, 'Florac', 'Florac', 'Florak,flrak,fu luo la ke,furorakku,Флорак,فلراک,フロラック,弗洛拉克', 44.3166700, 3.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55135, 'Floirac', 'Floirac', 'Floirac', 44.8323800, -0.5141100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55136, 'Floing', 'Floing', 'Floing', 49.7221600, 4.9294700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55137, 'Flogny-la-Chapelle', 'Flogny-la-Chapelle', '', 47.9500000, 3.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55138, 'Flize', 'Flize', 'Fliz,Flize,fu li ci,Флиз,Фліз,弗利兹', 49.6987500, 4.7717100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55139, 'Flixecourt', 'Flixecourt', 'Flixecourt', 50.0146500, 2.0809500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55140, 'Flins-sur-Seine', 'Flins-sur-Seine', 'Flen-sjur-Sen,Flins,Flins-sur-Seine,Флен-сюр-Сен', 48.9652300, 1.8731400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55141, 'Flines-lez-Raches', 'Flines-lez-Raches', 'Flin-le-Rash,Flines,Flines-les-Raohes,Flines-lez-Raches,Flines-lez-Râches,Flines-lès-Râohes,L''Abbaye,fu li ne lai la shen,Флин-ле-Раш,Флін-ле-Раш,弗利讷莱拉什', 50.4166700, 3.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55142, 'Flines-lès-Mortagne', 'Flines-les-Mortagne', 'Flin-le-Mortan'',Flines,Flines-les-Mortagne,Flines-lès-Mortagne,fu li ne lai mo er ta nie,Флин-ле-Мортань,Флін-ле-Мортань,弗利讷莱莫尔塔涅', 50.5028100, 3.4649500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55143, 'Fléville-devant-Nancy', 'Fleville-devant-Nancy', 'Fleville,Fleville-devant-Nancy,Fléville,Fléville-devant-Nancy', 48.6249300, 6.2049900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55144, 'Fleury-sur-Orne', 'Fleury-sur-Orne', 'Fleri-sjur-Orn,Fleury,Fleury-sur-Orne,Fljori-sjur-Orn,Floriacum ad Olnam,ao er en he pan fu lei li,Флери-сюр-Орн,Флері-сюр-Орн,Флёри-сюр-Орн,奥尔恩河畔弗勒里', 49.1485100, -0.3750800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55145, 'Fleury-sur-Andelle', 'Fleury-sur-Andelle', 'Fleury,Fleury-sur-Andelle', 49.3617600, 1.3559900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55146, 'Fleury-Mérogis', 'Fleury-Merogis', 'Fleri-Merozhi,Fleri-Merozhis,Fleury-Merogis,Fleury-Mérogis,fu lei li mei luo ji,Флери-Мерожи,Флері-Мерожис,弗勒里梅罗吉', 48.6373000, 2.3637800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55147, 'Fleury-les-Aubrais', 'Fleury-les-Aubrais', 'Fleri lez Obre,Fleri-lez-Obre,Fleury-les-Aubrais,Les Aubrais,flwry lzwbrh,fu lei li lai ao bu lai,fururi=rezobure,peulloelile-obeule,Флери лез Обре,Флері-лез-Обре,فلوری لزوبره,フルーリー＝レゾブレ,弗勒里莱奥布赖,플뢰리레오브레', 47.9332800, 1.9181100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55148, 'Fleury-la-Vallée', 'Fleury-la-Vallee', 'Fleury,Fleury-Vallee-d''Aillant,Fleury-Vallée-d’Aillant,Fleury-la-Vallee,Fleury-la-Vallée', 47.8667200, 3.4490800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55149, 'Fleury', 'Fleury', 'Fleury', 49.0400200, 6.1943500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55150, 'Fleury', 'Fleury', 'Fleury,Fleury "Bouches de l''Aude,Fleury ”Bouches de l''Aude,Fleury-d''Aude,Perignan,Pérignan', 43.2309500, 3.1374500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55151, 'Fleurines', 'Fleurines', 'Flerin,Fleurines,fu lei li nei,Флерин,弗勒里内', 49.2590100, 2.5838500, 'FR', '2016-04-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55152, 'Fleurieu-sur-Saône', 'Fleurieu-sur-Saone', 'Flere-sjur-Son,Fleurieu,Fleurieu-sur-Saone,Fleurieu-sur-Saône,Флерє-сюр-Сон', 45.8638100, 4.8445500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55153, 'Fleurie', 'Fleurie', 'Fleri,Fleurie,fururi,Флері,フルーリー', 46.1920800, 4.6973300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55154, 'Fleurey-sur-Ouche', 'Fleurey-sur-Ouche', 'Flere-sjur-Ush,Fleurey,Fleurey-sur-Ouche,Fljore-sjur-Ush,wu ke he pan fu lei lei,Флере-сюр-Уш,Флёре-сюр-Уш,乌克河畔弗勒雷', 47.3118200, 4.8591100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55155, 'Fleurbaix', 'Fleurbaix', 'Flerbe,Fleurbaei,Fleurbaix,Fleurbäi,Vloerbeke,flwbayks,fu lei er bai,Флербе,فلوبايكس,弗勒尔拜', 50.6506100, 2.8330500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55156, 'Fleurance', 'Fleurance', 'Flerans,Fleurance,Fleurence,Fljorans,Florenca,Florença,Pleurance,fu lei lang si,Флеранс,Флёранс,弗勒朗斯', 43.8482400, 0.6630200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55157, 'Flesselles', 'Flesselles', 'Flesselles', 50.0020200, 2.2611900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55158, 'Flers-en-Escrebieux', 'Flers-en-Escrebieux', 'Flers,Flers-en-Escrebieux,Flers-en-Escribeus', 50.3979000, 3.0603800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55159, 'Flers', 'Flers', 'Flers,Flers-de-l''Orne,Flers-de-l’Orne', 48.7372200, -0.5746600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55160, 'Fléac', 'Fleac', 'Fleac,Fleak,Fléac,fu lai a ke,Флеак,弗莱阿克', 45.6666700, 0.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55161, 'Flayosc', 'Flayosc', 'Flaiosc,Flaiòsc,Flayosc,Flejosk,Fleosk,fu lai ao si,Флейоск,Флеоск,弗莱奥斯', 43.5325300, 6.3940100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55162, 'Flaxlanden', 'Flaxlanden', 'Flakslanden,Flaxlanden,fu la ke si lang dang,Флаксланден,弗拉克斯朗当', 47.6949300, 7.3134300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55163, 'Flavy-le-Martel', 'Flavy-le-Martel', 'Flavy,Flavy-le-Martel', 49.7129900, 3.1915000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55164, 'Flavin', 'Flavin', 'Flavin', 44.2889000, 2.6051300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55165, 'Flavigny-sur-Moselle', 'Flavigny-sur-Moselle', 'Flavigny,Flavigny-sur-Moselle,La Basse Flavigny', 48.5641200, 6.1911300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55166, 'Flaviac', 'Flaviac', 'Flaviac', 44.7477700, 4.6743400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55167, 'Flassans-sur-Issole', 'Flassans-sur-Issole', 'Flacan,Flasan-sjur-Isol'',Flassan dIcola,Flassan dIçòla,Flassan-sjur-Issol'',Flassans,Flassans-sur-Issole,Flaçan,yi suo lei he pan fu la sang,Фласан-сюр-Исоль,Флассан-сюр-Іссоль,伊索勒河畔弗拉桑', 43.3702000, 6.2236300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55168, 'Flamanville', 'Flamanville', 'Flamanville', 49.5327400, -1.8656000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55169, 'Fitz-James', 'Fitz-James', 'Fic-Zhames,Fitz-James,fei te ya mei,Фіц-Жамес,菲特雅梅', 49.3911300, 2.4307000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55170, 'Fitilieu', 'Fitilieu', 'Fitilieu', 45.5474400, 5.5619400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55171, 'Fismes', 'Fismes', 'Fim,Fismes,fei si mei,Фім,菲斯梅', 49.3077300, 3.6860700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55172, 'Firminy', 'Firminy', 'Firmini,Firminy,fei er mi ni,Фірміні,菲尔米尼', 45.3873200, 4.2907400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55173, 'Firmi', 'Firmi', 'Firmi,Firmy', 44.5410600, 2.3076400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55174, 'Finhan', 'Finhan', 'Finhan', 43.9133500, 1.2212000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55175, 'Fillinges', 'Fillinges', '', 46.1594400, 6.3423700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55176, 'Fillé', 'Fille', 'Fie,Fille,Fille-sur-Sarthe,Fillé,Fillé-sur-Sarthe,Фіє', 47.9001100, 0.1254300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55177, 'Figeac', 'Figeac', 'Ceint-d''Eau,Figeac,Figiacum,Fijac,Fizhak,fei ya ke,fijakku,Фижак,Фіжак,フィジャック,菲雅克', 44.6000000, 2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55178, 'Figanières', 'Figanieres', 'Figanieres,Figanières', 43.5700000, 6.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55179, 'Feyzin', 'Feyzin', 'Fejzen,Feyzin,fyzn,Фейзен,فیزن', 45.6672800, 4.8597100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55180, 'Feytiat', 'Feytiat', 'Fejt''ja,Festiac,Feytiat,fei di a,Фейтья,费蒂阿', 45.8090500, 1.3303300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55181, 'Feurs', 'Feurs', 'Fer,Ferus,Feurs,Forum Segusiavorum,fu er,Фер,弗尔', 45.7398800, 4.2270600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55182, 'Feuquières-en-Vimeu', 'Feuquieres-en-Vimeu', 'Feuquieres,Feuquieres-en-Vimeu,Feuquières,Feuquières-en-Vimeu', 50.0598200, 1.6046500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55183, 'Feuquières', 'Feuquieres', 'Feuquieres,Feuquières', 49.6467700, 1.8478400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55184, 'Feuchy', 'Feuchy', 'Feshi,Feuchy,Filciacum,fu xi,fywtshy,Феши,Феші,فيوتشي,弗希', 50.2943900, 2.8433500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55185, 'Feucherolles', 'Feucherolles', 'Fesherol'',Feucherolles,Фешероль', 48.8700200, 1.9740200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55186, 'Féternes', 'Feternes', 'Feterne,Feternes,Féterne,Féternes', 46.3525900, 6.5639000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55187, 'Festubert', 'Festubert', 'Festubert', 50.5425000, 2.7359300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55188, 'Fessenheim', 'Fessenheim', 'Fessenheim', 47.9174400, 7.5369800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55189, 'Fesches-le-Châtel', 'Fesches-le-Chatel', 'Fesches,Fesches-le-Chatel,Fesches-le-Châtel', 47.5241500, 6.9053500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55190, 'Ferrières-en-Brie', 'Ferrieres-en-Brie', 'Ferrer-an-Bri,Ferrier-an-Bri,Ferrieres,Ferrieres-en-Brie,Ferrières,Ferrières-en-Brie,Ферриер-ан-Бри,Феррєр-ан-Брі', 48.8235200, 2.7066400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55191, 'Ferrière-la-Grande', 'Ferriere-la-Grande', 'Fer''er-la-Grand,Ferr''er-la-Grand,Ferrer-la-Grand,Ferriere,Ferriere-la-Grande,Ferrieres-la-Grande,Ferrière,Ferrière-la-Grande,Ferrières-la-Grande,da fei li ye er,Феррьер-ла-Гранд,Феррєр-ла-Гранд,Ферьер-ла-Гранд,大费里耶尔', 50.2552100, 3.9928800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55192, 'Ferrette', 'Ferrette', 'Ferret,Ferrett,Ferrette,Pfirt,fei lei te,Феррет,Ферретт,费雷特', 47.4919600, 7.3193700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55193, 'Ferrals-les-Corbières', 'Ferrals-les-Corbieres', 'Ferrals', 43.1500000, 2.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55194, 'Ferques', 'Ferques', 'Ferk,Ferques,fei er ke,fyrkywys,Ферк,فيركيويس,费尔克', 50.8300200, 1.7599400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55195, 'Férolles-Attilly', 'Ferolles-Attilly', 'Ferolles-Attilly,Férolles-Attilly', 48.7318400, 2.6308800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55196, 'Férolles', 'Ferolles', 'Ferol'',Ferolles,Férolles,fei luo lai,Фероль,费罗莱', 47.8347500, 2.1111300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55197, 'Ferney-Voltaire', 'Ferney-Voltaire', 'Ferne-Vol''ter,Ferney,Ferney Voltaire,Ferney-Voltaire,fei er mei-fu er tai,fyrny-fwltyr,Ферне-Вольтер,فيرني-فولتير,费尔梅－伏尔泰', 46.2585800, 6.1106300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55198, 'Fermanville', 'Fermanville', 'Fermanvil'',Fermanville,fu er mang wei er,Ферманвиль,Ферманвіль,弗尔芒维尔', 49.6867300, -1.4628400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55199, 'Férin', 'Ferin', 'Ferin,Férin', 50.3273200, 3.0741500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55200, 'Férel', 'Ferel', 'Ferel,Férel', 47.4820300, -2.3422700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55201, 'Fère-en-Tardenois', 'Fere-en-Tardenois', 'Fer-an-Tardenua,Fere en Tardenais,Fere-en-Tardenois,Fere-sur-Ourcq,Fère-en-Tardenois,Fère-sur-Ourcq,fei er ang ta de nu wa,Фер-ан-Тарденуа,费尔昂塔德努瓦', 49.2000000, 3.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55202, 'Fère-Champenoise', 'Fere-Champenoise', 'Fer-Shampenuaz,Fere-Champenoise,Fère-Champenoise,fei er shang pang wa si,Фер-Шампенуаз,费尔尚庞瓦斯', 48.7543100, 3.9906900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55203, 'Fenouillet', 'Fenouillet', 'Fenouillet', 43.6804100, 1.3920000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55204, 'Feneu', 'Feneu', 'Fene,Feneu,fei na,Фене,费纳', 47.5721100, -0.5942200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55205, 'Fénay', 'Fenay', 'Fenay,Fene,Fénay,fei nai,Фене,费奈', 47.2318500, 5.0621100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55206, 'Fenain', 'Fenain', 'Fenain,Fenen,fei nan,Фенен,费南', 50.3666700, 3.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55207, 'Felletin', 'Felletin', 'Falatin,Fel''ten,Felletin,fei lei tan,Фельтен,费勒坦', 45.8833300, 2.1743100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55208, 'Fellering', 'Fellering', 'Felleren,Fellering,Felleringen,fei lei lan,Феллерен,Феллеринг,费勒兰', 47.8965900, 6.9855200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55209, 'Félines', 'Felines', 'Felines,Félines', 45.3169300, 4.7306700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55210, 'Feillens', 'Feillens', 'Feillens', 46.3351500, 4.8886300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55211, 'Feignies', 'Feignies', 'Fen''i,Feni,fei ni,Фени,Феньи,Фені,费尼', 50.2980600, 3.9153400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55212, 'Feigères', 'Feigeres', 'Feigeres,Feigères', 46.1130500, 6.0804100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55213, 'Fégréac', 'Fegreac', 'Fegerieg,Fegreac,Fegreak,Fégréac,fei ge lei a ke,Фегреак,费格雷阿克', 47.5847600, -2.0441000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55214, 'Fegersheim', 'Fegersheim', '', 48.4901600, 7.6810700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55215, 'Féchain', 'Fechain', 'Fechain,Feshen,Féchain,fei xie,Фешен,费谢', 50.2663800, 3.2102400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55216, 'Fécamp', 'Fecamp', 'Fecamp,Fecan,Fekam,Fekan,Fiscamnum,Fécamp,Fécan,Secamp,Sècamp,fei kang,fekan,pekang,Фекам,Фекан,フェカン,费康,페캉', 49.7578700, 0.3745700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55217, 'Fayl-Billot', 'Fayl-Billot', 'Fayl-Billot,Fays-Billot', 47.7819900, 5.5991700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55218, 'Fayence', 'Fayence', 'Faens,Faienca,Faiença,Fajans,fei ang si,Файанс,Фаєнс,费昂斯', 43.6257000, 6.6953100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55219, 'Fay-de-Bretagne', 'Fay-de-Bretagne', 'Faouell,Fay,Fay-de-Bretagne', 47.4145300, -1.7915500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55220, 'Fay-aux-Loges', 'Fay-aux-Loges', 'Fay,Fay-aux-Loges,Fe-o-Lozh,fai=o=roju,fei ao luo re,Фе-о-Лож,ファイ＝オー＝ロジュ,费奥洛热', 47.9272400, 2.1401200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55221, 'Favières', 'Favieres', 'Favieres,Favières', 48.7632400, 2.7747000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55222, 'Faverolles-sur-Cher', 'Faverolles-sur-Cher', 'Faverolles,Faverolles-sur-Cher', 47.3173200, 1.1904500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55223, 'Faverney', 'Faverney', 'Faverne,Faverney,Puvernay,Фаверне', 47.7671300, 6.1042800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55224, 'Faverges-de-la-Tour', 'Faverges-de-la-Tour', 'Faverges,Faverges-de-la-Tour', 45.5909600, 5.5226500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55225, 'Faverges', 'Faverges', 'Faverga,Faverges,Faverzh,Favèrges,Фаверж', 45.7475200, 6.2929700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55226, 'Fauville-en-Caux', 'Fauville-en-Caux', 'Fauville,Fauville-en-Caux', 49.6525700, 0.5919700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55227, 'Faumont', 'Faumont', 'Faumont', 50.4601700, 3.1371300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55228, 'Faulx', 'Faulx', 'Faulx', 48.7939600, 6.1944900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55229, 'Faulquemont', 'Faulquemont', 'Falkenberg,Faulquemont,Fol''kemon,flkwmwn,fu er qu ai meng,Фолькемон,فلکومون,福尔屈埃蒙', 49.0471100, 6.6031400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55230, 'Farschviller', 'Farschviller', 'Farschviller,Farschwiller', 49.0942400, 6.8953400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55231, 'Farnay', 'Farnay', 'Farnay', 45.4929100, 4.5964300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55232, 'Fargues-Saint-Hilaire', 'Fargues-Saint-Hilaire', 'Farg-Sen-Iler,Fargas,Fargas Sent Ilari,Fargues,Fargues-Saint-Hilaire,fa er gai sheng yi lai er,Фарг-Сен-Ілер,Фарг-Сен-Илер,法尔盖圣伊莱尔', 44.8230400, -0.4467600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55233, 'Faremoutiers', 'Faremoutiers', 'Faremoutiers,Mont-l''Egalite,Mont-l''Egalité', 48.7996200, 2.9960700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55234, 'Fareins', 'Fareins', 'Fareins', 46.0179300, 4.7599300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55235, 'Farébersviller', 'Farebersviller', 'Farebersviller,Farébersviller,Pfarrebersweiler,fa lei bei er si wei lai,farbrswylr,Фареберсвиллер,Фареберсвіллер,فاربرسویلر,法雷贝尔斯维莱', 49.1199600, 6.8720100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55236, 'Fampoux', 'Fampoux', 'Fampu,fambwks,fang pu,Фампу,فامبوكس,方普', 50.3017300, 2.8731000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55237, 'Fameck', 'Fameck', 'Fameck,Famek,fa mei,famk,Фамек,فامک,法梅', 49.3033500, 6.1086000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55238, 'Famars', 'Famars', 'Famar,Famars,fa ma er,Фамар,法马尔', 50.3174300, 3.5194500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55239, 'Falleron', 'Falleron', 'Falleron', 46.8816000, -1.7020800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55240, 'Falicon', 'Falicon', 'Falico,Falicon,Falikon,fa li kong,falykwn,Фаликон,Фалікон,فاليكون,法利孔', 43.7478600, 7.2776400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55241, 'Falck', 'Falck', 'Falck', 49.2313400, 6.6349700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55242, 'Falaise', 'Falaise', 'Falaise', 48.8921700, -0.1952700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55243, 'Fains-Véel', 'Fains-Veel', 'Fains-les-Sources', 48.7833300, 5.1333300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55244, 'Fagnières', 'Fagnieres', 'Fagnieres,Fagnières', 48.9638500, 4.3169200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55245, 'Faches-Thumesnil', 'Faches-Thumesnil', 'Faches,Fash Timnij,Fash-Tjumenij,Fash-Tjumenil'',fa shen di mei si ni lei,Фаш Тимниј,Фаш-Тюмений,Фаш-Тюмениль,Фаш-Тюменій,法什蒂梅斯尼勒', 50.5833300, 3.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55246, 'Fabrezan', 'Fabrezan', 'Fabresan,Fabrezan,fa bu lei cang,fybryzn,Фабрезан,فیبریزن,法布雷藏', 43.1358100, 2.6981400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55247, 'Fabrègues', 'Fabregues', 'Fabreg,Fabregas,Fabregues,Fabrègues,fa bu lei gai,fybrygys,Фабрег,فیبریگیس,法布雷盖', 43.5505700, 3.7763700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55248, 'Ézy-sur-Eure', 'Ezy-sur-Eure', 'Ezi sir Er,Ezi-sjur-Er,Ezy,Ezy-sur-Er,Ezy-sur-Eure,e er he pan ai qi,Ézy,Ézy-sur-Eure,Ези сир Ер,Ези-сюр-Ер,Езі-сюр-Ер,厄尔河畔埃齐', 48.8666700, 1.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55249, 'Èze', 'Eze', 'Ehz,Esa,Ez,Eze,Eze-Village,Eze-sur-Mer,Isia,Mer-d''Eze,ai ci,azy,ezu,Ез,Эз,إزي,エズ,埃兹', 43.7166700, 7.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55250, 'Ézanville', 'Ezanville', 'Ehzanvil'',Ezanvil,Ezanvil'',Ezanville,ai cang wei er,Ézanville,Езанвил,Езанвиль,Езанвіль,Эзанвиль,埃藏维尔', 49.0279400, 2.3678700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55251, 'Eyzin-Pinet', 'Eyzin-Pinet', 'Eyzin,Eyzin-Pinet', 45.4724100, 4.9984100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55252, 'Eyvigues-et-Eybènes', 'Eyvigues-et-Eybenes', 'Eyvignes,Eyvignes-et-Eybenes,Eyvignes-et-Eybènes,Eyvigues', 44.9333300, 1.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55253, 'Eysines', 'Eysines', 'Aisinas,Esen,Eysines,Ezin,Езин,Езін,Есен', 44.8835200, -0.6468600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55254, 'Eyragues', 'Eyragues', 'Eyragues', 43.8410300, 4.8423100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55255, 'Eymoutiers', 'Eymoutiers', 'Aimostier,Ejmut''e,Emutje,Eymoutiers,ai mu di ye er,Еймутье,Еймутьє,Емутје,埃穆蒂耶尔', 45.7379000, 1.7418900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55256, 'Eymet', 'Eymet', 'Aimet,Eme,Eymet,ai mei,Еме,埃梅', 44.6681200, 0.3996100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55257, 'Eyguières', 'Eyguieres', 'Aiguiera,Egijer,Ehg''er,Ejgier,Eyguieres,Eyguières,ai ji ai,Егијер,Ейгіер,Эгьер,埃吉埃', 43.6948100, 5.0313100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55258, 'Eygalières', 'Eygalieres', 'Aigalieras,Egalijer,Ehgal''er,Ejgal''er,Eygalieres,Eygalières,ai jia li ai,Егалијер,Ейгальєр,Эгальер,埃加利埃', 43.7609900, 4.9496800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55259, 'Eybens', 'Eybens', 'Eban,Ehbans,Ejban,Eybens,ai bang,Ебан,Ейбан,Эбанс,埃邦', 45.1486700, 5.7492500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55260, 'Exireuil', 'Exireuil', 'Exireuil', 46.4338200, -0.1925100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55261, 'Exincourt', 'Exincourt', 'Exincourt', 47.4946500, 6.8316900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55262, 'Exideuil', 'Exideuil', 'Ehksidjoj,Eissiduelh,Eksidej,Excideuil,Exideuil,Exidolium,ai ke xi de yi,Ексидеј,Ексідей,Эксидёй,埃克西德伊', 45.8863900, 0.6731800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55263, 'Excideuil', 'Excideuil', 'Ehksidjoj,Eissiduelh,Eksidej,Ekssidej,Excideuil,ai ke si xi de yi,Ексидеј,Екссидей,Екссідей,Эксидёй,埃克斯西德伊', 45.3363500, 1.0475400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55264, 'Évry', 'Evry', 'Evry,Evry-Petit-Bourg,evuri,Évry,Évry-Petit-Bourg,エヴリー', 48.6333300, 2.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55265, 'Évron', 'Evron', 'Evron,ai fu long,evuron,Évron,Еврон,エヴロン,埃夫龙', 48.1564200, -0.3997000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55266, 'Évreux', 'Evreux', 'Aebura,EVX,Ebroicum,Eburovici,Ehvrjo,Evre,Evreaux,Evreus,Evreux,Evreux-le-Coudray,Evrieis,afrw,ai fu lei,awrw,ebeuloe,evuru,xe wer x,Évreux,Евре,Эврё,אוורה,إفرو,اورو,เอเวรอ,エヴルー,埃夫勒,에브뢰', 49.0241400, 1.1508200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55267, 'Évrecy', 'Evrecy', 'Ehvresi,Evrecy,Evresi,ai fu lei xi,Évrecy,Евреси,Евресі,Эвреси,埃夫雷西', 49.0990400, -0.5042100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55268, 'Évran', 'Evran', 'Evran,Evrann,Évran', 48.3798700, -1.9807600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55269, 'Évires', 'Evires', 'Evires,Évires', 46.0378300, 6.2245300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55270, 'Évin-Malmaison', 'Evin-Malmaison', 'Ehven-Mal''mezon,Even-Mal''mezon,Even-Malmezon,Evin,Evin-Malmaison,ai wan ma er mai zong,ayfyn malmyswn,Évin,Évin-Malmaison,Евен-Малмезон,Евен-Мальмезон,Эвен-Мальмезон,إيفين مالميسون,埃万马尔迈宗', 50.4392300, 3.0313900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55271, 'Évian-les-Bains', 'Evian-les-Bains', 'Aquianum,Ehv''jan-le-Ben,Evian,Evian-les-Bains,Evijan le Ben,Evjan-le-Ben,ai wei ang lai ban,ayfyan,ebianglebaeng,evu~ian=re=ban,Évian,Évian-les-Bains,Евијан ле Бен,Евян-ле-Бен,Эвьян-ле-Бен,إيفيان,エヴィアン＝レ＝バン,埃維昂萊班,에비앙레뱅', 46.4011100, 6.5879300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55272, 'Évenos', 'Evenos', 'Evenos,Évenos', 43.1586300, 5.8478600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55273, 'Évaux-les-Bains', 'Evaux-les-Bains', 'Ehvo-le-Ben,Evaun,Evaus,Evaux,Evaux-les-Bains,Evo le Ben,Evo-le-Ben,ai wo lai ban,Évaux-les-Bains,Ево ле Бен,Ево-ле-Бен,Эво-ле-Бен,埃沃莱班', 46.1734600, 2.4846300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55274, 'Euville', 'Euville', '', 48.7503000, 5.6260300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55275, 'Eurre', 'Eurre', 'Er,Err,Eurra,Eurre,Ер,Ерр', 44.7608800, 4.9909900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55276, 'Eulmont', 'Eulmont', 'Eulmont', 48.7517400, 6.2259300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55277, 'Eu', 'Eu', 'Eu', 50.0460600, 1.4207900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55278, 'Etzling', 'Etzling', 'Etzling', 49.1785600, 6.9613800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55279, 'Étupes', 'Etupes', 'Ehtjup,Etip,Etjup,Etupes,ai di pei,Étupes,Етип,Етюп,Этюп,埃蒂佩', 47.5052500, 6.8707500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55280, 'Étriché', 'Etriche', 'Etriche,Étriché', 47.6508700, -0.4437700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55281, 'Étreux', 'Etreux', '', 49.9833300, 3.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55282, 'Étretat', 'Etretat', 'Ehtreta,Etreta,Etretat,ai te lei ta,etoruta,Étretat,Етрета,Этрета,エトルタ,埃特雷塔', 49.7066900, 0.2052300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55283, 'Étrépagny', 'Etrepagny', 'Etrepagny,Étrépagny', 49.3062300, 1.6113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55284, 'Étrembières', 'Etrembieres', 'Etramber,Etrembieres,Etrembières,Etrembjer,Stamnaria,Étrembières,Етрамбєр,Етрембјер', 46.1786500, 6.2177400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55285, 'Étrelles', 'Etrelles', 'Etrel,Etrel'',Etrelles,Straellae,Stredell,ai te lei lai,Étrelles,Етрел,Етрель,埃特雷莱', 48.0603100, -1.1940200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55286, 'Étreillers', 'Etreillers', 'Etreillers,Étreillers', 49.8305900, 3.1602900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55287, 'Étréchy', 'Etrechy', 'Etrechy,Etrechy-la-Montagne,Etréchy-la-Montagne,Étréchy', 48.4946500, 2.1948900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55288, 'Étoile-sur-Rhône', 'Etoile-sur-Rhone', 'Estela,Estèla,Etoal sir Ron,Etoile,Etoile-sur-Rhone,Etoile-sur-Rhône,Etual''-sjur-Ron,luo ne he pan ai tu wa er,Étoile-sur-Rhône,Етоал сир Рон,Етуаль-сюр-Рон,罗讷河畔埃图瓦尔', 44.8381200, 4.8915900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55289, 'Étival-lès-le-Mans', 'Etival-les-le-Mans', 'Etival,Étival', 47.9500000, 0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55290, 'Étival-Clairefontaine', 'Etival-Clairefontaine', 'Etival,Etival Klerfonten,Etival''-Klerfonten,Etival-Clairefontaine,ai di wa ke lai lei feng tai na,Étival,Étival-Clairefontaine,Етивал Клерфонтен,Етиваль-Клерфонтен,Етіваль-Клерфонтен,埃蒂瓦克莱雷丰泰纳', 48.3651900, 6.8611800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55291, 'Étiolles', 'Etiolles', 'Et''jol'',Etiol,Etiolles,ai di ao lai,Étiolles,Етиол,Етьйоль,埃蒂奥莱', 48.6324800, 2.4822600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55292, 'Éterville', 'Eterville', 'Eterville,Éterville', 49.1442300, -0.4251200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55293, 'Étel', 'Etel', 'An Intel,Etel,Etel'',ai tai,eteru,Étel,Етел,Етель,エテル,埃泰', 47.6561400, -3.2001800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55294, 'Etaux', 'Etaux', 'Eteaux', 46.0666700, 6.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55295, 'Étauliers', 'Etauliers', 'Etauliers,Etol''e,Etolije,ai tuo li ye er,Étauliers,Етолије,Етолье,Етольє,埃托利耶尔', 45.2258200, -0.5724300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55296, 'Étaules', 'Etaules', 'Etaules,Étaules', 45.7340700, -1.0991800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55297, 'Étaples', 'Etaples', 'Ehtapl'',Etape,Etapl,Etapl'',Etaples,Etaples-sur-Mer,Montagne-sur-Mer,ai ta pu lei,atabls,Étape,Étaples,Étaples-sur-Mer,Етапл,Етапль,Этапль,إتابلس,埃塔普勒', 50.5219400, 1.6331900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55298, 'Étang-sur-Arroux', 'Etang-sur-Arroux', 'Etang,Etang-sur-Arroux,Étang,Étang-sur-Arroux', 46.8656000, 4.1898800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55299, 'Étampes-sur-Marne', 'Etampes-sur-Marne', 'Etampes,Etampes-sur-Marne,Étampes,Étampes-sur-Marne', 49.0346400, 3.4189300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55300, 'Étampes', 'Etampes', 'Ehtamp,Etamp,Etampes,Etan,Stampae,ai tang pu,atamp,etanpu,Étampes,Етамп,Етан,Этамп,اتامپ,エタンプ,埃唐普', 48.4333300, 2.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55301, 'Étalans', 'Etalans', 'Etalan,Etalans,ai ta lang,Étalans,Еталан,埃塔朗', 47.1512500, 6.2731500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55302, 'Étainhus', 'Etainhus', 'Etainhus,Étainhus', 49.5664800, 0.3128500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55303, 'Étain', 'Etain', 'Etain,Étain', 49.2125900, 5.6402200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55304, 'Étagnac', 'Etagnac', 'Ehtan''jak,Estanhac,Etagnac,Etan''jak,Etanak,ai ta ni ya ke,Étagnac,Етаньяк,Етањак,Этаньяк,埃塔尼亚克', 45.8950600, 0.7789700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55305, 'Étables-sur-Mer', 'Etables-sur-Mer', 'Ehtabl''-sjur-Mer,Etabl na Moru,Etabl''-sjur-Mer,Etables,Etables-sur-Mer,Stabuli,Staol,bin hai ai ta bu lai,Étables,Етабл на Мору,Етабль-сюр-Мер,Этабль-сюр-Мер,滨海埃塔布莱', 48.6333300, -2.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55306, 'Esvres', 'Esvres', 'Esvres,Evr,ai si fu lei,Евр,埃斯夫雷', 47.2853700, 0.7858800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55307, 'Estrées-Saint-Denis', 'Estrees-Saint-Denis', 'Ehstre-Sen-Deni,Estre Sen Deni,Estre-Sen-Deni,Estrees-Franciade,Estrees-Saint-Denis,Estrées-Franciade,Estrées-Saint-Denis,ai si te lei ai sheng de ni,Естре Сен Дени,Естре-Сен-Дені,Эстре-Сен-Дени,埃斯特雷埃圣德尼', 49.4260200, 2.6429300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55308, 'Estrées', 'Estrees', 'Estrees,Estrées', 50.3007900, 3.0698000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55309, 'Estrablin', 'Estrablin', 'Ehstrablen,Estrablen,Estrablin,ai si te la bu lan,Естраблен,Эстраблен,埃斯特拉布兰', 45.5173200, 4.9662600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55310, 'Estivareilles', 'Estivareilles', 'Estivareilles', 46.4253300, 2.6182900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55311, 'Estissac', 'Estissac', 'Estissac,Lyebault-sur-Vanne,Lyébault-sur-Vanne,Val-Libre', 48.2692000, 3.8051500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55312, 'Estillac', 'Estillac', 'Estijak,Estilhac,Estillac,ai si di la ke,Естияк,Естијак,Естіяк,埃斯蒂拉克', 44.1576600, 0.5638300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55313, 'Estevelles', 'Estevelles', 'Esteveje,Estevel'',Estevelles,ai si tai wei lei,astyfylys,Естевель,Естевеје,إستيفيليس,埃斯泰韦勒', 50.4765300, 2.9092800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55314, 'Esternay', 'Esternay', 'Esternay,Eterne,ai si tai er nai,Етерне,埃斯泰尔奈', 48.7323200, 3.5615900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55315, 'Estaires', 'Estaires', 'Bermerain,Ehster,Estaires,Ester,Stegers,ai si tai er,Естер,Эстер,埃斯泰尔', 50.6457400, 2.7278200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55316, 'Estagel', 'Estagel', 'Estagel,Estagell,Estazhel'',Etazhel,ai si ta re,Естажель,Етажел,埃斯塔热', 42.7731400, 2.6966500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55317, 'Essômes-sur-Marne', 'Essomes-sur-Marne', 'Essomes,Essomes-sur-Marne,Essômes,Essômes-sur-Marne', 49.0288100, 3.3757100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55318, 'Essigny-le-Grand', 'Essigny-le-Grand', 'Essigny,Essigny-le-Grand', 49.7786500, 3.2777400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55319, 'Essey-lès-Nancy', 'Essey-les-Nancy', 'Ehsse-le-Nansi,Ese le Nansi,Esse-le-Nansi,Essey,Essey-les-Nancy,Essey-lès-Nancy,ai sai lai nan xi,Есе ле Нанси,Ессе-ле-Нанси,Ессе-ле-Нансі,Эссе-ле-Нанси,埃塞莱南西', 48.7017900, 6.2242500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55320, 'Essert', 'Essert', 'Essert', 47.6325300, 6.8153900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55321, 'Essars', 'Essars', 'Esar,Essar,Essars,Essars-lez-Bethune,Essars-lez-Béthune,ai sa er,asars,Есар,Ессар,إسارس,埃萨尔', 50.5486800, 2.6662000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55322, 'Esquibien', 'Esquibien', 'An Eskevien,Ekibjen,Eskib''jan,Eskibjan,Esquibien,ai si qu yi bi an,esukibian,Екибјен,Ескибьян,Ескібян,エスキビアン,埃斯屈伊比安', 48.0250600, -4.5613900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55323, 'Esquerdes', 'Esquerdes', 'Ekerd,Eskerd,Esquerdes,ai si kai er de,askywrdys,Екерд,Ескерд,إسكيورديس,埃斯凯尔德', 50.7041400, 2.1885100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55324, 'Esquelbecq', 'Esquelbecq', 'Ekelbek,Ekelsbeke,Eskel''bek,Esquelbecq,ai si kai er bei ke,Екелбек,Ескельбек,埃斯凯尔贝克', 50.8869400, 2.4321500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55325, 'Esquéhéries', 'Esqueheries', 'Esqueheries,Esquéhéries', 49.9839100, 3.7474300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55326, 'Espéraza', 'Esperaza', 'Ehsperaza,Esperasan,Esperaza,Espéraza,ai si pei la zha,Еспераза,Эспераза,埃斯佩拉扎', 42.9322500, 2.2200600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55327, 'Espelette', 'Espelette', 'Ehspelet,Epelet,Espeleta,Espelett,Espelette,Ezpeleta,ai si pei lai te,esupuretto,Епелет,Еспелетт,Эспелет,エスプレット,埃斯佩莱特', 43.3401500, -1.4473700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55328, 'Espaly-Saint-Marcel', 'Espaly-Saint-Marcel', 'Espaly,Espaly-Saint-Marcel,Espaly-et-Marcel', 45.0479000, 3.8655700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55329, 'Espalion', 'Espalion', 'Ehspal''on,Espal''jon,Espalion,Espaliu,ai si pa li weng,esuparion,Еспалион,Еспальйон,Эспальон,エスパリオン,埃斯帕利翁', 44.5223700, 2.7626500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55330, 'Esnandes', 'Esnandes', 'Ehnand,Enand,Esnandes,ai si nan dai,Енанд,Энанд,埃斯南代', 46.2503300, -1.1156600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55331, 'Eslettes', 'Eslettes', 'Eslettes', 49.5482000, 1.0551500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55332, 'Escoutoux', 'Escoutoux', 'Escoutoux', 45.8207500, 3.5641500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55333, 'La Baule-Escoublac', 'La Baule-Escoublac', 'Ar Baol-Skoubleg,Baule-Escoublac,Escoublac,Escoublac-la-Baule,LBY,La Baule,La Baule-Escoublac,La Bol Ekublak,La-Bol''-Ehskublak,La-Bol''-Eskublak,Sublacum,la bo er ai si ku bu la ke,la bwly-yskwblak,Ла Бол Екублак,Ла-Боль-Ескублак,Ла-Боль-Эскублак,لا بولی-یسکوبلاک,拉博尔埃斯库布拉克', 47.2922100, -2.3639500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55334, 'Esches', 'Esches', 'Esches', 49.2208600, 2.1659500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55335, 'Eschentzwiller', 'Eschentzwiller', 'Eschentzwiller', 47.7125300, 7.3980600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55336, 'Eschbach', 'Eschbach', '', 48.8746500, 7.7360900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55337, 'Eschau', 'Eschau', '', 48.4889700, 7.7164400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55338, 'Escautpont', 'Escautpont', 'Ehskopon,Escautpont,Eskopon,ai si ke peng,Ескопон,Эскопон,埃斯科蓬', 50.4187500, 3.5534100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55339, 'Escaudœuvres', 'Escaudoeuvres', 'Ehskodevr,Escaudoeuvres,Eskodevr,ai si ke duo fu er,Ескодевр,Эскодевр,埃斯科多夫尔', 50.2000000, 3.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55340, 'Escaudain', 'Escaudain', 'Escaudain', 50.3331500, 3.3443000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55341, 'Escalquens', 'Escalquens', 'Escalquens', 43.5174400, 1.5589300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55342, 'Esbly', 'Esbly', 'Ebli,Esbly,ai si bu li,Ебли,Еблі,埃斯布利', 48.9052000, 2.8123500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55343, 'Ervy-le-Châtel', 'Ervy-le-Chatel', 'Ervy,Ervy-le-Chatel,Ervy-le-Châtel', 48.0411600, 3.9098800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55344, 'Erstein', 'Erstein', 'Eerstain,Erstein,Ersten,ai er si tan,arstyn,erusutan,Ерстен,إرستين,エルスタン,埃尔斯坦', 48.4237300, 7.6626200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55345, 'Erre', 'Erre', 'Erre,Erre-en-Ostrevent', 50.3625200, 3.3156100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55346, 'Erquy', 'Erquy', 'Ehrki,Erge-ar-Mor,Erki,Erqueium,Erquy,Erquy-Plages,ai er qu yi,eruki,Ерки,Еркі,Эрки,エルキ,埃尔屈伊', 48.6318600, -2.4628000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55347, 'Erquinghem-Lys', 'Erquinghem-Lys', 'Erquinghem-Lys', 50.6760100, 2.8450500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55348, 'Ernolsheim-Bruche', 'Ernolsheim-Bruche', 'Arelse,Ernol''sajm-Brjush,Ernolsheim,Ernolsheim-Bruche,ai er nuo er sang bu lu ke,arnwlshaym-brwkhh,arnwlshym brwtsh,Ернольсайм-Брюш,إرنولشيم بروتش,ارنولسهایم-بروخه,埃尔诺尔桑布吕克', 48.5653100, 7.5650300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55349, 'Ernée', 'Ernee', 'Erne,Ernee,Ernée,ai er nei ai,Ерне,埃尔内埃', 48.2976400, -0.9314300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55350, 'Ermont', 'Ermont', 'Ehrmon,Ermon,Ermont,ai er meng,armwn,eleumong,erumon,Ермон,Эрмон,ارمون,エルモン,埃尔蒙,에르몽', 48.9900400, 2.2580400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55351, 'Ergué-Gabéric', 'Ergue-Gaberic', 'An Erge-Vras,Erge-Gaberik,Ergue-Gaberic,Ergué-Gabéric,ai er gai jia bei li ke,eruge=gaberikku,Ерге-Габерик,エルゲ＝ガベリック,埃尔盖加贝里克', 47.9956200, -4.0222300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55352, 'Erdeven', 'Erdeven', 'An Ardeven,An Erdeven,Erdevan,Erdeven,ai er de wang,Ердеван,埃尔德旺', 47.6421000, -3.1570600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55353, 'Ercuis', 'Ercuis', 'Ercuis,Erkjui,ai er qu yi,Еркюї,埃尔屈伊', 49.2346500, 2.3040700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55354, 'Ercé-près-Liffré', 'Erce-pres-Liffre', 'Erce,Erce-pres-Liffre,Ercee-pres Liffre,Ercé,Ercé-près-Liffré,Ercée-près Liffré,Erse-pre-Liffre,Herceium prope Gahardum,Herzieg-Liverieg,ai er sai pu lei li fu lei,Ерсе-пре-Лиффре,Ерсе-пре-Ліффре,埃尔塞普雷利夫雷', 48.2545400, -1.5156000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55355, 'Ercé-en-Lamée', 'Erce-en-Lamee', 'Erce,Erce-en-Lamee,Ercé,Ercé-en-Lamée,Herzieg-Mez', 47.8304800, -1.5586700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55356, 'Erbrée', 'Erbree', 'Erbre,Erbree,Erbreia,Erbrée,Ervored,ai er bu lei ai,Ербре,埃尔布雷埃', 48.0974500, -1.1247900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55357, 'Erbray', 'Erbray', 'Arbraiacum,Erbray,Erbre,Ervoreg,ai er bu lai,Ербре,埃尔布赖', 47.6549200, -1.3178300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55358, 'Éragny', 'Eragny', 'Eragny,Éragny', 49.0166700, 2.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55359, 'Équihen-Plage', 'Equihen-Plage', 'Ekian-Plazh,Ekjen-Plazh,Equihen,Equihen-Plage,Inquihin-Plage,akywyhyn blaj,Équihen-Plage,Екиан-Плаж,Екіан-Плаж,Екјен-Плаж,إكيويهين بلاج', 50.6755700, 1.5722500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55360, 'Équeurdreville-Hainneville', 'Equeurdreville-Hainneville', 'Ekerdrevil''-Ennevil'',Equeurdreville,Equeurdreville-Hainneville,ai qu e er de lei wei er ai na wei er,Екердревиль-Енневиль,Екердревіль-Енневіль,埃屈厄尔德勒维尔艾纳维尔', 49.6486800, -1.6530600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55361, 'Équemauville', 'Equemauville', 'Equemauville,Équemauville', 49.3940600, 0.2076000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55362, 'Épron', 'Epron', 'Ehpron,Epron,ai pu long,Épron,Епрон,Эпрон,埃普龙', 49.2217400, -0.3708500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55363, 'Eppeville', 'Eppeville', 'Eppevil'',Eppeville,ai po wei er,Éppeville,Еппевіль,埃珀维尔', 49.7406900, 3.0511400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55364, 'Épouville', 'Epouville', 'Epouville,Epuvil'',Épouville,Епувиль,Епувіль', 49.5634900, 0.2237300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55365, 'Épône', 'Epone', 'Epon,Epone,Epône,Épône,Епон', 48.9547600, 1.8223300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55366, 'Épinouze', 'Epinouze', 'Epinouze,Épinouze', 45.3090700, 4.9337600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55367, 'Epiniac', 'Epiniac', 'Epinac,Epiniac,Sperneg', 48.5000000, -1.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55368, 'Épinay-sur-Seine', 'Epinay-sur-Seine', 'Ehpine-sjur-Sen,Epinay,Epinay-sur-Seine,Epine na Seni,Epine sjur Sen,Epine-sjur-Sen,abyny-swr-syn,apynh swr sn,apynh-swr-sn,epine=shuru=senu,sai na he pan ai pi nai,Épinay-sur-Seine,Епине на Сени,Епине сюр Сен,Епине-сюр-Сен,Епіне-сюр-Сен,Эпине-сюр-Сен,אפינה-סור-סן,ابيني-سور-سين,اپینه سور سن,اپینه-سور-سن,エピネー＝シュル＝セーヌ,塞纳河畔埃皮奈', 48.9535000, 2.3151400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55369, 'Épinay-sur-Orge', 'Epinay-sur-Orge', 'Epinay,Epinay-sur-Orge,Epine sir Orzh,Epine-sjur-Orzh,Spinetum ad Urbiam,ao er ri he pan ai pi nai,Épinay,Épinay-sur-Orge,Епине сир Орж,Епине-сюр-Орж,Епіне-сюр-Орж,奥尔日河畔埃皮奈', 48.6733800, 2.3107400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55370, 'Épinay-sous-Sénart', 'Epinay-sous-Senart', 'Epinay,Epinay-sous-Senart,Epine-su-Senar,ai pi nai su sai na er,Épinay-sous-Sénart,Епине-су-Сенар,Епіне-су-Сенар,埃皮奈苏塞纳尔', 48.6897000, 2.5118600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55371, 'Épinal', 'Epinal', 'EPL,Ehpinal'',Epinal,Epinal'',Epinalis,Spinalium,Spinalo,abnal,ai pi na lei,apynal,apynl,epinal,epinaru,Épinal,Епинал,Епиналь,Епіналь,Эпиналь,إبنال,اپینال,اپینل,ეპინალი,エピナル,埃皮纳勒,에피날', 48.1833300, 6.4500000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55372, 'Épinac', 'Epinac', 'Epinac-les-Mines,Epinak,Épinac-les-Mines,Епинак,Епінак', 46.9833300, 4.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55373, 'Épieds-en-Beauce', 'Epieds-en-Beauce', 'Epe-an-Bos,Epieds,Epieds-en-Beauce,bo ke de qu ai pi ye de,Épieds-en-Beauce,Епє-ан-Бос,博克地区埃皮耶德', 47.9506600, 1.6173200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55374, 'Epfig', 'Epfig', 'Apfig,Epfig,abfyj,ai pu fei,apfysh,Епфиг,Епфіг,إبفيج,اپفیش,埃普菲', 48.3593300, 7.4642700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55375, 'Épervans', 'Epervans', 'Epervan,Epervans,Épervans,Еперван', 46.7524700, 4.8993000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55376, 'Épernon', 'Epernon', 'Epernon,ai pei er nong,Épernon,Епернон,埃佩尔农', 48.6103100, 1.6721800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55377, 'Épernay', 'Epernay', 'Ehperne,Epernay,Eperne,ai pei er nai,aprnh,eperune,Épernay,Еперне,Эперне,اپرنه,エペルネー,埃佩尔奈', 49.0500000, 3.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55378, 'Éperlecques', 'Eperlecques', 'Eparlecques,Eperlecques,Eperlek,Sperleke,abyrlyskys,ai pei lai ke,Éparlecques,Éperlecques,Еперлек,إبيرليسكيس,埃佩莱克', 50.8056600, 2.1520700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55379, 'Épehy', 'Epehy', '', 50.0000000, 3.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55380, 'Épaignes', 'Epaignes', 'Epaignes,Épaignes', 49.2794500, 0.4398000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55381, 'Épagny', 'Epagny', 'Epagny,Épagny', 45.9380500, 6.0909500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55382, 'Envermeu', 'Envermeu', 'Aebura,Eburomagos,Envermeu', 49.8956000, 1.2649300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55383, 'Enval', 'Enval', 'Anval'',Enval,Envalh,ang wa,Анваль,昂瓦', 45.8988300, 3.0497000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55384, 'Entzheim', 'Entzheim', 'Entzheim', 48.5322400, 7.6332900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55385, 'Entre-deux-Guiers', 'Entre-deux-Guiers', 'Entre-deux-Guiers', 45.4318100, 5.7491100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55386, 'Entraygues-sur-Truyère', 'Entraygues-sur-Truyere', 'Antreg-sjur-Trjuier,Antreg-sjur-Trjujer,Entraigas,Entraygues,Entraygues-sur-Truyere,Entraygues-sur-Truyère,te lu yi ai er he pan ang te lai gai,Антрег-сюр-Трюйер,Антрег-сюр-Трюїер,特吕伊埃尔河畔昂特赖盖', 44.6460600, 2.5674500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55387, 'Entrange', 'Entrange', 'Entrange', 49.4158900, 6.1062000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55388, 'Entrammes', 'Entrammes', 'Entrammes', 47.9975900, -0.7139900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55389, 'Entraigues-sur-la-Sorgue', 'Entraigues-sur-la-Sorgue', 'Antreg-sjur-la-Sorg,Entraigas,Entraigas de Sorga,Entraigas de Sòrga,Entraigues,Entraigues-sur-Sorgues,la suo er ju he pan ang te lai ju e,Антрег-сюр-ла-Сорг,拉索尔居河畔昂特赖居厄', 44.0000000, 4.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55390, 'Ensuès-la-Redonne', 'Ensues-la-Redonne', 'Ansjue-la-Redonn,Ansjuehs-la-Redon,En Sua la Redona,En Suá la Redona,Ensue,Ensues,Ensues-la-Redonne,Ensuès,Ensuès-la-Redonne,Ensué,ang xu ai la lei dong,Ансюе-ла-Редонн,Ансюэс-ла-Редон,昂叙埃拉雷东', 43.3546400, 5.2035700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55391, 'Ensisheim', 'Ensisheim', 'Ehnsisajm,Ensisajm,Ensisheim,ang xi sang,Енсисайм,Енсісайм,Энсисайм,昂西桑', 47.8669500, 7.3521200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55392, 'Ennezat', 'Ennezat', 'Enesac,Ennezat,Ennza,ai nei zha,Еннза,埃内扎', 45.8976800, 3.2221700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55393, 'Ennevelin', 'Ennevelin', 'Ennevelin,Ennevelin-Ardomprez', 50.5412100, 3.1297200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55394, 'Ennetières-en-Weppes', 'Ennetieres-en-Weppes', 'Ennetieres,Ennetieres-en-Weppes,Ennetières,Ennetières-en-Weppes', 50.6353000, 2.9401200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55395, 'Ennery', 'Ennery', 'Ennery', 49.2262100, 6.2180500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55396, 'Ennery', 'Ennery', 'Ennery', 49.0750500, 2.1059900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55397, 'Englefontaine', 'Englefontaine', 'Englefontaine', 50.1909100, 3.6440100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55398, 'Enghien-les-Bains', 'Enghien-les-Bains', 'Ang''jan-le-Ben,Angen-le-Ben,Angjan-le-Ben,Angjen le Ben,Enghien,Enghien-les-Bains,ang ji an lai ban,angyan=re=ban,Анген-ле-Бен,Ангьян-ле-Бен,Ангян-ле-Бен,Ангјен ле Бен,アンギャン＝レ＝バン,昂吉安莱班', 48.9666700, 2.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55399, 'Enchenberg', 'Enchenberg', 'Enchenberg', 49.0122100, 7.3404900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55400, 'Emmerin', 'Emmerin', 'Emmeren,Emmerin,ai mo lan,Еммерен,埃默兰', 50.5947500, 3.0012400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55401, 'Émerchicourt', 'Emerchicourt', 'Emerchicourt,Émerchicourt', 50.3078600, 3.2453700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55402, 'Émerainville', 'Emerainville', 'Emerainville,Émerainville', 48.8127600, 2.6213900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55403, 'Embrun', 'Embrun', 'Aebura,Ambrun,Eburodunum', 44.5638700, 6.4952600, 'FR', '2017-02-09', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55404, 'Elven', 'Elven', 'An Elven,Elven', 47.7323000, -2.5895600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55405, 'Éloyes', 'Eloyes', 'Eloa,Eloyes,Elua,ai lu wa ai,Éloyes,Елоа,Елуа,埃卢瓦埃', 48.0979300, 6.6065300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55406, 'Elne', 'Elne', 'El''n,Elna,Elne,Euna,ai er en,erunu,Ельн,ኤልን,エルヌ,埃尔恩', 42.6003100, 2.9714600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55407, 'Elliant', 'Elliant', 'El''jan,Eliant,Elliant,ai li ang,Ельян,埃利昂', 47.9941700, -3.8896600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55408, 'Éleu-dit-Leauwette', 'Eleu-dit-Leauwette', 'Ele di Lovet,Ele-di-Lovett,Eleu,Eleu-dit-Leauwette,Liauwette,ai lei di luo wei te,alyw dyt lyawyt,Éleu-dit-Leauwette,Еле ди Ловет,Еле-ди-Ловетт,Еле-ді-Ловетт,إليو ديت لياويت,埃勒迪洛韦特', 50.4234000, 2.8113500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55409, 'Elbeuf', 'Elbeuf', 'Ehl''bjof,El''bef,Elbeuf,Elbovium,Ельбеф,Эльбёф', 49.2866900, 1.0028800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55410, 'Élancourt', 'Elancourt', 'Elancourt,Elankur,alankwr,ellangkuleu,erankuru,Élancourt,Еланкур,الانکور,エランクール,엘랑쿠르', 48.7842100, 1.9552000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55411, 'Einville-au-Jard', 'Einville-au-Jard', 'Einville,Einville-au-Jard', 48.6532300, 6.4878600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55412, 'Eguisheim', 'Eguisheim', 'Egisajm,Egishaym,Egisheim,Eguisheim,Ehgiskhajm,ai ji sang,egisuhaimu,Егисайм,Егісайм,Эгисхайм,Էգիսհայմ,אגיסהיים,اگیویزہائم,エギスハイム,埃吉桑', 48.0428000, 7.3061700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55413, 'Éguilles', 'Eguilles', 'Agulha,Agulha dAis,Egil'',Eguilles,Ehgjuij,ai ji lai,Éguilles,Егіль,Эгюий,埃吉莱', 43.5686700, 5.3557500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55414, 'Égriselles-le-Bocage', 'Egriselles-le-Bocage', 'Egriselles,Egriselles-le-Bocage,Égriselles-le-Bocage', 48.1210300, 3.1823300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55415, 'Égreville', 'Egreville', 'Egrevil'',Egreville,Égreville,Егревиль,Егревіль', 48.1760600, 2.8727800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55416, 'Égly', 'Egly', 'Egli,Egly,ai ge li,Égly,Егли,Еглі,埃格利', 48.5782800, 2.2241700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55417, 'Égletons', 'Egletons', 'Egletons,Égletons', 45.4033600, 2.0507300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55418, 'Edern', 'Edern', 'Edern,Guellevain', 48.1000000, -3.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55419, 'Écully', 'Ecully', 'Ecully,Écully', 45.7772600, 4.7748100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55420, 'Écuisses', 'Ecuisses', 'Ecuisses,Écuisses', 46.7563100, 4.5384500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55421, 'Écuelles', 'Ecuelles', 'Ecuelles,Écuelles', 48.3563600, 2.8233500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55422, 'Écueillé', 'Ecueille', 'Ecueille,Ehkjoje,Ekjuee,ai qu ai lai,Écueillé,Екюеє,Экёйе,埃屈埃莱', 47.0846200, 1.3466800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55423, 'Écrouves', 'Ecrouves', 'Ecrouves,Écrouves', 48.6793700, 5.8443300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55424, 'Écrainville', 'Ecrainville', 'Ecrainville,Écrainville', 49.6494300, 0.3248800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55425, 'Ecquevilly', 'Ecquevilly', 'Ecquevilly,Ekvilli,Еквилли,Еквіллі', 48.9519200, 1.9233800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55426, 'Ecques', 'Ecques', 'Ecques,Ek,ai ke,askyws,Ек,إسكيوس,埃克', 50.6699800, 2.2863300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55427, 'Écoyeux', 'Ecoyeux', 'Ecoyeux,Ehkuajjo,Ekuae,ai kua e,Écoyeux,Екуає,Экуайё,埃夸厄', 45.8223100, -0.5053900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55428, 'Écourt-Saint-Quentin', 'Ecourt-Saint-Quentin', 'Ecourt-Saint-Quentin,Écourt-Saint-Quentin', 50.2522600, 3.0733100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55429, 'Écouflant', 'Ecouflant', 'Ecouflant,Ekuflan,ai ku fu lang,Écouflant,Екуфлан,埃库夫朗', 47.5310100, -0.5278000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55430, 'Écouen', 'Ecouen', 'Ecouen,Ehkuan,Ekuan,ai ku ang,Écouen,Екуан,Экуан,埃库昂', 49.0206200, 2.3830900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55431, 'Écouché', 'Ecouche', 'Ecouche,Ekushe,ai ku xie,Écouché,Екуше,埃库谢', 48.7175100, -0.1240900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55432, 'Écommoy', 'Ecommoy', 'Ecommay,Ecommoy,Ekommua,Ekomoa,Écommoy,Екоммуа,Екомоа', 47.8256500, 0.2742200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55433, 'Eckwersheim', 'Eckwersheim', 'Eckwersheim', 48.6816700, 7.6968700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55434, 'Eckbolsheim', 'Eckbolsheim', 'Eckelse,Ekbol''sajm,ai ke bo er sang,akblshaym,akbwlshym,Екбольсайм,إكبولشيم,اکبلسهایم,埃克博尔桑', 48.5807500, 7.6876800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55435, 'Échirolles', 'Echirolles', 'Echirolles,Ehshirol'',Eshirol,Eshirol'',ai xi luo lai,ashyrwl,eshiroru,esilol,Échirolles,Еширол,Ешироль,Эшироль,اشيرول,اشیرول,エシロル,埃希罗莱,에시롤', 45.1439000, 5.7288300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55436, 'Échiré', 'Echire', 'Echire,Echireyum,Eshire,eshire,Échiré,Ешире,エシレ', 46.3874800, -0.4151100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55437, 'Échillais', 'Echillais', 'Echillais,Échillais', 45.9007200, -0.9521100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55438, 'Échenoz-la-Méline', 'Echenoz-la-Meline', 'Echenoz-la-Meline,Ehshno-la-Melin,Esheno-la-Melin,Échenoz-la-Méline,Ешено-ла-Мелін,Эшно-ла-Мелин', 47.6008600, 6.1354400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55439, 'Échenevex', 'Echenevex', 'Echenevex,Échenevex', 46.3096300, 6.0393000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55440, 'Échalas', 'Echalas', 'Echalas,Échalas', 45.5519000, 4.7164500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55441, 'Écaillon', 'Ecaillon', 'Ecaillon,Écaillon', 50.3503400, 3.2166400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55442, 'Ébreuil', 'Ebreuil', 'Eborolacum,Ebrej,Ebreuil,Ebruelh,Ehbrjoj,Esbreule,ai bu lei yi,Ébreuil,Ебрей,Эбрёй,埃布勒伊', 46.1162900, 3.0877100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55443, 'Ebersheim', 'Ebersheim', '', 48.3043800, 7.4990300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55444, 'Eauze', 'Eauze', 'Eauze', 43.8605500, 0.1019900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55445, 'Eaunes', 'Eaunes', 'Eaunes,Eunas,On,Èunas,Он', 43.4207900, 1.3539700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55446, 'Eaubonne', 'Eaubonne', 'Eaubonne,Obon,Obonn,ao bo ne,awbwn,obon,obon''nu,Обон,Обонн,اوبون,オーボンヌ,奥博讷,오본', 48.9971200, 2.2824900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55447, 'Duttlenheim', 'Duttlenheim', '', 48.5255300, 7.5657200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55448, 'Durtol', 'Durtol', 'Djurtol'',Durtol,Durtou,Durtòu,di er tuo,Дюртоль,迪尔托', 45.7962200, 3.0526400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55449, 'Durtal', 'Durtal', 'Djurtal'',di er ta,Дюрталь,迪尔塔', 47.6724700, -0.2339300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55450, 'Durrenbach', 'Durrenbach', 'Durrenbach', 48.8974800, 7.7673300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55451, 'Durdat-Larequille', 'Durdat-Larequille', 'Durdat-Larequille,Larequille', 46.2517300, 2.7011200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55452, 'Duras', 'Duras', 'Duras', 44.6761800, 0.1824700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55453, 'Duppigheim', 'Duppigheim', 'Dippje,Djuppigajm,Dueppigheim,Díppje,Düppigheim,di pi gan,dwbyhym,Дюппигайм,Дюппігайм,دوبيهيم,迪皮甘', 48.5286600, 7.5942100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55454, 'Dun-sur-Auron', 'Dun-sur-Auron', 'Den-sjur-Oron,Djon-sjur-Oron,Dun,Dun-sur-Auron,ao luo ne he pan dan,Ден-сюр-Орон,Дён-сюр-Орон,奥罗讷河畔丹', 46.8849000, 2.5734500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55455, 'Dun-le-Palestel', 'Dun-le-Palestel', 'Dun-le-Palestel,Dun-le-Palleteau,Dun-le-Pelletau', 46.3000000, 1.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55456, 'Dunkerque', 'Dunkerque', 'CQF,Denkerk,Denkerka,Diunkerkas,Djunkerk,Doun''kerki,Duenkirchen,Duinkerke,Duinkerken,Dukark,Dun-Libre,Dune-Libre,Dunes-Libres,Dunkeke,Dunkerk,Dunkerque,Dunkierka,Dunkirk,Dunkèke,Dunquerca,Dunquerque,Dunquèrca,Duntsjerk,Duunkerke,Dúntsjerk,Dünkirchen,Gorad Dzjunkerk,Lungsod ng Dunkerque,dainkarka,dankarka,dankeruku,dnkrk,dnqrq,doengkeleukeu,dui ke er ke,dun ke er ke,dun ku e ke,dwnkrk,dwnkyrk,tankirk,Δουνκέρκη,Горад Дзюнкерк,Денкерк,Дюнкерк,דונקערק,דנקרק,دنکرک,دونكيرك,دونکرک,ڈنکرک,डंकर्क,दैंकर्क,டன்கிர்க்,დიუნკერკი,ダンケルク,敦刻尔克,顿库厄克,됭케르크', 51.0329700, 2.3770000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55457, 'Dunières', 'Dunieres', 'Dunieres,Dunières', 45.2159800, 4.3457900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55458, 'Duisans', 'Duisans', 'Djuizan,Duisans,di cang,dwysans,Дюизан,Дюїзан,دويسانس,迪藏', 50.3063300, 2.6865300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55459, 'Dugny-sur-Meuse', 'Dugny-sur-Meuse', 'Dugny,Dugny-sur-Meuse', 49.1095300, 5.3855000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55460, 'Dugny', 'Dugny', 'Djun''i,Dugny,di ni,dwgny,Дюньи,Дюньї,דוגני,迪尼', 48.9537100, 2.4173400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55461, 'Duclair', 'Duclair', 'Djukler,Duclair,Дюклер', 49.4838500, 0.8761700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55462, 'Ducey', 'Ducey', 'Djuse,Ducey,di sai,Дюсе,迪塞', 48.6184300, -1.2905200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55463, 'Dry', 'Dry', 'Dry', 47.7961200, 1.7133000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55464, 'Drusenheim', 'Drusenheim', 'Drjuzenajm,Droesem,Drusenheim,Drösem,de lu se nan,doryuzenaimu,drwsynhym,Дрюзенайм,دروسينهيم,ドリュゼナイム,德吕瑟南', 48.7642800, 7.9505300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55465, 'Drumettaz-Clarafond', 'Drumettaz-Clarafond', 'Drjumetta-Klarafon,Drumeta-Cllarafond,Drumettaz,Drumettaz-Clarafond,Drumèta-Cllârafond,Дрюметта-Кларафон', 45.6603700, 5.9214500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55466, 'Drulingen', 'Drulingen', 'Drulingen', 48.8683400, 7.1876100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55467, 'Druelle', 'Druelle', 'Druelle', 44.3600600, 2.5050500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55468, 'Droue-sur-Drouette', 'Droue-sur-Drouette', 'Droue,Droue-sur-Drouette,Droué,Dru-sjur-Druett,de lu ai te he pan de lu ai,Дру-сюр-Друетт,德鲁埃特河畔德鲁埃', 48.6005300, 1.7011300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55469, 'Droué', 'Droue', 'Droue,Droué,Drue,de lu ai,Друе,德鲁埃', 48.0402300, 1.0753400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55470, 'Drocourt', 'Drocourt', 'Drocourt', 50.3900200, 2.9242500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55471, 'Dreux', 'Dreux', 'Dre,Dreux,Drjo,Drocae,Drė,XDR,de lei,deuloe,doru,drw,drw  fransh,Дре,Дрё,درو,درو، فرانسه,ድርው,ドルー,德勒,드뢰', 48.7333300, 1.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55472, 'Dreuil-lès-Amiens', 'Dreuil-les-Amiens', 'Dreuil,Dreuil-les-Amiens,Dreuil-lès-Amiens', 49.9148300, 2.2289300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55473, 'Dreslincourt', 'Dreslincourt', 'Dreslincourt', 49.5280900, 2.9269900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55474, 'Drémil-Lafage', 'Dremil-Lafage', 'Dremil,Dremil-Lafage,Drémil-Lafage', 43.5962400, 1.6011700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55475, 'Drefféac', 'Dreffeac', 'Devrieg,Drefeak,Dreffeac,Dreffeak,Drefféac,de lei fei a ke,Дрефеак,Дреффеак,德雷费阿克', 47.4746400, -2.0577400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55476, 'Draveil', 'Draveil', 'Draveil,Dravej,de la wei yi,deulabei,doravu~eiyu,drwy,Дравей,Дравеј,دروی,ドラヴェイユ,德拉韋伊,드라베이', 48.6846600, 2.4141800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55477, 'Drap', 'Drap', 'Drap', 43.7561400, 7.3205900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55478, 'Drancy', 'Drancy', 'Drancy,Dransi,de lang xi,deulangsi,doranshi,dr xng si,dransy,Дранси,Дрансі,דראנסי,درانسي,درانسی,ดร็องซี,ドランシー,德朗西,드랑시', 48.9257800, 2.4453300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55479, 'Drain', 'Drain', 'Drain', 47.3365500, -1.2077300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55480, 'Draguignan', 'Draguignan', 'Dragin''jan,Draginan,Draguignan,Draguinhan,Gorad Dragin''jan,de la ji ni ang,deulaginyang,doraginyan,draginiani,drgwaynyan,Горад Драгіньян,Драгиньян,Драгињан,Драгіньян,درگواینیان,დრაგინიანი,ドラギニャン,德拉吉尼昂,드라기냥', 43.5333300, 6.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55481, 'Dracy-le-Fort', 'Dracy-le-Fort', 'Dracy,Dracy-le-Fort', 46.7975000, 4.7621500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55482, 'Dozulé', 'Dozule', 'Dozil,Dozjule,Dozule,Dozulé,duo ju lai,Дозил,Дозюле,多聚莱', 49.2313200, -0.0445400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55483, 'Doyet', 'Doyet', 'Doyet', 46.3347600, 2.7970700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55484, 'Douzy', 'Douzy', 'Douzy', 49.6708000, 5.0415600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55485, 'Douvrin', 'Douvrin', 'Douvrin,Duvren,du fu lan,dwfrbn,Дуврен,دوفربن,杜夫兰', 50.5091600, 2.8305300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55486, 'Douvres-la-Délivrande', 'Douvres-la-Delivrande', 'Douvres,Douvres-la-Delivrande,Douvres-la-Délivrande,Duvr la Delivran,Duvr-la-Delivrand,du fu lei la dai li fu lang de,Дувр ла Деливран,Дувр-ла-Деливранд,Дувр-ла-Делівранд,杜夫雷拉代利夫朗德', 49.2947200, -0.3803900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55487, 'Douvaine', 'Douvaine', 'Duvania,Duven,Дувен', 46.3054400, 6.3037500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55488, 'Doussard', 'Doussard', 'Doussard,Dulciarium,Dusar,Dussar,Дусар,Дуссар', 45.7755600, 6.2194100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55489, 'Dourgne', 'Dourgne', 'Dourgne', 43.4838100, 2.1398900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55490, 'Dourges', 'Dourges', 'Dourches,Dourges,Dourques,Durzh,du er ri,dwrjys,Дурж,دورجيس,杜尔日', 50.4363600, 2.9858900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55491, 'Dourdan', 'Dourdan', 'Dourdan,Durdan,du er dang,Дурдан,杜尔当', 48.5277200, 2.0111300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55492, 'Doullens', 'Doullens', 'Doullens,Dourlin,Dulan,Dullan,du lang,Дулан,Дуллан,杜朗', 50.1572400, 2.3401900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55493, 'Doulaincourt-Saucourt', 'Doulaincourt-Saucourt', '', 48.3166700, 5.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55494, 'Doué-la-Fontaine', 'Doue-la-Fontaine', 'Doue,Doue-la-Fontaine,Doué,Doué-la-Fontaine,Due la Fonten,Due-la-Fonten,du ai la feng tan,Дуе ла Фонтен,Дуе-ла-Фонтен,杜埃拉丰坦', 47.1937200, -0.2749200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55495, 'Doue', 'Doue', 'Doue,Du,Ду', 48.8664100, 3.1626900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55496, 'Doudeville', 'Doudeville', 'Doudeville,Dudvil,Dudvil'',Дудвил,Дудвиль,Дудвіль', 49.7226800, 0.7847900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55497, 'Douchy-les-Mines', 'Douchy-les-Mines', 'Douchy,Douchy-les-Mines,Dushi le Men,Dushi-le-Min,du xi lai mi ne,Души ле Мен,Души-ле-Мин,Душі-ле-Мін,杜希莱米讷', 50.3008000, 3.3927000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55498, 'Douchy', 'Douchy', 'Douchy', 47.9428200, 3.0539200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55499, 'Doubs', 'Doubs', '', 46.9278800, 6.3510400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55500, 'Douarnenez', 'Douarnenez', 'Douamenez,Douarnenez,Dovarnena,Duarnene,Duarnenez,do~uarunune,du a er na na,Дуарнене,Дуарненез,ドゥアルヌネ,杜阿尔纳纳', 48.0954200, -4.3290400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55501, 'Douai', 'Douai', 'Doi,Douai,Dowaai,Doï,Duacum,Due,Dueh,XDN,do~ue,du ai,due,dway,dwyh,Дуе,Дуэ,دوئه,دواي,ドゥエー,杜埃,두에', 50.3666700, 3.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55502, 'Dossenheim-sur-Zinsel', 'Dossenheim-sur-Zinsel', 'Dosenkhajm sir Cinzel,Dossenajm-sjur-Zensel'',Dossenheim,Dossenheim an der Zinsel,Duusne,zan sai he pan duo se nan,Досенхајм сир Цинзел,Доссенайм-сюр-Зенсель,赞塞河畔多瑟南', 48.8059000, 7.4027300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55503, 'Dortan', 'Dortan', 'Dortan,duo er tang,dwrta,Дортан,Դորտան,دورتا,多尔唐', 46.3197300, 5.6602800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55504, 'Dornes', 'Dornes', 'Dornes', 46.7160000, 3.3534300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55505, 'Dormans', 'Dormans', 'Dorman,duo er mang,Дорман,多尔芒', 49.0739200, 3.6381900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55506, 'Dorlisheim', 'Dorlisheim', 'Dorlisheim,Dorliskhajm,Дорлисхајм', 48.5248500, 7.4862400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55507, 'Dordives', 'Dordives', 'Dordiv,Dordives,duo er di wei,Дордив,Дордів,多尔迪韦', 48.1425300, 2.7677500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55508, 'Donzy', 'Donzy', 'Donzi,Donziacum,Donzy,dong qi,Донзи,Донзі,东齐', 47.3706600, 3.1254800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55509, 'Donzère', 'Donzere', 'Donzer,Donzera,Donzere,Donzèra,Donzère,Dozera,Донзер', 44.4408900, 4.7117900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55510, 'Donzenac', 'Donzenac', 'Donzenac,Donzenak,Donznak,dong ze na ke,donzunakku,Донзенак,Донзнак,ドンズナック,东泽纳克', 45.2279500, 1.5237500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55511, 'Donville-les-Bains', 'Donville-les-Bains', 'Donvil le Ben,Donvil''-le-Ben,Donville,Donville-les-Bains,dong wei er lai ban,Донвил ле Бен,Донвиль-ле-Бен,Донвіль-ле-Бен,东维尔莱班', 48.8460800, -1.5831500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55512, 'Donnery', 'Donnery', 'Doneri,Donnery,Donnri,duo na li,Донери,Доннрі,多纳里', 47.9148600, 2.1029900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55513, 'Donnemarie-Dontilly', 'Donnemarie-Dontilly', 'Donmari Dontiji,Donnemarie,Donnemarie-en-Montois,Donnmari-Dontii,Донмари Донтији,Доннмари-Донтии,Доннмарі-Донтії', 48.4771900, 3.1316200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55514, 'Donges', 'Donges', 'Donez,Donges,Dongia,Donzh,dong re,donju,Донж,ドンジュ,东热', 47.3182400, -2.0753800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55515, 'Doncourt-lès-Conflans', 'Doncourt-les-Conflans', 'Doncourt,Doncourt-en-Jarnisy,Doncourt-les-Conflans,Doncourt-lès-Conflans', 49.1436000, 5.9338200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55516, 'Donchery', 'Donchery', 'Donchery,Donsheri,Donshri,dong she li,dwntshyry,Доншери,Доншері,Доншри,دونتشيري,东舍里', 49.6958400, 4.8741700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55517, 'Don', 'Don', 'Don', 50.5491200, 2.9181700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55518, 'Dompierre-sur-Yon', 'Dompierre-sur-Yon', 'Dampjer sir Jon,Domperr-sjur-Ion,Dompierre,Dompierre-sur-Yon,yong he pan dong pi ai er,Дампјер сир Јон,Домпєрр-сюр-Іон,永河畔栋皮埃尔', 46.7385700, -1.3846300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55519, 'Dompierre-sur-Veyle', 'Dompierre-sur-Veyle', 'Dompierre,Dompierre-sur-Veyle', 46.0717900, 5.2057300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55520, 'Dompierre-sur-Mer', 'Dompierre-sur-Mer', 'Dompierre,Dompierre-sur-Mer', 46.1881700, -1.0635100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55521, 'Dompierre-sur-Besbre', 'Dompierre-sur-Besbre', 'Dompierre,Dompierre-sur-Besbre,Source-Libre', 46.5196200, 3.6990500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55522, 'Domont', 'Domont', 'Domon,Domont,duo meng,Домон,多蒙', 49.0278200, 2.3263800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55523, 'Domme', 'Domme', 'Domme', 44.8021800, 1.2145900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55524, 'Dommartin-lès-Toul', 'Dommartin-les-Toul', 'Dommartin,Dommartin-les-Toul,Dommartin-lès-Toul', 48.6698100, 5.9099800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55525, 'Dommartin-lès-Remiremont', 'Dommartin-les-Remiremont', 'Domarten le Remirmon,Dommarten-le-Remirmon,Dommartin,Dommartin-les-Remiremont,Dommartin-lès-Remiremont,duo ma er tan lai lei mi lei meng,Домартен ле Ремирмон,Доммартен-ле-Ремирмон,Доммартен-ле-Ремірмон,多马尔坦莱雷米雷蒙', 47.9990200, 6.6404800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55526, 'Dom-le-Mesnil', 'Dom-le-Mesnil', 'Dom,Dom-le-Mesnil', 49.6901200, 4.8036300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55527, 'Domgermain', 'Domgermain', 'Domgermain', 48.6429200, 5.8258200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55528, 'Domfront', 'Domfront', '', 48.5920800, -0.6458800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55529, 'Domessin', 'Domessin', 'Domessin', 45.5343000, 5.7007700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55530, 'Domérat', 'Domerat', 'Domerat,Domérat', 46.3606400, 2.5342600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55531, 'Domène', 'Domene', 'Domen,Domene,Domène,duo mei en,Домен,多梅恩', 45.2034500, 5.8390500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55532, 'Dombasle-sur-Meurthe', 'Dombasle-sur-Meurthe', 'Dombal sir Mert,Dombal''-sjur-Mjort,Dombasl''-sjur-Mert,Dombasle,Dombasle-sur-Meurthe,mo er te he pan dong ba si er,Домбал сир Мерт,Домбаль-сюр-Мёрт,Домбасль-сюр-Мерт,默尔特河畔东巴斯尔', 48.6252000, 6.3496700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55533, 'Domart-en-Ponthieu', 'Domart-en-Ponthieu', 'Domart,Domart-en-Ponthieu', 50.0743700, 2.1259600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55534, 'Domarin', 'Domarin', 'Domarin', 45.5855500, 5.2430800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55535, 'Domancy', 'Domancy', 'Domancy', 45.9141800, 6.6474100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55536, 'Domalain', 'Domalain', 'Domalain,Domalan,Domalen,Domnus Alanus,duo ma lan,Домален,多马兰', 47.9961700, -1.2425000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55537, 'Domagné', 'Domagne', 'Domagne,Domagné,Doman''e,Domane,Domigneium,Dovanieg,duo ma nie,Доманье,Доманьє,Домање,多马涅', 48.0708100, -1.3929100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55538, 'Dolus-d''Oléron', 'Dolus-d''Oleron', 'Dulus', 45.9166700, -1.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55539, 'Dolomieu', 'Dolomieu', 'Dolomieu,Dolomieux', 45.6132800, 5.5001600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55540, 'Dollon', 'Dollon', 'Dollon', 48.0387900, 0.5868600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55541, 'Dole', 'Dole', 'DLE,Dole,Dolja,Доля', 47.1000000, 5.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55542, 'Dol-de-Bretagne', 'Dol-de-Bretagne', 'Bro Zol,Dol,Dol de Bretan,Dol''-de-Bretan'',Dol-de-Bretagne,Dola Britonum,doru=do=burutanyu,duo de bu lei ta ni,Дол де Бретањ,Доль-де-Бретань,ドル＝ド＝ブルターニュ,多德布雷塔尼', 48.5476500, -1.7501800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55543, 'Doingt', 'Doingt', 'Doingt', 49.9211300, 2.9676600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55544, 'Dogneville', 'Dogneville', 'Dogneville', 48.2225100, 6.4594400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55545, 'Docelles', 'Docelles', 'Docelles,Dosel,Dosel'',duo sai lai,Досел,Досель,多塞莱', 48.1447500, 6.6128900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55546, 'Dizy', 'Dizy', 'Dizy', 49.0666700, 3.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55547, 'Divonne-les-Bains', 'Divonne-les-Bains', 'Divon le Ben,Divon-le-Ben,Divonn-le-Ben,Divonne,Divonne-les-Bains,di wo en lai ban,dyfwn-lyh-ban,Дивон ле Бен,Дивон-ле-Бен,Дівонн-ле-Бен,Դիվոն լե Բեն,ديفون-ليه-بان,迪沃恩莱班', 46.3593800, 6.1357400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55548, 'Divion', 'Divion', 'Div''on,Divion,Divión,di wei yong,dyfwn,Дивион,Дивьон,Дівіон,ديفون,迪维永', 50.4716900, 2.5054600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55549, 'Dives-sur-Mer', 'Dives-sur-Mer', 'Div na Moru,Div-sjur-Mer,Dives,Dives-sur-Mer,bin hai di wei,Див на Мору,Див-сюр-Мер,Дів-сюр-Мер,滨海迪韦', 49.2817600, -0.1012500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55550, 'Distroff', 'Distroff', 'Diesdorf,Distrof,Distroff,di si te luo,dystrwf,Дистроф,Дистрофф,Дістрофф,دیستروف,迪斯特罗', 49.3330400, 6.2644800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55551, 'Distré', 'Distre', 'Distre,Distré', 47.2228100, -0.1107100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55552, 'Dissay', 'Dissay', 'Dise,Dissais,Dissay,Disse,di sai,Дисе,Діссе,迪赛', 46.7000700, 0.4331100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55553, 'Dirinon', 'Dirinon', 'Dirinon,Dirinonn,di li nong,Диринон,Діринон,迪里农', 48.3977500, -4.2701700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55554, 'Dirac', 'Dirac', 'Dirac', 45.6000000, 0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55555, 'Diou', 'Diou', 'Diou', 46.5333300, 3.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55556, 'Dinsheim-sur-Bruche', 'Dinsheim-sur-Bruche', 'Densajm-sjur-Brjush,Dinse,Dinsheim,Dinskhajm,Dínse,bu lu ke he pan dan sang,dynghshym swr brwtsh,dynshaym-swr-brwsh,Денсайм-сюр-Брюш,Динсхајм,دينغشيم سور بروتش,دینسهایم-سور-بروش,布吕克河畔丹桑', 48.5425800, 7.4272700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55557, 'Dingy-Saint-Clair', 'Dingy-Saint-Clair', 'Denzhi-Sen-Kler,Dingi,Dingy,Dingy-Parmelan,Dingy-Saint-Clair,Dinzhi Sen Kler,Tincia Anniciensium,Денжі-Сен-Клер,Динжи Сен Клер', 45.9080600, 6.2245200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55558, 'Dingsheim', 'Dingsheim', 'Dingsheim,Dingskhajm,Дингсхајм', 48.6305300, 7.6693200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55559, 'Dingé', 'Dinge', 'Dingad,Dinge,Dingé', 48.3570200, -1.7148900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55560, 'Dinéault', 'Dineault', 'Dineault,Dineo,Dineol,Dinéault,di nei ao er,dineo,Динео,Дінео,ディネオー,迪内奥尔', 48.2192200, -4.1641100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55561, 'Dinard', 'Dinard', 'Dinar,Dinard,Dinard-Saint-Enogat,Dinarzh,di na er,dinaru,Динар,Дінар,ディナール,迪纳尔', 48.6314300, -2.0614400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55562, 'Dinan', 'Dinan', 'Dinan,Dinnanum,dinan,dynan,dynan  frans,dynan  fransh,Динан,Дінан,דינאן,دينان,دینان، فرانس,دینان، فرانسه,ディナン', 48.4500000, -2.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55563, 'Dijon', 'Dijon', 'DIJ,Digion,Digione,Dijon,Dij·on,Divio,Diviodunum,Dizhon,Dizon,Dizona,Dizonas,Dižon,Dižona,Dižonas,Gorad Dyzhon,Ntizon,di rong,dichng,dijam,dijom,dijon,dijong,dizhoni,dyjwn,dyzhwn,dyzwn,Ντιζόν,Горад Дыжон,Дижон,Діжон,Դիժոն,דיזון,ديجون,دیجون,دیژون,ڈیجون,दिजाँ,दीजों,ดีฌง,དི་ཇཱོན།,დიჟონი,ディジョン,第戎,디종', 47.3166700, 5.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55564, 'Digosville', 'Digosville', 'Digosville', 49.6310400, -1.5262700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55565, 'Digoin', 'Digoin', 'Digoan,Digoin,Diguehn,Diguen,di gu an,digowan,Дигоан,Дигуен,Дигуэн,Дігуен,ディゴワン,迪古安', 46.4812400, 3.9794600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55566, 'Digne-les-Bains', 'Digne-les-Bains', 'Digne,Din le Ben,Din''-le-Ben,Dinha,Dinia,di nie lai ban,dinyu=re=ban,dinyulebaeng,Динь-ле-Бен,Дињ ле Бен,Дінь-ле-Бен,ディーニュ＝レ＝バン,迪涅萊班,디뉴레뱅', 44.0925200, 6.2319900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55567, 'Dignac', 'Dignac', 'Dignac,Din''jak,Dinak,Dinhac,di ni ya ke,Диньяк,Дињак,Діньяк,迪尼亚克', 45.5500000, 0.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55568, 'Diges', 'Diges', 'Diges,Dizh,Диж,Діж', 47.7286200, 3.3978600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55569, 'Dieuze', 'Dieuze', 'D''ez,D''joz,Dieuze,Djez,di ye yu ci,Дьез,Дьёз,Дьєз,Дјез,דיאז,迪耶于兹', 48.8126300, 6.7178000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55570, 'Dieulouard', 'Dieulouard', 'Dieulouard,Scarpone', 48.8414000, 6.0680800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55571, 'Dieulefit', 'Dieulefit', 'D''elefi,Dieulefit,Dieulofet,Djelfi,Mont-Jabron,di ye yu lai fei,Дьєлефі,Дјелфи,迪耶于莱菲', 44.5234100, 5.0642500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55572, 'Dieue-sur-Meuse', 'Dieue-sur-Meuse', 'Dieue,Dieue-sur-Meuse', 49.0720000, 5.4224800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55573, 'Dietwiller', 'Dietwiller', 'Dietweiler,Dietwiller,Ditviler,Ditviller,di ye te wei lai,Дитвилер,Дитвиллер,Дітвіллер,迪耶特维莱', 47.6925900, 7.4022200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55574, 'Diesen', 'Diesen', 'Diesen', 49.1780000, 6.6803500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55575, 'Dieppe', 'Dieppe', 'D''ep,DPE,Dgieppe,Diep,Dieppe,Dieppi,Dijep,Djep,di ye pu,diepeu,dieppu,dyyb,dyyp,dyyp  snh mrytym,tiyap,Διέππη,Диеп,Дијеп,Дьеп,Дьєп,Дјеп,דייפ,دييب,دیئپ، سنه مریتیم,தியப்,ディエップ,迪耶普,디에프', 49.9333300, 1.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55576, 'Diémoz', 'Diemoz', 'D''emo,D''emoz,Diemoz,Diémoz,Djemoz,di ai mo,Дьемоз,Дьємо,Дјемоз,迪埃莫', 45.5865100, 5.0939700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55577, 'Diemeringen', 'Diemeringen', 'Deemeringe,Diemeringen,Dimeringen,di ye mo lan rang,dymryngn,dymyrynghyn,Димеринген,Дімеринген,ديميرينغين,دیمرینگن,迪耶默兰让', 48.9396800, 7.1855500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55578, 'Diebling', 'Diebling', 'Diebling', 49.1091800, 6.9403400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55579, 'Die', 'Die', 'Dia,Die,Diá', 44.7500000, 5.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55580, 'Didenheim', 'Didenheim', 'Didenheim', 47.7173700, 7.3022000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55581, 'Dhuizon', 'Dhuizon', 'Dhuison,Dhuizon', 47.5872300, 1.6580900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55582, 'Deyvillers', 'Deyvillers', 'Deyvillers', 48.2001300, 6.5153300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55583, 'Déville-lès-Rouen', 'Deville-les-Rouen', 'Deville,Deville-les-Rouen,Déville,Déville-lès-Rouen', 49.4694200, 1.0521400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55584, 'Deville', 'Deville', 'Deville', 49.8789300, 4.7061000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55585, 'Devecey', 'Devecey', 'Devecey', 47.3216900, 6.0190000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55586, 'Deûlémont', 'Deulemont', 'Deulemont,Deûlemont,Deûlémont', 50.7333300, 2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55587, 'Deuil-la-Barre', 'Deuil-la-Barre', 'Dej la Bar,Dej-la-Barr,Deuil,Deuil-La Barre,Deuil-la-Barre,Djoj-la-Barr,de yi-la ba er,doeilabaleu,do~uiyu=ra=baru,dwy lbr,Дей-ла-Барр,Деј ла Бар,Дёй-ла-Барр,دوی لبر,ドゥイユ＝ラ＝バール,德伊-拉巴尔,되이라바르', 48.9767400, 2.3272200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55588, 'Dettwiller', 'Dettwiller', 'Dettviller,Dettweiler,Dettwiller,Detviler,dai te wei lai,dytwylyr,Детвилер,Деттвиллер,Деттвіллер,ديتويلير,代特维莱', 48.7541500, 7.4663300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55589, 'Desvres', 'Desvres', 'Defes,Desvres,Devr,Dèfes,dai fu lei,dysfryh,Девр,ديسفريه,代夫勒', 50.6688400, 1.8347800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55590, 'Dessenheim', 'Dessenheim', 'Dessenheim', 47.9763000, 7.4888600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55591, 'Désertines', 'Desertines', 'Desertines,Désertines', 46.3552100, 2.6207400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55592, 'Désaignes', 'Desaignes', 'Desaignes,Désaignes', 44.9954400, 4.5141300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55593, 'Derval', 'Derval', 'Derval,Derwal,Montagne-sur-Kurel', 47.6672400, -1.6699000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55594, 'Déols', 'Deols', 'Cereale,Céréale,Deol'',Deols,Déols,dai ao er,Деоль,代奥尔', 46.8293400, 1.7042800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55595, 'Denicé', 'Denice', 'Denice,Denicé', 46.0014100, 4.6452300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55596, 'Denguin', 'Denguin', 'Dangen,Denguin,dang ji en,Данген,当吉恩', 43.3666700, -0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55597, 'Denée', 'Denee', 'Denee,Denée', 47.3788500, -0.6081600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55598, 'Denain', 'Denain', 'Danen,Denain,Denen,Dnain,Dononium,de nan,deunaeng,do~unan,dwnn,Данен,Денен,دونن,ドゥナン,德南,드냉', 50.3293000, 3.3943000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55599, 'Démouville', 'Demouville', 'Demouville,Démouville', 49.1800100, -0.2694700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55600, 'Demigny', 'Demigny', 'Demigny', 46.9304800, 4.8338100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55601, 'Delle', 'Delle', 'Dattenried,Del,Del'',Delle,de er,Дел,Дель,德尔', 47.5104800, 6.9996300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55602, 'Decize', 'Decize', 'Decetia,Decize,Decize-le-Rocher,Desiz,Rocher-la-Montagne,dai xi ci,Десиз,Десіз,代西兹', 46.8285200, 3.4619200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55603, 'Décines-Charpieu', 'Decines-Charpieu', 'Decines,Decines-Charpieu,Desen Sharpje,Desin-Sharpe,Décines,Décines-Charpieu,deshinu=sharupyu,desinsyaleupioe,dsyn sharpyw,dysyn-sharbyw,Десен Шарпје,Десін-Шарпє,دسین شارپیو,ديسين-شاربيو,デシーヌ＝シャルピュー,데신샤르피외', 45.7689900, 4.9727700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55604, 'Dechy', 'Dechy', 'Deshi,de xi,Деши,Деші,德希', 50.3500000, 3.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55605, 'Decazeville', 'Decazeville', 'Decazeville,Dekazvil,Dekazvil'',La Sala,dai ka ze wei er,Деказвил,Деказвиль,Деказвіль,代卡泽维尔', 44.5604500, 2.2509100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55606, 'Deauville', 'Deauville', 'DOL,Deauville,Deauville-les-Bains,Dovil,Dovil'',dovu~iru,duo wei er,dwwyl,Довил,Довиль,Довіль,دوویل,ドーヴィル,多維爾', 49.3570000, 0.0699500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55607, 'Dax', 'Dax', 'Akize,Daks,Dax,Lepelletier,XDA,Дакс', 43.7103200, -1.0536600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55608, 'Davézieux', 'Davezieux', 'Davesiac,Davez''e,Davez''jo,Davezieux,Davezje,Davézieux,da wei qi e,Давезьё,Давезьє,Давезје,达韦齐厄', 45.2573200, 4.7087500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55609, 'Daux', 'Daux', 'Daus,Daux,Do,Doks,duo zhen,До,Докс,多镇', 43.6950600, 1.2689200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55610, 'Daumeray', 'Daumeray', 'Daumeray,Domre,duo mo lai,Домре,多默赖', 47.7007000, -0.3611900, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55611, 'Dauendorf', 'Dauendorf', 'Dauendorf,Дауендорф', 48.8298700, 7.6553200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55612, 'Dasle', 'Dasle', 'Dasle', 47.4784300, 6.8972800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55613, 'Darvoy', 'Darvoy', 'Darvoa,Darvoy,Darvua,da er wa,Дарвоа,Дарвуа,达尔瓦', 47.8583900, 2.1003300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55614, 'Darnieulles', 'Darnieulles', 'Darn''el'',Darnieulles,Darnijel,da er ni e lai,Дарнијел,Дарньель,Дарньєль,达尔尼厄莱', 48.1995000, 6.3492900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55615, 'Darney', 'Darney', 'Darne,Darney,da er nei,drny,Дарне,درنی,达尔内', 48.0866000, 6.0491700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55616, 'Darnétal', 'Darnetal', 'Darnetal,Darnetal'',Darnétal,Дарнетал,Дарнеталь', 49.4453300, 1.1514400, 'FR', '2017-04-03', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55617, 'Dargnies', 'Dargnies', 'Dargnies', 50.0414400, 1.5252600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55618, 'Dardilly', 'Dardilly', 'Dardii,Dardiji,Dardilly,dardyly,Дардији,Дардії,داردیلی', 45.8050600, 4.7534200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55619, 'Daoulas', 'Daoulas', 'Daoulas,Daoulaz', 48.3608900, -4.2597700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55620, 'Dannes', 'Dannes', 'Dan,Dann,Dannes,da ne,danys,Дан,Данн,دانيس,达讷', 50.5879900, 1.6138100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55621, 'Dannemarie-sur-Crête', 'Dannemarie-sur-Crete', 'Dannemarie,Dannemarie-sur-Crete,Dannemarie-sur-Crête', 47.2048800, 5.8701800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55622, 'Dannemarie', 'Dannemarie', 'Dannemarie', 47.6303100, 7.1223700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55623, 'Danjoutin', 'Danjoutin', 'Danjoutin', 47.6156000, 6.8663700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55624, 'Dangé-Saint-Romain', 'Dange-Saint-Romain', 'Danzhe Sen Romen,Danzhe-Sen-Romen,dang re sheng luo man,Данже Сен Ромен,Данже-Сен-Ромен,当热圣罗曼', 46.9333300, 0.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55625, 'Damville', 'Damville', 'Damville', 48.8693000, 1.0745800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55626, 'Damprichard', 'Damprichard', 'Damprichard', 47.2441300, 6.8812100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55627, 'Dampmart', 'Dampmart', 'Dampmart', 48.8885400, 2.7409500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55628, 'Dampierre-sur-Salon', 'Dampierre-sur-Salon', 'Dampierre,Dampierre-sur-Salon', 47.5571900, 5.6797000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55629, 'Dampierre-les-Bois', 'Dampierre-les-Bois', 'Dampierre,Dampierre-les-Bois', 47.5063900, 6.9127900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55630, 'Dampierre-en-Burly', 'Dampierre-en-Burly', 'Damperr-an-Bjurli,Dampierre,Dampierre-en-Burly,Dampjer an Birli,bi er li de qu dang pi ye er,Дампєрр-ан-Бюрлі,Дампјер ан Бирли,比尔利地区当皮耶尔', 47.7614300, 2.5196200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55631, 'Dampierre-en-Yvelines', 'Dampierre-en-Yvelines', 'Damp''err-an-Ivelin,Damperr-an-Ivlin,Dampjer an Ivlen,Дампьерр-ан-Ивелин,Дампєрр-ан-Івлін,Дампјер ан Ивлен', 48.7000000, 1.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55632, 'Dampierre', 'Dampierre', 'Dampierre', 47.1549800, 5.7416700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55633, 'Damparis', 'Damparis', 'Dampari,Damparis,dang pa li,Дампари,Дампарі,当帕里', 47.0755600, 5.4139800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55634, 'Dammartin-en-Goële', 'Dammartin-en-Goele', 'Damarten an Goel,Dammarten-an-Goel'',Dammartin,damartan awn ghwyl,damarutan=an=goeru,Дамартен ан Гоел,Даммартен-ан-Гоель,דמרטן-אן-גואל,دامارتان أون غويل,ダマルタン＝アン＝ゴエル', 49.0542300, 2.6777700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55635, 'Dammarie-les-Lys', 'Dammarie-les-Lys', 'Dammarie,Dammarie-les-Fontaines', 48.5166700, 2.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55636, 'Dammarie', 'Dammarie', 'Dammarie', 48.3431400, 1.4944400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55637, 'Damigny', 'Damigny', '', 48.4500000, 0.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55638, 'Damgan', 'Damgan', 'Dagman,Damgan,dang gang,Дамган,当冈', 47.5179900, -2.5769800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55639, 'Damery', 'Damery', 'Damery', 49.0723800, 3.8803600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55640, 'Damelevières', 'Damelevieres', 'Damelevieres,Damelevières', 48.5573600, 6.3861100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55641, 'Dambach-la-Ville', 'Dambach-la-Ville', 'Dambach,Dambak-la-Vil'',Dambakh la Vil,Dambch,dambatsh la fyl,dang ba ke la wei er,Дамбак-ла-Виль,Дамбак-ла-Віль,Дамбах ла Вил,دامباتش لا فيل,当巴克拉维尔', 48.3237900, 7.4254700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55642, 'Damazan', 'Damazan', 'Damasan,Damazan,Damazan-le-Republicain,Damazan-le-Républicain,da ma cang,Дамазан,达马藏', 44.2906800, 0.2769400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55643, 'Dallet', 'Dallet', 'Dale,Dalet,Dalle,Dallet,Dalèt,da lai,Дале,Далле,达莱', 45.7703900, 3.2390600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55644, 'Daix', 'Daix', 'Daix', 47.3508100, 5.0005200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55645, 'Dainville', 'Dainville', 'Dainville', 50.2809700, 2.7260300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55646, 'Dagneux', 'Dagneux', 'Dagnieu,Dan''e,Dan''jo,Dane,Danyo,da ni e,danyyw,Даньё,Даньє,Дање,Դանյո,دانييو,达尼厄', 45.8514000, 5.0778000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55647, 'Dadonville', 'Dadonville', 'Dadonvil,Dadonvil'',Dadonville,da dong wei er,Дадонвил,Дадонвіль,达东维尔', 48.1577600, 2.2715000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55648, 'Dachstein', 'Dachstein', '', 48.5612700, 7.5323300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55649, 'Dabo', 'Dabo', 'Dabo,Dagsburg', 48.6537100, 7.2363600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55650, 'Cysoing', 'Cysoing', 'Cysoing,Kizoan,Sizuehn,Sizuen,xi su wan,Кизоан,Сизуен,Сизуэн,Сізуен,锡苏万', 50.5693900, 3.2162700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55651, 'Cuzieu', 'Cuzieu', 'Cuzieu', 45.6084000, 4.2585800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55652, 'Cuxac-Cabardès', 'Cuxac-Cabardes', 'Cuccac de Cabardes,Cucçac de Cabardés,Cuxac,Cuxac-Cabardes,Cuxac-Cabardès,Kiksak Kabarde,Kjuksak-Kabardes,qu ke sa ke ka ba er dai,Киксак Кабарде,Кюксак-Кабардес,屈克萨克卡巴尔代', 43.3708700, 2.2836900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55653, 'Cuverville', 'Cuverville', 'Cuverville', 49.1899800, -0.2647400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55654, 'Cuttoli-Corticchiato', 'Cuttoli-Corticchiato', '', 41.9833300, 8.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55655, 'Cusy', 'Cusy', 'Cusy', 45.7663300, 6.0269500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55656, 'Custines', 'Custines', 'Custines,Port-sur-Moselle', 48.7936300, 6.1483500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55657, 'Cusset', 'Cusset', 'Cucet,Cusset,Cussetium,Kise,Kjusse,qu sai,Кисе,Кюссе,屈塞', 46.1300200, 3.4596300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55658, 'Cussac', 'Cussac', 'Cussac', 45.7066600, 0.8512400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55659, 'Cussac-Fort-Médoc', 'Cussac-Fort-Medoc', '', 45.1166700, -0.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55660, 'Cussac-sur-Loire', 'Cussac-sur-Loire', '', 44.9880700, 3.8841600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55661, 'Curtin', 'Curtin', 'Curtin', 45.6435300, 5.4898200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55662, 'Curgy', 'Curgy', 'Curgy,Kirzhi,Kjurzhi,Киржи,Кюржи,Кюржі', 46.9871400, 4.3845200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55663, 'Curgies', 'Curgies', 'Curgies', 50.3297500, 3.6029900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55664, 'Cunlhat', 'Cunlhat', 'Cunlhac,Cunlhat,Kenja,Kenla,Kinla,kan la,Кенла,Кеня,Кинла,坎拉', 45.6334800, 3.5598000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55665, 'Cunac', 'Cunac', 'Cunac', 43.9301000, 2.2187800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55666, 'Culoz', 'Culoz', 'Culoz,Kilo,Kjulo,Kyuloz,kwlwz,qu luo,Кило,Кюло,Կյուլոզ,كولوز,屈洛', 45.8496400, 5.7808100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55667, 'Culhat', 'Culhat', 'Culhat', 45.8625400, 3.3356600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55668, 'Cuisiat', 'Cuisiat', 'Cuisiat', 46.3002100, 5.3880900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55669, 'Cuisery', 'Cuisery', 'Cuisery,Kizeri,Kjuizeri,Кизери,Кюизери,Кюїзері', 46.5569600, 4.9979700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55670, 'Cuise-la-Motte', 'Cuise-la-Motte', 'Cuise,Cuise-la-Motte', 49.3864200, 3.0058800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55671, 'Cuiseaux', 'Cuiseaux', 'Cuiseaux,Kizo,Kjuizo,Кизо,Кюизо,Кюїзо', 46.4947300, 5.3893100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55672, 'Cuincy', 'Cuincy', 'Cuincy', 50.3793300, 3.0530100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55673, 'Cuinchy', 'Cuinchy', 'Cuinchy,Kinshi,Kjuenshi,kwyntshy,qu an xi,Кинши,Кюенши,Кюенші,كوينتشي,屈安希', 50.5175000, 2.7488000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55674, 'Cugnaux', 'Cugnaux', 'Cugnaux-Vingtcasses,Cunhaus,Kino,Kjun''o,qu ni ao,Кињо,Кюньо,屈尼奥', 43.5363500, 1.3442800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55675, 'Cuges-les-Pins', 'Cuges-les-Pins', 'Cuges,Cuges-les-Pins', 43.2758500, 5.6994400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55676, 'Cugand', 'Cugand', 'Cugand,Kigan,Kjugan,Kugant,qu gang,Киган,Кюган,屈冈', 47.0631800, -1.2527000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55677, 'Cuffy', 'Cuffy', 'Cuffy', 46.9627500, 3.0523800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55678, 'Cuffies', 'Cuffies', 'Cuffies', 49.4035800, 3.3211900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55679, 'Cuers', 'Cuers', 'Cuer,Cuers,Ker,Kjuehr,Kjuers,qu ai er,Кер,Кюерс,Кюэр,屈埃尔', 43.2373100, 6.0710700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55680, 'Cucuron', 'Cucuron', 'Cucuron,Kikiron,Kjukjuron,qu qu long,Кикирон,Кюкюрон,屈屈龙', 43.7732100, 5.4390000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55681, 'Cucq', 'Cucq', 'Cucq,Kik,Kjuk,Tchucq,kwsyk,qu ke,Кик,Кюк,كوسيك,屈克', 50.4773300, 1.6201800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55682, 'Cubzac-les-Ponts', 'Cubzac-les-Ponts', 'Cubzac,Cubzac daus Ponts,Cubzac-les-Ponts,Cupcac,Cupçac,Kibzak le Pont,Kjubzak-le-Pon,qu bu zha ke lai peng te,Кибзак ле Понт,Кюбзак-ле-Пон,屈布扎克莱蓬特', 44.9711900, -0.4497600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55683, 'Cublize', 'Cublize', 'Cublize', 46.0204000, 4.3795300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55684, 'Cublac', 'Cublac', 'Cubiac', 45.1448800, 1.3060900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55685, 'Crusnes', 'Crusnes', 'Crusnes', 49.4335900, 5.9153600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55686, 'Cruseilles', 'Cruseilles', 'Croueselyes,Crucellae,Cruseilles,Krizej,Krjuzej,Кризеј,Крюзей', 46.0333300, 6.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55687, 'Cruet', 'Cruet', 'Cruet', 45.5289000, 6.0922000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55688, 'Cruas', 'Cruas', 'Cruas,Crudatium,Cruàs,Krija,Krjua,ke lu a,Крија,Крюа,克吕阿', 44.6554400, 4.7614400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55689, 'Crozon', 'Crozon', 'Crathonia,Crozon,Kraozon,Kroazon,Krozon,ke luo zong,kurozon,Крозон,クロゾン,克罗宗', 48.2464300, -4.4899300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55690, 'Crouy-sur-Ourcq', 'Crouy-sur-Ourcq', 'Crouy,Crouy-sur-Ourcq,Kru sir Urk,Krui-sjur-Urk,wu er ke he pan ke lu yi,Кру сир Урк,Круи-сюр-Урк,Круї-сюр-Урк,烏爾克河畔克魯伊', 49.0898000, 3.0753000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55691, 'Crouy-en-Thelle', 'Crouy-en-Thelle', 'Crouy,Crouy-en-Thelle', 49.2148700, 2.3214600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55692, 'Crouy', 'Crouy', 'Crouy', 49.4027400, 3.3583400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55693, 'Crottet', 'Crottet', 'Crottet', 46.2777800, 4.8924900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55694, 'Croth', 'Croth', 'Croth', 48.8455700, 1.3786100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55695, 'Crossac', 'Crossac', 'Crossac,Kraozieg,Kroazieg,Krosak,Krossak,ke luo sa ke,Кросак,Кроссак,克罗萨克', 47.4111900, -2.1695200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55696, 'Crosne', 'Crosne', 'Crosne,Crosnes', 48.7192100, 2.4572800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55697, 'Crolles', 'Crolles', 'Crolles,Krol,Krol'',ke luo lai,Крол,Кроль,克罗莱', 45.2819800, 5.8782400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55698, 'Croix', 'Croix', 'Croix', 50.6784600, 3.1493000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55699, 'Croissy-sur-Seine', 'Croissy-sur-Seine', 'Croissy,Croissy-sur-Seine,Kroasi na Seni,Kruassi-sjur-Sen,Кроаси на Сени,Круасси-сюр-Сен,Круассі-сюр-Сен', 48.8792500, 2.1383600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55700, 'Croissy-Beaubourg', 'Croissy-Beaubourg', 'Croissy-Beaubourg,Croissy-Beaucourt,Kroasi Bobur,Kruassi-Bobur,Кроаси Бобур,Круасси-Бобур,Круассі-Бобур', 48.8283000, 2.6696400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55701, 'Croisilles', 'Croisilles', 'Croisilles', 50.1997800, 2.8793500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55702, 'Crissey', 'Crissey', 'Crissey', 46.8165200, 4.8818500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55703, 'Crisolles', 'Crisolles', 'Crisolles,Krizol,Krizol'',ke li suo lai,Кризол,Кризоль,克里索莱', 49.6225000, 3.0145100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55704, 'Criquebeuf-sur-Seine', 'Criquebeuf-sur-Seine', 'Criquebeuf,Criquebeuf-sur-Seine', 49.3056300, 1.0996400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55705, 'Criel-sur-Mer', 'Criel-sur-Mer', 'Criel,Criel-sur-Mer,Kriel''-sjur-Mer,Krijel na Moru,Криель-сюр-Мер,Кријел на Мору,Крієль-сюр-Мер', 50.0150800, 1.3145900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55706, 'Crézancy', 'Crezancy', 'Crezancy,Crézancy', 49.0483300, 3.5104700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55707, 'Creysse', 'Creysse', 'Creysse', 44.8547400, 0.5658300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55708, 'Creys-Mépieu', 'Creys-Mepieu', 'Creys,Creys-Pusigneu', 45.7333300, 5.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55709, 'Crevin', 'Crevin', 'Crevin,Crévin,Kreven,ke lei wan,Кревен,克勒万', 47.9333300, -1.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55710, 'Crèvecœur-le-Grand', 'Crevecoeur-le-Grand', 'Creuvetchoeur-lGrand,Creuvetchœur-lGrand,Crevecoeur,Crevecoeur-le-Grand,Crèvecoeur,Crèvecoeur-le-Grand,Krevker le Gran,Krevker-le-Gran,Krevkjor-le-Gran,da ke lei wei ke e,Кревкер ле Гран,Кревкер-ле-Гран,Кревкёр-ле-Гран,大克雷韦科厄', 49.6000000, 2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55711, 'Creuzier-le-Vieux', 'Creuzier-le-Vieux', 'Creuseir lo Vielh,Creusèir lo Vielh,Creuzier-le-Vieux,Krez''e-le-V''e,Krez''e-le-Ve,Krezje le Vje,Krjoz''e-le-V''jo,ke lei qi ye lai fu yue,Крезье-ле-Вье,Крезьє-ле-Вє,Крезје ле Вје,Крёзье-ле-Вьё,克勒齐耶莱弗约', 46.1625300, 3.4331100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55712, 'Creutzwald', 'Creutzwald', 'Creutzwald-la-Croix,Krecval''d,Kreuzwald,Krjotcval''d,Krojcvald,ke lei te ci wa er,krwytswald,Крецвальд,Кројцвалд,Крётцвальд,کرویتسوالد,克勒特兹瓦尔', 49.2000000, 6.6833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55713, 'Creully', 'Creully', 'Creully,Kreli,Krelli,Krjolli,ke lei li,Крели,Крелли,Креллі,Крёлли,克勒利', 49.2847800, -0.5397600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55714, 'Créteil', 'Creteil', 'Creteil,Créteil,Kretej,Kretejus,Kretėjus,ke lei tai yi,keuleteyu,krty,krytay,kureteiyu,qrtyy,Кретей,Кретеј,Կրեթեյ,קרטיי,كريتاي,کرتی,کریٹیل,クレテイユ,克雷泰伊,크레테유', 48.7833300, 2.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55715, 'Crest', 'Crest', 'Crest', 44.7283600, 5.0272200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55716, 'Cresserons', 'Cresserons', 'Cresserons', 49.2870100, -0.3556900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55717, 'Crespin', 'Crespin', '', 50.4211000, 3.6613700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55718, 'Crespières', 'Crespieres', 'Crespieres,Crespières,Krepjer,Krepjera,Krepjēra,Kresp''er,Kresper,Крепјер,Креспьер,Креспєр', 48.8831700, 1.9215100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55719, 'Crépy-en-Valois', 'Crepy-en-Valois', 'Bouillant-Germinal,Crepy,Crepy-en-Valois,Crépy,Crépy-en-Valois,Krepi an Valoa,Krepi-an-Valua,wa lu wa de qu ke lei pi,Крепи ан Валоа,Крепи-ан-Валуа,Крепі-ан-Валуа,קרפי-אן-ולואה,瓦卢瓦地区克雷皮', 49.2335900, 2.8880700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55720, 'Crépy', 'Crepy', 'Crepy-en-Laonnois,Crépy-en-Laonnois', 49.6000000, 3.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55721, 'Créon', 'Creon', 'Creon,Créon', 44.7745700, -0.3480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55722, 'Creney-près-Troyes', 'Creney-pres-Troyes', 'Creney', 48.3333300, 4.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55723, 'Crémieu', 'Cremieu', 'Cremieu,Cremioe,Crèmiœ,Crémieu,Krem''jo,Kreme,Kremje,ke lei mi e,Кремьё,Кремє,Кремје,克雷米厄', 45.7289900, 5.2483900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55724, 'Creissels', 'Creissels', 'Creissels', 44.0858800, 3.0607100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55725, 'Creissan', 'Creissan', 'Creissan', 43.3752400, 3.0119600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55726, 'Creil', 'Creil', 'CSF,Creil,Krej,ke lei yi,keuleyu,kkhyy,kry,kureiyu,Крей,Креј,کخیی,کری,クレイユ,克雷伊,크레유', 49.2567200, 2.4847700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55727, 'Créhen', 'Crehen', 'Crehen,Créhen,Krehen', 48.5454600, -2.2130700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55728, 'Créhange', 'Crehange', 'Crehange,Créhange,Grehange,Gréhange', 49.0495200, 6.5801200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55729, 'Crégy-lès-Meaux', 'Cregy-les-Meaux', 'Cregy,Cregy-les-Meaux,Crégy,Crégy-lès-Meaux', 48.9764800, 2.8748300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55730, 'Crédin', 'Credin', 'Credin,Crédin,Kerzhin,Kreden,ke lei dan,Креден,克雷丹', 48.0346200, -2.7663000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55731, 'Crécy-sur-Serre', 'Crecy-sur-Serre', 'Crecy,Crecy-sur-Serre,Crécy,Crécy-sur-Serre', 49.6959400, 3.6245300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55732, 'Crécy-en-Ponthieu', 'Crecy-en-Ponthieu', 'Carcy-in-Pontiu,Creciacum,Crecy,Crecy-en-Ponthie,Crecy-en-Ponthieu,Crécy,Crécy-en-Ponthie,Crécy-en-Ponthieu,Krescak,Kresi an Pontje,Kresi-an-Pont''e,Kresi-an-Pont''jo,Kresčak,ke lei xi ang peng di yue,kureshi=an=pontiyu,Креси ан Понтје,Креси-ан-Понтьё,Кресі-ан-Понтьє,クレシー＝アン＝ポンティユー,克雷西昂蓬蒂约', 50.2519300, 1.8808500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55733, 'Crêches-sur-Saône', 'Creches-sur-Saone', 'Creches,Creches-sur-Saone,Crêches,Crêches-sur-Saône,Kresh sir Saon,Kresh-sjur-Son,Креш сир Саон,Креш-сюр-Сон', 46.2447500, 4.7867800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55734, 'Créances', 'Creances', 'Creances,Créances,Kreans,ke lei ang sai,Креанс,克雷昂塞', 49.1987300, -1.5693800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55735, 'Cravanche', 'Cravanche', 'Cravanche', 47.6564400, 6.8364700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55736, 'Craponne-sur-Arzon', 'Craponne-sur-Arzon', 'Craponne,Craponne-sur-Arzon', 45.3313500, 3.8480200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55737, 'Craponne', 'Craponne', 'Craponne', 45.7468400, 4.7266100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55738, 'Craon', 'Craon', 'Craon', 47.8468700, -0.9492900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55739, 'Cranves-Sales', 'Cranves-Sales', 'Cranves-Sales', 46.1874600, 6.2910800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55740, 'Cransac', 'Cransac', 'Crancac,Cransac,Crançac,Kransak,ke lang sa ke,Крансак,克朗萨克', 44.5241100, 2.2837000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55741, 'Cran-Gevrier', 'Cran-Gevrier', 'Gevrier,Gévrier,Kran Zhevrije,Kran-Zhevrie,Кран Жеврије,Кран-Жевріє', 45.9000000, 6.1000000, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55742, 'Crach', 'Crach', 'Crach,Krac''h', 47.6170000, -3.0017000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55743, 'Cozes', 'Cozes', 'Cozes,Koz,ke ze,Коз,Կոզ,科泽', 45.5837500, -0.8317800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55744, 'Coye-la-Forêt', 'Coye-la-Foret', 'Coye,Coye-la-Foret,Coye-la-Forêt,Koa la Fore,Kua-la-Fore,kua ai la fu lei,Коа ла Форе,Куа-ла-Форе,夸埃拉福雷', 49.1423300, 2.4703800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55745, 'Couzeix', 'Couzeix', 'Coses,Cosés,Couzeix,Kuze,Kuzej,ku ze,Кузе,Кузеј,库泽', 45.8704700, 1.2382800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55746, 'Coux', 'Coux', 'Coux', 44.7348400, 4.6205700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55747, 'Couvron-et-Aumencourt', 'Couvron-et-Aumencourt', 'Couvron,Couvron-et-Aumencourt', 49.6447600, 3.5185700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55748, 'Coutras', 'Coutras', 'Cotras,Cotràs,Coutras,Kutra,Kutras,ku te la,Кутра,Кутрас,库特拉', 45.0333300, -0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55749, 'Coutouvre', 'Coutouvre', 'Coutouvre', 46.0729800, 4.2124300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55750, 'Coutiches', 'Coutiches', 'Coutiches,Kutish,ku di shen,Кутиш,Кутіш,库蒂什', 50.4552000, 3.2038400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55751, 'Couternon', 'Couternon', 'Couternon', 47.3333300, 5.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55752, 'Couterne', 'Couterne', 'Kutern,ku tai er en,Кутерн,库泰尔恩', 48.5131800, -0.4153800, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55753, 'Coutances', 'Coutances', 'Constantia,Couotaunches,Koutans,Kutans,ku tang si,kutansu,kwtans,Κουτάνς,Кутанс,کوتانس,クタンス,库唐斯', 49.0500000, -1.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55754, 'Coussac-Bonneval', 'Coussac-Bonneval', 'Cocac,Coussac,Coussac-Bonneval,Coussac-sans-Culottes,Coçac,Kusak Bonval,Kussak-Bonnval'',ku sa ke bo na wa,Кусак Бонвал,Куссак-Боннваль,库萨克博纳瓦', 45.5119900, 1.3226100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55755, 'Cousance', 'Cousance', 'Cousance-du-Jura', 46.5332400, 5.3921400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55756, 'Courzieu', 'Courzieu', 'Courzieu,Kurz''e,Kurzje,Курзьє,Курзје', 45.7430900, 4.5703400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55757, 'Courville-sur-Eure', 'Courville-sur-Eure', 'Courville,Courville-sur-Eure,Kurvil sir Er,Kurvil''-sjur-Er,e er he pan ku er wei er,Курвил сир Ер,Курвіль-сюр-Ер,厄尔河畔库尔维尔', 48.4489900, 1.2408500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55758, 'Courtry', 'Courtry', 'Courtry,Kurtri,Куртри,Куртрі', 48.9190600, 2.6043100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55759, 'Courtisols', 'Courtisols', 'Courtisols,Kurtizol,Kurtizol'',ku er di suo er,Куртизол,Куртізоль,库尔蒂索尔', 48.9867000, 4.5170000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55760, 'Courthézon', 'Courthezon', 'Corteson,Courthezon,Courthézon,Kurtezon,ku er tai zong,Куртезон,库尔泰宗', 44.0873100, 4.8838200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55761, 'Courtenay', 'Courtenay', 'Courtenay', 48.0390100, 3.0585100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55762, 'Courteilles', 'Courteilles', '', 48.7749500, -0.1994200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55763, 'Cours-les-Barres', 'Cours-les-Barres', 'Cours,Cours-les-Barres', 47.0251300, 3.0316700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55764, 'Courseulles-sur-Mer', 'Courseulles-sur-Mer', 'Courseulles,Courseulles-sur-Mer', 49.3302700, -0.4561200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55765, 'Cours-de-Pile', 'Cours-de-Pile', 'Corc,Cors de Pilas,Corç,Cours,Cours-de-Pile,Kur de Pij,Kur-de-Pil'',ku er de pi er,Кур де Пиј,Кур-де-Пиль,Кур-де-Піль,库尔德皮尔', 44.8360800, 0.5465600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55766, 'Coursan', 'Coursan', 'Corcan,Corsan,Corçan,Coursan,Kursan,ku er sang,Курсан,库尔桑', 43.2337000, 3.0571200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55767, 'Coursac', 'Coursac', 'Corsac,Coursac,Kursak,ku er sa ke,Курсак,库尔萨克', 45.1288100, 0.6391900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55768, 'Cours-la-Ville', 'Cours-la-Ville', 'Cours-La Ville,Kur la Vil,Kur-La-Vil'',Кур ла Вил,Кур-Ла-Віль', 46.1000000, 4.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55769, 'Courrières', 'Courrieres', 'Courrieres,Courrières,Dampierre-les-Dunes,Kur''er,Kurjer,Kurrier,ku li ye er,kwryrys,Курриер,Куррієр,Курьер,Курјер,كوريريس,库里耶尔', 50.4570100, 2.9472500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55770, 'Courpière', 'Courpiere', 'Corpeira,Corpèira,Curta Petra,Kurper,Kurpjer,ku er pi ai,Курпєр,Курпјер,库尔皮埃', 45.7568900, 3.5421600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55771, 'Courpalay', 'Courpalay', '', 48.6494700, 2.9611600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55772, 'Cournonterral', 'Cournonterral', 'Cornon lo Terral,Cornonterralh,Cournonterral,Kurnonteral,Kurnonterral'',ku er nong tai er la,Курнонтерал,Курнонтерраль,库尔农泰尔拉', 43.5588900, 3.7200000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55773, 'Cournonsec', 'Cournonsec', 'Cornon lo Sec,Cornonsec,Cournonsec,Kurnonsek,ku er nong sai ke,Курнонсек,库尔农塞克', 43.5494400, 3.7055600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55774, 'Cournon-d’Auvergne', 'Cournon-d''Auvergne', 'Cournon,Cournon-d''Auvergne,Cournon-d’Auvergne,ku er nong duo wei er ni,库尔农多韦尔尼', 45.7354300, 3.1960800, 'FR', '2016-12-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55775, 'Courmelles', 'Courmelles', 'Courmelles', 49.3459500, 3.3121500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55776, 'Courlon-sur-Yonne', 'Courlon-sur-Yonne', 'Courlon,Courlon-sur-Yonne', 48.3392700, 3.1666000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55777, 'Courlay', 'Courlay', 'Courlay', 46.7794100, -0.5660700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55778, 'Courdimanche', 'Courdimanche', 'Courdimanche,Kurdimansh,ku er di mang shen,kurudimanshu,Курдиманш,Курдіманш,クールディマンシュ,库尔迪芒什', 49.0351300, 2.0009600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55779, 'Courcy', 'Courcy', 'Courcy', 49.3236100, 4.0025700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55780, 'Courcouronnes', 'Courcouronnes', 'Courcouronnes,Kurkuron,Kurkuronn,ku er ku luo na,kwrkwrwn,Куркурон,Куркуронн,كوركورون,库尔库罗纳', 48.6142900, 2.4076200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55781, 'Courçon', 'Courcon', 'Courcon,Courçon,Kurson,La Bonne-Foy,ku er song,Курсон,Կուրսոն,库尔松', 46.2438900, -0.8130000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55782, 'Courcité', 'Courcite', 'Courcite,Courcité', 48.3063300, -0.2496100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55783, 'Cour-Cheverny', 'Cour-Cheverny', 'Cour-Chaverny,Cour-Cheverny,Kur-Sheverni,ku xie wei er ni,Кур-Шеверні,库谢韦尔尼', 47.5103300, 1.4558300, 'FR', '2017-01-26', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55784, 'Courchevel', 'Courchevel', 'CVF,Courchevel,Courchevel 1850,Courchevêl,Kursevelis,Kurshevel'',Kurševelis,kurushuvu~eru,kwrshwl,Куршевель,کورشول,クールシュヴェル', 45.4153800, 6.6364300, 'FR', '2016-12-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55785, 'Courchelettes', 'Courchelettes', 'Courchelettes', 50.3404300, 3.0593800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55786, 'Courcelles-sur-Seine', 'Courcelles-sur-Seine', 'Courcelles,Courcelles-sur-Seine', 49.1828500, 1.3600800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55787, 'Courcelles-lès-Montbéliard', 'Courcelles-les-Montbeliard', 'Courcelles,Courcelles-les-Montbeliard,Courcelles-lès-Montbéliard', 47.5011300, 6.7846100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55788, 'Courcelles-lès-Lens', 'Courcelles-les-Lens', 'Courcelles,Courchelle-les-Linse,Courchelle-lès-Linse,Kursel le Lan,Kursel''-le-Lan,Kursel''-le-Lans,ku er sai lei lai lang si,kwrsylys lyh lyns,Курсел ле Лан,Курсель-ле-Лан,Курсель-ле-Ланс,كورسيليس ليه لينس,库尔塞勒莱朗斯', 50.4166700, 3.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55789, 'Courcelles-Chaussy', 'Courcelles-Chaussy', 'Courcelles-Chaussy,Kursel Shosi,Kursel''-Shossi,ku er se lai shao xi,kwrsl-shwsy,Курсел Шоси,Курсель-Шосси,Курсель-Шоссі,کورسل-شوسی,库尔瑟莱绍西', 49.1086200, 6.4039100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55790, 'Courbevoie', 'Courbevoie', 'Curbavia,Kurb''ovoa,Kurbevua,Kurbvoa,QEV,ku er bu wa,kuleubeubua,kurubuvu~oa,kwrbfwa,kwrbwa,Курбвоа,Курбевуа,Курбьовоа,كوربفوا,کوربوآ,کوربیوۓ,კურბევუა,クールブヴォア,库尔布瓦,쿠르브부아', 48.8967200, 2.2566600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55791, 'Coupvray', 'Coupvray', 'Coupvray,Kuvre,kuvure,Кувре,クヴレ', 48.8928900, 2.7967000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55792, 'Coulounieix-Chamiers', 'Coulounieix-Chamiers', 'Colonhes e Champs Niers,Colonhes e Champsniers,Colonhés e Champs Niers,Colonhés e Champsniers,Coulounieix,Coulounieix-Chamiers,Kulun''e-Sham''e,Kulun''e-Shame,ku lu nie yi sha mi ye er,Кулунье-Шамье,Кулуньє-Шамє,库卢涅伊沙米耶尔', 45.1528900, 0.6885200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55793, 'Coulon', 'Coulon', 'Coulon', 46.3232800, -0.5856100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55794, 'Coulommiers', 'Coulommiers', 'Coulommiers', 48.8145100, 3.0849800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55795, 'Coulombs', 'Coulombs', 'Coulombs', 48.6525300, 1.5464600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55796, 'Coulombiers', 'Coulombiers', 'Coulombiers', 46.4832400, 0.1849400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55797, 'Coulogne', 'Coulogne', 'Coulogne,Coulonne,Kulon'',ku luo nie,kwlwjn,Кулонь,كولوجن,库洛涅', 50.9246300, 1.8813700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55798, 'Coullons', 'Coullons', 'Coullons,Kullon,ku long,Куллон,库隆', 47.6210500, 2.4925800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55799, 'Coulans-sur-Gée', 'Coulans-sur-Gee', 'Coulans,Coulans-sur-Gee,Coulans-sur-Gée', 48.0207000, 0.0097400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55800, 'Coulanges-lès-Nevers', 'Coulanges-les-Nevers', 'Coulanges,Coulanges-les-Nevers,Coulanges-lès-Nevers', 47.0050900, 3.1875600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55801, 'Coulaines', 'Coulaines', 'Kulen,Кулен', 48.0240900, 0.2041100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55802, 'Couiza', 'Couiza', 'Coisan,Couiza,Kuiza,ku yi zha,Куиза,Куїза,库伊扎', 42.9419800, 2.2545300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55803, 'Couilly-Pont-aux-Dames', 'Couilly-Pont-aux-Dames', 'Couilly,Couilly-Pont,Couilly-Pont-aux-Dames,Kui-Pon-o-Dam,Куи-Пон-о-Дам,Куї-Пон-о-Дам', 48.8847300, 2.8567700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55804, 'Couhé', 'Couhe', 'Couche,Couché,Couhe,Couhe-Verac,Couhé,Couhé-Verac,Kue,ku e,Куе,库厄', 46.2991100, 0.1817400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55805, 'Coufouleux', 'Coufouleux', 'Confoleuc,Confolèuç,Couffouleux,Coufouleux,Kuffule,Kufuljo,ku fu lei,Куфулё,Куффуле,库富勒', 43.8171300, 1.7307800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55806, 'Couffé', 'Couffe', 'Couffe,Couffé,Koufeg,Kuffe,kufe,Куффе,クフェ', 47.3912000, -1.2932100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55807, 'Couëron', 'Coueron', 'Coueron,Couëron,Koeron,Kueron,ku e long,kueron,Куерон,クエロン,库厄龙', 47.2150800, -1.7217100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55808, 'Coudun', 'Coudun', 'Coudun,Kuden,ku dan,Куден,库丹', 49.4614600, 2.8124800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55809, 'Coudoux', 'Coudoux', 'Codoc,Codoç,Coudeux,Coudoux,Kudu,ku du,Куду,库杜', 43.5580000, 5.2488900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55810, 'Coudekerque-Branche', 'Coudekerque-Branche', 'Coudekerque,Coudekerque-Branche,Couderkerque-Branche,Kudkerk Bransh,Kudkerk-Bransh,Nieuw-Koudekerke,Nieuw-Koukerke,ku de kai er ke-bu lang shen,kudeukeleukeubeulangsyu,kudokeruku=buranshu,kwdwkrkw bransh,Кудкерк Бранш,Кудкерк-Бранш,کودوکرکو برانش,クドケルク＝ブランシュ,庫德凱爾克-布朗什,쿠드케르크브랑슈', 51.0228800, 2.3935900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55811, 'Coudekerque-Village', 'Coudekerque-Village', 'Koudekerke-Dorp,Koukerke,Kudkerk-Villazh,ku de kai er ke cun,Кудкерк-Виллаж,Кудкерк-Віллаж,库德凯尔克村', 51.0000000, 2.4166700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55812, 'Coucy-le-Château-Auffrique', 'Coucy-le-Chateau-Auffrique', 'Coucy-Auffrique,Coucy-la-Montagne,Coucy-le-Chateau,Coucy-le-Chateau-Auffrique,Coucy-le-Château,Coucy-le-Château-Auffrique,Kusi-le-Shato-Offrik,Kusi-le-Shato-Ofrik,ku xi bao-ou fu li ke,Куси-ле-Шато-Офрик,Кусі-ле-Шато-Оффрик,库西堡-欧夫里克', 49.5208300, 3.3238100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55813, 'Couchey', 'Couchey', 'Couchey', 47.2599100, 4.9825700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55814, 'Couches', 'Couches', 'Couches-les-Mines,Kush,Куш', 46.8666700, 4.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55815, 'Coubron', 'Coubron', 'Coubron,Kubron,ku bu long,Куброн,库布龙', 48.9166700, 2.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55816, 'Coubon', 'Coubon', 'Coubon', 44.9973100, 3.9178300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55817, 'Coublevie', 'Coublevie', 'Coublevie,Kublevi,ku bu lei wei ye,Кублеви,Кублеві,库布勒维耶', 45.3562400, 5.6175900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55818, 'Coubert', 'Coubert', 'Coubert', 48.6718600, 2.6973300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55819, 'Cotignac', 'Cotignac', 'Cotignac,Cotinhac,Kotin''jak,ke di ni ya,Котиньяк,Котіньяк,科蒂尼亚', 43.5284100, 6.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55820, 'Cossé-le-Vivien', 'Cosse-le-Vivien', 'Cosse-le-Vivien,Cossé-le-Vivien,Kosse-le-Vivjan,ke sai lai wei wei an,Коссе-ле-Вівян,科塞莱维维安', 47.9459900, -0.9118500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55821, 'Cosne-Cours-sur-Loire', 'Cosne-Cours-sur-Loire', 'Cosne-sur-Loire,Cours,Kon-Kur-sjur-Luar,konu=kuru=shuru=rowaru,lu wa er he pan ke si nei-ku er,Кон-Кур-сюр-Луар,コーヌ＝クール＝シュル＝ロワール,卢瓦尔河畔科斯内-库尔', 47.4110100, 2.9252800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55822, 'Cosnes-et-Romain', 'Cosnes-et-Romain', 'Cosnes,Cosnes-et-Romain', 49.5194300, 5.7176500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55823, 'Cosnac', 'Cosnac', 'Cosnac,Konak,ke si na ke,Конак,科斯纳克', 45.1351600, 1.5857500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55824, 'Corzé', 'Corze', '', 47.5595600, -0.3906200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55825, 'Corte', 'Corte', 'Corte,Corti,Kort,Korte,korute,Корт,Корте,コルテ', 42.3095600, 9.1491700, 'FR', '2016-09-30', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55826, 'Corseul', 'Corseul', 'Corseul,Corsoltum,Kersaout,Korsel'',Korsjol'',ke er se,Корсель,Корсёль,科尔瑟', 48.4818000, -2.1694700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55827, 'Corsept', 'Corsept', 'Corbilo,Corsept,Korset,Korzed,ke er sai pu,koruseputo,Корсет,コルセプト,科尔塞普', 47.2770300, -2.0590400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55828, 'Corrèze', 'Correze', 'Correze,Corrèze', 45.3727300, 1.8746500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55829, 'Corquilleroy', 'Corquilleroy', 'Corquille-Libre,Corquilleroy,Curquilleroy,Korkijeroa,Korkijrua,ke er qu yi lei lu wa,Коркијероа,Коркійруа,科尔屈伊勒鲁瓦', 48.0421200, 2.7038200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55830, 'Corps-Nuds', 'Corps-Nuds', 'Cornutium,Corps-Nuds,Kor-Nju,Kornuz,Korp Nid,ke er pu ni de,Кор-Ню,Корп Нид,科尔普尼德', 47.9791500, -1.5840900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55831, 'Corpeau', 'Corpeau', 'Corpeau', 46.9291700, 4.7522600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55832, 'Coron', 'Coron', 'Coron', 47.1272600, -0.6451200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55833, 'Corny-sur-Moselle', 'Corny-sur-Moselle', 'Corny,Corny-sur-Moselle,Korni sir Mozel,Korni-sjur-Mozel'',kwrny-swr-mwzl,mo sai er he pan ke er ni,Корни сир Мозел,Корни-сюр-Мозель,Корні-сюр-Мозель,کورنی-سور-موزل,莫塞尔河畔科尔尼', 49.0349700, 6.0597100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55834, 'Cornimont', 'Cornimont', 'Cornimont', 47.9599800, 6.8303800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55835, 'Cornillon-Confoux', 'Cornillon-Confoux', 'Cornilhon e Conforc,Cornilhon e Conforç,Cornillon,Cornillon-Confoux,Kornijon Konfu,Kornijon-Konfu,ke er ni long kong fu,Корнийон-Конфу,Корнијон Конфу,Корнійон-Конфу,科尔尼隆孔富', 43.5666700, 5.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55836, 'Cornil', 'Cornil', 'Cornil,Cornilh,Kornij,Kornil'',ke er ni,Корний,Корниль,Корниј,Корній,科尔尼', 45.2116800, 1.6920400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55837, 'Cornier', 'Cornier', 'Cornier', 46.0937800, 6.2979600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55838, 'Corneville-sur-Risle', 'Corneville-sur-Risle', 'Corneville,Corneville-sur-Risle,Kornevil''-sjur-Ril'',Kornvil sir Ril,li si er he pan ke er na wei er,Корнвил сир Рил,Корневиль-сюр-Риль,Корневіль-сюр-Риль,里斯尔河畔科尔纳维尔', 49.3412800, 0.5862800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55839, 'Corneilla-la-Rivière', 'Corneilla-la-Riviere', 'Corneilla,Corneilla-de-la-Riviere,Corneilla-de-la-Rivière,Corneilla-la-Riviere,Corneilla-la-Rivière,Corneillà,Cornella de la Ribera,Cornellà de la Ribera', 42.6967500, 2.7296200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55840, 'Corneilla-del-Vercol', 'Corneilla-del-Vercol', 'Corneilla,Corneilla-del-Vercol,Cornella del Bercol,Cornellà del Bèrcol', 42.6239000, 2.9521600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55841, 'Corneilhan', 'Corneilhan', 'Corneilhan', 43.3995700, 3.1914700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55842, 'Cornebarrieu', 'Cornebarrieu', 'Cornabarriu,Cornebarrien,Cornebarrieu,Còrnabarriu,Kornbar''jo,Kornbarije,Kornbarre,ke er nei ba er li e,Корнбарије,Корнбаррє,Корнбарьё,科尔内巴尔里厄', 43.6489500, 1.3240700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55843, 'Corné', 'Corne', 'Corne,Corné', 47.4709100, -0.3499200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55844, 'Cornas', 'Cornas', 'Cornas', 44.9649800, 4.8480600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55845, 'Cormontreuil', 'Cormontreuil', 'Cormontreuil,Kormonrej,Kormontrej,ke er meng te lei yi,Кормонрей,Кормонтреј,科尔蒙特勒伊', 49.2166700, 4.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55846, 'Cormicy', 'Cormicy', 'Cormicy,Kormisi,ke er mi xi,Кормиси,Кормісі,科尔米西', 49.3707100, 3.8959500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55847, 'Cormery', 'Cormery', 'Cormery', 47.2681200, 0.8358300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55848, 'Corme-Royal', 'Corme-Royal', 'Corme-Royal,Corme-la-Foret,Corme-la-Forêt', 45.7439500, -0.8147100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55849, 'Cormeray', 'Cormeray', 'Cormeray', 47.4919500, 1.4061000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55850, 'Cormelles-le-Royal', 'Cormelles-le-Royal', 'Cormelles-le-Libre,Kormel le Roajal,Kormel''-le-Ruajal'',Kormel''-le-Ruajjal'',ke er mo lai lai lu wa a,Кормел ле Роајал,Кормель-ле-Руайяль,Кормель-ле-Руаяль,科尔默莱莱鲁瓦阿', 49.1539800, -0.3306200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55851, 'Cormeilles-en-Parisis', 'Cormeilles-en-Parisis', 'Cormeilles,Cormeilles-en-Parisis,Kormej an Parizi,Kormej-an-Parizi,koleumeyujangpaliji,korumeiyu=zan=pariji,kwrmy an pryzys,kwrmy-an-pryzy,pa li xi de qu ke er mei ye,Кормей-ан-Паризи,Кормей-ан-Паризі,Кормеј ан Паризи,کورمی آن پریزیس,کورمی-آن-پریزی,コルメイユ＝ザン＝パリジ,帕里西地区科尔梅耶,코르메유장파리지', 48.9711100, 2.2049100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55852, 'Cormeilles', 'Cormeilles', 'Cormeilles', 49.2480300, 0.3765400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55853, 'Corlay', 'Corlay', 'Corlay,Korle', 48.3172500, -3.0573300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55854, 'Corenc', 'Corenc', 'Corenc,Koran,Korank,Korenk,ke lang ke,Коран,Коранк,Коренк,科朗克', 45.2142100, 5.7715200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55855, 'Cordon', 'Cordon', 'Cordon', 45.9240800, 6.6123700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55856, 'Cordes-sur-Ciel', 'Cordes-sur-Ciel', 'Cordas,Còrdas,Kord-sir-Sjel,Kord-sjur-S''el'',korudo=shuru=shieru,xie he pan ke er de,Корд-сир-Сјел,Корд-сюр-Сьель,Корд-сюр-Сьєль,コルド＝シュル＝シエル,谢河畔科尔德', 44.0666700, 1.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55857, 'Cordemais', 'Cordemais', 'Cordemais,Kordevez,Kordme,ke er dai mai,korudome,Кордме,コルドメ,科尔代迈', 47.2910700, -1.8786900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55858, 'Corcieux', 'Corcieux', 'Corcieux,Kors''e,Korsje,ke er xi e,Корсье,Корсьє,Корсје,科尔西厄', 48.1723600, 6.8814800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55859, 'Corbreuse', 'Corbreuse', 'Corbreuse,Korbrez,ke er bu lei si,Корбрез,科尔布勒斯', 48.5006500, 1.9591300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55860, 'Corbigny', 'Corbigny', 'Corbigny,Korbin''i,Korbini,ke er bi ni,Корбиньи,Корбињи,Корбіньї,科尔比尼', 47.2567800, 3.6828500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55861, 'Corbie', 'Corbie', 'Abadia de Corbie,Abadía de Corbie,Corbeu,Corbie,Korbi,ke er bi,Корби,Корбі,科尔比', 49.9067200, 2.5068200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55862, 'Corbenay', 'Corbenay', 'Corbenay', 47.8927500, 6.3304700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55863, 'Corbelin', 'Corbelin', 'Corbelin', 45.6086800, 5.5444800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55864, 'Corbeilles', 'Corbeilles', 'Corbeilles,Corbeilles-en-Gatinais,Corbeilles-en-Gâtinais,Corbeilles-la-Montagne,Korbej,ke er bei lai,Корбей,Корбеј,科尔贝莱', 48.0720100, 2.5503000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55865, 'Corbeil-Essonnes', 'Corbeil-Essonnes', 'Corbeil,Corbeil-Essonnes,Corbeil-la-Montagne,Korbej Eson,Korbej-Ehson,Korbej-Ehsson,Korbej-Ehssonna,Korbej-Essonn,ke er bei ai suo na,koleubeyueson,korubeiyu=eson''nu,kwrby aswn,Корбей-Ессонн,Корбей-Эсон,Корбей-Эссон,Корбей-Эссонна,Корбеј Есон,کوربی اسون,コルベイユ＝エソンヌ,科尔贝埃索纳,코르베유에손', 48.6060300, 2.4875700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55866, 'Corbehem', 'Corbehem', 'Corbehem,Corbehin,Korbeam,Korbeem,ke er bei mu,kwrbyhym,Корбеам,Корбеем,كوربيهيم,科尔贝姆', 50.3314100, 3.0499500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55867, 'Corbas', 'Corbas', 'Corbas,Korba,Корба', 45.6679000, 4.8962700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55868, 'Corbarieu', 'Corbarieu', 'Corbarieu', 43.9441500, 1.3688100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55869, 'Coray', 'Coray', 'Coray,Kore,ke lai,kore,Коре,コレ,科赖', 48.0593400, -3.8305600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55870, 'Coquelles', 'Coquelles', 'Kokel,Kokel'',ke kai lei,kwkywlys,Кокел,Кокель,كوكيوليس,科凯勒', 50.9346100, 1.7988000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55871, 'Conty', 'Conty', 'Conty,Konti,kong di,Конти,Конті,孔蒂', 49.7410000, 2.1512000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55872, 'Contrexéville', 'Contrexeville', 'Contrexeville,Contrexéville,Kontreksevil,Kontreksevil'',kong te lei ke sai wei er,Контрексевил,Контрексевиль,Контрексевіль,孔特勒克塞维尔', 48.1842400, 5.8957200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55873, 'Contres', 'Contres', 'Contres', 47.4175400, 1.4284900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55874, 'Contes', 'Contes', 'Contes', 43.8127800, 7.3144400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55875, 'Contamine-sur-Arve', 'Contamine-sur-Arve', 'Contamine,Contamine-sur-Arve', 46.1294200, 6.3383900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55876, 'Conques-sur-Orbiel', 'Conques-sur-Orbiel', 'Concas,Concas dOrbiel,Concas dOrbièl,Konk sir Orbjel,Konk-sjur-Orb''el'',Konk-sjur-Orbel'',ao er bi ye he pan kong qu ai,Конк сир Орбјел,Конк-сюр-Орбьель,Конк-сюр-Орбєль,奥尔比耶河畔孔屈埃', 43.2666700, 2.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55877, 'Conquereuil', 'Conquereuil', 'Conquereuil,Konkerel', 47.6252400, -1.7510500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55878, 'Connerré', 'Connerre', 'Connerre,Connerré', 48.0569800, 0.4934400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55879, 'Connaux', 'Connaux', 'Connaux', 44.0891900, 4.5938700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55880, 'Connantre', 'Connantre', 'Connantre', 48.7265700, 3.9240300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55881, 'Conlie', 'Conlie', 'Conlie', 48.1233400, -0.0173900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55882, 'Congrier', 'Congrier', 'Congrier', 47.8098900, -1.1170000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55883, 'Congis-sur-Thérouanne', 'Congis-sur-Therouanne', 'Konzhi sir Teruan,Konzhi-sjur-Teruann,Конжи сир Теруан,Конжи-сюр-Теруанн,Конжі-сюр-Теруанн', 49.0000000, 2.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55884, 'Congénies', 'Congenies', 'Congenhas,Congenies,Congènhas,Konzheni,Konzhenije,kong re nie,Конжени,Конженије,Конжені,孔热涅', 43.7666700, 4.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55885, 'Confolens', 'Confolens', 'Confolent,Confolents,Konfolan,konforan,kong fu lang,Конфолан,コンフォラン,孔福朗', 46.0166700, 0.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55886, 'Conflans-Sainte-Honorine', 'Conflans-Sainte-Honorine', 'Conflans,Conflans-Sainte-Honorine,Confluent-de-Seine-et-Oise,Konflan Sent Onoren,Konflan-Sent-Onorin,knflan-snt-awnwryn,konfuran=santonorinu,kong fu lang-sheng ao nuo li ne,kongpeullangsaengtonolin,kwnflan snt awnwryn,Конфлан Сент Онорен,Конфлан-Сент-Онорин,کنفلان-سنت-اونورین,کونفلان سنت اونورین,コンフラン＝サントノリーヌ,孔夫朗-圣奥诺里讷,콩플랑생토노린', 49.0015800, 2.0969400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55887, 'Conflans-en-Jarnisy', 'Conflans-en-Jarnisy', 'Conflans,Conflans-en-Jarnisy', 49.1676800, 5.8486300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55888, 'Condrieu', 'Condrieu', 'Condrieu,Kondrie,Kondrije,kondoryu,Кондрије,Кондріє,コンドリュー', 45.4634400, 4.7684800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55889, 'Condom', 'Condom', 'Condom', 43.9581600, 0.3719900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55890, 'Condette', 'Condette', 'Condette,Kondet,Kondett,kong dai te,kwndyty,Кондет,Кондетт,كونديتي,孔代特', 50.6581700, 1.6338600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55891, 'Condé-sur-Vire', 'Conde-sur-Vire', 'Conde,Conde-sur-Vire,Condé-sur-Vire,Konde sir Vir,Konde-sjur-Vir,wei er he pan kong dai,Конде сир Вир,Конде-сюр-Вир,Конде-сюр-Вір,维尔河畔孔代', 49.0500000, -1.0333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55892, 'Condé-sur-Vesgre', 'Conde-sur-Vesgre', 'Conde,Conde-sur-Vesgre,Condé-sur-Vesgre,Konde sir Vegr,Konde-sjur-Vegr,Конде сир Вегр,Конде-сюр-Вегр', 48.7419900, 1.6606900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55893, 'Condé-sur-Sarthe', 'Conde-sur-Sarthe', 'Conde,Conde-sur-Sarthe,Condé,Condé-sur-Sarthe,Konde sir Sart,Konde-sjur-Sart,sa er te he pan kong dai,Конде сир Сарт,Конде-сюр-Сарт,萨尔特河畔孔代', 48.4319700, 0.0339800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55894, 'Condé-sur-Noireau', 'Conde-sur-Noireau', 'Conde,Conde sur Noireau,Conde-sur-Noireau,Condé sur Noireau,Condé-sur-Noireau,Konde sir Noaro,Konde-sjur-Nuaro,Noireau,konde=shuru=nowaro,nu wa luo he pan kong dai,Конде сир Ноаро,Конде-сюр-Нуаро,コンデ＝シュル＝ノワロー,努瓦罗河畔孔代', 48.8488100, -0.5521400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55895, 'Condé-sur-l’Escaut', 'Conde-sur-l''Escaut', 'Condate ad Scaldim,Conde,Conde-sur-Escaut,Conde-sur-l''Escaut,Condé,Condé-sur-Escaut,Condé-sur-l’Escaut,Konde sir l''Esko,Konde-sjur-l''Ehsko,Konde-sjur-l''Esko,Nord-Libre,ai si ke he pan kong dai,Конде сир л''Еско,Конде-сюр-л''Еско,Конде-сюр-л’Эско,埃斯科河畔孔代', 50.4543600, 3.5888400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55896, 'Condé-sur-Huisne', 'Conde-sur-Huisne', 'Conde,Conde-sur-Huine,Conde-sur-Huisne,Condé,Condé-sur-Huine,Condé-sur-Huisne', 48.3810300, 0.8509300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55897, 'Condé-Sainte-Libiaire', 'Conde-Sainte-Libiaire', 'Conde,Conde-Sainte-Libiaire,Conde-sur-Morin,Condé,Condé-Sainte-Libiaire,Condé-sur-Morin', 48.8969500, 2.8390400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55898, 'Condat-sur-Vienne', 'Condat-sur-Vienne', 'Condat,Condat-sur-Vienne', 45.7864800, 1.2845400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55899, 'Condat', 'Condat', 'Condat-en-Feniers,Condat-en-Féniers', 45.3409300, 2.7579100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55900, 'Conches-en-Ouche', 'Conches-en-Ouche', 'Conches,Conches-en-Ouche,Konsh an Ush,Konsh-an-Ush,La Montagne-de-Conches,wu shen de qu kong xie,Конш ан Уш,Конш-ан-Уш,乌什地区孔谢', 48.9576800, 0.9405200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55901, 'Conches-sur-Gondoire', 'Conches-sur-Gondoire', 'Konsh sir Gondoar,Konsh-sjur-Gonduar,Конш сир Гондоар,Конш-сюр-Гондуар', 48.8562400, 2.7178300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55902, 'Concarneau', 'Concarneau', 'Concarneau,Konk-Kerne,Konkarno,knkarnw,kong ka er nuo,konkaruno,Конкарно,کنکارنو,コンカルノー,孔卡尔诺', 47.8750200, -3.9224500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55903, 'Comps', 'Comps', 'Comps,Comps-Saint-Etienne,Comps-Saint-Étienne', 43.8530400, 4.6056700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55904, 'Compreignac', 'Compreignac', 'Compreignac', 45.9916200, 1.2756100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55905, 'Compiègne', 'Compiegne', 'Compendium,Compenha,Compiegne,Compiene,Compiègne,Compiène,Komp''en'',Kompen'',Kompien,Kompjen,Kompjene,Kompjenė,Marat-sur-Oise,gong bi nie,kongpienyu,konpienyu,kwmbyyn,kwmpyn,kwmpyny,Компиен,Компьень,Компєнь,Компјењ,كومبيين,کومپین,کومپینی,კომპიენი,コンピエーニュ,贡比涅,콩피에뉴', 49.4179400, 2.8260600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55906, 'Compertrix', 'Compertrix', 'Compertrix', 48.9417900, 4.3463100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55907, 'Communay', 'Communay', 'Communay,Komine,Kommjune,Комине,Коммюне', 45.6067100, 4.8398800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55908, 'Commercy', 'Commercy', 'Commercy,Komersi,Kommersi,ke mei er xi,komerushi,Комерси,Коммерси,Коммерсі,コメルシー,科梅尔西', 48.7612800, 5.5906700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55909, 'Commer', 'Commer', 'Commer', 48.2333300, -0.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55910, 'Commequiers', 'Commequiers', 'Commequiers,Kommeke,Konkje,ke mo qu ye er,Коммекє,Конкје,科默屈耶尔', 46.7604900, -1.8390100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55911, 'Commentry', 'Commentry', 'Comentriac,Commentry,Komantri,Kommantri,ke mang te li,Комантри,Коммантри,Коммантрі,科芒特里', 46.2921100, 2.7416000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55912, 'Commelle-Vernay', 'Commelle-Vernay', 'Commelle,Commelle-Vernay', 45.9943900, 4.0663500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55913, 'Comines', 'Comines', 'Comines', 50.7615000, 3.0106300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55914, 'Combs-la-Ville', 'Combs-la-Ville', 'Combs,Combs-la-Ville,Komb la Vil,Kon-la-Vil'',km lwyl,kon=ra=vu~iru,konglabil,Комб ла Вил,Кон-ла-Виль,Кон-ла-Віль,کم لویل,コン＝ラ＝ヴィル,콩라빌', 48.6649700, 2.5695700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55915, 'Combronde', 'Combronde', 'Combronde', 45.9813800, 3.0876800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55916, 'Combrit', 'Combrit', 'Combrit,Kombri,Kombrid,konburi,kong bu li,Комбри,Комбрі,コンブリ,孔布里', 47.8873400, -4.1581700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55917, 'Combrée', 'Combree', 'Combree,Combrée,Kombre,kong bu lei ai,Комбре,孔布雷埃', 47.7044600, -1.0300300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55918, 'Combrand', 'Combrand', 'Combrand', 46.8640500, -0.6886900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55919, 'Combourg', 'Combourg', 'Combourg,Comburnium,Komborn,Kombur,kong bu er,Комбур,孔布尔', 48.4126700, -1.7442400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55920, 'Combloux', 'Combloux', 'Combloux,Complutum,Komblu,Комблу', 45.8966900, 6.6344400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55921, 'Pontault-Combault', 'Pontault-Combault', 'Ponto Kombo,Ponto-Kombo,pongtokongbo,ponto=konbo,pwntw kwmbw,pwntwlt kwmbw,Понто Комбо,Понто-Комбо,پونتو کومبو,پونتولت کومبو,ポントー＝コンボー,퐁토콩보', 48.7981300, 2.6067600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55922, 'Combaillaux', 'Combaillaux', 'Combaillaux', 43.6719100, 3.7676700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55923, 'Colpo', 'Colpo', 'Colpo,Kol''po,Kolpo,Kolpou,Kolpoù,ke er bo,Колпо,Кольпо,科尔波', 47.8177800, -2.8100200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55924, 'Colomiers', 'Colomiers', 'Colomers,Colomiers,Colomièrs,Colomèrs,Kolom''e,Kolome,Kolomje,ke luo mi ye er,kollomie,koromie,kwlwmyh,Коломье,Коломє,Коломје,کولومیه,コロミエ,科洛米耶尔,콜로미에', 43.6105800, 1.3346700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55925, 'Colombiès', 'Colombies', 'Colombies,Colombiès', 44.3441400, 2.3377200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55926, 'Colombiers', 'Colombiers', 'Colombiers', 46.7715800, 0.4238800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55927, 'Colombiers', 'Colombiers', 'Colombiers', 43.3142400, 3.1394700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55928, 'Colombier-Fontaine', 'Colombier-Fontaine', 'Colombier-Fontaine,Kolombe-Fonten,Kolombje Fonten,ke long bi ye feng tan,Коломбє-Фонтен,Коломбје Фонтен,科隆比耶丰坦', 47.4522400, 6.6901000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55929, 'Colombey-les-Belles', 'Colombey-les-Belles', 'Colombey,Colombey-les-Belles', 48.5276600, 5.8969300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55930, 'Colombes', 'Colombes', 'Colombes,Columbae,Kolomb,Kolombas,bai ge cheng,klwmb,kollongbeu,koronbu,kwlwmb  aw dw syn,qwlwmb,Коломб,קולומב,كولومب، أو دو سين,کلومب,コロンブ,白鸽城,콜롱브', 48.9188200, 2.2540400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55931, 'Colombelles', 'Colombelles', 'Colombelles,Kolombel,Kolombel'',ke long bei lai,Коломбел,Коломбель,科隆贝莱', 49.2049000, -0.2957100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55932, 'Colombe', 'Colombe', 'Colombe,Colombes', 45.3991200, 5.4510900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55933, 'Colomars', 'Colomars', 'Colomars', 43.7540600, 7.2198000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55934, 'Colmar', 'Colmar', 'CMR,Colmar,Colmaria,Gorad Kal''mar,Koimar,Kol''mar,Kolmar,Kolmara,ke er ma,klmar,kolmaleu,korumaru,kwlmar,kwlmr,kx lmar,qwlmr,Κολμάρ,Горад Кальмар,Колмар,Кольмар,קולמר,كولمار,کلمار,کولمر,กอลมาร์,コルマール,科尔马,콜마르', 48.0833300, 7.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55935, 'Collonges-sous-Salève', 'Collonges-sous-Saleve', 'Collonge-sous-Saleve,Collonge-sous-Salève,Collonges', 46.1416000, 6.1537200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55936, 'Collonges', 'Collonges', 'Collonges', 46.1389400, 5.9033400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55937, 'Collobrières', 'Collobrieres', 'Collobrieres,Collobrières,Colobrieras,Colobrièras,Kollobrier,Kolobrijer,ke luo bu li ai,koroburieru,Коллобриер,Коллобрієр,Колобријер,コロブリエール,科洛布里埃', 43.2373500, 6.3087500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55938, 'Collioure', 'Collioure', 'Collioure,Colliure,Cotlliure,Kolijur,Koliur,Kolliur,XCU,ke li wu er,koriuru,kwlywr,Колиур,Колијур,Коллиур,Колліур,کولیور,コリウール,科利乌尔', 42.5246200, 3.0823500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55939, 'Colleville-Montgomery', 'Colleville-Montgomery', 'Colleville,Colleville-Montgomery,Colleville-sur-Orne,Kol''vil''-Mongomeri,Kolevil Mongomeri,ke lei wei er meng te ge mo li,Колевил Монгомери,Кольвиль-Монгомери,Кольвіль-Монгомері,科勒维尔蒙特戈默里', 49.2752800, -0.3005200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55940, 'Collégien', 'Collegien', 'Collegien,Collégien', 48.8357100, 2.6736500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55941, 'Coligny', 'Coligny', 'Coligny,Nant-Coteau', 46.3825200, 5.3455400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55942, 'Colayrac-Saint-Cirq', 'Colayrac-Saint-Cirq', 'Colayrac,Colayrac-Saint-Cirq', 44.2209500, 0.5506100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55943, 'Coise-Saint-Jean-Pied-Gauthier', 'Coise-Saint-Jean-Pied-Gauthier', 'Coise,Coise-Saint-Jean-Pied-Gauthier,Koaz Sen Zhan Pje Gotje,Kuaz-Sen-Zhan-Pe-Got''e,Коаз Сен Жан Пје Готје,Куаз-Сен-Жан-Пє-Готьє', 45.5257800, 6.1435900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55944, 'Coincy', 'Coincy', 'Coincy', 49.1603600, 3.4220200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55945, 'Coignières', 'Coignieres', 'Coignieres,Coignières,Koanijer,Kuan''er,Коањијер,Куаньер,Куаньєр', 48.7501000, 1.9208200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55946, 'Cogolin', 'Cogolin', 'Cogolin,Kogolen,ke ge lan,Коголен,科戈兰', 43.2522100, 6.5300200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55947, 'Cogny', 'Cogny', 'Cogny', 45.9873200, 4.6250100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55948, 'Cognin', 'Cognin', 'Cognen,Cognin,Kon''en,Konen,Коньєн,Коњен', 45.5637700, 5.8943500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55949, 'Cognac-la-Forêt', 'Cognac-la-Foret', 'Cognac,Cognac-le-Froid,Conhac,Conhac la Forest,Kon''jak-la-Fore,Konak la Fore,ke ni ya ke la fu lei,Коньяк-ла-Форе,Коњак ла Форе,科尼亚克拉福雷', 45.8333300, 1.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55950, 'Cognac', 'Cognac', 'CNG,Cognac,Conhac,Kon''jak,Konjak,Коньяк', 45.7000000, -0.3333300, 'FR', '2016-12-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55951, 'Coëx', 'Coex', 'Coex,Coëx,Koe,ke e,Кое,科厄', 46.6980800, -1.7595600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55952, 'Coëtmieux', 'Coetmieux', 'Coetmieux,Coëtmieux,Koedmaeg', 48.4911700, -2.6006700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55953, 'Coësmes', 'Coesmes', 'Coesmes,Coesmis,Coësmes,Coësmis,Koem,ke e si mei,Коем,科厄斯梅', 47.8832500, -1.4407400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55954, 'Codognan', 'Codognan', 'Codognan', 43.7303300, 4.2212000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55955, 'Cocheren', 'Cocheren', 'Cocheren', 49.1460400, 6.8558000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55956, 'Coarraze', 'Coarraze', 'Coarasa,Coarrasa,Coarraze,Koaraz,Koarraz,ke a er la ci,Коараз,Коарраз,科阿尔拉兹', 43.1666700, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55957, 'Cluses', 'Cluses', 'Clluses,Clusae Fulciniacenses,Cluses,Kliz,Kljuz,Клиз,Клюз', 46.0625100, 6.5749700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55958, 'Cluny', 'Cluny', 'Chiny,Cluniacum,Cluny,Kljuni,klwny,Клюни,كلوني', 46.4331800, 4.6584500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55959, 'Cluis', 'Cluis', 'Cluis,Kli,Kljui,ke lu yi,Кли,Клюи,Клюї,克吕伊', 46.5448600, 1.7493300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55960, 'Cloyes-sur-le-Loir', 'Cloyes-sur-le-Loir', 'Cloyes,Cloyes-sur-le-Loir', 47.9972600, 1.2371100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55961, 'Clouange', 'Clouange', 'Clouange', 49.2624000, 6.0972300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55962, 'Clonas-sur-Varèze', 'Clonas-sur-Vareze', 'Clonas,Clonas-sur-Vareze,Clonas-sur-Varèze', 45.4132600, 4.7899600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55963, 'Clohars-Fouesnant', 'Clohars-Fouesnant', 'Clohars,Clohars-Fouesnant,Kloar Fuenan,Kloar-Fouenant,Kloar-Fuenan,ke luo a er fu ai si nan,Клоар Фуенан,Клоар-Фуенан,克洛阿尔富埃斯南', 47.8965700, -4.0639600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55964, 'Clohars-Carnoët', 'Clohars-Carnoet', 'Clohars,Clohars-Carnoet,Clohars-Carnoët,Kloar Karnoe,Kloar-Karnoe,Kloar-Karnoed,ke luo a er ka er nuo e,Клоар Карное,Клоар-Карное,克洛阿尔卡尔诺厄', 47.7960600, -3.5850200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55965, 'Clisson', 'Clisson', 'Clisson,Clissonium,Klison,Klisson,ke li song,kurison,Клисон,Кліссон,クリソン,克利松', 47.0871400, -1.2828600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55966, 'Clion', 'Clion', 'Clion', 46.9408500, 1.2321400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55967, 'Clinchamps-sur-Orne', 'Clinchamps-sur-Orne', 'Clinchamps,Clinchamps-sur-Orne', 49.0785700, -0.4015600, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55968, 'Clichy-sous-Bois', 'Clichy-sous-Bois', 'Clichy,Clichy-sous-Bois,Klishi su Boa,Klishi-su-Bua,ke li xi cong lin,keullisisubua,klyshy sw bwa,kurishi=su=bowa,Клиши су Боа,Клиши-су-Буа,Кліші-су-Буа,كليشي سو بوا,کلیشی سو بوآ,クリシー＝ス＝ボワ,克利希丛林,클리시수부아', 48.9102000, 2.5532300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55969, 'Clichy', 'Clichy', 'Clichy,Clichy-la-Garenne,Clichy-sur-Seine,Clicy,Klishi,Клиши', 48.9001800, 2.3095200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55970, 'Cléry-Saint-André', 'Clery-Saint-Andre', 'Cleriacum,Clery,Clery-Saint-Andre,Cléry,Cléry-Saint-André,Kleri Sent Andre,Kleri-Sent-Andre,ke lai li sheng ang de lei,Клери Сент Андре,Клері-Сент-Андре,克莱里圣昂德雷', 47.8221800, 1.7509100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55971, 'Clerval', 'Clerval', 'Clerval', 47.3916700, 6.4992500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55972, 'Clermont-Ferrand', 'Clermont-Ferrand', 'Augustonemetum,CFE,Clarmont,Clarmont dAlvernia,Clarmont dAlvèrnia,Clarmont-Ferrand,Clermont,Clermont-Ferrand,Cllarmont-Ferrand,Cllârmont-Fèrrand,Gorad Klermon-Feran,Klermon Feran,Klermon-Feran,Klermon-Ferran,Klermonas-Feranas,Klermonferana,Klermonferāna,ke lai meng fei lang,keulleleumongpelang,kleramam feram,kleramam-pheram,klrmwn fran,klrmwn-fran,klymwn-fyrand,klyrmwn fyran,kurerumon=feran,Κλερμόν-Φεράν,Горад Клермон-Феран,Клермон Феран,Клермон-Феран,Клермон-Ферран,Կլերմոն Ֆերան,קלרמון-פראן,كليرمون فيران,کلرمون فران,کلرمون-فران,کلیمون-فیراند,क्लेरमाँ फ़ेराँ,क्लेरमाँ-फेराँ,แกลร์มง-แฟร็อง,კლერმონ-ფერანი,クレルモン＝フェラン,克莱蒙费朗,클레르몽페랑', 45.7796600, 3.0862800, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55973, 'Clermont-en-Argonne', 'Clermont-en-Argonne', 'Clermont,Clermont-en-Argonne,Clermont-sur-Meuse,Klermont an Argon,Klermont-an-Argonn,a ge ne de qu ke lai meng,Клермонт ан Аргон,Клермонт-ан-Аргонн,阿戈讷地区克莱蒙', 49.1071100, 5.0700200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55974, 'Clermont-Créans', 'Clermont-Creans', 'Clermont,Klermon Krean,Klermon-Krean,Клермон Креан,Клермон-Креан', 47.7183100, -0.0145900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55975, 'Clermont', 'Clermont', 'Clermont,Clermont-en-Beauvaisis', 49.3833300, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55976, 'Clérieux', 'Clerieux', 'Clerieux,Clérieux', 45.0772200, 4.9593700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55977, 'Clères', 'Cleres', 'Cleres,Clères', 49.6000000, 1.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55978, 'Cléré-les-Pins', 'Clere-les-Pins', 'Clere,Clere-les-Pins,Cléré,Cléré-les-Pins', 47.4255000, 0.3896300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55979, 'Clérac', 'Clerac', 'Clerac,Clérac,Klerak,ke lai la ke,Клерак,Կլերակ,克莱拉克', 45.1833300, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55980, 'Cléon', 'Cleon', 'Cleon,Cléon', 49.3123500, 1.0295000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55981, 'Cléguérec', 'Cleguerec', 'Cleguerec,Cléguérec,Klegereg,Klegerek,ke lai gai lei ke,Клегерек,克莱盖雷克', 48.1257700, -3.0716200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55982, 'Cléguer', 'Cleguer', 'Cleguer,Cléguer,Klege,Kleger,ke lai gai,Клеге,Клегер,克莱盖', 47.8540700, -3.3821900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55983, 'Cléder', 'Cleder', 'Cleder,Cléder,Klede,Kleder,ke lai dai,kurederu,Кледе,Кледер,クレデール,克莱代', 48.6630000, -4.1020000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55984, 'Cléden-Poher', 'Cleden-Poher', 'Cleden-Poher,Cléden-Poher,Kledan Poer,Kledan-Poe,Kledenn-Poc''her,Kledenn-Poc''hêr,Kledenn-Pocher,Kledenn-Pochêr,ke lai dang bo ai,Кледан Поер,Кледан-Пое,克莱当波埃', 48.2364400, -3.6691100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55985, 'Clécy', 'Clecy', 'Clecy,Clécy', 48.9171800, -0.4804100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55986, 'Claye-Souilly', 'Claye-Souilly', 'Claye,Claye-Souilly,Kle Suji,Kle-Sui,Кле Суји,Кле-Суи,Кле-Суї', 48.9449200, 2.6856600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55987, 'Claville', 'Claville', 'Claville', 49.0484400, 1.0195400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55988, 'Clary', 'Clary', 'Clary', 50.0778900, 3.3994300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55989, 'Claret', 'Claret', '', 43.8624400, 3.9052200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55990, 'Clarensac', 'Clarensac', 'Clarensac', 43.8253600, 4.2204700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55991, 'Clapiers', 'Clapiers', 'Clapiers', 43.6583300, 3.8891700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55992, 'Clamecy', 'Clamecy', 'Clamecy', 47.4500000, 3.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55993, 'Clamart', 'Clamart', 'Clamart,Clemartium,Klamar,Le Vignoble,ke la ma,keullamaleu,klamar,klmr,kuramaru,Кламар,كلامار,کلمر,クラマール,克拉马,클라마르', 48.8029900, 2.2669200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55994, 'Claix', 'Claix', 'Claix', 45.1225400, 5.6748100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55995, 'Clairvaux-les-Lacs', 'Clairvaux-les-Lacs', 'Clairvaux,Clairvaux-les-Lacs,Klervo le Lak,Klervo-le-Lak,ke lai er wo lai la ke,Клерво ле Лак,Клерво-ле-Лак,克莱尔沃莱拉克', 46.5747300, 5.7482500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55996, 'Clairoix', 'Clairoix', 'Clairoix,Clairox,Kleroa,Klerua,ke lai lu wa,Клероа,Клеруа,克莱鲁瓦', 49.4426400, 2.8462800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55997, 'Clairac', 'Clairac', 'Clairac', 44.3601100, 0.3789300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55998, 'Claira', 'Claira', 'Claira,Clairà,Klera,Клера', 42.7603600, 2.9557200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(55999, 'Civrieux', 'Civrieux', 'Civrieux', 45.9217700, 4.8854800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56000, 'Civray-de-Touraine', 'Civray-de-Touraine', 'Civray,Civray-de-Touraine,Civray-sur-Cher', 47.3325300, 1.0495200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56001, 'Civray', 'Civray', 'Civray', 46.1471000, 0.2950900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56002, 'Civens', 'Civens', 'Civens', 45.7798700, 4.2517000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56003, 'Varennes-Vauzelles', 'Varennes-Vauzelles', 'Varenn-Vozel'',Vauzelles,wa lei nei wo ze lai,warn wwzl,Варенн-Возель,وارن ووزل,瓦雷内沃泽莱', 47.0167800, 3.1403700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56004, 'Cissé', 'Cisse', 'Cisse,Cissé', 46.6458300, 0.2287000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56005, 'Ciry-le-Noble', 'Ciry-le-Noble', 'Ciry,Ciry-le-Noble', 46.6060700, 4.2986900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56006, 'Cires-lès-Mello', 'Cires-les-Mello', 'Cires,Cires-les-Mello,Cires-lès-Mello,Sir le Melo,Sir-le-Mello,xi lei lai mo luo,Сир ле Мело,Сир-ле-Мелло,Сір-ле-Мелло,西雷莱默洛', 49.2724200, 2.3584000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56007, 'Cintré', 'Cintre', 'Cintre,Cintreium,Cintré,Kentreg,Sentre,sheng lei,Сентре,圣雷', 48.1050400, -1.8716200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56008, 'Cintegabelle', 'Cintegabelle', 'Cintegabelle,Senta Gabela,Senta Gabèla,Sentegabel,Sentegabel'',Sentgabel'',sheng jia bei er,Сентгабель,Сентегабел,Сентегабель,圣加贝尔', 43.3131600, 1.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56009, 'Cinqueux', 'Cinqueux', 'Cinqueux,Senke,Sinke,sang qu e,Сенке,Сінке,桑屈厄', 49.3173900, 2.5299700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56010, 'Cinq-Mars-la-Pile', 'Cinq-Mars-la-Pile', 'Cinq-Mars,Cinq-Mars-la-Pile', 47.3463800, 0.4587300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56011, 'Ciboure', 'Ciboure', 'Ciboro,Ciboure,Sibur,Ziburu,shiburu,sybwrh,xi bu er,Сибур,Сібур,سیبوره,シブール,锡布尔', 43.3828700, -1.6760000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56012, 'Chuzelles', 'Chuzelles', 'Chuzelles', 45.5848400, 4.8779500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56013, 'Chouzy-sur-Cisse', 'Chouzy-sur-Cisse', 'Chouzy,Chouzy-sur-Cisse', 47.5257600, 1.2466100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56014, 'Chouzé-sur-Loire', 'Chouze-sur-Loire', 'Chouze,Chouzé,Shuze na Loari,Shuze-sjur-Luar,lu wa er he pan shu ze,Шузе на Лоари,Шузе-сюр-Луар,卢瓦尔河畔舒泽', 47.2367300, 0.1236400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56015, 'Chorges', 'Chorges', 'Caturigomagus,Chaurjas,Chorces,Chorge,Chorges,Shorzh,shao er ri,Шорж,ሾርዥ,绍尔日', 44.5471000, 6.2775200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56016, 'Chomérac', 'Chomerac', 'Chaumairac,Chaumeirac,Chomerac,Chomérac,Shomerak,shao mei la ke,Шомерак,绍梅拉克', 44.7075200, 4.6616400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56017, 'Cholet', 'Cholet', 'CET,Cauletum,Shole,Sole,shao lai,shore,shwlh,shwlh  fransh,syolle,Šolė,Шоле,شوله,شوله، فرانسه,ショレ,紹萊,숄레', 47.0666700, -0.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56018, 'Choisy-le-Roi', 'Choisy-le-Roi', 'Choisy,Choisy-le-Roi,Choisy-sur-Seine,Shoazi le Roa,Shuazi-le-Rua,showaji=ru=rowa,shu wa xi lei lu wa,shwazy lw rwa,shwazy-lw-rwa,syuasileulua,Шоази ле Роа,Шуази-ле-Руа,Шуазі-ле-Руа,شوآزی لو روآ,شوآزی-لو-روآ,ショワジー＝ル＝ロワ,舒瓦西勒鲁瓦,슈아시르루아', 48.7684600, 2.4187400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56019, 'Choisy-en-Brie', 'Choisy-en-Brie', 'Choisy,Choisy-en-Brie', 48.7586700, 3.2170500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56020, 'Choisy-au-Bac', 'Choisy-au-Bac', 'Choisy,Shoazi o Bak,Shuazi-o-Bak,shu wa xi ao ba ke,Шоази о Бак,Шуази-о-Бак,Шуазі-о-Бак,舒瓦西奥巴克', 49.4377700, 2.8773900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56021, 'Choisy', 'Choisy', 'Choisy', 45.9930500, 6.0553500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56022, 'Choisey', 'Choisey', 'Choisey,Shoaze,Shuaze,shu wa sai,Шоазе,Шуазе,舒瓦塞', 47.0638900, 5.4591100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56023, 'Chocques', 'Chocques', 'Chocques,Choques', 50.5408400, 2.5719300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56024, 'Chitenay', 'Chitenay', 'Chitenay', 47.4975300, 1.3713900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56025, 'Chissay-en-Touraine', 'Chissay-en-Touraine', 'Chissay,Chissay-en-Touraine', 47.3374700, 1.1336200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56026, 'Chiry-Ourscamp', 'Chiry-Ourscamp', 'Chiry,Chiry-Ourscamp,Chiry-Ourscamps,Shiri Urkan,Shiri-Urskam,xi li wu er si kang,Шири Уркан,Ширі-Урскам,希里乌尔斯康', 49.5437800, 2.9472100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56027, 'Chirens', 'Chirens', 'Chirens,Shiran,Shiren,Shireng,xi lang,Ширан,Ширен,Ширенг,希朗', 45.4128000, 5.5570700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56028, 'Chirac', 'Chirac', 'Chirac', 44.5228900, 3.2665200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56029, 'Chinon', 'Chinon', 'Chinon,Chinon-sur-Vienne,Chinonium,Shinon,shinon,synwn,xi nong,Шинон,שינון,シノン,希农', 47.1666700, 0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56030, 'Chindrieux', 'Chindrieux', 'Chindrieux', 45.8213200, 5.8512200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56031, 'Chimilin', 'Chimilin', 'Chimilin', 45.5775300, 5.5981900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56032, 'Chilly-Mazarin', 'Chilly-Mazarin', 'Chilly-Mazarin', 48.7148900, 2.3163800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56033, 'Chilly', 'Chilly', 'Chilly', 45.9933200, 5.9533500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56034, 'Chilleurs-aux-Bois', 'Chilleurs-aux-Bois', 'Chilleurs,Chilleurs-aux-Bois', 48.0722000, 2.1354000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56035, 'Chierry', 'Chierry', 'Chierry', 49.0394000, 3.4297600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56036, 'Chiché', 'Chiche', 'Chiche,Chiché', 46.7964300, -0.3556000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56037, 'Chézy-sur-Marne', 'Chezy-sur-Marne', 'Chezy,Chezy-sur-Marne,Chézy,Chézy-sur-Marne,Shezi na Marni,Shezi-sjur-Marn,ma en he pan xie ji,Шези на Марни,Шези-сюр-Марн,Шезі-сюр-Марн,马恩河畔谢济', 48.9888100, 3.3678600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56038, 'Chézeaux', 'Chezeaux', 'Chezeaux,Chézeaux', 47.8767300, 5.6485100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56039, 'Chevry-Cossigny', 'Chevry-Cossigny', 'Chevry,Chevry-Cossigny,Shevri Kosini,Shevri-Kossin''i,Шеври Косињи,Шеври-Коссиньи,Шеврі-Коссіньї', 48.7246500, 2.6610600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56040, 'Chevry', 'Chevry', 'Chevry', 46.2785500, 6.0400800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56041, 'Chevrières', 'Chevrieres', 'Chevrieres,Chevrières', 49.3464500, 2.6821900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56042, 'Chevreuse', 'Chevreuse', 'Caprosia,Chevreuse,Shevrez,Shevrjoz,shuvuruzu,syubeuleujeu,Шеврез,Шеврёз,シュヴルーズ,슈브르즈', 48.7066200, 2.0332900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56043, 'Chèvremont', 'Chevremont', 'Chevremont,Chèvremont', 47.6282400, 6.9216400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56044, 'Chevilly-Larue', 'Chevilly-Larue', 'Chevilly,Chevilly-Larue,Shevii-Larju,Sheviji Lari,Shevil''i-Larju,xie wei li la lu e,Шевии-Ларю,Шевильи-Ларю,Шевији Лари,Шевії-Ларю,谢维利拉吕厄', 48.7647600, 2.3503000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56045, 'Chevilly', 'Chevilly', 'Chevilly', 48.0297300, 1.8740200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56046, 'Chevillon-sur-Huillard', 'Chevillon-sur-Huillard', 'Chevillon,Chevillon-sur-Huillard,Shevijon sir Ijar,Shevijon-sjur-Juijar,yu yi la er he pan xie wei long,Шевијон сир Ијар,Шевійон-сюр-Юіяр,于伊拉尔河畔谢维隆', 47.9619700, 2.6260100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56047, 'Chevillon', 'Chevillon', 'Chevillon', 48.5286900, 5.1308600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56048, 'Chevigny-Saint-Sauveur', 'Chevigny-Saint-Sauveur', 'Alpha,Chevigny,Chevigny-Saint-Sauveur,Chevigny-Sauveur,Shevin''i-Sen-Sover,Shevin''i-Sen-Sovjor,Shevini Sen Sover,shwyny-sn-swwr,xie wei ni sheng suo fu,Шевиньи-Сен-Совер,Шевиньи-Сен-Совёр,Шевињи Сен Совер,Шевіньї-Сен-Совер,شوینی-سن-سوور,谢维尼圣索弗', 47.2990800, 5.1336700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56049, 'Cheverny', 'Cheverny', 'Cheverny,Shaverni,Sheverni,shuvu~eruni,xie wei er ni,Шаверни,Шеверні,シュヴェルニー,谢韦尔尼', 47.5007900, 1.4595100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56050, 'Chevannes', 'Chevannes', 'Chevannes', 48.5325900, 2.4438800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56051, 'Chevanceaux', 'Chevanceaux', 'Chevanceaux,Shevanso,xie wang suo,Шевансо,谢旺索', 45.3000000, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56052, 'Cheval-Blanc', 'Cheval-Blanc', 'Blanc-Montagne,Cheval-Blanc,Lo Chivau Blanc,Sheval Blan,Sheval''-Blan,xie wa bu lang ke,Шевал Блан,Шеваль-Блан,谢瓦布朗克', 43.8018900, 5.0622900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56053, 'Chevaigné', 'Chevaigne', 'Chavegneium,Chevaigne,Chevaigné,Kavaneg,Sheven''e,Shevene,xie wei nie,Шевенье,Шевеньє,Шевење,谢韦涅', 48.2115300, -1.6293300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56054, 'Cheux', 'Cheux', 'Cheux', 49.1661100, -0.5254400, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56055, 'Chessy', 'Chessy', 'Chessy', 48.8833300, 2.7666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56056, 'Chessy', 'Chessy', 'Chessy', 45.8870700, 4.6236600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56057, 'Cherveux', 'Cherveux', 'Cherveux', 46.4154300, -0.3570600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56058, 'Cherrueix', 'Cherrueix', 'Cherrueix,Kerruer,Sherije,Sherrjue,xie er lu ai,Шерије,Шеррюе,谢尔吕埃', 48.6062900, -1.7040500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56059, 'Cherré', 'Cherre', '', 48.1729000, 0.6578100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56060, 'Chéroy', 'Cheroy', 'Cheroy,Chéroy', 48.2007600, 3.0001100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56061, 'Chermignac', 'Chermignac', 'Chermignac,Shermin''jak,Sherminak,xie er mi ni ya ke,Шерминьяк,Шермињак,Шерміньяк,谢尔米尼亚克', 45.6857800, -0.6734900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56062, 'Cherisy', 'Cherisy', 'Cherizy', 48.7500000, 1.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56063, 'Chéreng', 'Chereng', 'Chereng,Chéreng,Sheran,xie lang,Шеран,谢朗', 50.6105900, 3.2066600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56064, 'Cherbourg-Octeville', 'Cherbourg-Octeville', 'CER,Cherbourg,Cherburgo-Octeville,Coriallum,Gorad Shehrbur-Aktehvil'',Kiaeresburh,Kiæresburh,Serburq-Oktevil,Sermpour-Oktvil,Sherbur Oktevil,Sherbur-Oktevil'',Sherbur-Oktvil'',Tchidbouo,cerpork-aktvil,sairbura,se bao-ao ke te wei er,sheruburu=okutovu~iru,shrbwrg-aktwwyl,srbwr,syeleubuleuogteubil,Şerburq-Oktevil,Σερμπούρ-Οκτβίλ,Горад Шэрбур-Актэвіль,Шербур Октевил,Шербур-Октвиль,Шербур-Октевиль,Шербур-Октевіль,שרבור,شربورگ-اکتوویل,शैर्बूर,செர்போர்க்-ஆக்ட்வில்,シェルブール＝オクトヴィル,瑟堡-奥克特维尔,셰르부르옥트빌', 49.6398400, -1.6163600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56065, 'Chéraute', 'Cheraute', 'Cheraute,Chéraute,Sherauta,Sherot,Sohueta,Sohüta,xie luo te,Шерот,谢罗特', 43.2309600, -0.8683100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56066, 'Chérac', 'Cherac', 'Cherac,Chérac,Sherak,xie la ke,Шерак,谢拉克', 45.7045600, -0.4385900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56067, 'Chépy', 'Chepy', 'Chepy,Chpy,Chépy,Shepi,shupi,xie pi,Шепи,Шепі,シュピー,谢皮', 50.0636100, 1.6469400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56068, 'Cheptainville', 'Cheptainville', 'Cheptainville,Shatenvil,Sheptenvil'',xie pu tan wei er,Шатенвил,Шептенвиль,Шептенвіль,谢普坦维尔', 48.5509000, 2.2766500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56069, 'Cheny', 'Cheny', 'Cheny,Sheni,xie ni,Шени,Шені,谢尼', 47.9516600, 3.5334000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56070, 'Chens-sur-Léman', 'Chens-sur-Leman', 'Chens,Chens-sur-Leman,Chens-sur-Léman,Shan sir Leman,Shan-sjur-Leman,Шан сир Леман,Шан-сюр-Леман', 46.3290600, 6.2626700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56071, 'Chenôve', 'Chenove', 'Chenove,Chenôve', 47.2932300, 5.0045700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56072, 'Chenoise', 'Chenoise', 'Chenoise,Shenoaz,Shenuaz,Шеноаз,Шенуаз', 48.6146200, 3.1945900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56073, 'Chennevières-sur-Marne', 'Chennevieres-sur-Marne', 'Chennevieres,Chennevieres-sur-Marne,Chennevières,Chennevières-sur-Marne,Shanvjer si Marn,Shennv''er-sjur-Marn,Shennver-sjur-Marn,ma en he pan xie nei wei ai,Шанвјер си Марн,Шеннвьер-сюр-Марн,Шеннвєр-сюр-Марн,马恩河畔谢内维埃', 48.7970200, 2.5404600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56074, 'Cheniménil', 'Chenimenil', 'Chenimenil,Cheniménil,Shenimenij,xie ni mo ni,Шенимений,Шенимениј,Шеніменій,谢尼默尼', 48.1388000, 6.6034600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56075, 'Chênehutte-Trèves-Cunault', 'Chenehutte-Treves-Cunault', 'Chenehutte-les-Tuffeaux,Chênehutte-les-Tuffeaux,Shenit Trev Kino,Shenjutt-Trev-Kjuno,xie na te te lei wei qu nuo er,Шенит Трев Кино,Шенютт-Трев-Кюно,谢纳特特雷韦屈诺尔', 47.3108400, -0.1604200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56076, 'Chemillé-Melay', 'Chemille-Melay', 'Chemille,Chemillé,shumie=mure,シュミエ＝ムレ', 47.2147600, -0.7248800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56077, 'Chéméré', 'Chemere', 'Camariacus,Chemere,Chéméré,Keverieg,Shemere,xie mei lei,Шемере,谢梅雷', 47.1166700, -1.9166700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56078, 'Chemazé', 'Chemaze', 'Chemaze,Chemazé', 47.7869000, -0.7752300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56079, 'Chemaudin', 'Chemaudin', 'Chemaudin', 47.2239200, 5.8941900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56080, 'Chelles', 'Chelles', 'Chelles', 48.8810900, 2.5929500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56081, 'Cheillé', 'Cheille', 'Cheille,Cheillé', 47.2611400, 0.4055300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56082, 'Chef-Boutonne', 'Chef-Boutonne', 'Chef-Boutonne,Shef Buton,Shef-Butonn,xie fu bu tuo ne,Шеф Бутон,Шеф-Бутонн,謝夫布托訥', 46.1085900, -0.0708300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56083, 'Chécy', 'Checy', 'Checy,Checy-lez-Orleans,Chécy,Chécy-lez-Orléans,Shesi,xie xi,Шеси,Шесі,谢西', 47.8940200, 2.0230400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56084, 'Chazey-sur-Ain', 'Chazey-sur-Ain', 'Chazey', 45.8930000, 5.2535200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56085, 'Chazelles-sur-Lyon', 'Chazelles-sur-Lyon', 'Chazelles,Chazelles-la-Victoire,Chazelles-sur-Lyon,Shazel sir Lion,Shazel''-sjur-Lion,li weng he pan sha ze lai,Шазел сир Лион,Шазель-сюр-Ліон,利翁河畔沙泽莱', 45.6380600, 4.3913000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56086, 'Chazelles', 'Chazelles', 'Chazelles', 45.6471300, 0.3674800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56087, 'Chaville', 'Chaville', 'Cativilla,Chaville,Shavil,Shavil'',sha wei er,shavu~iru,Шавил,Шавиль,Шавіль,シャヴィル,沙维尔', 48.8056500, 2.1886400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56088, 'Chavigny', 'Chavigny', 'Chavigny', 48.6288700, 6.1259900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56089, 'Chavenay', 'Chavenay', 'Chavenay,Shavene,Shavne,Шавене,Шавне', 48.8543700, 1.9916300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56090, 'Chavelot', 'Chavelot', 'Chavelot', 48.2345900, 6.4380900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56091, 'Chavanoz', 'Chavanoz', 'Chavanoz,Shavano,Shavanoz,sha wa nuo,Шавано,Шаваноз,沙瓦诺', 45.7764300, 5.1703200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56092, 'Chavanod', 'Chavanod', 'Cavannodum,Chavanod,Chavanôd,Shavano,Шавано', 45.8896400, 6.0423500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56093, 'Chavanay', 'Chavanay', 'Chavanay', 45.4143700, 4.7315700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56094, 'Chavagnes-en-Paillers', 'Chavagnes-en-Paillers', 'Chavagnes,Chavagnes-en-Paillers,Shavan an Paje,Shavan''-an-Pae,pei lai er de qu sha wa ge,Шавань-ан-Пає,Шавањ ан Паје,佩莱尔地区沙瓦格', 46.8916700, -1.2521400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56095, 'Chavagne', 'Chavagne', 'Cavana,Chavagne,Kavan,Shavan,Shavan'',sha wa ni,Шавань,Шавањ,沙瓦尼', 48.0543800, -1.7857100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56096, 'Chauvigny', 'Chauvigny', 'Calviniacum,Chauvigny,Shovin''i,Shovini,shao wei ni,Шовињи,Шовіньї,绍维尼', 46.5674700, 0.6492800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56097, 'Chauvé', 'Chauve', 'Calva,Chauve,Chauvé,Haxo-les-Landes,Kalveg,Shove,shao wei,Шове,绍韦', 47.1517400, -1.9848900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56098, 'Chaussin', 'Chaussin', 'Chaussin,Shosen,Shossen,shao sang,Шосен,Шоссен,绍桑', 46.9661200, 5.4079100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56099, 'Chauriat', 'Chauriat', 'Chauriat', 45.7515200, 3.2794600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56100, 'Chauray', 'Chauray', 'Chauray,Chaurraium,Shore,Шоре', 46.3599700, -0.3785900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56101, 'Chauny', 'Chauny', 'Chauny,Shoni,shao ni,Шони,Шоні,绍尼', 49.6151400, 3.2185700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56102, 'Chaunay', 'Chaunay', 'Chaunay,Shone,shao nai,Шоне,绍奈', 46.2075900, 0.1608400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56103, 'Chaumont-sur-Tharonne', 'Chaumont-sur-Tharonne', 'Chaumont,Chaumont-sur-Tharonne,Shomon sir Taron,Shomon-sjur-Taronn,ta luo ne he pan shao meng,Шомон сир Тарон,Шомон-сюр-Таронн,塔罗讷河畔绍蒙', 47.6103900, 1.9051400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56104, 'Chaumont-sur-Loire', 'Chaumont-sur-Loire', 'Chaumont,Chaumont-sur-Loire,Shomon na Loari,Shomon-sjur-Luar,lu wa er he pan shao meng,shomon=shuru=rowaru,Шомон на Лоари,Шомон-сюр-Луар,ショーモン＝シュル＝ロワール,卢瓦尔河畔绍蒙', 47.4810800, 1.1892900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56105, 'Chaumont-en-Vexin', 'Chaumont-en-Vexin', 'Chaumont,Chaumont-en-Vexin,Shomon-an-Veksen,Shomont an Veksen,Shomont-an-Veksen,wei ke sang de qu shao meng,Шомон-ан-Вексен,Шомонт ан Вексен,Шомонт-ан-Вексен,韦克桑地区绍蒙', 49.2659500, 1.8859700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56106, 'Chaumontel', 'Chaumontel', 'Chaumontel,Shomontel,Shomontel'',shao meng te er,Шомонтел,Шомонтель,绍蒙特尔', 49.1247000, 2.4323700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56107, 'Chaumont', 'Chaumont', 'Chaumant,Chaumont,Chaumont Enbassigby,Chaumont-en-Bassigny,Shomon,XCW,shomon,Шомон,ショーモン', 48.1112100, 5.1413400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56108, 'Chaumes-en-Brie', 'Chaumes-en-Brie', 'Chaumes,Chaumes-en-Brie', 48.6685300, 2.8401500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56109, 'Chaulnes', 'Chaulnes', 'Chaulnes,Chonne,Shol''n,Sholn,shao ne,Шолн,Шольн,绍讷', 49.8169900, 2.8006400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56110, 'Chaulgnes', 'Chaulgnes', 'Chaulgnes', 47.1288900, 3.1034800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56111, 'Chauffailles', 'Chauffailles', 'Chauffailles,Shofaj,Shoffaj,Шофај,Шоффай', 46.2072600, 4.3393200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56112, 'Chaudron-en-Mauges', 'Chaudron-en-Mauges', 'Chaudron,Chaudron-en-Mauges,Shodron an Mozh,Shodron-an-Mozh,mo re de qu shao de long,Шодрон ан Мож,Шодрон-ан-Мож,莫热地区绍德龙', 47.2880900, -0.9854700, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56113, 'Chaudon', 'Chaudon', 'Chaudon', 48.6627600, 1.4967000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56114, 'Chaudes-Aigues', 'Chaudes-Aigues', 'Chaldasaigas,Chaudes-Aigues,Shod-Eg,Shodez Eg,Shodz-Ehg,shao dai ai gai,shodo=zegu,Шод-Ег,Шодез Ег,Шодз-Эг,ショード＝ゼーグ,绍代艾盖', 44.8534400, 3.0036400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56115, 'Chauconin-Neufmontiers', 'Chauconin-Neufmontiers', 'Shokonen Nefmontje,Shokonen-Nefmont''e,Шоконен Нефмонтје,Шоконен-Нефмонтье,Шоконен-Нефмонтьє', 48.9666700, 2.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56116, 'Chauché', 'Chauche', 'Chauche,Chauché', 46.8296300, -1.2717800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56117, 'Chatuzange-le-Goubet', 'Chatuzange-le-Goubet', 'Chatuzange,Chatuzange-le-Goubet', 45.0013800, 5.0870000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56118, 'Chatte', 'Chatte', 'Chatte', 45.1431000, 5.2844100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56119, 'Châtres-sur-Cher', 'Chatres-sur-Cher', 'Chatres,Chatres-sur-Cher,Chátres,Châtres-sur-Cher,Shatr sir Sher,Shatr-sjur-Sher,xie he pan sha te lei,Шатр сир Шер,Шатр-сюр-Шер,谢河畔沙特雷', 47.2650500, 1.9059100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56120, 'Chatou', 'Chatou', 'Chatou,Shatu,shato~u,shtw,syatu,Шату,شتو,シャトゥー,샤투', 48.8898000, 2.1586300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56121, 'Châtonnay', 'Chatonnay', 'Chatonnay,Châtonnay', 45.4869900, 5.2036800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56122, 'Châtillon-sur-Thouet', 'Chatillon-sur-Thouet', 'Chatillon,Chatillon-sur-Thouet,Châtillon,Châtillon-sur-Thouet', 46.6617600, -0.2348900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56123, 'Châtillon-sur-Seine', 'Chatillon-sur-Seine', 'Castillonum ad Sequanam,Chatillon,Chatillon-sur-Seine,Châtillon,Châtillon-sur-Seine,Shatijon na Seni,Shatijon-sjur-Sen,sai na he pan sha di long,shatiyon=shuru=senu,Шатийон-сюр-Сен,Шатијон на Сени,Шатійон-сюр-Сен,シャティヨン＝シュル＝セーヌ,塞纳河畔沙蒂隆', 47.8585100, 4.5737500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56124, 'Châtillon-sur-Seiche', 'Chatillon-sur-Seiche', 'Chatillon,Chatillon-sur-Seiche,Châtillon-sur-Seiche', 48.0344800, -1.6711400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56125, 'Châtillon-sur-Marne', 'Chatillon-sur-Marne', 'Chatillon,Chatillon-sur-Marna,Chatillon-sur-Marne,Châtillon,Châtillon-sur-Marne,Montagne-sur-Marne,Shatijon na Marni,Shatijon-sjur-Marn,ma en he pan sha di long,Шатијон на Марни,Шатійон-сюр-Марн,马恩河畔沙蒂隆', 49.1004800, 3.7602300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56126, 'Châtillon-sur-Indre', 'Chatillon-sur-Indre', 'Chatillon,Chatillon-sur-Indre,Châtillon,Châtillon-sur-Indre,Indremont,Shatijon sir Endr,Shatijon-sjur-Ehndr,Shatijon-sjur-Endr,an de er he pan sha di long,Шатийон-сюр-Эндр,Шатијон сир Ендр,Шатійон-сюр-Ендр,安德尔河畔沙蒂隆', 46.9873500, 1.1721800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56127, 'Châtillon-sur-Cluses', 'Chatillon-sur-Cluses', 'Castellio Fulciniacorum,Chatillon,Chatillon-sur-Cluses,Châtillon-sur-Cluses,Shatijon sir Kliz,Shatijon-sjur-Kljuz,Шатијон сир Клиз,Шатійон-сюр-Клюз', 46.0910800, 6.5868900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56128, 'Châtillon-sur-Cher', 'Chatillon-sur-Cher', 'Chatillon,Chatillon-sur-Cher,Châtillon,Châtillon-sur-Cher', 47.2757100, 1.4942400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56129, 'Châtillon-sur-Chalaronne', 'Chatillon-sur-Chalaronne', 'Chatillon,Chatillon-sur-Chalaronne,Châtillon,Châtillon-sur-Chalaronne,Satiyon syur Salaron,Shatijon sir Shalaron,Shatijon-sjur-Shalaron,Shatijon-sjur-Shalaronn,sha la long en he pan sha di li weng,shatylwn-swr-shalarwn,Шатийон-сюр-Шаларон,Шатијон сир Шаларон,Шатійон-сюр-Шаларонн,Շատիյոն սյուր Շալարոն,شاتيلون-سور-شالارون,沙拉龙恩河畔沙蒂利翁', 46.1201900, 4.9581700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56130, 'Châtillon-le-Duc', 'Chatillon-le-Duc', 'Chatillon,Chatillon-le-Duc,Châtillon,Châtillon-le-Duc,Commune-du-Bellevue', 47.3048600, 6.0079200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56131, 'Châtillon-la-Palud', 'Chatillon-la-Palud', 'Chatillon,Chatillon-la-Palud,Châtillon-la-Palud', 45.9747300, 5.2479900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56132, 'Châtillon-en-Vendelais', 'Chatillon-en-Vendelais', 'Chatillon,Chatillon-en-Vendelais,Châtillon,Châtillon-en-Vendelais,Kastellan-Gwennel,Shatijon an Vendele,Shatijon-an-Vandele,wang dai lai de qu sha di long,Шатийон-ан-Ванделе,Шатијон ан Венделе,Шатійон-ан-Ванделе,旺代莱地区沙蒂隆', 48.2240900, -1.1769500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56133, 'Châtillon-en-Bazois', 'Chatillon-en-Bazois', 'Chatillon,Chatillon-en-Bazois,Chatillon-sur-Aron,Châtillon,Châtillon-en-Bazois,Châtillon-sur-Aron', 47.0546400, 3.6589300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56134, 'Châtillon-en-Michaille', 'Chatillon-en-Michaille', 'Chatillon,Chatillon en Michaille,Châtillon,Shatijon an Mishaj,Shatijon-an-Mishaj,mi sha yi de qu sha di li weng,shatylwn-awn-myshyl  ayn,Шатийон-ан-Мишай,Шатијон ан Мишај,Шатійон-ан-Мішай,شاتيلون-أون-ميشيل، أين,米沙伊地区沙蒂利翁', 46.1432000, 5.7995000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56135, 'Châtillon', 'Chatillon', 'Chatillon-d''Azergues,Châtillon-d''Azergues', 45.8833300, 4.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56136, 'Châtillon-Coligny', 'Chatillon-Coligny', 'Chatillon-Coligny,Châtillon-Coligny,Shatijon Kolini,Shatijon-Kolin''i,sha di long ke li ni,Шатийон-Колиньи,Шатијон Колињи,Шатійон-Коліньї,沙蒂隆科利尼', 47.8226600, 2.8456300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56137, 'Châtillon', 'Chatillon', 'Chatillon,Chatillon-sous-Bagneux,Châtillon,Châtillon-sous-Bagneux,Fort Chatillon,Fort Châtillon,Montagne-l''Union', 48.8024000, 2.2934600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56138, 'Châtillon', 'Chatillon', '', 45.8009100, 5.8435200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56139, 'Châtenoy-le-Royal', 'Chatenoy-le-Royal', 'Chatenoy,Chatenoy-le-National,Chatenoy-le-Royal,Châtenoy,Châtenoy-le-National,Châtenoy-le-Royal,Shatenua-le-Ruajal'',Shatnoa le Roajal,Шатенуа-ле-Руаяль,Шатноа ле Роајал', 46.7979700, 4.8119000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56140, 'Châtenois-les-Forges', 'Chatenois-les-Forges', 'Chatenois,Chatenois-les-Forges,Châtenois,Châtenois-les-Forges', 47.5598000, 6.8489400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56141, 'Châtenois', 'Chatenois', 'Chatenois,Châtenois', 48.3028600, 5.8312500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56142, 'Châtenois', 'Chatenois', 'Chatenois,Châtenois,Kestenholz', 48.2718800, 7.3992700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56143, 'Châtenay-sur-Seine', 'Chatenay-sur-Seine', 'Chatenay,Chatenay-sur-Seine,Châtenay-sur-Seine', 48.4183900, 3.0947400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56144, 'Châtenay-Malabry', 'Chatenay-Malabry', 'Chatenay,Chatenay-Malabry,Chatenay-la-Montagne,Chatenay-les-Bagneux,Châtenay,Châtenay-Malabry,Châtenay-la-Montagne,Châtenay-lès-Bagneux,Shatne Malabri,Shatne-Malabri,sha te nai ma la bu li,shatnh-mlbry,shatone=maraburi,shtwny mlbry,syateunemallabeuli,Шатне Малабри,Шатне-Малабри,Шатне-Малабрі,شاتنه-ملبری,شتونی ملبری,シャトネ＝マラブリー,沙特奈马拉布里,샤트네말라브리', 48.7650700, 2.2665500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56145, 'Châtel-sur-Moselle', 'Chatel-sur-Moselle', 'Chatel,Chatel-sur-Moselle,Châtel,Châtel-sur-Moselle,Durbion-Moselle,Shatel''-sjur-Mozel'',mo ze er he pan sha te,Шатель-сюр-Мозель,摩泽尔河畔沙特', 48.3143000, 6.3940300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56146, 'Châtel-Saint-Germain', 'Chatel-Saint-Germain', 'Chatel,Chatel-Saint-Germain,Châtel,Châtel-Saint-Germain,Shatel Sen Zhermen,Shatel''-Sen-Zhermen,sha tai sheng ri er man,shatl-sn-zhrmn,Шател Сен Жермен,Шатель-Сен-Жермен,شاتل-سن-ژرمن,沙泰圣日尔曼', 49.1229000, 6.0800100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56147, 'Châtellerault', 'Chatellerault', 'Castrum Heraldi,Chatellerault,Châtellerault,Shatel''ro,Shatelro,sha tai lei luo,shateruro,shth lwrw,syatello,Шателро,Шательро,شته لورو,シャテルロー,沙泰勒罗,샤텔로', 46.8000000, 0.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56148, 'Châtel-Guyon', 'Chatel-Guyon', 'Chatel Guyon,Chatel-Guyon les Bains,Chatelguyon,Châtelguyon', 45.9166700, 3.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56149, 'Châtelaillon-Plage', 'Chatelaillon-Plage', 'Chatelaillon,Chatelaillon-Plage,Châtelaillon,Châtelaillon-Plage,Les Sablons,Shatelajon-Plazh,Shatlajon-Plazh,sha tai lai long pu la ge,Шателайон-Плаж,Шатлайон-Плаж,沙泰莱隆普拉格', 46.0719000, -1.0892600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56150, 'Châtel', 'Chatel', 'Chatel,Châtel', 46.2665800, 6.8422900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56151, 'Châteauvillain', 'Chateauvillain', 'Chateauvillain,Châteauvillain,Commune-sur-Aujon,Shatovilen,Shatovillen,Ville-sur-Aujon,sha tuo wei lan,Шатовилен,Шатовіллен,沙托维兰', 48.0365500, 4.9182300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56152, 'Château-Thierry', 'Chateau-Thierry', 'Castrum Theodorici,Chateau-Egalite,Chateau-Thierry,Château-Egalité,Château-Thierry,Egalite-sur-Marne,Egalité-sur-Marne,Faubourg-du-Puits-d''Amour,Puits-d''Amour,Shato Tieri,Shato Tjeri,Shato-T''erri,chataw-thyry,di ye li bao,shato=tieri,syatotieli,Шато Тиери,Шато Тјери,Шато-Тьерри,Шато-Тьєррі,شتو تھیری,چاتاو-تهیری,シャトー＝ティエリ,蒂耶里堡,샤토티에리', 49.0500000, 3.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56153, 'Château-Salins', 'Chateau-Salins', 'Chateau-Salins,Saline-Libre,Salzburgen,Shato Salen,Shato-Salen,sha tuo sa lan,shato=saran,Шато Сален,Шато-Сален,シャトー＝サラン,沙托萨兰', 48.8188500, 6.5145500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56154, 'Châteauroux', 'Chateauroux', 'CHR,Castrum Radulphi,Chateauroux,Châteauroux,Gorad Shataru,Indrelibre,Indreville,Satoru,Shatoru,sha tuo lu,shatoru,shatwrw,shtwrw,syatolu,Šatoru,Горад Шатару,Шатору,שאטורו,شاتورو,شتورو,シャトールー,沙托鲁,샤토루', 46.8166700, 1.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56155, 'Château-Renault', 'Chateau-Renault', 'Chateau-Renault,Château-Renault,Mont-Braine', 47.5918800, 0.9114300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56156, 'Châteaurenard', 'Chateaurenard', 'Casteu-rainard,Casteurainard,Castèu-rainard,Castèurainard,Chateaurenard,Chateaurenard-Provence,Châteaurenard,Châteaurenard-Provence,Mont-Renard,Shatorenar,sha tuo lei na er,Шаторенар,沙托雷纳尔', 43.8816900, 4.8549300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56157, 'Château-Porcien', 'Chateau-Porcien', 'Chateau-Porcien,Château-Porcien,Marat-Fruvaine,Marat-sur-Aisne,Sato-Porsian,Shato Porsjen,Shato-Pors''en,Shato-Pors''jan,bo er xi an bao,Σατώ-Πορσιάν,Шато Порсјен,Шато-Порсьен,Шато-Порсьян,波尔西安堡', 49.5274000, 4.2453300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56158, 'Châteauponsac', 'Chateauponsac', 'Chastel,Chastelponcac,Chastelponçac,Chateauponsac,Châteauponsac,Ponsac-la-Montagne,Shatoponsak,sha tuo peng sa ke,Шатопонсак,沙托蓬萨克', 46.1353600, 1.2762300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56159, 'Châteauneuf-sur-Sarthe', 'Chateauneuf-sur-Sarthe', 'Chateauneuf,Chateauneuf-sur-Sarthe,Châteauneuf,Châteauneuf-sur-Sarthe,Mont-Sarthe,Shatonef sir Sart,Shatonef-sjur-Sart,sa er te he pan sha tuo na,Шатонеф сир Сарт,Шатонеф-сюр-Сарт,萨尔特河畔沙托纳', 47.6814500, -0.4865200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56160, 'Châteauneuf-sur-Loire', 'Chateauneuf-sur-Loire', 'Chateauneuf,Chateauneuf-sur-Loire,Châteauneuf,Châteauneuf-sur-Loire,Shatonef na Loari,Shatonef-sjur-Luar,lu wa er he pan xin bao,Шатонеф на Лоари,Шатонеф-сюр-Луар,卢瓦尔河畔新堡', 47.8657500, 2.2190300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56161, 'Châteauneuf-sur-Cher', 'Chateauneuf-sur-Cher', 'Chateauneuf,Chateauneuf-sur-Cher,Châteauneuf,Châteauneuf-sur-Cher,Montagne-sur-Cher', 46.8577800, 2.3171000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56162, 'Châteauneuf-sur-Charente', 'Chateauneuf-sur-Charente', 'Chateauneuf,Chateauneuf-sur-Charente,Châteauneuf,Châteauneuf-sur-Charente,Shatonef sir Sharant,Shatonef-sjur-Sharant,Shatonjof-sjur-Sharant,Val-Charente,sha lang te he pan sha tuo na,Шатонеф сир Шарант,Шатонеф-сюр-Шарант,Шатонёф-сюр-Шарант,沙朗特河畔沙托纳', 45.6000000, -0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56163, 'Châteauneuf-les-Martigues', 'Chateauneuf-les-Martigues', 'Casteunou dau Martegue,Castèunòu dau Martegue,Chateauneuf,Châteauneuf,Shatonef le Martig,Shatonef-le-Martig,Shatonjof-le-Martig,sha tuo na lai ma er di gai,Шатонеф ле Мартиг,Шатонеф-ле-Мартіг,Шатонёф-ле-Мартиг,沙托纳莱马尔蒂盖', 43.3833300, 5.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56164, 'Châteauneuf-le-Rouge', 'Chateauneuf-le-Rouge', 'Casteunou lo Roge,Castèunòu lo Roge,Chateauneuf,Chateauneuf-le-Rouge,Châteauneuf,Châteauneuf-le-Rouge,La Galiniere-Negrel,La Galinière-Négrel,Negrel,Shatonef la Ruzh,Shatonef-le-Ruzh,Shatonjof-le-Ruzh,lei lu re xin bao,Шатонеф ла Руж,Шатонеф-ле-Руж,Шатонёф-ле-Руж,勒鲁热新堡', 43.4893600, 5.5692100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56165, 'Châteauneuf-la-Forêt', 'Chateauneuf-la-Foret', 'Chasteu Nuou,Chasteu Nuòu,Chasteunuou,Chasteunuòu,Chateauneuf,Chateauneuf-la-Foret,Châteauneuf,Châteauneuf-la-Forêt,Mont-Combade,Shatonef la Fore,Shatonef-la-Fore,sha tuo na la fu lei,Шатонеф ла Форе,Шатонеф-ла-Форе,沙托纳拉福雷', 45.7143600, 1.6061000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56166, 'Châteauneuf-en-Thymerais', 'Chateauneuf-en-Thymerais', 'Chateauneuf,Chateauneuf-en Thimerais,Chateauneuf-en-Thymerais,Châteauneuf-en Thimerais,Châteauneuf-en-Thymerais,Puits-la-Montagne,Shatonef an Timere,Shatonef-an-Timere,di mo lai de qu sha tuo na,Шатонеф ан Тимере,Шатонеф-ан-Тімере,蒂默赖地区沙托纳', 48.5811200, 1.2408500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56167, 'Châteauneuf-du-Rhône', 'Chateauneuf-du-Rhone', 'Bourg-le-Rhone,Bourg-le-Rhône,Chastelnou de Rose,Chastelnou del Rose,Chastelnòu de Ròse,Chastelnòu del Ròse,Chateauneuf,Chateauneuf-du-Rhone,Châteauneuf,Châteauneuf-du-Rhône,Shatonef di Ron,Shatonef-dju-Ron,sha tuo na di long,Шатонеф ди Рон,Шатонеф-дю-Рон,沙托纳迪龙', 44.4877900, 4.7175900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56168, 'Châteauneuf-du-Pape', 'Chateauneuf-du-Pape', 'Casteunou dau Papa,Casteunou de Papa,Castèunòu dau Papa,Castèunòu de Papa,Chateauneuf,Chateauneuf-du-Pape,Châteauneuf,Châteauneuf-du-Pape,Shatonef di Pap,Shatonef-dju-Pap,Shatonjof-dju-Pap,sha tuo na di pa pu,shatonufu=de~yu=papu,Шатонеф ди Пап,Шатонеф-дю-Пап,Шатонёф-дю-Пап,シャトーヌフ＝デュ＝パプ,沙托纳迪帕普', 44.0563800, 4.8324400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56169, 'Châteauneuf-du-Faou', 'Chateauneuf-du-Faou', 'Chateauneuf,Chateauneuf-du-Faou,Châteauneuf,Châteauneuf-du-Faou,Kastell-Nevez-ar-Faou,Mont-sur-Aulne,Shatonef di Fau,Shatonef-dju-Fau,sha tuo na di fu,shatonufu=de~yu=fu,Шатонеф ди Фау,Шатонеф-дю-Фау,シャトーヌフ＝デュ＝フー,沙托纳迪福', 48.1875500, -3.8178900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56170, 'Châteauneuf-sur-Isère', 'Chateauneuf-sur-Isere', 'Chateauneuf,Chateauneuf-de-l''Isere,Châteauneuf,Châteauneuf-de-l''Isère', 45.0166700, 4.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56171, 'Châteauneuf-de-Galaure', 'Chateauneuf-de-Galaure', 'Chateauneuf,Chateauneuf-de-Galaure,Châteauneuf,Châteauneuf-de-Galaure,Mivalon-de-Galaure,Shatonef de Galor,Shatonef-de-Galor,sha tuo na de jia luo er,Шатонеф де Галор,Шатонеф-де-Галор,沙托纳德加洛尔', 45.2309600, 4.9568000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56172, 'Châteauneuf-de-Gadagne', 'Chateauneuf-de-Gadagne', 'Casteunou de Gadanha,Castèunòu de Gadanha,Chateauneuf,Chateauneuf-de-Gadagne,Châteauneuf,Châteauneuf-de-Gadagne,Gadanha,Shatonef de Gadan,Shatonef-de-Gadan'',Shatonjof-de-Gadan'',sha tuo na de jia da ge,Шатонеф де Гадањ,Шатонеф-де-Гадань,Шатонёф-де-Гадань,沙托纳德加达格', 43.9268300, 4.9445300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56173, 'Châteauneuf', 'Chateauneuf', '', 45.5245700, 4.6404400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56174, 'Châteauneuf-Grasse', 'Chateauneuf-Grasse', 'Casteunou de Grassa,Castèunòu de Grassa,Chateauneuf de Grasse,Chateauneuf-le-Pre-du-Lac,Châteauneuf-le-Pre-du-Lac,Shatonef Gras,Shatonef-Grass,Shatonjof-Gras,sha tuo na ge la si,shatonufu=gurasu,tshatyawnywf jras,Шатонеф Грас,Шатонеф-Грасс,Шатонёф-Грас,تشاتياونيوف جراس,シャトーヌフ＝グラース,沙托纳格拉斯', 43.6666700, 6.9833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56175, 'Châteaumeillant', 'Chateaumeillant', 'Chastelmelhan,Chastèlmelhan,Chateaumeillant,Châteaumeillant,Shatomejan,Tell-le-Grand,sha tuo mei lang,Шатомейан,Шатомеян,Шатомејан,沙托梅朗', 46.5621900, 2.1951500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56176, 'Châteaulin', 'Chateaulin', 'Castrolinum,Chateaulin,Châteaulin,Cite-sur-Aon,Cité-sur-Aôn,Kastellin,Montagne-sur-Aon,Montagne-sur-Aôn,Shatolen,Ville-sur-Aone,Ville-sur-Aône,sha tuo lan,shatoran,Шатолен,シャトーラン,沙托兰', 48.2000000, -4.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56177, 'Château-la-Vallière', 'Chateau-la-Valliere', 'Chateau-la-Valliere,Château-la-Vallière,Val-Joyeux', 47.5466500, 0.3245800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56178, 'Château-Landon', 'Chateau-Landon', 'Chateau-Landon,Château-Landon,Shato Landon,Shato-Landon,Шато Ландон,Шато-Ландон', 48.1472100, 2.6975400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56179, 'Château-Guibert', 'Chateau-Guibert', 'Chateau-Guibert,Château-Guibert,Fond-Guibert,Shato Giber,Shato-Giber,sha tuo ju yi bei er,Шато Гибер,Шато-Гібер,沙托居伊贝尔', 46.5811000, -1.2365600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56180, 'Château-Gontier', 'Chateau-Gontier', 'Castrum Gontherii,Mont-Hardi,Shato Gontje,Shato-Gont''e,sha tuo gong di ye,shato=gontie,Шато Гонтје,Шато-Гонтьє,シャトー＝ゴンティエ,沙托贡蒂耶', 47.8333300, -0.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56181, 'Châteaugiron', 'Chateaugiron', 'Chateaugiron,Châteaugiron,Kastell-Geron,Mont-Giron', 48.0462900, -1.5043800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56182, 'Châteaugay', 'Chateaugay', 'Bel-Air,Chasteugai,Chateaugay,Châteaugay,Shatoge,sha tuo gai,shatoge,Шатоге,シャトゲ,沙托盖', 45.8513400, 3.0897200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56183, 'Château-Gaillard', 'Chateau-Gaillard', 'Chateau,Chateau-Gaillard,Château-Gaillard', 45.9735900, 5.3067300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56184, 'Châteaufort', 'Chateaufort', 'Chateaufort,Châteaufort', 48.7358400, 2.0905400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56185, 'Châteaudun', 'Chateaudun', 'Castrodunum,Chateaudun,Châteaudun,Dun-sur-Loir,Shatoden,Shatodjon,sha tuo dan,shatodan,syatodeong,Шатоден,Шатодён,シャトーダン,沙托丹,샤토덩', 48.0833300, 1.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56186, 'Château-du-Loir', 'Chateau-du-Loir', 'Castrum ad Iaedum,Chateau-du-Loir,Château-du-Loir,Mont-du-Loir,Mont-sur-Loir,Shato di Loar,Shato-dju-Luar,Vau-du-Loir,Шато ди Лоар,Шато-дю-Луар', 47.6949200, 0.4185100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56187, 'Château-d’Olonne', 'Chateau-d''Olonne', 'Beau-Sejour,Beau-Séjour,Chateau-d''Olonne,Château-d’Olonne', 46.5038200, -1.7409700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56188, 'Château-Chinon(Ville)', 'Chateau-Chinon(Ville)', 'Chateau-Chinon,Chateau-Chinon-Ville,Chinon-la-Montagne,Château-Chinon,Château-Chinon-Ville', 47.0666700, 3.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56189, 'Châteaubriant', 'Chateaubriant', 'Castrum Brientii,Chateaubriant,Châteaubriant,Kastell-Briant,Montagne-sur-Chere,Montagne-sur-Chère,Satomprian,Shatobrian,Shatobrijan,sha tuo bu li ang,shatoburian,syatobeuliang,Σατωμπριάν,Шатобриан,Шатобријан,Шатобріан,シャトーブリアン,沙托布里昂,샤토브리앙', 47.7166700, -1.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56190, 'Châteaubourg', 'Chateaubourg', 'Chateaubourg,Châteaubourg,Kastell-Bourc''h', 48.1111900, -1.4001900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56191, 'Châteaubernard', 'Chateaubernard', 'Chateaubernard,Châteaubernard,Shatobernar,sha tuo bei er na er,shatwbrnar,Шатобернар,شاتوبرنار,沙托贝尔纳尔', 45.6666700, -0.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56192, 'Chassors', 'Chassors', 'Chassors,Shasor,Shassor,sha suo er,Шасор,Шассор,沙索尔', 45.7000000, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56193, 'Chassieu', 'Chassieu', 'Shas''e,Shasje,Шасьє,Шасје', 45.7458400, 4.9708800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56194, 'Chasse-sur-Rhône', 'Chasse-sur-Rhone', 'Chasse,Chasse sobre Rodano,Chasse-sur-Rhone,Chasse-sur-Rhône,Shas sir Ron,Shas-sjur-Ron,Shass-sjur-Ron,luo ne he pan sha si,Шас сир Рон,Шас-сюр-Рон,Шасс-сюр-Рон,罗讷河畔沙斯', 45.5833900, 4.7982300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56195, 'Chasseneuil-du-Poitou', 'Chasseneuil-du-Poitou', 'Chasseneuil,Chasseneuil-du-Poitou', 46.6511200, 0.3732900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56196, 'Chasseneuil-sur-Bonnieure', 'Chasseneuil-sur-Bonnieure', 'Chassanuelh,Shasnej sir Bonijer,Shasnjoj-sjur-Bon''jor,Shassnej-sjur-Bon''er,bo nie yu er he pan sha se na yi,Шаснеј сир Бонијер,Шаснёй-сюр-Боньёр,Шассней-сюр-Боньєр,博涅于尔河畔沙瑟纳伊', 45.8166700, 0.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56197, 'Chasselay', 'Chasselay', 'Chasselay', 45.8752400, 4.7734000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56198, 'Chassagny', 'Chassagny', 'Chassagny,Shasani,Shassan''i,Шасањи,Шассаньї', 45.6067000, 4.7321400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56199, 'Chasné-sur-Illet', 'Chasne-sur-Illet', 'Chasne,Chasne-sur-Illet,Chasné,Chasné-sur-Illet,Kadeneg', 48.2424700, -1.5613800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56200, 'Charvieu-Chavagneux', 'Charvieu-Chavagneux', '', 45.7500000, 5.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56201, 'Chartrettes', 'Chartrettes', 'Chartrettes,Shartret,Shartrett,Шартрет,Шартретт', 48.4880800, 2.7008300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56202, 'Chartres-de-Bretagne', 'Chartres-de-Bretagne', 'Carceres,Chartres,Chartres-de-Bretagne,Karnod,Shartr de Bretan,Shartr-de-Bretan'',sha er te lei de bu lei ta ni,Шартр де Бретањ,Шартр-де-Бретань,沙尔特雷德布雷塔尼', 48.0392400, -1.7053300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56203, 'Chartres', 'Chartres', 'Carnotes,Chartres,Chartrez,Gorad Shartr,QTJ,Sartr,Sartra,Sartras,Shartr,Shartur,cha thr,sha te er,shartr,sharutoru,syaleuteuleu,Şartr,Šartra,Šartras,Σαρτρ,Горад Шартр,Шартр,Шартър,Շարտր,שארטר,شارتر,ชาทร์,შარტრი,ሻርትረ,シャルトル,沙特尔,샤르트르', 48.4468500, 1.4892500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56204, 'Chars', 'Chars', 'Chars,Shar,sha er si,Шар,沙尔斯', 49.1603200, 1.9366900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56205, 'Charroux', 'Charroux', 'Charroux', 46.1441000, 0.4035400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56206, 'Charron', 'Charron', 'Charron', 46.2943300, -1.1057200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56207, 'Charquemont', 'Charquemont', 'Charquemont', 47.2141700, 6.8198000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56208, 'Chârost', 'Charost', 'Charost,Chârost,Sharo,sha luo si,Шаро,沙罗斯', 46.9939000, 2.1163900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56209, 'Charolles', 'Charolles', 'Charolles,Quadrigellae,Sharol,Sharol'',sha luo lei,sharoru,sharwl,Шарол,Шароль,شارول,シャロル,沙罗勒', 46.4333300, 4.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56210, 'Charny', 'Charny', 'Charny', 48.9709800, 2.7612100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56211, 'Charny', 'Charny', 'Charny', 47.8866100, 3.0958300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56212, 'Charnècles', 'Charnecles', 'Charnecles,Charnècles', 45.3446700, 5.5259500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56213, 'Charnay-lès-Mâcon', 'Charnay-les-Macon', 'Charnay,Charnay-les-Macon,Charnay-lès-Mâcon,Sharne le Makon,Sharne-le-Makon,Шарне ле Макон,Шарне-ле-Макон', 46.3075100, 4.7847900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56214, 'Charnay', 'Charnay', 'Charnay', 45.8911200, 4.6680100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56215, 'Charmes-sur-Rhône', 'Charmes-sur-Rhone', 'Charmes,Charmes-sur-Rhone,Charmes-sur-Rhône', 44.8639300, 4.8403900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56216, 'Charmes', 'Charmes', 'Charmes', 49.6534500, 3.3785700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56217, 'Charmes', 'Charmes', 'Charmes', 48.3722000, 6.2911700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56218, 'Charly-sur-Marne', 'Charly-sur-Marne', 'Charly,Charly-sur-Marne,Sharli na Marni,Sharli-sjur-Marn,ma en he pan sha er li,Шарли на Марни,Шарли-сюр-Марн,Шарлі-сюр-Марн,马恩河畔沙尔利', 48.9774900, 3.2846400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56219, 'Charly', 'Charly', 'Charly', 45.6525500, 4.7961000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56220, 'Charlieu', 'Charlieu', 'Charlieu,Sharl''e,Sharlije,sha er li e,Шарлије,Шарльє,沙尔利厄', 46.1601400, 4.1740600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56221, 'Charleville-Mézières', 'Charleville-Mezieres', 'Caroli Villa,Charleville,Charleville-Mezieres,Charleville-Mézières,Libreville,Mezieres,Mézières,Sarlevil Mezyer,Sarlevilis-Mezjeras,Sarlvil-Mezier,Sarlvill-Mezyer,Sharlevil Mezjer,Sharlevil''-Mez''er,Sharlvil Mezjer,sarlavhila-mejhi''eya,sha lei wei er-mei ji ye er,sharlwyl-mzyr,sharuruvu~iru=mejieru,shrlwyl-mzyh,srlwwyl-mzyyr,syaleulleubilmejieleu,Şarlevil Mezyer,Šarlevilis-Mezjeras,Σαρλβίλ-Μεζιέρ,Шарлвил Мезјер,Шарлевил Мезјер,Шарлевиль-Мезьер,Шарлевіль-Мезьєр,Շառլվիլլ-Մեզյեր,שרלוויל-מזייר,شارلویل-مزیر,شرلویل-مزیه,शार्लव्हिल-मेझिएया,シャルルヴィル＝メジエール,沙勒维尔-梅济耶尔,샤를르빌메지에르', 49.7666700, 4.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56222, 'Charleval', 'Charleval', 'Charleval', 49.3729000, 1.3836900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56223, 'Charleval', 'Charleval', 'Charleval,Charleval-de Provence', 43.7186400, 5.2454600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56224, 'Chargé', 'Charge', 'Charge,Chargé', 47.4327000, 1.0303700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56225, 'Charenton-le-Pont', 'Charenton-le-Pont', 'Carentonium,Charenton,Charenton-Republicain,Charenton-Républicain,Charenton-le-Pont,Le Republicain,Le Républicain,Sharanton le Pon,Sharanton-le-Pon,Sharonton-l-Pon,sha lang tong lei peng,sharanton=ru=pon,shrantwn-lw-pwn,shrntwn lw pwn,syalangtongleupong,Шарантон ле Пон,Шарантон-ле-Пон,Шаронтон-л-Пон,شرانتون-لو-پون,شرنتون لو پون,シャラントン＝ル＝ポン,沙朗通勒蓬,샤랑통르퐁', 48.8220900, 2.4121700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56226, 'Charenton-du-Cher', 'Charenton-du-Cher', 'Charenton,Charenton sur Cher,Charenton-du-Cher,Sharanton di Sher,Sharanton-dju-Sher,sha lang tong di xie,Шарантон ди Шер,Шарантон-дю-Шер,沙朗通迪谢', 46.7300700, 2.6443800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56227, 'Charentilly', 'Charentilly', 'Charentilly', 47.4698100, 0.6090300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56228, 'Charentay', 'Charentay', 'Charentay', 46.0890600, 4.6792300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56229, 'Charbuy', 'Charbuy', 'Charbuy,Sharbi,Sharbjui,sha er bi yi,Шарби,Шарбюи,Шарбюї,沙尔比伊', 47.8228200, 3.4661700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56230, 'Charbonnières-les-Varennes', 'Charbonnieres-les-Varennes', 'Charboneiras las Novas,Charbonnieres,Charbonnières,Charbonèiras las Novas,Sharbon''er-le-Varenn,Sharbonije le Varan,sha er bo ni ai lai wa lei nei,Шарбоније ле Варан,Шарбоньєр-ле-Варенн,沙尔博尼埃莱瓦雷内', 45.9000000, 3.0000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56231, 'Charbonnières-les-Bains', 'Charbonnieres-les-Bains', 'Charbonnieres,Charbonnieres-les-Bains,Charbonnières,Charbonnières-les-Bains,Sharbon''er-le-Ben,Sharbonijer le Ben,Шарбонијер ле Бен,Шарбоньєр-ле-Бен', 45.7842000, 4.7463000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56232, 'Charavines', 'Charavines', 'Charavines,Charavines-les-Bains', 45.4304300, 5.5160200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56233, 'Charantonnay', 'Charantonnay', 'Charantonnay,Charentonnay,Sharantone,Sharantonne,sha lang tuo nai,sharantone,Шарантоне,Шарантонне,シャラントネー,沙朗托奈', 45.5367100, 5.1103400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56234, 'Chaptelat', 'Chaptelat', 'Chaptalac,Chaptelat,Shaptela,Shatla,sha pu tai la,Шаптела,Шатла,沙普泰拉', 45.9096200, 1.2601800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56235, 'Chappes', 'Chappes', 'Chappes', 45.8683100, 3.2224100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56236, 'Chaponost', 'Chaponost', 'Chaponost,Shapono,Шапоно', 45.7059200, 4.7444100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56237, 'Chaponnay', 'Chaponnay', 'Chaponnay', 45.6309700, 4.9429900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56238, 'Chapet', 'Chapet', 'Chapet,Shape,Шапе', 48.9666700, 1.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56239, 'Chapdes-Beaufort', 'Chapdes-Beaufort', 'Chapdes,Chapdes-Beaufort', 45.8922500, 2.8638100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56240, 'Chapareillan', 'Chapareillan', 'Chapareillan,Shaparejan,sha pa lei lang,Шапареян,Шапарејан,沙帕雷朗', 45.4651300, 5.9917100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56241, 'Chaource', 'Chaource', 'Caduscia,Chaource,Shaurs,shao er ke,Шаурс,绍尔克', 48.0591500, 4.1373800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56242, 'Chanu', 'Chanu', 'Chanu,Shani,Shanju,sha ni,Шани,Шаню,沙尼', 48.7291400, -0.6760300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56243, 'Chantraine', 'Chantraine', 'Chantraine', 48.1715700, 6.4353800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56244, 'Chantonnay', 'Chantonnay', 'Chantonnay,La Prairiale,La Resolue,La Résolue,Shantone,Shantonne,shang tuo nai,Шантоне,Шантонне,尚托奈', 46.6870200, -1.0502400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56245, 'Chantôme', 'Chantome', 'Chantome,Chantôme', 46.4106700, 1.5559000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56246, 'Chantilly', 'Chantilly', 'Champ-Libre,Chantilly,XCV', 49.1946100, 2.4712400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56247, 'Chantepie', 'Chantepie', 'Cantus Picae,Chantepie,Kantpig,Shantepi,Shantpi,shang te pi ye,Шантепи,Шантпи,Шантпі,尚特皮耶', 48.0888500, -1.6152400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56248, 'Chantenay-Saint-Imbert', 'Chantenay-Saint-Imbert', 'Chantenay,Chantenay-Saint-Imbert', 46.7333300, 3.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56249, 'Chanteloup-les-Vignes', 'Chanteloup-les-Vignes', 'Chanteloup,Chanteloup-les-Vignes,Shantelu-le-Vin'',Shantelup le Vin,Шантелу-ле-Винь,Шантелу-ле-Вінь,Шантелуп ле Вињ', 48.9761400, 2.0326100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56250, 'Chanteloup-en-Brie', 'Chanteloup-en-Brie', 'Shantelu-an-Bri,Shantelup an Bri,Shantlu-an-Bri,Шантелу-ан-Бри,Шантелуп ан Бри,Шантлу-ан-Брі', 48.8547800, 2.7392900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56251, 'Chanteloup', 'Chanteloup', 'Chanteloup,Kantlou', 47.9657400, -1.6151700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56252, 'Chantelle', 'Chantelle', 'Chantelle', 46.2359200, 3.1520700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56253, 'Chanteheux', 'Chanteheux', 'Chanteheux', 48.5993800, 6.5286000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56254, 'Chanteau', 'Chanteau', 'Chanteau,Shanto,shang tuo,Шанто,尚托', 47.9665100, 1.9712900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56255, 'Chanos-Curson', 'Chanos-Curson', 'Chanos-Curson', 45.0605700, 4.9238100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56256, 'Chanonat', 'Chanonat', 'Chanonac,Chanonat,Shanona,shang ao na,Шанона,尚奥纳', 45.6929900, 3.0935100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56257, 'Chaniers', 'Chaniers', 'Chaniers,Shan''e,Shanije,sha nie er,Шаније,Шанье,Шаньє,沙涅尔', 45.7185800, -0.5577900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56258, 'Changy-les-Bois', 'Changy-les-Bois', 'Changy,Changy-les-Bois', 47.8579300, 2.6854300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56259, 'Changis-sur-Marne', 'Changis-sur-Marne', 'Changis,Changis-sur-Marne', 48.9581600, 3.0219100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56260, 'Changé', 'Change', 'Change,Changé', 48.0991800, -0.7929200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56261, 'Changé', 'Change', 'Change,Changé', 47.9849900, 0.2832800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56262, 'Chandon', 'Chandon', 'Chandon', 46.1496000, 4.2144600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56263, 'Chancenay', 'Chancenay', 'Chancenay', 48.6700100, 4.9871500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56264, 'Chancelade', 'Chancelade', 'Chancelada,Chancelade,Shanselad,shang se la de,Шанселад,尚瑟拉德', 45.2004900, 0.6726100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56265, 'Chanceaux-sur-Choisille', 'Chanceaux-sur-Choisille', 'Chanceaux,Chanceaux-sur-Choisille', 47.4714500, 0.7053900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56266, 'Chanas', 'Chanas', '', 45.3188100, 4.8184900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56267, 'Chanac', 'Chanac', 'Chanac', 44.4661400, 3.3432700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56268, 'Champvans', 'Champvans', 'Champvans', 47.1046600, 5.4376000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56269, 'Champtocé-sur-Loire', 'Champtoce-sur-Loire', 'Champtoce,Champtoce-sur-Loire,Champtocé,Champtocé-sur-Loire,Shamtose-sjur-Luar,Shantose na Loari,lu wa er he pan shang pu tuo sai,shantose=shuru=rowaru,Шамтосе-сюр-Луар,Шантосе на Лоари,シャントセ＝シュル＝ロワール,卢瓦尔河畔尚普托塞', 47.4123900, -0.8645200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56270, 'Champtoceaux', 'Champtoceaux', 'Champtoceaux,Shamtoso,Shantoso,shang pu tuo suo,shantoso,Шамтосо,Шантосо,シャントソー,尚普托索', 47.3347600, -1.2613100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56271, 'Champ-sur-Drac', 'Champ-sur-Drac', 'Champ,Champ-du Drac,Champ-sur-Drac,Sham-sjur-Drak,Shan sir Drak,de la ke he pan shang,Шам-сюр-Драк,Шан сир Драк,德拉克河畔尚', 45.0691200, 5.7322500, 'FR', '2016-08-06', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56272, 'Champs-sur-Tarentaine-Marchal', 'Champs-sur-Tarentaine-Marchal', 'Champs', 45.4000000, 2.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56273, 'Champs-sur-Marne', 'Champs-sur-Marne', 'Champs,Sham-sjur-Marn,Shan na Marni,Shan-sjur-Marn,sham swr mrn,shan=shuru=marunu,syangswileumaleun,Шам-сюр-Марн,Шан на Марни,Шан-сюр-Марн,شام سور مرن,シャン＝シュル＝マルヌ,샹쉬르마른', 48.8500000, 2.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56274, 'Champsecret', 'Champsecret', '', 48.6092500, -0.5505800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56275, 'Champs-sur-Yonne', 'Champs-sur-Yonne', '', 47.7333300, 3.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56276, 'Champniers', 'Champniers', 'ANG,Champniers', 45.7145100, 0.2043600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56277, 'Champlitte-la-Ville', 'Champlitte-la-Ville', 'Champlitte-la-Ville', 47.6133300, 5.5319100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56278, 'Champlan', 'Champlan', 'Champlan,Shamplan,shang pu lang,Шамплан,尚普朗', 48.7082300, 2.2797500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56279, 'Champigny', 'Champigny', 'Champigny-sur-Yonne', 48.3166700, 3.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56280, 'Champigny-sur-Marne', 'Champigny-sur-Marne', 'Campinio-ce-Marno,Champigny,Champigny-sur-Marne,Shampin''i-sjur-Marn,Shampini na Marni,Shampini sjur Marn,ma en he pan shang pi ni,shambyny swr marn,shampayn swr mrn,shampyny-swr-mrn,shanpini=shuru=marunu,syangpiniswileumaleun,Ĉampinio-ĉe-Marno,Шампини сюр Марн,Шампиньи-сюр-Марн,Шампињи на Марни,Шампіньї-сюр-Марн,شامبيني سور مارن,شامپاین سور مرن,شامپینی-سور-مرن,シャンピニー＝シュル＝マルヌ,马恩河畔尚皮尼,샹피니쉬르마른', 48.8164200, 2.4936600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56281, 'Champigneulles', 'Champigneulles', 'Champigneulles,Shampin''el'',Shampin''jol'',Shampinel,shang pi gai yu lai,Шампиньель,Шампиньёль,Шампињел,Шампіньєль,尚皮盖于莱', 48.7341900, 6.1641700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56282, 'Champignelles', 'Champignelles', 'Champignelles,Shampin''el'',Shampinel,shang pi ge lei,Шампиньель,Шампињел,Шампіньєль,尚皮格勒', 47.7800900, 3.0745700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56283, 'Champigné', 'Champigne', 'Champigne,Champigné,Shampin''e,Shampine,shang pi nie,Шампиње,Шампіньє,尚皮涅', 47.6633200, -0.5716000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56284, 'Champier', 'Champier', 'Champier', 45.4563800, 5.2922300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56285, 'Champhol', 'Champhol', 'Champhol,Shamfol'',Shanol,shang fu,Шамфоль,Шанол,尚福', 48.4681300, 1.5028100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56286, 'Champforgeuil', 'Champforgeuil', 'Champforgeuil,Shamforzhej,Shanforzhej,Шамфоржей,Шанфоржеј', 46.8185700, 4.8335700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56287, 'Champfleur', 'Champfleur', 'Champfleur', 48.3866800, 0.1294200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56288, 'Champenoux', 'Champenoux', 'Champenoux', 48.7417400, 6.3503200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56289, 'Champeix', 'Champeix', 'Champeilhs,Champeix,Champelhs,Shampe,shang pei,shanpei,Шампе,シャンペイ,尚佩', 45.5868000, 3.1286600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56290, 'Champdieu', 'Champdieu', 'Champdieu', 45.6447800, 4.0458300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56291, 'Champdeniers-Saint-Denis', 'Champdeniers-Saint-Denis', 'Shamden''e-Sen-Deni,Shandenije Sen Deni,Шамденьє-Сен-Дені,Шанденије Сен Дени', 46.4833300, -0.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56292, 'Champcueil', 'Champcueil', 'Champcueil,Shamkej,Shansej,shang pu qu ai,Шамкей,Шансеј,尚普屈埃', 48.5159400, 2.4467400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56293, 'Champcevinel', 'Champcevinel', 'Champ Savineu,Champcevinel,Champsavineu,Champsavinèu,Shamsevinel'',Shansevinel,shang pu se wei nei,Шамсевинель,Шамсевінель,Шансевинел,尚普瑟维内', 45.2163000, 0.7279600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56294, 'Champagnole', 'Champagnole', 'Champagnole,Shampan''ol'',Shampanol,shang pa ni ao lei,Шампаньоль,Шампањол,尚帕尼奥勒', 46.7445200, 5.9135400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56295, 'Champagnier', 'Champagnier', 'Champagnier', 45.1129400, 5.7265400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56296, 'Champagney', 'Champagney', 'Champagney,Champagny', 47.7050400, 6.6817300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56297, 'Champagne-sur-Seine', 'Champagne-sur-Seine', 'Champagne,Champagne-sur-Seine,Shampan na Seni,Shampan''-sjur-Sen,Шампань-сюр-Сен,Шампањ на Сени', 48.3979400, 2.7978500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56298, 'Champagne-sur-Oise', 'Champagne-sur-Oise', 'Champagne,Champagne-sur-Oise,Shampan si Oaz,Shampan''-sjur-Uaz,wa ci he pan xiang bin,Шампань-сюр-Уаз,Шампањ си Оаз,瓦兹河畔香槟', 49.1405200, 2.2423300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56299, 'Champagne-Mouton', 'Champagne-Mouton', 'Champagne-Mouton,Champanha Molton,Champanha de Moton,Shampan Muton,Shampan''-Muton,xiang bin mu tong,Шампань-Мутон,Шампањ Мутон,香槟穆通', 45.9907800, 0.4105100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56300, 'Champagné-les-Marais', 'Champagne-les-Marais', 'Champagne,Champagné', 46.3808100, -1.1211200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56301, 'Champagné', 'Champagne', '', 48.0218500, 0.3309600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56302, 'Champagnac', 'Champagnac', 'Champagnac,Champagnac-les-Mines', 45.3500000, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56303, 'Chamonix-Mont-Blanc', 'Chamonix-Mont-Blanc', 'Chamonix,Chamonix-Mont-Blanc,Chamônix,Shamoni,Shamoni Mon Blan,shamoni=mon=buran,syamoni,xia mu ni,Шамони,Шамони Мон Блан,シャモニー＝モン＝ブラン,霞慕尼,샤모니', 45.9237500, 6.8693300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56304, 'Chamigny', 'Chamigny', 'Chamigny', 48.9724200, 3.1516500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56305, 'Chameyrat', 'Chameyrat', 'Chameyrat', 45.2348100, 1.6980300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56306, 'Chambretaud', 'Chambretaud', 'Chambretaud,Shambreto,shang bu lei tuo,Шамбрето,尚布雷托', 46.9216600, -0.9640500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56307, 'Chambray-lès-Tours', 'Chambray-les-Tours', 'Chambray,Chambray-les-Tours,Chambray-lès-Tours,Shambre le Tur,Shambre-le-Tur,shang bu lai lai tu er,Шамбре ле Тур,Шамбре-ле-Тур,尚布赖莱图尔', 47.3353700, 0.7028600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56308, 'Chambourg-sur-Indre', 'Chambourg-sur-Indre', 'Chambourg,Chambourg-sur-Indre,Shambur sir Endr,Shambur-sjur-Endr,an de er he pan shang bu er,Шамбур сир Ендр,Шамбур-сюр-Ендр,安德尔河畔尚布尔', 47.1815900, 0.9686300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56309, 'Chambourcy', 'Chambourcy', 'Camburciacum,Chambourcy,Shambursi,Шамбурси,Шамбурсі', 48.9065500, 2.0410000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56310, 'Chamboulive', 'Chamboulive', 'Chamboliva,Chamboulive,Shambuliv,shang bu li fu,Шамбулив,Шамбулів,尚布利夫', 45.4329000, 1.7041500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56311, 'Chambon-sur-Voueize', 'Chambon-sur-Voueize', 'Chambon,Chambon-sur-Voueize,Lo Chambon de Sent Sarnin,Shambon sir Vuez,Shambon-sjur-Vuehz,Shambon-sjur-Vuez,wu ai ci he pan shang bang,Шамбон сир Вуез,Шамбон-сюр-Вуез,Шамбон-сюр-Вуэз,武埃兹河畔尚邦', 46.1893800, 2.4256800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56312, 'Chambœuf', 'Chamboeuf', '', 45.5833300, 4.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56313, 'Chambly', 'Chambly', 'Chambly', 49.1666700, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56314, 'Chambéry', 'Chambery', 'CMF,Camberiacum,Chamberi,Chambery,Chambery-le-Vieux,Chamberí,Chambèri,Chambéry,Chambéry-le-Vieux,Gorad Shambery,Samberi,Shamberi,shambry,shambyry,shanberi,shang bei li,syangbeli,Šamberi,Горад Шамберы,Шамбери,Шамбері,שאמברי,شامبری,شامبيري,شامبیری,シャンベリ,尚贝里,샹베리', 45.5666700, 5.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56315, 'Chamberet', 'Chamberet', 'Chambaret,Chamberet,Shambere,Shambre,shang bo lei,Шамбере,Шамбре,尚伯雷', 45.5831400, 1.7212400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56316, 'Chamarandes-Choignes', 'Chamarandes-Choignes', '', 48.0833300, 5.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56317, 'Chamarande', 'Chamarande', 'Bonne-Commune,Chamarande,Shamarand,sha ma lang de,Шамаранд,沙马朗德', 48.5171500, 2.2171000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56318, 'Chamant', 'Chamant', 'Chamant,Shaman,sha mang,Шаман,沙芒', 49.2199000, 2.6117600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56319, 'Chamalières', 'Chamalieres', 'Chamaleira,Chamaleiras,Chamalieres,Chamalières,Chamalèira,Shamal''er,Shamalijer,sha ma li ai,shamarieru,Шамалијер,Шамальер,Шамальєр,シャマリエール,沙马利埃', 45.7755900, 3.0631000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56320, 'Chamagnieu', 'Chamagnieu', 'Chamagnieu', 45.6811400, 5.1639200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56321, 'Châlus', 'Chalus', 'Caluca,Chalus,Chasluc,Chasluç,Châlus,Shali,Shalju,sha lu,shalw,Шали,Шалю,شالو,沙吕', 45.6544000, 0.9801100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56322, 'Chalo-Saint-Mars', 'Chalo-Saint-Mars', 'Chalo-Saint-Marc,Chalo-la-Raison,Châlo-Saint-Marc,Shalo Sen Mar,Shalo-Sen-Mars,sha luo sheng ma er,Шало Сен Мар,Шало-Сен-Марс,沙洛圣马尔', 48.4232800, 2.0649100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56323, 'Châlonvillars', 'Chalonvillars', 'Chalonvillars,Châlonvillars', 47.6405500, 6.7840700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56324, 'Chalon-sur-Saône', 'Chalon-sur-Saone', 'Cabillonum,Chalon,Chalon-sur-Saone,Chalon-sur-Saône,Chalons,Chalons sur Saone,Chalons sur Saône,Come-la-Montagne,Côme-la-Montagne,La Montagne,Montagne-les-Chalon,Montagne-lès-Chalon,Port-la-Montagne,Rochefort-des-Vignes,Rochefort-la-Vigne,Shalon sir Saon,Shalon-sjur-Son,sharon=shuru=sonu,shlwn swr sywn,shlwn-swr-swn,suo en he pan sha long,syallongswileuson,Шалон сир Саон,Шалон-сюр-Сон,שאלון-סור-סון,شلون سور سئون,شلون-سور-سون,シャロン＝シュル＝ソーヌ,索恩河畔沙隆,샬롱쉬르손', 46.7833300, 4.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56325, 'Châlons-en-Champagne', 'Chalons-en-Champagne', 'Chalons,Chalons-en-Champagne,Chalons-sur-Marne,Châlons,Châlons-en-Champagne,Châlons-sur-Marne,Durocatalaunum,Gorad Shalon-an-Shampan'',Salon an Sampayn,Sampanes Salonas,Shalon an Shampan,Shalon-an-Shampan'',cha lng-x xng-ch xng pay,salo-am-sampena,shalwn-an-shampany,sharon=an=shanpanyu,shlwnzan shampayn,shylwnz ayn shympayn,syallong-angsyangpanyu,xiang bin sha long,Šampanės Šalonas,Горад Шалон-ан-Шампань,Шалон ан Шампањ,Шалон-ан-Шампань,Շալոն ան Շամպայն,שאלון-אן-שמפאן,شالون-آن-شامپانی,شلونزان شامپاین,شیلونز این شیمپائن,शालो-आं-शाँपेन,ชาลง-อ็อง-ช็องปาญ,შალონ-ან-შამპანი,シャロン＝アン＝シャンパーニュ,香槟沙隆,샬롱앙샹파뉴', 48.9539300, 4.3672400, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56326, 'Chalonnes-sur-Loire', 'Chalonnes-sur-Loire', 'Chalonnes,Chalonnes-sur-Loire,Shalon na Loari,Shalonn-sjur-Luar,lu wa er he pan sha luo nei,Шалон на Лоари,Шалонн-сюр-Луар,卢瓦尔河畔沙洛内', 47.3516000, -0.7631000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56327, 'Challuy', 'Challuy', 'Challuy,Chaluy', 46.9497100, 3.1480700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56328, 'Challex', 'Challex', 'Challeux,Challex,Challez', 46.1845800, 5.9763900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56329, 'Challes-les-Eaux', 'Challes-les-Eaux', 'Challes,Challes-les-Eaux,Shal le O,Shal''-lez-O,Шал ле О,Шаль-лез-О', 45.5519500, 5.9817100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56330, 'Challes', 'Challes', 'Challes', 47.9303300, 0.4151100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56331, 'Challans', 'Challans', 'Challans,Shalan,Shallan,sha lang,shalan,Шалан,Шаллан,شالان,沙朗', 46.8436300, -1.8749100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56332, 'Chalindrey', 'Chalindrey', 'Chalindrey', 47.8030800, 5.4279700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56333, 'Chaligny', 'Chaligny', 'Chaligny,Shalin''i,Shalini,sha li ni,Шалиньи,Шалињи,Шаліньї,沙利尼', 48.6240500, 6.0833300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56334, 'Chalifert', 'Chalifert', 'Chalifert,Shalifer,Шалифер,Шаліфер', 48.8899300, 2.7733900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56335, 'Châlette-sur-Loing', 'Chalette-sur-Loing', 'Chalette,Chalette-sur-Loing,Châlette,Châlette-sur-Loing,Shalet sir Loan,Shalett-sjur-Luen,lu wan he pan sha lai te,Шалет сир Лоан,Шалетт-сюр-Луен,卢万河畔沙莱特', 48.0133700, 2.7358700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56336, 'Chaleins', 'Chaleins', 'Chaleins', 46.0305800, 4.8041700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56337, 'Chalampé', 'Chalampe', 'Chalampe,Chalampé,Eichwald,Shalampe,sha lang pei,Шалампе,沙朗佩', 47.8194100, 7.5409800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56338, 'Chalamont', 'Chalamont', 'Chalamont', 45.9966500, 5.1701400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56339, 'Chalais', 'Chalais', 'Chalais', 45.2733800, 0.0388000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56340, 'Chalabre', 'Chalabre', 'Chalabre,Eissalabra,Shalabr,sha la bu er,Шалабр,沙拉布尔', 42.9824800, 2.0053800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56341, 'Chaingy', 'Chaingy', 'Chaingy,Shenzhi,shang ji,Шенжи,Шенжі,尚吉', 47.8832600, 1.7705900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56342, 'Chailly-en-Brie', 'Chailly-en-Brie', 'Chailly,Chailly-en-Brie', 48.7900600, 3.1245300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56343, 'Chailly-en-Bière', 'Chailly-en-Biere', 'Chailly,Chailly-en-Biere,Chailly-en-Bière,Shai-an-B''er,Shai-an-Ber,Shaji an Bjer,shaii=an=bieru,Шаи-ан-Бьер,Шаї-ан-Бєр,Шаји ан Бјер,シャイイ＝アン＝ビエール', 48.4670100, 2.6078500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56344, 'Chaillevette', 'Chaillevette', 'Chaillevette,Shajvet,Shajvett,xie lei wei te,Шайвет,Шайветт,Шајвет,谢勒韦特', 45.7303000, -1.0581000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56345, 'Chailles', 'Chailles', 'Chailles,Shaj,xie lai,Шай,Шај,谢莱', 47.5416000, 1.3122000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56346, 'Chaillé-les-Marais', 'Chaille-les-Marais', 'Chaille,Chaille-les-Marais,Chaillé,Chaillé-les-Marais', 46.3962800, -1.0236900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56347, 'Chailland', 'Chailland', 'Chailland,Shajan,Shajjan,xie lang,Шайян,Шајан,谢朗', 48.2251600, -0.8738700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56348, 'Chaillac', 'Chaillac', 'Chaillac,Chalhac e Brossa,Chalhac e Bròssa,Shajak,xie la ke,Шайак,Шаяк,Шајак,谢拉克', 46.4338200, 1.2988900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56349, 'Chagny', 'Chagny', 'Chagny', 46.9095300, 4.7519000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56350, 'Chadrac', 'Chadrac', 'Chadrac', 45.0618100, 3.9026100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56351, 'Chacé', 'Chace', 'Shase,sha sai,Шасе,沙塞', 47.2143500, -0.0717900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56352, 'Chabris', 'Chabris', 'Chabris,Shabri,sha bu li,Шабри,Шабрі,沙布里', 47.2534300, 1.6518100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56353, 'Chabreloche', 'Chabreloche', 'Chabreloche', 45.8796700, 3.6951900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56354, 'Châbons', 'Chabons', 'Chabons,Châbons', 45.4409300, 5.4275000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56355, 'Chablis', 'Chablis', 'Chablis,shaburi,シャブリ', 47.8138600, 3.7983500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56356, 'Chabeuil', 'Chabeuil', 'Chabeuil,Chabuelh,Shabej,VAF,sha bo yi,Шабей,Шабеј,沙伯伊', 44.8996300, 5.0188400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56357, 'Chabanais', 'Chabanais', 'Chabanais,Chabanes,Chabanès,Chabanés,Shabane,sha ba nai,Шабане,沙巴奈', 45.8733900, 0.7176300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56358, 'Cézy', 'Cezy', 'Cezy,Cézy,Sezi,sai qi,Сези,Сезі,塞齐', 47.9926500, 3.3406700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56359, 'Cézac', 'Cezac', '', 45.0901900, -0.4196300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56360, 'Ceyzériat', 'Ceyzeriat', 'Ceyzeriat,Ceyzériat,Sejzerja,Sezer''ja,Sezeria,Sezerja,sai ze li ya,syzryat,syzyryat,Сезерья,Сезерја,Сейзеря,Սեզերիա,سيزيريات,سیزریات,塞泽里亚', 46.1801000, 5.3197200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56361, 'Ceyreste', 'Ceyreste', 'Ceiresta,Ceyreste,Sejrest,Serest,sai lei si te,Сейрест,Серест,塞雷斯特', 43.2133000, 5.6311100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56362, 'Ceyrat', 'Ceyrat', 'Ceirac,Ceirat,Ceyrat,Sejra,Sera,sai la,Сейра,Сера,塞拉', 45.7317600, 3.0633500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56363, 'Ceton', 'Ceton', 'Ceton', 48.2263100, 0.7496800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56364, 'Cestas', 'Cestas', 'Cestas,Cestàs,Sesta,Sestas,sai si ta,Сеста,Сестас,塞斯塔', 44.7434500, -0.6790500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56365, 'Cessy', 'Cessy', 'Cessy,Sesi,Sessi,sai xi,sysy,Сеси,Сесси,Сессі,Սեսսի,سيسي,塞西', 46.3166200, 6.0691500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56366, 'Cesson-Sévigné', 'Cesson-Sevigne', 'Cesson-Sevigne,Cesson-Sévigné,Cessonium,Saozon-Sevigneg,Seson Sevin,Sesson-Sevin''e,se song sai wei nie,Сесон Севињ,Сессон-Севинье,Сессон-Севіньє,瑟松塞维涅', 48.1212000, -1.6030000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56367, 'Cesson', 'Cesson', 'Cesson,Seson,Sesson,Сесон,Сессон', 48.5620400, 2.6081600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56368, 'Cessieu', 'Cessieu', 'Cessieu', 45.5657600, 5.3770400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56369, 'Cessenon-sur-Orb', 'Cessenon-sur-Orb', 'Cecenon,Sesnon sir Orb,Sessenon-sjur-Orb,ao er he pan se sang weng,Сеснон сир Орб,Сессенон-сюр-Орб,奥尔河畔瑟桑翁', 43.4501100, 3.0515400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56370, 'Cerzat', 'Cerzat', '', 45.1614900, 3.4796600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56371, 'Cervione', 'Cervione', 'Cervione,Cervioni,Chervione,Chervjone,Servion,Сервион,Червионе,Червйоне', 42.3309600, 9.4911200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56372, 'Certines', 'Certines', 'Certines', 46.1332400, 5.2649600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56373, 'Cers', 'Cers', 'Cers', 43.3235200, 3.3045000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56374, 'Cérons', 'Cerons', 'Cerons,Cérons', 44.6357200, -0.3335100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56375, 'Cerny', 'Cerny', 'Cerny', 48.4779600, 2.3281500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56376, 'Cernay-lès-Reims', 'Cernay-les-Reims', 'Cernay,Cernay-les-Reims,Cernay-lez-Reims,Cernay-lès-Reims', 49.2637500, 4.1021600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56377, 'Cernay-la-Ville', 'Cernay-la-Ville', 'Cernay,Cernay-la-Ville,Serne la Vil,Serne-la-Vil'',Серне ла Вил,Серне-ла-Виль,Серне-ла-Віль', 48.6732400, 1.9742200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56378, 'Cernay', 'Cernay', 'Cernay,Sennheim', 47.8097000, 7.1769900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56379, 'Cerizay', 'Cerizay', 'Cerizay', 46.8215400, -0.6672600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56380, 'Cerisy-la-Salle', 'Cerisy-la-Salle', 'Cerisy,Cerisy-la-Salle', 49.0262200, -1.2828300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56381, 'Cérilly', 'Cerilly', 'Cerilly,Cérilly', 46.6179000, 2.8202000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56382, 'Cergy', 'Cergy', 'Cergeium,Cergy,Serzhi,sai er ji,seleuji,seruji,srzhy,syrjy,Сержи,Сержі,سرژی,سيرجي,セルジー,塞尔吉,세르지', 49.0364500, 2.0761300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56383, 'Ceret', 'Ceret', 'Ceret,Céret', 42.4853300, 2.7480400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56384, 'Céreste', 'Cereste', 'Ceiresta,Ceirèsta,Cereste,Céreste,Serest,sai lei si te,Серест,塞雷斯特', 43.8556700, 5.5845200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56385, 'Cerelles', 'Cerelles', 'Cerelles,Serel,Serel'',se lei lai,Серел,Серель,瑟雷莱', 47.5016800, 0.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56386, 'Cerdon', 'Cerdon', 'Cerdon', 47.6357100, 2.3627700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56387, 'Cercy-la-Tour', 'Cercy-la-Tour', 'Cercy,Cercy-la-Tour,Cercy-sur-Aron,Cerey-la-Tour,Sersi la Tur,Sersi-la-Tur,sai er xi la tu,Серси ла Тур,Серси-ла-Тур,Серсі-ла-Тур,塞尔西拉图', 46.8620300, 3.6465200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56388, 'Cercoux', 'Cercoux', 'Cercoux', 45.1333300, -0.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56389, 'Cervera de la Marenda', 'Cervera de la Marenda', 'Cerbere,Cerbère,Cervera,Cervera de la Marenda', 42.4409400, 3.1651800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56390, 'Cérans-Foulletourte', 'Cerans-Foulletourte', 'Cerans,Cerans-Fouilletourte,Cerans-Foulletourte,Cérans,Cérans-Fouilletourte,Cérans-Foulletourte', 47.8265100, 0.0772400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56391, 'Cepoy', 'Cepoy', 'Cepoy,Sepoa,Sepua,se pu wa,Сепоа,Сепуа,瑟普瓦', 48.0479500, 2.7378200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56392, 'Cépet', 'Cepet', 'Cepet,Cépet', 43.7488500, 1.4316800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56393, 'Cenon-sur-Vienne', 'Cenon-sur-Vienne', 'Cenon,Cenon-sur-Vienne,Senon sir Vjen,Senon-sjur-Venn,wei ai na he pan kang weng,Сенон сир Вјен,Сенон-сюр-Вєнн,维埃纳河畔康翁', 46.7742600, 0.5369800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56394, 'Cenon', 'Cenon', 'Cenon,Senon,se nong,seunong,snwn,sunon,Сенон,سنون,スノン,瑟农,스농', 44.8559000, -0.5183900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56395, 'Cendras', 'Cendras', '', 44.1500000, 4.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56396, 'Cénac-et-Saint-Julien', 'Cenac-et-Saint-Julien', 'Cenac,Cenac-et-Saint-Julien,Cénac,Cénac-et-Saint-Julien,Senac e Sent Julian,Senak et Sen Zhilijen,Senak-e-Sen-Zhul''en,sai na ke he sheng rui li an,Сенак ет Сен Жилијен,Сенак-е-Сен-Жульен,Сенак-е-Сен-Жульєн,塞纳克和圣瑞利安', 44.7996800, 1.2053500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56397, 'Cénac', 'Cenac', 'Cenac,Cénac', 44.7800300, -0.4599900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56398, 'Cély', 'Cely', 'Cely-en-Biere,Cély-en-Bière', 48.4595900, 2.5324500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56399, 'Cellieu', 'Cellieu', 'Cellieu,Sel''e,Selije,sai li e,Селије,Сельє,塞利厄', 45.5225000, 4.5407600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56400, 'Cellettes', 'Cellettes', 'Cellettes', 47.5275800, 1.3810200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56401, 'Celles-sur-Durolle', 'Celles-sur-Durolle', 'Celles,Celles-sur-Durolle', 45.8578700, 3.6353400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56402, 'Celles-sur-Belle', 'Celles-sur-Belle', 'Celles,Celles-sur-Belle,Sel sir Bel,Sel''-sjur-Bel'',Сел сир Бел,Сель-сюр-Бель', 46.2622300, -0.2127400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56403, 'Celle-Lévescault', 'Celle-Levescault', 'Celle,Celle-Levescault,Celle-Lévescault,Celle-lEvescault,Celle-lÉvescault,Sel Levko,Sel''-Levesko,sai lei lai fu si ke er,Сел Левко,Сель-Левеско,塞勒莱弗斯科尔', 46.4240600, 0.1881000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56404, 'Cébazat', 'Cebazat', 'Cebasac,Cebazat,Cébazat,Sebaza,sai ba zha,Себаза,塞巴扎', 45.8340500, 3.1004800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56405, 'Ceaucé', 'Ceauce', '', 48.4943600, -0.6252600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56406, 'Cazouls-lès-Béziers', 'Cazouls-les-Beziers', 'Cazouls,Cazouls-les-Beziers,Cazouls-lès-Béziers', 43.3921800, 3.1010000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56407, 'Cazilhac', 'Cazilhac', 'Cazilhac', 43.9203100, 3.7028500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56408, 'Cazilhac', 'Cazilhac', 'Cazilhac', 43.1820500, 2.3608500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56409, 'Cazes-Mondenard', 'Cazes-Mondenard', 'Cases e Montdenard,Cazes-Mondenard,Kaz-Mondnar,Kaze Mondnar,ka ze meng dai na er,Каз-Монднар,Казе Монднар,卡泽蒙代纳尔', 44.2268900, 1.2029900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56410, 'Cazères', 'Cazeres', 'Caseras,Casèras,Cazeres,Cazères,Kazer,ka ze lei,Казер,卡泽雷', 43.2071000, 1.0863300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56411, 'Cazaubon', 'Cazaubon', 'Casaubon,Cazaubon,Kazobon,Kozobon,ka zuo bang,Казобон,Козобон,卡佐邦', 43.9343100, -0.0681400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56412, 'Caylus', 'Caylus', 'Caylus', 44.2360700, 1.7716800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56413, 'Cayeux-sur-Mer', 'Cayeux-sur-Mer', 'Cayeux,Kaje na Moru,Kajjo-sjur-Mer,Kajo-sjur-Mer,Tcheyeu,Tchéyeu,bin hai ka yue,kaiyu=shuru=meru,Кайо-сюр-Мер,Кайё-сюр-Мер,Каје на Мору,カイユー＝シュル＝メール,滨海卡约', 50.1820000, 1.4940000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56414, 'Cavignac', 'Cavignac', 'Cavignac', 45.1008300, -0.3897600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56415, 'Caveirac', 'Caveirac', 'Cavairac,Caveirac,Kaverak,ka wei la ke,Каверак,卡韦拉克', 43.8243700, 4.2666400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56416, 'Cavan', 'Cavan', 'Cavan,Kawan', 48.6724200, -3.3460600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56417, 'Cavalaire-sur-Mer', 'Cavalaire-sur-Mer', 'Cavalaira,Cavalaira de Mar,Cavalaire,Cavalaire-sur-Mer,Heraclea Cacabaria,Kavaler na Moru,Kavaler-sjur-Mer,bin hai ka wa lai lei,Кавалер на Мору,Кавалер-сюр-Мер,滨海卡瓦莱勒', 43.1740300, 6.5271500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56418, 'Cavaillon', 'Cavaillon', 'Cabellio,Cavaillon,Cavalhon,Kavajon,ka wa yong,kabayong,kavu~aiyon,kwywn,Кавайон,Кавајон,کویون,カヴァイヨン,卡瓦永,카바용', 43.8312500, 5.0358600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56419, 'Caux', 'Caux', 'Caux', 43.5062100, 3.3670900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56420, 'Cauville-sur-Mer', 'Cauville-sur-Mer', 'L''Unite-Nationale,L''Unité-Nationale,Saint-Pierre-de-Bonsecours', 49.6000000, 0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56421, 'Cauvigny', 'Cauvigny', 'Cauvigny,Kovin''i,Kovini,ke wei ni,Ковињи,Ковіньї,科维尼', 49.3018000, 2.2484400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56422, 'Cauterets', 'Cauterets', 'Cautares,Cautarès,Cautarés,Cauterets,Koterets,Kotre,Kotret,ke te lei te,Котеретс,Котре,Котрет,科特雷特', 42.8833300, -0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56423, 'Caussade', 'Caussade', 'Caussade,XCS', 44.1608000, 1.5391300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56424, 'Cauro', 'Cauro', 'Cauro', 41.9179000, 8.9139900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56425, 'Caunes-Minervois', 'Caunes-Minervois', 'Caunas de Menerbes,Caunas de Menerbés,Caunes,Caunes-Minervois,Kon Minervoa,Kon-Minervua,ke nei mi nei er wa,Кон Минервоа,Кон-Минервуа,Кон-Мінервуа,科内米内尔瓦', 43.3255500, 2.5254100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56426, 'Caumont-sur-Durance', 'Caumont-sur-Durance', 'Caumont,Caumont de Durenca,Caumont de Durença,Caumont-sur-Durance,Komon sir Dirans,Komon-sjur-Djurans,di lang se he pan ke meng,Комон сир Диранс,Комон-сюр-Дюранс,迪朗瑟河畔科蒙', 43.8935600, 4.9474500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56427, 'Caumont', 'Caumont', 'Caumont', 49.3664200, 0.8959100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56428, 'Caulnes', 'Caulnes', 'Caulnes,Kaon', 48.2880400, -2.1551800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56429, 'Cauffry', 'Cauffry', 'Cauffry,Koffri,Kofri,ke fu li,Кофри,Коффрі,科夫里', 49.3197800, 2.4458100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56430, 'Caudry', 'Caudry', 'Caudry,Kodri,ke de li,Кодри,Кодрі,科德里', 50.1249000, 3.4118600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56431, 'Caudebec-lès-Elbeuf', 'Caudebec-les-Elbeuf', 'Caudebec,Caudebec-les-Elbeuf,Caudebec-lès-Elbeuf,Kodbek lez Elbef,Kodbek-lez-El''bef,Кодбек лез Елбеф,Кодбек-лез-Ельбеф', 49.2808200, 1.0219500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56432, 'Caudebec-en-Caux', 'Caudebec-en-Caux', 'Caudebec,Caudebec-en-Caux,Kodbek an Ko,Kodbek-an-Ko,QUX,Кодбек ан Ко,Кодбек-ан-Ко', 49.5257700, 0.7256100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56433, 'Caudan', 'Caudan', 'Caudan,Kaodan,Kodan,ke dang,Кодан,科当', 47.8087700, -3.3425000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56434, 'Cauchy-à-la-Tour', 'Cauchy-a-la-Tour', 'Cauchy,Cauchy-a-la-Tour,Cauchy-à-la-Tour,El-Cauchie-a-lTour,El-Cauchie-à-lTour,Koshi a la Tur,Koshi-a-la-Tur,kawtshy la twr,ke xi la tu er,Коши а ла Тур,Коши-а-ла-Тур,Коші-а-ла-Тур,كاوتشي لا تور,科希拉图尔', 50.5039400, 2.4460600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56435, 'Cattenom', 'Cattenom', 'Cattenom,Katenom,Kattenhofen,Kattenom,Kettenuewen,ka tang weng,katanwm,Катеном,Каттеном,کاتانوم,卡唐翁', 49.4075500, 6.2442600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56436, 'Catenoy', 'Catenoy', 'Catenoy,Katenua,Katnoa,ka tang wa,Катенуа,Катноа,卡唐瓦', 49.3682400, 2.5105400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56437, 'Castries', 'Castries', 'Castias,Castries,Càstias,Kastri,Kastrij,ka si te li ye,Кастри,Кастрий,Кастрій,卡斯特里耶', 43.6797200, 3.9822200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56438, 'Castres-Gironde', 'Castres-Gironde', 'Castres,Castres-Gironde', 44.6946400, -0.4467900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56439, 'Castres', 'Castres', 'Castra Albigensium,Castras,Castres,Castres-sur-l''Agout,DCM,Gorad Kastr,Kastr,ka si te er,kaseuteuleu,kastr,kasutoru,kstr,Горад Кастр,Кастр,كاستر,کستر,カストル,卡斯特爾,카스트르', 43.6000000, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56440, 'Castillonnès', 'Castillonnes', 'Castilhones,Castilhonés,Castillonnes,Castillonnès,Kastijone,Kastijonnes,ka si di luo nei,Кастийоннес,Кастијоне,Кастійоннес,卡斯蒂洛内', 44.6521500, 0.5922200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56441, 'Castillon-du-Gard', 'Castillon-du-Gard', 'Castillon,Castillon-du-Gard', 43.9645700, 4.5533700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56442, 'Castets-en-Dorthe', 'Castets-en-Dorthe', 'Casteths Andorta,Casteths dAndorta,Castets,Castets-en-Dorthe,Castèths Andòrta,Castèths dAndòrta,Kastet an Dort,Kastets-an-Dort,duo er te de qu ka si tai te,Кастет ан Дорт,Кастетс-ан-Дорт,多尔特地区卡斯泰特', 44.5614600, -0.1522600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56443, 'Castets', 'Castets', 'Cap-de-la-Cote-Verte,Cap-de-la-Côte-Verte,Castets,Castets-des-Landes,Rameau-Vert', 43.8823300, -1.1457200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56444, 'Castelsarrasin', 'Castelsarrasin', 'Castellum Sarracenum,Kastel''sarrazen,Kastelsarazen,Los Sarrasins,Mont-Sarrazin,ka si te er sa la sang,kasuterusarazan,Кастелсаразен,Кастельсарразен,カステルサラザン,卡斯特尔萨拉桑', 44.0333300, 1.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56445, 'Castelnau-le-Lez', 'Castelnau-le-Lez', 'Castelnau,Castelnau-le-Lez,Castelnou de Les,Castèlnòu de Les,Kastel''no-le-Lez,Kastelno l Le,ka si tai er nuo lai lai,Кастелно л Ле,Кастельно-ле-Лез,卡斯泰尔诺莱莱', 43.6333300, 3.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56446, 'Castelnau-d''Estrétefonds', 'Castelnau-d''Estretefonds', 'Castelnau,Castelnau-d''Estretefonds,Castelnau-d''Estrétefonds,Castelnau-d’Estrétefonds,Kastel''no-d''Ehstretefon,Кастельно-д’Эстретефон', 43.7836700, 1.3590400, 'FR', '2016-12-17', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56447, 'Castelnau-Montratier', 'Castelnau-Montratier', 'Castelnau,Castelnau-la-Montagne,Castelnau-le-Montratier', 44.2666700, 1.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56448, 'Castelnau-de-Médoc', 'Castelnau-de-Medoc', 'Castelnau,Castelnau-de-Medoc,Castelnau-de-Médoc', 45.0293400, -0.7982800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56449, 'Castelnau-de-Lévis', 'Castelnau-de-Levis', 'Castelnau,Castelnau-de-Levis,Castelnau-de-Lévis', 43.9397500, 2.0849100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56450, 'Castelnau-de-Guers', 'Castelnau-de-Guers', 'Castelnau,Castelnau-de-Guers', 43.4339800, 3.4370800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56451, 'Castelnaudary', 'Castelnaudary', 'Castel Nou d''Arri,Castellnou dArri,Castellum Novum Arri,Castelnaudary,Castelnou dArri,Castèl Nòu d''Arri,Castèlnòu dArri,Kastel''nodari,Kastelnodari,ka si tai er nuo da li,kasuterunodari,Кастелнодари,Кастельнодари,Кастельнодарі,カステルノーダリ,卡斯泰尔诺达里', 43.3182900, 1.9544900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56452, 'Castelmoron-sur-Lot', 'Castelmoron-sur-Lot', 'Castel Moron dOlt,Castelmoron,Castelmoron-sur-Lot,Castèl Moron dÒlt,Castèlmoron,Kastel''moron-sjur-Lot,Kastelmoron sir Lot,luo te he pan ka si tai er mo long,Кастелморон сир Лот,Кастельморон-сюр-Лот,洛特河畔卡斯泰尔莫龙', 44.3981000, 0.4957200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56453, 'Castellane', 'Castellane', 'Castelana,Castellane,Kastelan,Kastelanas,Kastellan,ka si tai lang,kastlan,kasuteranu,Кастелан,Кастеллан,کاستلان,カステラーヌ,卡斯泰朗', 43.8500000, 6.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56454, 'Casteljaloux', 'Casteljaloux', 'Castelgelos,Casteljaloux,Castèlgelós,Kastel''zhalu,Kastelzhalu,ka si tai er ya lu,Кастелжалу,Кастельжалу,卡斯泰尔雅卢', 44.3176200, 0.0860500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56455, 'Castelginest', 'Castelginest', 'Castelginest', 43.6938200, 1.4344000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56456, 'Castelculier', 'Castelculier', 'Castelculher,Castelculhèr,Castelculier,Castèlculhèr,Kastel''kjul''e,Kastelkilije,ka si tai er qu li ye,Кастелкилије,Кастелькюлье,Кастелькюльє,卡斯泰尔屈利耶', 44.1748600, 0.6914200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56457, 'Castanet-Tolosan', 'Castanet-Tolosan', 'Castanet,Castanet Tolosan,Castanet-Tolosan,Castanet-Tolozan,Kastane Tolozan,Kastane-Tolozan,ka si ta nei tuo luo sang,Кастане Толозан,Кастане-Толозан,卡斯塔内托洛桑', 43.5159100, 1.4986400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56458, 'Castagniers', 'Castagniers', 'Castagniers', 43.7932100, 7.2328600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56459, 'Cast', 'Cast', 'Cast,Kast', 48.1571200, -4.1388900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56460, 'Casson', 'Casson', 'Casson,Kazon', 47.3876100, -1.5565400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56461, 'Cassis', 'Cassis', 'Cassis', 43.2124100, 5.5451000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56462, 'Casseneuil', 'Casseneuil', 'Casseneuil', 44.4431000, 0.6209500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56463, 'Cassel', 'Cassel', 'Cassel,Kassel', 50.8010900, 2.4852700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56464, 'Cassagnes-Bégonhès', 'Cassagnes-Begonhes', 'Cassagnes,Cassagnes-Begonhes,Cassagnes-Begonnes,Cassagnes-Bégonhès,Cassagnes-Bégonnès,Cassanhas de Begonhes,Cassanhas de Begonhés,Kasan Begon,Kasan''-Begones,Kassan''-Begone,ka sa gai bei ge nei,Касань-Бегонес,Касањ Бегон,Кассань-Бегоне,卡萨盖贝戈内', 44.1689300, 2.5308400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56465, 'Casevecchie', 'Casevecchie', 'Casevechje,Kazevekije,Kazevekk''e,Kazevekke,Казевекије,Казевеккье,Казевеккє', 42.1333300, 9.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56466, 'Carvin', 'Carvin', 'Karven,ka er wan,karfayn,karwyn,Карвен,كارفاين,کاروین,卡尔万', 50.4923500, 2.9581500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56467, 'Cartignies', 'Cartignies', 'Cartignies', 50.0929000, 3.8447300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56468, 'Carspach', 'Carspach', 'Carspach,Karspach,Karspak,Karspakh,ka er si pa ke,Карспак,Карспах,卡尔斯帕克', 47.6162800, 7.2115000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56469, 'Carsac-Aillac', 'Carsac-Aillac', 'Carsac,Carsac e Alhac,Carsac-Aillac,Carsac-de-Carlux,Karsak Ajak,Karsak-Ajak,ka er sa ke ai la ke,Карсак Ајак,Карсак-Аяк,卡尔萨克艾拉克', 44.8333300, 1.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56470, 'Cars', 'Cars', 'Cars', 45.1291700, -0.6195200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56471, 'Carry-le-Rouet', 'Carry-le-Rouet', 'Carri lo Roet,Carry,Carry-le-Rouet,Kari l''o Rue,Kari le Rue,Karri-le-Rue,Karri-le-Rueh,ka li lei lu ai,Кари ле Руе,Кари льо Руе,Карри-ле-Руэ,Каррі-ле-Руе,קארי-לה-רואה,卡里勒鲁埃', 43.3313900, 5.1523700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56472, 'Carros', 'Carros', 'Carroc,Carros,Carròs,Carròç,Karo,Karro,Karros,ka er luo,karws,Каро,Карро,Каррос,كاروس,卡尔罗', 43.7894100, 7.1839500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56473, 'Carrières-sur-Seine', 'Carrieres-sur-Seine', 'Carrieres,Carrieres-sur-Seine,Carrières,Carrières-sur-Seine,Karjer na Seni,Karr''er-sjur-Sen,Karrer-sjur-Sen,Каррьер-сюр-Сен,Каррєр-сюр-Сен,Карјер на Сени', 48.9068700, 2.1792000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56474, 'Carrières-sous-Poissy', 'Carrieres-sous-Poissy', 'Carrieres,Carrieres sur Poissy,Carrieres-sous-Poissy,Carrières,Carrières-sous-Poissy,Karjer su Poasi,Karr''er-su-Puassi,Karrer-su-Puassi,Каррьер-су-Пуасси,Каррєр-су-Пуассі,Карјер су Поаси', 48.9495200, 2.0406800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56475, 'Carqueiranne', 'Carqueiranne', 'Carcairana,Carqueirana,Carqueiranne,Carquieranne,Karkeran,Karkerann,Karkjeran,ka er qu ai la na,Каркеран,Каркеранн,Каркјеран,卡尔屈埃拉纳', 43.0953100, 6.0729700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56476, 'Carquefou', 'Carquefou', 'Carcafagus,Carquefou,Kark''ofu,Karkfu,Kerc''hfaou,Kerchfaou,ka er qu ai fu,Каркфу,Каркьофу,卡尔屈埃富', 47.2982100, -1.4902400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56477, 'Carpiquet', 'Carpiquet', 'Carpiquet', 49.1852200, -0.4462300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56478, 'Carpentras', 'Carpentras', 'Carpentoracte,Carpentras,Carpentràs,Karpantra,Karpantras,ka pang te la,kaleupangteula,karupantora,krpantrh,Карпантра,Карпантрас,کرپانتره,ཁར་པེན་ཏྲ།,カルパントラ,卡庞特拉,카르팡트라', 44.0500000, 5.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56479, 'Caromb', 'Caromb', 'Caromb,Karom,Karomb,Karon,ka long,Каром,Каромб,Карон,卡龙', 44.1107600, 5.1058000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56480, 'Caro', 'Caro', 'Caro,Karozh', 47.8642900, -2.3192400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56481, 'Carnoules', 'Carnoules', 'Carnolas,Carnoules,Karnul,Karnul'',ka er nu lai,karnwlys,Карнул,Карнуль,كارنوليس,卡尔努莱', 43.3019300, 6.1880400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56482, 'Carnac', 'Carnac', 'Alineamientos de Carnac,Carnac,Karnag,Karnak,ka er na ke,karnak karkal,karunakku,Карнак,கர்னாக் கற்கள்,カルナック,卡尔纳克', 47.5835100, -3.0788400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56483, 'Carmaux', 'Carmaux', 'Carmauc,Carmaux,Carmauç,Karmo,ka er mo,Кармо,卡尔莫', 44.0509900, 2.1579500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56484, 'Carling', 'Carling', 'Carling', 49.1676100, 6.7159600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56485, 'Carlepont', 'Carlepont', 'Carlepont', 49.5143800, 3.0232700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56486, 'Carignan', 'Carignan', 'Carignan,Ivoy', 49.6315900, 5.1679600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56487, 'Carignan-de-Bordeaux', 'Carignan-de-Bordeaux', 'Carinhan,Carinhan de Bordeu,Carinhan de Bordèu,Karin''jan-de-Bordo,Karinan de Bordo,ka li ni ang de bo er duo,Кариньян-де-Бордо,Карињан де Бордо,卡里尼昂德博尔多', 44.8000000, -0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56488, 'Carhaix-Plouguer', 'Carhaix-Plouguer', 'Carhaix,Carhaix-Plouguer,Carophesium,Karaez,Karaez-Plouger,Karaez-Plougêr,Kare Pluger,Kare-Pluge,Kare-Pluger,ka lai pu lu gai,kare=purugeru,karh-plwgh,Каре Плугер,Каре-Плуге,Каре-Плугер,کاره-پلوگه,カレ＝プルゲール,卡赖普卢盖', 48.2759400, -3.5732600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56489, 'Cargèse', 'Cargese', 'Cargese,Carghjese,Cargèse,Karnkeze,Karzhez,Karđeze,Le Village de Cargese,Le Village de Cargèse,Καργκέζε,Каржез,Карђезе', 42.1362900, 8.5958600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56490, 'Carentoir', 'Carentoir', 'Carentoir,Karantoar,Karantoer,Karantuar,Plebs Carentorensis,ka lang tu wa,Карантоар,Карантуар,卡朗图瓦', 47.8166700, -2.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56491, 'Carentan', 'Carentan', 'Carantan,Carentan,Carenton,Karantan,ka lang tang,karantan,kerantan,qrntn,Καραντάν,Карантан,קרנטן,கேரன்டான்,ካረንታን,カランタン,卡朗唐', 49.3031200, -1.2480600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56492, 'Carcès', 'Carces', 'Carcers,Carces,Carcès,Karse,Karses,ka er sai,Карсе,Карсес,卡尔塞', 43.4763100, 6.1830800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56493, 'Carcassonne', 'Carcassonne', 'CCF,Carcaso,Carcasona,Carcasonne,Carcassona,Carcassonne,Karkason,Karkasona,Karkasonas,Karkasson,Karkassonn,Karkasuno,ka er ka song,kaleukason,kar ka sxn,karkaswn,karukason''nu,qrqshwnt,qrqswn,Καρκασσόν,Каркасон,Каркассонн,קרקסון,قرقشونة,کارکاسون,การ์กาซอน,カルカソンヌ,卡尔卡松,카르카손', 43.2166700, 2.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56494, 'Carcans', 'Carcans', 'Carcan,Carcans,Karkan,ka er kang,Каркан,卡尔康', 45.0786900, -1.0442900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56495, 'Carbonne', 'Carbonne', 'Carbona,Carbonne,Karbon,Karbonn,ka er bang,Карбон,Карбонн,卡尔邦', 43.2985700, 1.2252000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56496, 'Carbon-Blanc', 'Carbon-Blanc', 'Carbon Blanc,Carbon-Blanc,Karbon Blan,Karbon-Blan,Lo Carbon Blanc,ka er bang bu lang ke,Карбон Блан,Карбон-Блан,卡尔邦布朗克', 44.8964200, -0.5010700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56497, 'Carantec', 'Carantec', 'Carantec,Karanteg,Karantek,ka lang tai ke,karantekku,Карантек,カランテック,卡朗泰克', 48.6681100, -3.9154500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56498, 'Caraman', 'Caraman', 'Caraman,Floreal,Floréal', 43.5327100, 1.7600200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56499, 'Capvern', 'Capvern', 'Capvern,Capvèrn,Kapvern,ka pu wei er en,Капверн,卡普韦尔恩', 43.1035700, 0.3160400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56500, 'Cappelle-la-Grande', 'Cappelle-la-Grande', 'Cappelle,Cappelle-la-Grand,Cappelle-la-Grande,Kapel la Grand,Kapelle,Kappel''-la-Grand,da ka pei lei,Капел ла Гранд,Каппель-ла-Гранд,大卡佩勒', 50.9997900, 2.3584800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56501, 'Cappelle-en-Pévèle', 'Cappelle-en-Pevele', 'Cappelle,Cappelle-en-Pevele,Cappelle-en-Pévèle,Kapel an Pevel,Kappel''-an-Pevel'',ka pei lei ang pei wei lei,Капел ан Певел,Каппель-ан-Певель,卡佩勒昂佩韦勒', 50.5101100, 3.1713300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56502, 'Capinghem', 'Capinghem', 'Capinghem,Kapengem,Kapingam,ka pan gai mu,Капенгем,Капингам,卡潘盖姆', 50.6455100, 2.9619300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56503, 'Capestang', 'Capestang', 'Cabestanh,Capestang,Capestanh,Kapestan,ka pei si tang,Капестан,卡佩斯唐', 43.3279100, 3.0444700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56504, 'Capendu', 'Capendu', 'Campendut,Camppendut,Capendu,Kapandi,Kapandju,ka pang di,Капанди,Капандю,卡庞迪', 43.1859600, 2.5567700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56505, 'Capdenac-Gare', 'Capdenac-Gare', 'Capdenac,Capdenac-Gara,Capdenac-Gare,Kadenak-Gar,Kapdenak Gar,Kapdenak-Gar,Sent Julian dEmpara e Livinhac lo Baish,ka pu de na ke jia er,Каденак-Гар,Капденак Гар,Капденак-Гар,卡普德纳克加尔', 44.5756700, 2.0807900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56506, 'Cap-d’Ail', 'Cap-d''Ail', 'Cap-d''Ail,Cap-d’Ail', 43.7219200, 7.4068500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56507, 'Capbreton', 'Capbreton', 'Cap Berton,Capberton,Capbreton,Capbrutus,Kabreton,Kapbreton,ka pu bu lei tong,kappuburuton,Кабретон,Капбретон,カップブルトン,卡普布雷通', 43.6421600, -1.4281600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56508, 'Cany-Barville', 'Cany-Barville', 'Cany,Cany-Barville', 49.7888500, 0.6370400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56509, 'Cantin', 'Cantin', 'Cantin,Kanten,kang tan,Кантен,康坦', 50.3088500, 3.1276500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56510, 'Cantenay-Épinard', 'Cantenay-Epinard', 'Cantenay,Cantenay-Epinard,Cantenay-Épinard,Epinard Cantenay,Kantene-Epinar,Kantne Epinar,kang te nai ai pi na er,Кантене-Епінар,Кантне Епинар,康特奈埃皮纳尔', 47.5350300, -0.5689900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56511, 'Cantenac', 'Cantenac', 'Cantenac', 45.0281600, -0.6531200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56512, 'Canteleu', 'Canteleu', 'Canteleu,Kantele,Кантеле', 49.4406500, 1.0245900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56513, 'Cantaron', 'Cantaron', 'Cantaron', 43.7586500, 7.3187600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56514, 'Canon', 'Canon', 'Canon', 49.0738000, -0.0921900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56515, 'Canohès', 'Canohes', 'Canoes,Canohes,Canohès,Cànoes,Kanoe,Kanoes,kang ao ai,Каное,Каноес,康奥埃', 42.6546100, 2.8363300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56516, 'Cannes-Écluse', 'Cannes-Ecluse', 'Cannes-Ecluse,Cannes-Écluse,Kan Ekliz,Kann-Ekljuz,Кан Еклиз,Канн-Еклюз', 48.3630300, 2.9874800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56517, 'Cannes', 'Cannes', 'CEQ,Canas,Canes,Cannes,Canua,Chalier,Châlier,Gorad Kany,Kan,Kanai,Kann,Kannad,Kannas,Kannash,Kannes,Kanni,Kanntae,Kanny,jia na,kaina,kan,kan''nu,kana,kang cheng,kn,Κάννες,Горад Каны,Кан,Канн,Каннаш,Канни,Каннтæ,Канны,Կանն,קאן,كان,کان,کن,कान,कैन,ਕੈਨ,கான்,กาน,კანი,カンヌ,康城,戛纳,칸', 43.5513500, 7.0127500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56518, 'Cangey', 'Cangey', 'Cangey', 47.4671800, 1.0605100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56519, 'Canet', 'Canet', 'Canet', 43.2274400, 2.8480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56520, 'Canet-en-Roussillon', 'Canet-en-Roussillon', 'Canet de Rosselhon,Canet de Rossello,Canet de Rosselló,Canet-en-Roussillon,Canetum,Kane-an-Russijon,Kanet an Rusijon,kane=tan=rushiyon,lu xi long de qu ka nei,Кане-ан-Руссийон,Кане-ан-Руссійон,Канет ан Русијон,カネ＝タン＝ルシヨン,鲁西隆地区卡内', 42.7000000, 3.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56521, 'Canéjan', 'Canejan', 'Canejan,Canéjan,Kanezhan,ka nei rang,Канежан,卡内让', 44.7666700, -0.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56522, 'Candillargues', 'Candillargues', 'Candillargues,Come-de-la-Palus,Côme-de-la-Palus', 43.6205200, 4.0692400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56523, 'Candé-sur-Beuvron', 'Cande-sur-Beuvron', 'Cande,Cande-sur-Beuvron,Candé,Candé-sur-Beuvron,Kande na Bevronu,Kande-sjur-Bevron,bo fu luo ne he pan kang dai,Канде на Беврону,Канде-сюр-Беврон,伯夫罗讷河畔康代', 47.4949900, 1.2593700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56524, 'Candé', 'Cande', 'Cande,Candé,Kande,Канде', 47.5615800, -1.0361900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56525, 'Cancon', 'Cancon', 'Cancon,Cancor,Kankon,kang kong,Канкон,康孔', 44.5354300, 0.6252000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56526, 'Cancale', 'Cancale', 'Cancale,Gorad Kankal'',Kankal,Kankal'',Kankaven,kang ka er,kankaru,Горад Канкаль,Канкал,Канкаль,カンカル,康卡尔', 48.6760100, -1.8523100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56527, 'Camps-la-Source', 'Camps-la-Source', 'Camps,Camps les Brignols,Camps-la-Source,Kam-la-Surs,Kan la Surs,kang pu la su er si,Кам-ла-Сурс,Кан ла Сурс,康普拉苏尔斯', 43.3864100, 6.0866100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56528, 'Campsas', 'Campsas', 'Campsas', 43.8959100, 1.3267700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56529, 'Camphin-en-Pévèle', 'Camphin-en-Pevele', 'Camphin,Camphin-Pevele,Camphin-Pevèle,Camphin-en-Pevele,Camphin-en-Pévèle', 50.5956100, 3.2608200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56530, 'Camphin-en-Carembault', 'Camphin-en-Carembault', 'Camphin,Camphin-en-Carembault', 50.5119600, 2.9871000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56531, 'Campénéac', 'Campeneac', 'Campaniacum,Campeneac,Campénéac,Kampeneak,Kempenieg,kang pei nei a ke,Кампенеак,康佩内阿克', 47.9573300, -2.2927700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56532, 'Campbon', 'Campbon', 'Cambidonnum,Campbon,Kambon,kang pu bang,Камбон,康普邦', 47.4131000, -1.9685700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56533, 'Campan', 'Campan', 'Campan,Kampan,kang pang,Кампан,康庞', 43.0158700, 0.1784600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56534, 'Campagne-lès-Hesdin', 'Campagne-les-Hesdin', 'Campagne,Campagne-les-Hesdin,Campagne-lès-Hesdin,Le Pelletier-sur-Canche,Lepelletier-sur-Canche', 50.3972400, 1.8749400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56535, 'Camors', 'Camors', 'Camors,Kamor,Kamorzh,kang ao er,Камор,康奥尔', 47.8473900, -2.9998100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56536, 'Camon', 'Camon', 'Camon', 49.8876400, 2.3448600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56537, 'Camiers', 'Camiers', 'Camie,Camiers,Camié,Kam''e,Kame,Kamijer,ka mi ye,kamyyrs,Камијер,Камье,Камє,كامييرس,卡米耶', 50.5715300, 1.6132500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56538, 'Cambronne-lès-Ribécourt', 'Cambronne-les-Ribecourt', 'Cambronne,Cambronne-les-Ribecourt,Cambronne-lès-Ribécourt,Kambron le Ribekur,Kambronn-le-Ribekur,kang bu long lai li bei ku er,Камброн ле Рибекур,Камбронн-ле-Рибекур,康布龙莱里贝库尔', 49.5071100, 2.8979700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56539, 'Cambronne-lès-Clermont', 'Cambronne-les-Clermont', 'Cambronne,Cambronne-le-Mont-Brutus,Cambronne-les-Clermont,Cambronne-lès-Clermont,Kambron le Klermon,Kambronn-le-Klermon,kang bu long lai ke lai meng,Камброн ле Клермон,Камбронн-ле-Клермон,康布龙莱克莱蒙', 49.3302200, 2.3992800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56540, 'Cambremer', 'Cambremer', 'Cambremer', 49.1519200, 0.0476000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56541, 'Cambrai', 'Cambrai', 'Cambrai,Cambria,Cameracum,Gorad Kambreh,Kambre,Kambrė,Kimbre,Kimbré,XCB,kambryh,kanbure,kang bu lei,kangbeule,kmbrh,qmbrh,Горад Камбрэ,Камбре,קמברה,كامبريه,کمبره,ካምብሬ,カンブレー,康布雷,캉브레', 50.1666700, 3.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56542, 'Cambo-les-Bains', 'Cambo-les-Bains', 'Cambo,Cambo-les-Bains,Cambon,Kambo le Ben,Kambo-le-Ben,Kanbo,La Montagne,kanbo=re=ban,kang bo lai ban,Камбо ле Бен,Камбо-ле-Бен,カンボ＝レ＝バン,康博莱班', 43.3585100, -1.4010500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56543, 'Camblanes-et-Meynac', 'Camblanes-et-Meynac', 'Camblanas e Meinac,Camblanes,Camblanes-et-Meynac,Kamblan et Menak,Kamblan-e-Mejnak,kang bu la nei he mei na ke,Камблан ет Менак,Камблан-е-Мейнак,康布拉内和梅纳克', 44.7655100, -0.4865300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56544, 'Camblain-Châtelain', 'Camblain-Chatelain', 'Camblain-Chatelain,Camblain-Châtelain', 50.4835500, 2.4552100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56545, 'Cambes-en-Plaine', 'Cambes-en-Plaine', 'Cambes,Cambes-en-Plaine', 49.2316100, -0.3854000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56546, 'Cambes', 'Cambes', 'Cambes', 44.7317900, -0.4626100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56547, 'Camaret-sur-Mer', 'Camaret-sur-Mer', 'Camaret,Camaret-sur-Mer,Kamare na Moru,Kamare-sjur-Mer,Kameled,bin hai ka ma lei,kamare=shuru=meru,Камаре на Мору,Камаре-сюр-Мер,カマレ＝シュル＝メール,滨海卡马雷', 48.2749700, -4.5961500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56548, 'Camaret-sur-Aigues', 'Camaret-sur-Aigues', 'Camaret,Camaret dEgues,Camaret-sur-Aigues,Camaret-sur-Eygues,Kamare sir Eg,Kamare-sjur-Eg,Kamare-sjur-Ehg,ai ju e he pan ka ma lei,Камаре сир Ег,Камаре-сюр-Ег,Камаре-сюр-Эг,艾居厄河畔卡马勒', 44.1640500, 4.8742400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56549, 'Camarès', 'Camares', 'Camares,Camares-sur-Dourdon,Camarès', 43.8220800, 2.8800500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56550, 'Calvisson', 'Calvisson', 'Calvisson,Cauvicon,Cauviçon,Kal''visson,Kalvison,ka er wei song,Калвисон,Кальвиссон,Кальвіссон,卡尔维松', 43.7869600, 4.1962600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56551, 'Calvi', 'Calvi', 'CLY,Calvi,Calvi - Korsika,Kal''vi,Kalvi,ka er wei,Калви,Кальви,卡尔维', 42.5660400, 8.7571300, 'FR', '2016-11-03', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56552, 'Caluire-et-Cuire', 'Caluire-et-Cuire', 'Caluire,Caluire et Cuire,Caluire-et-Cuire,Kalir e Kir,Kaljuir-e-Kjuir,Scevola,Scévola,kallileuekileu,karyuiru=e=kyuiru,klwyyr akwyyr,Калир е Кир,Калюїр-е-Кюїр,کلوئیر اکوئیر,カリュイール＝エ＝キュイール,칼리르에키르', 45.7904100, 4.8411200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56553, 'Calonne-sur-la-Lys', 'Calonne-sur-la-Lys', 'Calonne,Calonne-su-el-Lys,Calonne-sur-la-Lys,Kalon sir la Lis,Kalonn-sjur-la-Li,Kalonn-sjur-la-Lis,kalwny swr la lys,li si he pan ka luo ne,Калон сир ла Лис,Калонн-сюр-ла-Ли,Калонн-сюр-ла-Ліс,كالوني سور لا ليس,利斯河畔卡洛讷', 50.6229200, 2.6166400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56554, 'Calonne-Ricouart', 'Calonne-Ricouart', 'Calonne,Calonne-Ricouart,Kalon Rikuar,Kalonn-Rikuar,ka luo ne li ku a er,kalwny rykwrt,Калон Рикуар,Калонн-Рикуар,كالوني ريكورت,卡洛讷里库阿尔', 50.4850400, 2.4733500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56555, 'Calmont', 'Calmont', 'Calmont', 44.2488300, 2.5120100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56556, 'Calmont', 'Calmont', 'Calmont,Culmont', 43.2871800, 1.6303100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56557, 'Callian', 'Callian', 'Callian', 43.6231000, 6.7519000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56558, 'Callas', 'Callas', 'Callas', 43.5923700, 6.5373800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56559, 'Callac', 'Callac', 'Callac,Callacum,Kalak,Kallag,Kallak,ka la ke,Калак,Каллак,卡拉克', 48.4029200, -3.4280000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56560, 'Calenzana', 'Calenzana', 'Calenzana,Kalencana,Каленцана', 42.5083900, 8.8559400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56561, 'Calais', 'Calais', 'CQF,Calais,Cales,Calesium,Calés,Gorad Kale,Kalai,Kale,Kale shaary,Kales,Kalē,Kalė,jia lai,kale,kalh,kalle,kalyh,kare,Καλαί,Горад Кале,Кале,Кале шаары,Կալե,קאלה,كاليه,کاله,کالے,கலே,กาแล,カレー,加来,加莱,칼레', 50.9519400, 1.8563500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56562, 'Cajarc', 'Cajarc', 'Cajarc,Kazhar,Kazhark,ka ya ke,Кажар,Кажарк,卡雅克', 44.4854600, 1.8426100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56563, 'Caissargues', 'Caissargues', 'Caissargues,Kesarg,Kessarg,kai sa er gai,Кесарг,Кессарг,凯萨尔盖', 43.7950900, 4.3795500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56564, 'Cairon', 'Cairon', 'Cairon,Keron,kai long,Керон,凯龙', 49.2401700, -0.4504600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56565, 'Cailloux-sur-Fontaines', 'Cailloux-sur-Fontaines', 'Cailloux,Cailloux-sur-Fontaines', 45.8514700, 4.8758500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56566, 'Cahuzac-sur-Vère', 'Cahuzac-sur-Vere', 'Cahusac-sur-Vere,Cahusac-sur-Vère,Cahuzac,Cahuzac-sur-Vere,Cahuzac-sur-Vère,Cuhuzac-sur-Vere', 43.9826800, 1.9105200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56567, 'Cahors', 'Cahors', 'Cadurcum,Cahors,Caors,Gorad Kaor,Kaor,ZAO,ka ao er,kaoleu,kaoru,kywr,Горад Каор,Каор,קאור,کئور,カオール,卡奥尔,카오르', 44.4491000, 1.4366300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56568, 'Cahagnes', 'Cahagnes', 'Cahagnes,Kaan'',Kan,ka a gai,Каань,Кањ,卡阿盖', 49.0663100, -0.7686900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56569, 'Cagny', 'Cagny', 'Cagny', 49.8621700, 2.3426600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56570, 'Cagny', 'Cagny', 'Cagny', 49.1458000, -0.2563000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56571, 'Cagnes-sur-Mer', 'Cagnes-sur-Mer', 'Cagnes,Cagnes-sur-Mer,Canha de Mar,Kan na Moru,Kan sjur Mer,Kan''-sjur-Mer,XCG,ka nie,kajnys swr myr,kanyu=shuru=meru,kanyuswileumeleu,kny swr mrn,Кан сюр Мер,Кань-сюр-Мер,Кањ на Мору,كاجنيس سور مير,کنی سور مرن,カーニュ＝シュル＝メール,卡涅,카뉴쉬르메르', 43.6645900, 7.1533900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56572, 'Cagnac-les-Mines', 'Cagnac-les-Mines', 'Bon-Air,Cagnac,Cagnac-les-Mines,Roc-la-Montagne', 43.9844500, 2.1422700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56573, 'Caëstre', 'Caestre', 'Caestre,Caëstre', 50.7583800, 2.6027400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56574, 'Caen', 'Caen', 'CFR,Cadomum,Cadum,Caen,Can,Caën,Caðum,Gorad Kan,Kaen,Kan,Kana,Kanas,Kāna,k xng,ka ang,kam,kan,kang,kayn,kyn,qn,Καέν,Горад Кан,Кан,Կան,קן,كاين,کان,کین,कां,கன்,ก็อง,კანი,ካየን,カーン,卡昂,캉', 49.1858500, -0.3591200, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56575, 'Cadolive', 'Cadolive', 'Ca dOliva,Cadolive,Kadoliv,ka duo li wei,Кадолив,Кадолів,卡多利韦', 43.3969400, 5.5452600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56576, 'Cadillac', 'Cadillac', 'Cadilhac,Cadillac', 44.6363100, -0.3170200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56577, 'Caderousse', 'Caderousse', 'Caderousse', 44.1025200, 4.7567900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56578, 'Cadenet', 'Cadenet', 'Cadenet,Kadene,Kadne,ka dai na,kadone,Кадене,Кадне,カドネ,卡代纳', 43.7344500, 5.3749900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56579, 'Caden', 'Caden', 'Caden,Kadan,Kaden,ka dang,Кадан,卡当', 47.6312400, -2.2870400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56580, 'Cadaujac', 'Cadaujac', 'Cadaujac,Kadozhak,ka duo ya ke,Кадожак,卡多雅克', 44.7543700, -0.5312800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56581, 'Cadalen', 'Cadalen', 'Cadalen', 43.8493300, 1.9808900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56582, 'Cachan', 'Cachan', 'Cachan,Cachon,Caticantus,Kashan,ka shang,kashan,kasyang,kshan,Кашан,کشان,カシャン,卡尚,카샹', 48.7963200, 2.3366100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56583, 'Cabris', 'Cabris', 'Cabris,Kabri,Kabris,ka bu li,kabrys  alalb aljblyt,Кабри,Кабрис,Кабрі,كابريس، الألب الجبلية,卡布里', 43.6531700, 6.8717200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56584, 'Cabriès', 'Cabries', 'Cabries,Cabriès,Cabriés,Kabrie,Kabries,Kabrije,ka bu lie si,Кабриес,Кабрије,Кабріє,卡布列斯', 43.4412700, 5.3788400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56585, 'Cabrières', 'Cabrieres', 'Cabrieres,Cabrières', 43.9038900, 4.4709400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56586, 'Cabourg', 'Cabourg', 'Kabur,Kabura,Kabūra,ka bu er,kabuleu,kaburu,Кабур,カブール,卡布尔,카부르', 49.2911000, -0.1133000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56587, 'Cabestany', 'Cabestany', 'Cabestany,Kabestani,ka bei si ta ni,kabstany,Кабестани,Кабестані,کابستانی,کابستانے,卡贝斯塔尼', 42.6813200, 2.9412200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56588, 'Cabasse', 'Cabasse', 'Cabasse', 43.4282300, 6.2209100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56589, 'Cabariot', 'Cabariot', 'Cabariot,Cabarrot,Kabar''o,Kabario,Kabarjo,ka ba li ao,Кабарио,Кабарйо,Кабарьо,Կաբարիո,卡巴里奥', 45.9264500, -0.8574100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56590, 'Cabannes', 'Cabannes', 'Cabannes', 43.8601500, 4.9519200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56591, 'Cabanac-et-Villagrains', 'Cabanac-et-Villagrains', 'Cabanac e Vilagrans,Cabanac-et-Villagrains,Kabanak e Vilagren,Kabanak-e-Villagren,Kabanak-eh-Villagren,ka ba na ke he wei la ge lan,Кабанак е Вилагрен,Кабанак-е-Виллагрен,Кабанак-е-Віллагрен,Кабанак-э-Виллагрен,卡巴纳克和维拉格兰', 44.6000000, -0.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56592, 'Buzet-sur-Tarn', 'Buzet-sur-Tarn', 'Bize sir Tarn,Bjuze-sjur-Tarn,Bjuzet-sjur-Tarn,Buset de Tarn,Buzet,Buzet-sur-Tarn,ta er en he pan bi ze,Бизе сир Тарн,Бюзе-сюр-Тарн,Бюзет-сюр-Тарн,塔尔恩河畔比泽', 43.7797700, 1.6330100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56593, 'Buzet-sur-Baïse', 'Buzet-sur-Baise', 'Bize sir Bais,Bjuze-sjur-Baiz,Buseth,Busèth,Buzet,Buzet-sur-Baise,Buzet-sur-Baïse,bai si he pan bi ze,byuze=shuru=baizu,Бизе сир Баис,Бюзе-сюр-Баиз,Бюзе-сюр-Баїз,ビュゼ＝シュル＝バイズ,拜斯河畔比泽', 44.2581100, 0.2980900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56594, 'Buzançais', 'Buzancais', 'Bizanse,Bjuzanse,Buzancais,Buzançais,La Fraternite-sur-Indre,La Fraternité-sur-Indre,bi cang sai,Бизансе,Бюзансе,比藏赛', 46.8887700, 1.4195000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56595, 'Buxy', 'Buxy', 'Biksi,Bjuksi,Buxy,Buxy-le-National,Grand-Buxy,Бикси,Бюкси,Бюксі', 46.7136900, 4.7042700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56596, 'Buxières-les-Mines', 'Buxieres-les-Mines', 'Buxieres,Buxieres-les-Mines,Buxières-les-Mines,Buxiéres', 46.4688600, 2.9614300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56597, 'Buxerolles', 'Buxerolles', 'Buxerolles', 46.6166700, 0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56598, 'Butry-sur-Oise', 'Butry-sur-Oise', 'Bitri sir Oaz,Bjutri-sjur-Uaz,Butry,Butry-sur-Oise,wa ci he pan bi te li,Битри сир Оаз,Бютри-сюр-Уаз,Бютрі-сюр-Уаз,瓦兹河畔比特里', 49.0883700, 2.1991600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56599, 'Bussy-Saint-Georges', 'Bussy-Saint-Georges', 'Bisi Sen Zhorzh,Bjussi-Sen-Zhorzh,Bussi Sen Zorz,Bussy-Saint-Georges,bi xi sheng qiao zhi,Биси Сен Жорж,Бюсси-Сен-Жорж,Бюссі-Сен-Жорж,Բուսսի Սեն Ժորժ,比西圣乔治', 48.8409900, 2.7016500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56600, 'Bussières', 'Bussieres', 'Bussieres,Bussières', 45.8362100, 4.2685500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56601, 'Bussière-Poitevine', 'Bussiere-Poitevine', 'Bussiere,Bussiere-Poitevine,Bussiere-Portevine,Bussiere-l''Egalite,Bussière,Bussière-Poitevine,Bussière-Portevine,Bussière-l''Egalité', 46.2354300, 0.9053000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56602, 'Bussière-Galant', 'Bussiere-Galant', 'Bisjer Galan,Bjus''er-Galan,Bussiera Galand,Bussiera e Sent Nicolau,Bussiere-Galant,Bussière-Galant,bi xi ai jia lang,Бисјер Галан,Бюсьер-Галан,Бюсьєр-Галан,比西埃加朗', 45.6270200, 1.0364000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56603, 'Bussière-Dunoise', 'Bussiere-Dunoise', 'Bussiere,Bussiere-Dunoise,Bussière,Bussière-Dunoise', 46.2589800, 1.7621600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56604, 'Bussang', 'Bussang', 'Bisan,Bjussan,Bussang,bi sang,Бисан,Бюссан,比桑', 47.8844900, 6.8527200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56605, 'Bussac-sur-Charente', 'Bussac-sur-Charente', 'Bisak sir Sharant,Bjussak-sjur-Sharant,Byusak syur Sarant,sha lang te he pan bi sa ke,Бисак сир Шарант,Бюссак-сюр-Шарант,Բյուսակ սյուր Շարանտ,沙朗特河畔比萨克', 45.7833300, -0.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56606, 'Busnes', 'Busnes', 'Beunes,Bin,Bjun,bi ne,bwsnys,Бин,Бюн,بوسنيس,比讷', 50.5878100, 2.5182700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56607, 'Busigny', 'Busigny', 'Bizini,Bjuzin''i,Busigny,bi xi ni,Бизињи,Бюзиньи,Бюзіньї,比西尼', 50.0342400, 3.4671300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56608, 'Bury', 'Bury', 'Bury', 49.3130700, 2.3440100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56609, 'Buros', 'Buros', 'Biro,Bjuros,Buros,Buròs,Биро,Бюрос', 43.3500000, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56610, 'Burnhaupt-le-Haut', 'Burnhaupt-le-Haut', 'Bjurno-le-O,Burnhaupt-le-Haut,Burnkhaupt le O,Oberburnhaupt,bi er nuo pu lai ao,Бурнхаупт ле О,Бюрно-ле-О,比尔诺普莱奥', 47.7294500, 7.1461000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56611, 'Burnhaupt-le-Bas', 'Burnhaupt-le-Bas', 'Bjurno-le-Ba,Burnhaupt,Burnhaupt-le-Bas,Burnkhaupt le Bas,Niederburnhaupt,bi er nuo pu lai ba,Бурнхаупт ле Бас,Бюрно-ле-Ба,比尔诺普莱巴', 47.7172100, 7.1614900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56612, 'Burlats', 'Burlats', 'Burlats', 43.6363300, 2.3187900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56613, 'Burie', 'Burie', 'Biri,Bjuri,Byuri,bi li ye,Бири,Бюри,Бюрі,Բյուրի,比里耶', 45.7727300, -0.4228900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56614, 'Bures-sur-Yvette', 'Bures-sur-Yvette', 'Bir sir Ivet,Bjur-sjur-Ivett,Bures,Bures-Orsay,Bures-sur-Yvette,yi wei te he pan bi er,Бир сир Ивет,Бюр-сюр-Іветт,Бюр-сюр-Иветт,伊维特河畔比尔', 48.6998100, 2.1706400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56615, 'Burbure', 'Burbure', 'Birbir,Bjurbjur,Burbure,bi er bi er,bwrbwry,Бирбир,Бюрбюр,بوربوري,比尔比尔', 50.5366300, 2.4689700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56616, 'Bully-les-Mines', 'Bully-les-Mines', 'Bili le Men,Bjulli-le-Min,Bully,Bully-les-Mines,bi li lai mi ne,bwly lyh mynys,Били ле Мен,Бюлли-ле-Мин,Бюллі-ле-Мін,بولي ليه مينيس,比利莱米讷', 50.4438000, 2.7270300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56617, 'Bully', 'Bully', 'Bully', 49.1015500, -0.4082500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56618, 'Bully', 'Bully', 'Bully', 45.8520500, 4.5819500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56619, 'Bullion', 'Bullion', 'Bullion', 48.6228500, 1.9902400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56620, 'Bulgnéville', 'Bulgneville', 'Bjul''n''evil'',Bulgneville,Bulgnéville,Bulnevil,bi er ge wei er,Булњевил,Бюльньевиль,Бюльньєвіль,比尔格维尔', 48.2069400, 5.8343000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56621, 'Buis-les-Baronnies', 'Buis-les-Baronnies', 'Bi le Baroni,Bjui-le-Baronni,Buis,Buis-les-Baronnies,Le Buis-les-Baronnies,Lo Bois,Lo Bois dei Baronias,Lo Bois dei Baroniás,bi yi lai ba luo nie,Би ле Барони,Бюї-ле-Баронні,比伊莱巴罗涅', 44.2737300, 5.2722000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56622, 'Buironfosse', 'Buironfosse', 'Bironfos,Bjuironfos,Bjuironfoss,Buironfosse,bi long fu si,Биронфос,Бюиронфос,Бюїронфосс,比龙福斯', 49.9665900, 3.8358700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56623, 'Buhl', 'Buhl', 'Buhl', 47.9280600, 7.1871900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56624, 'Bugeat', 'Bugeat', 'Bizha,Bjuzha,Bugeat,Bujac,bi ya,Бижа,Бюжа,比雅', 45.5975600, 1.9288700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56625, 'Buellas', 'Buellas', 'Bijela,Bjuehlla,Bjuella,Buellas,Byuella,bu ai la si,bwylas,Бијела,Бюелла,Бюэлла,Բյուելլա,بويلاس,布埃拉斯', 46.2111000, 5.1322000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56626, 'Bueil', 'Bueil', 'Bueil', 48.9318900, 1.4425700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56627, 'Bucy-le-Long', 'Bucy-le-Long', 'Bucy,Bucy-le-Long', 49.3907200, 3.3958200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56628, 'Bucquoy', 'Bucquoy', '', 50.1397300, 2.7103600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56629, 'Buchy', 'Buchy', 'Buchy', 49.5851300, 1.3585200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56630, 'Buchères', 'Bucheres', 'Bucheres,Buchères', 48.2350800, 4.1131000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56631, 'Buchelay', 'Buchelay', 'Bishle,Bjushle,Buchelay,Бишле,Бюшле', 48.9792600, 1.6702600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56632, 'Buc', 'Buc', '', 48.7762700, 2.1257700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56633, 'Bubry', 'Bubry', 'Bibri,Bjubri,Bubri,Bubry,bi bu li,Бибри,Бюбри,Бюбрі,比布里', 47.9633600, -3.1710800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56634, 'Bû', 'Bu', 'Bi,Bju,Bu,Bû,bi zhen,Би,Бю,比镇', 48.7970500, 1.4970200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56635, 'Bry-sur-Marne', 'Bry-sur-Marne', 'Bri na Marni,Bri-sjur-Marn,Bry,Bry-sur-Marne,ma en he pan bu li,Бри на Марни,Бри-сюр-Марн,Брі-сюр-Марн,برے-سر-مرنے,马恩河畔布里', 48.8381100, 2.5248800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56636, 'Bruz', 'Bruz', 'Briz,Brju,Brjuz,Bruxa,Bruz,Бриз,Брю,Брюз', 48.0242000, -1.7459100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56637, 'Bruyères-sur-Oise', 'Bruyeres-sur-Oise', 'Brijer sir Oaz,Brjuer-sjur-Uaz,Bruyeres,Bruyeres-sur-Oise,Bruyères,Bruyères-sur-Oise,wa ci he pan bu lu yi ai lei,Бријер сир Оаз,Брюер-сюр-Уаз,Брюєр-сюр-Уаз,瓦兹河畔布吕伊埃雷', 49.1575600, 2.3257700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56638, 'Bruyères-le-Châtel', 'Bruyeres-le-Chatel', 'Brijer le Shatel,Brjuer-le-Shatel'',Bruyeres,Bruyeres-Libre,Bruyeres-le-Chatel,Bruyères,Bruyères-Libre,Bruyères-le-Châtel,bu lu yi ai lei lei sha te,Бријер ле Шател,Брюер-ле-Шатель,Брюєр-ле-Шатель,布吕伊埃雷勒沙特', 48.5886800, 2.1899100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56639, 'Bruyères-et-Montbérault', 'Bruyeres-et-Montberault', 'Brijer e Monbero,Brjuer-e-Monbero,Brjujer-eh-Monbero,Bruyeres,Bruyeres e Montberault,Bruyeres-et-Montberault,Bruyères,Bruyères e Montbérault,Bruyères-et-Montbérault,bu lu ye er he meng bei luo,Бријер е Монберо,Брюйер-э-Монберо,Брюєр-е-Монберо,布吕耶尔和蒙贝罗', 49.5253500, 3.6636900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56640, 'Bruyères', 'Bruyeres', 'Brijer,Brjuer,Bruerium,Bruyeres,Bruyères,bu lu yi ai lei,Бријер,Брюер,Брюєр,布吕伊埃雷', 48.2070900, 6.7184500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56641, 'Brunstatt', 'Brunstatt', 'Brjonstat,Brjunstat,Brunshtat,Brunstatt,bu lan si ta,Брунштат,Брюнстат,Брёнстат,布兰斯塔', 47.7200400, 7.3178400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56642, 'Brunoy', 'Brunoy', 'Brinoa,Brinoj,Brjunua,Brunoy,beulwinua,brwnwa,bu lu nu wa,buryunowa,Бриноа,Бриној,Брюнуа,برونوآ,ブリュノワ,布吕努瓦,브뤼누아', 48.6942000, 2.4922300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56643, 'Brumath', 'Brumath', 'Brjumat,Broeoemt,Brumat,Brumath,Bröömt,brwmath,bu lu ma,buryumato,Брумат,Брюмат,ברימאט,بروماث,ብሩማት,ブリュマト,布吕马', 48.7301400, 7.7121000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56644, 'Brûlon', 'Brulon', 'Brjulon,Brulon,Brûlon,Брулон,Брюлон', 47.9666700, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56645, 'Bruille-Saint-Amand', 'Bruille-Saint-Amand', 'Bruille,Bruille-Saint-Amand', 50.4660500, 3.5001300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56646, 'Bruille-lez-Marchiennes', 'Bruille-lez-Marchiennes', 'Brije le Marshijen,Brjuj-le-Marsh''enn,Brjuj-le-Marshenn,Bruille,Bruille-les-Marchiennes,Bruille-lez-Marchiennes,bu lu ye lai ma er xie ne,Брије ле Маршијен,Брюй-ле-Маршьенн,Брюй-ле-Маршєнн,布吕耶莱马尔谢讷', 50.3606800, 3.2442400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56647, 'Bruguières', 'Bruguieres', 'Brigjer,Brjug''er,Brjugier,Bruguieras,Bruguieres,Bruguièras,Bruguières,bu lu ji ai,Бригјер,Брюгьер,Брюгіер,布吕吉埃', 43.7272000, 1.4076200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56648, 'Brugheas', 'Brugheas', 'Briga,Brjugea,Brojac,Brugeacum,Brugheas,Brujat,bu lu ya,Брига,Брюгеа,布吕雅', 46.0769800, 3.3675400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56649, 'Bruges', 'Bruges', 'Bruges', 44.8798100, -0.6121900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56650, 'Bruay-sur-l’Escaut', 'Bruay-sur-l''Escaut', 'Bruay,Bruay-sur-l''Escaut,Bruay-sur-l’Escaut', 50.3991800, 3.5437900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56651, 'Bruay-la-Buissière', 'Bruay-la-Buissiere', 'Brije la Bisjer,Brjue-la-Bjuis''er,Brjueh-la-Bjuis''er,Brouay-lBussiere,Brouay-lBussière,Bruay-en-Artois,beulwielabisieleu,brway la bwysyr,brwy lbwyysyr,brwyh-la-bwyysyyr,bu lu ai la bi xi ai,buryue=ra=byuishieru,Брије ла Бисјер,Брюе-ла-Бюисьер,Брюе-ла-Бюїсьєр,Брюэ-ла-Бюисьер,بروئه-لا-بوئیسییر,برواي لا بويسير,بروی لبوئیسیر,ブリュエ＝ラ＝ビュイシエール,布律埃拉比西埃,브뤼에라비시에르', 50.4833300, 2.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56652, 'Broût-Vernet', 'Brout-Vernet', 'Brot e Vernet,Brot e lo Vernet,Brout-Vernet,Broût-Vernet,Bru Verne,Bru-Verne,bu lu wei er nei,Бру Верне,Бру-Верне,布鲁韦尔内', 46.1875600, 3.2732400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56653, 'Brou-sur-Chantereine', 'Brou-sur-Chantereine', 'Brou,Brou-sur-Chantereine,Bru sir Shantren,Bru-sjur-Shanteren,Бру сир Шантрен,Бру-сюр-Шантерен', 48.8833300, 2.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56654, 'Brouckerque', 'Brouckerque', 'Broekkerke,Brouckercque,Brouckerque,Brukerk,bu lu kai er ke,Брукерк,布鲁凯尔克', 50.9547600, 2.2937800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56655, 'Brou', 'Brou', 'Brou', 48.2171900, 1.1653900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56656, 'Broons', 'Broons', 'Broenisis,Bron,Bronn,Broon,Broons,bu luo weng,Брон,Броон,布罗翁', 48.3174800, -2.2595200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56657, 'Bron', 'Bron', 'Bron,beulong,brwn,buron,Брон,برون,ブロン,브롱', 45.7333300, 4.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56658, 'Broglie', 'Broglie', 'Broglie,Chambrois', 49.0091100, 0.5291500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56659, 'Brix', 'Brix', 'Brix', 49.5451200, -1.5801200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56660, 'Brives-Charensac', 'Brives-Charensac', 'Brives,Brives-Charensac', 45.0478000, 3.9287800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56661, 'Brive-la-Gaillarde', 'Brive-la-Gaillarde', 'BVE,Briv la Gajar,Briv-la-Gajard,Briva,Brive,Brive-la-Gaillarde,beulibeulagayaleudeu,bryw lgyrd,bryw-la-gyard,bu li fu la gai ya er de,burivu=ra=gaiyarudo,Брив ла Гајар,Брив-ла-Гайард,Брив-ла-Гаярд,Бриве-ла-Гаилларде,بریو لگیرد,بریو-لا-گیارد,ブリーヴ＝ラ＝ガイヤルド,布里夫拉盖亚尔德,브리브라가야르드', 45.1500000, 1.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56662, 'Brissac-Quincé', 'Brissac-Quince', 'Brisak Kense,Brissak-Kense,bu li sa ke qu an sai,Брисак Кенсе,Бриссак-Кенсе,布里萨克屈安塞', 47.3557500, -0.4492400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56663, 'Brison-Saint-Innocent', 'Brison-Saint-Innocent', 'Brison,Brison-Saint-Innocent,Brizon sent Enosent,Brizon-Sent-Innosan,Бризон сент Еносент,Бризон-Сент-Інносан', 45.7218500, 5.8901100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56664, 'Briscous', 'Briscous', 'Beskoitze,Briscos,Briscous,Briscós,Brisku,Briskus,Hiribery,bu li si ku,Бриску,Брискус,布里斯库', 43.4595800, -1.3335300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56665, 'Briouze', 'Briouze', 'Brijuz,Briouze-Saint-Gervais,Briuz,bu li wu ci,Бриуз,Бријуз,Бріуз,布里乌兹', 48.6984800, -0.3680600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56666, 'Brioux-sur-Boutonne', 'Brioux-sur-Boutonne', 'Brioux,Brioux-sur-Boutonne', 46.1417100, -0.2218200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56667, 'Brioude', 'Brioude', 'Brijud,Brioude,Briud,Briude,Brivas,bu li wu de,buriudo,Бриуд,Бријуд,Бріуд,ブリウド,布里乌德', 45.3000000, 3.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56668, 'Brionne', 'Brionne', 'Brion,Brionn,Brionne,bu li weng,Брион,Брионн,Бріонн,布里翁', 49.1955300, 0.7151000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56669, 'Brion', 'Brion', 'Brion', 47.4412100, -0.1561600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56670, 'Briollay', 'Briollay', 'Briole,Briollay,Briolle,bu li ao lai,Бриоле,Бріолле,布里奥莱', 47.5647800, -0.5068100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56671, 'Brinon-sur-Sauldre', 'Brinon-sur-Sauldre', 'Brinon,Brinon-sur-Sauldre', 47.5660000, 2.2564700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56672, 'Brindas', 'Brindas', 'Brenda,Brindas,Brindas-sur-Roches,Бренда', 45.7218100, 4.6897300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56673, 'Briis-sous-Forges', 'Briis-sous-Forges', 'Bri su Forzh,Bri-su-Forzh,Brii-su-Forzh,Briis,Briis-sous-Forges,bu li yi su fu er re,Бри су Форж,Брии-су-Форж,Брі-су-Форж,布里伊苏福尔热', 48.6239900, 2.1211200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56674, 'Brigueuil', 'Brigueuil', 'Brigej,Brigjoj,Briguelh,Brigueuil,bu li gai yu yi,Бригей,Бригеј,Бригёй,布里盖于伊', 45.9533700, 0.8606500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56675, 'Brignoles', 'Brignoles', 'Brignoles,Brin''jol'',Brin''ol'',Brinhola,Brinholà,Brinhòla,Brinol,bu li ni ao lei,burinyoru,Бриньйоль,Бриньоль,Брињол,ブリニョール,布里尼奥勒', 43.4000000, 6.0666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56676, 'Brignais', 'Brignais', 'Brignais,Brin''e,Brine,Brinhai,Бриньє,Бриње', 45.6735800, 4.7548400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56677, 'Briey', 'Briey', 'Briey', 49.2500000, 5.9333300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56678, 'Brienon-sur-Armançon', 'Brienon-sur-Armancon', 'Brienon,Brienon-sjur-Armanson,Brienon-sur-Armancon,Brienon-sur-Armançon,Brijenon sir Armanson,a er mang song he pan bu li ye nong,Бриенон-сюр-Армансон,Бријенон сир Армансон,Брієнон-сюр-Армансон,阿尔芒松河畔布里耶农', 47.9900900, 3.6162800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56679, 'Briennon', 'Briennon', 'Briennon', 46.1502400, 4.0872000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56680, 'Brienne-le-Château', 'Brienne-le-Chateau', 'Breonna,Brien-le-Shato,Brienn-le-Shato,Brienne-le-Bourg,Brienne-le-Chateau,Brienne-le-Château,Brijen le Shato,bu li an lai sha tuo,Бриен-ле-Шато,Бријен ле Шато,Брієнн-ле-Шато,布里安莱沙托', 48.3931900, 4.5263700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56681, 'Brié-et-Angonnes', 'Brie-et-Angonnes', 'Brie Augonnes,Brie-et-Angonnes,Brie-et-Augonnes,Brié Augonnes,Brié-et-Angonnes,Brié-et-Augonnes', 45.1241800, 5.7837400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56682, 'Brie-Comte-Robert', 'Brie-Comte-Robert', 'Bri Kont Rober,Bri-Kont-Rober,Brie-Comte-Robert,Brie-Libre,Brie-la-Ville,Brie-sur-Hieres,Brie-sur-Hières,Бри Конт Робер,Бри-Конт-Робер,Брі-Конт-Робер', 48.6924700, 2.6109000, 'FR', '2016-12-03', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56683, 'Briec', 'Briec', 'Briec,Briec-de-l''Odet,Briec-de-lOdet,Briec-de-l’Odet,Brieg,Briek,Brijek,Brithiacum,bu li ye ke,buriekku,Бриек,Бријек,Брієк,ブリエック,布里耶克', 48.1016700, -3.9983300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56684, 'Brie', 'Brie', 'ANG,Brie', 45.7380400, 0.2410700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56685, 'Bricy', 'Bricy', 'Briarres-sur-Essonne,Bricy,Brisi,bu li xi,Бриси,Брисі,布里西', 47.9984700, 1.7793700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56686, 'Bricquebec', 'Bricquebec', 'Bricquebec,Brikebek,bu li qu ai bei ke,Брикебек,布里屈埃贝克', 49.4700800, -1.6325400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56687, 'Briatexte', 'Briatexte', 'Briatexte', 43.7523700, 1.9087900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56688, 'Briare', 'Briare', 'Briar,Briare,Brijar,bu li a er,Бријар,Бріар,布里阿尔', 47.6334300, 2.7438000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56689, 'Briançon', 'Briancon', 'Briancon,Brianson,Briançon,Brigantium,Brijanson,XBC,bu li ang song,burianson,Μπριανσόν,Бриансон,Бријансон,Бріансон,ブリアンソン,布里昂松', 44.8997800, 6.6420100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56690, 'Brezolles', 'Brezolles', 'Brezol,Brezol'',Brezolles,Brézolles,bu lei zuo lai,Брезол,Брезоль,布雷佐莱', 48.6903300, 1.0740400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56691, 'Brézins', 'Brezins', 'Brezins,Brézins', 45.3520200, 5.3069200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56692, 'Brézé', 'Breze', 'Breze,Brézé', 47.1735700, -0.0605900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56693, 'Bréviandes', 'Breviandes', 'Breviande,Breviandes,Bréviande,Bréviandes', 48.2569300, 4.0953100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56694, 'Bréval', 'Breval', 'Breval,Breval'',Bréval,Бревал,Бреваль', 48.9454500, 1.5330900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56695, 'Breuschwickersheim', 'Breuschwickersheim', '', 48.5800700, 7.6015900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56696, 'Breuilpont', 'Breuilpont', 'Brejpon,Breuilpont,bu lei yi er peng,Брейпон,Брејпон,布勒伊尔蓬', 48.9639800, 1.4291900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56697, 'Breuil-Magné', 'Breuil-Magne', 'Brej Mane,Brej-Man''e,Breuil-Magne,Breuil-Magné,Brjoj-Man''e,Bryoy Mane,bu lei yi ma nie,Брей-Маньє,Бреј Мање,Брёй-Манье,Բրյոյ Մանե,布勒伊马涅', 45.9847800, -0.9600000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56698, 'Breuil-le-Vert', 'Breuil-le-Vert', 'Brej le Ver,Brej-le-Ver,Breuil,Breuil-le-Vert,bu lei yi lai wei er,Брей-ле-Вер,Бреј ле Вер,布勒伊莱韦尔', 49.3617600, 2.4363300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56699, 'Breuillet', 'Breuillet', 'Breuillet', 48.5706400, 2.1742400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56700, 'Breuillet', 'Breuillet', 'Breuillet', 45.6914300, -1.0517500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56701, 'Breuil-le-Sec', 'Breuil-le-Sec', 'Brej le Sek,Brej-le-Sek,Breuil,Breuil-le-Sec,bu lei yi lai sai ke,Брей-ле-Сек,Бреј ле Сек,布勒伊莱塞克', 49.3713500, 2.4508400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56702, 'Bretteville-sur-Odon', 'Bretteville-sur-Odon', 'Bretteville,Bretteville-sur-Odon,Brettvil''-sjur-Odon,Bretvil sir Odon,Bretvil''-sjur-Odon,ao dong he pan bu lei te wei er,Бретвил сир Одон,Бретвиль-сюр-Одон,Бреттвиль-сюр-Одон,Бреттвіль-сюр-Одон,奥东河畔布雷特维尔', 49.1662700, -0.4166200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56703, 'Bretteville-sur-Laize', 'Bretteville-sur-Laize', 'Bretteville,Bretteville-sur-Laize,Brettvil''-sjur-Lez,Bretvil sir Lez,Bretvil''-sjur-Lez,lai ci he pan bu lei te wei er,Бретвил сир Лез,Бретвиль-сюр-Лез,Бреттвиль-сюр-Лез,Бреттвіль-сюр-Лез,莱兹河畔布雷特维尔', 49.0446600, -0.3263900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56704, 'Bretteville-du-Grand-Caux', 'Bretteville-du-Grand-Caux', 'Bretteville,La Nativite,La Nativité', 49.6666700, 0.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56705, 'Bretteville', 'Bretteville', 'Bretteville', 49.6544000, -1.5288400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56706, 'Brette-les-Pins', 'Brette-les-Pins', 'Brette,Brette-les-Pins', 47.9106200, 0.3364900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56707, 'Bretoncelles', 'Bretoncelles', 'Bretoncelles', 48.4312200, 0.8877500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56708, 'Brétigny-sur-Orge', 'Bretigny-sur-Orge', 'Bretigny,Bretigny-sur-Orge,Bretin''i-sjur-Orzh,Bretini sir Orz,Brétigny-sur-Orge,ao er ri he pan bu lei di ni,beuletiniswileuoleuju,brtyny-swr-arzh,brwtny swr awrzh,buretini=shuru=oruju,Бретиньи-сюр-Орж,Бретињи сир Орж,Бретіньї-сюр-Орж,برتینی-سور-ارژ,بروتنی سور اورژ,ブレティニー＝シュル＝オルジュ,奥尔日河畔布雷蒂尼,브레티니쉬르오르주', 48.6113500, 2.3059300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56709, 'Bretignolles-sur-Mer', 'Bretignolles-sur-Mer', 'Bretignolles,Bretignolles-sur-Mer,Bretin''ol''-sjur-Mer,Bretinol na Moru,Brétignolles-sur-Mer,bin hai bu lei di ni ao lei,Бретињол на Мору,Бретіньоль-сюр-Мер,滨海布雷蒂尼奥勒', 46.6333300, -1.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56710, 'Breteuil', 'Breteuil', 'Breteuil-sur-Iton', 48.8333300, 0.9166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56711, 'Breteuil', 'Breteuil', 'Breteuil,Breteuil-sur-Noye', 49.6335700, 2.2950900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56712, 'Bretenoux', 'Bretenoux', 'Bertenons,Bertenor,Bretenoux,Bretenu,Bretnu,bu lei te nu,Бретену,Бретну,布雷特努', 44.9146800, 1.8400700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56713, 'Breteil', 'Breteil', 'Breteil,Bretej,Bretolium,Brezhiel,bu lei tai,Бретей,Бретеј,布雷泰', 48.1453400, -1.8988600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56714, 'Brest', 'Brest', 'BES,Brest,Brestia,braista,bu lei si te,buresuto,Брест,ब्रैस्त,ブレスト,布雷斯特', 48.3902900, -4.4862800, 'FR', '2017-05-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56715, 'Bressuire', 'Bressuire', 'Berceorium,Bresir,Bressjuir,Bressuire,Givre-en-Mai,bu lei xu er,bureshuiru,Бресир,Брессюир,Брессюїр,ブレシュイール,布雷敘爾', 46.8500000, -0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56716, 'Bressols', 'Bressols', 'Brecols,Bresol,Bressol'',Bressols,Bressòls,Breçòls,bu lei suo er,Бресол,Брессоль,布雷索尔', 43.9679600, 1.3383900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56717, 'Bresles', 'Bresles', 'Brel,Brel'',Brele,Bresles,Brèle,bu lei si lai,Брел,Брель,布雷斯莱', 49.4104400, 2.2502400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56718, 'Brens', 'Brens', 'Brens', 43.8872500, 1.9071600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56719, 'Brenouille', 'Brenouille', 'Brenouille,Brenuj,bu lei nu yi er,Бренуй,Бренуј,布雷努伊尔', 49.3055100, 2.5443700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56720, 'Brêmes', 'Bremes', 'Bremes,Brêmes', 50.8548300, 1.9768700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56721, 'La Crèche', 'La Creche', 'Breloux,Creche,Crèche,Kresh,La-Kresh,Креш,Ла-Креш', 46.3666700, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56722, 'Breil-sur-Roya', 'Breil-sur-Roya', 'Breil,Breil-sur-Roya,Brej sir Roaja,Brej sir Roja,Brej sla Roya,Brej-sjur-Ruaja,Brej-sjur-Ruajja,Brelh,Brelh de Roia,Brelh de Ròia,Brelium,bryl swr rwya,lu wa a he pan bu lei,Брей-сюр-Руайя,Брей-сюр-Руая,Бреј сир Роаја,Бреј сир Роја,بريل سور رويا,鲁瓦阿河畔布雷', 43.9434100, 7.5147400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56723, 'Bréhand', 'Brehand', 'Brean,Brehand,Brehant-Monkontour,Bréhand,bu lei ang,Бреан,布雷昂', 48.4033300, -2.5741200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56724, 'Bréhal', 'Brehal', 'Breal,Breal'',Brehal,Brhal,Bréhal,bu lei a,Бреал,Бреаль,布雷阿', 48.8991500, -1.5122500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56725, 'Brech', 'Brech', 'Brec''h,Brech,Bresh,Бреш', 47.7213400, -2.9986200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56726, 'Brécey', 'Brecey', 'Brcey,Brecey,Brese,Brécey,bu lei sai,Бресе,布雷塞', 48.7241300, -1.1664700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56727, 'Brécé', 'Brece', 'Brec''heg,Brece,Brécé', 48.1083900, -1.4808600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56728, 'Brebières', 'Brebieres', 'Breb''er,Breber,Brebjer,brybyrys,bu lei bi ye er,Бребьер,Бребєр,Бребјер,بريبيريس,布勒比耶尔', 50.3333300, 3.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56729, 'Bréauté', 'Breaute', 'Breaute,Bréauté,Le Bourg-Libre', 49.6280500, 0.4000500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56730, 'Bréal-sous-Montfort', 'Breal-sous-Montfort', 'Breal,Breal su Monfor,Breal''-su-Monfor,Breal-Monforzh,Breal-Moñforzh,Breal-sous-Montfort,Breallum Monteforti,Bréal,Bréal-sous-Montfort,bu lei a su meng te fu er,Бреал су Монфор,Бреаль-су-Монфор,布雷阿苏蒙特福尔', 48.0487600, -1.8643800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56731, 'Brazey-en-Plaine', 'Brazey-en-Plaine', 'Brazey,Brazey-en-Plaine', 47.1378400, 5.2153800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56732, 'Bray-sur-Somme', 'Bray-sur-Somme', 'Bray,Bray-su-Sonme,Bray-sur-Somme,Bre na Somi,Bre-sjur-Somm,suo mu he pan bu lai,Бре на Соми,Бре-сюр-Сомм,索姆河畔布赖', 49.9408500, 2.7184700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56733, 'Bray-sur-Seine', 'Bray-sur-Seine', 'Bray,Bray-sur-Seine,Bre na Seni,Bre-sjur-Sen,Бре на Сени,Бре-сюр-Сен', 48.4137100, 3.2385200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56734, 'Bray-en-Val', 'Bray-en-Val', 'Bray,Bray-en-Val,Bre-an-Val'',Brej an Val,wa de qu bu lai,Бре-ан-Валь,Бреј ан Вал,瓦地区布赖', 47.8285600, 2.3664400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56735, 'Bray-Dunes', 'Bray-Dunes', 'Bray,Bray-Dunes,Bray-Duunn,Brayduinen,Bre Din,Bre-Djun,bu lai di ne,Бре Дин,Бре-Дюн,布赖迪讷', 51.0778600, 2.5167300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56736, 'Brax', 'Brax', 'Brax', 44.2027700, 0.5516300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56737, 'Brax', 'Brax', 'Brax', 43.6179300, 1.2395700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56738, 'Braud-et-Saint-Louis', 'Braud-et-Saint-Louis', 'Braud,Braud-et-Saint-Louis', 45.2470300, -0.6243800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56739, 'Brassac-les-Mines', 'Brassac-les-Mines', 'Bracac,Brasak le Men,Brassac,Brassac-les-Mines,Brassak-le-Min,Braçac,bu la sa ke lai mi nei,burasakku=re=minu,Брасак ле Мен,Брассак-ле-Мин,Брассак-ле-Мін,ブラサック＝レ＝ミーヌ,布拉萨克莱米内', 45.4110500, 3.3291500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56740, 'Brassac', 'Brassac', 'Brassac', 43.6295900, 2.4976300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56741, 'Brasparts', 'Brasparts', 'Brapart,Braspar,Brasparts,Brasparzh,bu la si pa er te,Брапарт,Браспар,布拉斯帕尔特', 48.3016700, -3.9551600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56742, 'Brasles', 'Brasles', 'Brasles', 49.0481000, 3.4300000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56743, 'Bras', 'Bras', 'Bras', 43.4718300, 5.9567200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56744, 'Brantôme', 'Brantome', 'Brantome,Brantôme', 45.3609100, 0.6539800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56745, 'Branoux-les-Taillades', 'Branoux-les-Taillades', 'Branos e las Talhadas,Branoux,Branoux-les-Taillades,Branu le Tajad,Branu-le-Tajad,Branós e las Talhadas,bu la nu lai tai la dai,Брану ле Тајад,Брану-ле-Таяд,布拉努莱泰拉代', 44.2194100, 3.9964700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56746, 'Branne', 'Branne', 'Branne', 44.8333300, -0.1833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56747, 'Branges', 'Branges', 'Branges', 46.6444100, 5.1846500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56748, 'Brando', 'Brando', 'Brando', 42.7666700, 9.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56749, 'Brandérion', 'Branderion', 'Branderion,Branderjon,Brandérion,Praedium Annae,Prederion,bu lang dai li weng,Брандерион,Брандерйон,布朗代里翁', 47.7941200, -3.1947400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56750, 'Bram', 'Bram', '', 43.2437600, 2.1134100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56751, 'Brain-sur-Allonnes', 'Brain-sur-Allonnes', 'Brain,Brain-sur-Allonnes,Bren sir Alon,Bren-sjur-Allonn,a luo nei he pan bu lan,Брен сир Алон,Брен-сюр-Аллонн,阿洛内河畔布兰', 47.3032500, 0.0651400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56752, 'Brains', 'Brains', 'Brains,Brenn', 47.1685000, -1.7229000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56753, 'Braine', 'Braine', 'Braine,Braisne', 49.3426100, 3.5326200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56754, 'Bracieux', 'Bracieux', 'Bracieux,Bras''e,Brasje,bu la xi e,Брасьє,Брасје,布拉西厄', 47.5489500, 1.5412000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56755, 'Bozouls', 'Bozouls', 'Boason,Bozouls,Bozul,Bozul'',bo zu er,Бозул,Бозуль,博祖尔', 44.4705000, 2.7243200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56756, 'Bozel', 'Bozel', 'Bosel,Bosél,Bozel,Bozel'',Frutitidor,Бозел,Бозель', 45.4428800, 6.6489600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56757, 'Boynes', 'Boynes', 'Boan,Boynes,Buan,bu wa nei,Боан,Буан,布瓦内', 48.1182200, 2.3600600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56758, 'Boyard-Ville', 'Boyard-Ville', 'Bojardvil'',Boyard-Ville,Боярдвиль', 45.9671700, -1.2428900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56759, 'Boves', 'Boves', 'Boves', 49.8464500, 2.3960500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56760, 'Bouzy-la-Forêt', 'Bouzy-la-Foret', 'Bouzy,Bouzy-la-Foret,Bouzy-la-Forêt,Buzi la Fore,Buzi-la-Fore,bu qi la fu lei,Бузи ла Форе,Бузі-ла-Форе,布齐拉福雷', 47.8512000, 2.3777300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56761, 'Bouzonville', 'Bouzonville', 'Bouzanville,Bouzonville,Busendorf,Buzonvil'',bu zong wei er,Бузонвиль,Бузонвіль,布宗维尔', 49.2918800, 6.5338600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56762, 'Bouzillé', 'Bouzille', 'Bouzille,Bouzillé,Buzie,Buzije,bu qi lai,Бузије,Бузіє,布齐莱', 47.3375000, -1.1114300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56763, 'Bouzigues', 'Bouzigues', 'Bosiga,Bosigas,Bouzigues,Buzig,bu qi gai,Бузиг,Бузіг,布齐盖', 43.4481000, 3.6578100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56764, 'Bouxwiller', 'Bouxwiller', 'Bouksviler,Bouxwiller,Buchsweiler,Buksvile,Боуксвилер,Буксвиље', 48.8249500, 7.4811700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56765, 'Bouxières-aux-Dames', 'Bouxieres-aux-Dames', 'Bouxieres,Bouxieres-aux-Dames,Bouxieres-sur-Mont,Bouxières,Bouxières-aux-Dames,Bouxières-sur-Mont,Buks''er-o-Dam,Buksjer o Dam,bu ke xi ai ao da mei,Буксьер-о-Дам,Буксьєр-о-Дам,Буксјер о Дам,布克西埃奥达梅', 48.7519400, 6.1691800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56766, 'Bouxières-aux-Chênes', 'Bouxieres-aux-Chenes', 'Bouxieres,Bouxieres-aux-Chenes,Bouxières,Bouxières-aux-Chênes,Buks''er-o-Shen,Buksjer o Shen,bu ke xi ai ao xie nei,Буксьер-о-Шен,Буксьєр-о-Шен,Буксјер о Шен,布克西埃奥谢内', 48.7711500, 6.2603000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56767, 'Bouvron', 'Bouvron', 'Bolvronn,Bouvron,Bouyron', 47.4172600, -1.8467900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56768, 'Bouville', 'Bouville', 'Bouville', 49.5619300, 0.8951400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56769, 'Bouvigny-Boyeffles', 'Bouvigny-Boyeffles', 'Bouvigny,Bouvigny-Boyeffle,Bouvigny-Boyeffles,Buvin''i-Buaeffl'',Buvini Bojefl,bu wei ni bu wa ye fu lei,bwfyjny bwyflys,Бувиньи-Буаеффль,Бувињи Бојефл,Бувіньї-Буаєффль,بوفيجني بويفليس,布维尼布瓦耶夫勒', 50.4214600, 2.6720900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56770, 'Bouvignies', 'Bouvignies', 'Bouvignies', 50.4362700, 3.2436100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56771, 'Bouvesse-Quirieu', 'Bouvesse-Quirieu', 'Bouvesse,Bouvesse-Quirieu', 45.7950300, 5.4157400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56772, 'Bouttencourt', 'Bouttencourt', 'Bouttencourt', 49.9372500, 1.6343100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56773, 'Boutigny-sur-Essonne', 'Boutigny-sur-Essonne', 'Boutigny,Butin''i-sjur-Ehssonna,Butin''i-sjur-Essonn,Butini sir Eson,ai song he pan bu di ni,Бутиньи-сюр-Эссонна,Бутињи сир Есон,Бутіньї-сюр-Ессонн,埃松河畔布蒂尼', 48.4333300, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56774, 'Boutiers-Saint-Trojan', 'Boutiers-Saint-Trojan', 'Boutiers,Boutiers-Saint-Trojan,But''e-Sen-Trozhan,Butje Sen Trozhan,bu di ye er sheng te luo rang,Бутье-Сен-Трожан,Бутьє-Сен-Трожан,Бутје Сен Трожан,布蒂耶尔圣特罗让', 45.7166700, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56775, 'Bout-du-Pont-de-Larn', 'Bout-du-Pont-de-Larn', 'Bout-du-Pont-de-Larn', 43.4973800, 2.4164200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56776, 'Boutavent', 'Boutavent', '', 49.5928100, 1.7991600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56777, 'Boussy-Saint-Antoine', 'Boussy-Saint-Antoine', 'Boussy-Saint-Antoine,Boussy-sous-Senart,Boussy-sous-Sénart,Busi Sent Antoan,Bussi-Sent-Antuan,bu xi sheng ang tu wa en,Буси Сент Антоан,Бусси-Сент-Антуан,Буссі-Сент-Антуан,布西圣昂图瓦恩', 48.6910100, 2.5306000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56778, 'Boussois', 'Boussois', 'Busoa,Bussua,bu su wa,Бусоа,Буссуа,布苏瓦', 50.2890700, 4.0411700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56779, 'Boussières', 'Boussieres', 'Boussieres,Boussières', 47.1586600, 5.9031400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56780, 'Bousse', 'Bousse', 'Bousse', 49.2792500, 6.1952500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56781, 'Boussay', 'Boussay', 'Beuzid-Klison,Boussay', 47.0447600, -1.1847600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56782, 'Bousies', 'Bousies', 'Bousies,Busje,Buzi,bu xi,Бузи,Бузі,Бусје,布西', 50.1509700, 3.6175200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56783, 'Bousbecque', 'Bousbecque', 'Bousbecque,Bousbecques,Bubek,Busbek,Busbeke,bu si bei ke,Бубек,Бусбек,布斯贝克', 50.7712300, 3.0845900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56784, 'Bourth', 'Bourth', 'Bourth,Burt,Бурт', 48.7684600, 0.8091100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56785, 'Bourron-Marlotte', 'Bourron-Marlotte', 'Bourron,Buron Marlot,Burron-Marlott,Бурон Марлот,Буррон-Марлотт', 48.3405100, 2.7004100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56786, 'Bourogne', 'Bourogne', 'Bourogne', 47.5628700, 6.9161300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56787, 'Bournoncle-Saint-Pierre', 'Bournoncle-Saint-Pierre', 'Bornoncle de Sant Peire,Bornoncle de Sant Pèire,Bournoncle,Bournoncle-Saint-Pierre,Burnonkl Sen Pjer,Burnonkl''-Sen-P''err,Burnonkl''-Sen-Perr,bu er nong ke er sheng pi ye er,Бурнонкл Сен Пјер,Бурнонкль-Сен-Пьерр,Бурнонкль-Сен-Пєрр,布尔农克尔圣皮耶尔', 45.3430100, 3.3183700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56788, 'Bournezeau', 'Bournezeau', 'Bournezeau', 46.6371400, -1.1710700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56789, 'Bourlon', 'Bourlon', 'Bourlon,Burlon,bu er long,bwrlwn,Бурлон,بورلون,布尔隆', 50.1769200, 3.1142500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56790, 'Bourgueil', 'Bourgueil', 'Bourgueil,Burgej,Burgolium,bu er gai,buruguiyu,Бургей,Бургеј,ブルグイユ,布尔盖', 47.2833300, 0.1661200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56791, 'Bourguébus', 'Bourguebus', 'Bourguebus,Bourguébus', 49.1218700, -0.2978600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56792, 'Bourgtheroulde-Infreville', 'Bourgtheroulde-Infreville', 'Burgterul''d-Enfrevil'',Burterold Enfrvil,Burterul''d-Enfrevil'',bu er ge te lu er de an fu lei wei er,Бургтерульд-Енфревиль,Буртеролд Енфрвил,Буртерульд-Енфревіль,布尔格特鲁尔德安夫勒维尔', 49.3000000, 0.8833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56793, 'Bourg', 'Bourg', 'Bourg-sur-Gironde', 45.0406200, -0.5589300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56794, 'Bourg-Saint-Maurice', 'Bourg-Saint-Maurice', 'Bourg-Saint-Maurice,Bur Sen Moris,Bur-Sen-Moris,Burgus Sancti Mauritii,Le Borg,Le Bôrg,Nargue-Sarde,Pente-Rude,buru=san=morisu,bwrg-sn-mwrys,Бур Сен Морис,Бур-Сен-Морис,بورگ-سن-موریس,ブール＝サン＝モーリス', 45.6171600, 6.7690200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56795, 'Bourg-Saint-Andéol', 'Bourg-Saint-Andeol', 'Bourg-Saint-Andeol,Bourg-Saint-Andéol,Bourg-sur-Rhone,Bourg-sur-Rhône,Bur Sent Andeol,Bur-Sent-Andeol'',Commune-Libre,Lo Borg Sant Andiou,Lo Borg Sant Andiòu,Lo Borg de Sant Andiou,Lo Borg de Sant Andiòu,bu er sheng ang dai ao,Бур Сент Андеол,Бур-Сент-Андеоль,布尔圣昂代奥', 44.3756600, 4.6427300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56796, 'Bourgoin', 'Bourgoin', '', 45.5833300, 5.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56797, 'Bourgogne', 'Bourgogne', 'Bourgogne,Burgundija,Бургундия', 49.3496200, 4.0711100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56798, 'Bourgneuf-en-Retz', 'Bourgneuf-en-Retz', 'Bourc''hnevez-Raez,Bourchnevez-Raez,Bourgneuf,Bourgneuf-en-Retz,Burgum ad Ligerim,Burnef an Rec,Burnef-an-Re,lei te de qu bu er gai yu,Бурнеф-ан-Ре,Бурњеф ан Рец,雷特地区布尔盖于', 47.0412200, -1.9501900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56799, 'Bourgneuf', 'Bourgneuf', 'Bourgneuf', 46.1676600, -1.0214100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56800, 'la Guingueta d''Ix', 'la Guingueta d''Ix', 'Bourg-Madame,Bur-Madam,la Guingueta,la Guingueta d''Ix,Бур-Мадам', 42.4341600, 1.9439100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56801, 'Bourg-lès-Valence', 'Bourg-les-Valence', 'Bourg,Bourg-les-Valence,Bourg-lès-Valence,Bur le Valans,Bur-le-Valans,Lo Borg,Lo Borg de Valenca,Lo Borg de Valença,bu er lai wa lang ke,Бур ле Валанс,Бур-ле-Валанс,布尔莱瓦朗克', 44.9560100, 4.9102300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56802, 'Bourg-la-Reine', 'Bourg-la-Reine', 'Bourg la Reine,Bourg-Egalite,Bourg-Egalité,Bourg-la-Reine,Bourge la Reine,Bur la Ren,Bur-la-Ren,buru=ra=renu,bwr-lh-rn,huang hou zhen,Бур ла Рен,Бур-ла-Рен,בור-לה-רן,ブール＝ラ＝レーヌ,皇后镇', 48.7788800, 2.3178100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56803, 'Bourghelles', 'Bourghelles', 'Bourghelles', 50.5650100, 3.2444700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56804, 'Bourges', 'Bourges', 'Avaricum Biturigum,BOU,Borges,Bourges,Bourz,Burza,Burzas,Burzh,Burža,Buržas,Gorad Burzh,bu er ri,buleuju,buruju,bwrjyz,bwrz,bwrzh,Μπουρζ,Бурж,Горад Бурж,בורז,بورجيز,بورژ,ቡርዥ,ブールジュ,布尔日,부르주', 47.0833300, 2.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56805, 'Bourg-en-Bresse', 'Bourg-en-Bresse', 'Borg,Borg de Bressa,Bourg,Bourg-Regenere,Bourg-Regénéré,Bourg-en-Bresse,Burg an Bres,Burg-an-Bress,Burganbresa,Burgus Bressiae,Burk an Bres,Burk-an-Bres,Bôrg,Epi-d''Ain,Epi-d''Or,XBK,bu lei si de qu bu er ge,buleukangbeuleseu,buru=gan=buresu,bwran brs,bwrg-an-brs,bwrgh awn brys,Бург ан Брес,Бург-ан-Бресс,Бурк-ан-Брес,Բուրկ ան Բրես,بوران برس,بورغ أون بريس,بورگ-آن-برس,ブール＝ガン＝ブレス,布雷斯地区布尔格,부르캉브레스', 46.2057400, 5.2258000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56806, 'Bourg-de-Thizy', 'Bourg-de-Thizy', 'Bourg,Bourg-de-Thizy,Bur de Tizi,Bur-de-Tizi,Бур де Тизи,Бур-де-Тізі', 46.0337100, 4.2990400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56807, 'Bourg-des-Comptes', 'Bourg-des-Comptes', 'Bourg-des-Comptes,Bourg-la-Montagne,Gwikomm', 47.9293400, -1.7453400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56808, 'Bourg-de-Péage', 'Bourg-de-Peage', 'Bourg-de-Peage,Bourg-de-Péage,Bur de Peazh,Bur-de-Peazh,Le Bourg-de-Peage,Le Bourg-du-Peage,Le Bourg-du-Péage,Lo Borg dau Peatge,Lo Peatge de Pisancon,Lo Peatge de Pisançon,Unite-sur-Isere,Unité-sur-Isère,bu er de pei a ge,Бур де Пеаж,Бур-де-Пеаж,布尔德佩阿格', 45.0282500, 5.0716200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56809, 'Bourg-Blanc', 'Bourg-Blanc', 'Ar Vourc''h-Wenn,Ar Vourch-Wenn,Bourg-Blanc,Bur Blan,Bur-Blan,bu er bu lang ke,buru=buran,Бур Блан,Бур-Блан,ブール＝ブラン,布尔布朗克', 48.4986700, -4.5040600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56810, 'Bourgbarré', 'Bourgbarre', 'Bourgbarre,Bourgbarré,Bourvarred', 47.9951500, -1.6141900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56811, 'Bourg-Argental', 'Bourg-Argental', 'Borg-Argental,Bourg-Argental,Bur-Arzhantal'',Burg Arzhantal,Bôrg-Argental,Lo Borg dArgentau,bu er a er rang ta,Бур-Аржанталь,Бург Аржантал,布尔阿尔让塔', 45.2959000, 4.5603700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56812, 'Bourganeuf', 'Bourganeuf', 'Borgon Nuou,Borgon Nuòu,Borgonnuou,Borgonnuòu,Bourganeuf,Burganef,Burganjof,bu er jia na,buruganufu,Бурганеф,Бурганёф,ブルガヌフ,布尔加纳', 45.9526800, 1.7552000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56813, 'Bourg-Achard', 'Bourg-Achard', 'Bourg-Achard', 49.3532200, 0.8162300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56814, 'Bourcefranc-le-Chapus', 'Bourcefranc-le-Chapus', 'Bursfran le Sapyu,Bursfran le Shapi,Bursfran-le-Shapju,bu er sai fu lang ke lai sha pi,Бурсфран ле Шапи,Бурсфран-ле-Шапю,Բուրսֆրան լե Շապյու,布尔塞夫朗克莱沙皮', 45.8500000, -1.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56815, 'Bourbriac', 'Bourbriac', 'Boulvriag,Bourbriac,Burbriak,Burbrijak,Burgobriacum,bu er bu li a ke,Бурбриак,Бурбријак,Бурбріак,布尔布里阿克', 48.4738400, -3.1875800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56816, 'Bourbourg', 'Bourbourg', 'Bourbourg,Broekburg,Burbur,Burgus in Broco,bu er bao,Бурбур,布尔堡', 50.9478300, 2.1957600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56817, 'Bourbonne-les-Bains', 'Bourbonne-les-Bains', 'Bourbonne,Bourbonne-les-Bains,Burbon le Ben,Burbonn-le-Ben,bu er bang lai ban,Бурбон ле Бен,Бурбонн-ле-Бен,布尔邦莱班', 47.9530500, 5.7480100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56818, 'Bourbon-Lancy', 'Bourbon-Lancy', 'Bellevue-les-Bains,Bourbon-Lancy,Burbo Ancelli,Burbon Lansi,Burbon-Lansi,bwrbwn-lansy,Бурбон Ланси,Бурбон-Ланси,Бурбон-Лансі,بوربون-لانسی', 46.6221400, 3.7695300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56819, 'Bouray-sur-Juine', 'Bouray-sur-Juine', 'Bouray,Bouray-sur-Juine,Bure sir Zhijen,Bure-sjur-Zhuin,rui ne he pan bu lai,Буре сир Жијен,Буре-сюр-Жуин,Буре-сюр-Жуїн,瑞讷河畔布赖', 48.5198100, 2.3000100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56820, 'Boult-sur-Suippe', 'Boult-sur-Suippe', 'Boult,Boult-sur-Suippe,Bu sir Sip,Bul''t-sjur-Sjuipp,xu yi pu he pan bu er,Бу сир Сип,Бульт-сюр-Сюїпп,叙伊普河畔布尔', 49.3714900, 4.1463200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56821, 'Bouloire', 'Bouloire', 'Bouloire', 47.9738500, 0.5500900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56822, 'Boulogne-sur-Mer', 'Boulogne-sur-Mer', 'Bolonha de Mar,Bolonha-sobre-o-Mar,Bonen,Bononia,Boulogne,Boulogne-sur-Mer,Boulonne,Bulon na Moru,Bulon sjur Mer,Bulon''-sjur-Mer,Bulona,Bulonjo,Bulonjo-ce-Maro,Bulonjo-sur-Maro,Bulonjo-ĉe-Maro,Buloņa,Gesoriacum,Gorad Bulon''-sjur-Mehr,Itius Portus,Pajurio Bulone,Pajūrio Bulonė,Port-de-l''Union,Portus Itius,Vouloni,XBS,bin hai bu luo nie,bullonyuswileumeleu,buronyu=shuru=meru,bwlwn-swr-mr,bwlwny swr mr,bwlwny swr myr,polon,Βουλώνη,Булон сюр Мер,Булонь-сюр-Мер,Булоњ на Мору,Горад Булонь-сюр-Мэр,בולון-סור-מר,بولون-سور-مر,بولوني سور مير,بولونی سور مر,போலோன்,ブローニュ＝シュル＝メール,滨海布洛涅,불로뉴쉬르메르', 50.7166700, 1.6166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56823, 'Boulogne-sur-Gesse', 'Boulogne-sur-Gesse', 'Boulogne', 43.3000000, 0.6500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56824, 'Boulogne-Billancourt', 'Boulogne-Billancourt', 'Billancourt,Bononia ad Sequanam,Boulogne,Boulogne e Billancourt,Boulogne-Billancourt,Boulogne-sur-Seine,Bulon Bijankur,Bulon''-Bijankur,Bulona-Bijankura,Bulone-Bijankuras,Bulonė-Bijankūras,Buloņa-Bijankūra,XBT,bu luo nie-bi yang gu,bullonyubiyangkuleu,buronyu=biyankuru,bwlwn-blankwr,bwlwn-byankwr,bwlwny byankwr,bwlwny-byankwr,Булон Биянкур,Булонь-Бийанкур,Булонь-Биянкур,Булонь-Біянкур,Булоњ Бијанкур,بولون-بلانکور,بولون-بيانكور,بولونی بیانکور,بولونی-بیانکور,ბულონ-ბიანკური,ブローニュ＝ビヤンクール,布洛涅-比扬古,불로뉴비양쿠르', 48.8333300, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56825, 'Bouloc', 'Bouloc', 'Bouloc', 43.7816300, 1.4052200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56826, 'Boulleret', 'Boulleret', 'Boulleret', 47.4241900, 2.8734300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56827, 'Bouligny', 'Bouligny', 'Bouligny', 49.2918900, 5.7424800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56828, 'Boulieu-lès-Annonay', 'Boulieu-les-Annonay', 'Bonluec,Boulieu,Boulieu dAnonai,Boulieu-les-Annonay,Boulieu-lès-Annonay,Bul''e-lez-Annone,Bul''jo-lez-Annone,Bulije lez Anone,bu li e lai a nuo nai,Булије лез Аноне,Бульё-лез-Анноне,Бульє-лез-Анноне,布利厄莱阿诺奈', 45.2708400, 4.6671800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56829, 'Bouliac', 'Bouliac', 'Boliac,Bouliac,Bul''jak,Bulijak,bu li a ke,Булијак,Бульяк,布利阿克', 44.8172400, -0.5024800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56830, 'Bouleurs', 'Bouleurs', 'Bouleurs', 48.8818100, 2.9072800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56831, 'Boulbon', 'Boulbon', 'Boul-la-Montagne,Boulbon,Bourg-Montagne', 43.8623200, 4.6939100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56832, 'Boulazac', 'Boulazac', '', 45.1166700, 0.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56833, 'Boulay-Moselle', 'Boulay-Moselle', 'Bolchen,Boulay,Bule Mozel,Bule-Mozel'',bu lai mo ze er,bure=mozeru,Буле Мозел,Буле-Мозель,ブレ＝モゼル,布莱摩泽尔', 49.1833300, 6.5000000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56834, 'Boulange', 'Boulange', 'Boulange,Bulanzh,bu lang ge,bwlanzh,Буланж,بولانژ,布朗格', 49.3809300, 5.9523100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56835, 'Boujan-sur-Libron', 'Boujan-sur-Libron', 'Boujan,Boujan-sur-Libron', 43.3699600, 3.2475900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56836, 'Bouin', 'Bouin', 'Bonn,Bouin', 46.9731400, -1.9983000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56837, 'Bouilly', 'Bouilly', 'Bouilly', 48.1967400, 4.0001100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56838, 'Bouillé-Loretz', 'Bouille-Loretz', 'Bouille-Loretz,Bouillé-Loretz,Bue-Lore,Buje Lorec,Бує-Лоре,Бује Лорец', 47.0791100, -0.2717800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56839, 'Bouillargues', 'Bouillargues', 'Bolhargues,Bouillargues,Bujarg,bu yi la er gai,Буярг,Бујарг,布伊拉尔盖', 43.7973300, 4.4285300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56840, 'Bouguenais', 'Bouguenais', 'Bougenais,Bouguenais,Bugene,Castrum Bogenis,Kervegon,bu gai nai,bugene,Бугене,ブゲネ,布盖奈', 47.1776200, -1.6214300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56841, 'Bougival', 'Bougival', 'Bougivais,Bougival,Burgivallis,Buzhival,Buzhival'',bujivu~aru,Буживал,Буживаль,ブージヴァル', 48.8622300, 2.1414800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56842, 'Boufféré', 'Bouffere', 'Bouffere,Boufféré', 46.9617900, -1.3396500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56843, 'Bouffémont', 'Bouffemont', 'Bouffemont,Bouffémont,Bufemon,Buffemon,bu fei meng,Буфемон,Буффемон,布费蒙', 49.0437700, 2.2979600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56844, 'Boué', 'Boue', 'Boue,Boué', 50.0114100, 3.6960800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56845, 'Bouchemaine', 'Bouchemaine', 'Bushmen,bu xie man,Бушмен,布谢曼', 47.4223400, -0.6088800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56846, 'Bouchain', 'Bouchain', 'Bouchain', 50.2851900, 3.3149100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56847, 'Bouc-Bel-Air', 'Bouc-Bel-Air', 'Boc Bel Er,Boc Bel Erm,Boc Bèl Èr,Boc Bèl Èrm,Boc de Gardana,Bouc,Bouc-Bel-Air,Buk Bel Er,Buk-Bel''-Ehr,Buk-Bel''-Er,bu ke bei ai,Бук Бел Ер,Бук-Бель-Ер,Бук-Бель-Эр,布克贝艾', 43.4521700, 5.4130000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56848, 'Boucau', 'Boucau', 'Bokale,Boucau,Buko,Le Boucau,Lo Bocau,Буко', 43.5277000, -1.4655600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56849, 'Bouaye', 'Bouaye', 'Bouaye,Bouez,Bue,bu ai ai,Буе,布艾埃', 47.1426300, -1.6930600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56850, 'Bouafle', 'Bouafle', 'Bouafle,Buafl,Buafl'',Буафл,Буафль', 48.9646300, 1.9012000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56851, 'Bosmie-l''Aiguille', 'Bosmie-l''Aiguille', 'Bosmic', 45.7500000, 1.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56852, 'Bosdarros', 'Bosdarros', 'Bodaro,Bosc dArros,Bosdarros,Bòsc dArròs,Lo Bosc dArros,Lo Bòsc dArròs,bo si da luo,Бодаро,Босдаррос,博斯达罗', 43.2166700, -0.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56853, 'Bosc-le-Hard', 'Bosc-le-Hard', 'Bosc,Bosc-le-Hard,Bosk lAr,Bosk-le-Ard,Боск лАр,Боск-ле-Ард', 49.6273400, 1.1748300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56854, 'Bort-les-Orgues', 'Bort-les-Orgues', 'Bor lez Org,Bor-lez-Org,Bort,Bort-les-Orgues,Bòrt,bo er lai ao er gai,Бор лез Орг,Бор-лез-Орг,博尔莱奥尔盖', 45.4006500, 2.4965000, 'FR', '2017-01-04', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56855, 'Bornel', 'Bornel', 'Bornel,Bornel'',Борнел,Борнель', 49.1982000, 2.2091200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56856, 'Bormes-les-Mimosas', 'Bormes-les-Mimosas', 'Borm le Mimoza,Borm-le-Mimoza,Borma dei Mimosas,Bormas,Bormes,Bormes-les-Mimosas,Bòrma dei Mimòsas,Bòrmas,bo er mo lei mi mo sa,Борм ле Мимоза,Борм-ле-Мимоза,Борм-ле-Мімоза,博尔默勒米莫萨', 43.1407300, 6.3386300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56857, 'Borgo', 'Borgo', '', 42.5548800, 9.4263600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56858, 'Bords', 'Bords', 'Bor,Bord,Bords,bo er de,Бор,Борд,博尔德', 45.8972200, -0.7952800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56859, 'Bordes', 'Bordes', 'Bordes', 43.2333300, -0.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56860, 'Bordeaux', 'Bordeaux', 'BOD,Bordeaux,Bordele,Bordeos,Bordeu,Bordeus,Bordo,Bordox,Bordozo,Bordèu,Bordéus,Bordò,Bordôx,Bornto,Bourdel,Burdeos,Burdeus,Burdigala,Gorad Bardo,bo er duo,boleudo,borado,bordo,bordu,borudo,bwrdw,bwrڈw,bxr do,porto,Μπορντό,Бордо,Горад Бардо,Բորդո,בארדא,בורדו,بوردو,بورڈو,बोर्दू,बोर्दो,ਬੋਰਦੋ,பொர்தோ,บอร์โด,ບອກໂດ,ბორდო,ቦርዶ,ボルドー,波尔多,波爾多,보르도', 44.8404400, -0.5805000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56861, 'Boran-sur-Oise', 'Boran-sur-Oise', 'Boran,Boran sir Oaz,Boran-sjur-Uaz,Boran-sur-Oise,wa si he pan bo lang,Боран сир Оаз,Боран-сюр-Уаз,瓦斯河畔博朗', 49.1671500, 2.3580300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56862, 'Boos', 'Boos', 'Boos', 49.3884900, 1.2034800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56863, 'Boofzheim', 'Boofzheim', 'Bofckhajm,Bofze,Boofzajm,Boofzheim,bftshaym,bo ao fu zan,bwfzhym,Боофзайм,Бофцхајм,بفتسهایم,بوفزهيم,博奥夫赞', 48.3321200, 7.6803500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56864, 'Bonson', 'Bonson', 'Bonson', 45.5245500, 4.2165900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56865, 'Bons-en-Chablais', 'Bons-en-Chablais', 'Bon-an-Shable,Bons,Bontium,Bonz an Shable,Бон-ан-Шабле,Бонз ан Шабле', 46.2666700, 6.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56866, 'Bonny-sur-Loire', 'Bonny-sur-Loire', 'Boni na Loari,Bonni-sjur-Luar,Bonny,Bonny-sur-Loire,lu wa er he pan bo ni,Бони на Лоари,Бонні-сюр-Луар,卢瓦尔河畔博尼', 47.5617200, 2.8393300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56867, 'Bonnieux', 'Bonnieux', 'Bon''e,Bonije,Bonius,Bonn''jo,Bonnieux,bo ni yue,Боније,Бонньё,Боньє,博尼约', 43.8245200, 5.3073900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56868, 'Bonnières-sur-Seine', 'Bonnieres-sur-Seine', 'Bon''er-sjur-Sen,Bonijer na Seni,Bonnieres,Bonnieres-sur-Seine,Bonnières,Bonnières-sur-Seine,Бонијер на Сени,Боньер-сюр-Сен,Боньєр-сюр-Сен', 49.0352500, 1.5783000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56869, 'Bonneville', 'Bonneville', 'Bonneville,Mont-Mole,Mont-Molez', 46.0802000, 6.4072600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56870, 'Bonneval', 'Bonneval', 'Bonneval', 48.1831200, 1.3852400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56871, 'Bonneuil-sur-Marne', 'Bonneuil-sur-Marne', 'Bonneuil,Bonneuil-sur-Marne', 48.7695000, 2.4793000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56872, 'Bonneuil-Matours', 'Bonneuil-Matours', 'Bonej Matur,Bonnej-Matur,Bonneuil-Matouis,Bonneuil-Matours,bo na yi ma tu er,Бонеј Матур,Бонней-Матур,博纳伊马图尔', 46.6815500, 0.5706300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56873, 'Bonnétable', 'Bonnetable', 'Bonetabl,Bonnetabl'',Bonnetable,Bonnétable,Бонетабл,Боннетабль', 48.1790800, 0.4257000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56874, 'Bonne-sur-Ménoge', 'Bonne-sur-Menoge', 'Bonne,Bonne-sur-Menoge,Bonne-sur-Ménoge', 46.1660000, 6.3227700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56875, 'Bonnes', 'Bonnes', 'Bonnes', 46.6038600, 0.5979100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56876, 'Bonnemain', 'Bonnemain', 'Bonmaen,Bonmen,Bonnemain,Bonnmen,bo nei man,Бонмен,Боннмен,博内曼', 48.4665200, -1.7677400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56877, 'Bonnelles', 'Bonnelles', 'Bonel,Bonnel'',Bonnelles,Бонел,Боннель', 48.6181600, 2.0292200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56878, 'Bonnefamille', 'Bonnefamille', 'Bonnefamille', 45.5958900, 5.1303500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56879, 'Bonnat', 'Bonnat', 'Bonnat', 46.3333300, 1.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56880, 'Bonnac-la-Côte', 'Bonnac-la-Cote', 'Bonac,Bonak la Kot,Bonnac,Bonnac-la-Cote,Bonnac-la-Côte,Bonnak-la-Kot,bo na ke la ke te,Бонак ла Кот,Боннак-ла-Кот,博纳克拉科特', 45.9421200, 1.2841700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56881, 'Bonifacio', 'Bonifacio', 'Bonifacho,Bonifacio,Bonifaziu,Bunifaziu,La Ville de Bonifacio,Бонифачо', 41.3874000, 9.1594100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56882, 'Bon-Encontre', 'Bon-Encontre', 'Bon Ankontr,Bon-Ankontr,Bon-Encontre,Bonencontre,bang ang kong te er,Бон Анконтр,Бон-Анконтр,邦昂孔特尔', 44.1851800, 0.6675900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56883, 'Bondy', 'Bondy', 'Bondi,Bondy,bang di,bondi,bongdi,bwndy,Бонди,Бонді,بوندي,بوندی,ボンディ,邦迪,봉디', 48.9018000, 2.4893100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56884, 'Bondues', 'Bondues', 'Bondi,Bondju,Bondues,Bonduwe,bang di ai,Бонди,Бондю,邦迪埃', 50.7019600, 3.0949700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56885, 'Bondoufle', 'Bondoufle', 'Bondoufle,Bondufl,Bondufl'',bang du fu er,Бондуфл,Бондуфль,邦杜夫尔', 48.6129400, 2.3777500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56886, 'Bonchamp-lès-Laval', 'Bonchamp-les-Laval', 'Bonchamp,Bonchamp-les-Laval,Bonchamp-lès-Laval,Bonsham-le-Laval'',Bonshan le Laval,bang shang lai la wa,Боншам-ле-Лаваль,Боншан ле Лавал,邦尚莱拉瓦', 48.0735700, -0.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56887, 'Bompas', 'Bompas', 'Bompas,Bompàs', 42.7333300, 2.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56888, 'Bologne', 'Bologne', 'Bologne', 48.2000500, 5.1420900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56889, 'Bollwiller', 'Bollwiller', 'Bol''viller,Bollweiler,Bolviler,bo er wei lai,Болвилер,Больвиллер,Больвіллер,博尔维莱', 47.8583200, 7.2617900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56890, 'Bollezeele', 'Bollezeele', 'Bollezeel'',Bollezeele,Bollezele,Bolzel,bo lai ze lei,Болзел,Боллезеель,博莱泽勒', 50.8668700, 2.3475100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56891, 'Bollène', 'Bollene', 'Bolen,Bolena,Bollen,Bollene,Bollène,bo lai na,Болен,Боллен,博莱纳', 44.2847600, 4.7530300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56892, 'Bolbec', 'Bolbec', 'Bol''bek,Bolbec,Bolbek,Болбек,Больбек', 49.5732100, 0.4733900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56893, 'Boissy-sous-Saint-Yon', 'Boissy-sous-Saint-Yon', 'Boasi su Sen Jon,Boissy,Boissy-la-Montagne,Boissy-sous-Saint-Yon,Buassi-su-Sent-Ion,bu wa xi su sheng yi weng,Боаси су Сен Јон,Буасси-су-Сент-Ион,Буассі-су-Сент-Іон,布瓦西苏圣伊翁', 48.5537900, 2.2121200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56894, 'Boissy-Saint-Léger', 'Boissy-Saint-Leger', 'Boissy,Boissy-Saint-Leger,Boissy-Saint-Léger,Boissy-la-Montagne', 48.7514900, 2.5116300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56895, 'Boissy-le-Cutté', 'Boissy-le-Cutte', 'Boasi le Kite,Boissy,Boissy-le-Cutte,Boissy-le-Cutté,Buassi-le-Kjutte,bu wa xi lei qu te,Боаси ле Ките,Буасси-ле-Кютте,Буассі-ле-Кютте,布瓦西勒屈特', 48.4702000, 2.2832600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56896, 'Boissy-le-Châtel', 'Boissy-le-Chatel', 'Boasi le Shatel,Boissy,Boissy-le-Chatel,Boissy-le-Châtel,Buassi-le-Shatel'',Боаси ле Шател,Буасси-ле-Шатель,Буассі-ле-Шатель', 48.8207300, 3.1365100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56897, 'Boissise-le-Roi', 'Boissise-le-Roi', 'Boasiz le Roa,Boissise-la-Nation,Boissise-le-Roi,Buassiz-le-Rua,Боасиз ле Роа,Буассиз-ле-Руа,Буассіз-ле-Руа', 48.5247900, 2.5697100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56898, 'Boisseuil', 'Boisseuil', 'Boisseuil', 45.7697700, 1.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56899, 'Boisset-et-Gaujac', 'Boisset-et-Gaujac', 'Boisset,Boisset-et-Gaujac', 44.0474900, 4.0086100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56900, 'Boisseron', 'Boisseron', 'Boaseron,Boisseron,Buasseron,Castrum de Boisedono,bu wa se long,Боасерон,Буассерон,布瓦瑟龙', 43.7579500, 4.0797000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56901, 'Boismé', 'Boisme', 'Boame,Boisme,Boismé,Bomniacum,Buame,Боаме,Буаме', 46.7739300, -0.4347600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56902, 'Bois-le-Roi', 'Bois-le-Roi', 'Bois-la-Nation,Bois-le-Roi', 48.4734800, 2.7046400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56903, 'Bois-Guillaume', 'Bois-Guillaume', 'Boa Gijom,Bois-Guillaume,Bua-Gijom,Боа Гијом,Буа-Гийом,Буа-Гійом', 49.4602000, 1.1221900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56904, 'Bois-Grenier', 'Bois-Grenier', 'Bois-Grenier', 50.6498500, 2.8740900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56905, 'Boisgervilly', 'Boisgervilly', 'Boazherviji,Boisgervilly,Boscus Gervili,Buazhervilli,Koad-Yarnvili,bu wa si re er wei li,Боажервији,Буажервилли,Буажервіллі,布瓦斯热尔维利', 48.1669200, -2.0642600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56906, 'Bois-de-Cené', 'Bois-de-Cene', 'Bois-de-Cene,Bois-de-Cené,Koed-Keneg', 46.9368900, -1.8865600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56907, 'Bois-d’Arcy', 'Bois-d''Arcy', 'Bois-d''Arcy,Bois-d’Arcy', 48.7996600, 2.0232500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56908, 'Boiscommun', 'Boiscommun', 'Boakomen,Boiscommun,Buakommen,bu wa si ke man,Боакомен,Буакоммен,布瓦斯科曼', 48.0357600, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56909, 'Bois-Colombes', 'Bois-Colombes', 'Boa Kolomb,Boa Kolon,Bois-Colombes,Bua-Kolomb,bai ge lin,bowa=koronbu,buakollongbeu,bwa kwlmb,bwa-klmb,Боа Коломб,Боа Колон,Буа-Коломб,بوآ کولمب,بوآ-کلمب,ボワ＝コロンブ,白鸽林,부아콜롱브', 48.9193600, 2.2748500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56910, 'Boigny-sur-Bionne', 'Boigny-sur-Bionne', 'Boani sir Bion,Boigny,Buan''i-sjur-Bionn,bi weng he pan bu wa ni,Боањи сир Бион,Буаньї-сюр-Біонн,比翁河畔布瓦尼', 47.9333300, 2.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56911, 'Bohars', 'Bohars', 'Boar,Boc''harzh,Bocharzh,Bohars,boaru,Боар,ボアール', 48.4298300, -4.5129200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56912, 'Bohain-en-Vermandois', 'Bohain-en-Vermandois', 'Boehn-an-Vermandua,Boen an Vermandoa,Boen an Vermandua,Boen-an-Vermandua,Bohain,Bohain-en-Vermandois,Bohain-in-Vermindos,Bohain-in-Vérmindos,bo an ang wei er mang duo wa,Боен ан Вермандоа,Боен-ан-Вермандуа,Боэн-ан-Вермандуа,Բոեն ան Վերմանդուա,博安昂韦尔芒多瓦', 49.9873000, 3.4530000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56913, 'Boeschepe', 'Boeschepe', '', 50.8000000, 2.7000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56914, 'Bœrsch', 'Boersch', 'Bersch,Bersh,Boersch,Börsch,bo ai er si ke,bwrstsh,Берш,بورستش,博埃尔斯克', 48.4765600, 7.4399800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56915, 'Boën-sur-Lignon', 'Boen-sur-Lignon', 'Boen,Boen-sur-Lignon,Boën,Boën-sur-Lignon,bo e en,Боен,博厄恩', 45.7461800, 4.0095900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56916, 'Boeil-Bezing', 'Boeil-Bezing', 'Bej Bezen,Boehj-Bezen,Boeil,Boeil-Bezing,Boej-Bezen,Buelh e Vesinc,Buelh-Vesing,Bœil-Bezing,bo ai yi bo jin,Беј Безен,Боей-Безен,Боэй-Безен,博埃伊伯金', 43.2166700, -0.2666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56917, 'Boëge', 'Boege', 'Boege,Boezh,Bouejo,Bouèjo,Bovitium,Boëge,Боеж', 46.2095400, 6.4038300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56918, 'Boé', 'Boe', 'Boe,Boer,Boèr,Boé,Бое', 44.1600700, 0.6290500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56919, 'Bodilis', 'Bodilis', 'Bodilis,Bodiliz', 48.5297800, -4.1156700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56920, 'Bobigny', 'Bobigny', 'Bobigny,Bobin''i,Bobinhy,Bobini,bo bi ni,bobini,bwbyny,Бобини,Бобиньи,Бобињи,Бобіньї,بوبيني,بوبینی,ボビニー,博比尼,보비니', 48.9000000, 2.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56921, 'Blotzheim', 'Blotzheim', 'Blocajm,Blockhajm,Blotzajm,Blotzheim,bu luo te zan,Блотзайм,Блоцайм,Блоцхајм,布洛特赞', 47.6020500, 7.4963000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56922, 'Blonville-sur-Mer', 'Blonville-sur-Mer', 'Blonvil na Moru,Blonvil''-sjur-Mer,Blonville,Blonville-sur-Mer,bin hai bu long wei er,Блонвил на Мору,Блонвиль-сюр-Мер,Блонвіль-сюр-Мер,滨海布隆维尔', 49.3370900, 0.0270900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56923, 'Blois', 'Blois', 'Bleaz,Bles,Blesae,Bloa,Blois,Bloua,Blua,Gorad Blua,XBQ,beullua,blaw,blwa,bu lu wa,burowa,Μπλουά,Блоа,Блуа,Горад Блуа,Բլոիս,بلوآ,بلوا,บลัว,ブロワ,布卢瓦,블루아', 47.5833300, 1.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56924, 'Blodelsheim', 'Blodelsheim', 'Blodelsheim', 47.8841100, 7.5367900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56925, 'Bligny-lès-Beaune', 'Bligny-les-Beaune', 'Bligny,Bligny-les-Beaune,Bligny-lès-Beaune', 46.9863100, 4.8262000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56926, 'Bliesbruck', 'Bliesbruck', 'Blibrjuk,Bliesbauchen,Bliesbruck,Bliesbrucken,Bliesbrücken,Blizbruk,blysbrwk,bu li ye si bu lu,Блибрюк,Близбрук,Блібрюк,بلیسبروک,布利耶斯布吕', 49.1151700, 7.1835600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56927, 'Bletterans', 'Bletterans', 'Betterans,Bletran,Bletteran,Bletterans,bu lei te lang,Блетран,Блеттеран,布勒特朗', 46.7467300, 5.4544400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56928, 'Bléré', 'Blere', 'Blere,Bléré,bu lai lei,Блере,布莱雷', 47.3273800, 0.9918600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56929, 'Blérancourt', 'Blerancourt', 'Blerancourt,Blerankur,Blérancourt,Dlerancourt,Dlérancourt,bu lai lang ku er,Блеранкур,布莱朗库尔', 49.5166700, 3.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56930, 'Blénod-lès-Toul', 'Blenod-les-Toul', 'Blenod,Blenod-les-Toul,Blénod,Blénod-lès-Toul', 48.5981400, 5.8395600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56931, 'Blénod-lès-Pont-à-Mousson', 'Blenod-les-Pont-a-Mousson', 'Blenod,Blenod-les-Pont-a-Mousson,Blénod,Blénod-lès-Pont-à-Mousson,Les-Pont-a-Mousson,Les-Pont-à-Mousson', 48.8848700, 6.0484400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56932, 'Bléneau', 'Bleneau', 'Bleneau,Bléneau', 47.7000000, 2.9500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56933, 'Blendecques', 'Blendecques', 'Blandek,Blendecques,Blendeke,Blindecques,blyndyskyws,bu lang dai ke,Бландек,بلينديسكيوس,布朗代克', 50.7184300, 2.2860100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56934, 'Blaye-les-Mines', 'Blaye-les-Mines', 'Blaia,Blaia de las Minas,Blaj-le-Min,Blaye,Blaye-les-Mines,Ble le Men,Ble-le-Min,bu lai e lai mi na,Блай-ле-Мин,Бле ле Мен,Бле-ле-Мін,布莱厄莱米纳', 44.0307300, 2.1316600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56935, 'Blavozy', 'Blavozy', 'Blavozy', 45.0572000, 3.9799300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56936, 'Blauzac', 'Blauzac', 'Blausac,Blauzac,Blozak,bu luo zha ke,Блозак,布洛扎克', 43.9615100, 4.3693000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56937, 'Blausasc', 'Blausasc', 'Blausaccum,Blausasc,Blozak,Blozask,blwsask,bu luo sa si ke,Блозак,Блозаск,بلوساسك,布洛萨斯克', 43.8057200, 7.3647700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56938, 'Blaringhem', 'Blaringhem', 'Blarengem,Blaringam,Blaringem,Blaringhem,Bloaringem,bu la lan gai mu,Бларенгем,Бларингам,布拉兰盖姆', 50.6911000, 2.4032100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56939, 'Blanzy', 'Blanzy', 'Blanzi,Blanzy,Blanzy-sur-Bourbince,Бланзи,Бланзі', 46.7001200, 4.3883300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56940, 'Blanzat', 'Blanzat', 'Blanza,Blanzac,Blanzat,bu lang zha,Бланза,布朗扎', 45.8313700, 3.0811100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56941, 'Blanquefort', 'Blanquefort', 'Blanquefort', 44.9124800, -0.6366300, 'FR', '2017-05-07', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56942, 'Blangy-sur-Bresle', 'Blangy-sur-Bresle', 'Blangy,Blangy-sur-Bresle,Blanzhi sir Brel,Blanzhi-sjur-Brel'',Бланжи сир Брел,Бланжи-сюр-Брель,Бланжі-сюр-Брель', 49.9321100, 1.6251400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56943, 'Blancafort', 'Blancafort', 'Blancafort', 47.5321900, 2.5298100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56944, 'Blamont', 'Blamont', 'Blamon,Blamont,bu la meng,Бламон,布拉蒙', 47.3851300, 6.8480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56945, 'Blaison-Gohier', 'Blaison-Gohier', 'Blezon Goje,Blezon-Goe,bu lai song gua,Блезон Гоје,Блезон-Гоє,布莱松瓜', 47.3995100, -0.3772300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56946, 'Blainville-sur-Orne', 'Blainville-sur-Orne', 'Blainville,Blainville-sur-Orne,Blenvil sir Orn,Blenvil''-sjur-Orn,ao er en he pan bu lan wei er,Бленвил сир Орн,Бленвиль-сюр-Орн,Бленвіль-сюр-Орн,奥尔恩河畔布兰维尔', 49.2291300, -0.3006100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56947, 'Blainville-sur-Mer', 'Blainville-sur-Mer', 'Blainville,Blainville-sur-Mer,Blenvil na Moru,Blenvil''-sjur-Mer,bin hai bu lan wei er,Бленвил на Мору,Бленвиль-сюр-Мер,Бленвіль-сюр-Мер,滨海布兰维尔', 49.0659900, -1.5834000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56948, 'Blainville-Crevon', 'Blainville-Crevon', 'Blainville,Blainville-Crevon,Blenvil Krevon,Blenvil''-Krevon,bu lan wei er-ke lei weng,Бленвил Кревон,Бленвиль-Кревон,Бленвіль-Кревон,布兰维尔-克勒翁', 49.5039500, 1.2995200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56949, 'Blaincourt-lès-Précy', 'Blaincourt-les-Precy', 'Blenkur le Presi,Blenkur-le-Presi,bu lan ku er lai pu lei xi,Бленкур ле Преси,Бленкур-ле-Пресі,布兰库尔莱普雷西', 49.2333300, 2.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56950, 'Blain', 'Blain', 'Blaen,Blain', 47.4765500, -1.7628500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56951, 'Blagny', 'Blagny', 'Blagny', 49.6216700, 5.1919400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56952, 'Blagnac', 'Blagnac', 'Blagnac,Blan''jak,Blanak,Blanhac,beullanyakeu,blnyk,bu la ni ya ke,buranyakku,Бланьяк,Блањак,بلنیک,ブラニャック,布拉尼亚克,블라냐크', 43.6327600, 1.3939900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56953, 'Blaesheim', 'Blaesheim', 'Blaesheim', 48.5064800, 7.6092300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56954, 'Blacé', 'Blace', 'Blace,Blacé', 46.0318500, 4.6449900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56955, 'Bize-Minervois', 'Bize-Minervois', 'Bisa,Biz Minervoa,Biz-Minervua,Bize,Bize-Minervois,bi ci mi nei er wa,Биз Минервоа,Биз-Минервуа,Біз-Мінервуа,比兹米内尔瓦', 43.3165600, 2.8713400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56956, 'Bizanos', 'Bizanos', 'Bizano,Bizanons,Bizanos,Visanos,Visanòs,bi zha nuo,Бизано,Бизанос,Бізанос,比扎诺', 43.2833300, -0.3500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56957, 'Bizanet', 'Bizanet', 'Bizanet', 43.1641900, 2.8703400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56958, 'Biviers', 'Biviers', 'Biv''e,Bive,Biviers,Bivje,bi wei ye er,Бивье,Бивје,Бівє,比维耶尔', 45.2333300, 5.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56959, 'Bitschwiller-lès-Thann', 'Bitschwiller-les-Thann', 'Bischiville,Bitschwiller,Bitschwiller-les-Thann,Bitschwiller-lès-Thann', 47.8286300, 7.0806600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56960, 'Bitche', 'Bitche', 'Bich,Bitche,Bitsch,Bitsche,bi te ke,Бич,Біч,比特克', 49.0500900, 7.4267200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56961, 'Bischwiller', 'Bischwiller', 'Bischweiler,Bischwiller,Bishviler,Bishviller,Bíschwiller,bi si ke wei lai,bishuvu~ireru,bystshwylyr,Бишвилер,Бишвиллер,Бішвіллер,بيستشويلير,ビシュヴィレール,比斯克维莱', 48.7658800, 7.8583100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56962, 'Bischoffsheim', 'Bischoffsheim', 'Bischoffsheim,Bischofsheim,Bishoffsajm,Bishofskhajm,bi si shao fu sang,bystshwfshym,Бишофсхајм,Бишоффсайм,Бішоффсайм,بيستشوفشيم,比斯绍夫桑', 48.4870300, 7.4896700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56963, 'Bischheim', 'Bischheim', 'Bischheim', 48.6161200, 7.7534300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56964, 'Biscarrosse', 'Biscarrosse', 'Biscarosse,Biscarrossa,Biscarrosse,Biscarrosse-Bourg,Biscarròssa,Biskaros,Biskarross,bi si ka er luo si,bisukarossu,Бискарос,Бискарросс,Біскарросс,ビスカロッス,比斯卡尔罗斯', 44.3945400, -1.1672100, 'FR', '2016-12-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56965, 'Biot', 'Biot', 'Biot', 43.6272300, 7.0964500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56966, 'Bining', 'Bining', 'Binen,Bining,Bining-les-Rohrbach,Bining-lès-Rohrbach,Biningen,bi nan,bynyng,Бинен,Бининг,Бінен,بینینگ,比南', 49.0364700, 7.2522000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56967, 'Binic', 'Binic', 'Binic,Binig,Binik,bi ni ke,Биник,Бінік,比尼克', 48.6007400, -2.8260200, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56968, 'Billy-sur-Aisne', 'Billy-sur-Aisne', 'Billy,Billy-sur-Aisne', 49.3563200, 3.3835700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56969, 'Billy-Montigny', 'Billy-Montigny', 'Bii-Montin''i,Biji Montini,Biji-Montin''i,Bili-Montini,Billy,Billy-Montigny,bi yi meng di ni,byly mwntyjny,Бии-Монтиньи,Бийи-Монтиньи,Бији Монтињи,Бії-Монтіньї,بيلي مونتيجني,比伊蒙蒂尼', 50.4171100, 2.9028600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56970, 'Billy-Berclau', 'Billy-Berclau', 'Bii-Berklo,Biji Berklo,Biji-Berklo,Bili-Berclo,Bili-Bérclo,Billy-Berclau,bi yi bei er ke luo,byly byrslaw,Бии-Беркло,Бийи-Беркло,Бији Беркло,Бії-Беркло,بيلي بيرسلاو,比伊贝尔克洛', 50.5178300, 2.8661300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56971, 'Billom', 'Billom', 'Bijom,Bilhom,Billom,Billomagus,bi long,biyomu,Бийом,Бијом,Бійом,ビヨム,比隆', 45.7230300, 3.3424300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56972, 'Billère', 'Billere', 'Bier,Bijer,Billere,Billère,Vilhera,Vilhèra,bi ye er,Биер,Бийер,Бијер,Бієр,比耶尔', 43.3000000, -0.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56973, 'Bilieu', 'Bilieu', 'Bilieu,Billieu', 45.4445200, 5.5462400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56974, 'Bihorel', 'Bihorel', 'Bihorel,Biorel,Biorel'',Биорел,Биорель,Біорель', 49.4546800, 1.1223000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56975, 'Biguglia', 'Biguglia', 'Biguglia,Bigul''ja,Bigula,Бигулья,Бигуља,Бігулья', 42.6258900, 9.4332400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56976, 'Bignoux', 'Bignoux', 'Bignoux,Binju,Binu,bi niu,Бињу,Біню,比纽', 46.6000800, 0.4693200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56977, 'Bignan', 'Bignan', 'Begnen,Bignan,Bin''jan,Binan,bi ni ang,Биньян,Бињан,Біньян,比尼昂', 47.8793500, -2.7715300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56978, 'Biganos', 'Biganos', 'Bigano,Biganos,Viganos,Viganòs,bi gang ao,Бигано,Биганос,Біганос,比冈奥', 44.6450400, -0.9736700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56979, 'Bièvres', 'Bievres', 'Bievre,Bievre-la-Montagne,Bievres,Bièvre,Bièvre-la-Montagne,Bièvres', 48.7577200, 2.2188100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56980, 'Biesles', 'Biesles', 'Biesles', 48.0859700, 5.2940900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56981, 'Biesheim', 'Biesheim', 'Biesheim,Bisajm,Bishajm,Biskhajm,bi ye sang,Бисайм,Бисхајм,Бишайм,Бісайм,比耶桑', 48.0411800, 7.5447400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56982, 'Bierne', 'Bierne', 'B''ern,Bern,Bieren,Bierne,Bjern,bi ye er ne,Бьерн,Бєрн,Бјерн,比耶尔讷', 50.9623200, 2.4096300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56983, 'Bienville', 'Bienville', 'Bienville', 48.5758200, 5.0457900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56984, 'Bidart', 'Bidart', 'Bidar,Bidart,Bidarte,Бидар,Бидарт,Бідар', 43.4376000, -1.5912700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56985, 'Bidache', 'Bidache', 'Bidache,Bidaishe,Bidaixon,Bidash,Bidaxune,bi da xu,Бидаш,Бідаш,比达许', 43.4829900, -1.1412100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56986, 'Bias', 'Bias', 'Bias', 44.4165500, 0.6697700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56987, 'Biars-sur-Cère', 'Biars-sur-Cere', 'Biars,Biars-sur-Cere,Biars-sur-Cère', 44.9262900, 1.8540300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56988, 'Biarritz', 'Biarritz', 'BIQ,Biarica,Biarric,Biarritz,Biarriz,Bijaric,Biàrritz,Gorad Bijaryc,Lungsod ng Biarritz,Miarritze,bi ya li ci,bialicheu,biarittsu,byarytz,Биарриц,Бијариц,Біарріц,Горад Біярыц,ביאריץ,بياريتز,بیاریتز,ビアリッツ,比亚里茨,비아리츠', 43.4801200, -1.5555800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56989, 'Biard', 'Biard', 'Biar,Biard,Bjar,bi ya er,Біар,Бјар,比亞爾', 46.5788900, 0.3081200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56990, 'Biache-Saint-Vaast', 'Biache-Saint-Vaast', 'B''jash-Sen-Va,B''jash-Sen-Vaast,Biache-Saint-Waast,Biache-sous-Scarpe,Bjash Sen Vast,Bjash-Sen-Vaast,bi ya shen sheng wa si te,byatsh san fast,Бьяш-Сен-Ва,Бьяш-Сен-Вааст,Бяш-Сен-Вааст,Бјаш Сен Васт,بياتش سان فاست,比亚什圣瓦斯特', 50.3086900, 2.9477700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56991, 'Bézu-Saint-Éloi', 'Bezu-Saint-Eloi', 'Bezu,Bezu-Saint-Eloi,Bézu-Saint-Éloi', 49.2952400, 1.7040400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56992, 'Bezouce', 'Bezouce', 'Besoca,Besoça,Bezouce,Bezus,bo zu ke,Безус,伯祖克', 43.8822900, 4.4907200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56993, 'Bezons', 'Bezons', 'Bezon,Bezons,bei zong,beujong,buzon,bzwn,Безон,بزون,ブゾン,贝宗,브종', 48.9242600, 2.2128000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56994, 'Béziers', 'Beziers', 'BZR,Baeterrae,Besers,Besiers,Besièrs,Bez''e,Bezie,Beziers,Bezije,Bezje,Bezjė,Béziers,bei ji ye,bejie,byzyyh,bzyh,bzyyh,Μπεζιέ,Безие,Безије,Безье,Безьє,Безје,בזייה,بزیه,بيزييه,ベジエ,贝济耶,베지에', 43.3412200, 3.2140200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56995, 'Bezannes', 'Bezannes', 'Bezannes,Bezannes-les-Reims', 49.2233900, 3.9889200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56996, 'Beynost', 'Beynost', 'Beynost', 45.8380900, 5.0060800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56997, 'Beynes', 'Beynes', 'Beynes', 48.8562600, 1.8726100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56998, 'Beynat', 'Beynat', 'Bejna,Beynat,Бейна', 45.1241900, 1.7239200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(56999, 'Beychac-et-Caillau', 'Beychac-et-Caillau', 'Beychac,Beychac-et-Caillau', 44.8778100, -0.4021900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57000, 'Béville-le-Comte', 'Beville-le-Comte', 'Beville,Beville-la-Fontaine,Beville-le-Comte,Béville,Béville-le-Comte', 48.4355800, 1.7130500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57001, 'Beuzeville-la-Grenier', 'Beuzeville-la-Grenier', 'Beuzeville,Beuzeville-la-Grenier,L''Ingenue,L''Ingénue,Saint-Martin-le-Genereux,Saint-Martin-le-Généreux', 49.5915700, 0.4268400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57002, 'Beuzeville', 'Beuzeville', 'Beuzeville,Bezvil,Bezvil'',Bjozvil'',bo ze wei er,Безвил,Безвиль,Безвіль,Бёзвиль,伯泽维尔', 49.3448300, 0.3425400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57003, 'Beuzec-Cap-Sizun', 'Beuzec-Cap-Sizun', 'Beuzec,Beuzec-Cap-Sizun,Beuzeg-ar-C''hab,Beuzeg-ar-Chab,Bezek Kap Sizen,Bezek-Kap-Sizen,Bjozek-Kap-Sizjon,bo ze ke ka xi zan,buzekku=kappu=shizan,Безек Кап Сизен,Безек-Кап-Сизен,Безек-Кап-Сізен,Бёзек-Кап-Сизён,ブゼック＝カップ＝シザン,伯泽克卡西赞', 48.0756700, -4.5120000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57004, 'Beuvry', 'Beuvry', 'Beuvry,Bevri,Bjovri,bo fu li,bywfry,Беври,Беврі,Бёври,بيوفري,伯夫里', 50.5167400, 2.6854100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57005, 'Beuvrages', 'Beuvrages', 'Beuvrages,Bevrazh,Bjovrazh,bo fu la ri,Бевраж,Бёвраж,伯夫拉日', 50.3841400, 3.4942000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57006, 'Beuvillers', 'Beuvillers', 'Beuvillers', 49.1296100, 0.2549200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57007, 'Beuville', 'Beuville', '', 49.2436400, -0.3258500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57008, 'Beure', 'Beure', 'Ber,Beure,Бер', 47.2069000, 6.0054800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57009, 'Betz', 'Betz', 'Betz', 49.1555800, 2.9558400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57010, 'Betton', 'Betton', 'Betton,Bezhon', 48.1804800, -1.6382900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57011, 'Bettancourt-la-Ferrée', 'Bettancourt-la-Ferree', 'Bettancourt,Bettancourt-la-Ferree,Bettancourt-la-Ferrée', 48.6489800, 4.9697100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57012, 'Béthune', 'Bethune', 'Beten,Bethune,Bethunia,Betin,Betjun,Betunne,Béthune,Bétunne,bei di ne,bete~yunu,betwin,btwwn,bythwn,Бетен,Бетин,Бетюн,بتوون,بيثون,ベテューヌ,贝蒂讷,베튄', 50.5333300, 2.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57013, 'Bethoncourt', 'Bethoncourt', 'Bethoncourt,Betonkur,Béthoncourt,Бетонкур', 47.5351200, 6.8050400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57014, 'Béthisy-Saint-Pierre', 'Bethisy-Saint-Pierre', 'Bethisy-Saint-Pierre,Bethisy-la-Butte,Betizi Sen Pjer,Betizi-Sen-Perr,Béthisy-Saint-Pierre,Béthisy-la-Butte,bei di xi sheng pi ye er,Бетизи Сен Пјер,Бетізі-Сен-Пєрр,贝蒂西圣皮耶尔', 49.3048200, 2.7963600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57015, 'Béthisy-Saint-Martin', 'Bethisy-Saint-Martin', 'Bethisy-Saint-Martin,Bethisy-sur-Autonne,Betizi Sen Marten,Betizi-Sen-Marten,Béthisy-Saint-Martin,Béthisy-sur-Autonne,bei di xi sheng ma er tan,Бетизи Сен Мартен,Бетізі-Сен-Мартен,贝蒂西圣马尔坦', 49.2948000, 2.8174300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57016, 'Bétheny', 'Betheny', 'Betheny,Bétheny', 49.2849800, 4.0549500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57017, 'Béthencourt-sur-Mer', 'Bethencourt-sur-Mer', 'Betankur na Moru,Betankur-sjur-Mer,Bethencourt,Bethencourt-sur-Mer,Betincourt-su-Mer,Béthencourt,Béthencourt-sur-Mer,Bétincourt-su-Mér,bin hai bei dang ku er,Бетанкур на Мору,Бетанкур-сюр-Мер,滨海贝当库尔', 50.0775600, 1.5034800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57018, 'Bessines-sur-Gartempe', 'Bessines-sur-Gartempe', 'Becinas,Besin sir Gartan,Bessin-sjur-Gartamp,Bessines,Bessines-sur-Gartempe,jia er tang pu he pan bei xi na,Бесин сир Гартан,Бессин-сюр-Гартамп,Бессін-сюр-Гартамп,加尔唐普河畔贝西纳', 46.1079900, 1.3686500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57019, 'Bessines', 'Bessines', 'Bessines', 46.3020700, -0.5129400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57020, 'Bessières', 'Bessieres', 'Bessieres,Bessières', 43.7986100, 1.6062400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57021, 'Besse-sur-Issole', 'Besse-sur-Issole', 'Beca,Bes sir Izol,Bes-sjur-Isol'',Bess-sjur-Issol'',Bessa dIssola,Bessa dIssòla,Besse,Besse-sur-Issole,Beça,yi suo er he pan bei si,Бес сир Изол,Бес-сюр-Исоль,Бесс-сюр-Іссоль,伊索尔河畔贝斯', 43.3495700, 6.1775900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57022, 'Bessé-sur-Braye', 'Besse-sur-Braye', 'Besse,Besse-sur-Braye,Bessé,Bessé-sur-Braye', 47.8333300, 0.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57023, 'Bessenay', 'Bessenay', 'Bessenay', 45.7772100, 4.5537600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57024, 'Bessèges', 'Besseges', 'Besezh,Besseges,Besseja,Bessezh,Bessèges,Bessèja,bei sai ri,Бесеж,Бессеж,贝塞日', 44.2923000, 4.0966100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57025, 'Bessay-sur-Allier', 'Bessay-sur-Allier', 'Bese sir Alije,Bessay,Bessay-sur-Allier,Besse-sjur-Al''e,a li ye he pan bei sai,Бесе сир Алије,Бессе-сюр-Алье,Бессе-сюр-Альє,阿利耶河畔贝赛', 46.4435200, 3.3624800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57026, 'Bessancourt', 'Bessancourt', 'Besankur,Bessancourt,Bessankur,bei sang ku er,Бесанкур,Бессанкур,贝桑库尔', 49.0376500, 2.2093600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57027, 'Bessan', 'Bessan', 'Becan,Besan,Bessan,Beçan,bei sang,Бесан,Бессан,贝桑', 43.3619600, 3.4228800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57028, 'Besné', 'Besne', 'Bene,Besne,Besné,Gwennenid,Vinduneta,bei si nei,Бене,贝斯内', 47.4000000, -2.0897600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57029, 'Besançon', 'Besancon', 'Becoinson,Besancon,Besanson,Besanzon,Besanzón,Besançon,Bezanson,Bezansona,Bezansonas,Gorad Bezanson,Vesuntio,bei sang song,bejhamsom,beujangsong,bexs xngsng,bezansoni,buzanson,byzanswn,byznswn,bzanswn,Μπεζανσόν,Безансон,Бесансон,Горад Безансон,Բեզանսոն,בזאנסון,בעזאנסאן,بزانسون,بيزنسون,بیزانسون,بیسانکاں,बेझाँसों,เบอซ็องซง,ბეზანსონი,ブザンソン,贝桑松,브장송', 47.2487800, 6.0181500, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57030, 'Béruges', 'Beruges', 'Berizh,Berjuzh,Beruges,Béruges,bei lu re,Бериж,Берюж,贝吕热', 46.5673800, 0.2074100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57031, 'Bertry', 'Bertry', 'Bertri,Bertry,bei er te li,Бертри,Бертрі,贝尔特里', 50.0871800, 3.4429800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57032, 'Bertrange', 'Bertrange', 'Bertrange', 49.3076900, 6.1789300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57033, 'Berthecourt', 'Berthecourt', 'Bertekur,Berthecourt,Bertkur,bei er tai ku er,Бертекур,Берткур,贝尔泰库尔', 49.3509700, 2.2247100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57034, 'Bertheauville', 'Bertheauville', 'Bertheauville', 49.7548900, 0.6019400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57035, 'Berteaucourt-les-Dames', 'Berteaucourt-les-Dames', 'Berteaucourt,Berteaucourt-les-Dames', 50.0469700, 2.1575000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57036, 'Berstett', 'Berstett', '', 48.6790000, 7.6572100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57037, 'Berson', 'Berson', 'Berson', 45.1067900, -0.5877400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57038, 'Bersée', 'Bersee', 'Bersee,Bersée', 50.4797800, 3.1476500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57039, 'Berrwiller', 'Berrwiller', 'Berrwiller', 47.8491100, 7.2197800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57040, 'Berrien', 'Berrien', 'Berrien', 48.4027800, -3.7526600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57041, 'Berric', 'Berric', 'Berik,Berric,Berrig,Berrik,bei er li ke,Берик,Беррик,贝尔里克', 47.6332600, -2.5225000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57042, 'Berre-l''Étang', 'Berre-l''Etang', 'Berre,Berre-l''Etang,Berre-l''Étang', 43.4780900, 5.1704400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57043, 'Berre-les-Alpes', 'Berre-les-Alpes', 'Ber dez Alp,Ber-lez-Al''p,Berr-lez-Al''p,Berra,Berre,Berre-des Alpes,Berre-des-Alpes,Bèrra,Castrum Berrae,bei er lai a er pei,byry lyh alb,Бер дез Алп,Бер-лез-Альп,Берр-лез-Альп,بيري ليه ألب,贝尔莱阿尔佩', 43.8333300, 7.3333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57044, 'Bernis', 'Bernis', 'Bernis', 43.7691300, 4.2871300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57045, 'Bernin', 'Bernin', 'Bernin', 45.2714000, 5.8651600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57046, 'Bernières-sur-Mer', 'Bernieres-sur-Mer', 'Bern''er-sjur-Mer,Bernieres,Bernieres-sur-Mer,Bernijer na Moru,Bernières,Bernières-sur-Mer,bin hai bei er ni ai,Бернијер на Мору,Берньер-сюр-Мер,Берньєр-сюр-Мер,滨海贝尔尼埃', 49.3305700, -0.4229900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57047, 'Berneval-le-Grand', 'Berneval-le-Grand', 'Berneval,Berneval le Gran,Berneval''-le-Gran,Berneval-le-Grand,Берневал ле Гран,Берневаль-ле-Гран', 49.9532800, 1.1875500, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57048, 'Bernes-sur-Oise', 'Bernes-sur-Oise', 'Bernes,Bernes-sur-Oise', 49.1612800, 2.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57049, 'Berné', 'Berne', 'Berne,Berné,bei er nei,Берне,贝尔内', 47.9947000, -3.3942100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57050, 'Bernay', 'Bernay', 'Bernay,Bernay-de-l''Eure', 49.0888800, 0.5985800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57051, 'Bernaville', 'Bernaville', 'Bernavil,Bernavil'',Bernaville,Bérnaville,bei er na wei er,Бернавил,Бернавиль,Бернавіль,贝尔纳维尔', 50.1323200, 2.1630000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57052, 'Bernardswiller', 'Bernardswiller', 'Batschwiller,Bernardsviler,Bernardsviller,Bernardswiller,Bernhardsweiler,bei er na er de si wei lai,brnardswylr,byrnardswylyr,Бернардсвилер,Бернардсвиллер,Бернардсвіллер,برناردسویلر,بيرناردسويلير,贝尔纳尔德斯维莱', 48.4520800, 7.4617100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57053, 'Berlaimont', 'Berlaimont', 'Berlaimont,Berlemon,bei er lai meng,Берлемон,贝尔莱蒙', 50.2015500, 3.8134300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57054, 'Bergues', 'Bergues', 'Berg,Bergn,Bergues,Bergues-sur-Colme,Berzh,Sint-Winoksbergen,bei er ge,Берг,Берж,贝尔格', 50.9688200, 2.4324200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57055, 'Bergholtz', 'Bergholtz', 'Bergholtz', 47.9159500, 7.2461200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57056, 'Bergheim', 'Bergheim', 'Bergem,Bergheim,Bergkhajm,Бергем,Бергхајм', 48.2054000, 7.3629900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57057, 'Bergerac', 'Bergerac', 'Bergerac,Berzherak,Brageirac,EGC,Бержерак', 44.8500000, 0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57058, 'Berck', 'Berck', 'Berck-sur-Mer', 50.4000000, 1.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57059, 'Berck-Plage', 'Berck-Plage', '', 50.4070400, 1.5644600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57060, 'Bérat', 'Berat', 'Berat,Bérat', 43.3785700, 1.1757200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57061, 'Benquet', 'Benquet', 'Benke,Benquet,bang qu ai,Бенке,邦屈埃', 43.8299200, -0.5010200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57062, 'Bénouville', 'Benouville', 'Benouville,Benuvil,Bénouville,Бенувил', 49.2415100, -0.2824600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57063, 'Bénodet', 'Benodet', 'Benode,Benoded,Benodet,Bénodet,bei nuo dai,Беноде,贝诺代', 47.8753100, -4.1058000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57064, 'Bennwihr', 'Bennwihr', 'Bennvir,Bennweier,Benvir,bang wei,Бенвир,Беннвир,Беннвір,邦维', 48.1445600, 7.3244500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57065, 'Bennecourt', 'Bennecourt', 'Benkur,Bennecourt,Bennkur,Бенкур,Беннкур', 49.0414800, 1.5546900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57066, 'Béning-lès-Saint-Avold', 'Bening-les-Saint-Avold', 'Bening,Bening-les-Saint-Avold,Béning-lès-Saint-Avold', 49.1371600, 6.8297500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57067, 'Benfeld', 'Benfeld', 'Banfald,Benfel''d,Benfeld,bang fu er,benferudo,bynfyld,Бенфелд,Бенфельд,بينفيلد,ベンフェルド,邦弗尔', 48.3706200, 7.5937000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57068, 'Benet', 'Benet', 'Benet', 46.3697200, -0.5933300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57069, 'Bénesse-Maremne', 'Benesse-Maremne', 'Benesse,Benesse-Maremne,Benesse-Marenne,Bénesse-Maremne', 43.6367800, -1.3577300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57070, 'Bénéjacq', 'Benejacq', 'Benejac,Benejacq,Benezhak,Bénéjacq,bei nei ya ke,Бенежак,贝内雅克', 43.2000000, -0.2166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57071, 'Belz', 'Belz', 'Belz', 47.6750600, -3.1680000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57072, 'Belvès', 'Belves', 'Bel''ve,Bel''ves,Bellumvidere,Belve,Belves,Belvès,Belvés,bei er wei,bylws,Белве,Бельве,Бельвес,بیلوس,贝尔韦', 44.7763200, 1.0058800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57073, 'Belpech', 'Belpech', 'Bel''pesh,Belpech,Belpesh,Belpueg,Bèlpuèg,bei er pei ke,Белпеш,Бельпеш,贝尔佩克', 43.1995700, 1.7515700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57074, 'Belmont-sur-Rance', 'Belmont-sur-Rance', 'Bel''mon-sjur-Rans,Belmon sir Rans,Belmont,Belmont de Rance,Belmont-sur-Rance,Bèlmont de Rance,lang ke he pan bei er meng,Белмон сир Ранс,Бельмон-сюр-Ранс,朗克河畔贝尔蒙', 43.8198100, 2.7552400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57075, 'Belmont-de-la-Loire', 'Belmont-de-la-Loire', 'Belmont,Belmont-de-la-Loire', 46.1664000, 4.3473200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57076, 'Belloy-en-France', 'Belloy-en-France', 'Belloy,Belloy-en-France,Bellua-an-Frans,Beloaj an Frans,fu lang si de qu bei lu wa,Беллуа-ан-Франс,Белоај ан Франс,弗朗斯地区贝卢瓦', 49.0883700, 2.3715900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57077, 'Belligné', 'Belligne', 'Belenieg,Beline,Beliniacum,Belligne,Belligné,Bellin''e,bei li nie,Белиње,Белліньє,贝利涅', 47.4677400, -1.0278000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57078, 'Bellignat', 'Bellignat', 'Belignat,Belina,Belinya,Bellignat,Bellin''ja,bei li ni ya,bylynyat,Белиња,Беллинья,Беллінья,Բելինյա,بيلينيات,贝利尼亚', 46.2423700, 5.6284300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57079, 'Belley', 'Belley', 'Bele,Belle,Bellicium,Bèlê,bei lai,belle,bere,bly,byly,Беле,Белле,Բելլե,بلی,بلے,بيلي,ベレー,贝莱,벨레', 45.7666700, 5.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57080, 'Belleville-sur-Vie', 'Belleville-sur-Vie', 'Bel''vil''-sjur-Vi,Belevil sir Vie,Belleville,Belleville-sur-Vie,Belvil sir Vi,wei ye he pan bei lei wei lei,Белвил сир Ви,Белевил сир Вие,Бельвіль-сюр-Ві,维耶河畔贝勒维勒', 46.7836900, -1.4290500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57081, 'Belleville', 'Belleville', 'Bel''vil'',Belleville,Belleville sobre Saona,Belleville-sur-Saone,Belleville-sur-Saône,Belvil,bylyfyl,Белвил,Бельвіль,بيليفيل', 46.1000000, 4.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57082, 'Belleville-sur-Meuse', 'Belleville-sur-Meuse', 'Belleville,Belleville-sur-Meuse', 49.1786300, 5.3719000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57083, 'Belleville', 'Belleville', 'Belleville', 48.8190200, 6.1010800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57084, 'Belleville-sur-Loire', 'Belleville-sur-Loire', '', 47.5000000, 2.8500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57085, 'Bellevaux', 'Bellevaux', 'Bellevaux', 46.2598000, 6.5347400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57086, 'Belleu', 'Belleu', 'Belleu', 49.3591700, 3.3355600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57087, 'Bellerive-sur-Allier', 'Bellerive-sur-Allier', 'Bel''riv-sjur-Al''e,Bellerive,Bellerive-sur-Allier,Belriv sir Alije,Vaissa,a li ye he pan bei lei li fu,Белрив сир Алије,Бельрив-сюр-Алье,Бельрив-сюр-Альє,阿利耶河畔贝勒里夫', 46.1163300, 3.4033800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57088, 'Bellengreville', 'Bellengreville', 'Bellengreville', 49.1242500, -0.2096100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57089, 'Belleneuve', 'Belleneuve', 'Belleneuve', 47.3622400, 5.2639300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57090, 'Bellenaves', 'Bellenaves', 'Balanava,Balanavia,Bel''nav,Bellenaves,Belnav,bei lei na wei,Белнав,Бельнав,贝勒纳韦', 46.1997900, 3.0821500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57091, 'Bellême', 'Belleme', 'Belem,Belismum,Bellem,Belleme,Bellême,bei lai mu,Белем,Беллем,贝莱姆', 48.3732900, 0.5700500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57092, 'Belle-Isle-en-Terre', 'Belle-Isle-en-Terre', 'Bel Il an Ter,Bel''-Il''-an-Ter,Bel''-Il''-an-Terr,Bella Insula,Belle-Isle,Belle-Isle-en-Terre,Benac''h,Benach,tai er de qu bei lai-yi si er,Бел Ил ан Тер,Бель-Іль-ан-Терр,Бель-Иль-ан-Тер,Бель-Иль-ан-Терр,泰尔地区贝莱-伊斯尔', 48.5447800, -3.3950000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57093, 'Bellegarde-sur-Valserine', 'Bellegarde-sur-Valserine', 'Bel''gard-sjur-Val''serin,Belgard sir Valserin,Bellegarde,berugarudo=shuru=vu~arusurinu,blgard-swr-walzryn,bylyghard-swr-falsyryn,wa er se li en he pan bei lei jia er de,Белгард сир Валсерин,Бельгард-сюр-Вальсерин,بلگارد-سور-والزرین,بيليغارد-سور-فالسيرين,ベルガルド＝シュル＝ヴァルスリーヌ,瓦尔瑟里恩河畔贝勒加尔德', 46.1078700, 5.8242100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57094, 'Bellegarde-en-Forez', 'Bellegarde-en-Forez', 'Bellegarde,Bellegarde-en-Forez', 45.6466200, 4.2990800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57095, 'Bellegarde', 'Bellegarde', 'Bellegarde-du-Loiret', 47.9833300, 2.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57096, 'Bellegarde', 'Bellegarde', 'Bellegarde', 43.7532900, 4.5165400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57097, 'Bellaing', 'Bellaing', 'Bellaing', 50.3681100, 3.4251500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57098, 'Bellac', 'Bellac', 'Belac,Belak,Bellac,Bellak,bei la ke,berakku,Белак,Беллак,ベラック,贝拉克', 46.1166700, 1.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57099, 'Belin-Béliet', 'Belin-Beliet', 'Belen Belije,Belen-Bel''e,Belin e Beliet,bei lan bei li ye,Белен Белије,Белен-Белье,Белен-Бельє,贝兰贝利耶', 44.5000000, -0.7833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57100, 'Béligneux', 'Beligneux', 'Beligneux,Béligneux', 45.8682200, 5.1268300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57101, 'Belgentier', 'Belgentier', 'Bel''zhant''e,Belgentier,Belzhantje,Beujancia,Beujanciá,bei er gang di ye,Белжантје,Бельжантье,Бельжантьє,贝尔冈蒂耶', 43.2459400, 6.0009500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57102, 'Belfort', 'Belfort', 'BOR,Beffert,Bel''for,Belfor,Belfort,Belfortium,Belfòrt,Gorad Bel''for,bei er fu,belpoleu,beruforu,blfwr,Μπελφόρ,Белфор,Бельфор,Горад Бельфор,بلفور,แบลฟอร์,ベルフォール,贝尔福,벨포르', 47.6333300, 6.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57103, 'Bélesta', 'Belesta', 'Belesta,Bélesta', 42.9022800, 1.9332500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57104, 'Belcodène', 'Belcodene', 'Belcodene,Belcodène', 43.4261200, 5.5887800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57105, 'Belbeuf', 'Belbeuf', 'Belbeuf', 49.3876600, 1.1424500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57106, 'Belberaud', 'Belberaud', 'Belberaud', 43.5055700, 1.5672500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57107, 'Bélâbre', 'Belabre', 'Belabr,Belabre,Bélâbre,bei la bu er,Белабр,贝拉布尔', 46.5512100, 1.1579100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57108, 'Beignon', 'Beignon', 'Beignon,Ben''on,Benion,Benon,Bidainonum,bei ni weng,Беньон,Бењон,贝尼翁', 47.9720000, -2.1693300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57109, 'Behren-lès-Forbach', 'Behren-les-Forbach', 'Behren,Behren-les-Forbach,Behren-lès-Forbach', 49.1664000, 6.9433600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57110, 'Bégrolles-en-Mauges', 'Begrolles-en-Mauges', 'Begrol an Mozh,Begrol''-an-Mozh,Begrolles,Begrolles-en-Mauges,Bégrolles,Bégrolles-en-Mauges,beguroru=an=moju,mo re de qu bei ge luo lai,Бегрол ан Мож,Бегроль-ан-Мож,ベグロル＝アン＝モージュ,莫热地区贝格罗莱', 47.1404800, -0.9400000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57111, 'Bègles', 'Begles', 'Begl,Begl'',Begla,Begles,Beglese,Bègles,begeul,beguru,bei ge lai,bgl,Бегл,Беглесе,Бегль,بگل,ベグル,贝格莱,베글', 44.8084500, -0.5480900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57112, 'Bégard', 'Begard', 'Bear,Begar,Begard,Begard / Bear,Begardum,Bégard,Bégard / Bear,Prajou,bei jia er,Бегар,贝加尔', 48.6275400, -3.3006700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57113, 'Béganne', 'Beganne', 'Began,Begann,Beganne,Begaon,Bekamne plebs,Béganne,bei gang,Беган,Беганн,贝冈', 47.5967000, -2.2416200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57114, 'Bégaar', 'Begaar', '', 43.8236300, -0.8490400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57115, 'Bédoin', 'Bedoin', 'Bedoen,Bedoin,Bedouin-l''Aneanti,Beduehn,Beduen,Bédoin,Bédouin-l''Anéanti,bei duan,Бедоен,Бедуен,Бедуэн,贝端', 44.1243200, 5.1804000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57116, 'Bédée', 'Bedee', 'Bede,Bedee,Bediscum,Bezeg,Bédée,bei dai ai,Беде,贝代埃', 48.1795300, -1.9447700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57117, 'Bédarrides', 'Bedarrides', 'Bedarid,Bedarrid,Bedarrida,Bedarrides,Bédarrides,bei da er li dai,Бедарид,Бедаррид,贝达尔里代', 44.0402200, 4.8981900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57118, 'Bédarieux', 'Bedarieux', 'Bedar''e,Bedare,Bedarieux,Bedarius,Bedarje,Bédarieux,bei da li yue,Бедарье,Бедарє,Бедарје,贝达里约', 43.6155300, 3.1571400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57119, 'Bécon-les-Granits', 'Becon-les-Granits', 'Becon,Becon-les-Granits,Bekon le Granit,Bekon-le-Grani,Bécon,Bécon-les-Granits,bei kong lai ge la ni te,Бекон ле Гранит,Бекон-ле-Грані,贝孔莱格拉尼特', 47.5013400, -0.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57120, 'Beauzelle', 'Beauzelle', 'Beauzelle', 43.6671300, 1.3751800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57121, 'Beauzac', 'Beauzac', 'Bauzac,Beauzac', 45.2600100, 4.0987900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57122, 'Beauvoisin', 'Beauvoisin', 'Beauvoisin', 43.7183500, 4.3233900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57123, 'Beauvois-en-Cambrésis', 'Beauvois-en-Cambresis', 'Beauvois,Beauvois-en-Cambresis,Beauvois-en-Cambrésis,Bovoa an Kambrezi,Bovua-an-Kambrezi,bo wa ang kang bu lei xi,Бовоа ан Камбрези,Бовуа-ан-Камбрези,Бовуа-ан-Камбрезі,博瓦昂康布雷西', 50.1373500, 3.3787000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57124, 'Beauvoir-sur-Niort', 'Beauvoir-sur-Niort', 'Beauvoir,Beauvoir-sur-Niort', 46.1801700, -0.4717800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57125, 'Beauvoir-sur-Mer', 'Beauvoir-sur-Mer', 'Beauvoir,Beauvoir-sur-Mer,Bovoa na Moru,Bovoa sir Mer,Bovuar-sjur-Mer,bin hai bo wa,bovu~owaru=shuru=meru,Бовоа на Мору,Бовоа сир Мер,Бовуар-сюр-Мер,ボーヴォワール＝シュル＝メール,滨海博瓦', 46.9127400, -2.0415600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57126, 'Beauvoir-de-Marc', 'Beauvoir-de-Marc', 'Beauvoir,Beauvoir-de-Marc', 45.5113200, 5.0824900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57127, 'Beauvallon', 'Beauvallon', 'Beauvallon', 44.8566200, 4.9115500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57128, 'Beauval', 'Beauval', 'Beauval', 50.1078900, 2.3326900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57129, 'Beauvais', 'Beauvais', 'Beauvais,Bellovacum,Bieuvais,Bove,Bovoa,Bovė,Duthil-la-Montagne,La Chaussee-de-la-Montagne,La Chaussée-de-la-Montagne,bo wei,bobe,bovu~e,bwwh,Бове,Бовоа,בווה,بووه,ቦቬ,ボーヴェ,博韦,보베', 49.4333300, 2.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57130, 'Beautor', 'Beautor', 'Beautor', 49.6521400, 3.3447500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57131, 'Beautiran', 'Beautiran', 'Bautiran,Beautiran,Botiran,bo di lang,Ботиран,Ботіран,博蒂朗', 44.7039300, -0.4520200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57132, 'Beausoleil', 'Beausoleil', 'Beausoleil', 43.7490400, 7.4170200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57133, 'Beausemblant', 'Beausemblant', 'Beausemblant', 45.2178400, 4.8284700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57134, 'Beaurevoir', 'Beaurevoir', 'Beaurevoir,Borevoar,Borevuar,bo lei wa er,Боревоар,Боревуар,Բորևուար,博雷瓦尔', 49.9971400, 3.3085500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57135, 'Beaurepaire', 'Beaurepaire', 'Beaurepaire', 46.9097700, -1.0892800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57136, 'Beaurepaire', 'Beaurepaire', 'Beaurepaire', 45.3367500, 5.0552500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57137, 'Beaurainville', 'Beaurainville', 'Beaurain-sur-Canche,Beaurainville,Biaurinville,Borenvil,Borenvil'',bo lan wei er,bywraynfyl,Боренвил,Боренвиль,Боренвіль,بيوراينفيل,博兰维尔', 50.4243200, 1.8993800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57138, 'Beaurains', 'Beaurains', 'Beaurains,Biaurins,Boren,bo lan,bywrayns,Борен,بيوراينس,博兰', 50.2659900, 2.7946700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57139, 'Beauquesne', 'Beauquesne', 'Beauquesne', 50.0852600, 2.3927600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57140, 'Beaupuy', 'Beaupuy', '', 44.5354900, 0.1490000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57141, 'Beaupuy', 'Beaupuy', 'Beaupuy', 43.6471300, 1.5551700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57142, 'Beaupréau', 'Beaupreau', 'Beaupreau,Beaupréau,Bopreo,Bopro,bo pu lei ao,bopureo,Бопрео,Бопро,ボープレオ,博普雷奥', 47.2046400, -0.9870300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57143, 'Beaune-la-Rolande', 'Beaune-la-Rolande', 'Beaune,Beaune-la-Rolande,Bon la Roland,Bon-la-Roland,bo en la luo lang de,Бон ла Роланд,Бон-ла-Роланд,博恩拉罗朗德', 48.0712400, 2.4314000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57144, 'Beaune', 'Beaune', 'Beaune,Belna,Bon,Bonas,Gorad Bon,bo ne,bon,bonu,bu meng,bwn,Бон,Горад Бон,بون,ボーヌ,博讷,布蒙,본', 47.0333300, 4.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57145, 'Beaumont-sur-Sarthe', 'Beaumont-sur-Sarthe', 'Beaumont,Beaumont-le-Vicomte,Beaumont-sur-Sarthe,Bomon sir Sart,Bomon-sjur-Sart,Бомон сир Сарт,Бомон-сюр-Сарт', 48.2277200, 0.1318600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57146, 'Beaumont-sur-Oise', 'Beaumont-sur-Oise', 'Beaumont,Beaumont-sur-Oise,Bomon sir Oaz,Bomon-sjur-Uaz,wa ci he pan bo meng,Бомон сир Оаз,Бомон-сюр-Уаз,瓦兹河畔博蒙', 49.1423200, 2.2870500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57147, 'Beaumont-sur-Lèze', 'Beaumont-sur-Leze', 'Beaumont,Beaumont-sur-Leze,Beaumont-sur-Lèze', 43.3809500, 1.3582600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57148, 'Beaumont-Monteux', 'Beaumont-Monteux', 'Beaumont,Beaumont-Monteux', 45.0194200, 4.9224800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57149, 'Beaumont-lès-Valence', 'Beaumont-les-Valence', 'Beaumont,Beaumont-les-Valence,Beaumont-lès-Valence,Beumont de Valenca,Bomon le Valans,Bomon-le-Valans,Bèumont de Valença,bo meng lai wa lang ke,Бомон ле Валанс,Бомон-ле-Валанс,博蒙莱瓦朗克', 44.8632800, 4.9457000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57150, 'Beaumont-le-Roger', 'Beaumont-le-Roger', 'Beaumont,Beaumont-le-Roger,Bomon le Rozhe,Bomon-le-Rozhe,bo meng lai luo re,Бомон ле Роже,Бомон-ле-Роже,博蒙莱罗热', 49.0783900, 0.7808100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57151, 'Beaumont-la-Ronce', 'Beaumont-la-Ronce', 'Beaumont,Beaumont-la-Ronce', 47.5694800, 0.6701700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57152, 'Beaumont-Hague', 'Beaumont-Hague', 'Beaumont,Beaumont-Hague', 49.6638700, -1.8382200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57153, 'Beaumont-en-Véron', 'Beaumont-en-Veron', 'Beaumont', 47.1939700, 0.1843600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57154, 'Beaumont-du-Gâtinais', 'Beaumont-du-Gatinais', 'Beaumont', 48.1386000, 2.4791300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57155, 'Beaumont-du-Périgord', 'Beaumont-du-Perigord', 'Beaumont,Beaumont-du-Perigord,Beaumont-du-Périgord,Belli Mons,Belmont,Belmont de Perigord,Bomon di Perigor,Bomon-dju-Perigor,Bèlmont,Bèlmont de Perigòrd,bo meng di pei li ge er,Бомон ди Перигор,Бомон-дю-Перигор,博蒙迪佩里戈尔', 44.7666200, 0.7691600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57156, 'Beaumont-de-Pertuis', 'Beaumont-de-Pertuis', 'Beaumont,Beaumont-de-Pertuis,Beumont dAte,Beumont de Pertus,Beumont de Pertús,Bomon de Perti,Bomon-de-Pertjui,Bèumont de Pertús,bo meng de pei er di yi,Бомон де Перти,Бомон-де-Пертюи,Бомон-де-Пертюї,博蒙德佩尔蒂伊', 43.7378800, 5.6861800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57157, 'Beaumont-de-Lomagne', 'Beaumont-de-Lomagne', 'Beaumont,Beaumont-de-Lomagne,Beumont de Lomanha,Bomon de Loman,Bomon-de-Loman'',Bèumont de Lomanha,bo meng de luo ma ge,Бомон де Ломањ,Бомон-де-Ломань,博蒙德洛马格', 43.8828500, 0.9876200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57158, 'Beaumont', 'Beaumont', 'Beaumont', 46.7377300, 0.4296100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57159, 'Beaumont', 'Beaumont', 'Beaumont', 46.1015600, 6.1173200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57160, 'Beaumont', 'Beaumont', 'Beaumont,Bourg-Montagne', 45.7512300, 3.0835500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57161, 'Beaumetz-lès-Loges', 'Beaumetz-les-Loges', '', 50.2389700, 2.6581800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57162, 'Beaumes-de-Venise', 'Beaumes-de-Venise', 'Baumas,Baumas de Venisa,Beaumes,Beaumes-de-Venise,Bom de Veniz,Bom-de-Veniz,bo mo de fu ni se,Бом де Вениз,Бом-де-Вениз,Бом-де-Веніз,博默德弗尼瑟', 44.1193400, 5.0242600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57163, 'Beaulon', 'Beaulon', 'Beaulon', 46.6017800, 3.6726200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57164, 'Beaulieu-sur-Mer', 'Beaulieu-sur-Mer', 'Beaulieu,Beaulieu-sur-Mer,Bellus Locus,Beuluec de Mar,Bol''e-sjur-Mer,Bol''jo-sjur-Mer,Bolije na Moru,Bèuluec de Mar,XBM,bin hai bo e,boryu=shuru=meru,bywlyw swr myr,Болије на Мору,Больё-сюр-Мер,Больє-сюр-Мер,بيوليو سور مير,ボーリュー＝シュル＝メール,滨海博略', 43.7075800, 7.3328900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57165, 'Beaulieu-sur-Layon', 'Beaulieu-sur-Layon', 'Beaulieu,Beaulieu-sur-Layon,Bol''e-sjur-Lejon,Bolije sir Lajon,lai weng he pan bo li e,Болије сир Лајон,Больє-сюр-Лейон,莱翁河畔博利厄', 47.3109500, -0.5898800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57166, 'Beaulieu-sur-Dordogne', 'Beaulieu-sur-Dordogne', 'Beaulieu,Beaulieu-sur-Dordogne,Bel Luec,Belluec,Bellus Locus ad Duranium,Bol''e-sjur-Dordon'',Bol''jo-sjur-Dordon'',Bolije na Dordoni,Bèlluèc,Bél Luéc,bo li yex-sur-d xrdxy,boryu=shuru=dorudonyu,duo er duo ni he pan bo li e,Болије на Дордоњи,Болье-сюр-Дордонь,Больё-сюр-Дордонь,Больє-сюр-Дордонь,โบลีเยอ-ซูร์-ดอร์ดอญ,ボーリュー＝シュル＝ドルドーニュ,多尔多尼河畔博利厄', 44.9782600, 1.8383500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57167, 'Beaulieu-sous-la-Roche', 'Beaulieu-sous-la-Roche', 'Beaulieu,Beaulieu-sous-la-Roche,Bol''e-su-la-Rosh,Bolije su la Rosh,bo li e su si-la luo she,Болије су ла Рош,Больє-су-ла-Рош,博利厄苏斯-拉罗舍', 46.6764700, -1.6112900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57168, 'Beaulieu-lès-Loches', 'Beaulieu-les-Loches', 'Beaulieu,Beaulieu-les-Loches,Beaulieu-lès-Loches', 47.1252600, 1.0158500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57169, 'Beaulieu', 'Beaulieu', 'Beaulieu', 43.7286100, 4.0219400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57170, 'Beaujeu', 'Beaujeu', 'Beaujeu,Bojor,Bôjor', 46.1517600, 4.5924300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57171, 'Beaugency', 'Beaugency', 'Balgentiacum,Beaugency,Bozhansi,bo rang xi,Божанси,Божансі,博让西', 47.7801900, 1.6270500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57172, 'Beaufort-en-Vallée', 'Beaufort-en-Vallee', 'Beaufort,Beaufort-en-Vallee,Beaufort-en-Vallée,Bofor an Vale,Bofor-an-Valle,wa lai ai de qu bo fu er,Бофор ан Вале,Бофор-ан-Валле,瓦莱埃地区博福尔', 47.4396500, -0.2189000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57173, 'Beaufort', 'Beaufort', 'Beaufort,Beaufort-sur-Doron,Mont-Grand', 45.7177600, 6.5739100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57174, 'Beaufay', 'Beaufay', 'Beaufay', 48.1466400, 0.3622400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57175, 'Beaucroissant', 'Beaucroissant', 'Beaucroissant', 45.3422900, 5.4694200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57176, 'Beaucouzé', 'Beaucouze', 'Beaucouze,Beaucouzé,Bokuze,bo ku ze,Бокузе,博库泽', 47.4744400, -0.6301600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57177, 'Beaucourt', 'Beaucourt', 'Beaucourt,Bokur,bo ku er,Бокур,博库尔', 47.4899000, 6.9240700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57178, 'Beauchastel', 'Beauchastel', 'Beauchastel', 44.8275900, 4.7969600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57179, 'Beauchamps', 'Beauchamps', 'Beauchamps', 50.0120200, 1.5176400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57180, 'Beauchamp', 'Beauchamp', 'Beauchamp', 49.0166700, 2.2000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57181, 'Beaucé', 'Beauce', 'Beauce,Beaucé,Belzeg', 48.3389000, -1.1580400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57182, 'Beaucamps-le-Vieux', 'Beaucamps-le-Vieux', 'Beaucamps-le-Vieu,Beaucamps-le-Vieux', 49.8464200, 1.7827200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57183, 'Beaucaire', 'Beaucaire', 'Beaucaire,Bellcaire,Beucaire,Boker,Bèucaire,Castrum Bellicadri,Pont-National,bo kai er,bokeru,Бокер,ボーケール,博凯尔', 43.8080600, 4.6441700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57184, 'Bazouges-sur-le-Loir', 'Bazouges-sur-le-Loir', 'Bazouges,Bazuzh na Loari,Bazuzh-sjur-le-Luar,Базуж на Лоари,Базуж-сюр-ле-Луар', 47.6892800, -0.1688300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57185, 'Bazouges-la-Pérouse', 'Bazouges-la-Perouse', 'Bazeleg-ar-Veineg,Bazogiae Petrosae,Bazouges,Bazouges-la-Perouse,Bazouges-la-Pérouse,Bazuzh la Peruz,Bazuzh-la-Peruz,ba zu re la pei lu si,Базуж ла Перуз,Базуж-ла-Перуз,巴祖热拉佩鲁斯', 48.4260600, -1.5743100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57186, 'Bazoges-en-Pareds', 'Bazoges-en-Pareds', 'Bazoges,Bazoges en Pareds,Bazoges-en-Pareds', 46.6570200, -0.9165400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57187, 'Bazoches-les-Gallerandes', 'Bazoches-les-Gallerandes', 'Bazoches,Bazoches-les-Gallerandes,Bazosh le Galarand,Bazosh-le-Gallerand,ba zuo xie lai jia lei lang dai,Базош ле Галаранд,Базош-ле-Галлеранд,巴佐谢莱加勒朗代', 48.1654000, 2.0431900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57188, 'Baziège', 'Baziege', 'Basieja,Basièja,Baz''ezh,Baziege,Baziège,Bazjezh,ba qi ye ge,Базьеж,Базьєж,Базјеж,巴齐耶格', 43.4545400, 1.6139900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57189, 'Bazet', 'Bazet', 'Bazet', 43.2914500, 0.0672800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57190, 'Bazemont', 'Bazemont', 'Bazemon,Bazemont,Bazmon,Баземон,Базмон', 48.9272600, 1.8665100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57191, 'Bazeilles', 'Bazeilles', 'Bazeilles,Bazej,ba ze ye,Базей,Базеј,巴泽耶', 49.6765000, 4.9775200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57192, 'Bazas', 'Bazas', 'Basatum,Baza,Bazas,Vasats,bazasu,База,Базас,バザス', 44.4320200, -0.2132700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57193, 'Bazancourt', 'Bazancourt', 'Bazancourt', 49.3656200, 4.1705100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57194, 'Bazainville', 'Bazainville', 'Bazainville,Bazenvil,Bazenvil'',Базенвил,Базенвиль,Базенвіль', 48.8043500, 1.6673200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57195, 'Bayonne', 'Bayonne', 'Baiona,Bajon,Bajona,Bajonna,Bajono,Bayona,Bayonne,Gorad Bajona,XBY,ba yue ne,ba yxn,baiyon''nu,bayon,baywn,Байон,Байонна,Бајон,Горад Баёна,באיון,بايون,بایون,บายอน,バイヨンヌ,巴约讷,바욘', 43.4833300, -1.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57196, 'Bayon', 'Bayon', 'Bayon', 48.4736600, 6.3158300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57197, 'Bayeux', 'Bayeux', 'Bagie,Baiocae,Baius,Baje,Bajjo,Bajo,Bayeux,ba yue,baiyu,baye''uksa,bayw,bayw  frans,bayw  fransh,Μπαγιέ,Байо,Байё,Баје,באייה,بايو,بایو، فرانس,بایو، فرانسه,বায়েউক্স,バイユー,巴约', 49.2773200, -0.7039000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57198, 'Bavilliers', 'Bavilliers', 'Bavije,Bavil''e,Bavilliers,ba wei li ye er,Бавије,Бавільє,巴维利耶尔', 47.6225500, 6.8311000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57199, 'Bavent', 'Bavent', 'Bavan,Bavent,ba wang,Баван,巴旺', 49.2299600, -0.1867500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57200, 'Bavay', 'Bavay', 'Bagacum,Bavai,Bave,ba wei,Баве,巴韦', 50.2982800, 3.7937200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57201, 'Bavans', 'Bavans', 'Bavans', 47.4852800, 6.7332400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57202, 'Bauvin', 'Bauvin', 'Beauvin', 50.5171400, 2.8940400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57203, 'Bauné', 'Baune', 'Baune,Bauné', 47.4995400, -0.3190600, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57204, 'Baume-les-Dames', 'Baume-les-Dames', 'Baume,Baume-sur-le-Doubs,Bom le Dam,Bom-le-Dam,bo mu lai da mei,Бом ле Дам,Бом-ле-Дам,博姆莱达梅', 47.3529500, 6.3611700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57205, 'Baulon', 'Baulon', 'Baulon,Beloen,Bolon,Bulon,bo long,Болон,Булон,博隆', 47.9859000, -1.9311400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57206, 'Baulne', 'Baulne', 'Baulne,Bol''n,Buln,bo er en,Больн,Булн,博尔恩', 48.4930300, 2.3623000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57207, 'Baule', 'Baule', 'Baule,Bol,Bol'',Бол,Боль', 47.8108400, 1.6725900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57208, 'Baugy', 'Baugy', 'Baugy', 47.0818100, 2.7284800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57209, 'Baugé-en-Anjou', 'Bauge-en-Anjou', 'Bauge,Baugé', 47.5444700, -0.1065300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57210, 'Baud', 'Baud', 'Baod,Baud', 47.8747400, -3.0176000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57211, 'Batz-sur-Mer', 'Batz-sur-Mer', 'Ba-sjur-Mer,Bac na Moru,Batz,Batz-sur-Mer,Bourc''h-Baz,Bourch-Baz,bin hai ba te,Ба-сюр-Мер,Бац на Мору,滨海巴特', 47.2775000, -2.4802700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57212, 'Battenheim', 'Battenheim', 'Batenkhajm,Battenajm,Battenheim,ba te nan,Батенхајм,Баттенайм,巴特南', 47.8200700, 7.3830300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57213, 'Batilly', 'Batilly', 'Batilly', 49.1737200, 5.9688900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57214, 'Bastia', 'Bastia', 'BIA,Bastia,Bastija,Bastja,Bastìa,Gorad Bastyja,Mantinum,ba si di ya,baseutia,bastiya,bastya,basutia,bstya,Μπαστιά,Бастия,Бастија,Бастія,Горад Бастыя,باستيا,باستیا,بستیا,बास्तिया,バスティア,巴斯蒂亚,바스티아', 42.7027800, 9.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57215, 'Bassussarry', 'Bassussarry', 'Basisari,Basjusarri,Bassjussarri,Bassussarri,Bassussarry,Bassussary,Basusarri,ba xu sa li,Басисари,Бассюссарри,Бассюссаррі,Басюсарри,巴叙萨里', 43.4427200, -1.5164700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57216, 'Bassillac', 'Bassillac', 'Basijak,Basilak,Bassijak,Bassilac,Bassilhac,Bassiliacum,Bassillac,ba xi la ke,basyak,Басийак,Басилак,Бассияк,Бассіяк,باسیاک,巴西拉克', 45.1930500, 0.8152800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57217, 'Bassens', 'Bassens', 'Bassens', 45.5850300, 5.9434900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57218, 'Bassens', 'Bassens', 'Bassens', 44.9022600, -0.5163100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57219, 'Indre', 'Indre', 'Antr,Basse-Indre,Ehndr,Indre,La Basse-Indre,Эндр', 47.2000000, -1.6666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57220, 'Basse-Ham', 'Basse-Ham', 'Basse-Ham', 49.3871300, 6.2422800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57221, 'Basse-Goulaine', 'Basse-Goulaine', 'Bas Gulen,Bass-Gulen,Basse-Goulaine,Goueled-Goulen,Sanctus Bricius de Golena,ba si gu lan,Бас Гулен,Басс-Гулен,巴斯古兰', 47.2116700, -1.4674800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57222, 'Bassan', 'Bassan', 'Bassan,Bessan', 43.4106000, 3.2539600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57223, 'Bas-en-Basset', 'Bas-en-Basset', 'Ba-an-Basse,Bas,Bas de Basses,Bas de Bassès,Bas-en-Basset,Baz an Base,ba sai de qu ba,bazan=base,Ба-ан-Бассе,Баз ан Басе,バザン＝バセ,巴塞地区巴', 45.3065400, 4.1089900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57224, 'Bartenheim', 'Bartenheim', 'Bartenheim,Bartenkhajm,Бартенхајм', 47.6335400, 7.4771200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57225, 'Bart', 'Bart', 'Bart', 47.4886100, 6.7709000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57226, 'Bar-sur-Seine', 'Bar-sur-Seine', 'Bar,Bar sir Sen,Bar-sur-Seine,Бар сир Сен', 48.1129500, 4.3765600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57227, 'Bar-sur-Aube', 'Bar-sur-Aube', 'Aebura,Bar,Bar sir Ob,Bar-sjur-Ob,Bar-sur-Aube,Barium ad Albam,ao bu he pan ba er,baru=shuru=obu,Бар сир Об,Бар-сюр-Об,バール＝シュル＝オーブ,奥布河畔巴尔', 48.2333300, 4.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57228, 'Barsac', 'Barsac', 'Barsac', 44.6074500, -0.3152700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57229, 'Barraux', 'Barraux', 'Baro,Barraux,Barro,ba er luo,Баро,Барро,巴尔罗', 45.4350300, 5.9789000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57230, 'Barr', 'Barr', 'Bar,Barr,Bàrr,ba er,bar,bar  ba-rn,baru,Бар,Барр,بار,بار، با-رن,バール,巴尔', 48.4075500, 7.4487300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57231, 'Barneville-Plage', 'Barneville-Plage', 'Barneville-Plage,Plage de Barneville', 49.3678600, -1.7651200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57232, 'Barlin', 'Barlin', 'Barlen,Barlin,ba lan,barlyn,Барлен,بارلين,巴兰', 50.4523800, 2.6195500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57233, 'Bar-le-Duc', 'Bar-le-Duc', 'Bar,Bar le Dik,Bar-le-Djuk,Bar-le-Duc,Bar-sur-Meurthe,Bar-sur-Ornain,Barrum,XBD,ba lei di ke,baleuleudwikeu,bar lw dwk,bar-lw-dwk,baru=ru=de~yukku,br-lh-dwq,Бар ле Дик,Бар-ле-Дюк,בר-לה-דוק,بار لو دوك,بار-لو-دوک,バル＝ル＝デュック,巴勒迪克,바르르뒤크', 48.7833300, 5.1666700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57234, 'Barjouville', 'Barjouville', 'Barjouville,Barzhuvij,Barzhuvil,Баржувил,Баржувиј', 48.4100200, 1.4763900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57235, 'Barjols', 'Barjols', 'Barjols,Barjous,Barjòus,Barzhol,Barzhol'',ba er ruo er,Баржол,Баржоль,巴尔若尔', 43.5578300, 6.0078300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57236, 'Barjac', 'Barjac', 'Barjac', 44.3074300, 4.3514600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57237, 'Bargemon', 'Bargemon', 'Barjamon,Barzhemon,ba er re meng,Баржемон,巴尔热蒙', 43.6189900, 6.5495700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57238, 'Barenton', 'Barenton', 'Baranton,Barenton,Barentonium,Larenton,ba lang tong,Барантон,巴朗通', 48.6002700, -0.8325800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57239, 'Barentin', 'Barentin', 'Baranten,Barentin,Барантен,Барентин', 49.5453300, 0.9551500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57240, 'Bardos', 'Bardos', 'Bardos,Bardoze', 43.4739200, -1.2034700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57241, 'Barcelonnette', 'Barcelonnette', 'BAE,Barceloneta,Barcelonnette,Barcilona de Provenca,Barcilona de Provença,Barselonet,Barselonnet,Barselonnett,ba er se luo nei te,barslwnt,baruseronetto,barusuronetto,Барселонет,Барселоннет,Барселоннетт,بارسلونت,バルスロネット,バルセロネット,巴尔瑟洛内特', 44.3869100, 6.6517900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57242, 'Barcelonne-du-Gers', 'Barcelonne-du-Gers', 'Barcalona,Barcalona de Gerc,Barcalona de Gers,Barcelonne,Barcelonne-du-Gers,Barselon di Zher,Barselon-dju-Zher,Barselonn-dju-Zher,Barçalona,Barçalona de Gers,Barçalona de Gèrç,ba er se long di re er,baruseron''nu=de~yu=jeru,Барселон ди Жер,Барселон-дю-Жер,Барселонн-дю-Жер,バルセロンヌ＝デュ＝ジェール,巴尔瑟隆迪热尔', 43.7036000, -0.2361900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57243, 'Barby', 'Barby', 'Babri,Barby,Бабри', 45.5708300, 5.9827300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57244, 'Barbizon', 'Barbizon', 'Barbison,Barbizon,barbyzwn,barubizon,brbyzwn,Барбизон,Барбізон,ברביזון,باربیزون,バルビゾン', 48.4434600, 2.6031300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57245, 'Barbezieux-Saint-Hilaire', 'Barbezieux-Saint-Hilaire', 'Barbesillum,Barbez''e-Sen-Iler,Barbez''jo-Sent-Iler,Barbezje Sent Iler,ba er bei qi e sheng yi lai er,Барбезьё-Сент-Илер,Барбезьє-Сен-Ілер,Барбезје Сент Илер,巴尔贝齐厄圣伊莱尔', 45.4726500, -0.1521800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57246, 'Barberaz', 'Barberaz', 'Barbera,Barberaz,Barberiacum,Барбера,Барбераз', 45.5500000, 5.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57247, 'Barbentane', 'Barbentane', 'Barbantan,Barbentana,Barbentane,Barbontan,ba bang ta na,Барбантан,Барбонтан,巴邦塔纳', 43.8996700, 4.7492100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57248, 'Barbechat', 'Barbechat', 'Barbechat,Barbesha,Barbsha,Bargazh,ba er bei sha,barubusha,Барбеша,Барбша,バルブシャ,巴尔贝沙', 47.2775000, -1.2852400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57249, 'Barbazan-Debat', 'Barbazan-Debat', 'Barbadan Devath,Barbazan Deba,Barbazan-Deba,Barbazan-Debat,ba er ba cang dai ba,Барбазан Деба,Барбазан-Деба,Барбазан-Дебат,巴尔巴藏代巴', 43.1958000, 0.1206000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57250, 'Barbâtre', 'Barbatre', 'Barbatre,Barbâtre', 46.9411600, -2.1775200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57251, 'Barbaste', 'Barbaste', 'Barbaste', 44.1690500, 0.2865900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57252, 'Baraqueville', 'Baraqueville', 'Barakevil'',Barakvil,Barakvil'',Baraque de Fraysse,La Barraca de Fraisse,ba la qu ai wei er,Бараквил,Бараквиль,Баракевіль,巴拉屈埃维尔', 44.2765500, 2.4318400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57253, 'Bapaume', 'Bapaume', 'Bapalma,Bapaume,Bapom,ba bo mu,babwm,Бапом,بابوم,巴波姆', 50.1037900, 2.8496600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57254, 'Banyuls de la Marenda', 'Banyuls de la Marenda', 'Banyuls,Banyuls de la Marenda,Banyuls-sur-Mer', 42.4837500, 3.1289700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57255, 'Banyuls-dels-Aspres', 'Banyuls-dels-Aspres', 'Banijul''-del''-Aspr,Banjil dels Apr,Banyuls,Banyuls dels Aspres,Banyuls-dels-Aspres,ba ni yu er dai er a si pu lei,Баниюль-дель-Аспр,Баніюль-дель-Аспр,Банјил делс Апр,巴尼于尔代尔阿斯普雷', 42.5656700, 2.8666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57256, 'Bantzenheim', 'Bantzenheim', 'Bancenkhajm,Bantzenheim,Банценхајм', 47.8256100, 7.5149800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57257, 'Bannalec', 'Bannalec', 'Banaleg,Banalek,Bannalec,Bannalek,ba na lai ke,Баналек,Банналек,巴纳莱克', 47.9322900, -3.6975900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57258, 'Banize', 'Banize', '', 45.8747900, 2.0616800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57259, 'Bandol', 'Bandol', 'Bandol,Bandol AOC,Bandol'',Bandou,Bandòu,XBZ,bang duo,Бандол,Бандоль,邦多', 43.1370900, 5.7316000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57260, 'Ban-de-Laveline', 'Ban-de-Laveline', 'Ban de Lavlen,Ban-de-Laveline,Ban-de-Lavlin,Laveline,bang de la fu li na,Бан де Лавлен,Бан-де-Лавлин,Бан-де-Лавлін,邦德拉弗利纳', 48.2449800, 7.0659300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57261, 'Balzac', 'Balzac', 'Bal''zak,Balzac,Balzak,Балзак,Бальзак', 45.7000000, 0.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57262, 'Balma', 'Balma', 'Bal''ma,Balma,Balmar,ba er ma,baruma,Балма,Бальма,バルマ,巴尔马', 43.6111100, 1.4994400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57263, 'Ballots', 'Ballots', 'Ballots', 47.8961700, -1.0475900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57264, 'Ballon', 'Ballon', 'Ballon', 48.1731700, 0.2381400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57265, 'Ballan-Miré', 'Ballan-Mire', 'Balan Mire,Ballan,Ballan-Mire,Ballan-Miré,ba lang mi lei,Балан Мире,Баллан-Міре,巴朗米雷', 47.3405700, 0.6146600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57266, 'Ballancourt-sur-Essonne', 'Ballancourt-sur-Essonne', 'Balankur sir Eson,Ballankur-sjur-Ehssonna,Ballankur-sjur-Essonn,ai song he pan ba lang ku er,Баланкур сир Есон,Балланкур-сюр-Ессонн,Балланкур-сюр-Эссонна,埃松河畔巴朗库尔', 48.5252500, 2.3860400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57267, 'Ballaison', 'Ballaison', 'Ballaison', 46.2994300, 6.3319100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57268, 'Ballainvilliers', 'Ballainvilliers', 'Balenvije,Ballainvilliers,Ballenvil''e,ba lan wei li ye er,Баленвије,Балленвилье,Балленвільє,巴兰维利耶尔', 48.6748100, 2.3005700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57269, 'Baldersheim', 'Baldersheim', 'Baldersheim', 47.8015800, 7.3802100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57270, 'Balbigny', 'Balbigny', 'Bal''bin''i,Balbigny,Balbini,ba er bi ni,Балбињи,Бальбіньї,巴尔比尼', 45.8192800, 4.1875600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57271, 'Balazé', 'Balaze', 'Balaze,Balazeium,Balazé,Belezeg,ba la ze,Балазе,巴拉泽', 48.1679700, -1.1915700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57272, 'Balaruc-le-Vieux', 'Balaruc-le-Vieux', 'Balarik le Vje,Balarjuk-le-V''e,Balarjuk-le-Ve,Balaruc,Balaruc Vielh,Balaruc Vièlh,Balaruc-le-Vieux,ba la lu ke lai fu yue,Баларик ле Вје,Баларюк-ле-Вье,Баларюк-ле-Вє,巴拉吕克莱弗约', 43.4614000, 3.6853000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57273, 'Balaruc-les-Bains', 'Balaruc-les-Bains', 'Balarik le Ben,Balarjuk-le-Ben,Balaruc-les-Bains,Los Banhs de Balaruc,ba la lu ke lai ban,balarwk ly bayn,Баларик ле Бен,Баларюк-ле-Бен,بالاروك لي باين,巴拉吕克莱班', 43.4417000, 3.6778000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57274, 'Balan', 'Balan', 'Balan,Балан', 49.6888100, 4.9647800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57275, 'Balan', 'Balan', 'Balan,Балан', 45.8343000, 5.0983400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57276, 'Balagny-sur-Thérain', 'Balagny-sur-Therain', 'Balagny,Balagny-sur-Therain,Balagny-sur-Thérain,Balan''i-sjur-Teren,Balani sir Teren,tai lan he pan ba er la ni,Баланьї-сюр-Терен,Балањи сир Терен,泰兰河畔巴尔拉尼', 49.2960500, 2.3364500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57277, 'Baixas', 'Baixas', 'Baixas,Baixàs,Beksa,Beksas,bai ke sa,Бекса,Бексас,拜克萨', 42.7496900, 2.8100200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57278, 'Baisieux', 'Baisieux', 'Baisieux,Baizieux', 50.6084100, 3.2525100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57279, 'Bais', 'Bais', 'Bais', 48.2528000, -0.3649300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57280, 'Bais', 'Bais', 'Baez,Bais', 48.0095900, -1.2898300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57281, 'Bainville-sur-Madon', 'Bainville-sur-Madon', 'Bainville,Bainville-sur-Madon', 48.5880700, 6.0958200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57282, 'Bains-sur-Oust', 'Bains-sur-Oust', 'Baen-Ballon,Bains,Bains-sur-Oust,Balneum,Ben sir Ust,Ben-sjur-Ust,wu si he pan ban,Бен сир Уст,Бен-сюр-Уст,乌斯河畔班', 47.7036200, -2.0704700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57283, 'Bains-les-Bains', 'Bains-les-Bains', 'Bains,Bains-les-Bains,Ben le Ben,Ben-le-Ben,ban lai ban,Бен ле Бен,Бен-ле-Бен,班莱班', 48.0011300, 6.2649200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57284, 'Bains', 'Bains', 'Bains', 45.0096300, 3.7746500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57285, 'Bain-de-Bretagne', 'Bain-de-Bretagne', 'Baen-Veur,Bain,Bain-de-Bretagne,Baionum,Ben de Bretan,Ben-de-Bretan'',ban de bu lei ta ni,Бен де Бретањ,Бен-де-Бретань,班德布雷塔尼', 47.8441800, -1.6848600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57286, 'Baincthun', 'Baincthun', 'Baincthun,Benkten,ban ke tan,baynsthwn,Бенктен,باينسثون,班克坦', 50.7099400, 1.6807500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57287, 'Bailly-Romainvilliers', 'Bailly-Romainvilliers', 'Bai-Romenvil''e,Bailly-Romainvilliers,Baji Romenvilije,Баи-Роменвилье,Баї-Роменвільє,Баји Роменвилије', 48.8472900, 2.8235200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57288, 'Bailly-Carrois', 'Bailly-Carrois', 'Bailly-Carrois', 48.5802900, 2.9904700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57289, 'Bailly', 'Bailly', 'Bailly', 48.8416800, 2.0767300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57290, 'Bailleval', 'Bailleval', 'Bailleval,Bajval,Bajval'',bai lei wa,Байваль,Бајвал,拜勒瓦', 49.3460500, 2.4569500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57291, 'Bailleul-sur-Thérain', 'Bailleul-sur-Therain', 'Bailleul,Bailleul-sur-Therain,Bailleul-sur-Thérain', 49.3852600, 2.2227900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57292, 'Bailleul-Sir-Berthoult', 'Bailleul-Sir-Berthoult', 'Bailleul,Bailleul-Sir-Berthoult,Bailleul-la-Liberte,Bailleul-la-Liberté', 50.3375200, 2.8512900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57293, 'Bailleul', 'Bailleul', 'Bailleul,Bajel,Belle,Бајел', 50.7359200, 2.7359400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57294, 'Baillet-en-France', 'Baillet-en-France', 'Bae-an-Frans,Baillet,Baillet-en-France,Baje-an-Frans,Bajet an Frans,fu lang si de qu bai lei,Бае-ан-Франс,Байе-ан-Франс,Бає-ан-Франс,Бајет ан Франс,弗朗斯地区拜勒', 49.0618700, 2.2988000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57295, 'Bailleau-l’Évêque', 'Bailleau-l''Eveque', 'Bailleau,Bailleau-l''Eveque,Bailleau-l''Evêque,Bailleau-l''Évêque,Bailleau-les-Bois,Bailleau-l’Évêque,Bajo l''Evek,Бајо л''Евек', 48.4896000, 1.3966500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57296, 'Bailleau-le-Pin', 'Bailleau-le-Pin', 'Bailleau,Bailleau-le-Pin,Bajo le Pen,Бајо ле Пен', 48.3669800, 1.3294800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57297, 'Baillargues', 'Baillargues', 'Baillargues,Bajarg,Balhargues,bai la er gai,Баярг,Бајарг,拜拉尔盖', 43.6626700, 4.0168100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57298, 'Baignes-Sainte-Radegonde', 'Baignes-Sainte-Radegonde', 'Baignes,Baignes-Sainte-Radegonde,Ben Sent Radgon,Ben''-Sent-Radegond,Ben''-Sent-Radgond,bai gai sheng la dai gong de,Бень-Сент-Радгонд,Бень-Сент-Радегонд,Бењ Сент Радгон,拜盖圣拉代贡德', 45.3833300, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57299, 'Baigneaux', 'Baigneaux', '', 48.1333300, 1.8166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57300, 'Baho', 'Baho', 'Baho,Bao,Baó,bo zhen,Бао,博镇', 42.7000000, 2.8220400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57301, 'Baguer-Pican', 'Baguer-Pican', 'Bagar-Bihan,Baguer-Pican', 48.5525300, -1.6983700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57302, 'Baguer-Morvan', 'Baguer-Morvan', 'Bagar-Morvan,Bage Morvan,Bage-Morvan,Baguer,Baguer-Morvan,ba gai mo er wang,Баге Морван,Баге-Морван,巴盖莫尔旺', 48.5253100, -1.7733200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57303, 'Bagnols-sur-Cèze', 'Bagnols-sur-Ceze', 'Bagnols,Bagnols-sur-Ceze,Bagnols-sur-Cèze,Ban''ol''-sjur-Sez,Banhous,Banhous de Ceser,Banhòus,Banhòus de Céser,Banol sir Sez,banyoru=shuru=sezu,sai ci he pan ba er ni ao er,Баньоль-сюр-Сез,Бањол сир Сез,バニョール＝シュル＝セーズ,塞兹河畔巴尔尼奥尔', 44.1599000, 4.6177600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57304, 'Bagnols-en-Forêt', 'Bagnols-en-Foret', 'Bagnols,Bagnols-en-Foret,Bagnols-en-Forêt,Ban''ol''-an-Fore,Banhous,Banhòus,Banol an Fore,fu lei de qu ba ni ao er,Баньоль-ан-Форе,Бањол ан Форе,福雷地区巴尼奥尔', 43.5366600, 6.7019000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57305, 'Bagnolet', 'Bagnolet', 'Bagnolet,Ban''ole,Banole,ba ni ao lei,banyolle,banyore,bnywlh,Баньоле,Бањоле,بنیوله,バニョレ,巴尼奥雷,바뇰레', 48.8666700, 2.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57306, 'Bagneux', 'Bagneux', 'Bagneux,Bano,Бањо', 48.7956500, 2.3079600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57307, 'Bagnères-de-Luchon', 'Bagneres-de-Luchon', 'Bagneres de Luchon,Bagneres-de-Luchon,Bagnères de Luchon,Bagnères-de-Luchon,Balneum Lixonense,Ban''er-de-Ljushon,Baner de Lison,Banheras de Luishon,Banhèras de Luishon,Banyeras de Luixon,Banyeras de Luixón,Luchon,ba nie er-de lu xiong,Баньер-де-Люшон,Баньєр-де-Люшон,Бањер де Лишон,巴涅尔-德吕雄', 42.7907900, 0.5931500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57308, 'Bagnères-de-Bigorre', 'Bagneres-de-Bigorre', 'Bagneres,Bagneres-de-Bigorre,Bagnères,Bagnères-de-Bigorre,Ban''er-de-Bigor,Ban''er-de-Bigorr,Baner de Bigor,Banheras,Banheras de Bigorra,Banhèras de Bigòrra,Banyeras de Bigorra,Vicus Aquensis,ba nie er-de bi ge er,banyeru=do=bigoru,Баньер-де-Бигор,Баньєр-де-Бігорр,Бањер де Бигор,バニェール＝ド＝ビゴール,巴涅尔-德比戈尔', 43.0666700, 0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57309, 'Bagneaux-sur-Loing', 'Bagneaux-sur-Loing', 'Bagneaux,Bagneaux-sur-Loing,Ban''o-sjur-Luen,Bano sir Loan,Баньо-сюр-Луен,Бањо сир Лоан', 48.2331000, 2.7067500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57310, 'Bages', 'Bages', 'Bages,Bages del Rossello,Bages del Rosselló', 42.6058800, 2.8935000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57311, 'Bâgé-la-Ville', 'Bage-la-Ville', 'Bage-la-Ville,Bagie-la-Vela,Baze la Vil,Bazhe la Vil,Bazhe-la-Vil'',Bâgiê-la-Vela,Bâgé-la-Ville,ba re la wei ye,baj-la-fyl,bajelabil,Баже ла Вил,Баже-ла-Виль,Баже-ла-Віль,Բաժե լա Վիլ,باج-لا-فيل,巴热拉维耶,바제라빌', 46.3165400, 4.9466600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57312, 'Bagard', 'Bagard', 'Bagard', 44.0712600, 4.0522500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57313, 'Baden', 'Baden', 'Baden', 47.6173400, -2.9198700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57314, 'Bacqueville-en-Caux', 'Bacqueville-en-Caux', 'Bacqueville,Bacqueville-en-Caux,Bakvil an Ko,Bakvil''-an-Ko,Баквил ан Ко,Баквиль-ан-Ко,Баквіль-ан-Ко', 49.7876100, 0.9992700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57315, 'Bachy', 'Bachy', 'Bachy', 50.5507900, 3.2597600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57316, 'Bachant', 'Bachant', 'Bachant', 50.2154000, 3.8683500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57317, 'Baccarat', 'Baccarat', 'Baccarat,Bakara,Bakkara,ba ka la,bakara,byakareta,Бакара,Баккара,ब्याकारेट,バカラ,巴卡拉', 48.4508600, 6.7393500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57318, 'Azille', 'Azille', 'Asilha,Azij,Azilhan lo Comtal,Azille,a qi er,Азий,Азиј,Азій,阿齐尔', 43.2769100, 2.6598100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57319, 'Azé', 'Aze', 'Aze,Azé', 47.8514100, 0.9982900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57320, 'Azé', 'Aze', 'Aze,Azé', 47.8222000, -0.6833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57321, 'Azay-sur-Cher', 'Azay-sur-Cher', 'Azay,Azay-sur-Cher,Aze sir Sher,Азе сир Шер', 47.3496600, 0.8456200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57322, 'Azay-le-Rideau', 'Azay-le-Rideau', 'Asiacus Ridelli,Azay,Azay-le-Rideau,Aze le Rido,Aze-le-Rido,Azeh-ljo-Rido,Castello di Azay-le-Rideau,Castillo de Azay-le-Rideau,Chateau d''Azay-le-Rideau,Château d''Azay-le-Rideau,Kasteel van Azay-le-Rideau,Schloss Azay-le-Rideau,Slottet i Azay-le-Rideau,a ze lai li duo,ajeleulido,aze=ru=rido cheng,Азе ле Ридо,Азе-ле-Ридо,Азэ-лё-Ридо,アゼ＝ル＝リドー城,阿泽莱里多,아제르리도', 47.2640500, 0.4713200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57323, 'Azay-le-Ferron', 'Azay-le-Ferron', 'Azay,Azay-le-Feron,Azay-le-Ferron,Aze le Feron,Aze-le-Ferron,a ze lai fu er long,Азе ле Ферон,Азе-ле-Феррон,阿泽莱弗尔龙', 46.8509700, 1.0708400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57324, 'Azay-le-Brûlé', 'Azay-le-Brule', 'Azay,Azay-le-Brule,Azay-le-Brûlé', 46.4001100, -0.2491400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57325, 'Aytré', 'Aytre', 'Aytre,Aytré,Ehtre,Ejtre,Etre,ai te lei,Ейтре,Етре,Этре,艾特雷', 46.1357000, -1.1145200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57326, 'Ay-sur-Moselle', 'Ay-sur-Moselle', 'Ay,Ay-sur-Moselle', 49.2413900, 6.2068100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57327, 'Ayse', 'Ayse', 'Ayse,Ayze', 46.0833300, 6.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57328, 'Ayron', 'Ayron', 'Ayron,Eron,ai long,Ерон,艾龙', 46.6602600, 0.0754500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57329, 'Ayguesvives', 'Ayguesvives', 'Aigas Vivas,Aigasvivas,Aiguesvives,Ayguesvives,Egviv,Ehgviv,ai gai si wei wei,Егвив,Егвів,Эгвив,艾盖斯维韦', 43.4363600, 1.5950500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57330, 'Ayguemorte-les-Graves', 'Ayguemorte-les-Graves', 'Aiguemorte-les Graves,Ayguemorte,Ayguemorte-les-Graves', 44.7098800, -0.4806000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57331, 'Aydoilles', 'Aydoilles', 'Aydoilles', 48.2102600, 6.5738900, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57332, 'Aydat', 'Aydat', 'Ajda,Aydat,Eda,Ајда,Еда', 45.6613600, 2.9739100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57333, 'Ay', 'Ay', 'Ay,Aÿ,E,Е', 49.0545700, 4.0034300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57334, 'Ax-les-Thermes', 'Ax-les-Thermes', 'Acs,Aks,Aks le Term,Aks-le-Term,Ax,Ax-les-Thermes,XLT,a ke si lai tai er mu,akusu=re=terumu,Акс,Акс ле Терм,Акс-ле-Терм,アクス＝レ＝テルム,阿克斯莱泰尔姆', 42.7196800, 1.8384500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57335, 'Avrillé', 'Avrille', 'Avrille,Avrillé', 47.5000000, -0.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57336, 'Avrillé', 'Avrille', 'Avrille,Avrillé', 46.4684000, -1.4804900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57337, 'Avrecourt', 'Avrecourt', 'Avrecourt', 47.9632900, 5.5369900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57338, 'Avrechy', 'Avrechy', 'Avrechy,Avreshi,Avrshi,a fu lei xi,Авреші,Аврши,阿夫雷希', 49.4479600, 2.4271000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57339, 'Avranches', 'Avranches', 'Avranches,Avrans,Avransh,Avrincae,a fu lang shen,avuranshu,Αβράνς,Авранш,アヴランシュ,阿夫朗什', 48.6833300, -1.3666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57340, 'Avord', 'Avord', 'Avor,Avord,Авор', 47.0351400, 2.6529500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57341, 'Avon', 'Avon', 'Avon', 48.4021900, 2.7202200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57342, 'Avoine', 'Avoine', 'Avoen,Avoine,Авоен', 47.2053300, 0.1825300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57343, 'Avize', 'Avize', 'Aviz,Avize,a wei ci,Αβίζ,Авиз,Авіз,阿维兹', 48.9735200, 4.0143800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57344, 'Aviron', 'Aviron', 'Aviron,Авирон', 49.0500000, 1.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57345, 'Avion', 'Avion', 'Avion', 50.4103800, 2.8305300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57346, 'Avilly-Saint-Léonard', 'Avilly-Saint-Leonard', 'Aviji Sen Leonar,Avilli-Sen-Leonar,Avilly-Saint-Leonard,Avilly-Saint-Léonard,a wei li sheng lai ao na er,Авији Сен Леонар,Авіллі-Сен-Леонар,阿维利圣莱奥纳尔', 49.1944900, 2.5414800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57347, 'Avignonet-Lauragais', 'Avignonet-Lauragais', 'Avignonet', 43.3666700, 1.8000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57348, 'Avignon', 'Avignon', 'AVN,Abinion,Avennio,Avignon,Avignone,Avignuni,Avin''jon,Avin''on,Avinhao,Avinhon,Avinhão,Avinjonas,Avinjono,Avinon,Avinon - Avignon,Avinona,Avinyo,Avinyon,Avinyó,Avinyón,Aviñón,Aviñón - Avignon,Aviņona,Awinion,Gorad Avin''jon,abinyong,afynywn,avhiyom,avinioni,avu~inyon,awynywn,xa wiyng,ya wei nong,Αβινιόν,Авиньон,Авињон,Авіньйон,Горад Авіньён,Ավինյոն,אביניון,آوینیون,أفينيون,اوینیون,ایوگناں,आव्हियों,อาวีญง,ཨ་ཝི་ཉོང་།,ავინიონი,アヴィニョン,亞維農,아비뇽', 43.9483400, 4.8089200, 'FR', '2017-04-03', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57349, 'Avèze', 'Aveze', 'Aveze,Avèze', 43.9711600, 3.6009700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57350, 'Avessac', 'Avessac', 'Avessac,Avezeg', 47.6532400, -1.9896100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57351, 'Avesnes-sur-Helpe', 'Avesnes-sur-Helpe', 'Aven-sjur-Ehl''p,Aven-sjur-El''p,Aven-syr-Elp,Avesnes,Avesnes-sur-Helpe,Avne sir Elp,ai er pu he pan a wei ne,avu~enu=shuru=erupu,Αβέν-συρ-Ελπ,Авен-сюр-Ельп,Авен-сюр-Эльп,Авне сир Елп,アヴェーヌ＝シュル＝エルプ,埃尔普河畔阿韦讷', 50.1166700, 3.9333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57352, 'Avesnes-le-Sec', 'Avesnes-le-Sec', 'Avesnes,Avesnes-le-Sec', 50.2510000, 3.3776800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57353, 'Avesnes-les-Aubert', 'Avesnes-les-Aubert', 'Aven-lez-Ober,Aven-lez-Omper,Avesnes,Avesnes-lez-Aubert,Avne lez Ober,a wei ne lai suo bei er,Αβέν-λεζ-Ωμπέρ,Авен-лез-Обер,Авне лез Обер,阿韦讷莱索贝尔', 50.2000000, 3.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57354, 'Avesnes-le-Comte', 'Avesnes-le-Comte', 'Avesne-l''Egalite,Avesne-l''Egalité,Avesnes-le-Comte', 50.2776700, 2.5295700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57355, 'Avesnelles', 'Avesnelles', 'Avenel,Avenel'',Avesnelles,a wei ne lei,Авенел,Авенель,阿韦讷勒', 50.1178200, 3.9467400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57356, 'Avermes', 'Avermes', 'Averm,Averme,Avermes,a wei er mei,Аверм,Аверме,阿韦尔梅', 46.5866600, 3.3061900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57357, 'Avensan', 'Avensan', 'Avensan', 45.0344400, -0.7556800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57358, 'Avelin', 'Avelin', 'Avelin', 50.5396800, 3.0822200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57359, 'Aveizieux', 'Aveizieux', 'Aveizieux', 45.5675000, 4.3713600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57360, 'Aveize', 'Aveize', 'Aveize', 45.6813900, 4.4764600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57361, 'Avanton', 'Avanton', 'Avanton,a wang tong,Авантон,阿旺通', 46.6636900, 0.3086200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57362, 'Avanne-Aveney', 'Avanne-Aveney', 'Avan Avne,Avann-Avene,a wang a wei nei,Аван Авне,Аванн-Авене,阿旺阿韦内', 47.2000000, 5.9666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57363, 'Avallon', 'Avallon', 'Aballo,Avallon,Avalon,Avalun,Gorad Avalon,a wa long,aballong,avu~aron,Αβαλόν,Аваллон,Авалон,Авалун,Горад Авалон,アヴァロン,阿瓦隆,아발롱', 47.4833300, 3.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57364, 'Availles-Limouzine', 'Availles-Limouzine', 'Availles,Availles-Limouzine,Availles-la-Montagne,Avaj Limuzen,Avaj-Limuzin,Avalha Lemosina,Avalhas Lemosinas,a wei lei li mu qi na,Авай-Лімузін,Авај Лимузен,阿韦勒利穆齐纳', 46.1210400, 0.6555800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57365, 'Auzouer-en-Touraine', 'Auzouer-en-Touraine', 'Auzouer,Auzouer-en-Touraine', 47.5423000, 0.9206700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57366, 'Auzielle', 'Auzielle', 'Auzielle', 43.5416500, 1.5657400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57367, 'Auzeville-Tolosane', 'Auzeville-Tolosane', 'Auzeville,Auzeville-Tolosane', 43.5277700, 1.4824000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57368, 'Auzebosc', 'Auzebosc', 'Auzebosc', 49.5956500, 0.7285000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57369, 'Auzat-la-Combelle', 'Auzat-la-Combelle', 'Auzat-sur-Allier', 45.4500000, 3.3166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57370, 'Auzances', 'Auzances', 'Auzances', 46.0284900, 2.5004200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57371, 'Auxy', 'Auxy', 'Auxy', 46.9494000, 4.4044000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57372, 'Auxonne', 'Auxonne', 'Auxona,Auxonne,Oson,Osonn,Ukson,aksn,ao ke song,Осон,Осонн,Уксон,اکسن,奥克松', 47.1925500, 5.3872600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57373, 'Auxon-Dessous', 'Auxon-Dessous', 'Auxon-Dessous,Okson Desu,Оксон Десу', 47.3000000, 5.9500000, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57374, 'Auxi-le-Château', 'Auxi-le-Chateau', 'Aussi-ch''Catiau,Aussi-ch’Catiau,Auxi,Auxi-le-Chateau,Auxi-le-Château,Auxy-la-Reunion,Auxy-la-Réunion,Oksi le Shato,Oksi-le-Shato,Osi-le-Shato,awksy ly shatw,ou ke xi bao,Окси ле Шато,Окси-ле-Шато,Оксі-ле-Шато,Оси-ле-Шато,أوكسي لي شاتو,欧克西堡', 50.2310100, 2.1159300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57375, 'Auxerre', 'Auxerre', 'AUF,Antissiodorum,Ausserra,Aussèrra,Auxerre,Gorad Aser,Okser,Oksera,Oksēra,Oser,Oseras,agzr,awksar,oseleu,oseru,ou sai er,Οσέρ,Горад Асер,Оксер,Осер,אוסר,أوكسار,اگزر,โอแซร์,オセール,欧塞尔,오세르', 47.8000000, 3.5666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57376, 'Auvillar', 'Auvillar', 'Autvilar,Auvillar,Ovija,Ovillar,ao wei la,Овија,Овіллар,奥维拉', 44.0686300, 0.9019200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57377, 'Auvers-sur-Oise', 'Auvers-sur-Oise', 'Auvers,Auvers-sur-Oise,Over sir Oaz,Over syur Owaz,Over-sjur-Uaz,awr swr awaz,ovu~eru=shuru=owazu,wa ci he pan ou wei,Овер сир Оаз,Овер-сюр-Уаз,Օվեր սյուր Ուազ,اور سور اواز,โอแวร์ซูว์รวซ,オーヴェル＝シュル＝オワーズ,瓦兹河畔欧韦', 49.0715800, 2.1697800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57378, 'Auvers-Saint-Georges', 'Auvers-Saint-Georges', 'Auvers,Auvers-Saint-Georges,Over Sen Zhorzh,Over-Sen-Zhorzh,ao wei er sheng re ao er ri,Овер Сен Жорж,Овер-Сен-Жорж,奥韦尔圣热奥尔日', 48.4927600, 2.2204500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57379, 'Auvers-le-Hamon', 'Auvers-le-Hamon', 'Auvers,Auvers-l''Union,Auvers-le-Hamon', 47.9024600, -0.3517000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57380, 'Autun', 'Autun', 'Augustodunum,Autun,Bibracte,Ciutat dAutun,Oten,Otjon,awtn,otan,ou tan,xo teing,Отен,Отён,אוטן,اوتن,โอเติง,オータン,歐坦', 46.9500000, 4.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57381, 'Autry-le-Châtel', 'Autry-le-Chatel', 'Autry,Autry-le-Chatel,Autry-le-Châtel,Otri le Shatel,Otri-le-Shatel'',ao te li lai sha tai,Отри ле Шател,Отрі-ле-Шатель,奥特里莱沙泰', 47.5988600, 2.6020000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57382, 'Autrans', 'Autrans', 'Autrans,Otran,Otron,ao te lang,Отран,Отрон,奥特朗', 45.1770300, 5.5442400, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57383, 'Authon-du-Perche', 'Authon-du-Perche', 'Aothoun,Authon,Authon-du-Perche,Cinq-Fonds,Oton di Persh,Oton-dju-Persh,Oton-nty-Pers,ao tong di pei er ke,Âothoun,Ωτόν-ντυ-Περς,Отон ди Перш,Отон-дю-Перш,奥通迪佩尔克', 48.1961500, 0.8918900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57384, 'Authie', 'Authie', 'Authie,Oti,ao di ye,Оти,Оті,奥蒂耶', 49.2061500, -0.4319100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57385, 'Auterive', 'Auterive', 'Auterive', 43.3510300, 1.4779700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57386, 'Aussonne', 'Aussonne', 'Aussonne', 43.6816200, 1.3188600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57387, 'Aussillon', 'Aussillon', 'Aussillon', 43.5029300, 2.3679100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57388, 'Auriol', 'Auriol', 'Auriol,Auriou,Auriòu,Or''ol'',Oriol,Orjol'',ao li ao er,Ориол,Орйоль,Орьоль,奥里奥尔', 43.3716100, 5.6341000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57389, 'Aurillac', 'Aurillac', 'AUR,Aureliacum,Aurillac,Orijak,Orilak,Orlhac,awryak,oliyakeu,oriyakku,ou li ya ke,xo ri yak,Орийак,Орияк,Оријак,Ориљак,Оріяк,אוריאק,اوریاک,โอรียัก,オーリヤック,欧里亚克,오리야크', 44.9166700, 2.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57390, 'Aurignac', 'Aurignac', 'Aurignac,Aurinhac,Orin''jak,Orinak,ao li ni ya ke,Ориньяк,Орињак,奥里尼亚克', 43.2169500, 0.8817600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57391, 'Auribeau-sur-Siagne', 'Auribeau-sur-Siagne', 'Auribeau,Auribeau-sur-Siagne,Auribeu,Auribeu de Sianha,Auribèu,Auribèu de Sianha,Oribo sir Sjan,Oribo-sjur-S''jan'',awrybyw swrsyajn,oribo=shuru=shianyu,xi ya ni he pan ao li bo,Орибо сир Сјањ,Орибо-сюр-Сьянь,أوريبيو سورسياجن,オリボー＝シュル＝シアーニュ,西亚尼河畔奥里博', 43.6044100, 6.9077900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57392, 'Auriac-sur-Vendinelle', 'Auriac-sur-Vendinelle', 'Auriac,Auriac-sur-Vendinelle', 43.5241600, 1.8264000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57393, 'Aureille', 'Aureille', 'Aureille,Aurelha,Orej,ao lei ye,Орей,Ореј,奥雷耶', 43.7082100, 4.9472800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57394, 'Aureilhan', 'Aureilhan', 'Aureilhan', 43.2433700, 0.0958100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57395, 'Aurec-sur-Loire', 'Aurec-sur-Loire', 'Aurec,Aurec de Leir,Aurec de Lèir,Aurec-sur-Loire,Orek na Loari,Orek-sjur-Luar,lu wa er he pan ao lei ke,Орек на Лоари,Орек-сюр-Луар,卢瓦尔河畔奥雷克', 45.3690700, 4.2049000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57396, 'Auray', 'Auray', 'Alraium,An Alre,Auray,Ore,XUY,ole,ore,Оре,オーレー,오레', 47.6702500, -2.9918300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57397, 'Aups', 'Aups', 'Aups,Op,Ops,Up,Zaups,ao pu,Оп,Опс,Уп,奥普', 43.6290400, 6.2255300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57398, 'Auneuil', 'Auneuil', 'Ainej,Auneuil,Onej,Onjoj,ao na yi,Аинеј,Оней,Онёй,奥纳伊', 49.3702600, 1.9971200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57399, 'Auneau', 'Auneau', 'Auneau,Ono,Onu,ou nuo,Оно,Ону,欧诺', 48.4636100, 1.7726300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57400, 'Aunay-sur-Odon', 'Aunay-sur-Odon', 'Aunay,Aunay-sur-Odon,One sir Odon,One-sjur-Odon,ao dong he pan ao nai,awny-swr-adwn,Оне сир Одон,Оне-сюр-Одон,اونی-سور-ادون,奥东河畔奥奈', 49.0201200, -0.6323800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57401, 'Aunay-sous-Auneau', 'Aunay-sous-Auneau', 'Aunay,Aunay-sous-Auneau', 48.4414000, 1.8109400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57402, 'Aumont-Aubrac', 'Aumont-Aubrac', 'Aumont,Aumont-Aubrac,Auroux,Autmont dAubrac,Omon Obrak,Omon-Obrak,ao meng ao bu la ke,Омон Обрак,Омон-Обрак,奥蒙奥布拉克', 44.7220500, 3.2846600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57403, 'Aumetz', 'Aumetz', 'Aumetz,Omec,Umetz,Омец,Уметз', 49.4129400, 5.9491600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57404, 'Aumale', 'Aumale', 'Aumale,Omal,Омал', 49.7698500, 1.7558700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57405, 'Ault', 'Ault', 'Ault,Bourg d''Ault,Bourg d’Ault', 50.1040400, 1.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57406, 'Aulnoye-Aymeries', 'Aulnoye-Aymeries', 'Alniaco-Ameria,Aulnoye,Aulnoye-Aymeries,Ol''nua-Emeri,Olnoa Emeri,Onua-Ehmeri,XOY,ou nu wa ai mu li,Олноа Емери,Ольнуа-Емери,Ольнуа-Емері,Онуа-Эмери,欧努瓦艾姆里', 50.2014100, 3.8384400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57407, 'Aulnoy-lez-Valenciennes', 'Aulnoy-lez-Valenciennes', 'Auno,Ol''nua-le-Valans''en,Ol''nua-le-Valans''enn,Olnoa le Valansijen,ou nu wa lai wa lang xie ne,Олноа ле Валансијен,Ольнуа-ле-Валансьен,Ольнуа-ле-Валансьенн,Ольнуа-ле-Валансьєнн,欧努瓦莱瓦朗谢讷', 50.3333300, 3.5333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57408, 'Aulnois-sous-Laon', 'Aulnois-sous-Laon', 'Aulnois,Aulnois-sous-Laon', 49.6142900, 3.6054700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57409, 'Aulnay-sur-Mauldre', 'Aulnay-sur-Mauldre', 'Aulnay,Aulnay-sur-Mauldre,Ol''ne-sjur-Mol''dr,Olne sir Moldr,Олне сир Молдр,Ольне-сюр-Мольдр', 48.9295000, 1.8411300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57410, 'Aulnay-sous-Bois', 'Aulnay-sous-Bois', 'Aulnay,Aulnay-sous-Bois,Ol''ne-su-Bua,Olne su Boa,One-su-Bua,ao nai cong lin,awlnh sw bwa,awlnyh sw bwa,olne su boa,olnesubua,orune=su=bowa,Олне су Боа,Ольне-су-Буа,Оне-су-Буа,أولنيه سو بوا,اولنه سو بوآ,オルネー＝スー＝ボワ,奧奈叢林,올네수부아', 48.9381400, 2.4940200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57411, 'Aulnay', 'Aulnay', 'Aulnay,Aulnay-de-Saintonge', 46.0208200, -0.3477800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57412, 'Aulnat', 'Aulnat', 'Aulnac,Aulnat,Ol''na,Olna,Олна,Ольна', 45.7960400, 3.1649800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57413, 'Augy', 'Augy', 'Augy', 47.7664000, 3.6105100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57414, 'Augny', 'Augny', 'Augny,On''i,Oni,ao ni,awgny,Оньи,Оньї,Оњи,آوگنی,奥尼', 49.0611100, 6.1183500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57415, 'Augan', 'Augan', 'Algam,Augan,Ogan,ao gang,Оган,奥冈', 47.9194300, -2.2790500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57416, 'Auffargis', 'Auffargis', 'Auffargis,Ofarzhi,Offarzhis,Офаржи,Оффаржис', 48.7004900, 1.8869600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57417, 'Audun-le-Tiche', 'Audun-le-Tiche', 'Audun,Audun-le-Tiche,Daeitsch-Oth,Däitsch-Oth,Oden le Tish,Oden-le-Tish,adn-lw-tysh,ao dan lai di ke,Оден ле Тиш,Оден-ле-Тиш,Оден-ле-Тіш,ادن-لو-تیش,奥丹莱蒂克', 49.4722800, 5.9569400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57418, 'Audun-le-Roman', 'Audun-le-Roman', 'Audun,Audun-le-Roman', 49.3687800, 5.8956400, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57419, 'Audruicq', 'Audruicq', 'Audruicq,Odrjuik,Odruig,Ouderwijk,awdrwysk,ou de lu ke,Одруиг,Одрюик,Одрюїк,أودرويسك,欧德吕克', 50.8779500, 2.0797500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57420, 'Audincourt', 'Audincourt', 'Audincourt,Odankur,Odenkur,ao dan ku er,odankuru,Оданкур,Оденкур,オダンクール,奥丹库尔', 47.4832700, 6.8534100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57421, 'Audierne', 'Audierne', 'Audierne,Gwaien,Od''ern,Odjerne,ao di ye er en,odierunu,Одьерн,Одьєрн,Одјерне,オディエルヌ,奥迪耶尔恩', 48.0164000, -4.5383800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57422, 'Audenge', 'Audenge', 'Audenge,Audenja,Odnzh,Odonzh,ao dang ge,Однж,Одонж,奥当格', 44.6868600, -1.0134500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57423, 'Auchy-les-Mines', 'Auchy-les-Mines', 'Auchy,Auchy-les-Mines', 50.5134900, 2.7828300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57424, 'Auchy-lès-Hesdin', 'Auchy-les-Hesdin', 'Auchy,Auchy-les-Hesdin,Auchy-lès-Hesdin,Oshi lez Eden,Oshi-le-Eden,awtshy lyh hysdyn,ou xi lai sai si dan,Оши лез Еден,Оши-ле-Еден,Оші-ле-Еден,أوتشي ليه هيسدين,欧希莱塞斯丹', 50.4011400, 2.1014500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57425, 'Auchel', 'Auchel', 'Auchel,Auchez,Oshel'',Ushel,awshyl,ou xie lei,Ошель,Ушел,أوشيل,欧谢勒', 50.5034500, 2.4734600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57426, 'Auch', 'Auch', 'Auch,Augusta Auscorum,Aush,Auski,Osh,Ush,ash  fransh,oshu,osyu,ou shen,Ош,Уш,אוש,اش، فرانسه,オーシュ,欧什,오슈', 43.6500000, 0.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57427, 'Aucamville', 'Aucamville', 'Aucamville', 43.6702000, 1.4280800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57428, 'Auby', 'Auby', 'Auby,Auby-lez-Douai,Obi,ou bi,Оби,Обі,欧比', 50.4145700, 3.0539600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57429, 'Aubusson', 'Aubusson', 'Aubusson,Lo Bucon,Lo Buçon,Obison,Обисон', 45.9500000, 2.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57430, 'Aubry-du-Hainaut', 'Aubry-du-Hainaut', 'Obri di Eno,Obri-dju-Eno,ou bu li di ai nuo,Обри ди Ено,Обри-дю-Ено,Обрі-дю-Ено,欧布里迪埃诺', 50.3666700, 3.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57431, 'Auboué', 'Auboue', 'Auboue,Auboué', 49.2130900, 5.9780000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57432, 'Aubord', 'Aubord', 'Aubord,Auborn,Aubòrn,Obor,ao bo er,Обор,奥博尔', 43.7582700, 4.3110500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57433, 'Aubin', 'Aubin', 'Aubin,Aubinh,Oben,ao ban,Обен,奥班', 44.5280900, 2.2443900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57434, 'Aubigny-sur-Nère', 'Aubigny-sur-Nere', 'Aubigny,Aubigny-Ville,Aubigny-sur-Nere,Aubigny-sur-Nère,Obin''i-sjur-Ner,Obini sir Ner,nei er he pan ao bi ni,obini=shuru=neru,Обиньи-сюр-Нер,Обињи сир Нер,Обіньї-сюр-Нер,オービニー＝シュル＝ネール,内尔河畔奥比尼', 47.4881900, 2.4389500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57435, 'Aubigny-au-Bac', 'Aubigny-au-Bac', 'Aubigny,Aubigny-au-Bac', 50.2637000, 3.1644800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57436, 'Aubigny-en-Artois', 'Aubigny-en-Artois', '', 50.3500000, 2.5833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57437, 'Aubigny', 'Aubigny', 'Aubigny', 46.5965300, -1.4536400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57438, 'Aubigné-Racan', 'Aubigne-Racan', 'Aubigne,Aubigne-Racan,Aubigné,Aubigné-Racan', 47.6909100, 0.2687000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57439, 'Aubignan', 'Aubignan', 'Albinianus,Aubignan,Aubinhan,Obin''jan,Obinon,ao bi ni ang,Обиньян,Обињон,Обіньян,奥比尼昂', 44.0994100, 5.0240900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57440, 'Aubiet', 'Aubiet', 'Aubiet', 43.6463100, 0.7844100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57441, 'Aubière', 'Aubiere', 'Aubeira,Aubiera,Aubiere,Aubièra,Aubière,Aubèira,Ober,Obijer,ao bi ai,Обијер,Обєр,奥比埃', 45.7515700, 3.1125100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57442, 'Aubie-et-Espessas', 'Aubie-et-Espessas', 'Aubia e Espessas,Aubia e Espessàs,Aubie,Aubie-et-Espessas,Aubía e Espessàs,Obi et Epesa,Obi-e-Espessas,ao bi ye he ai si pei sa,Оби ет Епеса,Оби-е-Еспессас,Обі-е-Еспессас,奥比耶和埃斯佩萨', 45.0186900, -0.4029700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57443, 'Aubevoye', 'Aubevoye', 'Aubevoie,Aubevoye,Obevej,Obevua,Obvua,ao bo wa ai,Обвуа,Обевеј,Обевуа,奥伯瓦埃', 49.1709700, 1.3353700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57444, 'Aube-sur-Rîle', 'Aube-sur-Rile', 'Aube,Aube-sur-Rile,Aube-sur-Rîle', 48.7392000, 0.5516100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57445, 'Aubervilliers', 'Aubervilliers', 'Aubervilles,Aubervilliers,Obervil''e,Obervilije,ao bei wei ai,awbarfylyyh,awbrwyh,awbrwylyh,obeleubillie,oberuvu~irie,Обервилије,Обервилье,Обервільє,أوبارفيلييه,اوبرویلیه,اوبرویه,オーベルヴィリエ,奥贝维埃,오베르빌리에', 48.9166700, 2.3833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57446, 'Aubers', 'Aubers', 'Aubers,Obe,Ube,ou bei,Обе,Убе,欧贝', 50.5954300, 2.8266600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57447, 'Auberives-sur-Varèze', 'Auberives-sur-Vareze', 'Auberives', 45.4333300, 4.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57448, 'Aubergenville', 'Aubergenville', 'Aubergenville,Oberzhanvil'',Uberzhenvij,oberujan''vu~iru,Обержанвиль,Обержанвіль,Уберженвиј,オーベルジャンヴィル', 48.9599600, 1.8546700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57449, 'Auberchicourt', 'Auberchicourt', 'Auberchicourt,Obershikur,Ubershikur,ou bei er xi ku er,Обершикур,Убершикур,欧贝尔希库尔', 50.3333300, 3.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57450, 'Aubenas', 'Aubenas', 'Aubenas,Aubenàs,OBS,Obena,ao bo na,awbnas,obuna,Обена,اوبناس,オーブナ,奥伯纳', 44.6200600, 4.3899400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57451, 'Aubais', 'Aubais', 'Aubais,Obe,Ube,ao bai,Обе,Убе,奥拜', 43.7540200, 4.1456700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57452, 'Aubagne', 'Aubagne', 'Albania,Aubagne,Aubagne en Provence,Aubanha,JAH,Oban,Oban'',Obane,Obanė,Ubane,awbny,obanyu,ou ba nie,Обан,Обань,Обањ,Убање,اوبنی,オーバーニュ,欧巴涅,오바뉴', 43.2927600, 5.5706700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57453, 'Atur', 'Atur', 'Atir,Atur,Атир', 45.1408600, 0.7470100, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57454, 'Attigny', 'Attigny', 'Atini,Atinji,Attigny,Attin''i,Vieux-Pont,a di ni,Атињи,Аттиньи,Аттіньї,阿蒂尼', 49.4784600, 4.5780300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57455, 'Attignat', 'Attignat', 'Atina,Attignat,Атиња', 46.2881500, 5.1612600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57456, 'Attichy', 'Attichy', 'Atishi,Attichy,Attishi,a di xi,Атиши,Аттиши,Аттіші,阿蒂希', 49.4112100, 3.0494900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57457, 'Attiches', 'Attiches', 'Attiches', 50.5222000, 3.0622200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57458, 'Attainville', 'Attainville', 'Atenvil,Attainville,Attenvil'',a tan wei er,Атенвил,Аттенвиль,Аттенвіль,阿坦维尔', 49.0577900, 2.3449700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57459, 'Athis-Mons', 'Athis-Mons', 'Athis,Athis-Mons,Ati Mon,Atis-Mons,a di si meng si,atiseumongseu,atisu=monsu,aty mwn,Ати Мон,Атис-Монс,Атіс-Монс,اتی مون,アティス＝モンス,阿蒂斯蒙斯,아티스몽스', 48.7052200, 2.3914700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57460, 'Athies-sous-Laon', 'Athies-sous-Laon', 'Athies,Athies-sous-Laon', 49.5736900, 3.6841700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57461, 'Athée-sur-Cher', 'Athee-sur-Cher', 'Athee,Athee-sur-Cher,Athée,Athée-sur-Cher', 47.3202300, 0.9165900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57462, 'Astaffort', 'Astaffort', 'Astaffort', 44.0642600, 0.6514100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57463, 'Asson', 'Asson', 'Ason,Asson,Асон,Ассон', 43.1500000, -0.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57464, 'Assérac', 'Asserac', 'Aserak,Asserac,Asserak,Assérac,Azereg,a sai la ke,Асерак,Ассерак,阿塞拉克', 47.4288100, -2.3891600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57465, 'Assat', 'Assat', 'Asa,Asat,Assat,a sa,Аса,Асат,Ассат,阿萨', 43.2500000, -0.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57466, 'Assas', 'Assas', 'Asa,Assa,Assas,Assats,Assàs,a sa,Аса,Асса,阿萨', 43.7027800, 3.9000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57467, 'Aspremont', 'Aspremont', 'Aprmon,Aspremon,Aspremont,Апрмон,Аспремон', 43.7853900, 7.2445800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57468, 'Aspiran', 'Aspiran', '', 43.5658600, 3.4503100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57469, 'Aspet', 'Aspet', 'Aspet', 43.0145700, 0.8029400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57470, 'Aspach-le-Haut', 'Aspach-le-Haut', 'Aspach,Aspach-le-Haut,Aspak-le-O,Aspash lO,Oberaspach,a si pa ke lai ao,Аспак-ле-О,Аспаш лО,阿斯帕克莱奥', 47.7765300, 7.1314500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57471, 'Aspach-le-Bas', 'Aspach-le-Bas', 'Aspach,Aspach-le-Bas', 47.7611500, 7.1509000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57472, 'Aspach', 'Aspach', 'Aspach', 47.6417300, 7.2332400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57473, 'Asnières-sur-Oise', 'Asnieres-sur-Oise', 'An''er-sjur-Uaz,Anijer sir Oaz,Asnieres,Asnieres-sur-Oise,Asnières,Asnières-sur-Oise,wa ci he pan a nie er,Анијер сир Оаз,Аньер-сюр-Уаз,Аньєр-сюр-Уаз,瓦兹河畔阿涅尔', 49.1336900, 2.3555100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57474, 'Asnières-sur-Nouère', 'Asnieres-sur-Nouere', 'An''er-sjur-Nuehr,An''er-sjur-Nuer,Anijer sir Nuer,Asnieres,Asnieres-sur-Nouere,Asnières,Asnières-sur-Nouère,nu ai er he pan a si ni ai,Анијер сир Нуер,Аньер-сюр-Нуэр,Аньєр-сюр-Нуер,努埃尔河畔阿斯尼埃', 45.7166700, 0.0500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57475, 'Asnières-sur-Seine', 'Asnieres-sur-Seine', 'An''er-sjur-Sen,Anier sjur Sen,Anijer na Seni,Asinariae,Asnieres,Asnieres sur Seine,Asnières,Asnières sur Seine,anieleuswileusen,anieru=shuru=senu,anyar swr syn,anyyr-swr-sn,aznyr swr sn,sai na he pan a nie lei,Аниер сюр Сен,Анијер на Сени,Аньер-сюр-Сен,Аньєр-сюр-Сен,أنيار سور سين,ازنیر سور سن,انییر-سور-سن,アニエール＝シュル＝セーヌ,塞纳河畔阿涅勒,아니에르쉬르센', 48.9166700, 2.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57476, 'Aschères-le-Marché', 'Ascheres-le-Marche', 'Ascheres,Ascheres-le-Marche,Aschères,Aschères-le-Marché,Asher le Marshe,Assher-le-Marshe,a si xie lei lai ma er xie,Асшер-ле-Марше,Ашер ле Марше,阿斯谢雷莱马尔谢', 48.1100800, 2.0072500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57477, 'Ascain', 'Ascain', 'Ascain,Asken,Azkaine,a si kan,Аскен,阿斯坎', 43.3452100, -1.6207300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57478, 'Arzon', 'Arzon', 'Arzhon-Rewiz,Arzo,Arzon,a er zong,aruzon,Арзон,アルゾン,阿尔宗', 47.5485200, -2.8898900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57479, 'Arzens', 'Arzens', 'Arzan,Arzens,a er cang,Арзан,阿尔藏', 43.1983800, 2.2095400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57480, 'Arzano', 'Arzano', 'An Arzhanaou,Arzano', 47.9013600, -3.4403200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57481, 'Arveyres', 'Arveyres', 'Arveyres', 44.8833300, -0.2833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57482, 'Arvert', 'Arvert', 'Arve,Arver,Arvert,a er wei er,Арве,Арвер,Արվե,阿尔韦尔', 45.7448600, -1.1257300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57483, 'Arudy', 'Arudy', 'Aridi,Arjudi,Arudi,Arudy,a lu di,Ариди,Арюди,Арюді,阿吕迪', 43.1166700, -0.4333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57484, 'Art-sur-Meurthe', 'Art-sur-Meurthe', 'Art,Art-sur-Meurthe', 48.6558900, 6.2661200, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57485, 'Artres', 'Artres', 'Artres', 50.2948200, 3.5401300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57486, 'Artix', 'Artix', 'Arti,Artics,Artiks,Artix,a er di,Арти,Артикс,Артікс,阿尔蒂', 43.4000000, -0.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57487, 'Artigues-près-Bordeaux', 'Artigues-pres-Bordeaux', 'Artig pre Bordo,Artig-pre-Bordo,Artigas de Bordeu,Artigas de Bordèu,Artigues,Artigues-pres-Bordeaux,Artigues-près-Bordeaux,Artisii,a er di gai pu lei bo er duo,Артиг пре Бордо,Артиг-пре-Бордо,Артіг-пре-Бордо,阿尔蒂盖普雷博尔多', 44.8500000, -0.5166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57488, 'Artiguelouve', 'Artiguelouve', 'Artigaloba,Artigluv,Artiguelouve,a er di gai lu fu,Артиглув,Артіглув,阿尔蒂盖卢夫', 43.3166700, -0.4666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57489, 'Arthon-en-Retz', 'Arthon-en-Retz', 'Arthon,Arthon-en-Retz,Arton an Rec,Arton-an-Re,Arzhon-Raez,aruton=an=re,lei te de qu a er tong,Артон ан Рец,Артон-ан-Ре,アルトン＝アン＝レ,雷特地区阿尔通', 47.1158600, -1.9426000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57490, 'Arthon', 'Arthon', 'Arthon,Arton,a er tong,Артон,阿尔通', 46.6936100, 1.6985700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57491, 'Arthez-de-Béarn', 'Arthez-de-Bearn', 'Artes,Artes de Biarn,Artes-de-Bearn,Artez de Bearn,Artez-de-Bearn,Arthez,Arthez-de-Bearn,Arthez-de-Béarn,Artés,Artés de Biarn,a er tai de bei a er en,Артез де Беарн,Артез-де-Беарн,Артес-де-Беарн,阿尔泰德贝阿尔恩', 43.4666700, -0.6000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57492, 'Arthès', 'Arthes', 'Arthes,Arthès', 43.9574500, 2.2113000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57493, 'Arthaz-Pont-Notre-Dame', 'Arthaz-Pont-Notre-Dame', 'Arta-Pon-Notr-Dam,Artaz Pon Notre Dam,Arthaz,Арта-Пон-Нотр-Дам,Артаз Пон Нотре Дам', 46.1594100, 6.2659800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57494, 'Artenay', 'Artenay', 'Artenay,Artene,Artne,a er te nai,Артене,Артне,阿尔特奈', 48.0824600, 1.8809800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57495, 'Artemare', 'Artemare', 'Artemar,Artemare,Artmar,a er te ma er,aleuteumaleu,artmar,artymyr,Артемар,Артмар,Արտեմար,آرتمار,أرتيمير,阿尔特马尔,아르트마르', 45.8744100, 5.6936600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57496, 'Artas', 'Artas', 'Artas', 45.5355500, 5.1650500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57497, 'Artannes-sur-Indre', 'Artannes-sur-Indre', 'Artan sir Endr,Artann-sjur-Endr,Artannes,Artannes-sur-Indre,an de er he pan a er ta nei,Артан сир Ендр,Артанн-сюр-Ендр,安德尔河畔阿尔塔内', 47.2745100, 0.6003600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57498, 'Ars-sur-Moselle', 'Ars-sur-Moselle', 'Ar sir Mozel,Ars,Ars-sjur-Mozel'',Ars-sur-Moselle,ar-swr-mwzl,mo sai er he pan a er,Ар сир Мозел,Арс-сюр-Мозель,آر-سور-موزل,莫塞尔河畔阿尔', 49.0783100, 6.0727500, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57499, 'Ars-sur-Formans', 'Ars-sur-Formans', 'Ar sir Forman,Ar syur Forman,Ar-sjur-Forman,Ars,Ars-sjur-Forman,Ars-sur-Formans,Arsa,aleuswileupoleumang,ar-swr-frman,ars-swr-fwrmans,fu er mang he pan a er si,Ар сир Форман,Ар-сюр-Форман,Арс-сюр-Форман,Ար սյուր Ֆորման,آر-سور-فرمان,أرس-سور-فورمانس,福尔芒河畔阿尔斯,아르쉬르포르망', 45.9941800, 4.8231300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57500, 'Ars-en-Ré', 'Ars-en-Re', 'Ars,Ars an Re,Ars-an-Re,Ars-en-Re,Ars-en-Ré,Il''de Re,Ile-Republicaine,Ile-Républicaine,La Concorde,lei de qu a er,Арс ан Ре,Арс-ан-Ре,Иль де Ре,Արս ան Ռե,雷地区阿尔', 46.2055500, -1.5272000, 'FR', '2016-12-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57501, 'Arsac', 'Arsac', 'Arsac', 44.9968800, -0.6897600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57502, 'Arrou', 'Arrou', 'Arrou,Arru,Aru,a er lu,Арру,Ару,阿尔鲁', 48.0976800, 1.1285100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57503, 'Arras', 'Arras', 'Aras,Arasas,Aro,Arras,Arrasa,Arràs,Arrás,Atrecht,Gorad Aras,Nemetacum,QRV,a la si,alaseu,ar,aras,arasu,xa ras,Арас,Аррас,Горад Арас,אראס,آراس,أراس,ار,அராஸ்,อารัส,アラス,阿拉斯,아라스', 50.2930100, 2.7818600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57504, 'Arradon', 'Arradon', 'Aradon,Arradon,a er la dong,Арадон,Аррадон,阿尔拉东', 47.6270900, -2.8215000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57505, 'Arques-la-Bataille', 'Arques-la-Bataille', 'Ark la Bataj,Ark-la-Bataj,Arques,Arques-la-Bataille,Арк ла Батај,Арк-ла-Батай', 49.8812200, 1.1287500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57506, 'Arques', 'Arques', 'Arques', 50.7337500, 2.3023700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57507, 'Arpajon-sur-Cère', 'Arpajon-sur-Cere', 'Arpaionum super Ceram,Arpajon,Arpajon de Cera,Arpajon-sur-Cere,Arpajon-sur-Cère,Arpazhon sir Ser,Arpazhon-sjur-Ser,Lo Pajon dOrlhac,arupajon=shuru=seru,sai er he pan a er pa rong,Арпажон сир Сер,Арпажон-сюр-Сер,アルパジョン＝シュル＝セール,塞尔河畔阿尔帕容', 44.9026200, 2.4580900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57508, 'Arpajon', 'Arpajon', 'Arpaionum,Arpajon,Arpazhon,a er pa rong,Арпажон,阿尔帕容', 48.5887500, 2.2467200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57509, 'Aron', 'Aron', 'Aron', 48.2980000, -0.5598000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57510, 'Arnouville', 'Arnouville', 'Arnouville,Arnouville-les-Gonesse,Arnouville-lès-Gonesse,Arnuvil,Arnuvil'',a nu wei er,Арнувил,Арнувиль,Арнувіль,阿努维尔', 48.9833300, 2.4166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57511, 'Arnières-sur-Iton', 'Arnieres-sur-Iton', 'Armeres,Armères,Arnieres,Arnieres-sur-Iton,Arnières,Arnières-sur-Iton', 48.9967800, 1.1038400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57512, 'Arnèke', 'Arneke', 'Arneke,Arnèke', 50.8321900, 2.4094300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57513, 'Arnay-le-Duc', 'Arnay-le-Duc', 'Arnay,Arnay-le-Duc,Arnay-sur-Arroux,Arne le Dik,Arne-le-Djuk,Arnetium,a er nai lai di ke,arny-l-dwk,Арне ле Дик,Арне-ле-Дюк,آرنی-ل-دوک,آرنے-ل-دوک,阿尔奈莱迪克', 47.1320200, 4.4859500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57514, 'Arnas', 'Arnas', 'Arna,Arnas,Арна', 46.0239000, 4.7063800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57515, 'Arnage', 'Arnage', 'Arnage', 47.9261600, 0.1878200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57516, 'Arnac-Pompadour', 'Arnac-Pompadour', 'Arnac,Arnac e Pompador,Arnac-Pompadour,Arnac-la-Prairie,Arnak Pompadur,Arnak-Pompadur,a er na ke peng pa du,arunakku=ponpado~uru,Арнак Помпадур,Арнак-Помпадур,アルナック＝ポンパドゥール,阿尔纳克蓬帕杜', 45.4097500, 1.3699300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57517, 'Arnac-la-Poste', 'Arnac-la-Poste', 'Arnac,Arnac la Poste,Arnac la Pòste,Arnac-la-Poste,Arnak la Post,Arnak-la-Post,a er na ke la bo si te,xar nak-la-pxst,Арнак ла Пост,Арнак-ла-Пост,อาร์นัก-ลา-ป็อสต์,阿尔纳克拉波斯特', 46.2659700, 1.3737500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57518, 'Armoy', 'Armoy', 'Armoa,Armoj,Armoy,Армоа,Армој', 46.3489300, 6.5200100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57519, 'Armissan', 'Armissan', 'Armican,Armisan,Armissan,Armiçan,a er mi sang,Армисан,Армиссан,Арміссан,阿尔米桑', 43.1877800, 3.0966000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57520, 'Armentières-en-Brie', 'Armentieres-en-Brie', 'Armentieres,Armentieres-en-Brie,Armentières,Armentières-en-Brie', 48.9777500, 3.0207300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57521, 'Armentières', 'Armentieres', 'Armant''er,Armantier,Armantjer,Armantjeras,Armentieres,Armentiers,Armentières,Armintire,Armintîre,Armontijer,Ermentiers,a er mang di ye er,aleumangtieleu,armantyr,arumantieru,Αρμαντιέρ,Армантьер,Армантьєр,Армантјер,Армонтијер,ارمانتیر,アルマンティエール,阿尔芒蒂耶尔,아르망티에르', 50.6856800, 2.8821400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57522, 'Armenonville-les-Gâtineaux', 'Armenonville-les-Gatineaux', 'Armenonville,Armenonville-les-Gatineaux,Armenonville-les-Gâtineaux', 48.5436500, 1.6475000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57523, 'Armbouts-Cappel', 'Armbouts-Cappel', 'Armbouts-Cappel', 50.9768200, 2.3535200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57524, 'Arleux', 'Arleux', 'Arle,Arleux,Arleux-du-Nord,Arljo,Арле,Арлё', 50.2803700, 3.1044800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57525, 'Arles', 'Arles', 'Arl'',Arles,Arles-sur-Tech,Арль', 42.4565400, 2.6345700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57526, 'Arles', 'Arles', 'Arelate,Arl,Arl'',Arla,Arle,Arles,Arles-Trinquetaille,Arles-sur-Rhone,Arles-sur-Rhône,Arlet,Arlis,Arlés,Gorad Arl'',a er lei,aleul,arl,arli,aruru,Αρλ,Арл,Арль,Горад Арль,Առլ,ארל,آرل,ارل,არლი,アルル,阿爾勒,아를', 43.6768100, 4.6303100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57527, 'Arlanc', 'Arlanc', 'Arlan,Arlanc,Arlank,Arlantium,Arlon,a er lang,aruran,Арлан,Арланк,Арлон,アルラン,阿尔朗', 45.4138900, 3.7252800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57528, 'Arinthod', 'Arinthod', 'Arinthod', 46.3933900, 5.5661600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57529, 'Argent-sur-Sauldre', 'Argent-sur-Sauldre', 'Argent,Argent-sur-Sauldre,Arzhan sir Soldr,Arzhan-sjur-Sodr,Arzhan-sjur-Sol''dr,suo er de er he pan a er rang,Аржан сир Солдр,Аржан-сюр-Содр,Аржан-сюр-Сольдр,索尔德尔河畔阿尔让', 47.5584700, 2.4441000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57530, 'Argentré-du-Plessis', 'Argentre-du-Plessis', 'Argantred-ar-Genkiz,Argantreg-ar-Genkiz,Argentre,Argentre-du-Plessis,Argentreium Plessiaci,Argentré,Argentré-du-Plessis,Arzhantre di Plesi,Arzhantre-dju-Plessi,a rang te lei-di pu lai xi,Аржантре ди Плеси,Аржантре-дю-Плесси,Аржантре-дю-Плессі,阿让特雷-迪普莱西', 48.0569700, -1.1460100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57531, 'Argentré', 'Argentre', 'Argentre,Argentré', 48.0836200, -0.6415000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57532, 'Argenton-sur-Creuse', 'Argenton-sur-Creuse', 'Argentomagus,Argenton,Argenton-sur-Creuse,Arzhanton sir Krez,Arzhanton-sjur-Krez,Arzhanton-sjur-Krjoz,ke lei si he pan a er rang tong,Аржантон сир Крез,Аржантон-сюр-Крез,Аржантон-сюр-Крёз,አርዠንቶን-ሱር-ክሮይዝ,克勒斯河畔阿尔让通', 46.5899700, 1.5198100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57533, 'Argenton-les-Vallées', 'Argenton-les-Vallees', 'Argenton,Argenton-Chateau,Argenton-Château,Argenton-le-Peuple,Argentonium,Arzhanton-le-Valle,Аржантон-ле-Валле', 46.9833300, -0.4500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57534, 'Argenteuil', 'Argenteuil', 'Argenteuil,Arzhantej,Arzhentoj,arujanto~uiyu,Аржантей,Аржантеј,Аржентој,アルジャントゥイユ', 48.9500000, 2.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57535, 'Argentat', 'Argentat', 'Argentat,Arzhanta,Arzhenta,a er rang ta,arujanta,Аржанта,Аржента,アルジャンタ,阿尔让塔', 45.0963400, 1.9398700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57536, 'Argentan', 'Argentan', 'Argentan,Arzantan,Arzantana,Arzhantan,Aržantāna,a er rang tang,arujantan,Αρζαντάν,Аржантан,アルジャンタン,阿尔让唐', 48.7500000, -0.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57537, 'Argences', 'Argences', 'Argences,Arzhans,a er rang sai,Аржанс,阿尔让塞', 49.1263500, -0.1664400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57538, 'Argeliers', 'Argeliers', 'Argeliers,Argelièrs,Arzhel''e,Arzhelije,a er re li ye er,Аржелије,Аржелье,Аржельє,阿尔热利耶尔', 43.3121700, 2.9104600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57539, 'Argelers', 'Argelers', 'Argelers,Argeles,Argeles-sur-Mer,Argelès,Argelès-sur-Mer', 42.5471400, 3.0225300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57540, 'Argelès-Gazost', 'Argeles-Gazost', 'Argelers,Argelers de Gasost,Argeles-Gazost,Argelèrs,Argelèrs de Gasòst,Argelès-Gazost,Argilers,Argilèrs,Arzhele Gazo,Arzhele-Gazost,Arzheles-Gazost,a er re lai jia zuo si,arujuresu=gazosuto,Аржеле Газо,Аржеле-Газост,Аржелес-Газост,アルジュレス＝ガゾスト,阿尔热莱加佐斯', 43.0166700, -0.1000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57541, 'Argancy', 'Argancy', 'Argancy,Argansi,a er gang xi,Арганси,Аргансі,阿尔冈西', 49.1967000, 6.2013800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57542, 'Arette', 'Arette', 'Aret,Areta,Arett,Arette,Ereta,a lei te,Арет,Аретт,阿雷特', 43.1000000, -0.7166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57543, 'Arès', 'Ares', 'Are,Ares,Arès,Arés,Аре,Арес', 44.7666700, -1.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57544, 'Arenthon', 'Arenthon', 'Arenthon', 46.1046600, 6.3314900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57545, 'Ardres', 'Ardres', 'Aarden,Arde,Ardr,Ardres,a de er,ardrys,Ардр,أردريس,阿德尔', 50.8578600, 1.9816800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57546, 'Ardin', 'Ardin', 'Ardin', 46.4751200, -0.5541600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57547, 'Ardentes', 'Ardentes', 'Ardant,Ardentes,Ardentes-les-Bois,Ardon,a er dang tai,Ардант,Ардон,阿尔当泰', 46.7419100, 1.8342800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57548, 'Arcueil', 'Arcueil', 'Arcueil,Arkej,aleukei,arukuiyu,ya jie,Аркей,Аркеј,アルクイユ,亚捷,아르케이', 48.7999300, 2.3325600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57549, 'Arc-sur-Tille', 'Arc-sur-Tille', 'Arc,Arc-sur-Tille,Ark sir Til,Ark sjur Tij,Ark-sjur-Tij,ark-swr-ty,di er he pan a er ke,Арк сир Тил,Арк сюр Тий,Арк-сюр-Тий,Арк-сюр-Тій,آرک-سور-تی,蒂尔河畔阿尔克', 47.3434900, 5.1866600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57550, 'Arçonnay', 'Arconnay', 'Arconnay,Arçonnay', 48.3967800, 0.0862000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57551, 'Arcis-sur-Aube', 'Arcis-sur-Aube', 'Arcis,Arcis-sur-Aube,Arsi sir Ob,Arsi-sjur-Ob,Artiaca,ao bu he pan a er xi,Арси сир Об,Арси-сюр-Об,Арсі-сюр-Об,奥布河畔阿尔西', 48.5338700, 4.1408500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57552, 'Archigny', 'Archigny', 'Archigny,Archinniacum,Arshin''i,Arshini,a er xi ni,Аршиньї,Аршињи,阿尔希尼', 46.6741100, 0.6537200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57553, 'Archettes', 'Archettes', 'Archettes,Arshet,Arshett,a er she te,Аршет,Аршетт,阿尔舍特', 48.1232000, 6.5372300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57554, 'Arches', 'Arches', 'Arches', 48.1185600, 6.5280600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57555, 'Archamps', 'Archamps', 'Archamps', 46.1365100, 6.1328700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57556, 'Arcey', 'Arcey', 'Arcey', 47.5225800, 6.6622200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57557, 'Arc-et-Senans', 'Arc-et-Senans', 'Arc,Arc-et-Senans,Ark e Senan,Ark-e-Senan,a er ke he se nan,Арк е Сенан,Арк-е-Сенан,阿尔克和瑟南', 47.0312700, 5.7702700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57558, 'Arcangues', 'Arcangues', 'Arcangos,Arcangues,Arcangós,Arkang,Arrangoitze,a er kang gai,Арканг,阿尔康盖', 43.4312400, -1.5223700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57559, 'Arcachon', 'Arcachon', 'Arcachon,Arcachón,Arcaishon,Arkashon,Arkasonas,Arkašonas,Commune-Franklin,XAC,a er ka xiong,arkashon,arkashwn,arukashon,Аркашон,آرکاشون,アルカション,阿尔卡雄', 44.6500000, -1.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57560, 'Arc-lès-Gray', 'Arc-les-Gray', 'Ark le Gre,Ark-le-Gre,Арк ле Гре,Арк-ле-Гре', 47.4570100, 5.5854700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57561, 'Arbus', 'Arbus', 'Arbi,Arbjus,Arbus,Arbús,a er bi,Арби,Арбюс,阿尔比', 43.3333300, -0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57562, 'Arbouans', 'Arbouans', 'Arbouans', 47.4994400, 6.7950500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57563, 'Arbonne-la-Forêt', 'Arbonne-la-Foret', 'Arbon la Fore,Arbonn-la-Fore,Арбон ла Форе,Арбонн-ла-Форе', 48.4140500, 2.5667700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57564, 'Arbonne', 'Arbonne', 'Arbon,Arbona,Arbonn,Arbonne,Constante,a er bang,Арбон,Арбонн,阿尔邦', 43.4324800, -1.5511800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57565, 'Arbois', 'Arbois', 'Arboa,Arbois,Arbosia,Arbua,a er bu wa,arbwyys,Арбоа,Арбуа,اربوئیس,阿尔布瓦', 46.9031100, 5.7745400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57566, 'Arbent', 'Arbent', 'Arb,Arban,Arbent,a er bang,aleubang,arbynt,Арб,Арбан,Արբան,أربينت,阿尔邦,아르방', 46.2922100, 5.6789000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57567, 'Aramon', 'Aramon', 'Aramon', 43.8917400, 4.6809600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57568, 'Arâches-la-Frasse', 'Araches-la-Frasse', 'Araches,Arachium,Arash,Arash-la-Frass,Arâches,Араш,Араш-ла-Фрасс', 46.0429700, 6.6314500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57569, 'Apt', 'Apt', '', 43.8833300, 5.4000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57570, 'Apremont', 'Apremont', 'Apremont', 46.7485000, -1.7407500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57571, 'Apprieu', 'Apprieu', 'Apprieu', 45.3992200, 5.4962800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57572, 'Appoigny', 'Appoigny', 'Apoani,Appoigny,Appuan''i,a pu wa ni,Апоањи,Аппуаньи,Аппуаньї,阿普瓦尼', 47.8746700, 3.5252400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57573, 'Appietto', 'Appietto', 'Apieto,Apjeto,App''etto,Appetto,Appieto,Appietto,Appiettu,Апието,Аппьетто,Аппєтто,Апјето', 42.0145400, 8.7678900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57574, 'Aouste-sur-Sye', 'Aouste-sur-Sye', 'Aosta,AouSainte-sur-Sye,Aouste,Aouste-sur-Sye,AuSen sir Si,Aust-sjur-Si,xi ai he pan a wu si te,АуСен сир Си,Ауст-сюр-Сі,西埃河畔阿乌斯特', 44.7169900, 5.0551600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57575, 'Aoste', 'Aoste', 'Aost,Aosta,Aoste,ao si te,Аост,奥斯特', 45.5867900, 5.6101400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57576, 'Anzin-Saint-Aubin', 'Anzin-Saint-Aubin', 'Anzen Sent Oben,Anzen-Sent-Oben,Anzin,Anzin-Saint-Aubin,Aubin-la-Fontaine,Commune-des-Freres-Unis,Commune-des-Frères-Unis,Mesnil-Marat,ang zan sheng ou ban,anzn-sn-abn,anzyn san awbyn,Анзен Сент Обен,Анзен-Сент-Обен,آنزن-سن-ابن,أنزين سان أوبين,昂赞圣欧班', 50.3131300, 2.7473200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57577, 'Anzin', 'Anzin', 'Anzen,Anzin,Onzan,ang zan,Анзен,Онзан,昂赞', 50.3720100, 3.5038700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57578, 'Antran', 'Antran', 'Antran,Intra Amnem,ang te lang,Антран,昂特朗', 46.8535000, 0.5431700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57579, 'Antrain', 'Antrain', 'Antrain,Antrain-sur-Couesnon,Antren,Entraven,Intramnum,Ontran,ang te lan,Антрен,Онтран,昂特兰', 48.4603100, -1.4835400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57580, 'Antony', 'Antony', 'Antony,Ontoni,Онтони', 48.7500000, 2.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57581, 'Antonne-et-Trigonant', 'Antonne-et-Trigonant', 'Anton e Trigonan,Antona e Trigonant,Antona et Tregona,Antonn-e-Trigonan,Antonne-et-Trigonant,ang tong he te li ge nan,Антон е Тригонан,Антонн-е-Тригонан,昂通和特里戈南', 45.2127100, 0.8300600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57582, 'Antigny', 'Antigny', 'Antigny', 46.6209500, -0.7698800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57583, 'Antibes', 'Antibes', 'Antib,Antiba,Antibas,Antibes,Antibol,Antipolis,Antíbol,XAT,amtiba,ang di bu,angtibeu,antibu,antyb,Αντίμπ,Антиб,Антіб,Անթիբ,אנטיב,آنتیب,أنتيب,अँतिब,アンティーブ,昂蒂布,앙티브', 43.5624100, 7.1277700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57584, 'Anthy-sur-Léman', 'Anthy-sur-Leman', '', 46.3553400, 6.4273500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57585, 'Anstaing', 'Anstaing', 'Anstaing,Ansten,Onsta,ang si tan,Анстен,Онста,昂斯坦', 50.6047300, 3.1907900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57586, 'Ansouis', 'Ansouis', 'Ansois,Ansouis,Ansoís,Ansui,Onsui,ang su yi,ansuu~i,Ансуи,Ансуї,Онсуи,アンスウィ,昂苏伊', 43.7377500, 5.4640100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57587, 'Anse', 'Anse', 'Anse', 45.9302300, 4.7157600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57588, 'Ansauvillers', 'Ansauvillers', 'Ansauvillers,Ansovile,Ansoville,Ansovilé,Onsovije,ang suo wei lai er,Ансовілле,Онсовије,昂索维莱尔', 49.5652300, 2.3874200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57589, 'Anould', 'Anould', 'Anould,Anu,a nu er,Ану,阿努尔', 48.1852600, 6.9459700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57590, 'Anor', 'Anor', 'Anor,a nuo er,Анор,阿诺尔', 49.9899900, 4.1004900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57591, 'Annot', 'Annot', 'Anno,Annot,Ano,Anot,Anu,Anòt,a nuo,Анно,Ано,Ану,阿诺', 43.9656600, 6.6644100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57592, 'Annonay', 'Annonay', 'Annonay,Annone,Anonai,Anone,Anonė,a nuo nai,anwny,Анноне,Аноне,آنونی,阿诺奈', 45.2396900, 4.6707500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57593, 'Annoeullin', 'Annoeullin', 'Annellen,Annjollen,Annoeullin,Annœullin,Anoelen,a ne lan,Аннеллен,Аннёллен,Аноелен,阿讷兰', 50.5292500, 2.9318000, 'FR', '2016-03-17', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57594, 'Annezin', 'Annezin', 'Ann''zin,Annezen,Annezin,Annezin-les-Bethune,Annezin-lès-Béthune,Annzen,Ann’zin,Anzen,a ne zan,anyzyn,Анзен,Аннезен,Аннзен,أنيزين,阿讷赞', 50.5319200, 2.6178500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57595, 'Anneyron', 'Anneyron', 'Anneyron', 45.2726500, 4.8878600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57596, 'Annet-sur-Marne', 'Annet-sur-Marne', 'Annet,Annet-sur-Marne', 48.9266900, 2.7195900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57597, 'Annesse-et-Beaulieu', 'Annesse-et-Beaulieu', 'Anes e Bolije,Anessa e Beuluoc,Anessa e Beuluòc,Annes-eh-Bol''jo,Annesse-e-Bol''e,Annesse-et-Baulieu,Annesse-et-Beaulieu,a nei si he bo li e,Анес е Болије,Аннес-э-Больё,Аннессе-е-Болье,Аннессе-е-Больє,阿内斯和博利厄', 45.1641600, 0.5719300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57598, 'Annequin', 'Annequin', 'Annequin', 50.5052500, 2.7201900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57599, 'Annemasse', 'Annemasse', 'Anemasse,Anemâsse,Annemasse,Annimassia,Annmass,QNJ,an na ma si,anmas,anmaseu,anumassu,anwms,an‌ms,Анмас,Аннмасс,انومس,ان‌مس,アヌマッス,安纳马斯,안마스', 46.1943900, 6.2377500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57600, 'Annecy-le-Vieux', 'Annecy-le-Vieux', 'Anesi le Vje,Annecium Vetus,Annecy-le-Vieux,Annesi-le-V''e,Annesi-le-Ve,Анеси ле Вје,Аннеси-ле-Вье,Аннесі-ле-Вє', 45.9197100, 6.1439300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57601, 'Annecy', 'Annecy', 'Aneci,Anecí,Annecium,Annecy,Annesi,Ansi,Ansī,Eneci,Gorad Ansi,NCY,a ne xi,ansi,ansy,anushi,anwsy,Èneci,Аннесі,Анси,Горад Ансі,آنسي,انسی,انوسی,アヌシー,阿讷西,안시', 45.9000000, 6.1166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57602, 'Annay', 'Annay', 'Annay,Annay-sous-Lens', 50.4630300, 2.8812200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57603, 'Anizy-le-Château', 'Anizy-le-Chateau', 'Anisy-la-Riviere,Anisy-la-Rivière,Anizy,Anizy-le-Chateau,Anizy-le-Château', 49.5067800, 3.4511900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57604, 'Aniche', 'Aniche', 'Aniche,Aniches', 50.3299500, 3.2534600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57605, 'Aniane', 'Aniane', 'An''jan,Aniana,Aniane,Anijan,Kamuna An''jan,Nhana,a ni ang,Анијан,Аньян,Камуна Аньян,אניאן,阿尼昂', 43.6844800, 3.5874700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57606, 'Anhiers', 'Anhiers', 'Anhiers', 50.4073700, 3.1551200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57607, 'Angy', 'Angy', 'Angy,Anzhi,ang ji,Анжи,Анжі,昂吉', 49.3297500, 2.3285400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57608, 'Angresse', 'Angresse', 'Angresse', 43.6580900, -1.3719100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57609, 'Angres', 'Angres', 'Angr,Angres,Anques,ang ge er,anjrys,Ангр,أنجريس,昂格尔', 50.4057200, 2.7605400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57610, 'Angoulins', 'Angoulins', 'Angoulins-sur-Mer,Angulen,Ongula,ang gu lan,Ангулен,Онгула,Անգուլեն,昂古兰', 46.1052600, -1.1071300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57611, 'Angoulême', 'Angouleme', 'ANG,An''nkoulem,Angouleme,Angoulême,Angulem,Angulema,Angulemas,Angulemo,Engoleime,Engolesme,Engolisma,Gorad Angulem,Montagne-Charente,Ongulem,ang gu lai mu,ang-gullem,anghwlym,anguremu,angwlm,Ανγκουλέμ,Ангулем,Горад Ангулем,Онгулем,אנגולם,آنگولم,أنغوليم,アングレーム,昂古莱姆,앙굴렘', 45.6500000, 0.1500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57612, 'Anglet', 'Anglet', 'Angelu,Angl,Angle,Anglet,ang ge lai,ang-geulleteu,anglh,anguretto,Англ,Англе,Англет,آنگله,アングレット,昂格莱,앙글레트', 43.4766400, -1.5134600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57613, 'Angles', 'Angles', 'Angles', 46.4083900, -1.4038900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57614, 'Angicourt', 'Angicourt', 'Angicourt,Angiscurtis,Anzhikur,Onzhikur,ang ji ku er,Анжикур,Онжикур,昂吉库尔', 49.3117500, 2.5041900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57615, 'Angevillers', 'Angevillers', 'Angevillers,Anzhville,Arsweiler,Onzhevije,ang re wei lai er,anzhwylh,Анжвилле,Анжвілле,Онжевије,آنژویله,昂热维莱尔', 49.3845900, 6.0391300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57616, 'Angervilliers', 'Angervilliers', 'Angervilliers,Anzhervil''e,Onzhervile,ang re wei li ye er,Анжервилье,Анжервільє,Онжервиље,昂热维利耶尔', 48.5926300, 2.0654100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57617, 'Angerville', 'Angerville', 'Angerville', 48.3135400, 1.9993500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57618, 'Angers', 'Angers', 'ANE,Andecavis,Angero,Angers,Angieus,Anje,Anze,Anzhe,Anzier,Anĝero,Anžē,Anžė,Añje,Bonne-Terre,Fruits-Sucres,Fruits-Sucrés,Gorad Anzheh,amji,ang re,angje,anje,anjyh,anzhe,anzhh,anzhw,ayngrz,x xngche,ʼnzh,Ανζέ,Анже,Горад Анжэ,אנזה,آنژه,آنژو,آنژہ,أنجيه,اینگرز,अँजी,อ็องเฌ,ანჟე,አንዤ,アンジェ,昂热,앙제', 47.4666700, -0.5500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57619, 'Anetz', 'Anetz', 'Ane,Anec,Anetz,Arned,a nei te,Ане,Анец,阿内特', 47.3805900, -1.1058300, 'FR', '2017-05-29', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57620, 'Anet', 'Anet', 'Ane,Anet,Ане', 48.8564200, 1.4398100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57621, 'Anduze', 'Anduze', 'Andjuz,Andusa,Anduze,Ondiz,ang di ci,Андюз,Ондиз,昂迪兹', 44.0540900, 3.9854500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57622, 'Andrézieux-Bouthéon', 'Andrezieux-Boutheon', 'Andrez''e-Buteon,Andrezieux,Andrezje-Buteon,Andrézieux,ang de lei qi e bu tai weng,Андрезьє-Бутеон,Андрезје-Бутеон,昂德雷齐厄布泰翁', 45.5262500, 4.2602100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57623, 'Andrezé', 'Andreze', 'Andreze,Andrezé,Ondroze,andoruze,ang de lei ze,Андрезе,Ондрозе,アンドルゼ,昂德雷泽', 47.1715500, -0.9523900, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57624, 'Andrésy', 'Andresy', 'Andresy,Andrezi,Andrésy,Ondrezi,Андрези,Андрезі,Ондрези', 48.9823500, 2.0568700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57625, 'Andrest', 'Andrest', 'Andres,Andrest,Ondrest,ang de lei si,Андрес,Андрест,Ондрест,昂德雷斯', 43.3199800, 0.0640500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57626, 'Andres', 'Andres', 'Andres', 50.8655600, 1.9209400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57627, 'Andouillé', 'Andouille', 'Andoliacum,Andouille,Andouillé,Andue,Anduje,ang du yi lai,Андує,Андује,昂杜伊莱', 48.1768500, -0.7836400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57628, 'Andolsheim', 'Andolsheim', '', 48.0617900, 7.4163700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57629, 'Andlau', 'Andlau', 'Andlau,Andlo,Andloei,andlaw,ang de luo,Àndlöi,Андлау,Андло,آندلاو,أندلاو,昂德洛', 48.3860700, 7.4169700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57630, 'Andilly', 'Andilly', 'Andilly', 49.0093500, 2.3024000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57631, 'Andilly', 'Andilly', 'Andilly,Andilly-les-Marais', 46.2542500, -1.0267200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57632, 'Andeville', 'Andeville', 'Andevil'',Andeville,Ondevij,ang de wei er,Андевиль,Андевіль,Ондевиј,昂德维尔', 49.2607800, 2.1642700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57633, 'Andernos-les-Bains', 'Andernos-les-Bains', 'Anderno le Ben,Andernos,Andernos-le-Ben,Andernos-les-Bains,Endarnos,Endarnòs,andrnas-l-bnz,ang dai er nuo lai ban,Андерно ле Бен,Андернос-ле-Бен,اندرناس-ل-بنز,昂代尔诺莱班', 44.7457200, -1.1035500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57634, 'Andelnans', 'Andelnans', 'Andelnans', 47.6022300, 6.8672000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57635, 'Andé', 'Ande', 'Ande,Andé', 49.2316300, 1.2408800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57636, 'Andard', 'Andard', 'Andar,Ondar,andrd,ang da er,Андар,Ондар,اندرد,昂达尔', 47.4565900, -0.3975200, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57637, 'Andancette', 'Andancette', 'Andancette,Andanset,Andansett,andanst,ang dang sai te,Андансет,Андансетт,اندانست,昂当塞特', 45.2424200, 4.8060600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57638, 'Andance', 'Andance', 'Andanca,Andance,Andans,Andança,andansy,ang dang ke,Анданс,اندانسی,昂当克', 45.2404600, 4.7979800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57639, 'Ancy-sur-Moselle', 'Ancy-sur-Moselle', 'Ancy,Ancy-sur-Moselle', 49.0569300, 6.0581600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57640, 'Ancy-le-Franc', 'Ancy-le-Franc', 'Ancy-le-Franc', 47.7758600, 4.1636100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57641, 'Ancône', 'Ancone', 'Ancone,Ancône', 44.5816000, 4.7271100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57642, 'Ancerville', 'Ancerville', 'Ancerville,Ancerville-Gue,Ancerville-Güe', 48.6357400, 5.0209100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57643, 'Ancenis', 'Ancenis', 'Ancenesium,Ancenis,Ankiniz,Anseni,ang se ni,ansuni,ansynys,Ансени,Ансені,انسینیس,アンスニ,昂瑟尼', 47.3666700, -1.1666700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57644, 'Ampuis', 'Ampuis', 'Ampi,Ampjui,Ampuis,ampwys,Ампи,Ампюї,امپویس', 45.4890600, 4.8087900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57645, 'Amplepuis', 'Amplepuis', 'Amplepi,Amplepjui,Amplepuis,amplypwyy,amplypwyys,Амплепи,Амплепуис,Амплепюї,آمپلیپوئی,امپلیپوئیس', 45.9725900, 4.3316000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57646, 'Amou', 'Amou', 'Amou', 43.5925700, -0.7467600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57647, 'Amnéville', 'Amneville', 'Amnevij,Amnevil,Amnevil'',Amneville,Amnéville,amnwyl,ang nei wei er,Амневил,Амневиль,Амневиј,Амневіль,آمنویل,昂内维尔', 49.2574900, 6.1420300, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57648, 'Ammerschwihr', 'Ammerschwihr', 'Amershvir,Ammerschweier,Ammerschweir,Ammershvir,a mei er si ke wei,amrshwyr,Амершвир,Аммершвир,Аммершвір,آمرشویر,阿梅尔斯克维', 48.1254800, 7.2828200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57649, 'Amilly', 'Amilly', 'Amilly', 48.4433300, 1.3934900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57650, 'Amilly', 'Amilly', 'Amilly', 47.9728100, 2.7718600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57651, 'Amiens', 'Amiens', 'Am''en,Amen,Amian,Amians,Amien,Amiens,Amijen,Amjen,Amjena,Amjenas,Amjēna,Amyen,Anmyin,Gorad Amen,QAM,Samarobriva,amiaeng,amian,amieni,amiyam,amyan,xa meiyng,ya mian,Αμιάν,Амиен,Амијен,Амьен,Амєн,Амјен,Горад Амен,Ամյեն,אמיין,آمیاں,أميان,امیان,आमियां,อาเมียง,ამიენი,アミアン,亞眠,아미앵', 49.9000000, 2.3000000, 'FR', '2016-02-20', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57652, 'Amfreville-la-Mi-Voie', 'Amfreville-la-Mi-Voie', 'Amfrevil la Mi Voa,Amfrevil''-la-Mi-Vua,Amfreville,Amfreville-la-Mi-Voie,amfrwyl-la-my-wya,Амфревил ла Ми Воа,Амфревиль-ла-Ми-Вуа,Амфревіль-ла-Мі-Вуа,امفرویل-لا-می-ویا', 49.4075500, 1.1387100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57653, 'Amfreville', 'Amfreville', '', 49.2500000, -0.2333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57654, 'els Banys d''Arles', 'els Banys d''Arles', 'Ameli le Ben,Amelie-les Bains,Amelie-les-Bains,Amélie-les Bains,Amélie-les-Bains,els Banys,els Banys d''Arles,Амели ле Бен', 42.4728900, 2.6691600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57655, 'Ambronay', 'Ambronay', 'Ambronay,Ambrone,Ambroniacum,Ambronê,Ombrone,ambrwnay,ang bu luo nei,angbeulone,Амброне,Омброне,Ամբրոնե,آمبرونے,أمبروناي,امبرونای,昂布罗内,앙브로네', 46.0046000, 5.3610700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57656, 'Ambrières-les-Vallées', 'Ambrieres-les-Vallees', 'Ambrier-le-Valle,Ambrieres,Ambrieres-le-Grand,Ambrijer le Vale,Ambrières,Ambrières-le-Grand,ambryrz-l-wls,ang bu li ai lai wa lai ai,Амбријер ле Вале,Амбрієр-ле-Валле,امبریرز-ل-ولس,昂布里埃莱瓦莱埃', 48.4000000, -0.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57657, 'Ambon', 'Ambon', 'Ambon', 47.5536700, -2.5551200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57658, 'Amboise', 'Amboise', 'Ambacia,Amboaz,Amboise,Ambosa,Ambuaz,Ambuazas,Gorad Ambuaz,Saint-Denis-Hors,XAM,ambwz,anbowazu,ang bu wa si,Амбоаз,Амбуаз,Горад Амбуаз,Ամբուազ,امبوز,アンボワーズ,昂布瓦斯', 47.4124900, 0.9826600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57659, 'Ambleteuse', 'Ambleteuse', 'Ambletez,Imbelteuse,Ombletez,ambltyws,amblytyws,ang bu lei te si,Амблетез,Омблетез,أمبليتيوس,امبلتئوس,昂布勒特斯', 50.8072900, 1.6038800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57660, 'Ambleny', 'Ambleny', 'Ambleni,Ambleny,Ombleni,amblny,ang bu lei ni,Амблени,Амблені,Омблени,Ամբլենի,امبلنی,昂布勒尼', 49.3807900, 3.1844700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57661, 'Amblainville', 'Amblainville', 'Amblainville,Amblenvil'',Omblanvij,amblaynwyl,ang bu lan wei er,Амбленвіль,Омбланвиј,امبلاینویل,昂布兰维尔', 49.2044300, 2.1224200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57662, 'Ambillou', 'Ambillou', 'Ambillou', 47.4510000, 0.4473000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57663, 'Ambierle', 'Ambierle', 'Amberl'',Ambierle,Embierle,Embièrle,Ombjerl,ambyrl,ang bi ye er,Амбєрль,Омбјерл,امبیرل,昂比耶尔', 46.1041100, 3.8938600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57664, 'Ambès', 'Ambes', 'Ambes,Ambés,Ombe,Sent Jacme dAmbes,Sent Jacme dAmbés,ambs,ang bei,Амбес,Омбе,امبس,昂贝', 45.0112700, -0.5321900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57665, 'Ambert', 'Ambert', 'Amber,Ambert,Amberta,Embert,Embèrt,ambrt,anberu,ang bei er,Амбер,امبرت,アンベール,昂贝尔', 45.5500000, 3.7500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57666, 'Ambérieux-en-Dombes', 'Amberieux-en-Dombes', 'Amberieux,Amberieux-en-Dombes,Ambérieux,Ambérieux-en-Dombes', 45.9943200, 4.9051200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57667, 'Ambérieu-en-Bugey', 'Amberieu-en-Bugey', 'Amber''jo-an-Bjuzhe,Ambere-an-Bjuzhe,Amberieu,Amberieu-en-Bugey,Amberioex,Amberyo an Byuze,Ambèriœx,Ambérieu,Ambérieu-en-Bugey,Omberju-on-Buzhi,Saint-Amberieu,Saint-Ambérieu,ambryw-an-bwgy,ambyryw-awn-bwghy,ang bei e ang bi re,angbelioeangbwije,Амберьё-ан-Бюже,Амберє-ан-Бюже,Омберју-он-Бужи,Ամբերյո ան Բյուժե,آمبریو-آں-بوژے,أمبيريو-أون-بوغي,امبریو-ان-بوگی,昂贝略昂比热,앙베리외앙뷔제', 45.9588500, 5.3432000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57668, 'Ambazac', 'Ambazac', 'Ambazac,Ambazak,Embasac,ambazak,ang ba zha ke,x xng ba sak,Амбазак,امبازاک,อ็องบาซัก,昂巴扎克', 45.9598300, 1.4006300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57669, 'Ambarès-et-Lagrave', 'Ambares-et-Lagrave', 'Ambares e La Grava,Ambares e la Grava,Ambares-e-Lagrav,Ambarez-e-Lagrav,Ambarés e La Grava,Ambarés e la Grava,Amoares,Amoarès,ambars-at-lagrawa,ang ba lei he la ge la fu,Амбарез-е-Лаграв,Амбарес-е-Лаграв,امبارس-ات-لاگراوا,昂巴雷和拉格拉夫', 44.9166700, -0.4833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57670, 'Amanvillers', 'Amanvillers', 'Amanvije,Amanville,Amanviller,Amanvillers,a mang wei lai er,amanwylrs,Аманвилле,Аманвиллер,Аманвије,Аманвілле,آمانویلرس,阿芒维莱尔', 49.1669100, 6.0422000, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57671, 'Amanlis', 'Amanlis', 'Amanli,Amanlis,Amanlix,Amanliz,a mang li,amanlys,Аманли,Аманлі,امانلیس,阿芒利', 48.0075200, -1.4767700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57672, 'Amancy', 'Amancy', 'Amancy', 46.0744900, 6.3297300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57673, 'Alzonne', 'Alzonne', 'Al''zon,Al''zonn,Alzon,Alzona,Alzonne,a er zong,alzwny,Алзон,Альзон,Альзонн,الزونی,阿尔宗', 43.2533800, 2.1780800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57674, 'Altorf', 'Altorf', 'Al''torf,Aldorf,Altdorf,Altorf,a er tuo er,altarf,altwrf,Àldorf,Алторф,Альторф,ألتورف,التارف,阿尔托尔', 48.5216600, 7.5278700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57675, 'Altkirch', 'Altkirch', 'Al''tkirsh,Altkirch,Altkirkh,Altkirsh,a er te ji ke,arutokirushu,Алткирх,Алткирш,Альткирш,Альткірш,آلت‌کیرش,アルトキルシュ,阿尔特基克', 47.6166700, 7.2500000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57676, 'Althen-des-Paluds', 'Althen-des-Paluds', 'Al''tan-de-Palju,Al''tan-de-Paljud,Altan de Pali,Althen,Althen-des-Paluds,Althen-les-Paluds,Alton-des-Pali,Lei Palus,Lei Palús,a er tang dai pa lu de,altyn-d-palwdz,Алтан де Пали,Алтон-дес-Пали,Альтан-де-Палю,Альтан-де-Палюд,التین-د-پالودز,阿尔唐代帕吕德', 44.0040500, 4.9586100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57677, 'Alsting', 'Alsting', 'Al''sten,Alsting,Alstingen,a er si tan,alstyng,Алстинг,Альстен,آلستینگ,阿尔斯坦', 49.1815200, 6.9939700, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57678, 'Allouagne', 'Allouagne', 'Allouagne,Allouanne,Alluan'',Aluan,a lu nie,alwagny,alwajn,Аллуань,Алуањ,ألواجن,الواگنی,阿卢涅', 50.5316700, 2.5119400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57679, 'Allonzier-la-Caille', 'Allonzier-la-Caille', 'Allonz''e-la-Kaj,Allonzier-la-Caille,Alonzje la Kaj,Cura de Alonzie,alwnzyr-la-kayl,Аллонзьє-ла-Кай,Алонзје ла Кај,الونزیر-لا-کایل', 46.0035200, 6.1177600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57680, 'Allonnes', 'Allonnes', 'Allones,Allonnes', 47.9674000, 0.1580700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57681, 'Allonnes', 'Allonnes', 'Allonnes', 47.2933800, 0.0245800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57682, 'Allonne', 'Allonne', 'Allonne', 49.4086300, 2.1142700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57683, 'Allinges', 'Allinges', 'Alenzh,Allenzh,Allinges,Allingiae-Mesingiae,alyngz,Аленж,Алленж,الینگز', 46.3365800, 6.4636300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57684, 'Allières-et-Risset', 'Allieres-et-Risset', '', 45.0993400, 5.6792400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57685, 'Allex', 'Allex', 'Allex', 44.7645400, 4.9175700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57686, 'Allevard', 'Allevard', 'Al''var,Alevard,Alevârd,Allevar,Allevard,Allevard-les-Bains,Alvar,a lei wa er,alywrd,Алвар,Аллевар,Альвар,الیورد,阿勒瓦尔', 45.3944900, 6.0751900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57687, 'Allennes-les-Marais', 'Allennes-les-Marais', 'Alen le Mare,Allenn-le-Mare,Allennes,a lai ne lai ma lai,alyns-l-marays,Ален ле Маре,Алленн-ле-Маре,الینس-ل-مارایس,阿莱讷莱马赖', 50.5375400, 2.9536100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57688, 'Alleins', 'Alleins', 'Alen,Alleins,Allen,a lan,alynz,Ален,Аллен,الینز,阿兰', 43.7038700, 5.1620300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57689, 'Allègre', 'Allegre', 'Alegr,Alegre,Allegr,Allegre,Allègre,Alègre,a lai ge er,Алегр,Аллегр,阿莱格尔', 45.2005200, 3.7127600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57690, 'Allauch', 'Allauch', 'Alaug,Allauch,Allo,Allosh,Alosh,a luo,alawch,Алло,Аллош,Алош,الاوچ,阿洛', 43.3357300, 5.4820100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57691, 'Allassac', 'Allassac', 'Alacac,Alasak,Alaçac,Allassac,Allassak,a la sa ke,alasak,arasakku,Аласак,Аллассак,الاساک,アラサック,阿拉萨克', 45.2581600, 1.4753200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57692, 'Allanche', 'Allanche', 'Alancha,Alansh,Allancha,Allanche,Allanches,Allansh,Alonsh,a lang ke,alanchh,Аланш,Алланш,Алонш,الانچه,阿朗克', 45.2279800, 2.9345600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57693, 'Allan', 'Allan', 'Allan', 44.4986500, 4.7875100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57694, 'Allaire', 'Allaire', 'Alaer,Allaire', 47.6375200, -2.1632400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57695, 'Alizay', 'Alizay', 'Alizay,Alize,a li ze,alyzay,Ализе,Алізе,الیزای,阿利泽', 49.3215800, 1.1785400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57696, 'Alixan', 'Alixan', 'Alexianum,Aliksan,Alixan,Les Aleissans,Los Aleissans,a li ke sang,alksan,Аликсан,Аліксан,الکسان,阿利克桑', 44.9747600, 5.0264100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57697, 'Alissas', 'Alissas', 'Alissas', 44.7125300, 4.6293600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57698, 'Alignan-du-Vent', 'Alignan-du-Vent', 'Alignan,Alignan-du-Vent', 43.4694500, 3.3416500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57699, 'Algrange', 'Algrange', 'Algrange', 49.3586300, 6.0474800, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57700, 'Algolsheim', 'Algolsheim', 'Algolsheim,Algolshem,Алголшем', 48.0062900, 7.5594500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57701, 'Alfortville', 'Alfortville', 'Al''forvil'',Alfortvij,Alfortville,Alforvil,Alforvilis,Alforvill,a er fu wei er,alfwrwyl,alpoleubil,aruforuvu~iru,Алфорвил,Алфортвиј,Альфорвиль,Альфорвіль,Ալֆորվիլլ,آلفورویل,الفورویل,アルフォールヴィル,阿爾福維爾,알포르빌', 48.8057500, 2.4204000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57702, 'Alès', 'Ales', 'Alais,Ale,Ales,Alesas,Alest,Alestum,Alès,Alèst,Auxon,Pont-Auzon,XAS,a lai,alh,alleseu,als,aresu,Але,Алес,آلس,اله,อาแล็ส,アレス,阿莱,알레스', 44.1248900, 4.0808200, 'FR', '2016-07-27', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57703, 'Aléria', 'Aleria', 'Alalia,Aleria,Alerija,Aléria,Gorad Aleryja,a lai li ya,alarya,Алерия,Алерија,Алерія,Горад Алерыя,الاریا,علالية,阿萊里亞', 42.1024000, 9.5157500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57704, 'Alénya', 'Alenya', 'Alenija,Alenya,Alenyà,Alénya,Аленија', 42.6387500, 2.9814800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57705, 'Alençon', 'Alencon', 'Alanson,Alansonas,Alencon,Alenconium,Alenson,Alenzon,Alenzón,Alençon,XAN,a lang song,alanswn,allangsong,alnswn,aranson,xa l xngsng,Алансон,Аленсон,אלנסון,الانسون,النسون,อาล็องซง,アランソン,阿朗松,알랑송', 48.4333300, 0.0833300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57706, 'Alby-sur-Chéran', 'Alby-sur-Cheran', 'Al''bi-sjur-Sheran,Albi sir Sheran,Albium Annecensium,Arbi,alby-sw-chran,Алби сир Шеран,Альбі-сюр-Шеран,البی-سو-چران', 45.8166700, 6.0166700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57707, 'Albitreccia', 'Albitreccia', 'Al''bitrechcha,Albitreccia,Albitreksija,albytrsya,Албитрексија,Альбитречча,Альбітречча,البیترسیا', 41.8624800, 8.9418200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57708, 'Albigny-sur-Saône', 'Albigny-sur-Saone', 'Al''bin''i-sjur-Son,Albigny-sur-Saone,Albini na Saoni,albygny-sw-sawn,Албињи на Саони,Альбіньї-сюр-Сон,البیگنی-سو-ساون', 45.8666700, 4.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57709, 'Albias', 'Albias', 'Albias', 44.0904900, 1.4482100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57710, 'Albi', 'Albi', 'Al''bi,Albi,Albia,Alby,Albí,Albī,Almpi,LBI,a er bi,albi,alby,arubi,xa lbi,Αλμπί,Алби,Альби,Альбі,אלבי,ألبي,البی,ಆಲ್ಬಿ,อาลบี,ཨཱལ་ཕི།,ალბი,アルビ,阿尔比,알비', 43.9298000, 2.1480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57711, 'Albertville', 'Albertville', 'Al''bervil'',Albertopolis,Albertville,Albervij,Albervil,Albervila,Albervilis,Albērvila,Arbertvela,Arbèrtvela,Gorad Al''bervil'',Roc-Libre,Valbeau,XAV,a er bei wei er,albeleubil,albyrfyl,albyrwyl,aruberuvu~iru,Албервил,Албервиј,Альбервиль,Альбервіль,Горад Альбервіль,آلبرت‌ویل,آلبیرویل,ألبيرفيل,アルベールヴィル,阿尔贝维尔,알베르빌', 45.6745200, 6.3906100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57712, 'Albert', 'Albert', 'Albert,BYF', 50.0009100, 2.6509600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57713, 'Albens', 'Albens', 'Al''ban,Alban,Albenis,Albens,Arbens,albns,Албан,Альбан,البنس', 45.7846300, 5.9487500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57714, 'Alba-la-Romaine', 'Alba-la-Romaine', 'Al''ba-la-Romen,Alba la Romen,Alban,a er ba la luo man,alba-la-rmayn,Алба ла Ромен,Альба-ла-Ромен,البا-لا-رماین,阿尔巴拉罗曼', 44.5553700, 4.5984600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57715, 'Alata', 'Alata', 'Alata,alata  kras-dw-swd,Алата,الاتا، کراس-دو-سود', 41.9774900, 8.7423200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57716, 'Ajain', 'Ajain', 'Ajain', 46.2063500, 1.9985000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57717, 'Ajaccio', 'Ajaccio', 'AJA,Adiacium,Aiacciu,Ajacas,Ajaccio,Ajacciu,Ajachcho,Ajacho,Ajacio,Ajaçio,Ajačas,Azaksjo,Azaxio,Azhaksio,Ažaksjo,Gorad Ajacha,a ya ke xiao,aiacho,ajagsio,ajaksyw,ajakushio,ajakyw,ajhaksiyo,azhaksy aw,azhaksyw,ʼzʼqsyw,Αζαξιό,Ажаксио,Аячо,Аяччо,Ајачо,Горад Аяча,Այաչչո,אזאקסיו,آژاکسیو,أجاكسيو,اجاکیو,اژاکسی او,अझाक्सियो,ཨ་ཇཀ་སིའོ།,აიაჩო,アジャクシオ,阿雅克肖,아작시오', 41.9188600, 8.7381200, 'FR', '2017-05-23', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57718, 'Aizenay', 'Aizenay', 'Aizenaj,Aizenay,Alzenay,Ezene,ai ze nai,ayznay,Аизенај,Езене,ایزنای,艾泽奈', 46.7400400, -1.6083400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57719, 'Aix-Noulette', 'Aix-Noulette', 'Aix,Aix-Noulette', 50.4256800, 2.7055400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57720, 'Aix-les-Bains', 'Aix-les-Bains', 'Aix-le-Bain,Aix-les-Bains,Aquae Sabaudiae,Ehks-le-Ben,Eks le Ben,Eks le Benas,Eks-le-Ben,Eks-les-Bjan,Ex-los-Bens,XAI,aks lbn,aks-lh-bn,egseulebaeng,ekusu=re=ban,Èx-los-Bens,ʼqs-lh-bn,Αιξ-λε-Μπαιν,Екс ле Бен,Екс-ле-Бен,Екс-лес-Бјан,Экс-ле-Бен,אקס-לה-בן,اکس لبن,اکس-له-بن,エクス＝レ＝バン,엑스레뱅', 45.6917300, 5.9086300, 'FR', '2016-12-10', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57721, 'Aixe-sur-Vienne', 'Aixe-sur-Vienne', 'Aissa,Aixe,Aixe-sur-Vienna,Aixe-sur-Vienne,Ehks-sjur-V''en,Eks sir Vijen,Eks-sjur-V''enn,Eks-sjur-Venn,ayksh-sw-wyyn,wei ai na he pan ai ke si,Екс сир Вијен,Екс-сюр-Вьенн,Екс-сюр-Вєнн,Экс-сюр-Вьен,ایکسه-سو-ویین,แอ็กซ์-ซูร์-เวียน,维埃纳河畔艾克斯', 45.7986200, 1.1388400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57722, 'Aix-en-Provence', 'Aix-en-Provence', 'AEx-in-Profentse,Aikso Provenca,Ais de Provenca,Ais de Provença,Aix,Aix-an-Provans,Aix-en-Provence,Aquae Sextiae,Ehks-an-Provans,Eks an Provans,Eks-an-Provans,Eksanprovansa,Provanso Eksas,QXB,aks awn brwfans,aks-an-prwans,ayks ayn prwns,egsangpeulobangseu,ekusu=an=purovu~ansu,pu luo wang si de qu ai ke si,ya sang pu fang,Æx-in-Profentse,Ēksanprovansa,Αιξ-αν-Προβάνς,Екс ан Прованс,Екс-ан-Прованс,Экс-ан-Прованс,Էքս-ան-Պրովանս,אקס-אן-פרובאנס,آكس أون بروفانس,اکس-آن-پروانس,ایکس این پرونس,ཨེག་སི་-ཨེན་-ཕོ་རོའོ་ཝང་སི།,ექს-ან-პროვანსი,エクス＝アン＝プロヴァンス,亞桑蒲坊,普罗旺斯地区艾克斯,엑상프로방스', 43.5283000, 5.4497300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57723, 'Aix-en-Othe', 'Aix-en-Othe', 'Aix,Aix-en-Othe,Ehks-an-Ot,Eks-an-Ot,Eks-on-Ot,ao te de qu ai ke si,ayks-an-awth,Екс-ан-От,Екс-он-От,Экс-ан-От,ایکس-ان-اوته,奥特地区艾克斯', 48.2239100, 3.7342500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57724, 'Aiton', 'Aiton', 'Aiton', 45.5604800, 6.2605300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57725, 'Aiserey', 'Aiserey', 'Aiserey', 47.1722900, 5.1626000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57726, 'Airvault', 'Airvault', 'Airvault,Aurea Vallis,Ervo,Ervuel,ayrwalt,Ерво,Ервуел,ایروالت', 46.8253300, -0.1363400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57727, 'Aire-sur-la-Lys', 'Aire-sur-la-Lys', 'Aire,Aire-su-la-Lys,Aire-sur-la-Lys,Aria super Legia,Arien,Arien-aan-de-Leie,Ariën,Ariën-aan-de-Leie,Ehr-sjur-la-Lis,Er sir la Lis,Er-sjur-la-Li,Er-sjur-la-Lis,Morin-la-Montagne,ayr swr la lyz,ayry-sw-la-lys,li si he pan ai er,Ер сир ла Лис,Ер-сюр-ла-Ли,Ер-сюр-ла-Ліс,Эр-сюр-ла-Лис,أير سور لا ليز,ایری-سو-لا-لیس,利斯河畔艾尔', 50.6387100, 2.3987600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57728, 'Airaines', 'Airaines', 'Airaines,Araine,Ehren,Eren,ai lai ne,ayrayns,Ерен,Эрен,Էրեն,ایراینس,艾赖讷', 49.9682600, 1.9426600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57729, 'Ainay-le-Château', 'Ainay-le-Chateau', 'Ainay,Ainay-le-Chateau,Ainay-le-Château,Ainay-sur-Sologne,Ehne-le-Shato,Ene le Shato,Ene-le-Shato,ai nai bao,aynay-lw-shtw,Ене ле Шато,Ене-ле-Шато,Эне-ле-Шато,اینای-لو-شتو,艾奈堡', 46.7114200, 2.6924500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57730, 'Aime', 'Aime', 'Axima,Cime-Belle,Em,Les Antiquites,Les Antiquités,QAI,Ем', 45.5555900, 6.6504200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57731, 'Aimargues', 'Aimargues', 'Aimargues,Emarg,Emarge,ai ma er ge,aymargwys,Емарг,Емарге,ایمارگوئس,艾马尔格', 43.6844800, 4.2099900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57732, 'Ailly-sur-Somme', 'Ailly-sur-Somme', 'Ai-sjur-Somm,Ailly,Ailly-su-Sonme,Ailly-sur-Somme,Aji na Somi,Aji-sjur-Som,Eyi syur Som,ayly-sw-sam,suo mu he pan a yi,Айи-сюр-Сом,Аї-сюр-Сомм,Аји на Соми,Էյի սյուր Սոմ,ایلی-سو-سام,索姆河畔阿伊', 49.9288600, 2.1961500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57733, 'Ailly-sur-Noye', 'Ailly-sur-Noye', 'Ai-sjur-Nua,Ailly,Ailly-su-Noee,Ailly-su-Noée,Ailly-sur-Noye,Aji sir Noa,Aji-sjur-Nua,Ayi syur Nua,ayly-sw-nwy,nu wa he pan a yi,Айи-сюр-Нуа,Аї-сюр-Нуа,Аји сир Ноа,Այի սյուր Նուա,ایلی-سو-نوی,努瓦河畔阿伊', 49.7570700, 2.3636700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57734, 'Aillevillers-et-Lyaumont', 'Aillevillers-et-Lyaumont', 'Aillevillers,Aillevillers-et-Lyaumont,Ajavije-e-LJumon,Ajvijers et Liomon,Ајавије-е-Љумон,Ајвијерс ет Лиомон', 47.9203300, 6.3377500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57735, 'Aillant-sur-Tholon', 'Aillant-sur-Tholon', 'Aillant,Aillant-sur-Tholon', 47.8742600, 3.3504900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57736, 'Aigurande', 'Aigurande', 'Agiron,Aigurande,Egiran,Egjurand,Ehgjurand,ai ju lang de,aygwrand,egurando,Агирон,Егиран,Егюранд,Эгюранд,ایگوراند,エグランド,艾居朗德', 46.4339700, 1.8302600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57737, 'Aiguillon', 'Aiguillon', 'Agvijon,Aiguillon,Egijon,Агвијон,Егијон', 44.2989300, 0.3402000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57738, 'Aigues-Vives', 'Aigues-Vives', 'Aigues-Vives', 43.7379000, 4.1806600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57739, 'Aigues-Mortes', 'Aigues-Mortes', 'Aigas Mortas,Aigas Mòrtas,Aigasmortas,Aigasmòrtas,Aigueesmortes,Aigues-Mortes,Aigüesmortes,Aquae Mortuae,Eg-Mort,Egiu Mortas,Ehg-Mort,Fort-Peletier,ai ge mo er te,aygws-mwrts,egu=moruto,Ėgiu Mortas,Ег-Морт,Эг-Морт,ایگوس-مورتس,エーグ＝モルト,艾格莫尔特', 43.5668300, 4.1906800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57740, 'Aigueperse', 'Aigueperse', 'Aigueperse,Egeper,Егепер', 46.0228400, 3.2023100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57741, 'Aiguefonde', 'Aiguefonde', 'Aiguefonde', 43.4939400, 2.3168600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57742, 'Aigueblanche', 'Aigueblanche', 'Aigueblanche,Aquae Albae,Blanches-Eaux,Egblansh,Le Torrent,Sur-Vignes,aygwblanch,Егбланш,ایگوبلانچ', 45.5031300, 6.5080600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57743, 'Aigrefeuille-sur-Maine', 'Aigrefeuille-sur-Maine', 'Acrifolium,Aigrefeuille,Aigrefeuille-sur-Maine,Egrefej-sjur-Men,Egrfej sir Men,Kelenneg-ar-Mewan,aygrfwyl-sw-mayn,man en he pan ai ge er fu ye,Егрефей-сюр-Мен,Егрфеј сир Мен,ایگرفویل-سو-ماین,曼恩河畔艾格尔弗耶', 47.0788800, -1.4025400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57744, 'Aigre', 'Aigre', 'Aigre,Egr,Ehgr,agr  shrant,ai ge er,Егр,Эгр,اگر، شرانت,艾格尔', 45.8937700, 0.0096300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57745, 'Aigné', 'Aigne', 'Aigne,Aigné', 48.0647100, 0.1190800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57746, 'Aiglemont', 'Aiglemont', 'Aiglemont,Ajglemon,Eglemon,Eglmon,Ehglemon,ai ge lei meng,ayglmant,Ајглемон,Еглемон,Еглмон,Эглемон,ایگلمانت,艾格勒蒙', 49.7803100, 4.7648300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57747, 'Aiffres', 'Aiffres', 'Aiffres', 46.2944900, -0.4210100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57748, 'Ahuy', 'Ahuy', 'Ahuy,Ajuj,ahwy,Аюй,اهوی', 47.3694400, 5.0208900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57749, 'Ahun', 'Ahun', 'Aehn,Aen,Ahun,Aiun,Auen,Aün,a an,Аен,Аэн,阿安', 46.0859400, 2.0447900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57750, 'Ahuillé', 'Ahuille', 'Ahuille,Ahuillé,Aije,Ajuie,ahwyly,ao yi lai,Аије,Аюїє,اهویلی,奥伊莱', 48.0208600, -0.8690600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57751, 'Ahetze', 'Ahetze', 'Aec,Aehc,Ahetze,a ai te ci,ahtz,Аец,Аэц,اهتز,اہتز,阿埃特兹', 43.4043200, -1.5719100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57752, 'Agonac', 'Agonac', 'Agonac,Agonacum,Agonak,a ge na ke,agwnak,Агонак,اگوناک,阿戈纳克', 45.2924800, 0.7502500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57753, 'Agny', 'Agny', 'Agny,Aigny,An''i,Ani,a ni,ajny,Аньи,Аньї,Ањи,أجني,اگنے,阿尼', 50.2591400, 2.7600200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57754, 'Agnetz', 'Agnetz', 'Agnetz', 49.3811800, 2.3862100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57755, 'Agneaux', 'Agneaux', 'Agneaux,An''o,Ano,a gai ao,agnyw,agnywks,Аньо,Ањо,اگنیو,اگنیوکس,阿盖奥', 49.1190500, -1.1061000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57756, 'Agen', 'Agen', 'AGF,Agen,Aginnum,Agén,Azenas,Azhan,Azhen,Aženas,a rang,ajaeng,ajan,azhan,azheni,azhn,Ажан,Ажен,אזן,أجان,اژان,اژن,อาแฌ็ง,აჟენი,アジャン,阿让,아쟁', 44.2000000, 0.6333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57757, 'Agde', 'Agde', 'Agatha,Agd,Agde,Agdei vald,XAG,a ge de,agd,ageudeu,agudo,Агд,اگد,アグド,阿格德,아그드', 43.3108300, 3.4758300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57758, 'Afa', 'Afa', 'Afa,Afà,Афа', 41.9836200, 8.7946900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57759, 'Acquigny', 'Acquigny', 'Acquigny,Akin''i,Akini,Akuini,a ji ni,akwygny,Акиньи,Акињи,Акуини,Акіньї,اکویگنی,阿基尼', 49.1735000, 1.1765000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57760, 'Acigné', 'Acigne', 'Acigne,Acigneium,Acigné,Asin''e,Asine,Egineg,a xi nie,asyn,Асинье,Асиње,Асіньє,اسین,阿西涅', 48.1333300, -1.5370400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57761, 'Achiet-le-Grand', 'Achiet-le-Grand', 'Achiet-Grand,Achiet-le-Grand,Ash''e-le-Gran,Ashe-le-Gran,Ashje le Gran,ashyt-lw-grnd,atshyt lw jrand,da a xie,Ашье-ле-Гран,Ашє-ле-Гран,Ашје ле Гран,أتشيت لو جراند,اشیت-لو-گرند,大阿谢', 50.1306700, 2.7811900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57762, 'Achicourt', 'Achicourt', 'Achicourt,Ashikur,Hachicourt,a xi ku er,achykwrt,atshykwrt,xa chi kur,Ашикур,أتشيكورت,اچیکورت,อาชีกูร์,阿希库尔', 50.2742900, 2.7577900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57763, 'Achères-la-Forêt', 'Acheres-la-Foret', 'Acheres,Acheres-la-Foret,Achères,Achères-la-Forêt,Asher la Fore,Asher-la-Fore,ashr-la-fwrh,Ашер ла Форе,Ашер-ла-Форе,اشر-لا-فوره', 48.3545800, 2.5703500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57764, 'Achères', 'Acheres', 'Acheres,Achères', 48.9611500, 2.0688200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57765, 'Achenheim', 'Achenheim', 'Achene,Achenheim,Ashenajm,Ashenkhajm,Ashenkhem,a shang an,aknhym,atshynhym,Àchene,Ашенайм,Ашенхајм,Ашенхем,أتشينهيم,اکنهیم,阿尚安', 48.5807000, 7.6280300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57766, 'Abzac', 'Abzac', 'Abzac', 45.0166700, -0.1333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57767, 'Abscon', 'Abscon', 'Abscon,Absconium,Abskon,a pu si kong,abskan,Абскон,ابسکان,阿普斯孔', 50.3333300, 3.3000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57768, 'Abrest', 'Abrest', 'Abrest,Abret,Abrèt,a bu lei si,abrst,Абрест,ابرست,阿布雷斯', 46.0990700, 3.4480000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57769, 'Abreschviller', 'Abreschviller', 'Abreschviller,Abreschwiller,Abreshvije,Abreshviller,a bu lei shen wei lai,abrshwylr,Абрешвиллер,Абрешвије,Абрешвіллер,آبرشویلر,阿布雷什维莱', 48.6364700, 7.0946600, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57770, 'Abondant', 'Abondant', 'Abondan,Abondant,a bang dang,abandant,Абондан,اباندانت,阿邦当', 48.7859000, 1.4400600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57771, 'Abondance', 'Abondance', 'Abondance', 46.2803100, 6.7202600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57772, 'Ablon-sur-Seine', 'Ablon-sur-Seine', 'Ablon,Ablon na Seni,Ablon-sjur-Sen,Ablon-sur-Seine,ablwn-sw-syyn,sai na he pan a bu long,Аблон на Сени,Аблон-сюр-Сен,ابلون-سو-سیین,塞纳河畔阿布隆', 48.7273200, 2.4268600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57773, 'Ablon', 'Ablon', 'Ablon,a bu long,Аблон,阿布隆', 49.3921400, 0.2958400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57774, 'Ablis', 'Ablis', 'Abli,Ablis,a bu li,Абли,Аблі,阿布利', 48.5172000, 1.8362400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57775, 'Ableiges', 'Ableiges', 'Ableiges,Ablezh,a bu lai re,ablygs,Аблеж,ابلیگس,阿布莱热', 49.0893200, 1.9815400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57776, 'Ablain-Saint-Nazaire', 'Ablain-Saint-Nazaire', 'Abla-Sant-Nazer,Ablain,Ablain-Saint-Nazaire,Ablain-Saint-Nazart,Ablain-la-Montagne,Ablen Sen Nazer,Ablen-Sen-Nazer,a bu lan sheng na ze er,ablayn san nazyr,ablyan-saynt-nzayr,Абла-Сант-Назер,Аблен Сен Назер,Аблен-Сен-Назер,أبلاين سان نازير,ابلیان-ساینت-نزایر,阿布兰圣纳泽尔', 50.3932000, 2.7088000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57777, 'Abilly', 'Abilly', 'Abii,Abiji,Abili,Abilly,Abilly-sur-Claise,a bi yi,abyly,Абийи,Абили,Абији,Абії,ابیلی,阿比伊', 46.9333300, 0.7333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57778, 'Abeilhan', 'Abeilhan', 'Abeilhan,Abejan,Abelhan,a bei yang,abyhan,Абеян,Абејан,ابیهان,阿贝扬', 43.4492500, 3.2952900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57779, 'Abbeville', 'Abbeville', 'Abbatis Villa,Abbevil'',Abbeville,Abbéville,Abevil,Abeville,Abvij,Abvil,Abvil'',Abvilis,Advile,XAB,a bu wei er,abeubil,abfyl,abuvu~iru,abvili,abwwyl,abwyl,Аббевіль,Абвил,Абвиль,Абвиј,Абевил,Աբեվիլ,أبفيل,ابوویل,ابویل,აბვილი,アブヴィル,阿布维尔,아브빌', 50.1000000, 1.8333300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57780, 'Abbaretz', 'Abbaretz', 'Abarec,Abarrez,Abbare,Abbaretiacum,Abbaretz,a ba lei te,abartz,Абарец,Аббаре,ابارتز,阿巴雷特', 47.5531400, -1.5320000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57781, 'Lugon-et-l''Île-du-Carnay', 'Lugon-et-l''Ile-du-Carnay', '', 44.9555600, -0.3361100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57782, 'Guidel-Plage', 'Guidel-Plage', '', 47.7676800, -3.5218000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57783, 'Les Deux Alpes', 'Les Deux Alpes', 'DXA,Le Dezal''p,Ле Дезальп', 45.0116000, 6.1254800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57784, 'Villeneuve-d''Ascq', 'Villeneuve-d''Ascq', 'Neuvile-Ask,Vil''nev-d''Ask,Vil''njov-d''Ask,Villeneuve d''Ascq,Villeneuve-d''Ascq,Villeneuve-d’Ascq,Villenyev d''Ask,Viln''ov d''Ask,Vilnev d''Ask,Vilnev d''Askas,Vilneva d''Aska,Vilnēva d''Aska,a si ke xin cheng,fylynwf dask,vu~irunuvu=dasuku,wynw dsk,Вилнев д’Аск,Вилньов д''Аск,Вильнев-д''Аск,Вильнёв-д’Аск,Вільнев-д''Аск,וילנב-ד''אסק,فيلينوف داسك,وینو دسک,ヴィルヌーヴ＝ダスク,阿斯克新城', 50.6166900, 3.1666400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57785, 'Val Thorens', 'Val Thorens', 'Val''Torans,Vale Thorens,Валь Торанс,ואל טורנס', 45.2977700, 6.5837700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57786, 'Castelmaurou', 'Castelmaurou', 'Castelmauron,Castèlmauron,Kastel''moru,Kastelmoru,ka si tai er mo lu,Кастелмору,Кастельмору,卡斯泰尔莫鲁', 43.6777800, 1.5322200, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57787, 'Geneston', 'Geneston', 'Banaleg-ar-Gevred,Genestonium,Zheneston,re nei si tong,Женестон,热内斯通', 47.0563900, -1.5113900, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57788, 'Le Ban Saint-Martin', 'Le Ban Saint-Martin', '', 49.1225000, 6.1511100, 'FR', '2016-02-21', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57789, 'Le Sequestre', 'Le Sequestre', '', 43.9107600, 2.1180400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57790, 'Les Ulis', 'Les Ulis', 'Lez Ili,Lez-Julis,le suw lis,lewilliseu,lzwly,yu li si,Лез Или,Лез-Юлис,Лез-Юліс,לז אוליס,لزولی,เลซูว์ลิส,レ・ジュリス,于利斯,레윌리스', 48.6816700, 2.1694400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57791, 'Carnoux-en-Provence', 'Carnoux-en-Provence', 'Carnos de Provenca,Carnós de Provença,Karnu-an-Provans,Karnuks an Provans,pu luo wang si de qu ka nu,Карну-ан-Прованс,Карнукс ан Прованс,普罗旺斯地区卡努', 43.2563900, 5.5644400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57792, 'Saint-Manvieu-Norrey', 'Saint-Manvieu-Norrey', '', 49.1813900, -0.5000000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57793, 'Bourgoin-Jallieu', 'Bourgoin-Jallieu', 'Burgoan Zhalije,Burguen-Zhal''e,Burguin-Zhall''jo,bu er guan ya li e,buleugoangjallioe,burugowan=jaiyu,bwrghwan-jalyw,bwrgwan zhlyw,bwrgwan-zhlyw,Бургоан Жалије,Бургуен-Жальє,Бургуин-Жалльё,بورغوان-جاليو,بورگوآن ژلیو,بورگوآن-ژلیو,ブルゴワン＝ジャイユー,布尔关雅利厄,부르고앙잘리외', 45.5861100, 5.2736100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57794, 'Val-de-Reuil', 'Val-de-Reuil', 'Le Vaudreuil-Ville Nouvelle,Val''-de-Rej,Val''-de-Rjoj,wa de lei yi,Валь-де-Рей,Валь-де-Рёй,瓦德勒伊', 49.2738500, 1.2102100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57795, 'Condorcet', 'Condorcet', '', 44.4074800, 5.1993700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57796, 'Belle-Plagne', 'Belle-Plagne', 'Bel''-Plan'',Belle Plagne,Бель-Плань', 45.5093200, 6.7068500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57797, 'Marseille 01', 'Marseille 01', '', 43.2981400, 5.3840700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57798, 'Marseille 02', 'Marseille 02', '', 43.2966400, 5.3703400, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57799, 'Marseille 03', 'Marseille 03', '', 43.3025700, 5.3758300, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57800, 'Marseille 04', 'Marseille 04', '', 43.3021300, 5.4014100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57801, 'Marseille 05', 'Marseille 05', '', 43.2955100, 5.4005500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57802, 'Marseille 06', 'Marseille 06', '', 43.2876400, 5.3791800, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57803, 'Marseille 07', 'Marseille 07', 'Marseille 07,Marseille 7e arrondissement', 43.2828900, 5.3602100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57804, 'Marseille 08', 'Marseille 08', '', 43.2708300, 5.3821000, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57805, 'Marseille 10', 'Marseille 10', 'Marseille 10,Marseille 10e arrondissement,Masalia,Massalia,Massilia,Μασσαλία', 43.2788900, 5.4152300, 'FR', '2016-10-11', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57806, 'Marseille 09', 'Marseille 09', '', 43.2543300, 5.4057000, 'FR', '2016-04-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57807, 'Marseille 11', 'Marseille 11', '', 43.2907000, 5.4384000, 'FR', '2016-04-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57808, 'Marseille 12', 'Marseille 12', '', 43.2961400, 5.4361700, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57809, 'Marseille 13', 'Marseille 13', '', 43.3185600, 5.4083600, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57810, 'Marseille 14', 'Marseille 14', '', 43.3444700, 5.3800400, 'FR', '2016-04-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57811, 'Marseille 15', 'Marseille 15', '', 43.3722400, 5.3538600, 'FR', '2016-04-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57812, 'Marseille 16', 'Marseille 16', '', 43.3598200, 5.3342100, 'FR', '2016-04-28', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57813, 'La Defense', 'La Defense', 'La Defense,La Défense,Lja Defans,Paris La Defense,Ля Дефанс', 48.8919800, 2.2388100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57814, 'Saint-Quentin-en-Yvelines', 'Saint-Quentin-en-Yvelines', 'Communaute d''agglomeration de Saint-Quentin-en-Yvelines,Communauté d’agglomération de Saint-Quentin-en-Yvelines,Saint-Quentin-en-Yvelines', 48.7718600, 2.0189100, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57815, 'Cergy-Pontoise', 'Cergy-Pontoise', 'Cergy-Pontoise', 49.0389400, 2.0780500, 'FR', '2016-02-18', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57816, 'Rd pt des Chataigniers, Rte de Milizac, Guilers, Finistère, France', 'Rd pt des Chataigniers, Rte de Milizac, Guilers, Finistere, France', '', 48.4338700, -4.5680900, 'FR', '2016-08-25', 76);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57817, 'Tchibanga', 'Tchibanga', 'TCH,Tchibanga', -2.9332300, 10.9817800, 'GA', '2014-09-07', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57818, 'Port-Gentil', 'Port-Gentil', 'Mandji,POG,Port Gentil,Port Zantilis,Port Zhantil,Port Žantilis,Port-Gentil,Port-Jantil,Port-Zhantil'',bwrt jntyl,poleujangti,porujanti,pwrt-gntyl,rang di er gang,Порт Жантил,Порт-Жантиль,פורט-גנטיל,بورت جنتيل,ポールジャンティ,让蒂尔港,포르장티', -0.7193300, 8.7815100, 'GA', '2011-08-25', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57819, 'Oyem', 'Oyem', 'OYE', 1.5995000, 11.5793300, 'GA', '2011-08-25', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57820, 'Omboué', 'Omboue', 'Fernan Vaz,Fernand-Vaz,Omboue,Omboué', -1.5746400, 9.2618400, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57821, 'Okondja', 'Okondja', 'OKN,Okandja,Okondi,Okondja', -0.6548700, 13.6753300, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57822, 'Ntoum', 'Ntoum', '', 0.3905100, 9.7609600, 'GA', '2013-10-06', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57823, 'Ndendé', 'Ndende', 'KDN,Ndende,Ndendé', -2.4007700, 11.3581300, 'GA', '2017-07-04', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57824, 'Ndjolé', 'Ndjole', 'Ndjole,Ndjolé,Njole', -0.1782700, 10.7648800, 'GA', '2011-10-20', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57825, 'Mounana', 'Mounana', 'Mounana', -1.4085000, 13.1585700, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57826, 'Mouila', 'Mouila', 'MJL', -1.8684600, 11.0559400, 'GA', '2011-08-25', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57827, 'Moanda', 'Moanda', 'MFF,Moanda,Moanga,Mouanda,Mouenda,Muanda,mo an da,moanda,mwanda,Моанда,مواندا,モアンダ,莫安達,모안다', -1.5665200, 13.1987000, 'GA', '2015-03-31', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57828, 'Mitzic', 'Mitzic', 'MZC,Midzik,Mitsig,Mitzic,Mitzick,Mitzig,Mitzik', 0.7820500, 11.5490400, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57829, 'Mimongo', 'Mimongo', 'Mimongo', -1.6195200, 11.6067500, 'GA', '2012-02-02', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57830, 'Mbigou', 'Mbigou', 'M''bigou,MBC,Mbigou,M’bigou', -1.9004600, 11.9060000, 'GA', '2011-10-20', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57831, 'Mayumba', 'Mayumba', 'MYB,Mavumba,Mayoumba,Mayumba', -3.4319800, 10.6554000, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57832, 'Makokou', 'Makokou', 'MKU,Makokou,Makokou Fortifie,Makokou Fortifié,Makoku,Макоку', 0.5738100, 12.8641900, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57833, 'Libreville', 'Libreville', 'Gorad Librehvil'',LBV,Libarwil,Liberopolis,Librefille,Librevil,Librevil'',Librevila,Librevilis,Libreville,Librevilo,Librvil,Libvil,Limprebil,Limprvil,Liuravila,lbrwl,lbrywyl,li be rx wil,li bo wei er,libaravila,libarevile,libeuleubil,librevhila,librevili,lipravil,lybrfyl,lybrwwyl,lybrwyl,riburuvu~iru,Λιμπρβίλ,Λιμπρεβίλ,Горад Лібрэвіль,Либрвил,Либревил,Либревиль,Лібревіль,Լիբրևիլ,ליברוויל,ליברעוויל,لبرول,لبریویل,ليبرفيل,لیبرویل,لیبرێڤیل,लिबरेविले,लिब्रेव्हिल,ਲਿਬਰਵਿਲ,லிப்ரவில்,ลีเบรอวิล,ལིབ་རེ་ཝིལ།,ლიბრევილი,ሊብረቪል,リーブルヴィル,利伯維爾,利伯维尔,리브르빌', 0.3924100, 9.4535600, 'GA', '2012-04-25', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57834, 'Lékoni', 'Lekoni', 'Fortifie du Lekoni,Fortifie du Liconi,Fortifié du Liconi,Fortifié du Lékoni,Leconi,Lecori,Lekoni,Liconi,Léconi,Lékoni', -1.5843100, 14.2590500, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57835, 'Lastoursville', 'Lastoursville', 'Bonda,LTL,Lastoursville,Lastourville', -0.8174200, 12.7081800, 'GA', '2013-06-30', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57836, 'Lambaréné', 'Lambarene', 'LBQ,Lambarene,Lambarenė,Lambaréné,lambaryny,lambrny,lan ba lei nei,langbalene,ranbarene,Ламбарене,لامبارینی,لامبرنی,ランバレネ,兰巴雷内,랑바레네', -0.7001000, 10.2405500, 'GA', '2016-12-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57837, 'Koulamoutou', 'Koulamoutou', 'KOU,Koula Moubou,Koula Mouta,Koula Moutou,Koulamotou,Koulamoutou,Kulamutu,Куламуту', -1.1366700, 12.4639900, 'GA', '2016-11-27', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57838, 'Gamba', 'Gamba', 'GAX,Gamba', -2.6500000, 10.0000000, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57839, 'Franceville', 'Franceville', 'Franceville,Fransvil,Fransvil'',Fransvilis,Gorad Fransvil'',MVB,Masuku,fransfyl,franswyl,fu lang si wei er,furansuvu~iru,peulangseubil,Горад Франсвіль,Франсвил,Франсвиль,Франсвіль,فرانسفيل,فرانسویل,フランスヴィル,弗朗斯维尔,프랑스빌', -1.6333300, 13.5835700, 'GA', '2011-03-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57840, 'Fougamou', 'Fougamou', 'FOU,Fougamou', -1.2154400, 10.5837800, 'GA', '2012-04-25', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57841, 'Cocobeach', 'Cocobeach', 'Cocoabeach,Cocobeach,Ukoko', 1.0001900, 9.5822900, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57842, 'Booué', 'Booue', 'Booue,Booué,Boque,Boue,Boué', -0.0920700, 11.9384600, 'GA', '2012-01-18', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57843, 'Bitam', 'Bitam', 'BMM,Bitam', 2.0759700, 11.5006500, 'GA', '2012-02-28', 80);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57844, 'Ystrad Mynach', 'Ystrad Mynach', '', 51.6427600, -3.2362000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57845, 'Ystradgynlais', 'Ystradgynlais', '"stradgunlajs,Ystradgunlais,Ystradgynlais,Ъстрадгънлайс', 51.7666700, -3.7666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57846, 'Ystalyfera', 'Ystalyfera', 'Ystalfera,Ystalyfera', 51.7671600, -3.7808200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57847, 'Yoxall', 'Yoxall', 'Yoxall', 52.7665900, -1.7906800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57848, 'Youlgreave', 'Youlgreave', '', 53.1739900, -1.6904400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57849, 'York', 'York', 'Aebura,Eabhrac,Eabhraig,Eboracum,Efrog,Eoforwic,Everoui,Evrek,Giork,Gorad Jork,Jork,Jorka,Jorkas,Jorvik,Jórvík,QQY,York,yark,yokeu,yoku,yorka,yue ke,ywrk,ywrq,yxrk,Évèroui,Γιορκ,Јорк,Горад Ёрк,Йорк,Յորք,יורק,يورك,یارک,یورک,یۆرک,यॉर्क,யார்க்,ยอร์ก,იორკი,ヨーク,約克,요크', 53.9576300, -1.0827100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57850, 'Yetminster', 'Yetminster', 'Yetminster', 50.8957900, -2.5795900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57851, 'Yeovil', 'Yeovil', 'Giuela,Jeovil'',Jouvil,Jouvilis,Yeovil,yobil,yue wei er,yywwyl,Йеовиль,Йоувил,یئوویل,約維爾,요빌', 50.9415900, -2.6321100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57852, 'Yelverton', 'Yelverton', '', 50.4929000, -4.0838200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57853, 'Yealmpton', 'Yealmpton', 'Yealmpton', 50.3485600, -3.9987700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57854, 'Yeadon', 'Yeadon', 'Yeadon i West Yorkshire', 53.8643700, -1.6874300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57855, 'Yazor', 'Yazor', 'Yazor', 52.1166700, -2.8666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57856, 'Yaxley', 'Yaxley', 'Yaxley', 52.5176800, -0.2585200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57857, 'Yatton', 'Yatton', '', 51.9666700, -2.5333300, 'GB', '2014-08-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57858, 'Yatton', 'Yatton', 'Jatton,Yatton,Яттон', 51.3883900, -2.8235300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57859, 'Yate', 'Yate', 'yath,یاته', 51.5407400, -2.4183900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57860, 'Yarnton', 'Yarnton', 'Yarnton', 51.8044800, -1.3114900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57861, 'Yarmouth', 'Yarmouth', 'Jarmut,Yarmouth,Yarmouth pa Isle of Wight,Yarmouth på Isle of Wight,yameoseu,yarmwth  jzyrh wayt,Ярмут,یارموث، جزیره وایت,야머스', 50.7052900, -1.4992900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57862, 'Yarm', 'Yarm', 'Yarm,Yarm on Tees,yarm,یارم', 54.5036400, -1.3579300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57863, 'Yapton', 'Yapton', 'Yapton', 50.8209000, -0.6130000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57864, 'Yalding', 'Yalding', 'Yalding', 51.2238700, 0.4292000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57865, 'Wymondham', 'Wymondham', '', 52.7597800, -0.7405500, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57866, 'Wymeswold', 'Wymeswold', 'Wimeswould,Wymeswold', 52.8053600, -1.1128800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57867, 'Wylam', 'Wylam', 'Wylam', 54.9765400, -1.8218700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57868, 'Wye', 'Wye', '', 51.1824900, 0.9367800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57869, 'Wroxall', 'Wroxall', '', 52.3379100, -1.6689800, 'GB', '2011-03-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57870, 'Wroxall', 'Wroxall', '', 50.6162500, -1.2229200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57871, 'Wroughton', 'Wroughton', '', 51.5241100, -1.7955900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57872, 'Wrotham', 'Wrotham', '', 51.3085600, 0.3089900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57873, 'Writtle', 'Writtle', 'Writtle', 51.7290600, 0.4293800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57874, 'Wrington', 'Wrington', '', 51.3617300, -2.7631900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57875, 'Wrexham', 'Wrexham', 'Reksamas,Reksem,Reksum,Rexam,Wrecsam,Wreksam,Wrexham,legseom,lei ke si han mu,rekusamu,wrksam,Ρέξαμ,Рексем,Рексъм,Ռեքսհեմ,רקסהאם,ورکسام,レクサム,雷克斯漢姆,렉섬', 53.0466400, -2.9913200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57876, 'Wrentham', 'Wrentham', 'Wrentham', 52.3836700, 1.6669200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57877, 'Wrea Green', 'Wrea Green', '', 53.7765100, -2.9157300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57878, 'Wrawby', 'Wrawby', 'Wrawby', 53.5667200, -0.4619400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57879, 'Wragby', 'Wragby', 'Wragby', 53.2833300, -0.3000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57880, 'Wouldham', 'Wouldham', '', 51.3498600, 0.4581600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57881, 'Wotton-under-Edge', 'Wotton-under-Edge', 'Wotton-under-Edge,awtwn-andr-aj,اوتون-آندر-اج', 51.6324200, -2.3451200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57882, 'Worton', 'Worton', '', 51.3161100, -2.0411100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57883, 'Wortley', 'Wortley', '', 53.4833300, -1.5333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57884, 'Worthing', 'Worthing', 'Vorting,Worthing,wajingu,wwrtyng,Вортинг,وورتینگ,ワージング', 50.8179500, -0.3753800, 'GB', '2014-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57885, 'Worlaby', 'Worlaby', '', 53.6113000, -0.4668500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57886, 'Worksop', 'Worksop', 'Uehrksop,Uurksop,Worksop,wwrksap,Уърксоп,Уэрксоп,وورکساپ', 53.3018200, -1.1240400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57887, 'Workington', 'Workington', 'Uurkingtun,wo jin dun,wwrkyngtwn,Уъркингтън,وورکینگتون,沃金頓', 54.6425000, -3.5441300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57888, 'Worcester', 'Worcester', 'Caerwrangon,City of Worcester,Gorad Vustehr,UWC,Ustur,Vigornia,Vuster,Vusteris,Wiogoraceastre,Worcester,useuteo,usuta,vuster,wo shi da,wrkstr,wstr,wu si te,wurs texr,wwstr,Вустер,Горад Вустэр,Устър,Վուսթեր,ورکستر,وستر,وورسسٹر,ووستر,ووسٹر,วุร์สเตอร์,ウスター,伍斯特,窩士打,우스터', 52.1893500, -2.2200100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57889, 'Royal Wootton Bassett', 'Royal Wootton Bassett', 'Royal Wootton Bassett,Wooton Bassett,Wootton Bassett,rwyal wwtwn bast,رویال ووتون باست', 51.5419000, -1.9045000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57890, 'Wootton', 'Wootton', '', 53.6302100, -0.3532800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57891, 'Wootton', 'Wootton', '', 52.0952500, -0.5349400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57892, 'Wootton', 'Wootton', 'Wooton,Wootton', 51.1738000, 1.1794000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57893, 'Wootton', 'Wootton', '', 50.7284700, -1.2353600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57894, 'Woolwich', 'Woolwich', 'Vulidzh,Vulvic,Vulviç,o''ulica,ullichi,urijji,wu li qi,Вулидж,وول‌ویچ,ওউলিচ,ウーリッジ,伍利奇,울리치', 51.4910000, 0.0648000, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57895, 'Woolpit', 'Woolpit', '', 52.2245400, 0.8882600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57896, 'Woolley', 'Woolley', '', 53.6133900, -1.5145700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57897, 'Wooler', 'Wooler', 'Wooler,wwlr,وولر', 55.5475500, -2.0118600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57898, 'Wool', 'Wool', 'Wool', 50.6796600, -2.2189000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57899, 'Woodstock', 'Woodstock', 'Gorad Vudstak,Udstok,Vudstok,Woodstock,Woodstock i Oxfordshire,udeuseutog,wu de si tuo ke,wwdstwk  aksfwrdshr,Вудсток,Горад Вудстак,Удсток,وودستوک، آکسفوردشر,伍德斯托克,우드스톡', 51.8485000, -1.3513200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57900, 'Woodsetts', 'Woodsetts', 'Woodsetts', 53.3480400, -1.1720400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57901, 'Woodley', 'Woodley', 'wwdly  brkshr,وودلی، برکشر', 51.4500000, -0.8833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57902, 'Woodhall Spa', 'Woodhall Spa', 'Woodhall Spa', 53.1521500, -0.2145300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57903, 'Wood Green', 'Wood Green', 'wu de ge lin,wwd gryn,وود گرین,伍德格林', 51.6000000, -0.1166700, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57904, 'Woodford Green', 'Woodford Green', 'Woodford Green,vudafarda grina,वुडफ़र्ड ग्रीन', 51.6093800, 0.0232900, 'GB', '2012-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57905, 'Woodford', 'Woodford', '', 52.3823100, -0.5809900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57906, 'Woodford', 'Woodford', '', 51.1166700, -1.8333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57907, 'Woodcote', 'Woodcote', 'Woodcote', 52.7333300, -2.3333300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57908, 'Woodchurch', 'Woodchurch', '', 51.0760500, 0.7734600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57909, 'Woodbridge', 'Woodbridge', 'Vudbridzh,Woodbridge,Woodbridge i Suffolk,wwdbryj  safk,Вудбридж,وودبریج، سافک', 52.0933200, 1.3204200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57910, 'Woodborough', 'Woodborough', '', 51.3385200, -1.8397600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57911, 'Wombwell', 'Wombwell', 'Wombwell', 53.5218900, -1.3969800, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57912, 'Wombourn', 'Wombourn', 'Wombourn,Wombourne', 52.5333300, -2.1833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57913, 'Wolverhampton', 'Wolverhampton', 'Goulverchampton,Heantun,Ulvurkhamptun,Vulvergempton,Vulverhamptonas,Vulverhempton,Vulverhemptona,Vulverkhempton,Wolverhampton,Wulfrunehantona,XVW,ulbeohaempeuteon,u~oruvu~ahanputon,wlwrhmptwn,wu er fu han pu dun,wwlbrhmptwn,wwlfrhambtwn,Γουλβερχάμπτον,Вулвергемптон,Вулверхемптон,Улвърхамптън,Վուլվերհեմպտոն,וואלווערהאמפטאן,וולברהמפטון,ولورهمپتون,وولفرهامبتون,وولورہیمپٹن,วุลเวอร์แฮมป์ตัน,ვულვერჰემპტონი,ウォルヴァーハンプトン,伍爾弗漢普頓,울버햄프턴', 52.5854700, -2.1229600, 'GB', '2014-05-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57914, 'Wolston', 'Wolston', '', 52.3771700, -1.3954400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57915, 'Wolsingham', 'Wolsingham', '', 54.7308500, -1.8831900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57916, 'Wollaston', 'Wollaston', '', 52.2579400, -0.6703800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57917, 'Wold Newton', 'Wold Newton', '', 54.1428000, -0.3999300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57918, 'Wold Newton', 'Wold Newton', '', 53.4500000, -0.1333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57919, 'Woldingham', 'Woldingham', '', 51.2852700, -0.0337200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57920, 'Wokingham', 'Wokingham', 'Uokingam,Uokingkhem,oking-eom,wwkyngham,Уокингам,Уокингхем,ووکینگهام,오킹엄', 51.4112000, -0.8356500, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57921, 'Woking', 'Woking', 'Uoking,Uokinge,Vokingas,Woking,XWO,u~okingu,wo jin,wwdkyng,wwkng,Уокинг,Уокинге,وودکینگ,ووکنگ,ウォキング,沃金', 51.3190300, -0.5589300, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57922, 'Woburn Sands', 'Woburn Sands', '', 52.0157900, -0.6498200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57923, 'Woburn', 'Woburn', 'wwbwrn  bdfwrdshr,ووبورن، بدفوردشر', 51.9886500, -0.6190300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57924, 'Wivenhoe', 'Wivenhoe', 'Winehoe,Wivenhoe,Wyvenhoe,wywnhwyh,ویونهوئه', 51.8555300, 0.9579600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57925, 'Wivelsfield Green', 'Wivelsfield Green', '', 50.9631300, -0.0713300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57926, 'Wiveliscombe', 'Wiveliscombe', 'Wiveliscombe,wylzkm,ویلزکم', 51.0413900, -3.3127800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57927, 'Witton Gilbert', 'Witton Gilbert', 'Witton Gilbert', 54.8057200, -1.6368600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57928, 'Wittering', 'Wittering', 'Wittering', 52.6069800, -0.4404800, 'GB', '2014-09-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57929, 'Witney', 'Witney', 'Uitni,Witney,wytny,Уитни,ویتنی', 51.7836000, -1.4854000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57930, 'Witley', 'Witley', '', 51.1499300, -0.6476800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57931, 'Withington', 'Withington', '', 52.7166700, -2.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57932, 'Withington', 'Withington', '', 52.1000000, -2.6333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57933, 'Withernsea', 'Withernsea', 'Uiternsi,wytrnsy,Уитернси,ویترنسی', 53.7311000, 0.0334700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57934, 'Witheridge', 'Witheridge', '', 50.9174300, -3.7035100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57935, 'Witham', 'Witham', 'wytham,ویتهام', 51.8000700, 0.6403800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57936, 'Witchford', 'Witchford', '', 52.3869900, 0.2060200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57937, 'Wiston', 'Wiston', 'Wiston', 51.8258300, -4.8700000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57938, 'Wishaw', 'Wishaw', 'Camas Neachdain,Vishou,Wishae,Wishaw,wei xiao,wyshaw,Вішоу,ویشاو,威蕭', 55.7666700, -3.9166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57939, 'Wisbech', 'Wisbech', 'Uisbijch,Visbicas,Visbičas,Vizbich,Wisbech,wysbch,Визбич,Уисбийч,ویسبچ', 52.6662200, 0.1593800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57940, 'Wirksworth', 'Wirksworth', 'Wirksworth,wyrkswwrth,ویرکسوورث', 53.0823200, -1.5739100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57941, 'Winwick', 'Winwick', 'Winwick', 53.4333300, -2.6000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57942, 'Wintringham', 'Wintringham', 'Wintringham', 54.1459000, -0.6475900, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57943, 'Winterton', 'Winterton', '', 53.6549700, -0.5988500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57944, 'Winterbourne Stoke', 'Winterbourne Stoke', '', 51.1672900, -1.8980600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57945, 'Winterbourne', 'Winterbourne', 'Winterbourn,Winterbourne', 51.4460900, -1.3466000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57946, 'Winston', 'Winston', '', 54.5451900, -1.7885400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57947, 'Winslow', 'Winslow', 'Uinslou,Winslow i Buckinghamshire,Уинслоу,وینسلو، باکینگهام‌شر,وینسلو، بکنگھم شائر', 51.9428400, -0.8813100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57948, 'Winsford', 'Winsford', 'wynsfwrd,وینسفورد', 53.1914600, -2.5239800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57949, 'Winnersh', 'Winnersh', 'Winnersh', 51.4274700, -0.8799400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57950, 'Winkleigh', 'Winkleigh', 'Winkleigh', 50.8558100, -3.9430000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57951, 'Wingrave', 'Wingrave', 'Wingrave', 51.8649400, -0.7424400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57952, 'Wingham', 'Wingham', '', 51.2716800, 1.2146300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57953, 'Wingfield', 'Wingfield', 'Wingfield,Winkfield', 51.3134500, -2.2603800, 'GB', '2017-06-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57954, 'Wingerworth', 'Wingerworth', '', 53.2020000, -1.4335900, 'GB', '2016-02-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57955, 'Wingate', 'Wingate', '', 54.7324200, -1.3789600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57956, 'Wing', 'Wing', '', 52.6177500, -0.6827000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57957, 'Wing', 'Wing', 'Wing', 51.8952400, -0.7195600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57958, 'Winford', 'Winford', '', 51.3833300, -2.6611100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57959, 'Windsor', 'Windsor', 'New Windsor,Uindzor,Vindzor,Vindzoras,Vinjor,Windesoria,Windlesora,Windlesōra,Windsor,Windsor i Berkshire,u~inza,wen sha,winjeo,wnzr,wyndswr  brkshr,Виндзор,Віндзор,Уиндзор,Վինձոր,ونزر,ونڈسر، بارکشائر,ویندسور، برکشر,ウィンザー,溫莎,윈저', 51.4833300, -0.6000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57960, 'Windlesham', 'Windlesham', '', 51.3650900, -0.6547600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57961, 'Windermere', 'Windermere', 'Byen Windermere,u~indamia,wen de mi er,wyndrmr  kambrya,wyndrmyr,ويندرمير,ویندرمر، کامبریا,ウィンダミア,文德米爾', 54.3808600, -2.9070900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57962, 'Winchester', 'Winchester', 'Caerwynt,Gorad Vinchehstehr,Ouinchetre,Ouînchêtre,Uinchest"r,Uinchester,Vincester,Vincesteris,Vinchester,Vinčesteris,WNC,Winchester,Winsjester,Wintonia,u~inchesuta,vinacestara,vincestar,wen che shi da,wen che si te,win ches texr,wincheseuteo,wnshstr,wynchstr,wynzstr,Винчестер,Вінчестер,Горад Вінчэстэр,Уинчестер,Уинчестър,Վինչեսթեր,וינצסטר,ونشستر,ونچیسٹر,وینچستر,विनचेस्टर,వించెస్టర్,ವಿಂಚೆಸ್ಟರ್,วินเชสเตอร์,უინჩესტერი,ウィンチェスター,温彻斯特,溫車士打,윈체스터', 51.0651300, -1.3187000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57963, 'Winchcombe', 'Winchcombe', 'Winchcomb,Winchcombe', 51.9536300, -1.9639800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57964, 'Wincanton', 'Wincanton', 'Wincanton', 51.0567600, -2.4057400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57965, 'Wimborne Minster', 'Wimborne Minster', 'Uimborn Minstur,Wimborne,Wimborne Minster,wen bo en ming si te,wymbwrn mynstr,Уимборн Минстър,ویمبورن مینستر,溫伯恩明斯特', 50.7833300, -1.9833300, 'GB', '2012-03-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57966, 'Wimblington', 'Wimblington', 'Wimblington', 52.5092500, 0.0841600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57967, 'Wilton', 'Wilton', 'Uiltun,Vilton,Wiltonia,wyltwn  wyltshr,Вілтон,Уилтън,ولٹن، ویلٹشائر,ویلتون، ویلتشر', 51.0792600, -1.8621000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57968, 'Wilshamstead', 'Wilshamstead', 'Wilhamstead,Willshamstead,Wilstead', 52.0808800, -0.4488900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57969, 'Wilsford', 'Wilsford', 'Wilsford', 51.3000000, -1.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57970, 'Wilsden', 'Wilsden', 'Wilsden', 53.8208400, -1.8595900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57971, 'Wilmslow', 'Wilmslow', '', 53.3280300, -2.2314800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57972, 'Wilmcote', 'Wilmcote', 'Wilmcote', 52.2208100, -1.7652800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57973, 'Williton', 'Williton', 'Williton', 51.1623600, -3.3220800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57974, 'Willington', 'Willington', 'Willington', 54.7166700, -1.7000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57975, 'Willington', 'Willington', '', 52.1340900, -0.3723500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57976, 'Willingham', 'Willingham', '', 53.3500000, -0.6833300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57977, 'Willingham', 'Willingham', '', 52.3140400, 0.0577600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57978, 'Willerby', 'Willerby', '', 53.7609900, -0.4418600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57979, 'Willenhall', 'Willenhall', 'Willenhall,wylnhal,ویلنهال', 52.5851400, -2.0593400, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57980, 'Willaston', 'Willaston', 'Willaston', 53.2955000, -2.9973200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57981, 'Willaston', 'Willaston', '', 53.0666700, -2.4833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57982, 'Willand', 'Willand', 'Willand', 50.8833300, -3.3666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57983, 'Wilden', 'Wilden', '', 52.1827200, -0.3964500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57984, 'Wilburton', 'Wilburton', '', 52.3519100, 0.1767300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57985, 'Wilberfoss', 'Wilberfoss', '', 53.9485400, -0.8894500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57986, 'Wigton', 'Wigton', 'wygtwn,ویگتون', 54.8248200, -3.1611400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57987, 'Wigston Magna', 'Wigston Magna', 'Great Wigston,Wigston Magna,Wigston Two Steeples', 52.5812800, -1.0924800, 'GB', '2015-04-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57988, 'Wigmore', 'Wigmore', '', 52.3147400, -2.8580200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57989, 'Wigginton', 'Wigginton', '', 54.0171700, -1.0831000, 'GB', '2014-12-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57990, 'Wigan', 'Wigan', 'Uigan,Uigun,Vigan,Viganas,Wigan,XWI,la uigyn,u~igan,wei gan,wei gen,wigeon,wygan,Виган,Віган,Уиган,Уигън,ویگان,ウィガン,威根,维甘,위건', 53.5429600, -2.6370600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57991, 'Widnes', 'Widnes', 'Vidnes,Widnes,wei de ni si,wydnz,Виднес,ویدنز,威德尼斯', 53.3618000, -2.7340600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57992, 'Wickwar', 'Wickwar', 'Wickwar', 51.5940400, -2.3996800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57993, 'Wickham Market', 'Wickham Market', 'Wickham Market', 52.1529800, 1.3629900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57994, 'Wickham Bishops', 'Wickham Bishops', '', 51.7783000, 0.6682300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57995, 'Wickham', 'Wickham', '', 51.4434200, -1.4320000, 'GB', '2011-02-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57996, 'Wickham', 'Wickham', 'Wickham,wykham,ویکهام', 50.8992400, -1.1881500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57997, 'Wickford', 'Wickford', '', 51.6110100, 0.5233100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57998, 'Wick', 'Wick', 'Inbhir Uige,Inbhir Ùige,Inbhir Úige,Uik,Vikas,WIC,Week,Weik,Wick,Wick i Skottland,Yn Ooig,wei ke,Уик,維克', 58.4390600, -3.0942400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(57999, 'Wick', 'Wick', 'Wick', 51.4530600, -2.4236100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58000, 'Wick', 'Wick', 'Y Wig', 51.4394400, -3.5494400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58001, 'Whyteleafe', 'Whyteleafe', '', 51.3080800, -0.0842900, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58002, 'Whitworth', 'Whitworth', 'Whitworth,Whitworth i Lancashire,wytwwrth  lankashr,ویتوورث، لانکاشر', 53.6560100, -2.1771000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58003, 'Whitwell', 'Whitwell', 'Whitwell', 53.2833300, -1.2166700, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58004, 'Whitton', 'Whitton', '', 53.7000000, -0.6333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58005, 'Whitton', 'Whitton', '', 52.3000000, -3.0666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58006, 'Whittlesford', 'Whittlesford', 'Whittlesford', 52.1134500, 0.1496900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58007, 'Whittlesey', 'Whittlesey', 'Whittlesea,Whittlesey,wytlsy,ویتلسی', 52.5580400, -0.1301600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58008, 'Whittington', 'Whittington', '', 52.8732000, -3.0030400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58009, 'Whittington', 'Whittington', 'Whittington', 52.6737200, -1.7609100, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58010, 'Whittingham', 'Whittingham', '', 55.4011500, -1.8934000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58011, 'Whitstable', 'Whitstable', 'Uitstabl,Vitstabl,Whitstable,waytstabl,Витстабл,Уитстабл,وايتستابل', 51.3607000, 1.0257000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58012, 'Whitley Bay', 'Whitley Bay', 'Whitley,Whitley Bay', 55.0397300, -1.4471300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58013, 'Whitland', 'Whitland', 'Hendy Gwyn,Whitland', 51.8188900, -4.6152800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58014, 'Whitford', 'Whitford', '', 53.2833300, -3.2833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58015, 'White Waltham', 'White Waltham', '', 51.4922500, -0.7723900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58016, 'Whiteparish', 'Whiteparish', 'Whiteparish', 51.0104100, -1.6485500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58017, 'Whitehills', 'Whitehills', 'Whitehills', 57.6773000, -2.5786300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58018, 'Whitehead', 'Whitehead', '', 54.7537100, -5.7093300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58019, 'Whitehaven', 'Whitehaven', 'Uajtkhejvun,whythawn,Уайтхейвън,وهیتهاون', 54.5489700, -3.5841200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58020, 'Whitefield', 'Whitefield', 'Whitefield', 53.5500000, -2.3000000, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58021, 'Whitchurch', 'Whitchurch', 'Whitchurch,Whitchurch i Shropshire,Yr Eglwys Wen,ویتچورچ، شروپ‌شر', 52.9666700, -2.6833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58022, 'Whitchurch', 'Whitchurch', '', 51.8500000, -2.6500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58023, 'Whitchurch', 'Whitchurch', '', 51.4060600, -2.5626500, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58024, 'Whitby', 'Whitby', 'Streoneshalh,Strēoneshalh,Uitbi,Vitbis,Whitby,hwiteubi,u~ittobi,wytbay,Уитби,ویتبای,ウィットビー,휘트비', 54.4877400, -0.6149800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58025, 'Whitburn', 'Whitburn', 'Whitburn', 55.8666700, -3.6833300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58026, 'Whitburn', 'Whitburn', 'Whitburn', 54.9533300, -1.3686100, 'GB', '2014-04-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58027, 'Whiston', 'Whiston', '', 53.4085100, -1.3151000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58028, 'Whimple', 'Whimple', '', 50.7664900, -3.3565500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58029, 'Whickham', 'Whickham', '', 54.9456100, -1.6763500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58030, 'Wheldrake', 'Wheldrake', '', 53.8962400, -0.9630300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58031, 'Wheaton Aston', 'Wheaton Aston', 'Wheaton Aston', 52.7114500, -2.2206400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58032, 'Wheatley', 'Wheatley', 'Wheatley', 51.7473100, -1.1393600, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58033, 'Wheathampstead', 'Wheathampstead', '', 51.8114800, -0.2937100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58034, 'Whaplode', 'Whaplode', '', 52.7993400, -0.0363900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58035, 'Whalley', 'Whalley', '', 53.8220900, -2.4071200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58036, 'Whaley Bridge', 'Whaley Bridge', 'Whaley Bridge', 53.3303100, -1.9826000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58037, 'Whaddon', 'Whaddon', '', 52.1010500, -0.0344200, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58038, 'Weymouth', 'Weymouth', 'Uehjmut,Uejmut,Vejmut,Vimutium,Weymouth i Dorset,u~eimasu,waymth,wei mao si,weimeoseu,wymwth  dwrst,Вејмут,Уеймът,Уэймут,وايمث,ویموث، دورست,ウェイマス,韦茅斯,웨이머스', 50.6144800, -2.4599100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58039, 'Weybridge', 'Weybridge', 'Vejbridzh,Veybrij,Weybridge,wybryj,Вейбридж,Վեյբրիջ,ویبریج', 51.3717800, -0.4597500, 'GB', '2015-05-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58040, 'Wetwang', 'Wetwang', '', 54.0175000, -0.5773800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58041, 'Wetherby', 'Wetherby', 'Uehterbi,Vezerbi,Wedrebi,wedeobi,wtrby,Везербі,Уэтерби,وتربی,웨더비', 53.9283600, -1.3867200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58042, 'Wetheral', 'Wetheral', 'Wetheral', 54.8840100, -2.8332700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58043, 'Westwood', 'Westwood', '', 51.3346200, -2.2797500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58044, 'West Wickham', 'West Wickham', 'Vest-Uikkhehm,West Wickham,vesta vikahama,Вест-Уикхэм,ویسٹ وکہم,वेस्ट विकहम', 51.3666700, -0.0166700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58045, 'West Wellow', 'West Wellow', '', 50.9727300, -1.5829300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58046, 'West Walton', 'West Walton', 'Walton,West Walton', 52.6978200, 0.1740600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58047, 'West Thurrock', 'West Thurrock', '', 51.4782800, 0.2767200, 'GB', '2016-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58048, 'West Rainton', 'West Rainton', '', 54.8166700, -1.5000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58049, 'Westonzoyland', 'Westonzoyland', '', 51.1085400, -2.9284300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58050, 'Weston Underwood', 'Weston Underwood', '', 52.1457400, -0.7386200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58051, 'Weston Turville', 'Weston Turville', 'Weston Turville', 51.7916800, -0.7576700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58052, 'Weston-super-Mare', 'Weston-super-Mare', 'Uehston-s''juper-Mehr,Uest"n sjup"r Me"r,Uestun-Sjupur-Meur,Veston na Meru,Weston super Mare,Weston-super-Mare,u~esuton=supa=mea,weseuteonsyupeomeeo,wstwn-swpr-mar,Вестон на Меру,Уестън сюпър Меър,Уестън-Сюпър-Меър,Уэстон-сьюпер-Мэр,وستون-سوپر-مار,ウェストン＝スーパー＝メア,웨스턴슈퍼메어', 51.3460300, -2.9766500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58053, 'Westoning', 'Westoning', '', 51.9814000, -0.4969800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58054, 'Weston', 'Weston', '', 53.0666700, -2.4000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58055, 'West Molesey', 'West Molesey', 'Molesey', 51.3998500, -0.3799700, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58056, 'City of Westminster', 'City of Westminster', 'Westminster', 51.5000000, -0.1166700, 'GB', '2013-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58057, 'West Mersea', 'West Mersea', '', 51.7779800, 0.9187300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58058, 'West Malling', 'West Malling', 'wst malyng,وست مالینگ', 51.2927300, 0.4090700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58059, 'West Linton', 'West Linton', '', 55.7497200, -3.3560700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58060, 'West Kirby', 'West Kirby', 'Kirby,West Kirby', 53.3730200, -3.1841700, 'GB', '2014-09-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58061, 'West Kilbride', 'West Kilbride', 'Cille Bhrighde an Iar,Cille Bhrìghde an Iar,Cille Bhríghde an Iar,West Kilbride', 55.6900400, -4.8577100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58062, 'Westhoughton', 'Westhoughton', 'Westhoughton,wsthwtwn,وستهوتون', 53.5489900, -2.5246400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58063, 'West Horsley', 'West Horsley', '', 51.2603300, -0.4556300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58064, 'West Hallam', 'West Hallam', '', 52.9709300, -1.3584600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58065, 'West Haddon', 'West Haddon', 'West Haddon', 52.3416800, -1.0780400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58066, 'Westgate on Sea', 'Westgate on Sea', 'Vestgejt-on-Si,Westgate on Sea,Вестгейт-он-Си', 51.3823900, 1.3367300, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58067, 'Westfield', 'Westfield', '', 51.8833300, -1.8666700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58068, 'Westerham', 'Westerham', 'Westerham,wstrham,وسترهام', 51.2663200, 0.0689200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58069, 'West End', 'West End', '', 50.9274100, -1.3328200, 'GB', '2011-02-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58070, 'West Drayton', 'West Drayton', 'Drayton Thiar,West Drayton,vesta dretana,वेस्ट ड्रेटन', 51.5000000, -0.4666700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58071, 'Westcott', 'Westcott', '', 51.2243800, -0.3719500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58072, 'West Cornforth', 'West Cornforth', 'Cornforth,West Cornforth', 54.7028600, -1.5193800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58073, 'West Coker', 'West Coker', '', 50.9191200, -2.6870700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58074, 'West Clandon', 'West Clandon', '', 51.2606300, -0.5032300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58075, 'West Calder', 'West Calder', '', 55.8518800, -3.5698100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58076, 'West Byfleet', 'West Byfleet', 'West Byfleet', 51.3376400, -0.5064900, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58077, 'Westbury', 'Westbury', '', 52.6785600, -2.9543300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58078, 'Westbury', 'Westbury', 'Westbury i Wiltshire,wstbwry  wyltshr,wysbry,وستبوری، ویلتشر,ويسبري', 51.2600000, -2.1875000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58079, 'West Bromwich', 'West Bromwich', 'Bromwich Thiar,Uehst-Bromidzh,Uest Bromich,Vest Bromicas,Vest Bromičas,Vest Bromvich,Vest-Bromvich,West Bromwich,weseuteubeulomichi,west br xm mich,wst brwmwych,xi bu lang,xi bu luo mi qi,Вест Бромвич,Вест-Бромвіч,Уест Бромич,Уэст-Бромидж,Վեստ Բրոմվիչ,وست برومویچ,เวสต์บรอมมิช,ウェスト・ブロムウィッチ,西布朗,西布羅米奇,웨스트브로미치', 52.5186800, -1.9945000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58080, 'West Bridgford', 'West Bridgford', 'Uest Bridzhford,Vest Bridzford,West Bridgeford,West Bridgford,wst bryjfwrd,Вест Бриџфорд,Уест Бриджфорд,وست بریجفورد', 52.9297900, -1.1253700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58081, 'West Bergholt', 'West Bergholt', '', 51.9122100, 0.8498600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58082, 'Werrington', 'Werrington', '', 50.6666700, -4.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58083, 'Weobley', 'Weobley', '', 52.1596000, -2.8750000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58084, 'Wenvoe', 'Wenvoe', 'Wenvoe', 51.4477600, -3.2636900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58085, 'Wentworth', 'Wentworth', '', 53.4781600, -1.4150000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58086, 'Wendron', 'Wendron', 'Wendron,wndrn,وندرن', 50.1333300, -5.2500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58087, 'Wendover', 'Wendover', 'wndawr,ونداور', 51.7619400, -0.7398600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58088, 'Wemyss Bay', 'Wemyss Bay', 'Wemyss Bay', 55.8761400, -4.8895000, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58089, 'Wembury', 'Wembury', 'Wembury', 50.3227200, -4.0752900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58090, 'Wembley', 'Wembley', 'Uembli,Vembli,u~enburi,vembali,wembeulli,wen bu li,wmbly,Вембли,Уембли,ومبلی,ویمبلے,वेम्बली,ウェンブリー,温布利,웸블리', 51.5524200, -0.2968600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58091, 'Wem', 'Wem', 'wem,وم، شروپ‌شر,웸', 52.8583500, -2.7182600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58092, 'Welwyn Garden City', 'Welwyn Garden City', 'Garden City,Uehlin-Garden-Siti,Welvyn Garden City,Welwyn Garden,Welwyn Garden City,wei lin hua yuan shi,wellingadeunsiti,wlwyn gardn syty,Уэлин-Гарден-Сити,ولوین گاردن سیتی,ウェリン・ガーデン・シティ,韋林花園市,웰린가든시티', 51.8017400, -0.2069100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58093, 'Welwyn', 'Welwyn', 'Welwyn', 51.8331000, -0.2135900, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58094, 'Welton', 'Welton', 'Welton,Welton  East Yorkshire', 53.7321100, -0.5523200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58095, 'Welshpool', 'Welshpool', 'Uelshpul,Velspulas,Velšpulas,Welshpool,Y Trallwng,wei er shen pu er,welsipul,Уелшпул,韋爾什普爾,웰시풀', 52.6597300, -3.1471000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58096, 'Wells-next-the-Sea', 'Wells-next-the-Sea', 'Wells,Wells-next-the-Sea,Wells-on-Sea,wlz-nks-dh-sy,ولز-نکس-ده-سی', 52.9516400, 0.8511000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58097, 'Wells', 'Wells', 'Owels,Uehls,Velsas,Wellae,Wells,u~eruzu,wei er si,welseu,wlz,wlz  anglstan,Уэлс,Ուելս,ولز,ولز، انگلستان,ウェルズ,韋爾斯,웰스', 51.2079400, -2.6489600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58098, 'Wellow', 'Wellow', '', 51.3244400, -2.3741700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58099, 'Wellington', 'Wellington', 'Vellington,Wellington,Веллингтон', 52.7000000, -2.5166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58100, 'Wellington', 'Wellington', '', 52.1293400, -2.7421400, 'GB', '2017-06-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58101, 'Wellingborough', 'Wellingborough', 'Uehllingboro,Uelingburou,Velingboro,Vellingboro,Wellingborough,XWE,wei ling bo lei,Велингборо,Веллингборо,Уелингбъроу,Уэллингборо,ولینگ‌بورو,韋靈伯勒', 52.3027300, -0.6944600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58102, 'Welling', 'Welling', 'Welling,wylng,ویلنگ', 51.4624600, 0.1075900, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58103, 'Wellesbourne Mountford', 'Wellesbourne Mountford', '', 52.1924600, -1.6096700, 'GB', '2017-06-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58104, 'Wellesbourne', 'Wellesbourne', 'Wellesbourne,Wellesbourne Hastings', 52.1970900, -1.5905300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58105, 'Welford', 'Welford', 'Welford', 52.4170600, -1.0587100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58106, 'Welford', 'Welford', 'Welford', 51.4572700, -1.4113100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58107, 'Weeting', 'Weeting', 'Weeting', 52.4644000, 0.6148500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58108, 'Weedon Beck', 'Weedon Beck', 'Weedon,Weedon Bec,Weedon Beck', 52.2295500, -1.0837100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58109, 'Wednesfield', 'Wednesfield', 'Wednesfield', 52.5963000, -2.0850800, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58110, 'Wednesbury', 'Wednesbury', 'چرچ ہل، ویسٹ مڈلینڈز', 52.5514000, -2.0235500, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58111, 'Wedmore', 'Wedmore', '', 51.2272700, -2.8115200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58112, 'Weaverham', 'Weaverham', '', 53.2601800, -2.5729100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58113, 'Waverton', 'Waverton', '', 53.1666700, -2.8000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58114, 'Wavendon', 'Wavendon', '', 52.0254100, -0.6741100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58115, 'Watton at Stone', 'Watton at Stone', 'Watton,Watton at Stone', 51.8584200, -0.1138100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58116, 'Watton', 'Watton', '', 53.9333300, -0.4500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58117, 'Watton', 'Watton', 'Watton,Watton i Norfolk,watwn  nwrfk,واتون، نورفک', 52.5666700, 0.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58118, 'Wattisham', 'Wattisham', '', 52.1254300, 0.9386400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58119, 'Watlington', 'Watlington', 'watlyngtwn  aksfwrdshr,واتلینگتون، آکسفوردشر', 51.6432700, -1.0044800, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58120, 'Wath upon Dearne', 'Wath upon Dearne', 'Wath,Wath upon Dearne,Wath-on-Dearne', 53.5029100, -1.3458000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58121, 'Watford', 'Watford', 'Uotford,Votford,Votfordas,WXF,Watford,waspeodeu,watfwrd,watofodo,wo te fu de,wtpwrd,wwtpwrd,Вотфорд,Уотфорд,ווטפורד,וטפורד,واتفورد,ワトフォード,沃特福德,왓퍼드', 51.6553100, -0.3960200, 'GB', '2016-07-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58122, 'Water Orton', 'Water Orton', '', 52.5157500, -1.7400500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58123, 'Waterlooville', 'Waterlooville', 'Uoterluvil'',Voterluvil,Waterloo,Waterlooville,watrlwwyl,Вотерлувил,Уотерлувиль,واترلوویل', 50.8806700, -1.0304000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58124, 'Wateringbury', 'Wateringbury', '', 51.2554300, 0.4231700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58125, 'Waterbeach', 'Waterbeach', '', 52.2655300, 0.1912300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58126, 'Watchet', 'Watchet', 'Uochet,Watchet,watcht,Уочет,واتچت', 51.1818900, -3.3307900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58127, 'Washington', 'Washington', 'Vashington,Washington,Washington New Town,Washington i Tyne and Wear,hua sheng dun,washyngtn,Вашингтон,واشینگتن,華盛頓', 54.9000000, -1.5166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58128, 'Washington', 'Washington', '', 50.9048700, -0.4064900, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58129, 'Washingborough', 'Washingborough', 'Washingborough', 53.2242500, -0.4748500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58130, 'Warwick', 'Warwick', 'Uorik,Vorik,Vorikas,Warwick,Warwicum,u~orikku,wa li ke,wark,warwyk,wolig,wrk,Ворік,Уорик,وارویک,وارک,ورك,ウォリック,瓦立克,워릭', 52.2833300, -1.5833300, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58131, 'Warton', 'Warton', 'Warton', 54.1471500, -2.7643500, 'GB', '2016-05-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58132, 'Warton', 'Warton', 'WRT,Warton', 53.7498800, -2.8933500, 'GB', '2014-05-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58133, 'Warsop', 'Warsop', '', 53.2140200, -1.1509100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58134, 'Warrington', 'Warrington', 'Uorrington,Vorington,Warrington,waryngtwn,wo ling dun,wolingteon,Ворингтон,Уоррингтон,وارینگتون,沃灵顿,워링턴', 53.3925400, -2.5802400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58135, 'Warrington', 'Warrington', '', 52.1844600, -0.6875900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58136, 'Warrenpoint', 'Warrenpoint', 'An Phointe,Uorrenpojnt,Uorunpojnt,Уорренпойнт,Уорънпойнт', 54.1014800, -6.2573100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58137, 'Warnham', 'Warnham', 'Warnham', 51.0910700, -0.3484700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58138, 'Warminster', 'Warminster', 'Warminster,warmynstr,وارمینستر', 51.2043400, -2.1787300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58139, 'Warlingham', 'Warlingham', '', 51.3095300, -0.0579400, 'GB', '2015-07-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58140, 'Warkworth', 'Warkworth', 'Warkworth', 55.3500000, -1.6166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58141, 'Waringstown', 'Waringstown', '', 54.4343100, -6.2992900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58142, 'Wargrave', 'Wargrave', 'Wagrave,Wargrave,wrghrwf,ورغروف', 51.5006800, -0.8657700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58143, 'Warfield', 'Warfield', 'Warfield', 51.4421300, -0.7280200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58144, 'Wareham', 'Wareham', 'Ueurkham,Wareham,warham  dwrst,wei lei mu,Уеърхам,وارهام، دورست,韋勒姆', 50.6879200, -2.1105800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58145, 'Ware', 'Ware', 'wr  hrtfwrdshr,ور، هرتفوردشر', 51.8105800, -0.0287500, 'GB', '2014-12-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58146, 'Wardle', 'Wardle', 'Wardle', 53.6500000, -2.1333300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58147, 'Warden', 'Warden', '', 54.9833300, -2.1333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58148, 'Warboys', 'Warboys', 'Warboys', 52.4035200, -0.0793100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58149, 'Wantage', 'Wantage', 'Waneting,Wantage,wantj,وانتج', 51.5884600, -1.4256500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58150, 'Wansford', 'Wansford', '', 52.5785100, -0.4200100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58151, 'Wandsworth', 'Wandsworth', 'Borgo londinese di Wandsworth,Borough londonien de Wandsworth,Khu Wandsworth cua Luan GJon,Khu Wandsworth của Luân Đôn,London Borough of Wandsworth,Municipio de Wandsworth,Uondsuehrt,Vandsvorta,Vandzvert,Wandsworth,lndn bwrw wynڈzwrtھ,mntqh wandzwwrth lndn,vandsavartha baro,wandzwrth,wang zi wo si qu,wanjeuwoseu gu,wanzuwasu qu,wwndswwrt,Вандзверт,Уондсуэрт,וונדסוורת,לאנדאנער בארא פון וואנדזווערט,لندن بورو وینڈزورتھ,منطقه واندزوورث لندن,واندزورث,وینڈزورتھ,वंड्सवर्थ बरो,ワンズワース区,旺茲沃思區,완즈워스 구', 51.4577000, -0.2078400, 'GB', '2015-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58152, 'Wanborough', 'Wanborough', 'Wanborough', 51.5426300, -1.6983700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58153, 'Walworth', 'Walworth', '', 54.5666700, -1.6500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58154, 'Walton-on-Thames', 'Walton-on-Thames', 'Gouolton-on-Teims,Walton,Walton on Thames,watwn-an-tymz,Γουόλτον-ον-Τέιμς,واتون-آن-تیمز,والٹن-آن-ٹیمز', 51.3867800, -0.4131900, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58155, 'Walton-on-the-Naze', 'Walton-on-the-Naze', 'Walton-on-the-Naze,والٹن-آن-دی-نیز', 51.8481900, 1.2673800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58156, 'Walthamstow', 'Walthamstow', 'Uoltemstou,Uoltumstou,waltamstw,wo er se mu si tuo,Уолтемстоу,Уолтъмстоу,والتامستو,沃爾瑟姆斯托', 51.5906700, -0.0207700, 'GB', '2014-12-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58157, 'Waltham Cross', 'Waltham Cross', 'waltham kras,والتهام کراس', 51.6860200, -0.0357500, 'GB', '2015-07-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58158, 'Waltham Abbey', 'Waltham Abbey', 'Waltham Abbey,Waltham Abbey i Essex,waltham aby,والتهام ابی', 51.6870000, -0.0042100, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58159, 'Waltham', 'Waltham', '', 53.5166700, -0.1000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58160, 'Walsden', 'Walsden', 'Walsden', 53.6936100, -2.1000100, 'GB', '2017-07-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58161, 'Walsall', 'Walsall', 'Owolsol,Uolsol,Uolsoll,Volslas,Volsol,Walhshalh,Wallsall,Walsall,u~orusoru,walsal,wo er suo er,wolsol,Волсол,Уолсол,Уолсолл,Ուոլսոլ,والسال,ウォルソール,沃爾索爾,월솔', 52.5852800, -1.9839600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58162, 'Wallsend', 'Wallsend', 'Uolsend,Wallsend-on-Tyne,waysnd,wo er sen de,Уолсенд,وایسند,沃爾森德', 54.9911100, -1.5339700, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58163, 'Wallingford', 'Wallingford', 'Vollingford,Wallingford,walyngfwrd  aksfwrdshr,wollingpeodeu,Воллінгфорд,والینگفورد، آکسفوردشر,월링퍼드', 51.5998200, -1.1248000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58164, 'Wallasey', 'Wallasey', 'Uollasi,Volasi,Wallasey,walasy,wo lei xi,wolleosi,Воласи,Уолласи,والاسی,沃勒西,월러시', 53.4232400, -3.0649700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58165, 'Wall', 'Wall', '', 55.0000000, -2.1333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58166, 'Walkington', 'Walkington', '', 53.8195000, -0.4895800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58167, 'Walkern', 'Walkern', '', 51.9188800, -0.1275800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58168, 'Walkden', 'Walkden', 'Walkden', 53.5166700, -2.4000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58169, 'Walford', 'Walford', '', 51.8833300, -2.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58170, 'Wales', 'Wales', 'Uehl''s,Wales,Уэльс', 53.3406100, -1.2816200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58171, 'Walberton', 'Walberton', 'Walberton', 50.8447500, -0.6201300, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58172, 'Wakefield', 'Wakefield', 'Uehjkfild,Uejkfijld,Veikfildas,Vejkfild,Wakefield,XWD,u~eikufirudo,wei ke fei er de,weikeupildeu,wykfyld,Вејкфилд,Уейкфийлд,Уэйкфилд,Ուեյքֆիլդ,ويكفيلد,ウェイクフィールド,韦克菲尔德,웨이크필드', 53.6833100, -1.4976800, 'GB', '2010-10-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58173, 'Wainfleet All Saints', 'Wainfleet All Saints', 'Wainfleet,Wainfleet All Saints', 53.1057000, 0.2358300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58174, 'Wadworth', 'Wadworth', 'Wadsworth,Wadworth', 53.4672600, -1.1426100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58175, 'Wadhurst', 'Wadhurst', 'wadhwrst,وادهورست', 51.0623000, 0.3392900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58176, 'Wadebridge', 'Wadebridge', 'Ponsrys,Wadebridge,wadbryj,وادبریج', 50.5173400, -4.8363300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58177, 'Waddington', 'Waddington', '', 53.8897700, -2.4145900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58178, 'Waddington', 'Waddington', 'WTN,Waddington', 53.1666700, -0.5333300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58179, 'Waddesdon', 'Waddesdon', 'Waddesdon,wdsdn,ودسدن', 51.8467500, -0.9210500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58180, 'Wacton', 'Wacton', '', 52.2166700, -2.5666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58181, 'Victoria', 'Victoria', '', 51.7500000, -3.2000000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58182, 'Verwood', 'Verwood', 'wrwwd,وروود', 50.8757500, -1.8702300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58183, 'Ventnor', 'Ventnor', 'Jentnor,Ventnor,wntnwr,Вентнор,ونتنور', 50.5944900, -1.2067200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58184, 'Valley', 'Valley', '', 53.2849000, -4.5664400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58185, 'Uxbridge', 'Uxbridge', '"ksbridzh,aksabrija,wu ke si qiao,Ъксбридж,अक्सब्रिज,烏克斯橋', 51.5489000, -0.4821100, 'GB', '2015-02-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58186, 'Uttoxeter', 'Uttoxeter', '"ksutur,awtwkstr,Ъксътър,اوتوکستر', 52.8983800, -1.8648800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58187, 'Usk', 'Usk', '"sk,Ask,Brynbuga,Usk,a si ke,Аск,Ъск,阿斯克', 51.7034700, -2.9033200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58188, 'Ushaw Moor', 'Ushaw Moor', 'Ushaw Moor', 54.7780300, -1.6472000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58189, 'Urmston', 'Urmston', 'Urmston', 53.4485200, -2.3541900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58190, 'Upwell', 'Upwell', '', 52.6024900, 0.2219000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58191, 'Upton upon Severn', 'Upton upon Severn', 'Upton,Upton upon Severn,Upton-on-Severn', 52.0625800, -2.2180200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58192, 'Upton Scudamore', 'Upton Scudamore', '', 51.2300000, -2.1933300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58193, 'Upton', 'Upton', '', 53.6146600, -1.2867700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58194, 'Upton', 'Upton', '', 52.5906100, -0.3693500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58195, 'Uppingham', 'Uppingham', '"pingam,apyngham,Ъпингам,آپینگهام', 52.5880300, -0.7227200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58196, 'Upper Poppleton', 'Upper Poppleton', 'Poppleton,Upper Poppleton', 53.9790700, -1.1520400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58197, 'Upper Langwith', 'Upper Langwith', 'Langwith,Upper Langwith', 53.2291900, -1.2069500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58198, 'Upminster', 'Upminster', '"pminstur,appuminsuta,Ъпминстър,アップミンスター', 51.5559400, 0.2556000, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58199, 'Upchurch', 'Upchurch', '', 51.3762000, 0.6478900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58200, 'Uny Lelant', 'Uny Lelant', 'Lelant,Uny Lelant', 50.1829800, -5.4404700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58201, 'Undy', 'Undy', 'Undy', 51.5752600, -2.8145300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58202, 'Ulverston', 'Ulverston', '"lvurstun,Ulverston,Ulverstone,a er fu si dun,awlrstwn,Ълвърстън,اولرستون,阿爾弗斯頓', 54.1959400, -3.0962600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58203, 'Ulrome', 'Ulrome', '', 53.9919800, -0.2296800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58204, 'Ulley', 'Ulley', '', 53.3820000, -1.3022200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58205, 'Ullapool', 'Ullapool', 'Alapulas,Allapul,Ulapul,Ulapulis,Ullapool,Ullapul,a lei pu,Аллапул,阿勒浦', 57.8987200, -5.1603900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58206, 'Ulceby', 'Ulceby', '', 53.6166700, -0.3333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58207, 'Ufford', 'Ufford', '', 52.6237900, -0.3843500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58208, 'Uffculme', 'Uffculme', 'Uffculme', 50.9060400, -3.3274600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58209, 'Uddingston', 'Uddingston', 'Uddingston', 55.8197100, -4.0836200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58210, 'Uckfield', 'Uckfield', '"kfijld,awkfyld,Ъкфийлд,اوکفیلد', 50.9694800, 0.0958900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58211, 'Tytherington', 'Tytherington', 'Tytherington', 51.5925000, -2.4797200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58212, 'Tynemouth', 'Tynemouth', 'Tynemouth,tai en mao si,taymwth,تایموث,泰恩茅斯', 55.0178800, -1.4255900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58213, 'Tyldesley', 'Tyldesley', '', 53.5139300, -2.4675400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58214, 'Tycroes', 'Tycroes', 'Tycroes', 51.7780600, -4.0200000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58215, 'Tyberton', 'Tyberton', '', 52.0455000, -2.9041400, 'GB', '2015-02-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58216, 'Twyford', 'Twyford', 'Twyford', 51.4751800, -0.8603700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58217, 'Twickenham', 'Twickenham', 'Tuikenem,Tvikehnehm,Tvikenem,teuwikeuneom,to~uikkenamu,tvikanahama,twyknham,twyynkham,Твікенем,Твікэнэм,Туикенем,تويكنهام,تویینکهام,ट्विकनहम,トゥイッケナム,트위크넘', 51.4448900, -0.3377000, 'GB', '2015-05-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58218, 'Tuxford', 'Tuxford', 'Tuxford', 53.2300400, -0.8932500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58219, 'Turriff', 'Turriff', 'Baile Thurra,Torraibh,Turif,Turra,Търиф', 57.5384000, -2.4593200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58220, 'Turnastone', 'Turnastone', '', 52.0239800, -2.9483300, 'GB', '2015-02-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58221, 'Truro', 'Truro', 'Trouro,Truro,Truru,te lu luo,teululo,to~ururo,trwrw,Τρούρο,Труро,Տրուրո,טרורא,ترورو,ٹرورو,トゥルーロ,特魯羅,트루로', 50.2652600, -5.0543600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58222, 'Trowbridge', 'Trowbridge', 'Troubridzh,Troubridzhe,Trowbridge,te luo bu li qi,teulobeuliji,trwbrydj,trwbryj,Троубридж,Троубридже,تروبريدج,تروبریج,特羅布里奇,트로브리지', 51.3188900, -2.2086100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58223, 'Troon', 'Troon', 'An t-Sron,An t-Sròn,An t-Srón,The Truin,Trun,te lun,Трун,特伦', 55.5435900, -4.6633500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58224, 'Tring', 'Tring', 'Tring,tryng,Тринг,ترینگ', 51.7947100, -0.6582400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58225, 'Trimdon Grange', 'Trimdon Grange', 'Trimdon Grange', 54.7141400, -1.4261100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58226, 'Trimdon', 'Trimdon', '', 54.6987800, -1.4288100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58227, 'Trewen', 'Trewen', '', 50.6166700, -4.4666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58228, 'Treuddyn', 'Treuddyn', 'Treuddyn,Tryddyn', 53.1148000, -3.1200300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58229, 'Treorchy', 'Treorchy', 'Treorchy,Treorci,Treorky', 51.6595800, -3.5058700, 'GB', '2015-01-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58230, 'Trelech', 'Trelech', 'Trelech,Ty-newydd-trelech', 51.9444400, -4.5000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58231, 'Treherbert', 'Treherbert', '', 51.6713900, -3.5297200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58232, 'Treharris', 'Treharris', '', 51.6645700, -3.3072500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58233, 'Tregoney', 'Tregoney', '', 50.2674000, -4.9164700, 'GB', '2015-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58234, 'Tregarth', 'Tregarth', 'Tregarth,Tregorth', 53.1901200, -4.0878000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58235, 'Tregaron', 'Tregaron', 'Caron-is-Clawdd,Tregaron,Трегарон', 52.2195000, -3.9329500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58236, 'Trefnant', 'Trefnant', 'Trefnant', 53.2252600, -3.4203000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58237, 'Treeton', 'Treeton', '', 53.3856400, -1.3518900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58238, 'Tredegar', 'Tredegar', 'Tredegar,te lei di jia,Тредегар,特雷迪加', 51.7725100, -3.2467900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58239, 'Trawsfynydd', 'Trawsfynydd', 'Trawsfynydd', 52.9021200, -3.9228900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58240, 'Tranent', 'Tranent', 'Tranent', 55.9443900, -2.9541200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58241, 'Trafford Park', 'Trafford Park', 'trafwrd park,traipharda parka,ترافورد پارک,ट्रैफर्ड पार्क', 53.4687900, -2.3119400, 'GB', '2010-09-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58242, 'Townhill', 'Townhill', 'Townhill', 56.0891000, -3.4388900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58243, 'Tow Law', 'Tow Law', 'Tow Law', 54.7445600, -1.8143400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58244, 'Towcester', 'Towcester', 'Toustur,tawkstr,Тоустър,تاوکستر', 52.1335900, -0.9905700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58245, 'Totton', 'Totton', '', 50.9187700, -1.4903700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58246, 'Tottington', 'Tottington', '', 53.6132600, -2.3407100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58247, 'Totternhoe', 'Totternhoe', '', 51.8855500, -0.5734300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58248, 'Totnes', 'Totnes', 'Totenais,Totnes,Totnis,Tottaness,twtns,Тотнес,Тотнис,توتنس', 50.4310700, -3.6843000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58249, 'Totland', 'Totland', 'Totland', 50.6846600, -1.5368800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58250, 'Torquay', 'Torquay', 'Torcaium,Torki,Torkvej,Torquay,toki,tuo ji,twrky,twrqy,Торквей,Торки,Торкі,טורקי,تورکی,トーキー,托基,토키', 50.4619800, -3.5252200, 'GB', '2017-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58251, 'Torpoint', 'Torpoint', 'Penntorr,Torpoint,twrpwynt,تورپوینت', 50.3750500, -4.1956600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58252, 'Torphins', 'Torphins', 'Torphins', 57.1056100, -2.6239800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58253, 'Topsham', 'Topsham', 'twpsham  dwwn,توپشام، دوون', 50.6859600, -3.4669600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58254, 'Tonyrefail', 'Tonyrefail', '', 51.5840200, -3.4304100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58255, 'Tong', 'Tong', '', 52.6666700, -2.3000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58256, 'Tonbridge', 'Tonbridge', 'Tonbridge,Tonbridzh,twnbryj,Тонбридж,تونبریج', 51.1953200, 0.2736300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58257, 'Tolleshunt Knights', 'Tolleshunt Knights', '', 51.7986900, 0.7765100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58258, 'Tollesbury', 'Tollesbury', '', 51.7591300, 0.8346200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58259, 'Todwick', 'Todwick', '', 53.3537300, -1.2567300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58260, 'Todmorden', 'Todmorden', 'Todmorden,twdmwrdn,تودموردن', 53.7143400, -2.0970100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58261, 'Toddington', 'Toddington', 'tddynghtwn,تددينغتون', 51.9492200, -0.5327700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58262, 'Tobermory', 'Tobermory', 'Tobar Mhoire,Tobermori,twbrmwry,Тобермори,טוברמורי', 56.6219800, -6.0723100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58263, 'Tiverton', 'Tiverton', '', 53.1333300, -2.6666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58264, 'Tiverton', 'Tiverton', 'Tiverton,Tiverton i Devon,Tivertonia,Tivurtun,tywrtwn  dwwn,Тивъртън,تیورتون، دوون', 50.9024100, -3.4923200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58265, 'Tisbury', 'Tisbury', 'tysbwry  wyltshr,تیسبوری، ویلتشر,ٹسبری، ویلٹشائر', 51.0628300, -2.0805800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58266, 'Tiptree', 'Tiptree', '', 51.8123000, 0.7454000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58267, 'Tipton', 'Tipton', 'typtwn,تیپتون', 52.5295600, -2.0677300, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58268, 'Tinwell', 'Tinwell', 'Tinwell', 52.6462900, -0.5149800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58269, 'Tingewick', 'Tingewick', '', 51.9903100, -1.0480400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58270, 'Timsbury', 'Timsbury', '', 51.3244400, -2.4791700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58271, 'Timperley', 'Timperley', 'Timperley', 53.4000000, -2.3333300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58272, 'Tillicoultry', 'Tillicoultry', '', 56.1525100, -3.7401500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58273, 'Tilehurst', 'Tilehurst', '', 51.4564700, -1.0437000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58274, 'Tilbury', 'Tilbury', 'Tilbury,Tilbury Fort,tylbwry,تیلبوری', 51.4624800, 0.3585600, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58275, 'Tideswell', 'Tideswell', '', 53.2780700, -1.7729200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58276, 'Tickton', 'Tickton', '', 53.8623300, -0.3833000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58277, 'Tickhill', 'Tickhill', '', 53.4319400, -1.1085900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58278, 'Tickencote', 'Tickencote', 'Tickencote', 52.6750300, -0.5369600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58279, 'Ticehurst', 'Ticehurst', '', 51.0465200, 0.4086000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58280, 'Tibshelf', 'Tibshelf', 'Tibshelf', 53.1443600, -1.3405600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58281, 'Thwing', 'Thwing', '', 54.1154700, -0.3895000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58282, 'Thurston', 'Thurston', 'Thurston', 52.2524400, 0.8074900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58283, 'Thurso', 'Thurso', 'Inbhir Theorsa,Inbhir Theòrsa,Inbhir Theórsa,Terso,Thursa,Thurso,saso,se suo,Терсо,サーソー,瑟索', 58.5927100, -3.5259400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58284, 'Thurlton', 'Thurlton', 'Thurlton', 52.5288100, 1.5561700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58285, 'Thurlby', 'Thurlby', '', 52.7387900, -0.3786800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58286, 'Thruxton', 'Thruxton', '', 52.0000000, -2.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58287, 'Three Legged Cross', 'Three Legged Cross', '', 50.8500000, -1.8833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58288, 'Thrapston', 'Thrapston', 'trapstwn,تراپستون', 52.3967500, -0.5392000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58289, 'Thorpe le Soken', 'Thorpe le Soken', '', 51.8560300, 1.1658000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58290, 'Thorp Arch', 'Thorp Arch', 'Thorp Arch,Thorpe Arch', 53.9158400, -1.3198000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58291, 'Thornton Heath', 'Thornton Heath', 'Thornton Heath', 51.3988400, -0.0987200, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58292, 'Thornton Dale', 'Thornton Dale', 'Thornton Dale,Thornton-le-Dale', 54.2352800, -0.7201600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58293, 'Thornton', 'Thornton', 'Thornton', 56.1666700, -3.1500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58294, 'Thornton', 'Thornton', '', 53.9000000, -0.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58295, 'Thornton', 'Thornton', '', 53.5000000, -3.0000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58296, 'Thornley', 'Thornley', '', 54.7500000, -1.4333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58297, 'Thornhill', 'Thornhill', 'Thornhill', 55.2333300, -3.7666700, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58298, 'Thornhaugh', 'Thornhaugh', 'Thornhaugh', 52.5925200, -0.4241800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58299, 'Thorngumbald', 'Thorngumbald', 'Thorngumbald,Thorngumbold', 53.7210000, -0.1717500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58300, 'Thorney', 'Thorney', '', 52.6214700, -0.1081500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58301, 'Thorner', 'Thorner', '', 53.8609300, -1.4267600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58302, 'Thorne', 'Thorne', 'Thorne,تورن، یورک‌شر جنوبی', 53.6112200, -0.9630800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58303, 'Thornbury', 'Thornbury', '', 52.2333300, -2.5500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58304, 'Thornbury', 'Thornbury', 'Thornbury i South Gloucestershire,Tornburi,Торнбъри', 51.6088900, -2.5202800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58305, 'Thornaby-on-Tees', 'Thornaby-on-Tees', 'Thornaby,Thornaby on Tees,twrnaby-an-tyn,تورنابی-آن-تین', 54.5333300, -1.3000000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58306, 'Thixendale', 'Thixendale', 'Thixendale', 54.0434900, -0.7182700, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58307, 'Thirsk', 'Thirsk', 'XTK,trysk,تریسک', 54.2329800, -1.3441100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58308, 'Thimbleby', 'Thimbleby', '', 53.2127100, -0.1437200, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58309, 'Theydon Bois', 'Theydon Bois', '', 51.6742600, 0.0978100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58310, 'Thetford', 'Thetford', 'Tetford,Thetford,ttfwrd,Тетфорд,تتفورد,ጤትፎርድ', 52.4166700, 0.7500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58311, 'Theale', 'Theale', '', 51.4369400, -1.0770000, 'GB', '2011-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58312, 'Thaxted', 'Thaxted', 'takstd,تاکستد', 51.9532600, 0.3447800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58313, 'Thatcham', 'Thatcham', 'Thatcham,tachham,تاچهام', 51.4036600, -1.2604900, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58314, 'Thames Ditton', 'Thames Ditton', '', 51.3896400, -0.3392800, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58315, 'Thame', 'Thame', 'Thame,tym  aksfwrdshr,تیم، آکسفوردشر', 51.7484000, -0.9762400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58316, 'Teynham', 'Teynham', '', 51.3304500, 0.8052600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58317, 'Tewkesbury', 'Tewkesbury', 'T''juksberi,Tewkesbury,Theoci Curia,Tjuksburi,twksbwry,Тьюксбери,Тюксбъри,توکسبوری', 51.9924400, -2.1601000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58318, 'Tetney', 'Tetney', 'Tetney', 53.4923900, -0.0210600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58319, 'Tetbury', 'Tetbury', 'Tetbury,ttbwry,تتبوری', 51.6394400, -2.1622200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58320, 'Terrington Saint John', 'Terrington Saint John', '', 52.7054600, 0.2738900, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58321, 'Terrington St Clement', 'Terrington St Clement', 'Terrington,Terrington Saint Clement,Terrington St Clement', 52.7581300, 0.2973200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58322, 'Tenterden', 'Tenterden', 'Tenterden,tntrdn,تنتردن', 51.0684500, 0.6877600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58323, 'Tenby', 'Tenby', 'Dinbych-y-Pysgod,Dinbych-y-pysgod,Tenbi,Tenby,tynby,Тенби,تينبي', 51.6727900, -4.7044700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58324, 'Tenbury Wells', 'Tenbury Wells', 'Tenbury,tnbwry wlz,تنبوری ولز', 52.3107700, -2.5962100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58325, 'Tempsford', 'Tempsford', '', 52.1705100, -0.2958600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58326, 'Templeton', 'Templeton', 'Templeton', 51.7719400, -4.7377800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58327, 'Templepatrick', 'Templepatrick', 'Templepatrick', 54.6833300, -6.0833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58328, 'Templecombe', 'Templecombe', '', 50.9990800, -2.4157800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58329, 'Teignmouth', 'Teignmouth', 'Taba,Teignmouth,Tinmut,tynmwth,Тинмут,Тінмут,Թինմութ,تینموث', 50.5476800, -3.4963700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58330, 'Teddington', 'Teddington', 'Teddington,tedingatana,टेडिंगटन', 51.4223300, -0.3305300, 'GB', '2012-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58331, 'Tayport', 'Tayport', 'Ferry Port-on-Craig', 56.4469900, -2.8796600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58332, 'Tavistock', 'Tavistock', 'Taefingstoc,Tavistochia,Tavistok,Tæfingstoc,taebiseutog,tafystwk,tavu~isutokku,tawystwk  dwwn,Тависток,تافيستوك,تاویستوک، دوون,タヴィストック,태비스톡', 50.5494400, -4.1441800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58333, 'Taunton', 'Taunton', 'TTY,Tantonia,Taunton,Tonton,Tountun,tang dun,tawntwn,tonteon,tonton,Тонтон,Тоунтън,تاونتون,ولٹن، سومرسیٹ,トーントン,湯頓,톤턴', 51.0149400, -3.1029300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58334, 'Tattenhall', 'Tattenhall', '', 53.1218800, -2.7674600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58335, 'Tarvin', 'Tarvin', 'twrfyn,تورفين', 53.1973700, -2.7654800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58336, 'Tarporley', 'Tarporley', 'trbrly,تربرلي', 53.1591800, -2.6686700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58337, 'Tarleton', 'Tarleton', 'Tarleton', 53.6800500, -2.8296800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58338, 'Tarbolton', 'Tarbolton', 'Tarbolton', 55.5129200, -4.4864800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58339, 'Tarbert', 'Tarbert', '', 55.8627700, -5.4162200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58340, 'Tansley', 'Tansley', 'Tansley', 53.1319700, -1.5188200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58341, 'Tangmere', 'Tangmere', '', 50.8513100, -0.7163300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58342, 'Tanfield', 'Tanfield', '', 54.8928800, -1.7131600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58343, 'Tandragee', 'Tandragee', 'Tanderagee', 54.3548600, -6.4139600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58344, 'Tamworth', 'Tamworth', 'Tamvertas,Tamvort,Tamworth,Tomtun,ta mu wo si,Тамворт,تم‌وورث، استافوردشایر,塔姆沃思', 52.6339900, -1.6958700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58345, 'Talgarth', 'Talgarth', 'Talgart,Talgarth,Талгарт', 51.9958800, -3.2320500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58346, 'Takeley', 'Takeley', '', 51.8708900, 0.2658300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58347, 'Tain', 'Tain', 'Baile Dhubhthaich,Tain,tai en,泰恩', 57.8090300, -4.0599100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58348, 'Taibach', 'Taibach', 'Taibach', 51.5833300, -3.7666700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58349, 'Tadworth', 'Tadworth', '', 51.2916900, -0.2358200, 'GB', '2014-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58350, 'Tadley', 'Tadley', 'tadly,تادلی', 51.3504500, -1.1285000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58351, 'Tadcaster', 'Tadcaster', 'Tadcaster,Tadkaster,tadkastr,Тадкастер,تادکاستر', 53.8832200, -1.2634400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58352, 'Sywell', 'Sywell', '', 52.2985600, -0.7972800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58353, 'Syston', 'Syston', 'Syston,systwn,سیستون', 52.6833300, -1.0666700, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58354, 'Symington', 'Symington', 'Symington', 55.5517600, -4.5583500, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58355, 'Swinton', 'Swinton', 'Swinton', 53.5000000, -2.3500000, 'GB', '2013-12-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58356, 'Swineshead', 'Swineshead', '', 52.9454300, -0.1594700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58357, 'Swineshead', 'Swineshead', '', 52.2802900, -0.4501000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58358, 'Swindon', 'Swindon', 'Swindon Village', 51.9236300, -2.0983900, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58359, 'Swindon', 'Swindon', 'SWI,Suindon,Suindun,Svindon,Svindonas,Swindon,XWS,s win dan,seuwindeon,si wen dun,suu~indon,swyndwn,swyyndwn,Свиндон,Свіндон,Суиндон,Суиндън,Սուինդոն,سوئیندون,سويندون,สวินดัน,スウィンドン,斯温顿,스윈던', 51.5579700, -1.7811600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58360, 'Swillington', 'Swillington', '', 53.7684600, -1.4175000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58361, 'Sway', 'Sway', 'Sway', 50.7868500, -1.6029400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58362, 'Swavesey', 'Swavesey', '', 52.3015500, -0.0047600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58363, 'Swansea', 'Swansea', 'Abertawe,SWS,Souonsi,Suonsi,Suonzi,Svonsi,Svonsis,Svonzi,Swansea,s wxn si,seuwanji,si wang xi,suuae~onji,suu~onji,svanzi,svonjhi,swansy,swanzy,swwnsy,Σουόνσι,Свонзи,Свонсі,Суонзи,Суонси,Սուոնսի,סוונסי,سوانزي,سوانزی,سوانسی,स्वान्ज़ी,स्वॉन्झी,สวอนซี,スウæォンジ,スウォンジ,斯旺西,스완지', 51.6207900, -3.9432300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58364, 'Swanscombe', 'Swanscombe', 'Swanscombe', 51.4471300, 0.3102800, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58365, 'Swanmore', 'Swanmore', '', 50.9440400, -1.1802100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58366, 'Swanley', 'Swanley', 'swanly,سوانلی', 51.3971700, 0.1732100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58367, 'Swanage', 'Swanage', 'Suonidzh,swanj,Суонидж,سوانج', 50.6092300, -1.9626000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58368, 'Swallowfield', 'Swallowfield', '', 51.3787500, -0.9580400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58369, 'Swaffham', 'Swaffham', 'aswafham,اسوافهام', 52.6477000, 0.6857000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58370, 'Swadlincote', 'Swadlincote', 'Swadlincote', 52.7740000, -1.5574400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58371, 'Sutton upon Derwent', 'Sutton upon Derwent', 'Sutton,Sutton upon Derwent', 53.9131400, -0.9246500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58372, 'Sutton on Trent', 'Sutton on Trent', 'Sutton,Sutton on Trent,Sutton upon Trent', 53.1843700, -0.8109100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58373, 'Sutton in Ashfield', 'Sutton in Ashfield', 'Sutton in Ashfield', 53.1254200, -1.2613500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58374, 'Sutton Courtenay', 'Sutton Courtenay', 'Sutton Courtenay', 51.6413000, -1.2768200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58375, 'Sutton Coldfield', 'Sutton Coldfield', 'Saton Koldfild,Saton Koldfildas,Sutton Coldfield,satn kwldfyld,seoteonkoldeupildeu,Сатон Колдфилд,ساتن کولدفیلد,サットン・コールドフィールド,서턴콜드필드', 52.5666700, -1.8166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58376, 'Sutton Bridge', 'Sutton Bridge', 'Saton Bridzas,Saton Bridžas,Sutton Bridge', 52.7699500, 0.1855000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58377, 'Sutton Bonington', 'Sutton Bonington', 'Sutton Bonington', 52.8214400, -1.2496900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58378, 'Sutton Benger', 'Sutton Benger', '', 51.5068500, -2.0801500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58379, 'Sutton', 'Sutton', '', 52.3880400, 0.1186600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58380, 'Sutton', 'Sutton', '', 52.1000000, -2.6833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58381, 'Sutton', 'Sutton', '', 52.1107800, -0.2138000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58382, 'Sutton', 'Sutton', 'London Borough of Sutton,Satton,Sutton,Sutton keruelet,Sutton kerület,Саттон', 51.3500000, -0.2000000, 'GB', '2014-04-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58383, 'Sutterton', 'Sutterton', '', 52.9026900, -0.0923500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58384, 'Sunningdale', 'Sunningdale', 'swnynghdl,سونينغدل', 51.3987800, -0.6294400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58385, 'Sunk Island', 'Sunk Island', '', 53.6516800, -0.0840700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58386, 'Sundridge', 'Sundridge', 'Sundridge', 51.2779700, 0.1223100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58387, 'Sunderland', 'Sunderland', 'Sanderland,Sanderlandas,Sanderlend,Sanderlenda,Santerlant,Sunderland,Sundurland,sandaralamda,sandarando,sandrlnd,sandrlnd  tayn w wr,sang de lan,seondeollaendeu,sndrland,sndrlnd,Σάντερλαντ,Сандерланд,Сандерленд,Съндърланд,Սանդերլենդ,סנדרלנד,ساندرلند,ساندرلند، تاین و ور,سندرلاند,संडरलँड,サンダーランド,桑德兰,선덜랜드', 54.9046500, -1.3822200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58388, 'Sunbury-on-Thames', 'Sunbury-on-Thames', 'Sunbury,Sunbury-on-Thames', 51.4042400, -0.4181700, 'GB', '2014-09-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58389, 'Sudbury', 'Sudbury', '', 52.0389000, 0.7311700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58390, 'Sudbrooke', 'Sudbrooke', 'Sudbrooke', 53.2666700, -0.4500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58391, 'Sturry', 'Sturry', '', 51.3013200, 1.1215500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58392, 'Sturminster Newton', 'Sturminster Newton', 'astwrmynstr nywtwn,استورمینستر نیوتون', 50.9268100, -2.3051500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58393, 'Sturminster Marshall', 'Sturminster Marshall', '', 50.7996800, -2.0761500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58394, 'Studley', 'Studley', '', 52.2702600, -1.8918800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58395, 'Stroud', 'Stroud', 'Straud,Stroud,astrwd  glastrshr,seuteulaudeu,Страуд,استرود، گلاسترشر,스트라우드', 51.7500000, -2.2000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58396, 'Strood', 'Strood', 'astrwd  knt,استرود، کنت', 51.3932300, 0.4771300, 'GB', '2015-07-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58397, 'Stromness', 'Stromness', 'Hamnavoe,Sroimnis,Sróimnis,Straumnes,Stromnaes,Stromnes,Stromness,Stromnæs,Strømnes,seuteulomniseu,si te luo mu nei si,strwmns,Стромнесс,סטרומנס,斯特罗姆内斯,스트롬니스', 58.9649800, -3.2960100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58398, 'Stretton', 'Stretton', '', 53.3333300, -2.5666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58399, 'Stretham', 'Stretham', 'Stretham,strtham,سترتهام', 52.3470900, 0.2185200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58400, 'Stretford', 'Stretford', 'Stretford,strtfwrd,strtpwrd,Стретфорд,סטרטפורד,سترتفورد', 53.4500000, -2.3166700, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58401, 'Strensall', 'Strensall', '', 54.0399900, -1.0351200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58402, 'Streetly', 'Streetly', 'Streetly', 52.5833300, -1.8833300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58403, 'Street', 'Street', 'Street', 51.1247200, -2.7400000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58404, 'Streatley', 'Streatley', '', 51.9462800, -0.4437400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58405, 'Strathpeffer', 'Strathpeffer', 'Strathpeffer', 57.5852200, -4.5419500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58406, 'Strathblane', 'Strathblane', 'Strath Bhlathain,Strath Bhlàthain,Strath Bhláthain', 55.9859600, -4.3065800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58407, 'Strathaven', 'Strathaven', 'Srath Abhainn,Strath Aibhne,Strathaven', 55.6771000, -4.0668000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58408, 'Stratford-upon-Avon', 'Stratford-upon-Avon', 'Gorad Stratfard-on-Ehjvan,Stratford,Stratford na Ejv"n,Stratford na Ejvonu,Stratford on Avon,Stratford-Ehjvonekh'',Stratford-apon-Ehjvon,Stratford-na-Ehjvone,Stratford-upon-Avon,Stratfordia super Avonam,Stretford-na-Ejvoni,ai wen he pan si te la te fu,astratfwrd,seuteulaespeodeueopon-eibeon,stratfwrd,sutoratofodo=apon=eivu~on,Горад Стратфард-он-Эйван,Стратфорд на Ейвън,Стратфорд на Ејвону,Стратфорд-Эйвонехь,Стратфорд-апон-Эйвон,Стратфорд-на-Эйвоне,Стретфорд-на-Ейвоні,استراتفورد,ستراتفورد,စထရက်ဖို့အက်ပွန်းဧဗွန်မြို့,ストラトフォード＝アポン＝エイヴォン,埃文河畔斯特拉特福,스트랫퍼드어폰에이번', 52.1916600, -1.7073400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58409, 'Stratfield Mortimer', 'Stratfield Mortimer', 'Mortimer,Stratfield Mortimer', 51.3733900, -1.0349500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58410, 'Stranraer', 'Stranraer', 'An t-Sron Reamhar,An t-Sròn Reamhar,Stanraer,Stranraer,Stranrar,Stranrawer,Странрар', 54.9023400, -5.0273100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58411, 'Stradbroke', 'Stradbroke', '', 52.3181900, 1.2727800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58412, 'Strabane', 'Strabane', 'An Srath Ban,An Srath Bán,Straban,si te la ban,Страбан,斯特拉班', 54.8237300, -7.4691600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58413, 'Stow on the Wold', 'Stow on the Wold', 'Stow on the Wold', 51.9300800, -1.7238200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58414, 'Stowmarket', 'Stowmarket', 'astwmarkt,استومارکت', 52.1889300, 0.9977400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58415, 'Stourport-on-Severn', 'Stourport-on-Severn', 'Stourport,Stourport-on-Severn,astwrpwrt-an-swrn,استورپورت-آن-سورن', 52.3397600, -2.2803400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58416, 'Stourbridge', 'Stourbridge', 'Stauerbridz,Stauerbridzas,Stauerbridžas,Staurbridzh,Stourbridge,Stourbridzh,astawrbryj,s tea r bridc,Стауербриџ,Стаурбридж,Стоурбридж,استاوربریج,สเตาร์บริดจ์', 52.4560800, -2.1431700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58417, 'Stotfold', 'Stotfold', '', 52.0163200, -0.2320900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58418, 'Storrington', 'Storrington', 'Storrington', 50.9176500, -0.4547300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58419, 'Stornoway', 'Stornoway', 'SYY,Steornabhagh,Steornavaie,Steòrnabhagh,Steórnabhagh,Stornavey,Stornovej,Stornovejus,Stornovėjus,Stornoway,seutoneowei,si tuo nuo wei,sutonou~ei,Сторновей,ストーノーウェイ,斯托诺韦,스토너웨이', 58.2092500, -6.3864900, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58420, 'Stony Stratford', 'Stony Stratford', 'Stony Stratford,astwny astrtfwrd,stwny stafwrd,استونی استرتفورد,ستوني ستافورد', 52.0568200, -0.8528100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58421, 'Stoney Stanton', 'Stoney Stanton', 'Stoney Stanton', 52.5483900, -1.2793000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58422, 'Stone', 'Stone', '', 51.4503200, 0.2647000, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58423, 'Stonesfield', 'Stonesfield', 'Stonesfield', 51.8514200, -1.4296000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58424, 'Stonehouse', 'Stonehouse', '', 55.6943500, -3.9878000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58425, 'Stonehouse', 'Stonehouse', 'Stonehouse', 51.7500000, -2.2833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58426, 'Stonehaven', 'Stonehaven', 'Cala na Creige,Stanehyve,Stongejven,Stonhevenas,Стонгейвен', 56.9636500, -2.2117700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58427, 'Stone', 'Stone', 'Stone i Staffordshire', 52.9059000, -2.1540900, 'GB', '2010-09-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58428, 'Stone', 'Stone', '', 51.8024600, -0.8703200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58429, 'Stone', 'Stone', '', 51.0000000, 0.7666700, 'GB', '2010-09-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58430, 'Stondon', 'Stondon', 'Lower Stondon', 52.0015000, -0.3193300, 'GB', '2017-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58431, 'Stoke upon Tern', 'Stoke upon Tern', 'Stoke,Stoke upon Tern', 52.8500000, -2.5333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58432, 'Stokesley', 'Stokesley', '', 54.4699800, -1.1933000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58433, 'Stoke Prior', 'Stoke Prior', 'Stoke Prior', 52.2997800, -2.0803400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58434, 'Stoke Poges', 'Stoke Poges', 'Stoke Poges', 51.5444100, -0.5888000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58435, 'Stoke-on-Trent', 'Stoke-on-Trent', 'Gorad Stok-on-Trehnt,Stok-on-Trent,Stoka pie Trentas,Stokas prie Trento,Stoke,Stoke-on-Trent,Stoke-upon-Trent,Stoouk on Trent,Stouk na Trent,Stouk na Trentu,Stouk on Trent,The Potteries,XWH,astwk-an-trnt,seutokeuonteulenteu,stwk-awn-trynt,te lun te he pan si tuo ke,Στόουκ ον Τρεντ,Горад Сток-он-Трэнт,Сток-он-Трент,Стоук на Трент,Стоук на Тренту,Стоук он Трент,استوک-آن-ترنت,ستوك-أون-ترينت,سٹاک اون ٹرینٹ,ストーク・オン・トレント,特倫特河畔斯托克,스토크온트렌트', 53.0041500, -2.1853800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58436, 'Stokenchurch', 'Stokenchurch', '', 51.6583100, -0.8974000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58437, 'Stoke Goldington', 'Stoke Goldington', 'Stoke Goldington', 52.1313300, -0.7781400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58438, 'Stoke Golding', 'Stoke Golding', 'Stoke Golding', 52.5706000, -1.4112400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58439, 'Stoke Gifford', 'Stoke Gifford', 'Stoke Gifford', 51.5168600, -2.5405300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58440, 'Stoke Gabriel', 'Stoke Gabriel', 'Stoke Gabriel', 50.4032800, -3.6211100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58441, 'Stoke Ferry', 'Stoke Ferry', '', 52.5705100, 0.5132000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58442, 'Stoke', 'Stoke', '', 53.2500000, -2.8666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58443, 'Upper Stoke', 'Upper Stoke', '', 51.4467900, 0.6182400, 'GB', '2015-05-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58444, 'Stockton-on-Tees', 'Stockton-on-Tees', 'Stockton,Stockton-on-Tees,Stokton na Tizu,Stokton-on-Tis,Stoktun on Tijs,astaktwn-an-tyz,di si he pan si tuo ke dun,sutokkuton=on=tizu,Стоктон на Тизу,Стоктон-он-Тис,Стоктън он Тийс,استاکتون-آن-تیز,ストックトン＝オン＝ティーズ,蒂斯河畔斯托克頓', 54.5684800, -1.3187000, 'GB', '2014-04-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58445, 'Stockton', 'Stockton', '', 52.2718100, -1.3605500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58446, 'Stocksfield', 'Stocksfield', 'Stocksfield', 54.9402600, -1.9039800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58447, 'Stocksbridge', 'Stocksbridge', 'astwkzbryj,استوکزبریج', 53.4824900, -1.5937300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58448, 'Stockport', 'Stockport', 'Gorad Stokpart,Stockport,Stokport,Stokportas,XVA,seutogpoteu,si tuo ke bo te,st xk phxrt,stwkbwrt,sutokkupoto,Горад Стокпарт,Стокпорт,Ստոկպորտ,استاک‌پورت,ستوكبورت,สต็อกพอร์ต,ストックポート,斯托克波特,스톡포트', 53.4097900, -2.1576100, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58449, 'Stock', 'Stock', '', 51.6635100, 0.4426300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58450, 'Stithians', 'Stithians', 'Stithians', 50.1887000, -5.1780700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58451, 'Stirling', 'Stirling', 'Sruighle,Sruighlea,Sterling,Stirlin,Stirling,Stirlingas,Stirlingum,Stirlinq,Striuelin,Sturling,XWB,astyrlyng,astyrlyngh,s texr ling,seuteolling,shi te ling,sutaringu,Стерлинг,Стерлінг,Стърлинг,Ստերլինգ,استيرلينغ,استیرلینگ,سٹرلنگ,สเตอร์ลิง,スターリング,史特靈,스털링', 56.1190300, -3.9368200, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58452, 'Stilton', 'Stilton', 'Stilton', 52.4878800, -0.2889400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58453, 'Stillington', 'Stillington', 'Stillington', 54.6052900, -1.4219100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58454, 'Stickney', 'Stickney', 'Stickney', 53.0894900, 0.0054500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58455, 'Steyning', 'Steyning', 'Stening,astynyn,Стенинг,استینین', 50.8874400, -0.3278700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58456, 'Stewkley', 'Stewkley', 'Stewkley', 51.9274400, -0.7638100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58457, 'Stewarton', 'Stewarton', 'Baile nan Stiubhartach,Baile nan Stiùbhartach,Baile nan Stiúbhartach,Stewarton', 55.6798600, -4.5143500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58458, 'Stevington', 'Stevington', '', 52.1684800, -0.5551500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58459, 'Steventon', 'Steventon', '', 51.6247300, -1.3214500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58460, 'Stevenston', 'Stevenston', 'Baile Steafain,Gorad Styvenstan,Stivenston,Горад Стывенстан,Стивенстон', 55.6397000, -4.7533900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58461, 'Stevenage', 'Stevenage', 'Stevenage,Stiden Ac,Stivenedzh,Stivenidz,Stīðen Āc,XVJ,astywnj,seutebeoniji,si di fu ni qi,srrivanej,sti weni c,sutibunijji,Стивенедж,Стивениџ,استیونج,سٹیوینڈیج,സ്റ്റീവനേജ്,สตีเวนิจ,スティーブニッジ,斯蒂夫尼奇,스테버니지', 51.9022400, -0.2025600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58462, 'Stepps', 'Stepps', 'Stepps,Steps', 55.8889900, -4.1521000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58463, 'Steppingley', 'Steppingley', '', 52.0075800, -0.5285500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58464, 'Steeton', 'Steeton', 'Steeton', 53.8833300, -1.9500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58465, 'Steeple Claydon', 'Steeple Claydon', 'Claydon,Steeple Claydon', 51.9364300, -0.9832800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58466, 'Steeple Bumpstead', 'Steeple Bumpstead', 'Steeple Bumpstead', 52.0434600, 0.4480800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58467, 'Staveley', 'Staveley', 'Staveley', 54.3766100, -2.8179100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58468, 'Staveley', 'Staveley', 'Staveley,Staveley i Derbyshire,استاولی، دربی‌شر', 53.2666700, -1.3500000, 'GB', '2013-04-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58469, 'Startforth', 'Startforth', 'Startforth', 54.5385100, -1.9301600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58470, 'Starcross', 'Starcross', 'Starcross', 50.6273400, -3.4479700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58471, 'Staplehurst', 'Staplehurst', '', 51.1611000, 0.5524900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58472, 'Stapleford', 'Stapleford', '', 51.1166700, -1.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58473, 'Stanwick', 'Stanwick', 'Stanwick', 52.3319800, -0.5634800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58474, 'Stansted', 'Stansted', 'Stansted', 51.9000000, 0.2000000, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58475, 'Stannington', 'Stannington', '', 55.1086200, -1.6685500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58476, 'Stanmore', 'Stanmore', 'Stanmole,Stanmore,stainamora,स्टैनमोर', 51.6166700, -0.3166700, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58477, 'Stanley', 'Stanley', '', 56.4854000, -3.4518400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58478, 'Stanhope', 'Stanhope', 'Stanhope,astanhwp  kanty dwrham,استانهوپ، کانتی دورهام', 54.7500000, -2.0166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58479, 'Stanford-le-Hope', 'Stanford-le-Hope', 'Stanford', 51.5227400, 0.4342200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58480, 'Stanford in the Vale', 'Stanford in the Vale', 'Stanford in the Vale', 51.6396900, -1.5065200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58481, 'Standon', 'Standon', 'Standon', 52.9166700, -2.2833300, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58482, 'Standlake', 'Standlake', '', 51.7269000, -1.4243600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58483, 'Stanbridge', 'Stanbridge', '', 51.9086400, -0.5981500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58484, 'Stamford Bridge', 'Stamford Bridge', 'Stanfurdubryggja,Stanfurðubryggja', 53.9885000, -0.9154700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58485, 'Stamford', 'Stamford', 'Stamford,Stamford i Lincolnshire,seutaempeodeu,Стамфорд,스탬퍼드', 52.6500000, -0.4833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58486, 'Stalybridge', 'Stalybridge', 'Stalibridzh,Stalybridge,Сталибридж,استالی‌بریج', 53.4841400, -2.0590800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58487, 'Stallingborough', 'Stallingborough', 'Stallingborough', 53.5867500, -0.1848900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58488, 'Stalham', 'Stalham', 'astalham,استالهام', 52.7707900, 1.5178300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58489, 'Stalbridge', 'Stalbridge', '', 50.9580700, -2.3754800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58490, 'Stainton', 'Stainton', '', 53.4333300, -1.1666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58491, 'Stainforth', 'Stainforth', '', 53.6000000, -1.0333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58492, 'Staines', 'Staines', 'Staines,Staines-upon-Thames,Stejns,astaynz,si tan si,Стејнс,استاینز,斯坦斯', 51.4309200, -0.5060600, 'GB', '2013-04-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58493, 'Staindrop', 'Staindrop', 'Staindrop', 54.5810200, -1.8070800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58494, 'Stainburn', 'Stainburn', 'Stainburn', 53.9333300, -1.6166700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58495, 'Stainborough', 'Stainborough', '', 53.5262300, -1.5180000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58496, 'Stagsden', 'Stagsden', '', 52.1304600, -0.5667800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58497, 'Stafford', 'Stafford', 'Staefford,Stafford,Staford,Stæfford,XVB,astafwrd  anglstan,seutaepeodeu,si ta fu de,sutaffodo,Стафорд,Стаффорд,استافورد، انگلستان,スタッフォード,斯塔福德,스태퍼드', 52.8052100, -2.1163600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58498, 'Sproatley', 'Sproatley', '', 53.7937900, -0.1913000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58499, 'Springside', 'Springside', '', 55.6151400, -4.5906200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58500, 'Spratton', 'Spratton', 'Spratton', 52.3244700, -0.9538600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58501, 'Spofforth', 'Spofforth', 'Spofforth', 53.9542700, -1.4484800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58502, 'Spixworth', 'Spixworth', '', 52.6852900, 1.3202700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58503, 'Spittal', 'Spittal', 'Spittal', 51.8688900, -4.9425000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58504, 'Spilsby', 'Spilsby', 'aspylsby,اسپیلسبی', 53.1736300, 0.0937300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58505, 'Spennymoor', 'Spennymoor', 'Spennymoor,aspnymwr,اسپنیمور', 54.6988000, -1.6022900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58506, 'Speldhurst', 'Speldhurst', '', 51.1507600, 0.2194700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58507, 'Spalding', 'Spalding', 'Spalding i Lincolnshire,Spoldingas,اسپالدینگ، لینکلن‌شر', 52.7870900, -0.1514100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58508, 'Sowerby Bridge', 'Sowerby Bridge', '', 53.7090300, -1.9092900, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58509, 'Southwold', 'Southwold', 'Southwold,ساوت‌وود', 52.3275200, 1.6797900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58510, 'South Witham', 'South Witham', 'South Witham', 52.7647600, -0.6281100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58511, 'South Wingfield', 'South Wingfield', 'South Wingfield,Wingfield', 53.0959300, -1.4399800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58512, 'Southwick', 'Southwick', 'Southwick', 51.2969400, -2.2325000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58513, 'Southwell', 'Southwell', 'Southwell,Southwell i Nottinghamshire,ساوتول، ناتینگهام‌شر', 53.0780400, -0.9553800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58514, 'Southwater', 'Southwater', 'Southwater', 51.0236900, -0.3517300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58515, 'Tidworth', 'Tidworth', 'North Tidworth,South Tidworth,Tidworth,Todeorde,Tudworth,tydwwrth,تیدوورث', 51.2314200, -1.6632400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58516, 'South Shields', 'South Shields', 'Saut Shijlds,Saut Shilds,Saut-Shilds,Shields,Shields Theas,South Shields,nan xi er ci,sauseusiljeu,sawt shyldz,Саут Шийлдс,Саут Шилдс,Саут-Шилдс,ساوت شیلدز,サウス・シールズ,南希尔兹,사우스실즈', 54.9985900, -1.4323000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58517, 'Southsea', 'Southsea', 'nan hai cheng,sawth sy,ساوت‌سی,ساوث سي,南海城', 50.7920500, -1.0859300, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58518, 'Southport', 'Southport', 'Sautport,Southport,sauseupoteu,sausupoto,shao si bo te,Саутпорт,ساوت‌پورت,サウスポート,紹斯波特,사우스포트', 53.6458100, -3.0100800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58519, 'South Petherton', 'South Petherton', 'Petherton Theas,sawt ptrtwn,ساوت پترتون', 50.9482900, -2.8070800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58520, 'Southowram', 'Southowram', '', 53.7098800, -1.8318100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58521, 'Southorpe', 'Southorpe', '', 52.6105500, -0.4051200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58522, 'South Ockendon', 'South Ockendon', 'South Ockedon,South Ockendon', 51.5079900, 0.2833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58523, 'South Nutfield', 'South Nutfield', '', 51.0166700, -0.1333300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58524, 'South Molton', 'South Molton', 'Molton Theas,South Molton,sawt mwltwn,ساوت مولتون', 51.0166700, -3.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58525, 'Southminster', 'Southminster', '', 51.6622800, 0.8296800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58526, 'South Milford', 'South Milford', 'South Milford', 53.7767200, -1.2460900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58527, 'South Luffenham', 'South Luffenham', 'South Luffenham', 52.6085700, -0.6123200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58528, 'South Littleton', 'South Littleton', 'Littleton,South Littleton', 52.1141600, -1.8901400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58529, 'Southill', 'Southill', '', 52.0643100, -0.3235800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58530, 'South Hill', 'South Hill', '', 50.5333300, -4.3500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58531, 'South Hetton', 'South Hetton', 'South Hetton', 54.7990600, -1.4067100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58532, 'South Hayling', 'South Hayling', 'Hayling,South Hayling', 50.7877300, -0.9769700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58533, 'South Harting', 'South Harting', '', 50.9692400, -0.8838800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58534, 'Southery', 'Southery', '', 52.5271400, 0.3878300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58535, 'Southend-on-Sea', 'Southend-on-Sea', 'SEN,Sautend-on-Si,Southend,Southend-on-Sea,Саутенд-он-Си', 51.5378200, 0.7143300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58536, 'South Elmsall', 'South Elmsall', 'Elmsall Theas,sawt almsal,ساوت المسال', 53.5970900, -1.2803400, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58537, 'South Collingham', 'South Collingham', '', 53.1333300, -0.7666700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58538, 'South Cerney', 'South Cerney', 'South Cerney', 51.6731900, -1.9309700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58539, 'South Cave', 'South Cave', 'Cave Theas,sawt kyw,ساوت کیو', 53.7698700, -0.6010700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58540, 'South Brent', 'South Brent', 'Brent,South Brent', 50.4265400, -3.8342600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58541, 'South Benfleet', 'South Benfleet', 'Benfleet,Benfleet Theas,South Benfleet', 51.5529500, 0.5596200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58542, 'South Bank', 'South Bank', 'South Bank in Normanby,South Bank-on-Tees', 54.5666700, -1.1500000, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58543, 'Southampton', 'Southampton', 'Gorad Sautgemptan,Hantonia,Hantonne,SOU,Saouthampton,Sautamptonas,Sautgempton,Sauthempton,Sauthemptona,Sautkhamptun,Sautkhempton,Southampton,nan an pu dui,sausaempeuteon,sausanputon,sawthhambtwn,Σαουθάμπτον,Горад Саўтгемптан,Саутгемптон,Саутхамптън,Саутхемптон,סאות''המפטון,ساؤتھمپٹن,ساوت‌همپتون,ساوثهامبتون,เซาแทมป์ตัน,ဆောက်သမ္ပတန်မြို့,サウサンプトン,南安普敦,사우샘프턴', 50.9039500, -1.4042800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58544, 'Southam', 'Southam', 'Southam,sawtam,sawthham,ساوتام,ساوثهام', 52.2526600, -1.3884000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58545, 'Southall', 'Southall', 'Southall,sa''uthala,sa''uthola,sawthal,shao suo er,ساؤتھ ہال,ساوتهال,साउथॉल,ਸਾਊਥਾਲ,紹索爾', 51.5089600, -0.3713000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58546, 'Sonning', 'Sonning', 'Sonning,snyngh,سنينغ', 51.4741100, -0.9121200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58547, 'Somerton', 'Somerton', '', 51.9542100, -1.2761300, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58548, 'Somersham', 'Somersham', 'Somersham', 52.3833300, 0.0000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58549, 'Solihull', 'Solihull', 'Solihalas,Solihull,Solikhal,Solikhall,solliheol,sorifuru,suo li he er,swlyhal,swlyhl,Солихал,Солихалл,سوليهل,سولیهال,ソリフル,索利赫爾,솔리헐', 52.4142600, -1.7809400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58550, 'Soham', 'Soham', 'swham,سوهام', 52.3354300, 0.3365400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58551, 'Snodland', 'Snodland', 'Snodland,asnwdlnd,اسنودلند', 51.3297100, 0.4430500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58552, 'Snettisham', 'Snettisham', '', 52.8788200, 0.5009900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58553, 'Snetterton', 'Snetterton', 'Snetterton', 52.4758300, 0.9291200, 'GB', '2015-01-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58554, 'Snaith', 'Snaith', '', 53.6911200, -1.0285900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58555, 'Smethwick', 'Smethwick', 'Smedikas,Smethwick,Smetvik,Сметвик,اسمت‌ویک', 52.4926800, -1.9674500, 'GB', '2015-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58556, 'Slough', 'Slough', 'Slau,Slough,Слау', 51.5094900, -0.5954100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58557, 'Slinfold', 'Slinfold', '', 51.0720900, -0.4065800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58558, 'Sleights', 'Sleights', '', 54.4550600, -0.6648400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58559, 'Sleaford', 'Sleaford', 'Sleaford,aslyfwrd,slyfwrd,اسلیفورد,سليفورد', 52.9982600, -0.4094100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58560, 'Slamannan', 'Slamannan', '', 55.9372900, -3.8331100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58561, 'Slaley', 'Slaley', '', 54.9136800, -2.0371100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58562, 'Skipton', 'Skipton', 'Skipton,askyptwn,اسکیپتون', 53.9614400, -2.0167600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58563, 'Skipsea', 'Skipsea', '', 53.9767400, -0.2208400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58564, 'Skinningrove', 'Skinningrove', 'Skinningrove', 54.5690800, -0.8986900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58565, 'Skidby', 'Skidby', '', 53.7892100, -0.4613100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58566, 'Skelton', 'Skelton', 'Skelton,Skelton-in-Cleveland', 54.5606200, -0.9882500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58567, 'Skelton', 'Skelton', '', 54.0000000, -1.1333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58568, 'Skelton', 'Skelton', 'Skelton', 53.7252100, -0.8418700, 'GB', '2015-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58569, 'Skelmorlie', 'Skelmorlie', 'Skelmorlie', 55.8695000, -4.8847500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58570, 'Skelmersdale', 'Skelmersdale', 'Skelmersdale,asklmrsdyl,اسکلمرسدیل', 53.5502400, -2.7734800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58571, 'Skellingthorpe', 'Skellingthorpe', 'Skellingthorpe', 53.2353100, -0.6190500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58572, 'Skegness', 'Skegness', 'asgns,اسگنس', 53.1436200, 0.3363000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58573, 'Sittingbourne', 'Sittingbourne', 'sytyngbwrw,سیتینگبورو', 51.3412800, 0.7328200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58574, 'Siston', 'Siston', 'Siston', 51.4744400, -2.4500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58575, 'Sissinghurst', 'Sissinghurst', '', 51.1090500, 0.5600000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58576, 'Sion Mills', 'Sion Mills', 'Sion Mill', 54.7875200, -7.4727600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58577, 'Simpson', 'Simpson', '', 52.0166700, -0.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58578, 'Silverton', 'Silverton', 'Silverton', 50.8166700, -3.4833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58579, 'Silverstone', 'Silverstone', 'Sil''verstoun,Silverstonas,Silverstone,sylfrstwn,yin shi,Сильверстоун,Сільверстоун,سيلفرستون,銀石', 52.0921600, -1.0260200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58580, 'Silverdale', 'Silverdale', 'Silverdale', 54.1666700, -2.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58581, 'Silsoe', 'Silsoe', '', 52.0085400, -0.4248400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58582, 'Silsden', 'Silsden', 'Silsden', 53.9144300, -1.9380200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58583, 'Silloth', 'Silloth', 'sylwth,سیلوث', 54.8687000, -3.3844800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58584, 'Silkstone', 'Silkstone', '', 53.5480800, -1.5638100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58585, 'Sileby', 'Sileby', '', 52.7328600, -1.1077300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58586, 'Sidmouth', 'Sidmouth', 'Sidmouth,Sidmut,sydmwth,Сидмут,Сидмът,سیدموث', 50.6909400, -3.2397000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58587, 'Siddington', 'Siddington', '', 53.2333300, -2.2333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58588, 'Sidcup', 'Sidcup', 'Sidcup,سڈکپ، لندن', 51.4261900, 0.1036000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58589, 'Sibsey', 'Sibsey', 'Sibsey', 53.0385800, 0.0157900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58590, 'Sible Hedingham', 'Sible Hedingham', 'Sible Hedingham', 51.9777200, 0.5926200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58591, 'Shurdington', 'Shurdington', 'Shurdington', 51.8626400, -2.1206000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58592, 'Shropham', 'Shropham', '', 52.5001000, 0.9240300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58593, 'Shrivenham', 'Shrivenham', 'Shrivenham', 51.5985300, -1.6546100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58594, 'Shrewton', 'Shrewton', '', 51.1919400, -1.9026400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58595, 'Shrewsbury', 'Shrewsbury', 'Amwythig,Shrewsbury,Shrjusburi,Shrusberi,Шрусбери,Шрюсбъри', 52.7100900, -2.7520800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58596, 'Shotwick', 'Shotwick', '', 53.2393800, -2.9905600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58597, 'Shotton', 'Shotton', '', 54.7833300, -1.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58598, 'Shotley Gate', 'Shotley Gate', '', 51.9579100, 1.2687100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58599, 'Shoreham-by-Sea', 'Shoreham-by-Sea', 'ESH,New Shoreham,Shoreham,Shoreham-by-Sea,shwrham-bay-sy,shwryham,شورهام-بای-سی,شوريهام', 50.8341300, -0.2743100, 'GB', '2015-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58600, 'Shirley', 'Shirley', '', 52.9701200, -1.6755000, 'GB', '2015-01-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58601, 'Shirland', 'Shirland', 'Shirland', 53.1215500, -1.4046400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58602, 'Shirebrook', 'Shirebrook', 'shayrbrwk,شایربروک', 53.2033300, -1.2133600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58603, 'Shipton under Wychwood', 'Shipton under Wychwood', 'Shipton,Shipton under Wychwood', 51.8603500, -1.5984700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58604, 'Shipston on Stour', 'Shipston on Stour', '', 52.0605700, -1.6277800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58605, 'Shipley', 'Shipley', 'Shipley,Shipley i West Yorkshire,Shipli,Шипли', 53.8333300, -1.7666700, 'GB', '2014-04-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58606, 'Shipham', 'Shipham', '', 51.3142800, -2.8001000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58607, 'Shipdham', 'Shipdham', '', 52.6292300, 0.8857700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58608, 'Shinfield', 'Shinfield', 'Shinfield', 51.4054200, -0.9453400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58609, 'Shillington', 'Shillington', '', 51.9934400, -0.3600600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58610, 'Shillingstone', 'Shillingstone', 'Shillingstone', 50.8956700, -2.2449500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58611, 'Shildon', 'Shildon', 'shyldwn,شیلدون', 54.6299700, -1.6429500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58612, 'Shilbottle', 'Shilbottle', '', 55.3709900, -1.6882000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58613, 'Shifnal', 'Shifnal', 'Shifnal,shyfnal,شیفنال', 52.6704300, -2.3724800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58614, 'Shevington', 'Shevington', '', 53.5723600, -2.6931600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58615, 'Sherston', 'Sherston', 'Sherston', 51.5720500, -2.2127800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58616, 'Sherington', 'Sherington', 'Sherington', 52.1117200, -0.6997300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58617, 'Sheringham', 'Sheringham', 'Sheringem,shryngham,Шерингем,شرینگهام', 52.9407800, 1.2093100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58618, 'Sheriff Hutton', 'Sheriff Hutton', 'Sheriff Hutton', 54.0890400, -1.0063900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58619, 'Sherburn in Elmet', 'Sherburn in Elmet', 'Sherburn,Sherburn in Elmet', 53.7951900, -1.2466000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58620, 'Sherburn Hill', 'Sherburn Hill', 'Sherburn Hill', 54.7727000, -1.4798500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58621, 'Sherburn', 'Sherburn', 'Sherburn', 54.7760600, -1.5047400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58622, 'Sherborne St John', 'Sherborne St John', 'Sherborne St John', 51.2970500, -1.1138700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58623, 'Sherborne', 'Sherborne', 'Scirburna,Scireburna,Scīrburna,Sherborn,Sherborne,Sherbourne,shrbwrn,Шерборн,شربورن', 50.9459900, -2.5177600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58624, 'Shepton Mallet', 'Shepton Mallet', 'Shepton Mallet,Sheptun Molit,Shepun,Simon Browne,shptwn malt,Шептън Молит,شپتون مالت', 51.1897200, -2.5472200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58625, 'Shepshed', 'Shepshed', 'Sheepshed,Shepshed,shpshd,شپشد', 52.7657000, -1.2902100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58626, 'Shepperton', 'Shepperton', 'Shepperton,Шеппертон', 51.3954600, -0.4488900, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58627, 'Shepley', 'Shepley', 'Shepley', 53.5833300, -1.7166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58628, 'Shepherdswell', 'Shepherdswell', 'Shepherdswell,Sibertswold', 51.1871300, 1.2304900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58629, 'Shenstone', 'Shenstone', 'Shenstone', 52.6380200, -1.8414700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58630, 'Shenley Church End', 'Shenley Church End', 'Shenley,Shenley Church End', 52.0252200, -0.7899400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58631, 'Shenley AV', 'Shenley AV', 'Shenley', 51.6905400, -0.2806700, 'GB', '2017-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58632, 'Shelley', 'Shelley', 'Shelley', 53.6000000, -1.6833300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58633, 'Shefford', 'Shefford', '', 52.0387000, -0.3339900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58634, 'Sheffield', 'Sheffield', 'DSA,Gorad Shehfild,Seffild,Sefild,Sefilda,Sefildas,Sefilnt,Sheffield,Sheffild,Shefild,chef fi ld,sefilda,sephild,sephilda,shefirudo,shepildi,shfyld,shyfyld,spyld,syepildeu,xie fei er de,Şeffild,Šefildas,Šefīlda,Σέφιλντ,Горад Шэфілд,Шефилд,Шеффилд,Шеффілд,Շեֆիլդ,שעפילד,שפילד,شفيلد,شفیلد,شيفيلد,شیفیلڈ,شێفیڵد,शेफ़ील्ड,शेफील्ड,షెఫీల్డ్,เชฟฟีลด์,შეფილდი,シェフィールド,谢菲尔德,셰필드', 53.3829700, -1.4659000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58635, 'Sheerness', 'Sheerness', 'Sheerness,Shirness,Ширнесс', 51.4404200, 0.7625200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58636, 'Shawbury', 'Shawbury', 'Shawbury', 52.7909800, -2.6618300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58637, 'Shaw', 'Shaw', '', 53.5666700, -2.0833300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58638, 'Sharpness', 'Sharpness', 'Sharpness', 51.7197200, -2.4775000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58639, 'Sharnbrook', 'Sharnbrook', '', 52.2260600, -0.5442500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58640, 'Shap', 'Shap', '', 54.5314900, -2.6755100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58641, 'Shanklin', 'Shanklin', 'Shanklin,shanklyn,Шанклин,شانکلین', 50.6261300, -1.1785000, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58642, 'Shalford', 'Shalford', '', 51.2117500, -0.5696600, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58643, 'Shalfleet', 'Shalfleet', 'Shalfleet', 50.7011300, -1.4200700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58644, 'Shalbourne', 'Shalbourne', 'Shalbourn,Shalbourne', 51.3635800, -1.5505300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58645, 'Shafton', 'Shafton', 'Shafton', 53.5928600, -1.4092500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58646, 'Shaftesbury', 'Shaftesbury', 'Sceftonia,Shaftesbury,shaftsbwry,شافتسبوری', 51.0052800, -2.1933300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58647, 'Shadoxhurst', 'Shadoxhurst', '', 51.1079700, 0.8191700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58648, 'Seven Sisters', 'Seven Sisters', '', 51.7666700, -3.7166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58649, 'Sevenoaks', 'Sevenoaks', 'Sevenoks,Sevunouks,sebeun-okeuseu,sebunokusu,swnwks,Севенокс,Севъноукс,سونوکس,セブノークス,세븐오크스', 51.2726600, 0.1888300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58650, 'Settle', 'Settle', 'Settle,stl,ستل', 54.0686500, -2.2772000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58651, 'Sennen', 'Sennen', 'Sennan,Sennen,snn,سنن', 50.0777700, -5.7011700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58652, 'Send', 'Send', '', 51.2887500, -0.5266600, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58653, 'Selsey', 'Selsey', 'Selsey,Selsi,slsy,Селси,سلسی', 50.7350100, -0.7897900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58654, 'Sellack', 'Sellack', '', 51.9500000, -2.6333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58655, 'Selkirk', 'Selkirk', 'Salcraig,Selkerk,sai er kou ke,Селкерк,塞尔扣克', 55.5473800, -2.8391100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58656, 'Selby', 'Selby', 'Selbi,Selby,sai er bi,slby,Селби,سلبی,塞爾比', 53.7833300, -1.0666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58657, 'Seghill', 'Seghill', '', 55.0622500, -1.5502700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58658, 'Seend', 'Seend', '', 51.3480600, -2.0847200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58659, 'Sedgefield', 'Sedgefield', '', 54.6532900, -1.4495200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58660, 'Sedbergh', 'Sedbergh', 'Sedbergh,sai de bo,sdbr,سدبر,塞德伯', 54.3212300, -2.5251400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58661, 'Seaview', 'Seaview', '', 50.7195600, -1.1116400, 'GB', '2012-01-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58662, 'Seaton Delaval', 'Seaton Delaval', '', 55.0719600, -1.5260900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58663, 'Seaton', 'Seaton', '', 52.5748900, -0.6675900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58664, 'Seascale', 'Seascale', 'Seascale', 54.3983100, -3.4796100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58665, 'Seale', 'Seale', '', 51.2241400, -0.7208100, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58666, 'Seahouses', 'Seahouses', '', 55.5806300, -1.6549700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58667, 'Seaham', 'Seaham', 'Seaham,Seaham Harbour,Sikhem,syham,Сихем,سیهام', 54.8390300, -1.3457500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58668, 'Seaford', 'Seaford', 'Seaford i East Sussex,syfwrd  sasks shrqy,xi fu de,سیفورد، ساسکس شرقی,西福德', 50.7714100, 0.1026800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58669, 'Seafield', 'Seafield', '', 55.9666700, -3.1500000, 'GB', '2013-11-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58670, 'Scunthorpe', 'Scunthorpe', 'Scunthorpe,Skantorp,Skantorpas,Skantorpe,seukeonsopeu,si ken suo pu,sukansopu,Сканторп,Сканторпе,اسکان‌ثورپ,スカンソープ,斯肯索普,스컨소프', 53.5790500, -0.6543700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58671, 'Scotter', 'Scotter', '', 53.4965200, -0.6742900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58672, 'Scotby', 'Scotby', '', 54.8900400, -2.8746400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58673, 'Scorton', 'Scorton', '', 54.3978500, -1.6127600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58674, 'Scole', 'Scole', '', 52.3670600, 1.1567400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58675, 'Scholes', 'Scholes', '', 53.8234600, -1.4280500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58676, 'Scawby', 'Scawby', 'Scawby', 53.5378700, -0.5408500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58677, 'Scarcroft', 'Scarcroft', 'Scarcroft', 53.8666700, -1.4500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58678, 'Scarborough', 'Scarborough', 'Scarborough,Skarboro,Skarburou,seukabeoleo,si ka bu luo,skarbwrw,sqrbwrw,sukabura,Скарборо,Скарбъроу,סקרבורו,اسکاربرو، یورک‌شر شمالی,سكاربورو,スカーブラ,斯卡布羅,스카버러', 54.2796600, -0.4044300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58679, 'Scalloway', 'Scalloway', 'Scalloway', 60.1383200, -1.2769000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58680, 'Scalby', 'Scalby', 'Scalby', 53.7666700, -0.7166700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58681, 'Saxmundham', 'Saxmundham', 'saksmandham,ساکسماندهام', 52.2149700, 1.4880500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58682, 'Saxilby', 'Saxilby', 'Saxilby', 53.2674600, -0.6625300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58683, 'Sawtry', 'Sawtry', 'Sawtry', 52.4398400, -0.2842200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58684, 'Sawston', 'Sawston', 'swstwn,سوستون', 52.1208900, 0.1694300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58685, 'Sawbridgeworth', 'Sawbridgeworth', 'Sawbridgeworth,ساوبریج‌وورث', 51.8166700, 0.1500000, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58686, 'Saundersfoot', 'Saundersfoot', 'Saundersfoot', 51.7094500, -4.7021500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58687, 'Saughall', 'Saughall', 'Great Saughall', 53.2261800, -2.9564900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58688, 'Sapcote', 'Sapcote', 'Sapcote', 52.5370700, -1.2790000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58689, 'Sanquhar', 'Sanquhar', 'An t-Seann Chathair,Sanquhar', 55.3652700, -3.9216000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58690, 'Sandy', 'Sandy', 'Sandy i Bedfordshire,sndy  bdfwrdshr,سندی، بدفوردشر', 52.1292700, -0.2892500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58691, 'Sandwick', 'Sandwick', '', 60.0000000, -1.2500000, 'GB', '2006-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58692, 'Sandwich', 'Sandwich', 'Sandwic,Sandwich,Sandwich i Kent,Sandwīc,Sehndvich,sandou~itchi,sandwych  knt,sang wei zhi,Сэндвич,ساندویچ، کنت,サンドウィッチ,桑威治', 51.2722300, 1.3377600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58693, 'Sandown', 'Sandown', 'Sandaun,Sandown,sandwn,Сандаун,ساندون', 50.6515800, -1.1610300, 'GB', '2011-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58694, 'Sandhurst', 'Sandhurst', 'Sandhurst,Sandkherst,sandhwrst  brkshr,sang he si te,Сандхерст,ساندهورست، برکشر,桑赫斯特', 51.3467500, -0.7865500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58695, 'Sandford', 'Sandford', '', 51.3322800, -2.8312200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58696, 'Sandbank', 'Sandbank', '', 55.9820300, -4.9497300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58697, 'Sandbach', 'Sandbach', 'snbach,سنباچ', 53.1451500, -2.3625100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58698, 'Sampford Peverell', 'Sampford Peverell', '', 50.9194500, -3.3808100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58699, 'Saltford', 'Saltford', '', 51.4013900, -2.4594400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58700, 'Saltcoats', 'Saltcoats', 'Baile an t-Salainn,Soltkots,Солткотс', 55.6361600, -4.7858800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58701, 'Saltburn-by-the-Sea', 'Saltburn-by-the-Sea', 'Saltburn,Saltburn-by-the-Sea,Soltbern-baj-ze-Si,Солтберн-бай-зе-Сі', 54.5823700, -0.9736700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58702, 'Saltash', 'Saltash', 'Essa,Saltash,saltsh,سالتش', 50.4095900, -4.2251400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58703, 'Salisbury', 'Salisbury', 'Caersallog,New Sarum,Salisbury,Sarisberia,Searoburg,Solsb"ri,Solsberi,Solsberis,Solsmperi,XSR,salsbry,salysbry,salzbry,shu shi ba li,soljeubeli,soljhabri,soruzuberi,suo er zi bo li,swlsbry,sxls bri,Σόλσμπερι,Солсбери,Солсбері,Солсбъри,Սոլսբերի,סולסברי,سالزبری,سالسبری,ساليسبري,سولسبرى,सॉल्झब्री,সল্‌স্‌বারি,ซอลส์บรี,ሳልዝብሪ,ソールズベリー,梳士巴利,索爾茲伯里,솔즈베리', 51.0693100, -1.7956900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58704, 'Saline', 'Saline', 'Saline', 56.1139900, -3.5703400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58705, 'Salfords', 'Salfords', '', 51.2043000, -0.1694700, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58706, 'Salford', 'Salford', 'Gorad Solfard,Salford,Salfordas,Solford,salfwrd,sarufodo,solpeodeu,suo er fu de,Горад Солфард,Солфорд,سالفورد,サルフォード,索爾福德,솔퍼드', 53.4877100, -2.2904200, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58707, 'Sale', 'Sale', 'Sale i Stor-Manchester,Sejl,sai er,seil,syl  mnchstr bzrg,Сейл,Сејл,سیل، منچستر بزرگ,塞爾,세일', 53.4251900, -2.3244300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58708, 'Salcombe', 'Salcombe', 'salkwmb,سالکومب', 50.2374300, -3.7687400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58709, 'Saint Stephen', 'Saint Stephen', '', 50.3446900, -4.8997300, 'GB', '2015-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58710, 'Saint Peters', 'Saint Peters', 'Saint Peter Extra,Saint Peters,Thanet', 51.3666700, 1.4166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58711, 'Saint Osyth', 'Saint Osyth', '', 51.8000000, 1.0833300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58712, 'Saint Neots', 'Saint Neots', 'Saint Neots,St Neots', 52.2166700, -0.2666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58713, 'Saint Monans', 'Saint Monans', 'Saint Monans', 56.2065100, -2.7682100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58714, 'Saint Leonards-on-Sea', 'Saint Leonards-on-Sea', 'Saint Leonards,Saint Leonards-on-Sea,St Leonards,St Leonards on Sea,St Leonards-on-Sea,St. Leonards-on-Sea', 50.8556500, 0.5452000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58715, 'St Leonards', 'St Leonards', '', 50.8307700, -1.8437700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58716, 'St Ives', 'St Ives', 'Porth Ia,Saint Ives,Sent-Ajvs,St. Ives,St. Ives i Cornwall,sheng ai fu si,snt ayws  kwrnwal,Сент-Айвс,سنت ایوس، کورنوال,စိန့်အိုက်ဗ်မြို့,セント・アイヴス,圣艾夫斯', 50.2086100, -5.4875000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58717, 'St Helens', 'St Helens', 'Saint Helens,Sent-Khelens,St Helens,St. Helens,Сент-Хеленс', 53.4500000, -2.7333300, 'GB', '2014-04-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58718, 'St. Helens', 'St. Helens', 'Saint Helens,St Helens', 50.6968800, -1.1115900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58719, 'Saintfield', 'Saintfield', '', 54.4604600, -5.8306500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58720, 'Saint Dennis', 'Saint Dennis', 'Saint Denis,Saint Dennis', 50.3833300, -4.8833300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58721, 'St. Day', 'St. Day', '', 50.2395800, -5.1857200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58722, 'Saint Davids', 'Saint Davids', 'Saint David''s,Saint David’s,Sent-Dehvidz,St David''s,St Davids,Tyddewi,Сент-Дэвидз', 51.8809400, -5.2655400, 'GB', '2017-07-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58723, 'Saint Cyrus', 'Saint Cyrus', 'Saint Cyrus', 56.7750400, -2.4155300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58724, 'Saint Columb Major', 'Saint Columb Major', 'Saint Columb,Saint Columb Major,St Columb,St. Columb,Synt Colom Gwartha,Synt Colom Veur', 50.4316300, -4.9433600, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58725, 'Saint Clears', 'Saint Clears', 'Sancler,Sanclêr', 51.8198900, -4.4978300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58726, 'Saint Boswells', 'Saint Boswells', '', 55.5730100, -2.6441000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58727, 'Saint Bees', 'Saint Bees', 'Saint Bees,Saint Bega,St Bees,St. Bees', 54.4918300, -3.5898700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58728, 'St Austell', 'St Austell', 'Austol,Saint Austell,Sent-Ostell,St Austell,St. Austell,USX,snt astl,Сент-Остелл,سنت آستل', 50.3425000, -4.7744200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58729, 'Saint Asaph', 'Saint Asaph', 'Llanelwy,Saint Asaph,St Asaph', 53.2581500, -3.4452400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58730, 'Saint Andrews', 'Saint Andrews', 'ADX,Saint Andrews,Sejnt Andrjus,Sent-Andrus,St Andrews,St. Andrews,sento・andoruzu,Сейнт Андрюс,Сент-Андрус,セント・アンドルーズ', 56.3387100, -2.7990200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58731, 'St Albans', 'St Albans', 'Fanum Sancti Albani,Gorad Sent-Olbans,Saint Albans,Sejnt Olbans,Sent Olbans,Sent-Ehlbans,Sent-Olbans,St Albans,St. Albans,sant albanz,seinteuolbeonseu,sheng ao er ben si,snt albnz,Горад Сент-Олбанс,Сейнт Олбанс,Сент Олбанс,Сент-Олбанс,Сент-Элбанс,سانت ألبانز,سنت آلبنز,セント・オールバンズ,聖奧爾本斯,세인트올번스', 51.7500000, -0.3333300, 'GB', '2014-04-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58732, 'Saint Agnes', 'Saint Agnes', 'Saint Agnes,St. Agness', 50.3127800, -5.2045600, 'GB', '2014-09-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58733, 'Saffron Walden', 'Saffron Walden', 'Safron-Uolden,sa fu lun wo er deng,safrwn waldn,Сафрон-Уолден,سافرون والدن,薩弗倫沃爾登', 52.0233700, 0.2423400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58734, 'Sacriston', 'Sacriston', 'Sacriston', 54.8176900, -1.6241000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58735, 'Sabden', 'Sabden', 'Sabden', 53.8335500, -2.3372800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58736, 'Ryton on Dunsmore', 'Ryton on Dunsmore', 'Ryton on Dunsmore', 52.3666700, -1.4333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58737, 'Ryton', 'Ryton', '', 52.6166700, -2.3500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58738, 'Ryhope', 'Ryhope', 'Ryhope', 54.8713900, -1.3700000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58739, 'Ryhill', 'Ryhill', '', 53.6220400, -1.4107100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58740, 'Ryhall', 'Ryhall', '', 52.6858500, -0.4684600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58741, 'Rye', 'Rye', 'Raj,Rye,Rye i East Sussex,lai yi,ry  sasks shrqy,Рай,ری، ساسکس شرقی,萊伊', 50.9511400, 0.7337000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58742, 'Ryde', 'Ryde', 'Rajd,rayd,Райд,راید', 50.7299900, -1.1621000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58743, 'Ruyton-XI-Towns', 'Ruyton-XI-Towns', 'Ruyton,Ruyton XI Towns,Ruyton of the Eleven Towns,Ruyton-XI-Towns', 52.7955500, -2.9031800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58744, 'Ruthin', 'Ruthin', 'Ratin,Rhuthun,Ridin,Ridinas,Ritin,Ruthin,lu si yin,ludin,Ратін,Ридин,Ритин,魯思因,루딘', 53.1136800, -3.3178200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58745, 'Rutherglen', 'Rutherglen', 'An Ruadh-Ghleann,Razerqlen,Ruglen,Ruterglen,rwdrgln,Рутерглен,رودرگلن', 55.8288500, -4.2137600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58746, 'Rustington', 'Rustington', 'Rustington', 50.8102700, -0.5067400, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58747, 'Ruskington', 'Ruskington', 'Ruskington', 53.0454400, -0.3869200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58748, 'Rushden', 'Rushden', 'Rushdun,rashdn,Ръшдън,راشدن', 52.2892700, -0.6018400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58749, 'Rushall', 'Rushall', '', 51.2833300, -1.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58750, 'Runcorn', 'Runcorn', 'Rankorn,Runcorn,XRC,lang ke en,rankwrn,Ранкорн,رانکورن,朗科恩', 53.3417400, -2.7312400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58751, 'Ruislip', 'Ruislip', 'Ruislip,lai si li pu,ra''islipa,राइस्लिप,莱斯里普', 51.5734400, -0.4234100, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58752, 'Rugeley', 'Rugeley', 'Rudzhli,XRG,rwjly,Ръджли,روجلی', 52.7593000, -1.9369400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58753, 'Rugby', 'Rugby', 'Ragbi,Rugby i Warwickshire,XRU,la ge bi,leogbi,ragubi,rajby,rakbi,rakpi,Рагби,راجبي,راگبی، وارویک‌شایر,ரக்பி,รักบี้,ラグビー,拉格比,럭비', 52.3709200, -1.2641700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58754, 'Rufford', 'Rufford', '', 53.6337500, -2.8166200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58755, 'Rudgwick', 'Rudgwick', '', 51.0873500, -0.4516400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58756, 'Ruddington', 'Ruddington', '', 52.8925400, -1.1495300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58757, 'Ruabon', 'Ruabon', 'Rhiwabon,Ruabon', 52.9878000, -3.0388300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58758, 'Royton', 'Royton', '', 53.5650700, -2.1226700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58759, 'Royston', 'Royston', 'Royston', 53.6000000, -1.4500000, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58760, 'Royston', 'Royston', 'Royston i Hertfordshire,rwystwn  hrtfwrdshr,رویستون، هرتفوردشر', 52.0483200, -0.0243800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58761, 'Roydon', 'Roydon', '', 51.7718000, 0.0403000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58762, 'Royal Tunbridge Wells', 'Royal Tunbridge Wells', 'Rojal Tanbridz Vels,Royal Tunbridge Wells,Tunbridge Wells,Turnbridge Wells,huang jia tang qiao jing,rwyal tanbryj wlz,Ројал Танбриџ Велс,رویال تانبریج ولز,皇家唐橋井', 51.1332100, 0.2625600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58763, 'Roxton', 'Roxton', '', 52.1775600, -0.3159400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58764, 'Rowlstone', 'Rowlstone', '', 51.9333300, -2.9166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58765, 'Rowley Regis', 'Rowley Regis', 'Rowley Regis,rawly rjys,راولی رجیس', 52.4829200, -2.0437600, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58766, 'Rowlands Gill', 'Rowlands Gill', '', 54.9192200, -1.7448900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58767, 'Rowhedge', 'Rowhedge', '', 51.8573800, 0.9453400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58768, 'Rowde', 'Rowde', 'Rowde', 51.3632500, -2.0309800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58769, 'Rottingdean', 'Rottingdean', '', 50.8098400, -0.0593900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58770, 'Rothwell', 'Rothwell', 'Rothwell,Rowell', 52.4166700, -0.8000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58771, 'Rothley', 'Rothley', '', 55.1833300, -1.9166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58772, 'Rothley', 'Rothley', '', 52.7091600, -1.1373900, 'GB', '2016-07-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58773, 'Rothienorman', 'Rothienorman', 'Rothienorman', 57.4114500, -2.4645500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58774, 'Rothesay', 'Rothesay', 'Baile Bhoid,Baile Bhòid,Baile Bhóid,Rodsej,Rothesay,Rothesay  Bute,Rothsey,Rotsej,rosushi,Родсей,Ротсей,ロスシー', 55.8364800, -5.0550800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58775, 'Rothes', 'Rothes', 'Rothes', 57.5262400, -3.2066300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58776, 'Rotherham', 'Rotherham', 'Roderamas,Rodurum,Roteram,Roterem,Rotergem,Rotherdam,Rotherham,lodeoleom,luo se lei mu,ratrham,rozaramu,Родъръм,Ротерам,Ротергем,Ротерем,Ռոտերեմ,راترهام,ロザラム,羅瑟勒姆,로더럼', 53.4301200, -1.3567800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58777, 'Rotherfield Peppard', 'Rotherfield Peppard', 'Rotherfield Peppard', 51.5306400, -0.9784700, 'GB', '2013-07-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58778, 'Rothbury', 'Rothbury', 'rwtbwry,روتبوری', 55.3105900, -1.9084500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58779, 'Rosyth', 'Rosyth', 'Ros Fhiobh,Ros Fhíobh,Rosajt,Rosyth,rosaisu,Росайт,ロサイス', 56.0368900, -3.4380000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58780, 'Rostrevor', 'Rostrevor', 'Rosstrevor,Rostrevor', 54.1000000, -6.2000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58781, 'Ross on Wye', 'Ross on Wye', 'Rhosan ar Wy,Ross,Ross on Wye', 51.9166700, -2.5666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58782, 'Rossington', 'Rossington', '', 53.4793100, -1.0619000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58783, 'Rossett', 'Rossett', 'Rosset,Rossett', 53.1092100, -2.9447800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58784, 'Rosneath', 'Rosneath', 'Roseneath,Rosheath,Rosneath', 56.0098500, -4.8015100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58785, 'Rosehearty', 'Rosehearty', 'Rosehearty', 57.6970000, -2.1132200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58786, 'Roos', 'Roos', '', 53.7529200, -0.0446300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58787, 'Romsley', 'Romsley', '', 52.4500000, -2.3166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58788, 'Romsley', 'Romsley', 'Romsley', 52.4199600, -2.0569500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58789, 'Romsey', 'Romsey', 'Romsey,luo mu xi,ramsy,رامسی,罗姆西', 50.9890600, -1.4998900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58790, 'Romford', 'Romford', 'lompeodeu,luo mu fu de,ramfwrd,رامفورد,羅姆福德,롬퍼드', 51.5751500, 0.1858200, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58791, 'Romaldkirk', 'Romaldkirk', 'Romaldkirk', 54.5944000, -2.0105800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58792, 'Rokeby', 'Rokeby', '', 54.5166700, -1.8666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58793, 'Rode Heath', 'Rode Heath', 'Rode Heath', 53.1138700, -2.2918600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58794, 'Rode', 'Rode', 'Road,Rode', 51.2839000, -2.2814100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58795, 'Rochford', 'Rochford', 'Rochford,rwchfwrd,Рочфорд,روچفورد', 51.5819800, 0.7067300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58796, 'Rochester', 'Rochester', '', 55.2752000, -2.2649000, 'GB', '2012-11-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58797, 'Rochester', 'Rochester', 'Durobrivae,Gorad Rochehstehr,RCS,Rochester,Rochester i Kent,Rochester í Kent,Rotsester,locheseuteo,luo che si te,rochesuta,rwchstr  knt,Ρότσεστερ,Горад Рочэстэр,Рочестер,روچستر، کنت,روچیسٹر، کینٹ,ロチェスター,羅徹斯特,로체스터', 51.3876400, 0.5054600, 'GB', '2012-01-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58798, 'Roche', 'Roche', 'Roche', 50.4080800, -4.8337300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58799, 'Rochdale', 'Rochdale', 'Recedham,Rocdeilis,Rochdale,Rochdejl,Ročdeilis,lochideil,luo qi dai er,rotchideru,rwchdyl,Рочдейл,Рочдејл,راچڈیل,روچدیل,ロッチデール,羅奇代爾,로치데일', 53.6176600, -2.1552000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58800, 'Robertsbridge', 'Robertsbridge', '', 50.9856900, 0.4725300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58801, 'Roade', 'Roade', 'Roade', 52.1582400, -0.8974500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58802, 'Rishton', 'Rishton', '', 53.7680600, -2.4144400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58803, 'Riseley', 'Riseley', 'rysly,ريسلي', 52.2521300, -0.4792800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58804, 'Risca', 'Risca', 'Risca', 51.6079900, -3.1008100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58805, 'Ripponden', 'Ripponden', '', 53.6744900, -1.9418300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58806, 'Ripon', 'Ripon', 'Ripon,Ripun,li peng,lipeon,ripon,rpn,rybwn,rypwn,Рипон,Рипън,Ріпон,Ռիպոն,ريبون,رپن,ریپون,リポン,里彭,리펀', 54.1357900, -1.5282600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58807, 'Ripley', 'Ripley', 'Ripley,Ripley i Derbyshire,Ripli,Рипли,ریپلی، دربی‌شر', 53.0333300, -1.4000000, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58808, 'Ripley', 'Ripley', '', 51.2990700, -0.4916400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58809, 'Ringwood', 'Ringwood', 'RNW,Ringwood,ryngwwd,رینگوود', 50.8454100, -1.7887100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58810, 'Ringway', 'Ringway', '', 53.3500000, -2.2833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58811, 'Ringstead', 'Ringstead', '', 52.3652800, -0.5549000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58812, 'Ringmer', 'Ringmer', '', 50.8926400, 0.0547200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58813, 'Rimswell', 'Rimswell', '', 53.7407900, -0.0174200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58814, 'Rillington', 'Rillington', 'Rillington', 54.1577900, -0.6949400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58815, 'Ridlington', 'Ridlington', '', 52.6133700, -0.7560000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58816, 'Ridgmont', 'Ridgmont', '', 52.0153200, -0.5787100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58817, 'Rickmansworth', 'Rickmansworth', 'Rickmansworth', 51.6389800, -0.4771800, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58818, 'Rickinghall', 'Rickinghall', 'Rickinghall', 52.3364900, 0.9927200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58819, 'Richmond', 'Richmond', 'Richmond,Richmond i North Yorkshire,li shi man,lichimeondeu,رچمنڈ، شمالی یارکشائر,ریچموند، یورک‌شر شمالی,里士满,리치먼드', 54.4036000, -1.7343400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58820, 'Richmond', 'Richmond', '', 51.4617100, -0.3063300, 'GB', '2015-07-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58821, 'Riccall', 'Riccall', 'Riccall', 53.8333100, -1.0573000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58822, 'Rhymney', 'Rhymney', 'Rhymney', 51.7599800, -3.2855300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58823, 'Rhyl', 'Rhyl', 'Rhyl,Ril,Rilis,Y Rhyl,lai er,Рил,Ріл,萊爾', 53.3192900, -3.4922800, 'GB', '2014-12-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58824, 'Rhuddlan', 'Rhuddlan', 'Rhuddlan,Rhyddlan,Ridlan,Ридлан', 53.2920300, -3.4699600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58825, 'Rhu', 'Rhu', 'Rhu,Row', 56.0166700, -4.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58826, 'Rhosneigr', 'Rhosneigr', 'Rhosneigir,Rhosneigr', 53.2318600, -4.5148000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58827, 'Rhosllanerchrugog', 'Rhosllanerchrugog', 'Rhos,Rhosllanerchrugog', 53.0097400, -3.0581400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58828, 'Rhoose', 'Rhoose', 'Rhoose', 51.3881800, -3.3543000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58829, 'Rhondda', 'Rhondda', 'Rhondda,Ronda,Ronta,Y Rhondda,rwnta,Ронда,Ронта,رونتا', 51.6589600, -3.4488500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58830, 'Rhayader', 'Rhayader', 'Rajaderis,Rejudur,Rhaeadr Gwy,Rhayader,Рейъдър', 52.3015400, -3.5114600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58831, 'Resolven', 'Resolven', '', 51.7119300, -3.6974500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58832, 'Repton', 'Repton', 'Repton', 52.8398300, -1.5506100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58833, 'Renton', 'Renton', '', 55.9720000, -4.5839900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58834, 'Renfrew', 'Renfrew', 'Gorad Rehnfru,Renfrju,Renfru,Rinn Friu,Rinn Friù,Rinn Friú,lenpeulu,lun fu lu,rnfrw,rynfrw,Горад Рэнфру,Ренфру,Ренфрю,رنفرو,رينفرو,倫弗魯,렌프루', 55.8719700, -4.3925300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58835, 'Rendlesham', 'Rendlesham', 'Rendlesham', 52.1266500, 1.4153600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58836, 'Remenham', 'Remenham', '', 51.5518900, -0.8908400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58837, 'Reigate', 'Reigate', 'Rajgejt,Rajgit,Reigate,rygyt,Райгейт,Райгит,ریگیت', 51.2373600, -0.2058200, 'GB', '2016-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58838, 'Reepham', 'Reepham', 'Reepham', 53.2333300, -0.4333300, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58839, 'Reepham', 'Reepham', 'rypham  nwrfk,ریپهام، نورفک', 52.7632000, 1.1109900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58840, 'Reedham', 'Reedham', '', 52.5605400, 1.5712200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58841, 'Redwick', 'Redwick', 'Redwick', 51.5527800, -2.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58842, 'Redruth', 'Redruth', 'Redrut,Resrudh,Ryd Ruth,ledeuluseu,rdrwth,Редрът,ردروث,레드루스', 50.2331500, -5.2243400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58843, 'Redlynch', 'Redlynch', 'Redlynch', 51.0986100, -2.4266700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58844, 'Redhill', 'Redhill', 'KRH,Redhill', 51.2404800, -0.1704400, 'GB', '2011-02-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58845, 'Redditch', 'Redditch', 'Radditch,Reddich,Redditch,Redicas,Redich,Redičas,ledichi,lei di qi,rdych,reditchi,Реддитч,Реддич,Редич,ردیچ,レディッチ,雷迪奇,레디치', 52.3065000, -1.9456900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58846, 'Redcar', 'Redcar', 'Redkar,ledeuka,lei de ka,rdkar,Редкар,ردكار,ردکار,ویسٹ فیلڈ، ریڈکار,雷德卡,레드카', 54.6165700, -1.0599900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58847, 'Redbourne', 'Redbourne', 'Redbourne', 53.4872800, -0.5356700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58848, 'Redbourn', 'Redbourn', '', 51.7989600, -0.3959400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58849, 'Reading', 'Reading', 'Reading,Reding,XRE,Рединг', 51.4562500, -0.9711300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58850, 'Rayne', 'Rayne', 'Rayne', 51.8666700, 0.5833300, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58851, 'Rayleigh', 'Rayleigh', 'Rayleigh', 51.5857100, 0.6045900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58852, 'Rawtenstall', 'Rawtenstall', 'Rawtenstall,rawtnstal,راوتنستال', 53.7007600, -2.2844200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58853, 'Rawmarsh', 'Rawmarsh', '', 53.4606200, -1.3443700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58854, 'Rawcliffe', 'Rawcliffe', '', 53.6977700, -0.9631900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58855, 'Ravenstone', 'Ravenstone', 'Ravenstone,Ravenstone with Snibston', 52.7211100, -1.4058200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58856, 'Ravenstone', 'Ravenstone', '', 52.1493400, -0.7587400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58857, 'Raunds', 'Raunds', 'rwndz,روندز', 52.3442800, -0.5365700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58858, 'Ratho', 'Ratho', 'Ratho', 55.9216400, -3.3802800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58859, 'Rathfriland', 'Rathfriland', 'Rathfriland,Rathfryland', 54.2500000, -6.1666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58860, 'Raskelf', 'Raskelf', 'Raskelf', 54.1330500, -1.2487900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58861, 'Ranskill', 'Ranskill', 'Ramskill,Ranskill', 53.3828100, -1.0140200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58862, 'Randalstown', 'Randalstown', 'Randalstown', 54.7500000, -6.3000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58863, 'Ramsgate', 'Ramsgate', 'QQR,Ramsgate,Ramsgato,Ramsgejt,Ramsgit,laemseugeiteu,ramuzugeto,Рамсгейт,Рамсгит,رامس‌گیت,ラムズゲート,램스게이트', 51.3356800, 1.4179700, 'GB', '2015-05-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58864, 'Ramsey', 'Ramsey', 'Hramesige on Huntadunscire,Hramesige on Huntadūnscīre,rymsy  kymbrjshayr,رمزی، کمبریج‌شر,ریمسی، کیمبرجشائر', 52.4505800, -0.1093200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58865, 'Ramsbury', 'Ramsbury', '', 51.4437300, -1.6025700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58866, 'Ramsbottom', 'Ramsbottom', '', 53.6478900, -2.3168300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58867, 'Rainworth', 'Rainworth', '', 53.1188300, -1.1185200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58868, 'Rainham', 'Rainham', '', 51.3632300, 0.6089300, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58869, 'Rainford', 'Rainford', '', 53.5022300, -2.7883900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58870, 'Raglan', 'Raglan', 'Rhaglan', 51.7650000, -2.8533100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58871, 'Radyr', 'Radyr', 'Radir,Radyr', 51.5186400, -3.2582900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58872, 'Radstock', 'Radstock', 'Radstok,radstwk,Радсток,رادستوک', 51.2886200, -2.4600300, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58873, 'Radley', 'Radley', 'Radley', 51.6874600, -1.2402500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58874, 'Radlett', 'Radlett', 'Radlett', 51.6859300, -0.3186800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58875, 'Radcliffe on Trent', 'Radcliffe on Trent', 'Radcliffe,Radcliffe on Trent', 52.9480200, -1.0385500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58876, 'Rackheath', 'Rackheath', '', 52.6625400, 1.3803200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58877, 'Quorndon', 'Quorndon', '', 52.7446100, -1.1734800, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58878, 'Queniborough', 'Queniborough', 'Queniboro,Queniborough', 52.7059100, -1.0474900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58879, 'Queensferry', 'Queensferry', 'Cas Chaolais,Cas Chaolas,Queensferry,South Queensferry,jnwby kwynzfyry,جنوبی کوئنزفیری', 55.9908900, -3.3984700, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58880, 'Queensferry', 'Queensferry', '', 53.2000000, -3.0333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58881, 'Queensbury', 'Queensbury', 'Queensbury', 53.7666700, -1.9166700, 'GB', '2013-11-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58882, 'Queenborough', 'Queenborough', 'کویین‌بورو', 51.4176000, 0.7444100, 'GB', '2015-07-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58883, 'Pyle', 'Pyle', 'Pyle', 51.5166700, -3.7000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58884, 'Pwllheli', 'Pwllheli', 'Pulkheli,Pwllbeli,Pwllheli,Пулхели', 52.8899000, -4.4145100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58885, 'Purton', 'Purton', 'Purton', 51.5888900, -1.8741900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58886, 'Purley', 'Purley', 'Purley', 51.3367800, -0.1120100, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58887, 'Puriton', 'Puriton', '', 51.1693300, -2.9719800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58888, 'Purfleet', 'Purfleet', '', 51.4839000, 0.2424700, 'GB', '2016-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58889, 'Pulloxhill', 'Pulloxhill', '', 51.9948700, -0.4531600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58890, 'Pulborough', 'Pulborough', 'Pulborough', 50.9575300, -0.5128000, 'GB', '2015-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58891, 'Pudsey', 'Pudsey', 'Pudsi,padsy,Пъдси,پادسی', 53.7953800, -1.6613400, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58892, 'Puddletown', 'Puddletown', 'Piddletown,Puddletown', 50.7500000, -2.3500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58893, 'Puckeridge', 'Puckeridge', 'Puckeridge', 51.8901300, 0.0130900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58894, 'Publow', 'Publow', '', 51.3787700, -2.5435100, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58895, 'Prudhoe', 'Prudhoe', 'prwdw,پرودو', 54.9615400, -1.8516800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58896, 'Probus', 'Probus', 'Probus', 50.2926700, -4.9540100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58897, 'Priston', 'Priston', '', 51.3430600, -2.4391700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58898, 'Princetown', 'Princetown', 'Princeton,Princetown', 50.5439300, -3.9885500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58899, 'Princes Risborough', 'Princes Risborough', 'prns rysbwrw,پرنس ریسبورو', 51.7254900, -0.8314400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58900, 'Prestwick', 'Prestwick', 'Preastabhaig,Prestuik,Prestvik,Prestwick,Preswick,pu lei si te wei ke,puresutou~ikku,Прествік,Престуик,プレストウィック,普雷斯特威克', 55.4833300, -4.6166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58901, 'Prestwich', 'Prestwich', 'Prestwich', 53.5333300, -2.2833300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58902, 'Prestonpans', 'Prestonpans', 'Prestonpans', 55.9593900, -2.9803800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58903, 'Preston', 'Preston', 'Gorad Prehstan,Preston,Prestonas,Prestun,XPT,brstwn,peuleseuteon,prestana,prstwn,pu lei si dun,puresuton,Горад Прэстан,Престон,Престън,Պրեստոն,פרסטון,برستون,پرستون,پریسٹن، لنکاشائر,प्रेस्टन,プレストン,普雷斯顿,프레스턴', 53.7628200, -2.7045200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58904, 'Preston', 'Preston', '', 53.7566300, -0.1977500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58905, 'Preston', 'Preston', '', 52.6126400, -0.7143700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58906, 'Presteigne', 'Presteigne', 'Llanandras,Presteigh,Presteign,Presteigne,Prestijn,Prestin,Престийн,Престин', 52.2718300, -3.0057900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58907, 'Prestbury', 'Prestbury', 'Prestburg,Prestburis,brstbwry,برستبوري', 53.2833300, -2.1500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58908, 'Prestatyn', 'Prestatyn', 'Prestatin,Prestatinas,pu lei si ta ting,Престатин,Престатін,普雷斯塔廷', 53.3374800, -3.4077600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58909, 'Prescot', 'Prescot', 'Prescot,Prescott,prskwt,پرسکوت', 53.4294800, -2.8003100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58910, 'Preesall', 'Preesall', '', 53.9182000, -2.9663300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58911, 'Prees', 'Prees', 'Precs,Prees', 52.8968900, -2.6640100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58912, 'Poynton', 'Poynton', 'Poynton,pwyntwn-wyt-wwrth,پوینتون-ویت-وورث', 53.3500000, -2.1166700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58913, 'Poundstock', 'Poundstock', 'Poundstock,Pounstock', 50.7666700, -4.5500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58914, 'Poulton le Fylde', 'Poulton le Fylde', 'Poulton,Poulton le Fylde', 53.8333300, -2.9833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58915, 'Pott Shrigley', 'Pott Shrigley', '', 53.3095700, -2.0840500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58916, 'Potton', 'Potton', 'pwtwn,پوتون', 52.1291100, -0.2156100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58917, 'Potterspury', 'Potterspury', 'Potterspury', 52.0828800, -0.8967600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58918, 'Potters Bar', 'Potters Bar', 'Potters Bar', 51.6935300, -0.1783500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58919, 'Potterne', 'Potterne', '', 51.3291700, -2.0051900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58920, 'Potsgrove', 'Potsgrove', '', 51.9593900, -0.6175500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58921, 'Port Talbot', 'Port Talbot', 'Port Talbotas,Port Tolbut,Port-Tolbot,Puerto Talbot,poteutaelbeos,ta er bo te gang,Порт Толбът,Порт-Толбот,塔爾伯特港,포트탤벗', 51.5924100, -3.7801900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58922, 'Portstewart', 'Portstewart', 'Port Stiobhaird,Port Stíobhaird,Portst''juart,Portstjuart,Портстьюарт,Портстюарт', 55.1813200, -6.7140200, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58923, 'Portsoy', 'Portsoy', 'Port Saoidh,Portsoy', 57.6814400, -2.6895600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58924, 'Portsmouth', 'Portsmouth', 'Gorad Portsmut,Porchemue,Porchémue,Portsmouth,Portsmut,Portsmuta,Portsmutas,Portus Ostium,bwrtsmwth,phxrt smath,pocheumeoseu,portasmatha,potsumasu,pu ci mao si,pwrtsmwt'',pwrtsmwth,Πόρτσμουθ,Горад Портсмут,Портсмут,Портсмът,Պորտսմութ,פורטסמות'',بورتسموث,پورتسموث,پۆرتسموت,पोर्टस्मथ,পোর্টস্‌মাথ,พอร์ตสมัท,ポーツマス,朴次茅斯,포츠머스', 50.7989900, -1.0912500, 'GB', '2011-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58925, 'Portslade', 'Portslade', '', 50.8428600, -0.2160800, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58926, 'Portrush', 'Portrush', 'Port Rois,Portrash,Portrush,Портраш,Портръш', 55.1959200, -6.6493000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58927, 'Portree', 'Portree', 'Port Righ,Port Rìgh,Port Rígh,Portree,Portri,bo te li,Портри,波特里', 57.4128800, -6.1941800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58928, 'Portlethen', 'Portlethen', 'Am Port Leathann,Port Leathain', 57.0694200, -2.1324600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58929, 'Portknockie', 'Portknockie', 'Portknockie', 57.7024800, -2.8598900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58930, 'Portishead', 'Portishead', 'Portishead,Portishead i Somerset,Portiskhed,potiseuhedeu,Портисхед,포티스헤드', 51.4819900, -2.7697300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58931, 'Portscatho', 'Portscatho', '', 50.1727100, -4.9735600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58932, 'Porthmadog', 'Porthmadog', 'Porthmadog,Portmadoc,Portmadog,Portmadogas,Портмадог', 52.9292400, -4.1313700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58933, 'Porthleven', 'Porthleven', 'Porthleven,pwrtlwn,پورتلون', 50.0861800, -5.3150100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58934, 'Porthcawl', 'Porthcawl', 'Porthcawl,Portkaul,Portkovl,bo si kao er,Порткаул,Портковл,波斯考尔', 51.4790300, -3.7036200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58935, 'Porth', 'Porth', 'Porth', 51.6130600, -3.4036100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58936, 'Portglenone', 'Portglenone', '', 54.8714700, -6.4714600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58937, 'Port Glasgow', 'Port Glasgow', 'Port Ghlaschu,Port Ghlaschú,Port Glasgow,Port Glesga,Port-Glazgo,Порт-Глазго', 55.9346400, -4.6895000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58938, 'Port Erroll', 'Port Erroll', 'Cruden Bay,Port Errol,Port Erroll', 57.4142700, -1.8459600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58939, 'Port Bannatyne', 'Port Bannatyne', 'Kamesburgh,Port Bannatyne', 55.8566000, -5.0650300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58940, 'Portavogie', 'Portavogie', '', 54.4591600, -5.4430400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58941, 'Portaferry', 'Portaferry', 'Port an Pheire,Portaferry,portapherri,पोर्ताफेर्री', 54.3808600, -5.5456900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58942, 'Portadown', 'Portadown', 'Port an Dunain,Port an Dúnáin,Portadaun,Portadaunas,Portadoun,Portadown,Портадаун', 54.4230200, -6.4443400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58943, 'Porlock', 'Porlock', 'Porlock', 51.2088900, -3.5955600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58944, 'Poringland', 'Poringland', 'Poringland', 52.5675600, 1.3496100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58945, 'Poplar', 'Poplar', 'poplara,pwplr  lndn,پوپلر، لندن,पॉप्लर', 51.5111300, -0.0156500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58946, 'Poole', 'Poole', 'POQ,Poole,Pul,Pulas,Puul,pu er,puru,pwl  anglstan,Пул,Պուլ,پول، انگلستان,プール,普爾', 50.7142900, -1.9845800, 'GB', '2015-09-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58947, 'Pool', 'Pool', 'Pool,Pool-in-Wharfedale,Poole', 53.9000000, -1.6166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58948, 'Pontypridd', 'Pontypridd', 'Pontepridas,Pontiprit,Pontiprite,Pontuprid,Pontypridd,pang te pu li si,pontipeulideu,Понтиприт,Понтиприте,Понтъприд,龐特普里斯,폰티프리드', 51.6021000, -3.3421100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58949, 'Pontypool', 'Pontypool', 'Pont-y-pwl,Pont-y-pŵl,Pontipul,Pontupul,Pontypool,pang di pu,pontipul,Понтъпул,Понтіпул,龐蒂浦,폰티풀', 51.7011100, -3.0444400, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58950, 'Pontycymer', 'Pontycymer', 'Pont y Cymmer,Pontycymer', 51.6111800, -3.5842100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58951, 'Pontyberem', 'Pontyberem', 'Pont-y-Berem,Pontyberem', 51.7782600, -4.1689000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58952, 'Pontyates', 'Pontyates', 'Pont Yates,Pontiets,Pontyates', 51.7518200, -4.2171800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58953, 'Ponthir', 'Ponthir', 'Panthir,Pont-hir,Ponthir', 51.6322200, -2.9761100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58954, 'Pontesbury', 'Pontesbury', 'Pontesbury', 52.6482600, -2.8903500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58955, 'Ponteland', 'Ponteland', '', 55.0502400, -1.7453200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58956, 'Pontefract', 'Pontefract', 'Pontefrakt,Pontifrakt,ponteupeulaegteu,pwntfrakt,Понтефракт,Понтифракт,پونتفراکت,폰트프랙트', 53.6910700, -1.3126900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58957, 'Pontarddulais', 'Pontarddulais', '', 51.7142300, -4.0385900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58958, 'Polperro', 'Polperro', 'Polperro,Porthpyra,blbryw,Полперро,بلبريو', 50.3313000, -4.5222000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58959, 'Polmont', 'Polmont', 'Poll Mhonadh,Polmont,Polmonte,Powmont,Полмонт,Полмонте', 55.9905000, -3.7073700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58960, 'Pollington', 'Pollington', '', 53.6709300, -1.0723700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58961, 'Polesworth', 'Polesworth', '', 52.6196200, -1.6103600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58962, 'Podington', 'Podington', 'Puddington', 52.2542400, -0.6246300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58963, 'Pocklington', 'Pocklington', 'pwklyngtwn,پوکلینگتون', 53.9333500, -0.7810600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58964, 'Plymstock', 'Plymstock', 'Plymstock', 50.3599900, -4.0904900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58965, 'Plympton', 'Plympton', 'Plympton,Plympton Erle,Plympton Maurice,Plympton Saint Mary,Plympton Saint Maurice,Plymton,Ridgeway,pu lin pu dun,普林普頓', 50.3907400, -4.0602200, 'GB', '2013-11-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58966, 'Plymouth', 'Plymouth', 'Aberplymm,PLH,Pliemue,Plimmuta,Plimouth,Plimowt,Plimut,Plimuta,Plimutas,Pliémue,Plymouth,Suthtun on Defnum,Sūþtun on Defnum,blymwth,peullimeoseu,phli math,plimatha,plymwt,plymwt'',plymwth,pu li mao si,purimasu,Πλίμουθ,Плимут,Плимът,Плімут,פלימות'',بليموث,پلائیموتھ,پلیموت,پلیموث,प्लिमथ,พลิมัท,プリマス,普利茅斯,플리머스', 50.3715300, -4.1430500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58967, 'Plumpton Green', 'Plumpton Green', '', 50.9342000, -0.0612000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58968, 'Plean', 'Plean', '', 56.0651600, -3.8759600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58969, 'Pittington', 'Pittington', 'Pittington', 54.8000000, -1.4833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58970, 'Pittenweem', 'Pittenweem', 'Baile na h-Uaimh,Pittenuim,Питтенуим', 56.2140600, -2.7283900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58971, 'Pitstone', 'Pitstone', '', 51.8283000, -0.6398700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58972, 'Pitsea', 'Pitsea', '', 51.5638700, 0.5085900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58973, 'Pitmedden', 'Pitmedden', 'Pitmedden', 57.3369100, -2.1802200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58974, 'Pitlochry', 'Pitlochry', 'Baile Chloichridh,Pitlochry,Pitlokhri,Питлохри', 56.7051400, -3.7343200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58975, 'Pirton', 'Pirton', '', 51.9712000, -0.3339400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58976, 'Pirbright', 'Pirbright', '', 51.2913700, -0.6472100, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58977, 'Pinxton', 'Pinxton', '', 53.0906200, -1.3176700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58978, 'Pinner', 'Pinner', 'Pinner,pinara,Піннер,पिनर', 51.5938400, -0.3821600, 'GB', '2012-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58979, 'Pinchbeck', 'Pinchbeck', 'Pinchbeck', 52.8130300, -0.1625600, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58980, 'Pimperne', 'Pimperne', 'Pimperne', 50.8837400, -2.1362000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58981, 'Pilsley', 'Pilsley', 'Pilsley', 53.1500000, -1.3666700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58982, 'Pilning', 'Pilning', '', 51.5633700, -2.6426400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58983, 'Pillaton', 'Pillaton', '', 50.4500000, -4.3000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58984, 'Pickworth', 'Pickworth', '', 52.7131100, -0.5331800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58985, 'Pickering', 'Pickering', 'Pickering,Pickering i North Yorkshire,pkrng  shmaly yarkshayr,پکرنگ، شمالی یارکشائر,پیکرینگ، یورک‌شر شمالی', 54.2500000, -0.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58986, 'Pewsey', 'Pewsey', '', 51.3385500, -1.7654500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58987, 'Pevensey', 'Pevensey', 'Pevensey,Pevensi,pei wen xi,Певенсі,佩文西', 50.8196600, 0.3396300, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58988, 'Petworth', 'Petworth', '', 50.9866900, -0.6100000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58989, 'Petton', 'Petton', '', 52.8333300, -2.8333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58990, 'Petersfield', 'Petersfield', 'Petersfield,pytrsfyld,پیترسفیلد', 51.0049500, -0.9337500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58991, 'Peterlee', 'Peterlee', 'Peterlee,Peterli,ptrly,Петерли,پترلی', 54.7603200, -1.3364900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58992, 'Peterhead', 'Peterhead', 'Ceann Phadraig,Ceann Phàdraig,Ceann Phádraig,Peterheid,Piterkhed,Piturkhed,Pyterhedas,bi de hei de,pytrhd,Питерхед,Питърхед,Пітерхед,پیترهد,彼得黑德', 57.5058400, -1.7980600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58993, 'Peterculter', 'Peterculter', 'Culter,Peterculter', 57.0992900, -2.2658800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58994, 'Peterborough', 'Peterborough', 'Peterborough,Peterbrough,Petersborough,Petroburgum,Piterboras,Piterboro,Pīterboro,XVH,bi de bo lei,pitabara,piteobeoleo,pytrbwrw,Питерборо,Пітерборо,پیتربورو,پیٹربرا,ピーターバラ,彼得伯勒,피터버러', 52.5736400, -0.2477700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58995, 'Perth', 'Perth', 'P"rt,PSL,Pairth,Peairt,Pert,Pertas,Perth,Perth i Skottland,bo si,byrth,pasu,peoseu,prt,Περθ,Перт,Пърт,פרת,بيرث,پرت,پرتھ,پرتھ، سکاٹ لینڈ,パース,伯斯,퍼스', 56.3952200, -3.4313900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58996, 'Pertenhall', 'Pertenhall', '', 52.2793400, -0.4144800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58997, 'Pershore', 'Pershore', 'Pershore,prshwr,پرشور', 52.1116300, -2.0758600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58998, 'Perranwell', 'Perranwell', '', 50.2133300, -5.1205300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(58999, 'Perranporth', 'Perranporth', 'Perranport,Porthpyran,brnbrth,Перранпорт,برنبرث', 50.3437700, -5.1555800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59000, 'Peover Superior', 'Peover Superior', 'Peover', 53.2500000, -2.3500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59001, 'Penzance', 'Penzance', 'PZE,Pen Sans,Pennsans,Penzance,Penzans,peng zan si,penzansu,Πενζάνς,Пензанс,ပင်န်ဇန့်မြို့,ペンザンス,彭赞斯', 50.1186100, -5.5371500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59002, 'Penygroes', 'Penygroes', 'Pen-y-groes', 53.0550200, -4.2853500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59003, 'Penybont', 'Penybont', 'Penybont', 52.2666700, -3.3000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59004, 'Pentyrch', 'Pentyrch', 'Pentyrch', 51.5288900, -3.2950000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59005, 'Penryn', 'Penryn', 'Pennrynn,Penrynn,pnryn  kwrnwal,پنرین، کورنوال', 50.1681200, -5.1041600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59006, 'Penrith', 'Penrith', 'Penrit,Penrith,Penrith i England,Pioraid,Pìoraid,Píoraid,Voreda,XPF,peng li si,pnryth  kambrya,Пенрит,پنریث، کامبریا,彭里斯', 54.6657900, -2.7575700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59007, 'Penrhyndeudraeth', 'Penrhyndeudraeth', 'Penrhyn Deudraeth,Penrhyndeudraeth,Penrhyndeudreath', 52.9333300, -4.0666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59008, 'Penmaenmawr', 'Penmaenmawr', 'Penmajnmaur,Пенмайнмаур', 53.2666700, -3.9333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59009, 'Penllyn', 'Penllyn', 'Penlline,Penllyn', 51.4744400, -3.4788900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59010, 'Penkridge', 'Penkridge', 'Penkridge', 52.7255600, -2.1156000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59011, 'Penistone', 'Penistone', 'pnystwn,پنیستون', 53.5257200, -1.6302700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59012, 'Penicuik', 'Penicuik', 'Peighinn na Cuthaig,Penikjuik,pnykwk,Пенікюїк,پنیکوک', 55.8311600, -3.2260800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59013, 'Pengam', 'Pengam', 'Pengam', 51.6652800, -3.2269400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59014, 'Pencoyd', 'Pencoyd', '', 51.9333300, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59015, 'Pencoed', 'Pencoed', '', 51.5237100, -3.5001600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59016, 'Pen-clawdd', 'Pen-clawdd', '', 51.6402800, -4.0991700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59017, 'Pencaitland', 'Pencaitland', '', 55.9072700, -2.8949000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59018, 'Pencader', 'Pencader', 'Pencader', 52.0008000, -4.2657500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59019, 'Penarth', 'Penarth', 'Penart,bynarth,po na si,Пенарт,بينارث,珀納斯', 51.4386000, -3.1734200, 'GB', '2013-09-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59020, 'Penally', 'Penally', 'Penally', 51.6598600, -4.7239900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59021, 'Pembury', 'Pembury', '', 51.1429600, 0.3218700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59022, 'Pembroke Dock', 'Pembroke Dock', 'Doc Penfro,Pater,Paterchurch,Pembroke Dock,Pembruk Dok,Pembruk-Dok,Пембрук Док,Пембрук-Док', 51.6916100, -4.9403600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59023, 'Pembroke', 'Pembroke', 'Pembroke,Pembruk,Penfro,pembeulokeu,peng bu luo ke,Пембрук,彭布羅克,펨브로크', 51.6746400, -4.9128600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59024, 'Pelton', 'Pelton', '', 54.8730500, -1.6095000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59025, 'Pelsall', 'Pelsall', 'Pelsall', 52.6291000, -1.9673800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59026, 'Pegswood', 'Pegswood', '', 55.1793000, -1.6452500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59027, 'Peebles', 'Peebles', 'Na Puballan,Na Pùballan,Na Púballan,Peebles,pi bu er si,皮布尔斯', 55.6519000, -3.1888000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59028, 'Peakirk', 'Peakirk', '', 52.6456700, -0.2729400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59029, 'Paulton', 'Paulton', '', 51.3047200, -2.5002800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59030, 'Paull', 'Paull', '', 53.7200800, -0.2330300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59031, 'Pattingham', 'Pattingham', 'Pattingham', 52.5891000, -2.2653800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59032, 'Patrington', 'Patrington', '', 53.6839500, -0.0133000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59033, 'Patna', 'Patna', '', 55.3640600, -4.5059400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59034, 'Pateley Bridge', 'Pateley Bridge', 'patly bryj,پاتلی بریج', 54.0861600, -1.7598100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59035, 'Partridge Green', 'Partridge Green', '', 50.9594000, -0.3079600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59036, 'Partington', 'Partington', '', 53.4188400, -2.4281500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59037, 'Parkstone', 'Parkstone', '', 50.7299400, -1.9449200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59038, 'Parbold', 'Parbold', '', 53.5914500, -2.7702800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59039, 'Par', 'Par', 'PCW,Par', 50.3510700, -4.7028800, 'GB', '2015-07-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59040, 'Papworth Everard', 'Papworth Everard', 'Papworth,Papworth Everard', 52.2489300, -0.1182700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59041, 'Pant', 'Pant', 'Pant', 52.7900500, -3.0803100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59042, 'Pannal', 'Pannal', 'Pannal', 53.9603100, -1.5357300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59043, 'Pangbourne', 'Pangbourne', 'Pangbourne,bnghbwrn,بنغبورن', 51.4837000, -1.0851900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59044, 'Paisley', 'Paisley', 'Gorad Pejsli,Paislig,Peislis,Pejsli,Pejzli,Peysli,Pàislig,Páislig,pei si li,peijeulli,peizuri,pyyzly,pyzly,Горад Пейслі,Пейзли,Пейсли,Пейслі,Пејсли,פייזלי,پیزلی,پیزلے,ペイズリー,佩斯利,페이즐리', 55.8317300, -4.4325400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59045, 'Painswick', 'Painswick', 'Painswick,paynzwyk,peinsuu~ikku,پاینزویک,ペインスウィック', 51.7856800, -2.1955500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59046, 'Paignton', 'Paignton', 'Paignton,Pehjnton,Peintona,Pejnton,Pejntun,pei en dun,peinton,pyntwn,Пейнтон,Пейнтън,Пејнтон,Пэйнтон,پینتون,ペイントン,佩恩頓', 50.4356500, -3.5678900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59047, 'Padstow', 'Padstow', 'Lannwedhenek,padstw,پادستو', 50.5388500, -4.9366400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59048, 'Padiham', 'Padiham', 'padyham,پادیهام', 53.8018700, -2.3151100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59049, 'Paddock Wood', 'Paddock Wood', 'padwk wwd,پادوک وود', 51.1818700, 0.3822900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59050, 'Oxted', 'Oxted', '', 51.2568700, -0.0060100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59051, 'Oxford', 'Oxford', 'Ath nan Damh,Gorad Oksfard,OXF,Oksford,Oksforda,Oksfordas,Oksfordo,Oksfuords,Oxford,Oxnaford,Oxonia,Oxphorde,Rhydychen,Rysoghen,akasaforada,akcuportu,aksaphorda,aksfwrd,awksfwrd,niu jin,ogseupeodeu,okkusufodo,oksapharda,oksaphorda,okspordi,x xksf xrd,Àth nan Damh,Οξφόρδη,Горад Оксфард,Оксфорд,Оқсфорд,אוקספורד,אקספארד,آکسفورد,آکسفورڈ,أكسفورد,اوكسفورد,ऑक्सफर्ड,ऑक्सफोर्ड,অক্সফোর্ড,ਆਕਸਫ਼ੋਰਡ,ஆக்சுபோர்டு,ఆక్స్‌ఫర్డ్,ಆಕ್ಸ್‌ಫರ್ಡ್,อ๊อกซฟอร์ด,အောက်စဖို့မြို့,ოქსფორდი,オックスフォード,牛津,옥스퍼드', 51.7522200, -1.2559600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59052, 'Oxenhope', 'Oxenhope', 'Oxenhope', 53.8123300, -1.9519600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59053, 'Owston Ferry', 'Owston Ferry', 'Owston,Owston Ferry', 53.4940700, -0.7804500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59054, 'Overtown', 'Overtown', '', 55.7571900, -3.9164500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59055, 'Overton', 'Overton', '', 54.0152800, -2.8606500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59056, 'Overton', 'Overton', '', 52.9666700, -2.9333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59057, 'Overton', 'Overton', 'Overton', 51.2438900, -1.2615400, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59058, 'Overstrand', 'Overstrand', '', 52.9162300, 1.3390000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59059, 'Over', 'Over', 'Over', 53.1833300, -2.5500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59060, 'Over', 'Over', 'Over', 52.3166700, 0.0166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59061, 'Outwell', 'Outwell', '', 52.6094600, 0.2333300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59062, 'Oundle', 'Oundle', 'Oundle,awndl,اوندل', 52.4809300, -0.4673200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59063, 'Oughtibridge', 'Oughtibridge', '', 53.4361200, -1.5390200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59064, 'Ottringham', 'Ottringham', '', 53.7009200, -0.0790900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59065, 'Ottery St Mary', 'Ottery St Mary', 'OTTERY ST MARY,OTTERY ST. MARY,Ottery Saint Mary,Ottery St Mary,awtry sant mary,awtry snt mary,أوتري سانت ماري,اوتری سنت ماری', 50.7500000, -3.2666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59066, 'Ottershaw', 'Ottershaw', 'Ottershaw', 51.3626200, -0.5275200, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59067, 'Otterburn', 'Otterburn', '', 55.2334000, -2.1805900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59068, 'Otley', 'Otley', 'Otley,awtly,oteulli,اوتلی,오틀리', 53.9055300, -1.6938300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59069, 'Otford', 'Otford', '', 51.3128300, 0.1904600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59070, 'Oswestry', 'Oswestry', 'Croesoswallt,Osvestris,Oswestry,Ozuehstri,Ozuustri,awswstry,Озуъстри,Озуэстри,اوسوستری', 52.8619500, -3.0549700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59071, 'Ossett', 'Ossett', 'Oset,Ossett,awst,Осет,Оссетт,اوست', 53.6797800, -1.5800600, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59072, 'Orwell', 'Orwell', 'Orwell', 52.1356000, -0.0109900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59073, 'Orsett', 'Orsett', '', 51.5123200, 0.3675300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59074, 'Orpington', 'Orpington', 'ao er ping dun,orpingatana,اورپنگٹن، لندن,ओर्पिंगटन,奧爾平頓', 51.3745700, 0.0978500, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59075, 'Ormskirk', 'Ormskirk', 'Ormskirk,ao mu si ke ke,awrmskyrk,Ормскирк,اورمسکیرک,奧姆斯柯克', 53.5668500, -2.8817800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59076, 'Ormiston', 'Ormiston', '', 55.9130200, -2.9398500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59077, 'Ormesby St Margaret', 'Ormesby St Margaret', 'Great Ormesby,Ormesby Saint Margaret,Ormesby St Margaret', 52.6750600, 1.6885000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59078, 'Orleton', 'Orleton', 'Orleton', 52.3000000, -2.7500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59079, 'Orgreave', 'Orgreave', '', 53.3833300, -1.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59080, 'Omagh', 'Omagh', 'An Oghmagh,An Omaigh,An Ómaigh,Oma,Omey,Ouma,ao ma,awmah,oma,Ома,Оума,أوماه,オマー,奧馬,오마', 54.6000000, -7.3000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59081, 'Olveston', 'Olveston', 'Olveston', 51.5803200, -2.5775000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59082, 'Olney', 'Olney', 'Olney i Buckinghamshire,ao er ni,awlny,أولني,اولنی، باکینگهام‌شر,奧爾尼', 52.1534500, -0.7020100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59083, 'Old Windsor', 'Old Windsor', 'Old Windsor,Vetus Windesoria,ald wyndzr,الد ويندزر', 51.4580700, -0.5867400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59084, 'Oldmeldrum', 'Oldmeldrum', 'Mealdruim,Meall Druim,Old Meldrum,Oldmeldrum,Олдмелдрум', 57.3349200, -2.3199000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59085, 'Old Leake', 'Old Leake', 'Leake,Old Leake', 53.0310800, 0.0987300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59086, 'Old Kilpatrick', 'Old Kilpatrick', 'Auld Kilpatrick,Cille Phadraig,Cille Phádraig,Kilpatrick,Old Kilpatrick,West Kilpatrick', 55.9224100, -4.4556700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59087, 'Oldham', 'Oldham', 'Oldam,Oldamas,Oldem,Oldema,Oldham,Oldum,Olntam,ao er de mu,awldham,oldeom,orudamu,xo ldam,Όλνταμ,Олдам,Олдем,Олдъм,Օլդեմ,אולדהאם,أولدهام,اولدهام,โอลดัม,オールダム,奧爾德姆,올덤', 53.5405100, -2.1183000, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59088, 'Oldbury', 'Oldbury', 'Oldberis,Oldbury-Smethwick,ao er de bo li,awldbwry  mydlndz ghrby,اولدبوری، میدلندز غربی,奧爾德伯里', 52.5000000, -2.0166700, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59089, 'Okehampton', 'Okehampton', 'Ochamentona,Okehampton,awkhamptwn,اوکهامپتون', 50.7384100, -4.0016000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59090, 'Odiham', 'Odiham', 'ODH,Odiham,Odikhem,Одихем', 51.2540700, -0.9393300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59091, 'Odell', 'Odell', '', 52.2093700, -0.5888000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59092, 'Ocle Pychard', 'Ocle Pychard', '', 52.1166700, -2.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59093, 'Ockley', 'Ockley', '', 51.1467800, -0.3636600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59094, 'Ochiltree', 'Ochiltree', 'Ochiltree', 55.4598100, -4.3678200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59095, 'Oban', 'Oban', 'An t-Oban,An t-Òban,An t-Óban,OBN,Oban,Oban i Skottland,Oub"n,ao ben,oban,Обан,Оубън,オーバン,奧本', 56.4153500, -5.4718400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59096, 'Oakley', 'Oakley', 'Oakley', 56.0842100, -3.5631100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59097, 'Oakley', 'Oakley', '', 52.1686200, -0.5264900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59098, 'Oakley', 'Oakley', 'Oakley', 51.8040600, -1.0726100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59099, 'Oakington', 'Oakington', '', 52.2604400, 0.0684900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59100, 'Oakham', 'Oakham', 'OKH,Okem,ao ke mu,awkham,okeom,Окем,اوکهام,奧克姆,오컴', 52.6666700, -0.7333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59101, 'Oakengates', 'Oakengates', '', 52.6950100, -2.4503600, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59102, 'Oadby', 'Oadby', 'Oadby,Oudbi,Оудби', 52.6062100, -1.0835400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59103, 'Nunthorpe', 'Nunthorpe', '', 54.5288000, -1.1843800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59104, 'Nuneaton', 'Nuneaton', 'Naniton,Nonne Etone,Nuneaton,XNV,na ni dun,nanytwn,nuniton,Нанитон,نانیتون,ヌニートン,納尼頓', 52.5232300, -1.4652300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59105, 'Notton', 'Notton', '', 53.6126700, -1.4723400, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59106, 'Nottingham', 'Nottingham', 'NQT,Nottigham,Nottingem,Nottingham,nottingamu,nuo ding han,nuo ding xian,nwtnghham,Ноттингем,Ноттингҳам,נוטינגהאם,نوتنغهام,ノッティンガム,諾定咸,诺丁汉', 52.9536000, -1.1504700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59107, 'Norwich', 'Norwich', 'NWI,Nordovicum,Norgouits,Norich,Noridzas,Noridzh,Noridžas,Norvic,Norvich,Norviç,Norwich,narwch,nolichi,noritchi,nuo li qi,nwrwych,nwrwytsh,nx rich,Νόργουιτς,Норвіч,Норидж,Норич,ناروچ,نورويتش,نورویچ,นอริช,ノリッチ,諾里奇,노리치', 52.6278300, 1.2983400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59108, 'Norton Canes', 'Norton Canes', 'Norton Canes', 52.6714200, -1.9626200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59109, 'Norton', 'Norton', 'Norton,Norton-on-Derwent', 54.1330300, -0.7850100, 'GB', '2017-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59110, 'Norton', 'Norton', '', 53.6333300, -1.1833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59111, 'Norton', 'Norton', '', 51.5594400, -2.1650000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59112, 'North Wraxall', 'North Wraxall', '', 51.4734000, -2.2630000, 'GB', '2017-06-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59113, 'Northwood', 'Northwood', '', 50.7410200, -1.3119200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59114, 'Northwich', 'Northwich', 'Northwich,Nortvicas,Nortvich,Nortvičas,nwrtwych,Нортвич,نورتویچ', 53.2588200, -2.5202500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59115, 'North Walsham', 'North Walsham', 'North Walsham,Walsham Thuaidh,nwrth walsham,نورث والشام', 52.8212100, 1.3874600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59116, 'North Thoresby', 'North Thoresby', 'North Thoresby', 53.4665100, -0.0557500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59117, 'North Tawton', 'North Tawton', '', 50.7996800, -3.8975900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59118, 'North Sunderland', 'North Sunderland', 'North Sunderland', 55.5768800, -1.6643600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59119, 'North Somercotes', 'North Somercotes', 'North Somercotes', 53.4457300, 0.1410300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59120, 'North Shields', 'North Shields', 'Shields Thuaidh', 55.0164600, -1.4492500, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59121, 'North Queensferry', 'North Queensferry', 'Port na Banrighinn', 56.0089900, -3.3913400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59122, 'North Petherton', 'North Petherton', 'North Petherton,nwrth ptrtwn,نورث پترتون', 51.0924300, -3.0154900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59123, 'Northorpe', 'Northorpe', '', 53.4630700, -0.6534700, 'GB', '2015-12-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59124, 'Northop', 'Northop', '', 53.2069200, -3.1327700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59125, 'Northolt', 'Northolt', 'NHT,Northolt,northaholta,نورتھولٹ,नॉर्थहॉल्ट', 51.5485500, -0.3677800, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59126, 'North Newbald', 'North Newbald', 'North Newbald', 53.8166700, -0.6166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59127, 'North Luffenham', 'North Luffenham', 'North Luffenham', 52.6210800, -0.6198700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59128, 'North Leigh', 'North Leigh', 'North Leigh', 51.8143200, -1.4414400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59129, 'Northleach', 'Northleach', 'Northleach,nosurichi,ノースリーチ', 51.8299400, -1.8371200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59130, 'Lancing', 'Lancing', 'Lancing,North Lancing', 50.8288200, -0.3224700, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59131, 'Northiam', 'Northiam', '', 50.9943900, 0.6002600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59132, 'North Hill', 'North Hill', '', 50.5500000, -4.4333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59133, 'North Ferriby', 'North Ferriby', 'Ferriby,North Ferriby', 53.7212400, -0.5052000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59134, 'North Elmsall', 'North Elmsall', '', 53.6088500, -1.2821400, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59135, 'North Elmham', 'North Elmham', '', 52.7464000, 0.9461100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59136, 'North Collingham', 'North Collingham', 'Collingham,North Collingham', 53.1500000, -0.7500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59137, 'North Cave', 'North Cave', '', 53.7801200, -0.6496500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59138, 'North Bradley', 'North Bradley', 'North Bradley', 51.2950000, -2.2047200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59139, 'Northborough', 'Northborough', 'Northborough', 52.6586800, -0.2981800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59140, 'North Berwick', 'North Berwick', 'Bearaig a Tuath,Bearaig-a-Tuath,Nort-Berik,Nort-Bervik,North Berwick,Норт-Бервік,Норт-Берик', 56.0582500, -2.7229000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59141, 'Northampton', 'Northampton', 'Norsempton,Nortamptonas,Nortgempton,Northampton,Northamptonia,Nortkhamptun,Nortkhempton,ORM,bei an pu dun,nosaempeuteon,nozanputon,nwrthambtwn,nwrthhambtwn,Νορθάμπτον,Нортгемптон,Нортхамптън,Нортхемптон,Նորթհեմփթոն,نارتھیمپٹن,نورثامبتون,نورثهامبتون,نورث‌همپتون,നോർത്താംപ്റ്റൺ,ノーザンプトン,北安普顿,노샘프턴', 52.2500000, -0.8833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59142, 'Northam', 'Northam', 'Northam', 51.0333300, -4.2166700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59143, 'Northallerton', 'Northallerton', 'XNO,nosaelleoteon,nuo si a lei dun,nwrthalrtwn,نورثالرتون,諾斯阿勒頓,노샐러턴', 54.3390100, -1.4324300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59144, 'Normanton', 'Normanton', '', 53.7000000, -1.4166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59145, 'Normandy', 'Normandy', '', 51.2575100, -0.6747200, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59146, 'Norbury', 'Norbury', '', 52.5333300, -2.9500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59147, 'Niton', 'Niton', 'Najton,Niton,Найтон', 50.5870200, -1.2848900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59148, 'Ninfield', 'Ninfield', 'Ninfield', 50.8864100, 0.4252900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59149, 'Neyland', 'Neyland', 'New Milford,Neyland', 51.7101400, -4.9515500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59150, 'New Tredegar', 'New Tredegar', 'New Tredegar', 51.7205100, -3.2413000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59151, 'Newtownstewart', 'Newtownstewart', '', 54.7177800, -7.3788600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59152, 'Newtown St Boswells', 'Newtown St Boswells', 'Newtown St Boswells', 55.5788700, -2.6687400, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59153, 'Newtownards', 'Newtownards', 'Baile Nua na hArda,N''jutaunards,Niutonardsas,Njutaunards,niu dui na zi,Ньютаунардс,Нютаунардс,紐敦納茲', 54.5923600, -5.6909200, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59154, 'Newtownabbey', 'Newtownabbey', 'Baile na Mainistreach,N''jutaunabbi,N''jutonehbbej,Newtownabbey,Njutaunabi,Njutonabi,niu dui a bi,Њутонаби,Ньютаунабби,Ньютонэббей,Нютаунаби,تیوتاون‌ابی,紐敦阿比', 54.6598300, -5.9085800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59155, 'Newtown', 'Newtown', 'Neapolis,Newtown,Niutaunas,Njutaun,Tre-Newydd,Y Drenewydd,Нютаун,نیو ٹاؤن، پوویز', 52.5166700, -3.3000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59156, 'Newton Stewart', 'Newton Stewart', 'Baile Ur nan Stiubhartach,Baile Ùr nan Stiùbhartach,Baile Úr nan Stiúbhartach,Njutun Stjuart,Нютън Стюарт', 54.9578400, -4.4831500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59157, 'Newton Poppleford', 'Newton Poppleford', '', 50.7000000, -3.2958600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59158, 'Newtonmore', 'Newtonmore', 'Baile Ur an t-Sleibh,Baile Ur an t-Sléibh,Baile Ùr an t-Slèibh,Newtonmore', 57.0656700, -4.1209700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59159, 'Newton Mearns', 'Newton Mearns', 'Baile Ur na Maoirne,Baile Ùr na Maoirne,Baile Úr na Maoirne,N''juton-Mirns,Newton Mearns,nywtn mrnz,Ньютон-Мірнс,نیوتن مرنز', 55.7733400, -4.3333900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59160, 'Newton Longville', 'Newton Longville', 'Newton Longville', 51.9760000, -0.7659500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59161, 'Newton-le-Willows', 'Newton-le-Willows', 'Newton-le-Willows,nywtwn-lh-wylwwz,نیوتون-له-ویلووز', 53.4500000, -2.6000000, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59162, 'Newtonhill', 'Newtonhill', 'Newtonhill', 57.0333300, -2.1500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59163, 'Newton Ferrers', 'Newton Ferrers', 'Newton Ferrers', 50.3146700, -4.0392000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59164, 'Newton Aycliffe', 'Newton Aycliffe', 'Newton Aycliffe', 54.6184200, -1.5719000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59165, 'Newton Abbot', 'Newton Abbot', 'N''juton-Ehbbot,Newton Abbot,Njutun Abut,nywtwn abwt,Ньютон-Эббот,Нютън Абът,نیوتون آبوت', 50.5285800, -3.6118600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59166, 'Scone', 'Scone', 'New Scone,Scone i Perthshire,Sgain,Sgàin,Sgáin,si kun,sukun,スクーン,斯昆', 56.4194200, -3.4050700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59167, 'Newry', 'Newry', 'An tiur,An tïúr,Iubhar Cinn Tragha,Iubhar Cinn Trágha,Iuir Cinn Tra,Iuorus,Iur Cinn Tra,Iúir Cinn Trá,Iúr Cinn Trá,N''juri,Newry,Niuris,Niūris,Njuri,Nyuri,Yn Euar,niu li,nyuli,nyuri,nywry,Ньюри,Нюри,Նյուրի,ניורי,نیوری,ニューリー,纽里,뉴리', 54.1784100, -6.3373900, 'GB', '2017-03-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59168, 'New Romney', 'New Romney', 'nyw ramny,نیو رامنی', 50.9859900, 0.9412200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59169, 'New Quay', 'New Quay', 'New Quay,Y Cei Newydd', 52.2151500, -4.3588700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59170, 'Newquay', 'Newquay', 'N''juki,NQY,Newquay,Njukij,Tewyn Plustry,Tewynblustri,nyuki,nywky,Ньюки,Нюкий,نیوکی,ニューキー', 50.4155700, -5.0731900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59171, 'Newport Pagnell', 'Newport Pagnell', 'Newport Pagnell,Njuport Pagnel,nywpwrt pagnl,Нюпорт Пагнел,نیوپورت پاگنل', 52.0873100, -0.7221800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59172, 'Newport-On-Tay', 'Newport-On-Tay', 'Newport', 56.4391100, -2.9367000, 'GB', '2006-07-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59173, 'Newport', 'Newport', '', 53.7633300, -0.6998600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59174, 'Newport', 'Newport', 'N''juport,Newport,Ньюпорт', 52.7668400, -2.3773400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59175, 'Newport', 'Newport', 'Njuport,Trefdraeth,Нюпорт,نیوپورٹ، پیمبروک شائر', 52.0166700, -4.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59176, 'Newport', 'Newport', 'Casnewydd,Gorad N''jupart,N''juport,Newport,Niouport,Niuportas,Njuport,Novus Burgus,Nuporta,Nyuport,Trefdraeth,XNE,n''yuporta,niu bo te,niw phxrt,nyupoteu,nyupoto,nywbwrt,nywpwrt,Ņūporta,Νιούπορτ,Њупорт,Горад Ньюпарт,Ньюпорт,Нюпорт,Նյուպորտ,ניופורט,نيوبورت,نیوپورت,نیوپورٹ,نیوپورٹ، ویلز,न्यूपोर्ट,นิวพอร์ต,ニューポート,纽波特,뉴포트', 51.5877400, -2.9983500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59177, 'Newport', 'Newport', 'N''juport,Newport pa Isle of Wight,Newport på Isle of Wight,niu bo te,nyupoteu,nyupoto,nywpwrt  jzyrh wayt,Ньюпорт,نیوپورت، جزیره وایت,ニューポート,紐波特,뉴포트', 50.7014600, -1.2912400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59178, 'New Pitsligo', 'New Pitsligo', 'New Pitsligo', 57.5901900, -2.1953500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59179, 'New Milton', 'New Milton', 'nyw myltn,نیو میلتن', 50.7560100, -1.6658000, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59180, 'Newmilns', 'Newmilns', 'Na Muilnean Ura', 55.6075100, -4.3241600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59181, 'New Mills', 'New Mills', 'niyu mils,nyw mylz,نیو میلز,நியூ மில்ஸ்', 53.3659200, -1.9998600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59182, 'Newmarket', 'Newmarket', 'N''jumarket,Newmarket,Newmarket i Suffolk,nyumaketto,nywmarkt  safk,Ньюмаркет,نیومارکت، سافک,ニューマーケット', 52.2446700, 0.4041800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59183, 'New Malden', 'New Malden', 'New Malden,Niou Malnten,n''yu moldana,nyumoldeun,Νιου Μάλντεν,न्यू मॉल्डन,뉴몰든', 51.4006500, -0.2617000, 'GB', '2015-02-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59184, 'Newmains', 'Newmains', 'Newmains', 55.7851400, -3.8746500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59185, 'Newmacher', 'Newmacher', 'New Machar,Newmachar,Newmacher', 57.2666700, -2.1833300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59186, 'Newington', 'Newington', '', 51.3521700, 0.6676800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59187, 'Newick', 'Newick', '', 50.9751800, 0.0157900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59188, 'Newhaven', 'Newhaven', 'Newhaven,Newhaven i East Sussex,niu hei wen,nywhawn  asks shrqy,نیوهاون، اسکس شرقی,紐黑文', 50.7969300, 0.0554500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59189, 'New Ferry', 'New Ferry', '', 53.3604600, -2.9937700, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59190, 'Newent', 'Newent', 'nywnt,نیونت', 51.9336500, -2.4081500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59191, 'Newdigate', 'Newdigate', '', 51.1666400, -0.2910500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59192, 'New Cumnock', 'New Cumnock', 'New Cumnock', 55.3956300, -4.1845800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59193, 'Newchurch', 'Newchurch', '', 50.6674400, -1.2082800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59194, 'Newcastle upon Tyne', 'Newcastle upon Tyne', 'An Caisteal Nuadh,Gorad N''jukasl-apan-Tajn,N''jukasl,N''jukasl-apon-Tajn,NCL,Neuchate,Neuchâté,Newcastle,Newcastle tren song Tyne,Newcastle trên sông Tyne,Newcastle upon Tyne,Newcastle-on-Tyne,Newcastle-upon-Tyne,Nioukasl,Niukaslas prie Taino,Njukasl na Tajnu,Njukasul upon Tajn,Novum Castellum,Nukasla pie Tainas,Nyukasl apon Tayn,n''yukesala apona ta''ina,ni''ukyasala apana tya''ina,niw khas seilxa phxn thin,nyukaeseul-eopontain,nywkasl,nywkasl abwn tayn,tai en he pan niu ka si er,Ņūkāsla pie Tainas,Νιούκασλ,Њукасл на Тајну,Горад Ньюкасл-апан-Тайн,Ньюкасл,Ньюкасл-апон-Тайн,Нюкасъл ъпон Тайн,ניוקאסטל,ניוקאסל,نيوكاسل أبون تاين,نیوکاسل,نیوکاسڵ,न्यूकॅसल अपॉन टाईन,নিউক্যাসল আপন ট্যাইন,นิวคาสเซิลอะพอนไทน์,ნიუკასლ-აპონ-ტაინი,ニューカッスル・アポン・タイン,泰恩河畔纽卡斯尔,뉴캐슬어폰타인', 54.9732800, -1.6139600, 'GB', '2017-06-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59195, 'Newcastle under Lyme', 'Newcastle under Lyme', 'Newcastle under Lyme,Newcastle-under-Lyme', 53.0000000, -2.2333300, 'GB', '2016-12-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59196, 'Newcastle Emlyn', 'Newcastle Emlyn', 'Castell Newydd Emlyn,Castellnewydd Emlyn,Newcastle Emlyn,Njukasul Emlin,Нюкасъл Емлин', 52.0405600, -4.4667000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59197, 'Newbury', 'Newbury', 'EWY,N''juberi,Neubiria,Newbury i Berkshire,Niuberis,Njuburi,Ulfretun,Ulfretūn,niu bo li,nyuberi,nywbwry  brkshr,Ньюбери,Нюбъри,نیوبوری، برکشر,ニューベリー,纽伯里', 51.4014800, -1.3247100, 'GB', '2015-01-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59198, 'Newburn', 'Newburn', '', 54.9876000, -1.7441500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59199, 'Newburgh', 'Newburgh', 'Newburgh', 57.3171100, -2.0044900, 'GB', '2017-06-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59200, 'Newburgh', 'Newburgh', 'Newburgh', 56.3507900, -3.2365000, 'GB', '2017-06-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59201, 'Newbridge', 'Newbridge', '', 55.9333300, -3.4000000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59202, 'Newbridge', 'Newbridge', 'Cefn Bychan,Newbridge', 51.6666700, -3.1333300, 'GB', '2016-02-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59203, 'Newborough', 'Newborough', '', 52.6389000, -0.2233300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59204, 'Newbold Verdon', 'Newbold Verdon', 'Newbold Verdon', 52.6295900, -1.3422000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59205, 'Newbiggin-by-the-Sea', 'Newbiggin-by-the-Sea', 'nywbygyn-bay-dh-sy,نیوبیگین-بای-ده-سی', 55.1853200, -1.5146900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59206, 'Newbiggin', 'Newbiggin', '', 54.6417100, -2.1355500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59207, 'Newarthill', 'Newarthill', 'Newarthill', 55.8151000, -3.9373300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59208, 'Newark on Trent', 'Newark on Trent', 'Newark,Newark on Trent,Newark upon Trent', 53.0666700, -0.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59209, 'New Alresford', 'New Alresford', 'Novum Forum,nyw awlrsfwrd,نیو اولرسفورد', 51.0862400, -1.1701100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59210, 'Nefyn', 'Nefyn', 'Nefyn,Nevin,Невин', 52.9353800, -4.5225000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59211, 'Nevern', 'Nevern', 'Nevern', 52.0238700, -4.8006800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59212, 'Nettleton', 'Nettleton', '', 51.5022200, -2.2625000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59213, 'Nettleham', 'Nettleham', '', 53.2660300, -0.4886600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59214, 'Netley', 'Netley', 'Abbaye de Netley,Netley,Netley Abbey,Netley Marsh', 50.8763400, -1.3539800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59215, 'Netherton', 'Netherton', 'Netherton', 52.4833300, -2.0833300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59216, 'Nether Stowey', 'Nether Stowey', '', 51.1510100, -3.1567600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59217, 'Nether Poppleton', 'Nether Poppleton', 'Nether Poppleton', 53.9879300, -1.1506200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59218, 'Netheravon', 'Netheravon', '', 51.2361300, -1.7908300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59219, 'Neston', 'Neston', 'nstwn,نستون', 53.2833300, -3.0500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59220, 'Nelson', 'Nelson', 'Nelson,nlswn  lankashr,نلسون، لانکاشر', 53.8333300, -2.2000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59221, 'Nelson', 'Nelson', '', 51.6533300, -3.2844400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59222, 'Neilston', 'Neilston', 'Baile Neill,Baile Nèill,Baile Néill,Neilston,Neilstoun,nylstn,نيلستن', 55.7857400, -4.4263700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59223, 'Needingworth', 'Needingworth', 'Needingworth', 52.3305100, -0.0311600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59224, 'Needham Market', 'Needham Market', 'nydham markt,نیدهام مارکت', 52.1555000, 1.0516000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59225, 'Necton', 'Necton', '', 52.6499400, 0.7753900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59226, 'Neath', 'Neath', 'Castell Nedd,Castell-nedd,Neath,Nijt,Nit,Nitas,ni si,Нийт,Нит,尼思', 51.6631700, -3.8044300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59227, 'Navenby', 'Navenby', 'Navenby', 53.1068000, -0.5249400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59228, 'Nash', 'Nash', '', 51.5488900, -2.9461100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59229, 'Narborough', 'Narborough', 'Narborough', 52.6833300, 0.5833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59230, 'Narborough', 'Narborough', 'Narborough', 52.5666700, -1.2000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59231, 'Narberth', 'Narberth', 'Arberth,Narberth,Narburt,Нарбърт', 51.7978400, -4.7427500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59232, 'Nantwich', 'Nantwich', 'nan te wei qi,نانت‌ویچ,楠特威奇', 53.0687800, -2.5205100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59233, 'Nairn', 'Nairn', 'Inbhir Narann,Nairn,Nehrn,Nern,nai en,Нерн,Нэрн,奈恩', 57.5809400, -3.8797300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59234, 'Nailsworth', 'Nailsworth', 'Nailsworth,naylswwrth,نایلسوورث', 51.6938200, -2.2199000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59235, 'Nailsea', 'Nailsea', 'Nailsea,naylsy,نایلسی', 51.4323900, -2.7584700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59236, 'Nafferton', 'Nafferton', '', 54.0196500, -0.3919000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59237, 'Mytholmroyd', 'Mytholmroyd', '', 53.7306500, -1.9825800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59238, 'Mylor Bridge', 'Mylor Bridge', 'Mylor,Mylor Bridge', 50.1850600, -5.0796300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59239, 'Musselburgh', 'Musselburgh', 'Baile nam Feusgan,Maselburg,Masselboro,Masselburg,ma se er bao,maslbrg,Маселбург,Масселборо,Масселбург,ماسلبرگ,馬瑟爾堡', 55.9417000, -3.0499100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59240, 'Murton', 'Murton', '', 54.8181200, -1.3903600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59241, 'Mundford', 'Mundford', 'Mundford', 52.5093000, 0.6499100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59242, 'Mundesley', 'Mundesley', 'Mundersley', 52.8784200, 1.4297000, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59243, 'Mullion', 'Mullion', 'mwlyn,مولين', 50.0270600, -5.2424800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59244, 'Mulbarton', 'Mulbarton', '', 52.5591300, 1.2332700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59245, 'Muir of Ord', 'Muir of Ord', 'Muir of Ord', 57.5197600, -4.4593900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59246, 'Muirkirk', 'Muirkirk', 'Muirkirk', 55.5227200, -4.0655100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59247, 'Muirhead', 'Muirhead', 'Muirhead,Muirhead of Liff', 56.5000000, -3.0666700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59248, 'Muggleswick', 'Muggleswick', 'Muggleswick', 54.8333300, -1.9333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59249, 'Much Wenlock', 'Much Wenlock', 'Much Wenlock,mach wnlak,meochiwenlog,wen luo ke,ماچ ونلاک,マッチ・ウェンロック,溫洛克,머치웬록', 52.5958200, -2.5574900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59250, 'Much Hadham', 'Much Hadham', '', 51.8540700, 0.0718800, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59251, 'Much Birch', 'Much Birch', '', 51.9710800, -2.7234900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59252, 'Moy', 'Moy', 'Moy', 54.4500000, -6.6666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59253, 'Mountsorrel', 'Mountsorrel', 'Mountsorrel', 52.7166700, -1.1500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59254, 'Mountain Ash', 'Mountain Ash', 'Aberpennar', 51.6836100, -3.3800800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59255, 'Moulton Chapel', 'Moulton Chapel', '', 52.7466800, -0.0827400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59256, 'Moulsoe', 'Moulsoe', 'Moulsoe', 52.0688000, -0.6732600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59257, 'Mouldsworth', 'Mouldsworth', '', 53.2333300, -2.7333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59258, 'Motherwell', 'Motherwell', 'Madervelis,Mazervell,Mitherwall,Moteruehll,Motervell,Muduruel,Tobar na Mathar,Tobar na Màthar,Tobar na Máthar,XQW,ma se wei er,madrwl,mazau~eru,meodeowel,Мазервелл,Мотервелл,Мотеруэлл,Мъдъруел,مادرول,マザーウェル,馬瑟威爾,머더웰', 55.7892400, -3.9918700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59259, 'Motcombe', 'Motcombe', '', 51.0292900, -2.2162700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59260, 'Mostyn', 'Mostyn', '', 53.3127100, -3.2676500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59261, 'Mossley', 'Mossley', 'mwsly,موسلی', 53.5145400, -2.0346200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59262, 'Moss', 'Moss', '', 53.6166700, -1.1000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59263, 'Morriston', 'Morriston', 'Morriston,Treforys', 51.6699500, -3.9294100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59264, 'Morpeth', 'Morpeth', 'Morpet,Morpitium,mo po si,mopeseu,Морпет,مورپث، نورث‌آمبرلند,莫珀斯,모페스', 55.1688200, -1.6889300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59265, 'Morley', 'Morley', 'Morley i West Yorkshire,Morli,mwrly  ywrkshayr ghrby,Морли,مورلی، یورکشایر غربی', 53.7401300, -1.5987700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59266, 'Moreton in Marsh', 'Moreton in Marsh', 'Moreton in Marsh,Moreton in the Marsh', 51.9896400, -1.7029700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59267, 'Moretonhampstead', 'Moretonhampstead', 'mwrtwnhampstyd,مورتونهامپستید', 50.6607700, -3.7649500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59268, 'Moreton', 'Moreton', 'Moreton', 53.4000000, -3.1166700, 'GB', '2012-04-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59269, 'Morecambe', 'Morecambe', 'Morecambe,Morkam,Morkamas,Morkem,mo ke mu,mwrkm,Моркам,Моркем,مورکم,莫克姆', 54.0683500, -2.8610800, 'GB', '2013-10-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59270, 'Morden', 'Morden', 'Morden,mo deng,莫登', 51.3982200, -0.1983700, 'GB', '2010-08-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59271, 'Morcott', 'Morcott', 'Morcott', 52.5966900, -0.6370400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59272, 'Morchard Bishop', 'Morchard Bishop', 'Morchard Bishop', 50.8541600, -3.7489400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59273, 'Montrose', 'Montrose', 'Monadh Rois,Montrose,Montrose i Angus,Montrouz,Montroz,Montrozas,Монтроз,Монтроуз', 56.7168300, -2.4669500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59274, 'Monmouth', 'Monmouth', 'Gorad Monmut,Menoe,Monemuta,Monmouth,Monmut,Trefynwy,manama''utha,meng mao si,monama''utha,monmasu,monmeoseu,mwnmwt,vikipidiya sahara,Μόνμουθ,Горад Монмут,Монмут,Монмът,מאנמעטה,מונמות,मनमाउथ,मॉनमाउथ,विकिपीडिया शहर,മൊൻമത്,モンマス,蒙茅斯,몬머스', 51.8126500, -2.7136300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59275, 'Monk Fryston', 'Monk Fryston', 'Monk Fryston', 53.7616000, -1.2375100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59276, 'Monifieth', 'Monifieth', 'Monadh Feith,Monadh Feithe,Monadh Fèithe,Monifieth,Monifijt,Монифийт', 56.4822700, -2.8173200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59277, 'Moneymore', 'Moneymore', '', 54.6922900, -6.6695600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59278, 'Mollington', 'Mollington', '', 53.2293400, -2.9215900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59279, 'Mold', 'Mold', 'Mold,Moldas,Mould,Yr Wyddgrug,mo er de,moldeu,Молд,Моулд,莫爾德,몰드', 53.1667400, -3.1414300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59280, 'Moira', 'Moira', 'Maigh Rath,Mojra,mo''ira,Мойра,मोइरा', 54.4802100, -6.2282200, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59281, 'Moira', 'Moira', '', 52.7369800, -1.5349600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59282, 'Moffat', 'Moffat', 'Am Magh Fada,Mofat,Мофат', 55.3352700, -3.4414200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59283, 'Moelfre', 'Moelfre', 'Moelfre', 53.3522800, -4.2373400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59284, 'Modbury', 'Modbury', 'Modbury', 50.3495700, -3.8868400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59285, 'Mochdre', 'Mochdre', '', 53.2833300, -3.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59286, 'Mochdre', 'Mochdre', '', 52.4833300, -3.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59287, 'Moccas', 'Moccas', 'Moccas', 52.0772900, -2.9453200, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59288, 'Mobberley', 'Mobberley', 'Mobberley', 53.3166700, -2.3166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59289, 'Mitchel Troy', 'Mitchel Troy', '', 51.7872800, -2.7373100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59290, 'Mitcheldean', 'Mitcheldean', 'Milcheldean,Mitcheldean,mytchldyn,میتچلدین', 51.8644000, -2.4895000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59291, 'Mitcham', 'Mitcham', 'Mitcham', 51.4032200, -0.1683100, 'GB', '2014-12-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59292, 'Mistley', 'Mistley', 'Mistley', 51.9433100, 1.0825400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59293, 'Misterton', 'Misterton', 'Misterton', 53.4449200, -0.8503200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59294, 'Mirfield', 'Mirfield', 'Murfijld,myrfyld,Мърфийлд,میرفیلد', 53.6734300, -1.6963600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59295, 'Mintlaw', 'Mintlaw', '', 57.5241400, -2.0009900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59296, 'Minster Lovell', 'Minster Lovell', 'Minster Lovell', 51.7927400, -1.5483000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59297, 'Minsterley', 'Minsterley', 'Minsterley', 52.6398900, -2.9280700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59298, 'Minety', 'Minety', '', 51.6166700, -1.9500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59299, 'Minehead', 'Minehead', 'Minehead,mynhyd,مینهید', 51.2045200, -3.4828400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59300, 'Minchinhampton', 'Minchinhampton', 'Minchinhampton', 51.7067500, -2.1850200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59301, 'Milverton', 'Milverton', 'Milverton', 51.0233300, -3.2522200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59302, 'Milton Keynes', 'Milton Keynes', 'KYN,MK,Middeltūn þǣra de Cahaignes,Milton Keinsas,Milton Keynes,Milton Kins,Milton-Kins,Milton-Kinz,mi er dun kai en si,milteonkeinseu,myltwn kynz,Милтон-Кинс,Мілтон-Кінз,Միլթոն-Քինս,ميلتون كينز,میلتون کینز,ミルトン・キーンズ,米尔顿凯恩斯,밀턴케인스', 52.0417200, -0.7558300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59303, 'Milton Bryan', 'Milton Bryan', '', 51.9500000, -0.5833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59304, 'Milston', 'Milston', '', 51.2062100, -1.7690100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59305, 'Milnthorpe', 'Milnthorpe', 'Milnthorpe', 54.2278500, -2.7693900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59306, 'Milnrow', 'Milnrow', '', 53.6111500, -2.1126600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59307, 'Milngavie', 'Milngavie', 'Milguy,Milngavie,Milngevi,Molqay,Muileann Dhaibhidh,Muileann Dhàibhidh,Muileann Dháibhidh,Мілнгеві', 55.9407100, -4.3231100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59308, 'Milnathort', 'Milnathort', 'Milnathort', 56.2268800, -3.4193000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59309, 'Milltimber', 'Milltimber', 'Milltimber', 57.1042400, -2.2409900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59310, 'Millport', 'Millport', '', 55.7534800, -4.9255900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59311, 'Millom', 'Millom', 'mylwm,میلوم', 54.2107200, -3.2720000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59312, 'Millisle', 'Millisle', '', 54.6063800, -5.5297300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59313, 'Millington', 'Millington', '', 53.9500000, -0.7333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59314, 'Millbrook', 'Millbrook', '', 52.0388200, -0.5243800, 'GB', '2016-02-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59315, 'Millbrook', 'Millbrook', '', 50.3492500, -4.2150600, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59316, 'Milford on Sea', 'Milford on Sea', 'Milford,Milford on Sea', 50.7256100, -1.5900400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59317, 'Milford Haven', 'Milford Haven', 'Aberdaugleddau,Milford,Milford Haven,Milford Heivenas,Milford Khejvun,mi er fu de gang,mylfwrd hafn,Милфорд Хейвън,ميلفورد هافن,میلفورڈ ہیون,米爾福德港', 51.7127800, -5.0341000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59318, 'Milford', 'Milford', '', 51.1727200, -0.6504200, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59319, 'Mildenhall', 'Mildenhall', 'MHZ,Mildenhall,myldnhal  safk,میلدنهال، سافک', 52.3444600, 0.5108600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59320, 'Mildenhall', 'Mildenhall', 'Cunetio', 51.4256000, -1.6998800, 'GB', '2013-05-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59321, 'Milborne St Andrew', 'Milborne St Andrew', 'Milborne,Milborne Saint Andrew,Milborne St Andrew', 50.7782900, -2.2811400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59322, 'Milborne Port', 'Milborne Port', '', 50.9660500, -2.4624800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59323, 'Midsomer Norton', 'Midsomer Norton', 'mydswmr nwrtwn,میدسومر نورتون', 51.2856700, -2.4859100, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59324, 'Midhurst', 'Midhurst', 'Midhurst,mydhwrst,میدهورست', 50.9855900, -0.7400300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59325, 'Middle Winterslow', 'Middle Winterslow', '', 51.0934600, -1.6545300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59326, 'Middlewich', 'Middlewich', 'Middlewich,Middlewick,mydlwych,میدلویچ', 53.1929600, -2.4440200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59327, 'Middleton', 'Middleton', 'Middleton', 53.5500000, -2.2000000, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59328, 'Middlestown', 'Middlestown', 'Middlestown,Middletown', 53.6507900, -1.5976200, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59329, 'Middlesbrough', 'Middlesbrough', 'Gorad Midlsbra,Middlebrough,Middlesborough,Middlesbrough,Midlsbro,Midulzbro,Mintlesmpro,mi de er si bo lei,mid deilsbe rx,midalsabro,mideuljeubeuleo,midlzbro,midoruzubura,mydlsbrw,mydlzbrt,mydlzbwrw,Μίντλεσμπρο,Горад Мідлсбра,Мидлсбро,Мидълзбро,Мідлсбро,מידלזברא,מידלסברו,ميدلزبرة,میدلزبورو,मिडल्सब्रो,มิดเดิลส์เบรอ,მიდლზბრო,ミドルズブラ,米德爾斯伯勒,미들즈브러', 54.5762300, -1.2348300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59330, 'Middle Rasen', 'Middle Rasen', '', 53.3872200, -0.3620200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59331, 'Mid Calder', 'Mid Calder', 'Mid Calder', 55.8926100, -3.4800200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59332, 'Mickle Trafford', 'Mickle Trafford', '', 53.2214600, -2.8322500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59333, 'Mickleton', 'Mickleton', '', 54.6080700, -2.0499800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59334, 'Mickleton', 'Mickleton', '', 52.0915200, -1.7662300, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59335, 'Mickleham', 'Mickleham', '', 51.2654900, -0.3271900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59336, 'Mexborough', 'Mexborough', 'Mexborough,mksbwrw,مکسبورو', 53.4938900, -1.2924300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59337, 'Mevagissey', 'Mevagissey', 'Lannvorek,Mevagissey,mwghysy,موغيسي', 50.2732400, -4.7916600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59338, 'Methven', 'Methven', '', 56.4173700, -3.5783200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59339, 'Methley', 'Methley', '', 53.7288700, -1.4031800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59340, 'Methil', 'Methil', 'Maothchoille,Medil,Methil,Metilas,Медил', 56.1854300, -3.0215700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59341, 'Metheringham', 'Metheringham', '', 53.1401500, -0.4036800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59342, 'Messingham', 'Messingham', '', 53.5282800, -0.6538500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59343, 'Merthyr Tydfil', 'Merthyr Tydfil', 'Co-chorp Coontae Verthyr Tudful,Merter Tidvilis,Merthyr Tudful,Merthyr Tydfil,Mertir-Tidvil,Mertyr Tydfil,Murdur Tidfil,mei se di de fei er,meoseotideubil ju,Мертир-Тидвил,Мертір-Тідвіл,Мърдър Тидфил,マーサー・ティドビル,梅瑟蒂德菲尔,머서티드빌 주', 51.7479400, -3.3777900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59344, 'Meriden', 'Meriden', '', 52.4377000, -1.6436600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59345, 'Mere', 'Mere', '', 53.3321000, -2.4093500, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59346, 'Mere', 'Mere', 'mrh  wyltshr,مره، ویلتشر', 51.0888900, -2.2669400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59347, 'Meppershall', 'Meppershall', '', 52.0171300, -0.3399100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59348, 'Meopham', 'Meopham', '', 51.3684400, 0.3600700, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59349, 'Menston', 'Menston', '', 53.8904100, -1.7439500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59350, 'Menai Bridge', 'Menai Bridge', 'Menai,Menai Bridge,Menaj Bridzh,Menaj-Bridzh,Porthaethwy,Менай Бридж,Менай-Брідж', 53.2277500, -4.1692600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59351, 'Melton Mowbray', 'Melton Mowbray', 'Melton Mowbray,Meltun Moubrej,mltwn mwbry,Мелтън Моубрей,ملتون موبری', 52.7658800, -0.8869300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59352, 'Meltham', 'Meltham', '', 53.5930500, -1.8486100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59353, 'Melrose', 'Melrose', 'Maol Ros,Meall-Ros,Melrose,Melrose i Skottland,Melrouz,Melroz,mei er luo si,Мелроз,Մելրոուզ,梅尔罗斯', 55.5996900, -2.7277000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59354, 'Melling', 'Melling', '', 53.4833300, -2.9166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59355, 'Melksham', 'Melksham', 'Melksham,malkshm,mlksham,مالكشم,ملکشام', 51.3728100, -2.1400200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59356, 'Meldreth', 'Meldreth', '', 52.0939600, 0.0080700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59357, 'Meldon', 'Meldon', '', 55.1333300, -1.8000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59358, 'Melbourne', 'Melbourne', '', 53.8875500, -0.8592500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59359, 'Melbourne', 'Melbourne', 'Melbourne i Derbyshire,ملبورن، ڈربیشائر', 52.8219000, -1.4252200, 'GB', '2011-02-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59360, 'Melbourn', 'Melbourn', 'Melborn,Melbourn', 52.0812800, 0.0151400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59361, 'Measham', 'Measham', 'Measham', 52.7064400, -1.5063700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59362, 'Mayland', 'Mayland', '', 51.6803300, 0.7671500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59363, 'Mayfield', 'Mayfield', 'Mayfield', 53.0000000, -1.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59364, 'Maybole', 'Maybole', 'Am Magh Baoghail,Maybole,mei bo er,梅博尔', 55.3550300, -4.6802600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59365, 'Maulden', 'Maulden', '', 52.0306300, -0.4697500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59366, 'Mauchline', 'Mauchline', 'Machlainn,Mauchline,Mokhlin,mo he lin,Мохлин,莫赫林', 55.5160400, -4.3792800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59367, 'Mattishall', 'Mattishall', 'Mattishall', 52.6590500, 1.0325000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59368, 'Matlock', 'Matlock', 'Matlock Town,maeteullog,ماتلوک، دربی‌شر,매틀록', 53.1383800, -1.5556000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59369, 'Mathry', 'Mathry', 'Mathry', 51.9463900, -5.0866700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59370, 'Masham', 'Masham', 'masam,ماسام', 54.2227000, -1.6571800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59371, 'Maryport', 'Maryport', 'Maryport,Meriport,ma li bo te,marypwrt,Мерипорт,ماریپورت,瑪麗波特', 54.7143400, -3.4950900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59372, 'Martock', 'Martock', '', 50.9736100, -2.7668400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59373, 'Martham', 'Martham', 'Martham', 52.7046400, 1.6363600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59374, 'Marstow', 'Marstow', '', 51.8666700, -2.6500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59375, 'Marston Moretaine', 'Marston Moretaine', '', 52.0641000, -0.5493200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59376, 'Marston', 'Marston', '', 53.2666700, -2.5000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59377, 'Marske-by-the-Sea', 'Marske-by-the-Sea', 'Marske,Marske by the Sea,Marske-by-the-Sea', 54.5914700, -1.0195900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59378, 'Marshfield', 'Marshfield', 'Marshfield,Marshfields', 51.5338900, -3.0730600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59379, 'Marshfield', 'Marshfield', '', 51.4619400, -2.3200000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59380, 'Marsden', 'Marsden', 'Marsden', 53.6000000, -1.9166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59381, 'Marr', 'Marr', '', 53.5429600, -1.2205100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59382, 'Marple', 'Marple', '', 53.3945200, -2.0629200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59383, 'Marnhull', 'Marnhull', 'Marnhull', 50.9704500, -2.3132700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59384, 'Marlow', 'Marlow', 'Great Marlow,Marlow', 51.5693300, -0.7741500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59385, 'Marldon', 'Marldon', '', 50.4551200, -3.5967800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59386, 'Marlborough', 'Marlborough', 'Marlborough i Wiltshire,Merlebrigia,malabara,malbeoleo,marlbwrw  wyltshr,mrlbwrw,מרלבורו,مارلبورو، ویلتشر,مارلبورو، ویلٹشائر,मालबर,말버러', 51.4202700, -1.7294900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59387, 'Markyate', 'Markyate', 'Markyate,Markyatestreet', 51.8384600, -0.4634500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59388, 'Marks Tey', 'Marks Tey', '', 51.8762800, 0.7642400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59389, 'Markinch', 'Markinch', 'Markinch', 56.2021400, -3.1351700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59390, 'Markfield', 'Markfield', 'Markfield', 52.6874700, -1.2747600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59391, 'Market Weighton', 'Market Weighton', 'markt wytwn,مارکت ویتون', 53.8631000, -0.6650500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59392, 'Market Warsop', 'Market Warsop', '', 53.2051600, -1.1525700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59393, 'Market Rasen', 'Market Rasen', 'Market Rasen,markt rasn,مارکت راسن', 53.3876400, -0.3378100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59394, 'Market Overton', 'Market Overton', 'Market Overton', 52.7380600, -0.6863000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59395, 'Market Lavington', 'Market Lavington', 'Lavington,Market Lavington', 51.2875600, -1.9772900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59396, 'Market Harborough', 'Market Harborough', 'Market Harborough,Market Kharburo,XQM,markt harbwrw,Маркет Харбъро,مارکت هاربورو', 52.4776000, -0.9205300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59397, 'Market Drayton', 'Market Drayton', 'markt draytwn,مارکت درایتون', 52.9053800, -2.4901200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59398, 'Market Deeping', 'Market Deeping', 'markt dpyng,مارکت دپینگ', 52.6765400, -0.3162900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59399, 'Market Bosworth', 'Market Bosworth', 'Bosvorts''kij rinok,Bosvortskij rynok,markt bwswwrth,Босвортский рынок,Босвортський ринок,مارکت بوسوورث', 52.6242800, -1.4017400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59400, 'Marholm', 'Marholm', '', 52.6046900, -0.3082400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59401, 'Margate', 'Margate', 'Margate,Margejt,Margit,ma gai te,mageito,margyt,Маргейт,Маргејт,Маргит,مارگیت,マーゲイト,马盖特', 51.3813200, 1.3861700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59402, 'Marden', 'Marden', 'Marden', 51.1748200, 0.4885500, 'GB', '2011-02-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59403, 'Marchwood', 'Marchwood', 'Marchwood', 50.8896600, -1.4544000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59404, 'Marchwiel', 'Marchwiel', '', 53.0239000, -2.9610600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59405, 'Marcham', 'Marcham', 'Marcham', 51.6675500, -1.3429500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59406, 'March', 'March', 'Marcas,March,March i Cambridgeshire,Marčas,Марч,مارچ، کمبریج‌شر', 52.5513100, 0.0882800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59407, 'Marazion', 'Marazion', 'Marazion,Marghas Yow,Marghasyow,Parvum Forum,marazywn,مارازیون', 50.1255600, -5.4750500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59408, 'Mappleton', 'Mappleton', 'Mapleton,Mappleton', 53.8768700, -0.1366400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59409, 'Manton', 'Manton', '', 53.5136000, -0.5943800, 'GB', '2015-12-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59410, 'Manton', 'Manton', '', 52.6322300, -0.7003800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59411, 'Manston', 'Manston', 'Manston', 50.9500000, -2.2666700, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59412, 'Mansfield Woodhouse', 'Mansfield Woodhouse', '', 53.1649500, -1.1938400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59413, 'Mansfield', 'Mansfield', 'Mansfield,Mansfijld,Mansfildas,Mehnsfild,Mensfild,ZMA,maenseupildeu,man si fei er de,mansufirudo,mnspyld,mnzfyld,Мансфийлд,Менсфилд,Менсфілд,Мэнсфилд,מנספילד,منزفیلد,マンスフィールド,曼斯菲爾德,맨스필드', 53.1333300, -1.2000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59414, 'Manorbier', 'Manorbier', 'Manorbier', 51.6461400, -4.7990100, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59415, 'Manningtree', 'Manningtree', 'manyngtry,مانینگتری', 51.9453800, 1.0611200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59416, 'Mangotsfield', 'Mangotsfield', '', 51.4878000, -2.5040300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59417, 'Manea', 'Manea', '', 52.4848700, 0.1793000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59418, 'Manchester', 'Manchester', 'Gorad Manchehstehr,MAN,Mameceaster,Manceinion,Mancesteris,Mancestra,Manchain,Manchester,Manchestur,Manchetre,Manchuin,Manchéstér,Manchêtre,Mancunium,Mantsester,Mančesteris,Mančestra,Mánchester,maencheseuteo,maincestara,mamcestara,man che si te,mancestar,manchesuta,manshstr,mnchstr,mnchystyr,mnz''str,myanacestara,myancestar,Μάντσεστερ,Горад Манчэстэр,Манчестер,Манчестър,מאנטשעסטער,מנצ''סטר,مانشستر,مانچسٹر,منچئستئر,منچستر,मँचेस्टर,मैन्चेस्टर,ম্যানচেস্টার,மான்செஸ்டர்,మాంచెస్టర్,ಮ್ಯಾಂಚೆಸ್ಟರ್,മാഞ്ചസ്റ്റർ,แมนเชสเตอร์,მანჩესტერი,ማንችስተር,マンチェスター,曼彻斯特,맨체스터', 53.4809500, -2.2374300, 'GB', '2011-06-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59419, 'Manby', 'Manby', 'Manby', 53.3629100, 0.0965300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59420, 'Malton', 'Malton', 'Malton,Malton i North Yorkshire,مالتون، یورک‌شر شمالی', 54.1369500, -0.7996000, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59421, 'Maltby', 'Maltby', 'Maltby i South Yorkshire,مالتبی، یورک‌شر جنوبی', 53.4166700, -1.2000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59422, 'Malpas', 'Malpas', 'Malpas', 53.0166700, -2.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59423, 'Malmesbury', 'Malmesbury', 'Mal''msberi,Malmesburia,Malmesbury,malmzbwry,Мальмсбері,مالمزبوری', 51.5817500, -2.0970800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59424, 'Maldon', 'Maldon', 'Maeldun,Malden,Maldon,Maldon i Essex,Meldona,Moldon,Mældūn,maldwn  asks,Мелдона,Молдон,مالدون، اسکس', 51.7311000, 0.6746300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59425, 'Mainstone', 'Mainstone', '', 52.4833300, -3.0833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59426, 'Maidstone', 'Maidstone', 'Maidstone,Meintstooun,Mejdston,Mejdstoun,medosuton,mei de si tong,meideuseuton,mydnstwn,Μέιντστοουν,Мейдстон,Мейдстоун,Мејдстон,میدنستون,میڈسٹون,メードストン,梅德斯通,메이드스톤', 51.2666700, 0.5166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59427, 'Maiden Newton', 'Maiden Newton', 'Maiden Newton', 50.7790900, -2.5722600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59428, 'Maidenhead', 'Maidenhead', 'Maidenhead,Mejdenkhed,mei deng hei de,meidenheddo,mydnhd,Мейденхед,Мејденхед,میدنهد,メイデンヘッド,梅登黑德', 51.5227900, -0.7198600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59429, 'Magor', 'Magor', 'Magor', 51.5794400, -2.8313900, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59430, 'Maghull', 'Maghull', 'magwl,ماگول', 53.5161900, -2.9411700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59431, 'Magheralin', 'Magheralin', '', 54.4669500, -6.2598000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59432, 'Magherafelt', 'Magherafelt', 'Machaire Fiolta,Machaire Fíolta,Makhurafelt,Marafelt,Марафелт,Махърафелт', 54.7535600, -6.6065600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59433, 'Maghera', 'Maghera', 'Machaire Ratha,Machaire Rátha,Makhura,maghera,Махъра,मघेरा', 54.8439000, -6.6714500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59434, 'Maesycwmmer', 'Maesycwmmer', 'Maes y Cwmmer,Maesycwmmer', 51.6352800, -3.2322200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59435, 'Maesteg', 'Maesteg', 'Maesteg,Maisteigas,Majsteg,Masteg,mai si tai ge,Майстег,Мастег,邁斯泰格', 51.6092600, -3.6582300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59436, 'Maerdy', 'Maerdy', 'Maerdy,Mardy', 51.6752800, -3.4866700, 'GB', '2013-11-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59437, 'Maentwrog', 'Maentwrog', 'Maentwrog', 52.9460000, -3.9878700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59438, 'Madley', 'Madley', 'Madley', 52.0455500, -2.8509100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59439, 'Madeley', 'Madeley', 'Madeley', 53.0000000, -2.3333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59440, 'Madeley', 'Madeley', '', 52.6333300, -2.4333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59441, 'Macmerry', 'Macmerry', '', 55.9404500, -2.9050300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59442, 'Machynlleth', 'Machynlleth', 'Machynlleth,Makhinlet,Makhunlet,Махинлет,Махънлет', 52.5909700, -3.8505100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59443, 'Machen', 'Machen', 'Machen', 51.5959900, -3.1419000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59444, 'Macduff', 'Macduff', 'An Dun,An Dùn,An Dún,Dun MhicDhuibh,Dùn MhicDhuibh', 57.6701200, -2.4968600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59445, 'Macclesfield', 'Macclesfield', 'Maklsfild,Maklsfildas,Makulsfijld,XMZ,meikeuljeupildeu,Маклсфилд,Макълсфийлд,مک‌کلسفیلد,메이클즈필드', 53.2602300, -2.1256400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59446, 'Mablethorpe', 'Mablethorpe', 'Mablethorpe', 53.3409000, 0.2610200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59447, 'Lytchett Matravers', 'Lytchett Matravers', 'Lytchett Matravers', 50.7582600, -2.0780600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59448, 'Lynton', 'Lynton', 'Linton,Lynton', 51.2296800, -3.8413100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59449, 'Lyneham', 'Lyneham', 'LYE,Lyneham', 51.5166700, -1.9666700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59450, 'Lyndhurst', 'Lyndhurst', '', 50.8725900, -1.5766200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59451, 'Lympstone', 'Lympstone', 'Lympstone', 50.6475100, -3.4316200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59452, 'Lympne', 'Lympne', 'Limpn,Лимпн', 51.0777300, 1.0280800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59453, 'Lymm', 'Lymm', 'Lim,lymm,Лим,ليمم', 53.3810500, -2.4776300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59454, 'Lymington', 'Lymington', 'Limington,Lymington,limingteon,lymyngtwn,Лимингтон,لیمینگتون,리밍턴', 50.7576700, -1.5443000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59455, 'Lyminge', 'Lyminge', '', 51.1295100, 1.0889600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59456, 'Lyme Regis', 'Lyme Regis', 'Lajm-Redzhis,Lajm-Ridzhis,Lyme Regis,la''ima regisa,lai mu li jie si,laym rjys,laym ryjys,Лайм-Реджис,Лайм-Риджис,لائم رجیس,لایم ریجیس,लाईम रेगीस,莱姆里杰斯', 50.7265400, -2.9347700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59457, 'Lydney', 'Lydney', 'Lydney,lydny,لیدنی', 51.7259800, -2.5260500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59458, 'Lydiard Tregoze', 'Lydiard Tregoze', '', 51.5500000, -1.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59459, 'Lydiard Millicent', 'Lydiard Millicent', '', 51.5711700, -1.8634600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59460, 'Lydham', 'Lydham', '', 52.5147600, -2.9797000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59461, 'Lydd', 'Lydd', 'LYX,Lydd,lyd  knt,لید، کنت', 50.9513200, 0.9065400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59462, 'Lydbrook', 'Lydbrook', 'Lydbrook', 51.8376300, -2.5781800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59463, 'Lutterworth', 'Lutterworth', 'Lutterworth,latrwwrth,لاتروورث', 52.4563400, -1.2021800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59464, 'Luton', 'Luton', 'Luton,Lutonas,Lutun,lu dun,luteon,lwtn,lwtwn,ruton,Лутон,Лутън,لوتن,لوتون,ルートン,卢顿,루턴', 51.8796700, -0.4174800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59465, 'Lundin Links', 'Lundin Links', 'Lundin Links', 56.2124000, -2.9529600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59466, 'Lund', 'Lund', '', 53.9192000, -0.5221100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59467, 'Luncarty', 'Luncarty', '', 56.4530800, -3.4700700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59468, 'Lugwardine', 'Lugwardine', 'Lugwardine', 52.0658300, -2.6578000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59469, 'Ludlow', 'Ludlow', 'Ladlou,Llwydlo,Ludlou,Ludlow,lwdlaw,Ладлоу,Лъдлоу,لودلاو', 52.3743100, -2.7131100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59470, 'Ludgershall', 'Ludgershall', 'Ludgershall,Lugershall', 51.2555800, -1.6222000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59471, 'Luddenden Foot', 'Luddenden Foot', '', 53.7187300, -1.9458200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59472, 'Luckington', 'Luckington', 'Luckington', 51.5544400, -2.2422200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59473, 'Lowick', 'Lowick', '', 55.6504400, -1.9780900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59474, 'Low Etherley', 'Low Etherley', '', 54.6534900, -1.7431500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59475, 'Lowestoft', 'Lowestoft', 'Loustoft,Lowestoft,loseutopeuteu,luo si tuo fu te,lwystaft,Лоустофт,لوئستافت,洛斯托夫特,로스토프트', 52.4752000, 1.7515900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59476, 'Lower Kingswood', 'Lower Kingswood', '', 51.2696800, -0.2123000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59477, 'Lower Halstow', 'Lower Halstow', '', 51.3739500, 0.6681900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59478, 'Lower Bullingham', 'Lower Bullingham', 'Lower Bullingham', 52.0333300, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59479, 'Lower Brailes', 'Lower Brailes', 'Brailes,Lower Brailes', 52.0503400, -1.5417600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59480, 'Lowdham', 'Lowdham', '', 53.0120500, -1.0048300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59481, 'Low Bradley', 'Low Bradley', 'Bradley,Low Bradley', 53.9321700, -1.9964600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59482, 'Low Ackworth', 'Low Ackworth', '', 53.6502300, -1.3233400, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59483, 'Louth', 'Louth', 'Laut,Louth,Louth i Lincolnshire,Лаут,لوث، لینکلن‌شر', 53.3666400, -0.0043800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59484, 'Loughton', 'Loughton', '', 52.0303700, -0.7864200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59485, 'Loughborough', 'Loughborough', 'Lafboro,Loughborough,Lufburou,la fu bao,lafba ra,lafbwrw,leopeubeoleo,rafubara,Лафборо,Лъфбъроу,لافبورو,ลัฟบะระ,ラフバラー,拉夫堡,러프버러', 52.7666700, -1.2000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59486, 'Lostwithiel', 'Lostwithiel', 'Lostwithiel,Lostwydhyel,lastwytyl,lwstwyzyl,لاستویتیل,لوستويزيل', 50.4078400, -4.6702300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59487, 'Lossiemouth', 'Lossiemouth', 'Inbhir Losaidh,LMO,Lossiemouth,Lossimut,Лоссимут,Лоссімут', 57.7213600, -3.2834100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59488, 'Longwick', 'Longwick', '', 51.7360700, -0.8567600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59489, 'Long Whatton', 'Long Whatton', '', 52.8057700, -1.2850600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59490, 'Longtown', 'Longtown', 'Longtown', 55.0092500, -2.9672200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59491, 'Longtown', 'Longtown', '', 51.9500000, -2.9833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59492, 'Longton', 'Longton', 'Longton', 52.9833300, -2.1333300, 'GB', '2017-07-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59493, 'Long Sutton', 'Long Sutton', 'Long Sutton', 51.2197800, -0.9429300, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59494, 'Long Stratton', 'Long Stratton', 'Long Stratton', 52.4880300, 1.2347800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59495, 'Longstanton', 'Longstanton', 'Long Stanton,Longstanton', 52.2807600, 0.0455800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59496, 'Longridge', 'Longridge', 'Longridge,langryj,لانگریج', 53.8321200, -2.5996400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59497, 'Longnor', 'Longnor', '', 52.6000000, -2.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59498, 'Longniddry', 'Longniddry', 'Longniddry', 55.9754300, -2.8959300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59499, 'Long Melford', 'Long Melford', '', 52.0748100, 0.7163900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59500, 'Long Lawford', 'Long Lawford', 'Long Lawford', 52.3817600, -1.3071600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59501, 'Long Itchington', 'Long Itchington', '', 52.2839600, -1.3924300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59502, 'Longhoughton', 'Longhoughton', '', 55.4313100, -1.6169100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59503, 'Longhorsley', 'Longhorsley', '', 55.2458600, -1.7691400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59504, 'Longhope', 'Longhope', 'Longhope', 51.8666700, -2.4500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59505, 'Longforgan', 'Longforgan', '', 56.4573200, -3.1143700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59506, 'Longfield', 'Longfield', '', 51.3969000, 0.3021200, 'GB', '2011-02-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59507, 'Long Eaton', 'Long Eaton', 'Long Eaton,Long-Iton,Лонг-Итон', 52.8985500, -1.2713600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59508, 'Longdendale', 'Longdendale', '', 53.4666700, -2.0000000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59509, 'Long Crendon', 'Long Crendon', 'Long Crendon', 51.7729400, -0.9968400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59510, 'Long Clawson', 'Long Clawson', 'Long Clawson', 52.8372500, -0.9288000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59511, 'Long Buckby', 'Long Buckby', '', 52.3026000, -1.0811300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59512, 'Long Bennington', 'Long Bennington', '', 52.9931400, -0.7580300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59513, 'Long Ashton', 'Long Ashton', '', 51.4299700, -2.6609800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59514, 'Londonderry County Borough', 'Londonderry County Borough', '', 54.9972100, -7.3091700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59515, 'Derry', 'Derry', 'Derae,Deri,Derri,Derry,Derry / Londonderry,Derry City,Dhoire,Doire,Doire Choluim Chille,Ker Dherow,LDY,Londenderry,Londonderis,Londonderry,Lunnonderry,de li,deli,dry,dyry,lun dui de li cheng,rondonderi,Дери,Дерри,Деррі,דרי,دری,ديري,ڈیری,ロンドンデリー,伦敦德里城,德里,데리', 54.9981000, -7.3093400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59516, 'City of London', 'City of London', 'Bandaraya London,Cathair Londan,Ceety o Lunnon,Cidade de Londres,Cite de Londres,Citta di Londra,Città di Londra,City,City de Londres,City of London,Cité de Londres,Civitas Londinium,Dakbayan sa Londres,Dinas Llundain,Idolobha weLondon,Ker Londrez,Kota London,Kêr Londrez,La City,London,Londonas Sitija,Londono Sitis,Londons''ke Siti,Londons''ke siti,Londra Sehri,Londra Şehri,Lontoon City,Lun-tun Chhi,Lundenceaster,Lundunaborg,Lundúnaborg,Lungsod ng Londres,Lûn-tun Chhī,Sici,Siti,Siti tou Londinou,Square Mile,Thanh pho Luan GJon,The City,Thành phố Luân Đôn,hsyty sl lwndwn,lun dui cheng,lun dui jin rong cheng,lun dui shi,mdynt lndn,nkhr lxndxn,siti ofa landana,siti opha landana,sitiobeuleondeon,syty lndn,Σίτι του Λονδίνου,Лондонське Сіті,Лондонське сіті,Сити,Сіці,Լոնդոնյան Սիթի,הסיטי של לונדון,סיטי פון לאנדאן,سیتی لندن,لندن شہر,مدينة لندن,सिटी ऑफ लंडन,सिटी ऑफ़ लंदन,นครลอนดอน,シティ・オブ・ロンドン,伦敦城,倫敦市,倫敦金融城,시티오브런던', 51.5127900, -0.0918400, 'GB', '2017-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59517, 'London', 'London', 'Gorad Londan,ILondon,LON,Lakana,Landan,Landen,Ljondan,Llundain,Lodoni,Londain,Londan,Londar,Londe,Londen,Londin,Londinium,Londino,Londn,London,London osh,Londona,Londonas,Londoni,Londono,Londons,Londonu,Londra,Londres,Londrez,Londri,Londro,Londye,Londyn,Londýn,Lonn,Lontoo,Loundres,Luan GJon,Lun-tun,Lunden,Lundra,Lundun,Lundunir,Lundúnir,Lung-dung,Lunnainn,Lunnin,Lunnon,Luân Đôn,Lùn-tûn,Lùng-dŭng,Lûn-tun,Lākana,Lůndůn,Lọndọnu,Ranana,Rānana,ilantan,ladana,landan,landana,leondeon,lndn,london,londoni,lun dui,lun dun,lwndwn,lxndxn,rondon,Łondra,Λονδίνο,Горад Лондан,Лондан,Лондон,Лондон ош,Лондонъ,Лёндан,Լոնդոն,לאנדאן,לונדון,لأندأن,لندن,لوندون,لەندەن,ܠܘܢܕܘܢ,लंडन,लंदन,लण्डन,लन्डन्,लन्दन,লন্ডন,ਲੰਡਨ,લંડન,ଲଣ୍ଡନ,இலண்டன்,లండన్,ಲಂಡನ್,ലണ്ടൻ,ලන්ඩන්,ลอนดอน,ລອນດອນ,ལོན་ཊོན།,လန်ဒန်မြို့,ლონდონი,ለንደን,ᎫᎴ ᏗᏍᎪᏂᎯᏱ,ロンドン,伦敦,倫敦,런던', 51.5085300, -0.1257400, 'GB', '2016-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59518, 'Londesborough', 'Londesborough', '', 53.8833300, -0.6833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59519, 'Loftus', 'Loftus', '', 54.5554300, -0.8945900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59520, 'Lofthouse', 'Lofthouse', '', 53.7294700, -1.4969700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59521, 'Loddon', 'Loddon', 'Loddon,lwdwn  nwrfk,لودون، نورفک', 52.5327000, 1.4818300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59522, 'Lockington', 'Lockington', '', 53.9141500, -0.4857200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59523, 'Locking', 'Locking', '', 51.3332700, -2.9138700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59524, 'Lockerbie', 'Lockerbie', 'Lockerbie,Logarbaidh,Lokerbi,Lokurbi,lokarabi,lokeobi,luo ke bi,lwkrby,lxk ke xrbi,lxkh ke xrbi,Локерби,Локербі,Локърби,لوكربي,लॉकरबी,ล็อกเกอร์บี,ล็อคเกอร์บี,洛克比,로커비', 55.1230200, -3.3563500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59525, 'Lochwinnoch', 'Lochwinnoch', 'Loch Eanach,Lochwinnoch', 55.7952100, -4.6303400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59526, 'Lochmaben', 'Lochmaben', 'Loch Mhabain,Lochmaben', 55.1301100, -3.4428600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59527, 'Lochgilphead', 'Lochgilphead', 'Ceann Loch Gilb,Lokhgilpkhed,Loxqilpxed,lwkgylphd,lwkgylphyd,Лохгилпхед,Лохгілпхед,לוכגילפהד,لوکگیلپهید', 56.0379600, -5.4320600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59528, 'Lochgelly', 'Lochgelly', 'Lochgelly', 56.1282600, -3.3096400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59529, 'Locharbriggs', 'Locharbriggs', 'Locharbriggs', 55.1033700, -3.5843800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59530, 'Loanhead', 'Loanhead', 'Loanhead', 55.8794500, -3.1587400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59531, 'Llysfaen', 'Llysfaen', 'Llysfaen', 53.2833300, -3.6666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59532, 'Llwynypia', 'Llwynypia', 'Llwyn-y-pia,Llwynpia,Llwynypia', 51.6333300, -3.4500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59533, 'Lledrod', 'Lledrod', 'Llanfihangel Lledrod,Lledrod', 52.3000000, -3.9833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59534, 'Llanwnda', 'Llanwnda', 'Llanwnda', 53.1013900, -4.2784900, 'GB', '2015-05-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59535, 'Llanwinio', 'Llanwinio', 'Llanwinio', 51.9086100, -4.5305600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59536, 'Llanwern', 'Llanwern', 'Llanwern', 51.5888900, -2.9136100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59537, 'Llanveynoe', 'Llanveynoe', '', 51.9666700, -3.0000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59538, 'Llanvaches', 'Llanvaches', 'Llanvaches', 51.6211100, -2.8183300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59539, 'Llantwit Major', 'Llantwit Major', 'Lantuit Mejdzhur,Llanilltud Fawr,Llantvit-Mejdzhor,Llantwit Major,Лантуит Мейджър,Ллантвіт-Мейджор', 51.4107000, -3.4863200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59540, 'Llantwit Fardre', 'Llantwit Fardre', 'Llanilltud Faerdref,Llantwit Fardre,Llantwitt-fardre,Llantwitvairdre', 51.5546000, -3.3324100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59541, 'Llantrisant', 'Llantrisant', 'Lantrisant,Llantrisant,Лантрисант', 51.5402800, -3.3738900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59542, 'Llansteffan', 'Llansteffan', 'Llansteffan,Llanstephan', 51.7722200, -4.3913900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59543, 'Llansawel', 'Llansawel', '', 52.0000000, -4.0166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59544, 'Llansantffraid Glan Conwy', 'Llansantffraid Glan Conwy', 'Llansantffraid,Llansantffraid Glan Conwy,Llansantffraid-Glan-Conway', 53.2666700, -3.8000000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59545, 'Llansadwrn', 'Llansadwrn', 'Llansadwrn', 51.9500000, -3.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59546, 'Llanrwst', 'Llanrwst', 'Lanrust,Llanrust,Llanrwst,Llanwrst,Ланруст,Лланруст', 53.1402100, -3.7952700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59547, 'Llanrug', 'Llanrug', '', 53.1478800, -4.1959600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59548, 'Llanrothal', 'Llanrothal', '', 51.8666700, -2.7666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59549, 'Llanrhian', 'Llanrhian', 'Llanrhian,Llanrian', 51.9375000, -5.1738900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59550, 'Llanllwchaiarn', 'Llanllwchaiarn', '', 52.1833300, -4.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59551, 'Llanilar', 'Llanilar', 'Llanilar', 52.3565700, -4.0257400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59552, 'Llanidloes', 'Llanidloes', 'Lanidloisas,Lanidlojs,Llanidloes,Ланидлойс', 52.4497700, -3.5399700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59553, 'Llanharry', 'Llanharry', 'Llanharry,Llanhary', 51.5142200, -3.4324000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59554, 'Llanharan', 'Llanharan', '', 51.5380500, -3.4390600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59555, 'Llangynog', 'Llangynog', '', 52.8333300, -3.4000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59556, 'Llangynidr', 'Llangynidr', 'Llangynidr', 51.8673000, -3.2276200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59557, 'Llangybi', 'Llangybi', '', 52.1500000, -4.0500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59558, 'Llangwm', 'Llangwm', 'Llangwm,Llangwm-isaf', 51.6961100, -2.8300000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59559, 'Llangwm', 'Llangwm', '', 52.9833300, -3.5333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59560, 'Llangollen', 'Llangollen', 'Lan''nkollen,Langolen,Llangollen,lngwln,Λανγκόλλεν,Ланголен,Лланголлен,לנגולן', 52.9682900, -3.1712700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59561, 'Llangoed', 'Llangoed', 'Langoes,Llangoed', 53.2942000, -4.0877200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59562, 'Llangybi', 'Llangybi', 'Llangibby,Llangybi', 51.6658300, -2.9080600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59563, 'Llangefni', 'Llangefni', 'Langevni,Langevnis,Llangevni,lan gai fu ni,lang-gepeuni,surangevuni,Лангевни,Ллангевні,スランゲヴニ,蘭蓋夫尼,랑게프니', 53.2556100, -4.3106300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59564, 'Llangathen', 'Llangathen', 'Llangathen', 51.8797200, -4.0561100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59565, 'Llangan', 'Llangan', '', 51.4869400, -3.5005600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59566, 'Llangain', 'Llangain', 'Llangain', 51.8183300, -4.3475000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59567, 'Llanfynydd', 'Llanfynydd', 'Llanfyndd,Llanfynydd', 51.9280600, -4.0988900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59568, 'Llanfyllin', 'Llanfyllin', '', 52.7657000, -3.2718700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59569, 'Llanfechain', 'Llanfechain', 'Llanfechain,Llanfechan', 52.7746300, -3.2027300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59570, 'Llanfairpwllgwyngyll', 'Llanfairpwllgwyngyll', 'Lanfairpwll,Llanfair Pwllgwyngyll,Llanfairpwllgwyngyll,Llanfairpwllgwyngyllgogerychwyrndrobwllllantysiliogogogoch,Llanfairpwllgwyngyllgogerychwyrndrobwyll-llantysiliogogogoch,Llanfairpwll­gwyngyllgogerychwyrndrobwllllantysiliogogogoch,Llanfair­pwllgwyn­gyllgo­gery­chwyrn­drobwll­llanty­silio­gogo­goch,Llanvajr-Pullgvingill,laenbaieopuheulgwingiheul,lan wei er pu er gu yin ji er ge ge li hui er en de luo bu er lan di xi li ao ge ge ge he,Лланвайр-Пуллгвингилл,ランヴァイル・プルグウィンギル・ゴゲリフウィルンドロブル・ランティシリオゴゴゴホ,兰韦尔普尔古因吉尔戈格里惠尔恩德罗布尔兰蒂西利奥戈戈戈赫,랜바이어푸흘귄기흘', 53.2214100, -4.2032900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59571, 'Llanfairfechan', 'Llanfairfechan', 'Lanvajrvekhan,Llanfairfechan,Ланвайрвехан', 53.2577900, -3.9742300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59572, 'Llanfair Caereinion', 'Llanfair Caereinion', '', 52.6479000, -3.3266800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59573, 'Llanfair', 'Llanfair', '', 52.8441500, -4.1154100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59574, 'Llanfaethlu', 'Llanfaethlu', 'Llanfaethlu,Llanfaethly', 53.3524000, -4.5341800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59575, 'Llanfachraeth', 'Llanfachraeth', 'Llanfachraeth,Llanfachreth', 53.3124400, -4.5333600, 'GB', '2014-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59576, 'Llanerchymedd', 'Llanerchymedd', 'Llanerchymedd', 53.3305500, -4.3770000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59577, 'Llanelli', 'Llanelli', 'Laneli,Lanelis,Llanelli,Llanelly,heullaneheulli,la nei li,lnly,Ланели,Лланелли,Лланеллі,خلانیتھلی,لنلی,拉內利,흘라네흘리', 51.6819500, -4.1619100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59578, 'Llandysul', 'Llandysul', 'Landusil,Llandyssil,Llandyssul,Llandysul,Ландъсил', 52.0416600, -4.3090900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59579, 'Llandybie', 'Llandybie', 'Llandebie,Llandybie', 51.8204400, -4.0071000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59580, 'Llandudno', 'Llandudno', 'Landidnas,Landidno,Llandadno,Llandidno,Llandudno,Llundadno,lan di de nuo,Ландидно,Лландадно,Лландидно,蘭迪德諾', 53.3249800, -3.8314800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59581, 'Llandrindod Wells', 'Llandrindod Wells', 'Landrindod Uels,Llandrindod,Llandrindod-Vells,laendeulindodeuwelseu,lan de lin duo de wei er si,Ландриндод Уелс,Лландріндод-Веллс,蘭德林多德威爾斯,랜드린도드웰스', 52.2416400, -3.3786800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59582, 'Llandrillo', 'Llandrillo', '', 52.9227700, -3.4376000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59583, 'Llanddowror', 'Llanddowror', 'Llanddowror,Llandowror', 51.8016700, -4.5313900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59584, 'Llandovery', 'Llandovery', 'Landuvri,Llandovery,Llanymddyfri,Ландъври', 51.9941500, -3.7963700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59585, 'Llandeilo', 'Llandeilo', 'Landejlo,Llandeilo,Llandilo,Ландейло', 51.8845900, -3.9915400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59586, 'Llandegla', 'Llandegla', 'Llandegla', 53.0590100, -3.1988200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59587, 'Llanddeusant', 'Llanddeusant', 'Llanddausaint,Llanddeusant', 51.9000000, -3.7833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59588, 'Llanddarog', 'Llanddarog', '', 51.8272200, -4.1744400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59589, 'Llancillo', 'Llancillo', '', 51.9166700, -2.9333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59590, 'Llanbradach', 'Llanbradach', 'Llanbradach', 51.6063900, -3.2302800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59591, 'Llanboidy', 'Llanboidy', 'Llanboidy', 51.8788900, -4.5927800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59592, 'Llanberis', 'Llanberis', 'Lanberis,Llanberis,Ланберис,Лланберис', 53.1180900, -4.1292300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59593, 'Llanbedr', 'Llanbedr', 'Llanbedr', 52.8166700, -4.1000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59594, 'Llanbadoc', 'Llanbadoc', 'Llanbaddock,Llanbadoc', 51.6950000, -2.9036100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59595, 'Llanarth', 'Llanarth', '', 52.1942400, -4.3081100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59596, 'Llanarth', 'Llanarth', '', 51.7833300, -2.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59597, 'Livingston', 'Livingston', 'Baile Dhun Leibhe,Baile Dhunleibhe,Baile Dhùnlèibhe,Baile Dhún Léibhe,Baile Leibhinn,Baile Lèibhinn,Leivinstoun,Livingston,Livingston i Skottland,Livingstonas,Livinqston,li wen si tong,lywyngstwn  askatlnd,Ливингстон,Лівінгстон,لونگسٹن,لیونگسٹن، مغربی لوتھیان,لیوینگستون، اسکاتلند,利文斯通', 55.9028800, -3.5226100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59598, 'Liversedge', 'Liversedge', '', 53.7051400, -1.6932700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59599, 'Liverpool', 'Liverpool', 'Gorad Liverpul,LPL,Learpholl,Lerphoyll,Lerpwl,Liberpoul,Liverpolium,Liverpool,Liverpuil,Liverpul,Liverpul'',Liverpule,Liverpulis,Liverpūle,Livurpul,Liwerpol,Liwérpol,Poll a'' Ghruthain,Poll a'' Ghrùthain,li wu pu,libeopul,livarapula,livarpul,livharapula,liwexrphul,lybrpwl,lyfrbwl,lywr pwl,lywrpwl,rivu~apuru,Λίβερπουλ,Горад Ліверпул,Ливерпул,Ливерпуль,Ливерпүүл,Ливърпул,Ліверпуль,Լիվերպուլ,ליברפול,ליווערפול,ليفربول,لیور پول,لیورپول,لیڤەرپوول,ܠܝܒܪܦܘܠ,लिवरपूल,लिव्हरपूल,லிவர்பூல்,ಲಿವರ್‌ಪೂಲ್,ലിവർപൂൾ,ลิเวอร์พูล,ლივერპული,ሊቨርፑል፣ እንግሊዝ,リヴァプール,利物浦,리버풀', 53.4105800, -2.9779400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59600, 'Little Weighton', 'Little Weighton', '', 53.7902100, -0.5067900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59601, 'Littleport', 'Littleport', '', 52.4578400, 0.3060300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59602, 'Little Paxton', 'Little Paxton', 'Little Paxton', 52.2504500, -0.2580100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59603, 'Little Lever', 'Little Lever', '', 53.5634600, -2.3780300, 'GB', '2012-04-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59604, 'Little Hulton', 'Little Hulton', 'Little Hulton', 53.5333300, -2.4166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59605, 'Little Houghton', 'Little Houghton', '', 53.5457600, -1.3599900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59606, 'Littlehampton', 'Littlehampton', 'Litlkhempton,Littlehampton,li te er han pu dun,liteulhaempeuteon,Литлхемптон,لیتل‌هامپتون,利特爾漢普頓,리틀햄프턴', 50.8113700, -0.5407800, 'GB', '2015-05-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59607, 'Little Eaton', 'Little Eaton', 'Little Eaton', 52.9702800, -1.4595000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59608, 'Little Dunmow', 'Little Dunmow', '', 51.8609600, 0.4147800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59609, 'Little Clacton', 'Little Clacton', '', 51.8255700, 1.1421500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59610, 'Littlebourne', 'Littlebourne', '', 51.2744500, 1.1668700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59611, 'Littleborough', 'Littleborough', 'Littleborough', 53.6441300, -2.0958100, 'GB', '2013-12-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59612, 'Little Barford', 'Little Barford', '', 52.1989800, -0.2729000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59613, 'Little Amwell', 'Little Amwell', '', 51.7833300, -0.0333300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59614, 'Litherland', 'Litherland', 'Litherland', 53.4699300, -2.9980900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59615, 'Liss', 'Liss', 'Liss,Лисс', 51.0427700, -0.8923800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59616, 'Lisnaskea', 'Lisnaskea', 'Lisnaskea', 54.2500000, -7.4500000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59617, 'Liskeard', 'Liskeard', 'Liskeard,Lyskerrys,lyskard,لیسکارد', 50.4545000, -4.4651700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59618, 'Lisburn', 'Lisburn', 'Districtul Lisburn,Lios na gCearrbhach,Lisbern,Lisbernas,Lisburn,Lizbern,li si ben,lijeubeon,lsbrn,lysbwrn,risuban,Лизберн,Лисберн,Лисбърн,لسبرن,لیسبورن,リスバーン,利斯本,리즈번', 54.5233700, -6.0352700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59619, 'Liphook', 'Liphook', 'Liphook', 51.0767300, -0.8032000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59620, 'Linton upon Ouse', 'Linton upon Ouse', 'Linton,Linton upon Ouse,Linton-on-Ouse', 54.0463900, -1.2492000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59621, 'Linton', 'Linton', '', 52.0978300, 0.2767200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59622, 'Linton', 'Linton', '', 51.9252900, -2.4966900, 'GB', '2016-05-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59623, 'Linthwaite', 'Linthwaite', 'Linthwaite', 53.6241800, -1.8501700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59624, 'Linlithgow', 'Linlithgow', 'Gleann Iucha,Linlitgou,Linlithgow,Lithgae,lin li si ge,linlithago,rinrisugo,Линлитгоу,Лінлітгоу,लिन्लिथगो,リンリスゴー,林利斯哥', 55.9763900, -3.6036400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59625, 'Lingwood', 'Lingwood', '', 52.6210400, 1.4861600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59626, 'Lingfield', 'Lingfield', '', 51.1771900, -0.0155800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59627, 'Lingen', 'Lingen', '', 52.3000000, -2.9333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59628, 'Lingdale', 'Lingdale', 'Lingdale', 54.5378700, -0.9586400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59629, 'Lincoln', 'Lincoln', 'Gorad Linkal''n,Lincoln,Lincoln i England,Lindum,Linkol''n,Linkoln,Linkolnas,Linkuln,lin ken,ling khxln,lingkeon,linkona,lnkn  anglstan,lnkwln,lynkln  anglstan,lynqwln,rinkan,Горад Лінкальн,Линколн,Линкольн,Линкълн,Лінкольн,Լինքոլն,לינקולן,لنكولن,لنکن، انگلستان,لینکلن، انگلستان,লিঙ্কোন,ลิงคอล์น,လင်ကွန်းမြို့၊ အင်္ဂလန်,ლინკოლნი,リンカン,林肯,링컨', 53.2268300, -0.5379200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59630, 'Limpley Stoke', 'Limpley Stoke', 'Limpley Stoke', 51.3448700, -2.3140900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59631, 'Limekilns', 'Limekilns', 'Limekilns', 56.0333600, -3.4771300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59632, 'Limavady', 'Limavady', 'Leim an Mhadaidh,Limavadi,Limavadis,Léim an Mhadaidh,Newtown Limavady,li ma wa di,Лимавади,利馬瓦迪', 55.0504500, -6.9507400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59633, 'Lifton', 'Lifton', '', 50.6435600, -4.2821600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59634, 'Lidlington', 'Lidlington', '', 52.0415400, -0.5591400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59635, 'Lichfield', 'Lichfield', 'Liccidfeld,Lichfield,Lichfijld,Lichfild,Lichfildia,XQT,li qi fei er de,lichipildeu,lychfyld,ritchifirudo,Личфийлд,Личфилд,Լիչֆիլդ,لخفیلڈ,لیچفیلد,لیچفیلڈ,リッチフィールド,利奇菲爾德,리치필드', 52.6815400, -1.8254900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59636, 'Lhanbryde', 'Lhanbryde', 'Lhanbryde', 57.6352900, -3.2183900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59637, 'Leysdown-on-Sea', 'Leysdown-on-Sea', 'Leysdown,Leysdown-on-Sea', 51.3973000, 0.9215600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59638, 'Leyland', 'Leyland', '', 53.6978600, -2.6875800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59639, 'Leyburn', 'Leyburn', 'Leyburn,لیبورن، یورک‌شر شمالی,لےبرن', 54.3100400, -1.8304100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59640, 'Lewes', 'Lewes', 'L''juis,Luis,lei wei si,lu-iseu,lwys,ruisu,Луис,Льюис,لوئس,لویس,ルイス,雷威斯,루이스', 50.8739800, 0.0088000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59641, 'Leven', 'Leven', 'Inbhir Liobhann,Inbhir Lìobhann,Inbhir Líobhann,Leven', 56.2000000, -3.0000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59642, 'Leven', 'Leven', '', 53.8902800, -0.3178300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59643, 'Leuchars', 'Leuchars', 'Leuchars', 56.3817400, -2.8825300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59644, 'Letterston', 'Letterston', '', 51.9275700, -4.9914100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59645, 'Letham', 'Letham', 'Letham', 56.6268300, -2.7706000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59646, 'Letchworth', 'Letchworth', 'Lechuort,Letchuehrt,Letchworth,Letchworth Garden,Letchworth Garden City,lai qi wo si,lechiwoseu,ltchwwrth gardn syty,retchiwasu,Летчуэрт,Лечуорт,لتچوورث گاردن سیتی,レッチワース,萊奇沃思,레치워스', 51.9794400, -0.2284000, 'GB', '2014-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59647, 'Lesmahagow', 'Lesmahagow', 'Lesmahagow', 55.6366800, -3.8873600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59648, 'Leslie', 'Leslie', 'Leslie', 56.2000000, -3.2166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59649, 'Lesbury', 'Lesbury', 'Lesbury,Lisburg', 55.3983200, -1.6283000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59650, 'Lerwick', 'Lerwick', 'Gorad Leruik,LSI,Lamwic,Leirvik,Leirvík,Lergouik,Leruik,Lervik,Lervikas,Lerwick,Liurabhaig,Liùrabhaig,Liúrabhaig,Lāmwic,lei wei ke,leowig,lrwwyq,lrwyk,rau~ikku,Λέργουικ,Горад Леруік,Лервик,Лервік,Леруик,לרוויק,لرویک,ラーウィック,勒威克,러윅', 60.1545300, -1.1494100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59651, 'Leominster', 'Leominster', 'Leminster,Llanllieni,lmstr,Леминстер,لمستر', 52.2258300, -2.7449100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59652, 'Lennoxtown', 'Lennoxtown', 'Lennoxtown', 55.9726300, -4.2000100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59653, 'Lenham', 'Lenham', 'Lenham', 51.2370500, 0.7189200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59654, 'Leiston', 'Leiston', 'lystwn,لیستون', 52.2061100, 1.5775700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59655, 'Leighton Buzzard', 'Leighton Buzzard', '', 51.9172200, -0.6580200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59656, 'Leigh-on-Sea', 'Leigh-on-Sea', 'Leigh,Leigh-on-Sea', 51.5429700, 0.6490500, 'GB', '2017-05-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59657, 'Leigh', 'Leigh', 'Leigh,Leigh i Stor-Manchester,ly,ly  mnchstr bzrg,لي,لی، منچستر بزرگ', 53.4964200, -2.5197300, 'GB', '2015-07-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59658, 'Leigh', 'Leigh', 'Leigh', 52.1767700, -2.3163100, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59659, 'Leigh', 'Leigh', '', 51.6166700, -1.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59660, 'Leicester', 'Leicester', 'Caerlyr,Caerlŷr,Gorad Lestehr,Leicester,Leicestria,Leiscester,Lester,Lestera,Lesteris,Lestur,Leysester,Léyséstér,QEW,lai si te,laystr,les texr,leseuteo,lstr,resuta,Λέστερ,Горад Лестэр,Лестер,Лестър,לסטר,לעסטער,لايستر,لستر,لیسسٹر,เลสเตอร์,レスター,莱斯特,레스터', 52.6386000, -1.1316900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59661, 'Leeswood', 'Leeswood', '', 53.1334700, -3.0946600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59662, 'Lee-on-the-Solent', 'Lee-on-the-Solent', 'Lee on Solent,Lee-on-the-Solent', 50.8016900, -1.2017400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59663, 'Leek Wootton', 'Leek Wootton', 'Leek Wootton', 52.3178200, -1.5793300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59664, 'Leek', 'Leek', 'Leek,Leek i Staffordshire,Lijk,Lik,lyk  astafwrdshr,Лийк,Лик,لیک، استافوردشر', 53.1043400, -2.0220700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59665, 'Leeds', 'Leeds', 'Gorad Lids,LBA,Ledesia,Leeds,Lids,Lidsa,Lidsas,Lijds,Lints,Loidis,Līdsa,Ritis,li ci,lidjha,lids,lidsa,lidzi,lie si,lijeu,lyds,lydz,rizu,Ληντς,Горад Лідс,Лидс,Лийдс,Лідс,Լիդս,לידז,לידס,ليدز,لیدز,لیڈز,ܠܝܕܣ,लीड्स,લીડ્ઝ,లీడ్స్,ಲೀಡ್ಸ್,ลีดส์,ლიდზი,リーズ,列斯,利兹,리즈', 53.7964800, -1.5478500, 'GB', '2016-07-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59666, 'Ledston', 'Ledston', 'Ledston,Ledstone', 53.7525400, -1.3435500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59667, 'Ledsham', 'Ledsham', '', 53.7632200, -1.3085700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59668, 'Ledsham', 'Ledsham', '', 53.2666700, -2.9666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59669, 'Ledbury', 'Ledbury', 'ldbwry,لدبوری', 52.0363900, -2.4263500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59670, 'Leconfield', 'Leconfield', 'Leckonfield,Leconfield', 53.8773000, -0.4572900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59671, 'Lechlade', 'Lechlade', 'lchlyd,لچلید', 51.6940300, -1.6912800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59672, 'Leatherhead', 'Leatherhead', 'Leatherhead,lytrhyd,لیترهید', 51.2965200, -0.3338000, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59673, 'Leasingham', 'Leasingham', 'Heasingham,Leasingham', 53.0257300, -0.4260600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59674, 'Royal Leamington Spa', 'Royal Leamington Spa', 'Leamington,Leamington Spa,Lemington,Lemington Spa,Rojal Lemington Spa,Rojal-Lemington-Spa,Royal Leamington Spa,huang jia li ming dun wen quan,rwyal lymyngtwn aspa,Лемингтон,Лемингтон Спа,Ройал-Лемингтон-Спа,Ројал Лемингтон Спа,رویال لیمینگتون اسپا,ロイヤル・レミントン・スパ,皇家利明頓溫泉', 52.3000000, -1.5333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59675, 'Lea', 'Lea', '', 51.9000000, -2.5000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59676, 'Layer de la Haye', 'Layer de la Haye', '', 51.8459300, 0.8574500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59677, 'Laxton', 'Laxton', '', 53.7200500, -0.8032900, 'GB', '2015-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59678, 'Law', 'Law', '', 55.7500000, -3.8833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59679, 'Lavenham', 'Lavenham', 'Lavenem,Лавенем', 52.1086100, 0.7961700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59680, 'Lavendon', 'Lavendon', 'Lavendon', 52.1727900, -0.6610900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59681, 'Laurencekirk', 'Laurencekirk', 'Laurencekirk', 56.8333800, -2.4654000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59682, 'Launceston', 'Launceston', 'Dunheafod,Dūnhēafod,Lannstefan,Launceston i Cornwall,Lonston,Лонстон', 50.6369900, -4.3600600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59683, 'Lauder', 'Lauder', 'Labhdair,Labhdar,Lauder,lao de,劳德', 55.7190800, -2.7475500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59684, 'Lathbury', 'Lathbury', 'Lathbury', 52.0988100, -0.7213200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59685, 'Latchingdon and Snoreham', 'Latchingdon and Snoreham', 'Latchingdon,Latchingdon and Snoreham,Snoreham', 51.6716000, 0.7257800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59686, 'Lartington', 'Lartington', 'Lartington', 54.5541500, -1.9723900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59687, 'Larne', 'Larne', 'Larn,Larnas,Latharna,la en,larn,lrn,ran,Ларн,לארן,לרן,لارن,ラーン,拉恩', 54.8500000, -5.8166700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59688, 'Lark Hill', 'Lark Hill', 'Lark Hill,Larkhill', 51.2000000, -1.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59689, 'Larkhall', 'Larkhall', 'Darkhall,Larkhall,Larkhauch,Larkkholl,Taigh na h-Uiseig,Ларкхолл', 55.7333300, -3.9666700, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59690, 'Largs', 'Largs', 'An Leargaidh Ghallda,Gorad Largs,Largs,largs,Горад Ларгс,Ларгс,لارگس', 55.7962900, -4.8633700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59691, 'Larbert', 'Larbert', 'Lairbert,Leirbeart,Leirbert,Lèirbeart,Lèirbert,Léirbert', 56.0224600, -3.8287200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59692, 'Llangwm', 'Llangwm', 'Langwm,Llangwm', 51.7483300, -4.9136100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59693, 'Langton', 'Langton', '', 54.0972000, -0.7854400, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59694, 'Langtoft', 'Langtoft', 'Langfoft,Langtoft', 52.6983400, -0.3404000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59695, 'Langport', 'Langport', 'Langport,langpwrt,لانگپورت', 51.0377800, -2.8280600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59696, 'Langley Park', 'Langley Park', '', 54.7997900, -1.6700500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59697, 'Langholm', 'Langholm', 'Langaim', 55.1510100, -2.9988900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59698, 'Langho', 'Langho', '', 53.8021700, -2.4507600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59699, 'Langham', 'Langham', '', 52.6915200, -0.7538500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59700, 'Langford', 'Langford', '', 52.0546000, -0.2716500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59701, 'Landrake', 'Landrake', '', 50.4226500, -4.2902300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59702, 'Landore', 'Landore', 'Landore', 51.6439600, -3.9414300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59703, 'Landewednack', 'Landewednack', 'Landewednack', 49.9696900, -5.1971800, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59704, 'Lanchester', 'Lanchester', '', 54.8210800, -1.7425600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59705, 'Lancaster', 'Lancaster', 'Caerhirfryn,Gorad Lankastehr,Lancaster,Lancaster i Lancashire,Lankaster,Lankasteris,Lankastér,Lonceaster,XQL,laengkeoseuteo,lan ka si te,lankstr,lnqstr,rankasuta,Горад Ланкастэр,Ланкастер,Լանքասթեր,לנקסטר,لانكستر,لنکاسٹر,لنکاسٹر، لنکاشائر,ランカスター,蘭卡斯特,랭커스터', 54.0464900, -2.7998800, 'GB', '2013-10-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59706, 'Lanark', 'Lanark', 'Lanark,Lannraig,Lanrik,lnark,ranaku,Ланарк,لنارک,ラナーク', 55.6737100, -3.7817000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59707, 'Lampeter', 'Lampeter', 'Lampeter,Lampitur,Llanbedr Pont Steffan,Λάμπετερ,Лампитър', 52.1128500, -4.0803900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59708, 'Lamlash', 'Lamlash', 'An t-Eilean Ard,An t-Eilean Árd,Loch an Eilein', 55.5335800, -5.1295600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59709, 'Lambourn', 'Lambourn', 'lmbwrn,لمبورن', 51.5080500, -1.5310500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59710, 'Lamberhurst', 'Lamberhurst', '', 51.1005000, 0.3896700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59711, 'Lakenheath', 'Lakenheath', 'Lake Heath,Lakenheath', 52.4175500, 0.5221100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59712, 'Ladybank', 'Ladybank', 'Ladybank', 56.2742100, -3.1239000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59713, 'Lacock', 'Lacock', 'Lacock,Laycock', 51.4152800, -2.1219400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59714, 'Laceby', 'Laceby', 'Laceby', 53.5409200, -0.1683000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59715, 'Knutsford', 'Knutsford', 'Natsford,natsfwrd,Натсфорд,ناتسفورد', 53.3028900, -2.3748200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59716, 'Knowsley', 'Knowsley', '', 53.4540100, -2.8539600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59717, 'Knowle', 'Knowle', 'Knowle', 52.3833300, -1.7333300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59718, 'Knottingley', 'Knottingley', 'Knottingley,Knottingly', 53.7077800, -1.2563900, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59719, 'Knighton', 'Knighton', 'Knighton,Trefyclo', 52.3425100, -3.0470800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59720, 'Knebworth', 'Knebworth', 'Knebworth,نب‌ورد', 51.8667400, -0.1839400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59721, 'Knaresborough', 'Knaresborough', 'Knaresborough,Nejrsboro,narsbwrw,Нейрсборо,نارسبورو', 54.0091000, -1.4685100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59722, 'Kiveton Park', 'Kiveton Park', 'Kiveton,Kiveton Park', 53.3412000, -1.2549800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59723, 'Kislingbury', 'Kislingbury', 'Kislingbury', 52.2297600, -0.9791400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59724, 'Kirton in Lindsey', 'Kirton in Lindsey', 'Kirton,Kirton in Lindsey', 53.4754800, -0.5956600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59725, 'Kirton', 'Kirton', '', 52.9277400, -0.0600800, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59726, 'Kirriemuir', 'Kirriemuir', 'Cearan Mhoire,Kirimjuur,Kirriemuir,Киримюър', 56.6739800, -3.0034300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59727, 'Kirkwall', 'Kirkwall', 'Bagh na h-Eaglaise,Baile na h-Eaglaise,Bàgh na h-Eaglaise,Bágh na h-Eaglaise,Ciricewael,Ciricewæl,KOI,Kerkgouol,Kerkuoll,Kerkvolas,Kerkvoll,Kirkvol,Kirkwaa,Kirkwall,kakuu~oru,ke ke wo er,keokeuwol,qyrqwwl,Κέρκγουολ,Керкволл,Керкуолл,Кирквол,קירקוול,カークウォール,柯克沃尔,커크월', 58.9847900, -2.9587300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59728, 'Kirk Sandall', 'Kirk Sandall', '', 53.5621100, -1.0687600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59729, 'Kirknewton', 'Kirknewton', '', 55.8875400, -3.4189800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59730, 'Kirknewton', 'Kirknewton', '', 55.5500000, -2.1333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59731, 'Kirkliston', 'Kirkliston', 'Kirkliston', 55.9536400, -3.4028800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59732, 'Kirkintilloch', 'Kirkintilloch', 'Cair Cheann Tulaich,Cathair Cheann Tulaich,Kerkintillokh,Kirkintillock,Kirkintillox,krkyntylf,Керкинтиллох,Керкінтіллох,کرکینتیلف', 55.9393300, -4.1526200, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59733, 'Kirkham', 'Kirkham', 'Kirkham,Kirkham i Lancashire,kyrkham  lankashr,کیرکهام، لانکاشر', 53.7824400, -2.8718900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59734, 'Kirk Ella', 'Kirk Ella', '', 53.7539900, -0.4549000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59735, 'Kirkcudbright', 'Kirkcudbright', 'Cille Chuithbeirt,Kerkubri,Kircudbright,Kirkcudbright,Керкубри,Керкубрі', 54.8383000, -4.0490800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59736, 'Kirkconnel', 'Kirkconnel', 'Kirkconnel', 55.3856100, -3.9983600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59737, 'Kirkcaldy', 'Kirkcaldy', 'Cair Chaladain,Kerkoldi,Kerkoldis,Kirkalnty,Kirkcaldy,Kirkcaudy,Kurkoldi,ke ke di,keokoldi,krkwdy,Κιρκάλντυ,Керколди,Керколді,Кърколди,کرکالڈی,کرکودی,柯科迪,커콜디', 56.1168300, -3.1599900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59738, 'Kirkby Stephen', 'Kirkby Stephen', 'Kirkby Stephen,kyrby astywn,کیربی استیون', 54.4722900, -2.3486500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59739, 'Kirkbymoorside', 'Kirkbymoorside', 'Kirby Moorside,Kirkby Moorside,kyrbymwrsayd,کیربیمورساید', 54.2701400, -0.9321800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59740, 'Kirkby Lonsdale', 'Kirkby Lonsdale', 'Kirkby Lonsdale,kyrby lansdyl,کیربی لانسدیل', 54.2025900, -2.5982700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59741, 'Kirkby in Ashfield', 'Kirkby in Ashfield', 'Kirkby,Kirkby in Ashfield', 53.0998200, -1.2437900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59742, 'Kirkby', 'Kirkby', 'Kerbi,Kirkby,Керби', 53.4813800, -2.8921500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59743, 'Kirkburton', 'Kirkburton', '', 53.6104700, -1.7029200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59744, 'Kircubbin', 'Kircubbin', '', 54.4873900, -5.5338500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59745, 'Kirby Underdale', 'Kirby Underdale', 'Kirby Underdale,Kirkby Underdale', 54.0171500, -0.7710200, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59746, 'Kirby Muxloe', 'Kirby Muxloe', 'Kirby Muxloe', 52.6302500, -1.2275500, 'GB', '2013-01-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59747, 'Kippen', 'Kippen', 'Kippen', 56.1267300, -4.1708300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59748, 'Kippax', 'Kippax', '', 53.7668700, -1.3709900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59749, 'Kinvere', 'Kinvere', 'Kinver,Kinvere', 52.4500000, -2.2333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59750, 'Kintore', 'Kintore', 'Ceann-an-Tor,Kintore', 57.2372100, -2.3454000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59751, 'Kintbury', 'Kintbury', '', 51.3995800, -1.4486500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59752, 'Kinsham', 'Kinsham', 'Kinsham,Upper Kinsham', 52.2833300, -2.9333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59753, 'Kinross', 'Kinross', 'Ceann Rois,Kinross', 56.2046600, -3.4213800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59754, 'Kinnersley', 'Kinnersley', '', 52.1333300, -2.9500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59755, 'Kinloss', 'Kinloss', '', 57.6349400, -3.5701200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59756, 'Kingussie', 'Kingussie', 'Ceann a Ghiuthsaich,Ceann a Ghiùthsaich,Ceann a Ghiúthsaich,Kineussie,Kingussie,jin you xi,金尤西', 57.0799600, -4.0523100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59757, 'Kington', 'Kington', 'Kington i Herefordshire,kyngtwn  hrfwrdshr,کینگتون، هرفوردشر', 52.2040800, -3.0255300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59758, 'Kington', 'Kington', 'Ceintun,Kington', 52.2000000, -2.0166700, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59759, 'Kings Worthy', 'Kings Worthy', 'Kings Worthy', 51.0886200, -1.2978000, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59760, 'Kingswood', 'Kingswood', 'Kingswood', 51.6258300, -2.3672200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59761, 'Kingswood', 'Kingswood', 'Kingsvud,Kingswood,Кингсвуд', 51.4527800, -2.5083300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59762, 'Kingswinford', 'Kingswinford', 'Kingswinford', 52.4975500, -2.1688900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59763, 'Kingston upon Hull', 'Kingston upon Hull', 'Hull,Kingston upon Hull,Kingston-apon-Khall,Kingston-upon-Hull,he er he pan jing shi dun,Кингстон-апон-Халл,האל,赫爾河畔京士頓', 53.7446000, -0.3352500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59764, 'Kingston Seymour', 'Kingston Seymour', '', 51.3983300, -2.8611100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59765, 'Kingstone', 'Kingstone', '', 52.0166700, -2.8333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59766, 'Kingston Bagpuize', 'Kingston Bagpuize', '', 51.6815000, -1.4204100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59767, 'Kingsteignton', 'Kingsteignton', 'Kingsteignton', 50.5500000, -3.5833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59768, 'Kings Sutton', 'Kings Sutton', '', 52.0231300, -1.2761300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59769, 'King''s Lynn', 'King''s Lynn', 'KNF,King''s Lynn,Kings Lin,Kings Linas,Kings Lynn,Kingslinn,King’s Lynn,Lynn,Lynn Regis,Кингс Лин,Кингслинн', 52.7517200, 0.3951600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59770, 'Kingsley', 'Kingsley', '', 53.2666700, -2.6666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59771, 'Kingsley', 'Kingsley', '', 51.1375200, -0.8782200, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59772, 'Kings Langley', 'Kings Langley', 'Kings Langley,Langeleia Regis,קינגס לאנגלי', 51.7139500, -0.4504400, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59773, 'Kingsland', 'Kingsland', '', 52.2491100, -2.8154200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59774, 'Kingskettle', 'Kingskettle', '', 56.2621500, -3.1169300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59775, 'Kingskerswell', 'Kingskerswell', '', 50.4991500, -3.5819500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59776, 'Kingsclere', 'Kingsclere', '', 51.3248700, -1.2433900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59777, 'Kingsbury', 'Kingsbury', 'kyngzbry,کینگزبری', 52.5610600, -1.6793600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59778, 'Kingsbridge', 'Kingsbridge', 'Kingsbridge,Kingsbridzh,kyngzbryj,Кингсбридж,کینگزبریج', 50.2845100, -3.7763800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59779, 'Kinglassie', 'Kinglassie', 'Kinglassie', 56.1737100, -3.2424100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59780, 'Kinghorn', 'Kinghorn', 'Kinghorn', 56.0689600, -3.1760700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59781, 'Kineton', 'Kineton', '', 52.1564500, -1.5114800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59782, 'Kincardine', 'Kincardine', 'Kincardine', 56.0694500, -3.7196400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59783, 'Kimpton', 'Kimpton', 'Kimpton', 51.8508900, -0.2998000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59784, 'Kimbolton', 'Kimbolton', '', 52.2970400, -0.3891600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59785, 'Kimbolton', 'Kimbolton', '', 52.2500000, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59786, 'Kimberley', 'Kimberley', 'Kimberley,Kimberley i Nottinghamshire,کیمبرلی، ناتینگهام‌شر', 52.9833300, -1.2666700, 'GB', '2012-02-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59787, 'Kilwinning', 'Kilwinning', 'Cill Fhinnean,Kiluinning,Kilvinning,ji er wen ning,kylwynyng,Килуиннинг,Кілвіннінг,کیلوینینگ,基爾溫寧', 55.6533300, -4.7066600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59788, 'Kilsyth', 'Kilsyth', 'Cill Saidhe,Kilsitas', 55.9759600, -4.0591600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59789, 'Kilsby', 'Kilsby', 'Kilsby', 52.3337500, -1.1750500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59790, 'Kilrea', 'Kilrea', '', 54.9509100, -6.5569500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59791, 'Kilpin', 'Kilpin', '', 53.7328000, -0.8339700, 'GB', '2015-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59792, 'Kilmington', 'Kilmington', '', 51.1269400, -2.3269400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59793, 'Kilmaurs', 'Kilmaurs', 'Cille Mhara,Cille Mhàra,Cille Mhára,Kilmaurs', 55.6380100, -4.5273000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59794, 'Kilmarnock', 'Kilmarnock', 'Cill Mhearnag,Cill Mhearnaig,Cill Mheàrnag,Cill Mheárnaig,Cille Mhearnaig,Cille Mheàrnaig,Kilmarnok,Kilmarnokas,ji er ma nuo ke,kilmanog,kirumanokku,klmarnwk,kylmarnak,Килмарнок,Кілмарнок,کلمارنوک,کیلمارناک,キルマーノック,基爾馬諾克,킬마녹', 55.6117100, -4.4958100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59795, 'Kilmacolm', 'Kilmacolm', '', 55.8947000, -4.6264300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59796, 'Killyleagh', 'Killyleagh', 'Killyleagh', 54.4013500, -5.6480000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59797, 'Killearn', 'Killearn', 'Killearn', 56.0423900, -4.3684000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59798, 'Killamarsh', 'Killamarsh', '', 53.3239500, -1.3168800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59799, 'Kilkeel', 'Kilkeel', '', 54.0619600, -6.0030800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59800, 'Kilham', 'Kilham', '', 54.0641300, -0.3805700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59801, 'Kilgetty', 'Kilgetty', 'Cilgeti', 51.7320300, -4.7198300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59802, 'Kilcreggan', 'Kilcreggan', 'Kilcreggan', 55.9846000, -4.8210000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59803, 'Kilburn', 'Kilburn', 'Kilbourn,Kilbourne,Kilburn', 53.0058000, -1.4386900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59804, 'Kilbirnie', 'Kilbirnie', 'Cille Bhraonaidh,Gorad Kilbirni,Kilbirni,Горад Кілбірні,Килбирни', 55.7508200, -4.6879100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59805, 'Kilbarchan', 'Kilbarchan', 'Kilbarchan', 55.8362000, -4.5535600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59806, 'Kidwelly', 'Kidwelly', 'Cydweli,Kidueli,Kidwelly,ji de wei li,Кидуели,基德韋利', 51.7363900, -4.3033300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59807, 'Kidsgrove', 'Kidsgrove', 'Kidsgrouv,Kidsgrove,kydsgrw,Кидсгроув,کیدسگرو', 53.0869100, -2.2377700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59808, 'Kidlington', 'Kidlington', 'Kidlington', 51.8216600, -1.2886000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59809, 'Kidderminster', 'Kidderminster', 'Kidderminster,Kiderminster,Kiderminsteris,ji de ming si te,kydrmynstr,Кидерминстер,کیدرمینستر,基德明斯特', 52.3881900, -2.2500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59810, 'Kibworth Harcourt', 'Kibworth Harcourt', 'Kibworth,Kibworth Harcourt', 52.5443900, -0.9949100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59811, 'Keynsham', 'Keynsham', 'Keynsham,kynsham,کینشام', 51.4138700, -2.4978000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59812, 'Keyingham', 'Keyingham', '', 53.7096100, -0.1132500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59813, 'Ketton', 'Ketton', 'Ketton', 52.6280400, -0.5545900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59814, 'Kettering', 'Kettering', 'Ketering,Kettering,Keturing,kai te ling,ketaringu,keteoling,ktryng,Кетеринг,Кеттеринг,Кетъринг,کترینگ,ケタリング,凱特靈,케터링', 52.3983600, -0.7257100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59815, 'Keswick', 'Keswick', 'Kesvik,Keswick,Keswick i Cumbria,Koswick,kai xi ke,kezu~ikku,kzyk  kambrya,Кесвик,کزیک، کامبریا,ケズィック,凯西克', 54.5994700, -3.1325600, 'GB', '2016-06-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59816, 'Kessingland', 'Kessingland', 'Kessingland', 52.4198700, 1.7087800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59817, 'Keresley', 'Keresley', 'Keresley', 52.4515600, -1.5331900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59818, 'Kenton', 'Kenton', 'Kenton', 50.6397800, -3.4715100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59819, 'Kensworth', 'Kensworth', '', 51.8517300, -0.5038600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59820, 'Kensington', 'Kensington', 'Kensington,Kensingtun,Kensinqton,ken xin dun,ken xing dun,kenjingteon,kenjinton,kensingtana,knzyngtwn,qnzyngtwn,Кенсингтон,Кенсингтън,Кенсінгтон,קנזינגטון,کنزینگتون,केंसिंग्टन,ケンジントン,肯星頓,肯辛顿,켄징턴', 51.5009400, -0.1917500, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59821, 'Kennoway', 'Kennoway', 'Kennoway', 56.2108100, -3.0491700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59822, 'Kennington', 'Kennington', '', 51.1674000, 0.8849100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59823, 'Kenn', 'Kenn', '', 51.4166700, -2.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59824, 'Kenley', 'Kenley', '', 52.6000000, -2.6333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59825, 'Kenilworth', 'Kenilworth', 'Keniluurt,Kenilworth,Кенилуърт,کنیل‌وورث', 52.3495800, -1.5827600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59826, 'Kendal', 'Kendal', 'KXN,Kendal,ken de er,kendaru,kendeul,kndal,Кендал,کندال,ケンダル,肯德爾,켄들', 54.3268100, -2.7475700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59827, 'Kemsing', 'Kemsing', '', 51.3060400, 0.2291700, 'GB', '2011-02-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59828, 'Kempston', 'Kempston', 'kmpstwn,کمپستون', 52.1159900, -0.5004400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59829, 'Kempsey', 'Kempsey', '', 52.1393600, -2.2175100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59830, 'Kemnay', 'Kemnay', 'Kemnay', 57.2357300, -2.4439500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59831, 'Kemble', 'Kemble', 'GBA,Kemble', 51.6749500, -2.0195100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59832, 'Kelvedon Hatch', 'Kelvedon Hatch', '', 51.6673900, 0.2681400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59833, 'Kelvedon', 'Kelvedon', '', 51.8400700, 0.7057000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59834, 'Kelty', 'Kelty', 'Kelty', 56.1336200, -3.3869000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59835, 'Kelso', 'Kelso', 'Cealsach,Cealsaidh,Kelsae,Kelso,kai er suo,Келсо,Քելսո,凯尔索', 55.5981400, -2.4338200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59836, 'Kelsall', 'Kelsall', '', 53.2077500, -2.7124200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59837, 'Keith', 'Keith', 'Baile Che,Baile Chè,Baile Ché,Keith,Kieth', 57.5363300, -2.9481100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59838, 'Keighley', 'Keighley', 'Keighley,Kejli,Kitli,ji si li,kyly,Кейли,Китли,کیلی,کیگلے,基斯利', 53.8679100, -1.9066400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59839, 'Kegworth', 'Kegworth', '', 52.8348200, -1.2804200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59840, 'Keele', 'Keele', '', 53.0038200, -2.2874100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59841, 'Keelby', 'Keelby', 'Keelby', 53.5758000, -0.2470100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59842, 'Kedington', 'Kedington', '', 52.0928200, 0.4867500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59843, 'Kearsley', 'Kearsley', 'Kearsley', 53.5333300, -2.3833300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59844, 'Keady', 'Keady', 'Keady', 54.2500000, -6.7000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59845, 'Keadby', 'Keadby', '', 53.5930800, -0.7402100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59846, 'Jordanstown', 'Jordanstown', 'Jordanstown', 54.6833300, -5.9000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59847, 'Johnstone', 'Johnstone', 'Baile Eoin,Baile Eòin,Baile Iain,Dzhonston,Johnstone,Johnstoun,janstwn,Джонстон,جانستون', 55.8290600, -4.5160500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59848, 'Johnston', 'Johnston', 'Johnston', 51.7555600, -4.9966700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59849, 'Jeffreyston', 'Jeffreyston', 'Jefferston,Jeffreston,Jeffreyston', 51.7250000, -4.7675000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59850, 'Jedburgh', 'Jedburgh', 'Deadard,Dzhedboro,Jedburg,Jedburgh,Jedburgo,Jethart,jedobara,jie de bao,Джедборо,ジェドバラ,杰德堡', 55.4799700, -2.5520000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59851, 'Jarrow', 'Jarrow', 'Dzharrou,Gyruum,Jarrow,Jarrow-on-Tyne,jarw  tayn w wr,ya luo,Джарроу,جارو، تاین و ور,雅羅', 54.9803600, -1.4842300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59852, 'Jacobstow', 'Jacobstow', 'Jacobstow', 50.7333300, -4.5500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59853, 'Ixworth', 'Ixworth', '', 52.2989300, 0.8341000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59854, 'Iwade', 'Iwade', '', 51.3775400, 0.7293500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59855, 'Ivybridge', 'Ivybridge', 'Pons Hederosus,آیوی‌بریج', 50.3903900, -3.9191400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59856, 'Ivinghoe', 'Ivinghoe', 'Ivinghoe', 51.8360200, -0.6298300, 'GB', '2010-08-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59857, 'Iver', 'Iver', 'Iver,awr,aywr,آیور,اور', 51.5000000, -0.5000000, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59858, 'Islington', 'Islington', 'District londonien d''Islington,Islington,Islinqton,Izlingtan,ayzlyntn,ijeullingteon,izurinton,yi si ling dun,İslinqton,Ізлінгтан,Ислингтон,איזלינגטון,ازلنگٹن، لندن,ایزلینتن,იზლინგტონი,イズリントン,伊斯靈頓,이즐링턴', 51.5362200, -0.1030400, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59859, 'Isleworth', 'Isleworth', 'Isleworth,QIF,a''izalavartha,aizuruwasu,ayzlwrth,ايزلورث,आइज़लवर्थ,アイズルワース', 51.4751800, -0.3424600, 'GB', '2012-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59860, 'Isleham', 'Isleham', '', 52.3428900, 0.4121200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59861, 'Irvinestown', 'Irvinestown', 'Irvinestown,Lowtherstown', 54.4666700, -7.6333300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59862, 'Irvine', 'Irvine', '"rvin,Ehrvin,Irbhinn,Irvin,Irvine i Ayrshire,OErvin,abain,arwyn,ou wen,Örvin,Ірвін,Ървин,Эрвин,اروین,アーバイン,歐文', 55.6194000, -4.6550800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59863, 'Irthlingborough', 'Irthlingborough', 'ایرتلینگ‌بورو', 52.3267400, -0.6112900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59864, 'Ironbridge', 'Ironbridge', 'Ironbridge', 52.6279500, -2.4846500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59865, 'Irlam', 'Irlam', '', 53.4425300, -2.4232300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59866, 'Irchester', 'Irchester', '', 52.2810800, -0.6451000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59867, 'Ipswich', 'Ipswich', 'Gippevicum,IPW,Ipsuich,Ipsvicas,Ipsvich,Ipsvičas,Ipswich,abswtsh,aypswyych,ibseuwichi,ipsuichi,ipsvic,ipusuu~itchi,xips wich,yi pu si wei qi,ʼypswwyz,Іпсвіч,Ипсвич,Ипсуич,Իպսուիչ,איפסוויץ,إبسوتش,ایپسوییچ,இப்ஸ்விச்,อิปสวิช,იფსუიჩი,イプスウィッチ,伊普斯威奇,입스위치', 52.0591700, 1.1554500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59868, 'Ipplepen', 'Ipplepen', '', 50.4891900, -3.6390000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59869, 'Inverurie', 'Inverurie', 'Inbhir Uaraidh,Inbhir Uraidh,Inbhir Úraidh,Inveruri,Inverurie,Inveruris,Invururi,yin fu lu li,Інверурі,Инверури,Инвърури,因弗鲁里', 57.2844600, -2.3773600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59870, 'Inverness', 'Inverness', 'INV,Inbhear Nis,Inbhir Nis,Innerness,Invernes,Invernesas,Inverness,Invurnes,anfrnys,anwrns,aynwrns,in''vu~anesu,inbeoneseu,xin wexr ness,yin wei nei si,İnverness,Ινβερνές,Інвернесс,Инвернес,Инвернесс,Инвърнес,Ինվերնես,אינוורנס,إنفرنيس,انورنس,اینورنس,อินเวอร์เนสส์,インヴァネス,印威內斯,인버네스', 57.4790800, -4.2239800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59871, 'Inverkip', 'Inverkip', 'Inverkip', 55.9083100, -4.8705100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59872, 'Inverkeithing', 'Inverkeithing', 'Inbhir Cheitinn,Inbhir Chèitinn,Inbhir Chéitinn,Inverkeithing,Inverkiting,Инверкитинг', 56.0329700, -3.3955500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59873, 'Invergowrie', 'Invergowrie', '', 56.4611100, -3.0615800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59874, 'Invergordon', 'Invergordon', 'Inbhir Ghordain,Inbhir Ghòrdain,Inbhir Ghórdain,Invergordon,yin fu ge deng,Инвергордон,因弗戈登', 57.6886000, -4.1674500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59875, 'Inverbervie', 'Inverbervie', 'Bervie,Inverbervie', 56.8446300, -2.2799700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59876, 'Insch', 'Insch', '', 57.3427300, -2.6132100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59877, 'Innerleithen', 'Innerleithen', '', 55.6192700, -3.0630100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59878, 'Inkberrow', 'Inkberrow', '', 52.2128400, -1.9809300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59879, 'Ingrave', 'Ingrave', '', 51.6041600, 0.3405800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59880, 'Ingoldmells', 'Ingoldmells', 'Ingoldmells', 53.1941400, 0.3335800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59881, 'Ingleton', 'Ingleton', '', 54.5795200, -1.7353200, 'GB', '2010-08-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59882, 'Ingleby Greenhow', 'Ingleby Greenhow', '', 54.4498300, -1.1068700, 'GB', '2010-12-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59883, 'Ingatestone', 'Ingatestone', 'Ingatestone', 51.6702700, 0.3835900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59884, 'Inchture', 'Inchture', '', 56.4455100, -3.1695600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59885, 'Inchinnan', 'Inchinnan', 'Inchinnan', 55.8899500, -4.4384200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59886, 'Ince-in-Makerfield', 'Ince-in-Makerfield', 'Ince,Ince-in-Makerfield', 53.5333300, -2.6166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59887, 'Ince Blundell', 'Ince Blundell', '', 53.5242900, -3.0273300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59888, 'Ince', 'Ince', '', 53.2833300, -2.8333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59889, 'Immingham', 'Immingham', 'aymyngham,yi ming han mu,ایمینگهام,伊明漢姆', 53.6123900, -0.2221900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59890, 'Ilminster', 'Ilminster', 'aylmynstr,ایلمینستر', 50.9268400, -2.9100900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59891, 'Ilkley', 'Ilkley', 'aylky,ایلکی', 53.9244900, -1.8232600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59892, 'Ilkeston', 'Ilkeston', 'Ilkeston,aylkstwn,ایلکستون', 52.9705500, -1.3095100, 'GB', '2015-06-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59893, 'Ilfracombe', 'Ilfracombe', 'Ilfracombe,Iltracombe,aylfrakm,ایلفراکم', 51.2093000, -4.1134400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59894, 'Ilford', 'Ilford', 'Ilford,aylfwrd,ilafarda,ilpeodeu,irufodo,yi er fu de,Илфорд,ایلفورد,इलफ़र्ड,イルフォード,伊爾福德,일퍼드', 51.5576500, 0.0727800, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59895, 'Ilchester', 'Ilchester', 'Lindinis,yi er qie si te,伊爾切斯特', 51.0058700, -2.6798100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59896, 'Ibstock', 'Ibstock', 'Ibstock', 52.6855400, -1.3996500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59897, 'Hythe', 'Hythe', 'Hythe,Hythe i Kent,Khajt,Khit,hayt  knt,hiti,Хайт,Хит,هایت، کنت,ჰითი', 51.0715000, 1.0842100, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59898, 'Hythe', 'Hythe', '', 50.8600400, -1.4016200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59899, 'Hyde', 'Hyde', '', 53.4513100, -2.0794300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59900, 'Huyton', 'Huyton', 'Huyton,Huyton with Roby,Khejton,Хейтон', 53.4115000, -2.8393500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59901, 'Hutton Magna', 'Hutton Magna', 'Great Hutton,Hutton Magna', 54.5099200, -1.8062200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59902, 'Hutton', 'Hutton', '', 51.3241700, -2.9302800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59903, 'Husthwaite', 'Husthwaite', 'Husthwaite', 54.1697200, -1.2094000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59904, 'Husbands Bosworth', 'Husbands Bosworth', '', 52.4523200, -1.0555700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59905, 'Hurworth', 'Hurworth', '', 54.4900800, -1.5329400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59906, 'Hurstpierpoint', 'Hurstpierpoint', '', 50.9338800, -0.1800700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59907, 'Hurst', 'Hurst', '', 51.4579100, -0.8519600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59908, 'Hurley', 'Hurley', '', 51.5464400, -0.8092100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59909, 'Hunwick', 'Hunwick', 'Hunwick', 54.6879100, -1.7053900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59910, 'Huntspill', 'Huntspill', '', 51.2056200, -2.9873500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59911, 'Huntly', 'Huntly', 'Hunndaidh,Huntly,Khuntli,Srath Bhalgaidh,heng te li,Хънтли,亨特利', 57.4474100, -2.7860800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59912, 'Huntley', 'Huntley', 'Huntley', 51.8717200, -2.4013700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59913, 'Huntington', 'Huntington', '', 54.0000000, -1.0500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59914, 'Huntingdon', 'Huntingdon', 'Gantingdon,Huntandun,Huntandūn,Huntingdon,Huntingtonia,Khuntingdun,The Huntingdon,XHU,hantindon,hantyngdwn,heng ting deng,heontingdeon,Гантінгдон,Хънтингдън,هانتینگدون,ہنٹنگڈن,ハンティンドン,亨廷登,헌팅던', 52.3304900, -0.1865100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59915, 'Hunstanton', 'Hunstanton', 'Hanstantonas,Hunstanton,hanstantwn,هانستانتون', 52.9500000, 0.5000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59916, 'Hunmanby', 'Hunmanby', 'Hunmanby', 54.1795700, -0.3200700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59917, 'Hungerford', 'Hungerford', 'hangrfwrd,هانگرفورد', 51.4151300, -1.5155600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59918, 'Humbleton', 'Humbleton', '', 53.7833300, -0.1500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59919, 'Humberston', 'Humberston', 'Humberston,Humberstone', 53.5303600, -0.0246500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59920, 'Humber', 'Humber', '', 52.2000000, -2.6666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59921, 'Huish', 'Huish', 'Huish', 51.3711400, -1.7926600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59922, 'Hugh Town', 'Hugh Town', 'Hugh Town,Kh''jutaun,Khju Taun,Khjutaun,Tre Huw,xiu zhen,Хьютаун,Хютаўн,Хју Таун,Հյուջ Թաուն,休镇', 49.9144700, -6.3114500, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59923, 'Huddersfield', 'Huddersfield', 'Chantersfilnt,Gaddersfild,Gorad Khadehrsfild,Haddersfild,Hadersfild,Hadersfildas,Huddersfield,Khaddersfild,Khadersfild,Khudursfijld,attarcupiltu,ha de si fei er de,hadasufirudo,haderzpildi,hadrzfyld,hdrsfyld,heodeojeupildeu,Χάντερσφιλντ,Гаддерсфілд,Горад Хадэрсфілд,Хаддерсфилд,Хадерсфилд,Хъдърсфийлд,Հադերսֆիլդ,هادرزفیلد,هدرسفيلد,அட்டர்சுபீல்டு,ჰადერზფილდი,ハダースフィールド,哈德斯菲爾德,허더즈필드', 53.6490400, -1.7841600, 'GB', '2016-07-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59924, 'Hucknall', 'Hucknall', 'Hucknall Torkard,Khuknal,Хъкнал', 53.0333300, -1.2000000, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59925, 'Hoyland Nether', 'Hoyland Nether', 'Hoyland,Hoyland Nether', 53.5000000, -1.4500000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59926, 'Hoylake', 'Hoylake', '', 53.3904600, -3.1806600, 'GB', '2014-09-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59927, 'Howwood', 'Howwood', 'Howwood', 55.8106000, -4.5573300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59928, 'Howden', 'Howden', 'hwdn,هودن', 53.7463000, -0.8699400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59929, 'Hove', 'Hove', 'Hove,Hove i England,Khouv,Khov,hovu,hww  anglstan,Хов,Хоув,هوو، انگلستان,ホヴ', 50.8308800, -0.1672000, 'GB', '2017-06-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59930, 'Houston', 'Houston', 'Cille Pheadair', 55.8685900, -4.5520100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59931, 'Hounslow', 'Hounslow', 'Hounslow,Hounslow keruelet,Hounslow kerület,London Borough of Hounslow,ha''unslo,hao en si luo,haunzuro,hwnslw,هونسلو,ہانزلو,हाउंस्लो,ハウンズロー,豪恩斯洛', 51.4683900, -0.3609200, 'GB', '2015-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59932, 'Houghton Regis', 'Houghton Regis', 'hwtwn rjys,هوتون رجیس', 51.9044100, -0.5212500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59933, 'Houghton on the Hill', 'Houghton on the Hill', 'Houghton,Houghton on the Hill', 52.6266300, -0.9954600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59934, 'Houghton-Le-Spring', 'Houghton-Le-Spring', 'Houghton-Le-Spring', 54.8403400, -1.4642700, 'GB', '2015-05-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59935, 'Houghton Conquest', 'Houghton Conquest', '', 52.0617800, -0.4775600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59936, 'Hotham', 'Hotham', '', 53.7958300, -0.6425300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59937, 'Horwich', 'Horwich', 'hwrwych,هورویچ', 53.6012600, -2.5497500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59938, 'Horton Kirby', 'Horton Kirby', '', 51.3948100, 0.2448300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59939, 'Horton', 'Horton', '', 51.5583300, -2.3525000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59940, 'Horton', 'Horton', '', 51.4731500, -0.5424500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59941, 'Horsted Keynes', 'Horsted Keynes', '', 51.0365900, -0.0279800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59942, 'Horsmonden', 'Horsmonden', '', 51.1390800, 0.4288100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59943, 'Horsley', 'Horsley', '', 54.9833300, -1.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59944, 'Horsham', 'Horsham', 'Horsham,Khorsham,Khorshehm,Khorshum,West Horsham,hwrshm,Хоршам,Хоршъм,Хоршэм,هورشم', 51.0631400, -0.3275700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59945, 'Horsforth', 'Horsforth', 'Horsfordia,huo si fu si,hwrsfwrth,هورسفورث,霍斯福斯', 53.8426000, -1.6375400, 'GB', '2015-05-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59946, 'Horsford', 'Horsford', '', 52.7015300, 1.2401500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59947, 'Horrabridge', 'Horrabridge', 'Horrabridge', 50.5084300, -4.1004200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59948, 'Hornsea', 'Hornsea', 'hwrnsy  rydyng shrqy ywrkshr,هورنسی، ریدینگ شرقی یورکشر', 53.9104100, -0.1680600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59949, 'Horning', 'Horning', 'Horning', 52.7046000, 1.4629400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59950, 'Horndon on the Hill', 'Horndon on the Hill', '', 51.5235800, 0.4049100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59951, 'Horncastle', 'Horncastle', 'Banovallum,Horncastle,هورنکستل، لینکلن‌شر', 53.2077500, -0.1172000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59952, 'Horley', 'Horley', 'hwrly,هورلی', 51.1742300, -0.1591900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59953, 'Horbury', 'Horbury', 'Horbury', 53.6605100, -1.5601400, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59954, 'Horam', 'Horam', 'Horam,Horeham', 50.9352300, 0.2443600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59955, 'Hopton on Sea', 'Hopton on Sea', 'Hopton,Hopton on Sea', 52.5333300, 1.7333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59956, 'Hope under Dinmore', 'Hope under Dinmore', 'Hope under Dinmore', 52.1833300, -2.7166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59957, 'Hopeman', 'Hopeman', 'Hopeman', 57.7068100, -3.4291100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59958, 'Hope', 'Hope', '', 53.1166700, -3.0333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59959, 'Hook Norton', 'Hook Norton', 'Hook Norton', 51.9956400, -1.4827700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59960, 'Hook', 'Hook', '', 53.7213200, -0.8489100, 'GB', '2015-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59961, 'Hook', 'Hook', '', 51.3680300, -0.3065000, 'GB', '2014-12-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59962, 'Hook', 'Hook', '', 51.2842500, -0.9596700, 'GB', '2011-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59963, 'Hoo', 'Hoo', '', 51.4205000, 0.5630000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59964, 'Honiton', 'Honiton', 'Honiton,hwnytwn,هونیتون', 50.7996000, -3.1889900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59965, 'Holywood', 'Holywood', 'Ard Mhic Nasca,Kholivud,Khouliud,huo li wu de,hwlywwd,Холивуд,Хоулиуд,הוליווד,霍利伍德', 54.6386300, -5.8247300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59966, 'Holywell', 'Holywell', 'Holivelis,Holywell,Khouliuel,Treffynnon,Хоулиуел', 53.2746600, -3.2289500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59967, 'Holytown', 'Holytown', '', 55.8201100, -3.9727000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59968, 'Holyhead', 'Holyhead', 'Caergybi,Goliged,HLY,Holihedas,Holyhead,Kholikhed,Khoulikhed,hollihedeu,horiheddo,huo li xi de,hwlyhd,Голігед,Холихед,Хоулихед,הוליהד,ホリーヘッド,霍利希德,홀리헤드', 53.3062100, -4.6321100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59969, 'Holwick', 'Holwick', 'Holwick', 54.6358000, -2.1437100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59970, 'Holton le Clay', 'Holton le Clay', '', 53.5052000, -0.0630000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59971, 'Holtby', 'Holtby', 'Holtby', 53.9787600, -0.9725500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59972, 'Holt', 'Holt', 'Holt', 53.0666700, -2.8833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59973, 'Holt', 'Holt', '', 51.3555600, -2.1972200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59974, 'Holsworthy', 'Holsworthy', 'Holsworthy i Devon,hwlswwrty  dwwn,هولسوورتی، دوون', 50.8119600, -4.3538300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59975, 'Holmwood', 'Holmwood', '', 51.1804900, -0.3217600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59976, 'Holmpton', 'Holmpton', '', 53.6877100, 0.0658300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59977, 'Holmfirth', 'Holmfirth', '', 53.5696800, -1.7877700, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59978, 'Holmes Chapel', 'Holmes Chapel', 'Holms Capel,Holms Čapel,Kholms Chapul,hwlmz tshabl,Холмс Чапъл,هولمز تشابل', 53.2014000, -2.3574200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59979, 'Hollym', 'Hollym', '', 53.7040200, 0.0400800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59980, 'Holbrook', 'Holbrook', '', 51.9834000, 1.1585400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59981, 'Holbeach', 'Holbeach', 'Holbicas,Holbičas,hwlbych,هولبیچ', 52.8040100, 0.0144200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59982, 'Hoddesdon', 'Hoddesdon', 'Hoddesdon,Khoddsdon,hwdsdwn,Ходдсдон,هودسدون', 51.7614800, -0.0114400, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59983, 'Hockwold cum Wilton', 'Hockwold cum Wilton', 'Hockwold,Hockwold cum Wilton', 52.4638000, 0.5461400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59984, 'Hockliffe', 'Hockliffe', '', 51.9310900, -0.5865200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59985, 'Hockley', 'Hockley', '', 52.5000000, -1.9166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59986, 'Hitchin', 'Hitchin', 'Hitchin,hichin,hytchyn,hytsyn,xi qin,היטשין,هیتچین,希欽,히친', 51.9492400, -0.2849600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59987, 'Histon', 'Histon', '', 52.2516600, 0.1064300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59988, 'Hirwaun', 'Hirwaun', 'Hirwain,Hirwaun', 51.7391700, -3.5102800, 'GB', '2017-06-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59989, 'Hinton Charterhouse', 'Hinton Charterhouse', '', 51.3237700, -2.3284100, 'GB', '2016-03-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59990, 'Hinton', 'Hinton', 'Hinton', 51.4897200, -2.3847200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59991, 'Hingham', 'Hingham', 'Hingham,hyngham  nwrfk,هینگهام، نورفک', 52.5796900, 0.9842200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59992, 'Hindon', 'Hindon', 'Hindon', 51.0922200, -2.1258300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59993, 'Hindley', 'Hindley', 'Hindley', 53.5333300, -2.5833300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59994, 'Hindhead', 'Hindhead', '', 51.1138100, -0.7335100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59995, 'Hinckley', 'Hinckley', 'Hinckley,Khinkli,hingkeulli,hynkly,Хинкли,هینکلی,힝클리', 52.5389000, -1.3761300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59996, 'Hilton', 'Hilton', 'Hilton', 52.2790800, -0.1122200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59997, 'Hillside', 'Hillside', 'Hillside', 56.7448300, -2.4740000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59998, 'Hillsborough', 'Hillsborough', '', 54.4634500, -6.0766400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(59999, 'Hill', 'Hill', '', 51.6513900, -2.5155600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60000, 'High Wycombe', 'High Wycombe', 'Chepping,HYC,High Wycombe,Khaj Uikumb,Khaj Vikom,Khaj-Uikom,Wycombe,hai wei ke mu,haiwikeom,hay waykamb,hi wi khamb,Хай Уикъмб,Хай-Уиком,Хај Виком,های وایکامب,ไฮวิคัมบ์,ハイ・ウィカム,海威科姆,하이위컴', 51.6290700, -0.7493400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60001, 'Highworth', 'Highworth', 'Highworth,haywwrth,هایوورث', 51.6305100, -1.7110000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60002, 'High Valleyfield', 'High Valleyfield', 'High Valleyfield,Valleyfield', 56.0635700, -3.5991300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60003, 'Hightown', 'Hightown', '', 53.5245200, -3.0619200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60004, 'High Ongar', 'High Ongar', '', 51.7095300, 0.2622100, 'GB', '2015-02-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60005, 'Highley', 'Highley', 'Highley', 52.4486600, -2.3825100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60006, 'High Legh', 'High Legh', '', 53.3513900, -2.4538000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60007, 'High Halstow', 'High Halstow', '', 51.4477500, 0.5555800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60008, 'High Halden', 'High Halden', '', 51.1033100, 0.7139400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60009, 'High Etherley', 'High Etherley', 'Etherley,High Etherley', 54.6539100, -1.7436300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60010, 'High Coniscliffe', 'High Coniscliffe', 'High Coniscliffe', 54.5333300, -1.6500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60011, 'Highclere', 'Highclere', 'Highclere', 51.3386000, -1.3756900, 'GB', '2011-02-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60012, 'Highbridge', 'Highbridge', 'Highbridge,Highbridge i Somerset', 51.2166700, -2.9833300, 'GB', '2012-05-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60013, 'High Blantyre', 'High Blantyre', 'Blantyre,High Blantyre', 55.7843800, -4.1000700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60014, 'High Bentham', 'High Bentham', 'Bentham,High Bentham', 54.1182300, -2.5119900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60015, 'Higham Ferrers', 'Higham Ferrers', 'hygham frrz,هیگهام فررز', 52.3059600, -0.5934200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60016, 'Hibaldstow', 'Hibaldstow', 'Hibaldstow', 53.5113300, -0.5208200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60017, 'Hexham', 'Hexham', 'Hagastaldunum,Hexham,Kheksem,hksham,Хексем,هکسهام', 54.9698600, -2.1040000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60018, 'Hetton-Le-Hole', 'Hetton-Le-Hole', 'Hetton-Le-Hole', 54.8166700, -1.4500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60019, 'Hethersett', 'Hethersett', 'Hethersett', 52.5976100, 1.1735900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60020, 'Heswall', 'Heswall', '', 53.3273300, -3.0964800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60021, 'Hessle', 'Hessle', 'hsl,هسل', 53.7245400, -0.4384200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60022, 'Heslington', 'Heslington', 'Heslington', 53.9463600, -1.0491900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60023, 'Hertford', 'Hertford', 'Heortford,Hertfordia,Khertford,ha te fu,hateupeodeu,hatofodo,hrtfwrd,Хертфорд,هرتفورد,ہارٹفورڈ,ჰერტფორდი,ハートフォード,哈特福,하트퍼드', 51.7958800, -0.0785400, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60024, 'Herstmonceux', 'Herstmonceux', 'Herstmonceux,Hurstmonceaux,Hurstmonceux', 50.8895800, 0.3229000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60025, 'Herne Bay', 'Herne Bay', 'Herne Bay,Herne Bay i Kent', 51.3730000, 1.1285700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60026, 'Hermitage', 'Hermitage', '', 51.4554000, -1.2682300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60027, 'Hereford', 'Hereford', 'Gereford,HFH,Henffordd,Hereford,Herefordas,Herefordia,Hererford,Khereford,Khereforde,he li fu de,he ri f xrd,helipeodeu,herefodo,hrfwrd,hrfwrd  anglstan,hrpwrd,xi fu,Герефорд,Херефорд,Херефорде,Հերերֆորդ,הרפורד,هرفورد,هرفورد، انگلستان,ہیریفورڈ,เฮริฟอร์ด,ヘレフォード,禧福,赫里福德,헤리퍼드', 52.0568400, -2.7148200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60028, 'Herbrandston', 'Herbrandston', '', 51.7263900, -5.0866700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60029, 'Henstridge', 'Henstridge', '', 50.9771700, -2.3950000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60030, 'Henlow', 'Henlow', '', 52.0302100, -0.2859900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60031, 'Henllan', 'Henllan', '', 53.2000000, -3.4666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60032, 'Henley on Thames', 'Henley on Thames', 'Henley on Thames', 51.5333300, -0.9000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60033, 'Henley in Arden', 'Henley in Arden', '', 52.2903200, -1.7780700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60034, 'Hengoed', 'Hengoed', 'Hengoed', 51.6508300, -3.2316700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60035, 'Henfield', 'Henfield', 'Henfield', 50.9299500, -0.2707100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60036, 'Hendon', 'Hendon', 'Khendon,hendana,hendeon,heng dun,hndwn,Хендон,هندون,ہینڈن، لندن,हेंडन,亨頓,헨던', 51.6000000, -0.2166700, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60037, 'Hemyock', 'Hemyock', 'Hemyock', 50.9123400, -3.2280700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60038, 'Hemsworth', 'Hemsworth', 'Hemsworth', 53.6126700, -1.3542400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60039, 'Hemsby', 'Hemsby', '', 52.6971400, 1.6918100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60040, 'Hemingford Grey', 'Hemingford Grey', 'Hemingford,Hemingford Grey', 52.3175600, -0.1002900, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60041, 'Hemingbrough', 'Hemingbrough', '', 53.7686300, -0.9767300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60042, 'Hemel Hempstead', 'Hemel Hempstead', 'Hemel,Hemel Hempstead,Khemel Khempsted,he mo er heng pu si te de,hemeolhempeuseutedeu,hml hmpstd,Хемел Хемпстед,همل همپستد,ヘメル・ヘムステッド,赫默爾亨普斯特德,헤멀헴프스테드', 51.7536800, -0.4497500, 'GB', '2015-05-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60043, 'Helston', 'Helston', 'Hellys,Helston,Henlys,hlstwn,هلستون', 50.1031900, -5.2704500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60044, 'Helsby', 'Helsby', 'hlsby,هلسبي', 53.2739600, -2.7690500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60045, 'Helpston', 'Helpston', 'Helpston,Helpstone', 52.6323300, -0.3467600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60046, 'Helmsley', 'Helmsley', 'hlmsly,هلمسلی', 54.2457700, -1.0568300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60047, 'Hellifield', 'Hellifield', 'Hellifield', 54.0048600, -2.2230200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60048, 'Helland', 'Helland', '', 50.5000000, -4.7166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60049, 'Helensburgh', 'Helensburgh', 'Baile Eilidh,Elenesburh,Gelensburg,Gorad Khelensburg,Helensburgas,Helensburgh,Khelensboro,Khelunsburg,hai lun si bao,herenzubara,Геленсбург,Горад Хеленсбург,Хеленсборо,Хелънсбърг,ヘレンズバラ,海倫斯堡', 56.0061400, -4.7264800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60050, 'Heighington', 'Heighington', '', 54.5959400, -1.6179100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60051, 'Heighington', 'Heighington', '', 53.2124100, -0.4590200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60052, 'Hedon', 'Hedon', 'hdwn,هدون', 53.7396200, -0.1965500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60053, 'Heddon on the Wall', 'Heddon on the Wall', '', 54.9969200, -1.7938600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60054, 'Heckmondwike', 'Heckmondwike', '', 53.7064600, -1.6774700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60055, 'Heckington', 'Heckington', 'Heckington', 52.9818300, -0.2990300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60056, 'Hebron', 'Hebron', '', 55.1833300, -1.6833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60057, 'Hebden Bridge', 'Hebden Bridge', '', 53.7409300, -2.0133700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60058, 'Hebburn', 'Hebburn', 'Gebburn,Hebburn,Hebburn-on-Tyne,Геббурн', 54.9730200, -1.5154600, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60059, 'Heathfield', 'Heathfield', 'Heathfield i East Sussex,hytfyld  sasks shrqy,هیتفیلد، ساسکس شرقی', 50.9671800, 0.2561200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60060, 'Heath and Reach', 'Heath and Reach', '', 51.9451700, -0.6569700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60061, 'Heanor', 'Heanor', 'Hinor,hynwr w lwskw,Հինոր,هینور و لوسکو', 53.0137200, -1.3538300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60062, 'Healing', 'Healing', '', 53.5810100, -0.1620200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60063, 'Healey', 'Healey', '', 54.9166700, -1.9666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60064, 'Heage', 'Heage', 'Heage', 53.0505000, -1.4468800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60065, 'Headcorn', 'Headcorn', '', 51.1696600, 0.6243300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60066, 'Heacham', 'Heacham', '', 52.9078200, 0.4938700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60067, 'Hazel Grove', 'Hazel Grove', 'Hazel Grove', 53.3833300, -2.1166700, 'GB', '2014-01-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60068, 'Haywards Heath', 'Haywards Heath', 'Baywards Heath,Haywards Heath,Khejuurds Khijt,haywardz hyth,Хейуърдс Хийт,هایواردز هیث', 50.9976900, -0.1031300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60069, 'Hayton', 'Hayton', '', 53.9000000, -0.7500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60070, 'Haynes', 'Haynes', '', 52.0664600, -0.3994600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60071, 'Hayle', 'Hayle', 'Hayle,Heyl,Khejl,hayl,Хейл,هایل', 50.1839200, -5.4213700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60072, 'Hayfield', 'Hayfield', '', 53.3789300, -1.9454400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60073, 'Hayes', 'Hayes', '', 51.5157900, -0.4234000, 'GB', '2012-03-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60074, 'Haydon Bridge', 'Haydon Bridge', 'Haydon Bridge', 54.9748600, -2.2468000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60075, 'Haydock', 'Haydock', '', 53.4672300, -2.6816600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60076, 'Hay', 'Hay', 'Hay,Hay-on-wye', 52.0704900, -3.1274100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60077, 'Haxey', 'Haxey', '', 53.4893700, -0.8402000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60078, 'Haxby', 'Haxby', 'Haxby', 54.0142200, -1.0712100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60079, 'Hawthorn', 'Hawthorn', '', 54.8000000, -1.3500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60080, 'Haworth', 'Haworth', 'Haworth,Khoehrt,hawasu,Хоэрт,ハワース', 53.8290500, -1.9482700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60081, 'Hawkinge', 'Hawkinge', '', 51.1127600, 1.1617600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60082, 'Hawkhurst', 'Hawkhurst', '', 51.0479000, 0.5109500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60083, 'Hawick', 'Hawick', 'Haaick,Hamhaig,Khoik,huo yi ke,Хоик,Хоїк,霍伊克', 55.4227300, -2.7866600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60084, 'Hawarden', 'Hawarden', 'Hawarden,Khavarden,Penarlag,Penarlâg,Хаварден', 53.1847800, -3.0257800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60085, 'Haverigg', 'Haverigg', '', 54.1997300, -3.2926300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60086, 'Haverhill', 'Haverhill', '', 52.0822600, 0.4389100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60087, 'Haverfordwest', 'Haverfordwest', 'Gejverfordvest,HAW,Haverfordvestas,Haverfordwest,Hwlffordd,Khaverforduehst,Khavurforduest,ha fu fu wei si te,Гейверфордвест,Хаверфордуэст,Хавърфордуест,哈弗福韦斯特', 51.8016900, -4.9691400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60088, 'Havant', 'Havant', 'Havant,Khavant,ha wen te,hawant,Хавант,هاوانت,哈文特', 50.8567000, -0.9855900, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60089, 'Haughley', 'Haughley', '', 52.2190700, 0.9680000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60090, 'Hatton', 'Hatton', 'Hatton', 52.3000700, -1.6326000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60091, 'Hathersage', 'Hathersage', 'Hathersage', 53.3303000, -1.6539800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60092, 'Hathern', 'Hathern', 'Hathern', 52.7954800, -1.2564400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60093, 'Hatherleigh', 'Hatherleigh', '', 50.8214400, -4.0722800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60094, 'Hatfield Peverel', 'Hatfield Peverel', '', 51.7759100, 0.5948900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60095, 'Hatfield Heath', 'Hatfield Heath', '', 51.8123300, 0.2124300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60096, 'Hatfield', 'Hatfield', '', 53.5778800, -0.9992400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60097, 'Hatfield', 'Hatfield', 'Bishops Hatfield,Hatfeldia,Hatfield,Hatfield i Hertfordshire,Khatfild,ha te fei er de,hatfyld  hrtfwrdshr,Хатфилд,هاتفیلد، هرتفوردشر,哈特菲尔德', 51.7633800, -0.2241900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60098, 'Haswell', 'Haswell', '', 54.7833300, -1.4166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60099, 'Hastings', 'Hastings', 'Gastings,Hastings,Heistingsas,Khejstings,hai si ting si,heiseutingseu,heisutingusu,hystnghs,hystyngz,Гастингс,Гастінгс,Хейстингс,Хејстингс,Հասթինգս,هيستنغس,هیستینگز,ヘイスティングス,海斯廷斯,헤이스팅스', 50.8551900, 0.5729200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60100, 'Hassocks', 'Hassocks', '', 50.9281400, -0.1661700, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60101, 'Haslingfield', 'Haslingfield', 'Haslingfield', 52.1501600, 0.0557900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60102, 'Haslingden', 'Haslingden', 'Haslingden,haslyngdn,هاسلینگدن', 53.7032600, -2.3238200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60103, 'Haslemere', 'Haslemere', 'haslmr,هاسلمر', 51.0901500, -0.7078500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60104, 'Harwich', 'Harwich', 'Harwich,Harwick,Kharidzh,Kharvich,QQH,harwych,Харвич,Харидж,هارویچ', 51.9419400, 1.2843700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60105, 'Harwell', 'Harwell', 'Harwell,Kharvel,Харвел', 51.5994700, -1.2917500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60106, 'Harvington', 'Harvington', 'Harvington', 52.1409500, -1.9231300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60107, 'Hartwell', 'Hartwell', '', 52.1461600, -0.8537600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60108, 'Hartshill', 'Hartshill', 'Hartshill', 52.5483100, -1.5222100, 'GB', '2015-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60109, 'Hartley Wintney', 'Hartley Wintney', '', 51.3037900, -0.9001900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60110, 'Hartley', 'Hartley', '', 51.3867300, 0.3036700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60111, 'Hartlepool', 'Hartlepool', 'Harlepolis,Hartlepool,Hartlepulas,Khartlpul,ha te er pu,har tli phul,hatorupuru,Хартлпул,هارتل‌پول,ฮาร์ตลีพูล,ハートルプール,哈特爾浦', 54.6861100, -1.2125000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60112, 'Hartlebury', 'Hartlebury', 'Hartlebury', 52.3333300, -2.2333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60113, 'Harthill', 'Harthill', 'Harthill', 55.8606700, -3.7516600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60114, 'Harthill', 'Harthill', 'Harthill', 53.3166700, -1.2666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60115, 'Harthill', 'Harthill', '', 53.0833300, -2.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60116, 'Hartford', 'Hartford', '', 53.2450800, -2.5511900, 'GB', '2015-01-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60117, 'Hartburn', 'Hartburn', 'Hartburn', 55.1666700, -1.8500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60118, 'Harston', 'Harston', '', 52.1369100, 0.0799900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60119, 'Harrow on the Hill', 'Harrow on the Hill', 'Harrow,Harrow keruelet,Harrow kerület,Harrow on the Hill', 51.5714200, -0.3337100, 'GB', '2010-09-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60120, 'Harrow', 'Harrow', 'Harrow i London,ha luo,harou,harw  lndn,هارو، لندن,ハーロウ,哈羅', 51.5783500, -0.3320800, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60121, 'Harrold', 'Harrold', '', 52.2012700, -0.6103800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60122, 'Harrogate', 'Harrogate', 'HRT,Harrogate,Kharrogejt,ha luo gai te,harogeito,harwghyt,hrwgyt,Харрогейт,هاروغيت,هروگیت,ჰეროგეიტი,ハロゲイト,哈罗盖特', 53.9907800, -1.5373000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60123, 'Harrietsham', 'Harrietsham', '', 51.2425200, 0.6706000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60124, 'Harpole', 'Harpole', 'Harpole', 52.2424600, -0.9893700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60125, 'Harpenden', 'Harpenden', 'ha peng deng,harpndn,هارپندن,哈彭登', 51.8168400, -0.3570600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60126, 'Harlow', 'Harlow', 'Gorad Kharlau,Harlow,Kharlou,hallo,harlw,harou,Горад Харлаў,Харлоу,هارلو,ہارلو,ハーロウ,할로', 51.7765500, 0.1115800, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60127, 'Harlington', 'Harlington', '', 51.9628800, -0.4924100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60128, 'Harley', 'Harley', 'Harley', 52.6000000, -2.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60129, 'Harleston', 'Harleston', 'Harleston', 52.4030200, 1.2966400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60130, 'Harlech', 'Harlech', 'Harlech,Kharlekh,harekku,hrlk,Харлех,הרלך,ハーレック', 52.8594100, -4.1083100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60131, 'Harefield', 'Harefield', 'Harefield,herafilda,हेरफ़ील्ड', 51.6033300, -0.4854600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60132, 'Hardingstone', 'Hardingstone', '', 52.2135800, -0.8858200, 'GB', '2011-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60133, 'Harbury', 'Harbury', '', 52.2353700, -1.4570600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60134, 'Hapton', 'Hapton', 'Hapton', 53.7833300, -2.3166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60135, 'Hanwell', 'Hanwell', '', 52.0912400, -1.3676300, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60136, 'Hanslope', 'Hanslope', '', 52.1142500, -0.8267200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60137, 'Hannington', 'Hannington', '', 51.6333300, -1.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60138, 'Hankerton', 'Hankerton', '', 51.6144400, -2.0450000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60139, 'Handcross', 'Handcross', '', 51.0538300, -0.2007600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60140, 'Hamsterley', 'Hamsterley', '', 54.6833300, -1.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60141, 'Hampton in Arden', 'Hampton in Arden', 'Hampton in Arden', 52.4254000, -1.7027100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60142, 'Hampton', 'Hampton', 'Hampton', 51.4133400, -0.3670100, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60143, 'Hammersmith', 'Hammersmith', 'Hammersmith,Khammersmit,WUK,ha mo shi mi si,haemeoseumiseu,haimarasmitha,hamasumisu,hamrsmyth,hmrsmyt,Хаммерсмит,هامرسميث,همرسمیت,हैमरस्मिथ,ハマースミス,哈默史密斯,해머스미스', 51.4938400, -0.2288200, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60144, 'Hamilton', 'Hamilton', 'Baile Hamaltan,Gamil''ton,Hamaltan,Hamilton i Skottland,Hamiltonas,Hamiltoun,Həmilton,Khamiltun,hamiruton,han mi er dun,hmyltwn,Гамильтон,Гамільтон,Хамилтън,همیلتون,ہملٹن,ہیملٹن، جنوبی لینکاشائر,ハミルトン,漢密爾頓', 55.7666700, -4.0333300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60145, 'Hambleton', 'Hambleton', 'Hambleton', 53.7666700, -1.1666700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60146, 'Hamble', 'Hamble', 'Hample', 50.8596600, -1.3243200, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60147, 'Haltwhistle', 'Haltwhistle', 'haltwystl,هالتویستل', 54.9710100, -2.4568200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60148, 'Halton', 'Halton', '', 54.0788700, -2.7580000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60149, 'Halton', 'Halton', '', 53.3166700, -2.7000000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60150, 'Halstead', 'Halstead', 'halstyd  asks,هالستید، اسکس', 51.9450600, 0.6392700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60151, 'Halsham', 'Halsham', '', 53.7298500, -0.0745000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60152, 'Hallow', 'Hallow', '', 52.2234400, -2.2546800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60153, 'Halling', 'Halling', '', 51.3514200, 0.4452000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60154, 'Halkyn', 'Halkyn', 'Halkin,Halkyn', 53.2255600, -3.1901600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60155, 'Halkirk', 'Halkirk', 'Hacraig', 58.5122700, -3.4915500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60156, 'Halifax', 'Halifax', 'Galifaks,Halifax,Halifax i England,Khalifaks,ha li fa ke si,haellipaegseu,harifakusu,hlyfks,Галифакс,Халифакс,האליפאקס,هلیفکس,ハリファクス,哈利法克斯,핼리팩스', 53.7166700, -1.8500000, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60157, 'Halesworth', 'Halesworth', 'halswwrth,هالسوورث', 52.3464000, 1.5029000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60158, 'Halesowen', 'Halesowen', 'Halesowen,Heilsovenas,Khejlsoven,hylzawwn,Хейлсовен,Хејлсовен,هیلزاوون', 52.4485900, -2.0493800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60159, 'Hale', 'Hale', '', 53.3333300, -2.8000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60160, 'Hale', 'Hale', 'Hale', 51.2294600, -0.7890800, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60161, 'Hailsham', 'Hailsham', 'Fairlight,Hailsham,haylsham,هایلشام', 50.8622000, 0.2577500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60162, 'Haigh', 'Haigh', '', 53.6000000, -2.5833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60163, 'Hagley', 'Hagley', 'Hagley,ha ge li,哈格利', 52.4262000, -2.1281900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60164, 'Hadlow', 'Hadlow', '', 51.2241700, 0.3391400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60165, 'Hadley', 'Hadley', 'Hadley', 52.7000000, -2.4833300, 'GB', '2016-07-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60166, 'Hadleigh', 'Hadleigh', 'hadly  safk,هادلی، سافک', 52.0449900, 0.9529800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60167, 'Hadleigh', 'Hadleigh', '', 51.5526900, 0.6098300, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60168, 'Haddington', 'Haddington', 'Baile Adainn,Gaddington,Haddinqton,ha ding dui,Гаддінгтон,哈丁敦', 55.9561200, -2.7833200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60169, 'Haddenham', 'Haddenham', '', 52.3578900, 0.1482700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60170, 'Haddenham', 'Haddenham', 'Haddenham', 51.7732600, -0.9262800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60171, 'Hackney', 'Hackney', '', 51.5500000, -0.0500000, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60172, 'Hackleton', 'Hackleton', 'Hackleton', 52.1879800, -0.8231200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60173, 'Gurnard', 'Gurnard', 'Gurnard', 50.7605700, -1.3241100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60174, 'Gunnislake', 'Gunnislake', 'Gunnislake', 50.5244100, -4.2133300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60175, 'Gunness', 'Gunness', 'Gunhouse,Gunness', 53.5908000, -0.7283400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60176, 'Gullane', 'Gullane', 'A Ghualainn', 56.0365200, -2.8282900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60177, 'Guiseley', 'Guiseley', 'Gajzli,Guiseley,Гайзли', 53.8756100, -1.7123200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60178, 'Guisborough', 'Guisborough', 'gwysbwrw,گویسبورو', 54.5347800, -1.0560600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60179, 'Guilsfield', 'Guilsfield', '', 52.6963400, -3.1571200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60180, 'Guildford', 'Guildford', 'Gildfordas,Gilford,Gilfordia,Guildford,Guilford,ghldfwrd,gilpeodeu,girufodo,gyldfwrd,ji er fu de,Гилфорд,Гілфорд,غلدفورد,گیلدفورد,گیلڈفورڈ,ギルフォード,吉爾福德,길퍼드', 51.2353600, -0.5742700, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60181, 'Grundisburgh', 'Grundisburgh', 'Grundisburgh', 52.1122200, 1.2461800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60182, 'Grove', 'Grove', '', 51.6095400, -1.4218700, 'GB', '2010-10-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60183, 'Grosmont', 'Grosmont', 'Grosmont,Grosmount,Y Grysmwnt', 51.9166700, -2.8666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60184, 'Groombridge', 'Groombridge', 'Groombridge', 51.1154300, 0.1829500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60185, 'Griston', 'Griston', '', 52.5572000, 0.8643600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60186, 'Grindon', 'Grindon', '', 54.6166700, -1.3833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60187, 'Grindale', 'Grindale', '', 54.1245300, -0.2736300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60188, 'Grimston', 'Grimston', '', 52.7901100, -0.9865600, 'GB', '2011-03-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60189, 'Grimston', 'Grimston', '', 52.7731200, 0.5484600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60190, 'Grimsby', 'Grimsby', 'GSY,Great Grimsby,Grimsbi,Grimsbis,Grimsby,Grimzbi,ge li mu si bi,geulimjeubi,grymsbay,gurimuzubi,Гримзби,Гримсби,گریمسبای,グリムズビー,格里姆斯比,그림즈비', 53.5653900, -0.0755300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60191, 'Greyabbey', 'Greyabbey', '', 54.5348300, -5.5602800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60192, 'Gretna', 'Gretna', 'Greatna,Gretna', 54.9938000, -3.0659400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60193, 'Gresford', 'Gresford', 'Gresford', 53.0853900, -2.9706200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60194, 'Greetham', 'Greetham', '', 52.7205900, -0.6306800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60195, 'Greenock', 'Greenock', 'Greenock,Grianaig,Grijnok,Grinok,Grinokas,Qrinok,ge li nuo ke,geulinog,grynwk,gurinokku,Грийнок,Гринок,Грінок,گرینوک,გრინოკი,グリーノック,格里诺克,그리녹', 55.9483800, -4.7612100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60196, 'Greenisland', 'Greenisland', 'Greenisland,Grijnajland,Inis Glas,grinislanda,Грийнайланд,ग्रीनिस्लंद', 54.7008100, -5.8747900, 'GB', '2016-12-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60197, 'Greenhithe', 'Greenhithe', '', 51.4502600, 0.2853900, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60198, 'Greenhead', 'Greenhead', 'Greenhead', 54.9666700, -2.5166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60199, 'Greenford', 'Greenford', 'Greenford,grinafarda,grynfwrd,گرینفورد,گرینفورڈ,ग्रीनफ़र्ड', 51.5286600, -0.3550800, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60200, 'Greenfield', 'Greenfield', 'Greenfield', 53.2833300, -3.2166700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60201, 'Great Yeldham', 'Great Yeldham', 'Great Yeldham,Yeldham', 52.0134700, 0.5654000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60202, 'Great Yarmouth', 'Great Yarmouth', 'Gorad Grehjt-Jarmut,Grejt Jarmut,Grejt-Jarmut,Yarmouth,geuleiteuyameoseu,gryt yarmwth,Горад Грэйт-Ярмут,Грейт-Ярмут,Грејт Јармут,گریت یارموث,グレート・ヤーマス,그레이트야머스', 52.6083100, 1.7305200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60203, 'Great Wyrley', 'Great Wyrley', 'Great Wyrley,Wyrley', 52.6627700, -2.0111100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60204, 'Great Waldingfield', 'Great Waldingfield', 'Great Waldingfield,Waldingfield', 52.0554500, 0.7743600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60205, 'Great Wakering', 'Great Wakering', '', 51.5524200, 0.8038000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60206, 'Great Torrington', 'Great Torrington', 'Great Torrington,Torrington,gryt twryngtwn,گریت تورینگتون', 50.9530900, -4.1440100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60207, 'Great Sankey', 'Great Sankey', 'Great Sankey,Sankey', 53.3923400, -2.6399400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60208, 'Great Paxton', 'Great Paxton', 'Great Paxton', 52.2605700, -0.2281800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60209, 'Great Ness', 'Great Ness', 'Great Ness', 52.7638500, -2.8915100, 'GB', '2015-01-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60210, 'Great Munden', 'Great Munden', '', 51.8996700, -0.0394400, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60211, 'Great Missenden', 'Great Missenden', 'Great Missenden,ghryt mysndn,غريت ميسندن', 51.7041900, -0.7079700, 'GB', '2010-08-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60212, 'Great Malvern', 'Great Malvern', 'Great Malvern,Malvern', 52.1116100, -2.3251500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60213, 'Great Leighs', 'Great Leighs', 'Great Leighs', 51.8276100, 0.5064000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60214, 'Great Houghton', 'Great Houghton', 'Great Houghton,Houghton', 53.5535200, -1.3495200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60215, 'Great Horwood', 'Great Horwood', '', 51.9735100, -0.8808800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60216, 'Great Horkesley', 'Great Horkesley', 'Great Horkesley,Horkesley', 51.9382100, 0.8755100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60217, 'Great Harwood', 'Great Harwood', 'Nkreit Chargount,Γκρέιτ Χάργουντ', 53.7851200, -2.4086500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60218, 'Great Hanwood', 'Great Hanwood', 'Great Hanwood,Hanwood', 52.6833300, -2.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60219, 'Greatham', 'Greatham', '', 54.6418300, -1.2380600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60220, 'Great Habton', 'Great Habton', 'Great Habton,Habton', 54.1784100, -0.8416600, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60221, 'Great Gransden', 'Great Gransden', 'Gransden,Great Gransden', 52.1854600, -0.1457400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60222, 'Great Gonerby', 'Great Gonerby', '', 52.9350700, -0.6668500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60223, 'Great Glen', 'Great Glen', 'Great Glen,Great Glenn', 52.5754800, -1.0349000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60224, 'Great Eccleston', 'Great Eccleston', 'Eccleston,Great Eccleston', 53.8531500, -2.8702600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60225, 'Great Dunmow', 'Great Dunmow', 'Dunmow,Great Dunmow,gryt danmw,گریت دانمو', 51.8723000, 0.3625500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60226, 'Driffield', 'Driffield', 'Driffield,dryfyld,دریفیلد', 54.0061300, -0.4449500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60227, 'Great Coates', 'Great Coates', 'Great Coates', 53.5707000, -0.1390500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60228, 'Great Chesterford', 'Great Chesterford', 'Chesterford,Great Chesterford', 52.0643100, 0.1972000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60229, 'Great Bookham', 'Great Bookham', 'Great Bookham', 51.2791600, -0.3742300, 'GB', '2012-05-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60230, 'Great Bentley', 'Great Bentley', '', 51.8533300, 1.0637900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60231, 'Great Bedwyn', 'Great Bedwyn', 'Bedwyn,Great Bedwyn', 51.3795000, -1.6015100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60232, 'Great Barton', 'Great Barton', 'Great Barton', 52.2725700, 0.7667900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60233, 'Great Barford', 'Great Barford', '', 52.1579100, -0.3523500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60234, 'Great Bardfield', 'Great Bardfield', 'Great Bardfield', 51.9481300, 0.4364500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60235, 'Great Ayton', 'Great Ayton', '', 54.4914800, -1.1362300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60236, 'Great Amwell', 'Great Amwell', '', 51.7901400, -0.0166900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60237, 'Grays', 'Grays', 'Grays,Grays Thurrock,Grejz,ge lei si,geuleiseu,gryz  anglstan,Грејз,گریز، انگلستان,格雷斯,그레이스', 51.4756600, 0.3252100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60238, 'Gravesend', 'Gravesend', 'Gravesend,Grejvsend,Grejvzend,ge lei fu sen de,geuleibeujendeu,grywznd,Грейвзенд,Грејвсенд,گریوزند,格雷夫森德,그레이브젠드', 51.4420600, 0.3710600, 'GB', '2017-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60239, 'Gravenhurst', 'Gravenhurst', '', 52.0085400, -0.3698200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60240, 'Grassington', 'Grassington', '', 54.0714000, -1.9982200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60241, 'Grantown on Spey', 'Grantown on Spey', 'Grantown,Grantown on Spey', 57.3305100, -3.6086700, 'GB', '2017-06-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60242, 'Grantham', 'Grantham', 'Grantam,Grantem,Grantham,Grantum,Granty,XGM,ge lan se mu,grantham,guransamu,Грантем,Грантъм,Гранты,گرانتهام,グランサム,格兰瑟姆', 52.9114900, -0.6418400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60243, 'Grangemouth', 'Grangemouth', 'Grangemouth', 56.0114100, -3.7218300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60244, 'Grain', 'Grain', '', 51.4559100, 0.7112600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60245, 'Goxhill', 'Goxhill', 'Goxhill', 53.6763500, -0.3375900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60246, 'Govilon', 'Govilon', 'Govilon', 51.8192800, -3.0629500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60247, 'Gourock', 'Gourock', 'Guireag,Gurok,Гурок', 55.9615700, -4.8178900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60248, 'Goudhurst', 'Goudhurst', '', 51.1131400, 0.4561500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60249, 'Gotham', 'Gotham', 'Gotham', 52.8679900, -1.2055800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60250, 'Gosport', 'Gosport', 'Gosport,gaspwrt,ge si bo te,Госпорт,گاسپورت,戈斯波特', 50.7950900, -1.1290200, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60251, 'Gosforth', 'Gosforth', 'Gosforth,Gosforth i Newcastle,gosufosu,ゴスフォース', 55.0000000, -1.6166700, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60252, 'Gosfield', 'Gosfield', '', 51.9365700, 0.5919700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60253, 'Gosberton', 'Gosberton', 'Gosberton', 52.8691300, -0.1610200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60254, 'Gorseinon', 'Gorseinon', 'Gorsejnon,Горсейнон', 51.6693100, -4.0416300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60255, 'Gorleston-on-Sea', 'Gorleston-on-Sea', 'Gorleston', 52.5730100, 1.7306900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60256, 'Goring-by-Sea', 'Goring-by-Sea', 'Goring,Goring by Sea', 50.8123900, -0.4219400, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60257, 'Goring', 'Goring', '', 51.5232200, -1.1334200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60258, 'Gorebridge', 'Gorebridge', 'Gorebridge', 55.8459400, -3.0456300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60259, 'Goostrey', 'Goostrey', '', 53.2273100, -2.3391900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60260, 'Goosnargh', 'Goosnargh', '', 53.8220000, -2.6701700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60261, 'Goole', 'Goole', 'Gul,gwl  rydyng shrqy ywrkshr,jwwl,Гул,جوول,گول، ریدینگ شرقی یورکشر', 53.7032400, -0.8773200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60262, 'Goodwick', 'Goodwick', 'Wdig', 52.0049100, -4.9951100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60263, 'Golspie', 'Golspie', 'Goillspidh,Golspie', 57.9726600, -3.9779800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60264, 'Goldcliff', 'Goldcliff', 'Goldcliff', 51.5422200, -2.9177800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60265, 'Golborne', 'Golborne', '', 53.4769300, -2.5965100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60266, 'Godstone', 'Godstone', '', 51.2477900, -0.0691400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60267, 'Godshill', 'Godshill', '', 50.6330800, -1.2547600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60268, 'Godmanchester', 'Godmanchester', 'Durolipons,Godmanchester,Godmundesceaster,gwdmnchstr,گودمنچستر', 52.3193900, -0.1750900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60269, 'Godalming', 'Godalming', 'Godalming,Godalminge,Godlmingas,godelmingi,godeolming,gwdalmyng,Годалминг,Годалминге,گودالمینگ,გოდელმინგი,고덜밍', 51.1858000, -0.6148900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60270, 'Gobowen', 'Gobowen', 'Gobowen', 52.8961500, -3.0368600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60271, 'Gnosall', 'Gnosall', 'Gnosall,Gnossall', 52.7855800, -2.2548300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60272, 'Glyn-neath', 'Glyn-neath', 'Glyn Neath,Glyn-neath', 51.7475000, -3.6183300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60273, 'Glyncorrwg', 'Glyncorrwg', 'Glyncorrwg,Glyncorwg', 51.6794400, -3.6280600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60274, 'Glusburn', 'Glusburn', 'Glusburn', 53.9000000, -2.0000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60275, 'Gloucester', 'Gloucester', 'Caerloyw,GLO,Glevum,Gloster,Glosteris,Glostur,Gloucester,Glutsester,Glutséstér,Gorad Glostehr,gao luo shi da,ge luo si te,geulloseuteo,ghlwstr,glastr,glwstr,gurosuta,jlwstr,klxs texr,Глостер,Глостър,Горад Глостэр,Գլոստեր,גלאסטער,גלוסטר,جلوستر,غلوستر,گلاستر,گلوسسٹر,گلوسٹر,กลอสเตอร์,グロスター,告羅士打,格洛斯特,글로스터', 51.8656800, -2.2431000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60276, 'Glossop', 'Glossop', 'Ardotalia,Glossop,Glosup,glwswp,Глосъп,گلوسوپ', 53.4432500, -1.9490000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60277, 'Glinton', 'Glinton', '', 52.6392100, -0.2962900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60278, 'Glenrothes', 'Glenrothes', 'Gleann Rathais,Gleann Ráthais,Glenrotes,Glenrotesas,Glenrots,Qlenrots,ge lun luo xi si,geullenlosiseu,glnratys,Гленротес,Гленротс,گلنراتیس,格倫羅西斯,글렌로시스', 56.1951400, -3.1731600, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60279, 'Glenfield', 'Glenfield', 'Glenfield,Glenfield i England', 52.6466000, -1.1949300, 'GB', '2014-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60280, 'Glenboig', 'Glenboig', '', 55.8942200, -4.0461900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60281, 'Glenavy', 'Glenavy', 'Glenavy', 54.5923100, -6.2137100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60282, 'Glenariff', 'Glenariff', 'Glenariff,Glenariffe,Warren,Waterfoot', 55.0500000, -6.0666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60283, 'Glemsford', 'Glemsford', '', 52.1035100, 0.6691200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60284, 'Glazebury', 'Glazebury', '', 53.4707800, -2.4982300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60285, 'Glastonbury', 'Glastonbury', 'Glastonberi,Glastonbury,Glastonia,Nklastonmperi,ge la si dun bo li,geullaeseuteonbeli,glastwnbwry,glstwnbry,gurasutonberi,Γκλάστονμπερι,Гластонбери,Гластонбері,גלסטונברי,گلاستونبوری,グラストンベリー,格拉斯頓伯里,글래스턴베리', 51.1474500, -2.7207500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60286, 'Glasgow', 'Glasgow', 'GLA,Glascho,Glaschu,Glaschú,Glasgovo,Glasgow,Glasgua,Glaskobe,Glazgas,Glazgo,Glazgos,Glazgou,Glazgov,Glazgova,Glazgua,Glesga,Glázgua,Glāzgova,Gorad Glazga,Kak-la-su-ko,Kak-là-sṳ̂-kô,Qlazqo,galasago,ge la si ge,geullaeseugo,ghlaskw,glasago,glasgo,glasgw,glasgwv,glazgo,glyasgo,gurasugo,jlasjw,kilasko,klas kow,Γλασκώβη,Глазго,Глазгов,Глазгоу,Горад Глазга,Գլազգո,גלאזגא,גלאזגו,جلاسجو,غلاسكو,گلاسگو,گلاسگوۋ,گلاسگۆ,ग्लासगो,ग्लास्गो,গ্লাসগো,ਗਲਾਸਗੋ,கிளாஸ்கோ,గ్లాస్గో,ಗ್ಲ್ಯಾಸ್ಗೋ,กลาสโกว์,ဂလပ်စဂိုးမြို့,გლაზგო,ግላዝጎ,グラスゴー,格拉斯哥,글래스고', 55.8651500, -4.2576300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60287, 'Glanamman', 'Glanamman', 'Glanamman', 51.8000000, -3.9333300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60288, 'Girvan', 'Girvan', 'Gervan,Inbhir Gharbhain,ge wen,Герван,格文', 55.2425500, -4.8555100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60289, 'Girton', 'Girton', 'Girton', 52.2333300, 0.0833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60290, 'Gilwern', 'Gilwern', '', 51.8247500, -3.0935500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60291, 'Gillingham', 'Gillingham', 'Dzhillingem,Dzilingam,Dzilingamas,Džilingamas,Gillingham,gylynghʼm,jiringamu,jylyngham  knt,Џилингам,Джиллингем,גילינגהאם,جیلینگهام، کنت,ジリンガム', 51.3891400, 0.5486300, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60292, 'Gillingham', 'Gillingham', 'Gillingem,Gillingham,Gillingham i Dorset,jylyngham  samrst,Гиллингем,جیلینگهام، سامرست', 51.0383300, -2.2761100, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60293, 'Gilford', 'Gilford', '', 54.3725600, -6.3612600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60294, 'Gilfach Goch', 'Gilfach Goch', '', 51.5921300, -3.4729600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60295, 'Gildersome', 'Gildersome', 'Gildersome,Home of the Gilders', 53.7614000, -1.6314700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60296, 'Gilberdyke', 'Gilberdyke', '', 53.7529700, -0.7389200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60297, 'Giffnock', 'Giffnock', 'Giffneck,Giffnok,Giofnag,Qiffnok,Гиффнок,Гіффнок', 55.8037300, -4.2948800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60298, 'Germoe', 'Germoe', 'Germoe,Germol', 50.1153900, -5.3788100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60299, 'Gelligaer', 'Gelligaer', 'Gelligaer', 51.6644400, -3.2561100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60300, 'Gedney Hill', 'Gedney Hill', 'Gedney Hill,Godney Hill', 52.6843400, -0.0200800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60301, 'Geddington', 'Geddington', 'Geddington', 52.4375700, -0.6896500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60302, 'Gayhurst', 'Gayhurst', 'Gayhurst', 52.1136200, -0.7627800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60303, 'Gateshead', 'Gateshead', 'Gateshead,Gateshead-on-Tyne,Geitshedas,Gejtskhed,Gorad Gejtskhed,gai ci hei de,geicheuhedeu,getsuheddo,gyytshd,jytshyd,Гейтсхед,Гејтсхед,Горад Гейтсхед,גייטסהד,גייטסהעד,جيتشيد,گیتس‌هد,გეიტსჰედი,ゲーツヘッド,蓋茨黑德,게이츠헤드', 54.9620900, -1.6016800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60304, 'Garvagh', 'Garvagh', 'Garvagh', 54.9833300, -6.6666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60305, 'Garstang', 'Garstang', 'garstng,گارستنگ', 53.9008100, -2.7741700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60306, 'Garsington', 'Garsington', 'Garsington', 51.7162300, -1.1612900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60307, 'Gargrave', 'Gargrave', '', 53.9835300, -2.1045900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60308, 'Garforth', 'Garforth', 'Nkarforth,Γκάρφορθ', 53.7917300, -1.3806700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60309, 'Garelochhead', 'Garelochhead', 'Garelochhead', 56.0820300, -4.8290900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60310, 'Gamlingay', 'Gamlingay', 'ghmlynghy,غملينغي', 52.1556100, -0.1930300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60311, 'Galston', 'Galston', 'Baile nan Gall,Galston,Golston,Голстон,Ґалстон', 55.6009300, -4.3817200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60312, 'Galgate', 'Galgate', 'Galgate', 53.9936200, -2.7920100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60313, 'Galashiels', 'Galashiels', 'An Geal Ath,An Geal Àth,An Geal Áth,Gafashiels,Galashiels,Galashils,Galasils,Gallae,jia la xi er si,Галашилс,Գալաշիլս,加拉希尔斯', 55.6145800, -2.8069500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60314, 'Gainsborough', 'Gainsborough', 'Gainesborough,Gainsborough,Gainsborough i Lincolnshire,gen si bao,گینزبورو، لینکلن‌شر,根斯堡', 53.3833300, -0.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60315, 'Gainford', 'Gainford', '', 54.5471800, -1.7360100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60316, 'Gaerwen', 'Gaerwen', 'Gaerwen', 53.2211200, -4.2736200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60317, 'Fylde', 'Fylde', 'Borough of Fylde,Fylde,Fylde Borough,Fylde Coast', 53.8333300, -2.9166700, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60318, 'Fyfield', 'Fyfield', '', 51.7406500, 0.2697600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60319, 'Fyfield', 'Fyfield', 'Fyfield', 51.4166700, -1.7833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60320, 'Full Sutton', 'Full Sutton', 'Full Sutton', 53.9886900, -0.8675800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60321, 'Fulford', 'Fulford', 'Fulford,Gate Fulford', 53.9333300, -1.0666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60322, 'Fulbourn', 'Fulbourn', 'Fulbourn,Fulbourne', 52.1828300, 0.2204600, 'GB', '2015-02-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60323, 'Frome', 'Frome', 'From,Frome,Frum,Frōm,frwm  samrst,fu luo mu,Фрум,فروم، سامرست,弗罗姆', 51.2283400, -2.3221100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60324, 'Frodsham', 'Frodsham', 'fwrdsham,فوردشام', 53.2948500, -2.7274500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60325, 'Frizington', 'Frizington', 'Frizington', 54.5418500, -3.4946000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60326, 'Friston', 'Friston', '', 50.7640200, 0.1993000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60327, 'Friockheim', 'Friockheim', 'Friockheim', 56.6368800, -2.6680600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60328, 'Frinton-on-Sea', 'Frinton-on-Sea', 'Frinton,Frinton-on-Sea', 51.8306100, 1.2442400, 'GB', '2014-12-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60329, 'Frimley', 'Frimley', '', 51.3166700, -0.7454400, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60330, 'Freystrop', 'Freystrop', 'Freyston,Freystrop', 51.7633300, -4.9602800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60331, 'Freuchie', 'Freuchie', 'Freuchie', 56.2468800, -3.1586100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60332, 'Freshwater', 'Freshwater', '', 50.6836500, -1.5261600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60333, 'Freshford', 'Freshford', '', 51.3391700, -2.3030600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60334, 'Fremington', 'Fremington', 'Fremington,Фремингтон', 51.0695500, -4.1366000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60335, 'Freckleton', 'Freckleton', '', 53.7543300, -2.8648900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60336, 'Fraserburgh', 'Fraserburgh', 'A Bhruaich,A'' Bhruaich,Faithlie,Fraserburgh,Frazerburgh,Freizerburgas,Frejzerburg,The Broch,fu lei ze bao,Фрейзербург,弗雷泽堡', 57.6874400, -2.0184400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60337, 'Frampton on Severn', 'Frampton on Severn', 'Frampton,Frampton on Severn', 51.7705400, -2.3638200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60338, 'Framlingham', 'Framlingham', 'framlyngham,فراملینگهام', 52.2211700, 1.3420500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60339, 'Fowlmere', 'Fowlmere', 'Foulmere,Fowlmere', 52.0934300, 0.0743300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60340, 'Fowey', 'Fowey', 'Fowey,Fowy,Fowydh,fwy  kwrnwal,فوی، کورنوال', 50.3363400, -4.6386000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60341, 'Four Marks', 'Four Marks', 'Four Marks', 51.1073500, -1.0494500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60342, 'Four Crosses', 'Four Crosses', 'Four Crosses', 52.7594100, -3.0810600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60343, 'Foulsham', 'Foulsham', 'Foulham,Foulsham', 52.7818200, 1.0104900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60344, 'Foulridge', 'Foulridge', 'Foulridge', 53.8757900, -2.1686400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60345, 'Fort William', 'Fort William', 'An Gearasdan,FWM,Fort Vil''jam,Fort Viljamas,Fort William,Fort William i Skottland,Fort-Uil''jam,Fort-Vil''jam,wei lian bao,Форт Вильям,Форт-Вільям,Форт-Уильям,פורט ויליאם,フォート・ウィリアム,威廉堡', 56.8164800, -5.1120800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60346, 'Fortuneswell', 'Fortuneswell', 'Fortuneswell', 50.5603000, -2.4424300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60347, 'Fortrose', 'Fortrose', 'Fortrose', 57.5808700, -4.1326300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60348, 'Forth', 'Forth', '', 55.7650200, -3.6887400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60349, 'Forres', 'Forres', 'FSS,Farrais,Forres', 57.6099700, -3.6211500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60350, 'Formby', 'Formby', '', 53.5583800, -3.0699900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60351, 'Forfar', 'Forfar', 'Baile Fharfair,Farfar,Forfar,Forfaras,Gorad Forfar,fu fu er,Горад Форфар,Форфар,弗福爾', 56.6438200, -2.8900100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60352, 'Forest Row', 'Forest Row', 'Forest Row', 51.0964100, 0.0326200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60353, 'Fordingbridge', 'Fordingbridge', 'فوردینگ‌بریج', 50.9274700, -1.7902900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60354, 'Fordham', 'Fordham', '', 52.3112900, 0.3905700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60355, 'Ford', 'Ford', '', 55.6333300, -2.0833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60356, 'Ford', 'Ford', 'Ford', 52.7169300, -2.8688100, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60357, 'Folkestone', 'Folkestone', 'Fokston,Folkestone,Folkston,fu ke si tong,fwkstwn,fwlkstwn,Фокстон,Фолкстон,فولكستون,فوکستون,福克斯通', 51.0816900, 1.1673400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60358, 'Fochriw', 'Fochriw', 'Fochriw', 51.7400300, -3.2986100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60359, 'Fochabers', 'Fochabers', 'Fachabair', 57.6144500, -3.0994700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60360, 'Flore', 'Flore', '', 52.2364700, -1.0572600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60361, 'Flookburgh', 'Flookburgh', 'Flookborough,Flookburgh', 54.1741500, -2.9721400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60362, 'Flockton', 'Flockton', '', 53.6303400, -1.6394500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60363, 'Flitwick', 'Flitwick', '', 52.0033800, -0.4947200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60364, 'Flint', 'Flint', 'Flint,Flintas,Y Fflint,fu lin te,Флинт,Флінт,弗林特', 53.2448800, -3.1323100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60365, 'Flimby', 'Flimby', 'Flimby', 54.6895600, -3.5209200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60366, 'Fleetwood', 'Fleetwood', 'Fleetwood,flytwwd  lankashr,plytwwd,פליטווד,فلیتوود، لانکاشر', 53.9252700, -3.0108500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60367, 'Fleet', 'Fleet', 'Fleet', 52.7932100, 0.0585400, 'GB', '2015-09-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60368, 'Fleet', 'Fleet', 'Fleet,Fleet i Hampshire,flyt  hmpshr,فلیت، همپشر', 51.2833300, -0.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60369, 'Flamborough', 'Flamborough', '', 54.1148700, -0.1227400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60370, 'Fivemiletown', 'Fivemiletown', 'Fivemiletown', 54.3833300, -7.3000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60371, 'Fitzwilliam', 'Fitzwilliam', '', 53.6328800, -1.3769000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60372, 'Fishtoft', 'Fishtoft', '', 52.9609500, 0.0270200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60373, 'Fishguard', 'Fishguard', 'Abergwaun,Fishgard,Fishguard,Фишгард', 51.9937600, -4.9763100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60374, 'Fishburn', 'Fishburn', 'Fishburn', 54.6829600, -1.4363100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60375, 'Fintona', 'Fintona', 'Fintona,Fintona Tramway,Fionntamhnach,phintona,फिन्तोना', 54.5000000, -7.3166700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60376, 'Finningley', 'Finningley', 'Finningley', 53.4869600, -0.9908300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60377, 'Finedon', 'Finedon', 'Finedon', 52.3391700, -0.6500800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60378, 'Findon', 'Findon', '', 50.8681600, -0.4073500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60379, 'Findochty', 'Findochty', 'Findochty', 57.6973500, -2.9010400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60380, 'Findern', 'Findern', 'Findern', 52.8703700, -1.5440900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60381, 'Finchampstead', 'Finchampstead', '', 51.3614900, -0.8572800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60382, 'Fimber', 'Fimber', '', 54.0349500, -0.6313300, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60383, 'Filey', 'Filey', 'Filey,فیلی، یورک‌شر شمالی', 54.2100000, -0.2891700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60384, 'Ffestiniog', 'Ffestiniog', 'Ffestiniog', 52.9599600, -3.9324200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60385, 'Ferryhill', 'Ferryhill', '', 54.6833300, -1.5500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60386, 'Ferrybridge', 'Ferrybridge', '', 53.7105800, -1.2794800, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60387, 'Fernhurst', 'Fernhurst', 'Fernhurst', 51.0487300, -0.7178900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60388, 'Fernhill Heath', 'Fernhill Heath', 'Fernhill Heath', 52.2300200, -2.1965900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60389, 'Ferndale', 'Ferndale', 'Ferndale', 51.6605600, -3.4475000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60390, 'Fenwick', 'Fenwick', '', 55.6582300, -4.4434200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60391, 'Fenwick', 'Fenwick', '', 53.6386800, -1.0976000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60392, 'Fenstanton', 'Fenstanton', '', 52.2990300, -0.0671200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60393, 'Feltwell', 'Feltwell', '', 52.4858100, 0.5194500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60394, 'Felton', 'Felton', '', 55.2976800, -1.7114300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60395, 'Feltham', 'Feltham', 'Feltham,felthama,फ़ेल्ठम', 51.4462000, -0.4138800, 'GB', '2012-05-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60396, 'Felling', 'Felling', '', 54.9529700, -1.5715200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60397, 'Felixstowe', 'Felixstowe', 'Felixstowe,Filikstou,fei li ke si tuo,flykstw,Филикстоу,فلیکستو,费利克斯托', 51.9637500, 1.3511000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60398, 'Felbridge', 'Felbridge', '', 51.1391300, -0.0411600, 'GB', '2014-08-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60399, 'Featherstone', 'Featherstone', 'Featherstone,fytrstwn,فیترستون', 53.6768800, -1.3564700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60400, 'Fazeley', 'Fazeley', 'Fazeley', 52.6144300, -1.6985000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60401, 'Faversham', 'Faversham', 'Faversham,Fejveshem,fawrsham,Фейвешем,فاورشام', 51.3148000, 0.8885600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60402, 'Fauldhouse', 'Fauldhouse', '', 55.8274900, -3.7074100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60403, 'Farnworth', 'Farnworth', 'Farnworth', 53.5500000, -2.4000000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60404, 'Farnsfield', 'Farnsfield', 'Farnsfield', 53.1022300, -1.0332000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60405, 'Farnham Royal', 'Farnham Royal', '', 51.5420800, -0.6158400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60406, 'Farnham', 'Farnham', 'Farnham,farnham,فارنهام', 51.2144400, -0.8005400, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60407, 'Farndon', 'Farndon', 'Farndon', 53.0836100, -2.8746400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60408, 'Farndon', 'Farndon', 'Farndon', 53.0500000, -0.8500000, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60409, 'Farnborough', 'Farnborough', '', 52.1428900, -1.3692600, 'GB', '2015-10-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60410, 'Farnborough', 'Farnborough', '', 51.5333300, -1.3666700, 'GB', '2015-10-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60411, 'Farnborough', 'Farnborough', '', 51.3594800, 0.0690500, 'GB', '2015-09-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60412, 'Farnborough', 'Farnborough', 'FAB,Farnboro,Farnborough,Farnborough i Hampshire,fa en bo lei,farnbrt,farn‌bwrw  hmpshr,Фарнборо,פארנבורו,فارنبرة,فارن‌بورو، همپشر,法恩伯勒', 51.2942400, -0.7556500, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60413, 'Faringdon', 'Faringdon', 'Faringdon,faryngdwn,فارینگدون', 51.6564400, -1.5867600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60414, 'Fareham', 'Fareham', 'farham,fei lei mu,فارهام,แฟร์อัม,費勒姆', 50.8516200, -1.1792900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60415, 'Falmouth', 'Falmouth', 'Aberfal,Aberfala,Falmouth,Falmut,Falmuthum,Folmut,UFM,fa er mao si,falmwth  kwrnwal,farumasu,paelmeoseu,Фалмут,Фолмът,فالموث، کورنوال,ファルマス,法尔茅斯,팰머스', 50.1544100, -5.0711300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60416, 'Falkland', 'Falkland', 'Falkland', 56.2525500, -3.2038900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60417, 'Falkirk', 'Falkirk', 'An Eaglais Bhreac,Falkirk,Fawkirk,Folkerk,Folkerkas,Folkirk,Folkurk,falkrk,falkyrk,forukaku,fu er ke ke,polkeokeu,Фалкирк,Фолкерк,Фолкърк,فالکرک,فالکیرک,フォルカーク,福爾柯克,폴커크', 56.0021000, -3.7853500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60418, 'Falfield', 'Falfield', 'Falfield', 51.6369400, -2.4605600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60419, 'Fakenham', 'Fakenham', 'FKH,Fakenham,faknham,فاکنهام', 52.8299600, 0.8477000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60420, 'Fairlight', 'Fairlight', 'Fairlight', 50.8780200, 0.6566900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60421, 'Fairlie', 'Fairlie', '', 55.7560200, -4.8556400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60422, 'Fairford', 'Fairford', 'FFD,fayrfwrd,فایرفورد', 51.7081600, -1.7812800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60423, 'Eyton upon the Weald Moors', 'Eyton upon the Weald Moors', 'Eyton,Eyton upon the Weald Moors', 52.7333300, -2.5166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60424, 'Eyton', 'Eyton', '', 52.2500000, -2.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60425, 'Eythorne', 'Eythorne', '', 51.1971000, 1.2662000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60426, 'Eynsham', 'Eynsham', 'Ensham,Eynsham', 51.7807700, -1.3745400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60427, 'Eynsford', 'Eynsford', 'Eynsford', 51.3676500, 0.2113200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60428, 'Eyemouth', 'Eyemouth', 'Ajmut,Eyemouth,Inbhir Eighe,ai mao si,Аймут,Այմութ,艾茅斯', 55.8713000, -2.0901000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60429, 'Eye', 'Eye', 'Eye', 52.6080000, -0.1920900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60430, 'Exton', 'Exton', '', 52.6910600, -0.6346300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60431, 'Exning', 'Exning', 'Exning', 52.2664200, 0.3743900, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60432, 'Exmouth', 'Exmouth', 'Ehksmut,Eksmut,Exanmutha,Exanmūþa,Exmouth,aksmwth,egseumeoseu,Ексмут,Эксмут,اکسموث,엑스머스', 50.6172300, -3.4023300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60433, 'Exminster', 'Exminster', 'Exminster', 50.6807500, -3.4970600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60434, 'Exhall', 'Exhall', '', 52.4646400, -1.4814400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60435, 'Exeter', 'Exeter', 'Caerwysg,EXT,Ehkseter,Ekseter,Eksetera,Ekseteris,Eksetur,Exanceaster,Exeter,Exonia,Karesk,ai ke sai te,akstr,akztr,egseoteo,ekuseta,xek se texr,xek si texr,ya xi te,Ексетер,Ексетър,Эксетер,Էքսետեր,אקסטר,עקסעטער,إكزتر,اکستر,ایکسٹر,เอกเซเตอร์,เอ็กซิเตอร์,エクセター,埃克塞特,雅息特,엑서터', 50.7236000, -3.5275100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60436, 'Ewyas Harold', 'Ewyas Harold', '', 51.9535800, -2.8932500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60437, 'Ewhurst', 'Ewhurst', '', 51.1544800, -0.4434400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60438, 'Evesham', 'Evesham', 'Evesham,Ivsham,aywsham,Ившам,ایوشام', 52.0923700, -1.9488700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60439, 'Evesbatch', 'Evesbatch', '', 52.1333300, -2.4500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60440, 'Everton', 'Everton', '', 52.1458100, -0.2461600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60441, 'Eversholt', 'Eversholt', '', 51.9870200, -0.5598300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60442, 'Evercreech', 'Evercreech', 'Evercreech', 51.1480600, -2.5055600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60443, 'Evenwood', 'Evenwood', 'Evenwood', 54.6221300, -1.7613300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60444, 'Evanton', 'Evanton', 'Baile Eoghainn,Baile Eòghainn,Baile Eóghainn,Ehvanton,Evanton,Эвантон', 57.6638500, -4.3400400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60445, 'Euxton', 'Euxton', '', 53.6699000, -2.6761500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60446, 'Etwall', 'Etwall', 'Etwall', 52.8835300, -1.6002300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60447, 'Etton', 'Etton', '', 53.8784800, -0.5131400, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60448, 'Eton', 'Eton', 'Eton,Eton i Berkshire,Etona,Iton,Itonas,Itun,atwn  brkshr,iton,yi dun,Ітон,Итон,Итън,اتون، برکشر,イートン,伊顿', 51.4883300, -0.6090500, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60449, 'Essendine', 'Essendine', '', 52.7018700, -0.4525000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60450, 'Esher', 'Esher', 'Ehsher,Esher,Эшер', 51.3696900, -0.3669300, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60451, 'Errol', 'Errol', 'Errol', 56.3923400, -3.2127500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60452, 'Erlestoke', 'Erlestoke', 'Erlestoke', 51.2847200, -2.0544400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60453, 'Erith', 'Erith', 'Erith,ayrt,Έριθ,ایرت,ایرتھ', 51.4831500, 0.1748400, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60454, 'Epworth', 'Epworth', 'Epvort,Epworth i Lincolnshire,Епворт,اپوورث، لینکلن‌شر', 53.5260200, -0.8239900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60455, 'Epsom', 'Epsom', 'Ehpsom,Epsom,ai pu suo mu,ebsom,epusomu,Эпсом,ເມືອງເອັບຊຳ,エプソム,埃普索姆,엡솜', 51.3305000, -0.2701100, 'GB', '2011-02-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60456, 'Epping', 'Epping', 'Ehpping,Epping,ai pan,ai ping,apyng,eping,Эппинг,اپینگ,埃潘,艾坪,에핑', 51.6981500, 0.1105500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60457, 'Enniskillen', 'Enniskillen', 'ENK,Ehnniskillen,Eniskilen,Eniskilun,Enniskillen,Inis Ceithlann,Inis Ceithleann,en ni si ji lin,eniseukillin,enisukiren,Ενισκίλεν,Енискилън,Эннискиллен,エニスキレン,恩尼斯基林,에니스킬린', 54.3461500, -7.6413300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60458, 'Enfield Town', 'Enfield Town', 'Enfield', 51.6514700, -0.0849700, 'GB', '2015-10-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60459, 'Enderby', 'Enderby', 'Enderby', 52.5877800, -1.2061900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60460, 'Emsworth', 'Emsworth', 'amswwrth,امسوورث', 50.8477900, -0.9369700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60461, 'Empingham', 'Empingham', 'Empingham', 52.6672200, -0.5960100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60462, 'Emneth', 'Emneth', '', 52.6424400, 0.2085700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60463, 'Emley', 'Emley', '', 53.6139500, -1.6313000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60464, 'Embsay', 'Embsay', '', 53.9766400, -1.9928200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60465, 'Embleton', 'Embleton', 'Embleton', 55.4959200, -1.6361900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60466, 'Emberton', 'Emberton', 'Emberton', 52.1369100, -0.7067300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60467, 'Ely', 'Ely', 'Elig,Ely,Ili,Ilis,alayy,aly  kmryjshayr,ayly,ayly  kymbrjshayr,illi,iri,yi li,Ілі,Или,Իլի,إيلي,الائی,الی، کمبریج‌شایر,الی، کمریجشایر,ایلی، کیمبرجشائر,イーリー,伊利,일리', 52.3996400, 0.2619600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60468, 'Elwick', 'Elwick', '', 54.6845500, -1.2955900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60469, 'Elvington', 'Elvington', '', 53.9208700, -0.9349500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60470, 'Elton', 'Elton', '', 54.5500000, -1.3666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60471, 'Elton', 'Elton', '', 53.2666700, -2.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60472, 'Elton', 'Elton', '', 52.3333300, -2.8000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60473, 'Elswick', 'Elswick', 'Elswick', 53.8383600, -2.8814700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60474, 'Elstree', 'Elstree', 'Elstree', 51.6403000, -0.2969300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60475, 'Elstow', 'Elstow', 'alstw,الستو', 52.1072700, -0.4649000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60476, 'Elstead', 'Elstead', '', 51.1854800, -0.7053600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60477, 'Elsenham', 'Elsenham', '', 51.9143100, 0.2293400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60478, 'Elmswell', 'Elmswell', '', 52.2361600, 0.9124700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60479, 'Ellon', 'Ellon', '', 57.3640500, -2.0731300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60480, 'Ellingham', 'Ellingham', '', 55.5258900, -1.7360100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60481, 'Ellesmere Port', 'Ellesmere Port', 'Ellesmere Port,Elsmir Port,ai er si mi er gang,alzmr pwrt,Елсмир Порт,الزمر پورت,埃爾斯米爾港', 53.2787500, -2.9013400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60482, 'Ellesmere', 'Ellesmere', 'Ellesmere,الزمیر، شروپ‌شر', 52.9083800, -2.8980600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60483, 'Ellerton', 'Ellerton', '', 53.8500000, -0.9333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60484, 'Ellerker', 'Ellerker', '', 53.7532300, -0.6041600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60485, 'Elland', 'Elland', 'aylnd  ywrkshr ghrby,ایلند، یورکشر غربی', 53.6851000, -1.8387800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60486, 'Elgin', 'Elgin', 'Ehlgin,Eilginn,Elgin,Elqin,ai er jin,alghyn,algyn,elgin,erugin,Елгин,Елгін,Элгин,إلغين,الگین,エルギン,埃爾金,엘긴', 57.6494700, -3.3184300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60487, 'Elderslie', 'Elderslie', 'Elderslie', 55.8332700, -4.4859800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60488, 'Egremont', 'Egremont', 'Egremont i Cumbria,agrmwnt  kambrya,اگرمونت، کامبریا', 54.4794100, -3.5275600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60489, 'Eglinton', 'Eglinton', 'Eglinton', 55.0166700, -7.1833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60490, 'Egham', 'Egham', 'Egham,Ehgkhem,Эгхем', 51.4315800, -0.5523900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60491, 'Eggleston', 'Eggleston', 'Eggleston', 54.6091600, -2.0031200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60492, 'Edworth', 'Edworth', '', 52.0559700, -0.2171500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60493, 'Edwinstowe', 'Edwinstowe', '', 53.1945400, -1.0643900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60494, 'Edith Weston', 'Edith Weston', 'Edith Weston', 52.6378600, -0.6318900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60495, 'Edington', 'Edington', '', 51.2758300, -2.1063900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60496, 'Edinburgh', 'Edinburgh', 'Aebura,Caeredin,Dinedin,Doon Edin,Dun Eideann,Dùn Èideann,Dún Éideann,EDI,Ebora,Edimborg,Edimborgh,Edimbourg,Edimbourgo,Edimburg,Edimburgh,Edimburgo,Edimburgo - Dun Eideann,Edimburgo - Dùn Èideann,Edimburgu,Edimburgum,Edimbùrgh,Edinbo,Edinboarch,Edinborg,Edinburc,Edinburg,Edinburga,Edinburgas,Edinburgh,Edinburgo,Edinburq,Edinburrie,Edynburg,Ehdinburg,Embra,Gorad Ehdynburg,Idinburg,adnbrt,adynbrw,ai ding bao,edeunbeoleo,edinabara,edinbara,edinburgi,etinparo,xedinbara,Édimbourg,Εδιμβούργο,Горад Эдынбург,Единбург,Эдинбург,Էդինբուրգ,אדינבורו,עדינבורג,إدنبرة,ئێدینبەرە,ادینبرو,ایڈنبرا,एडिनबरा,एदिनबरा,এডিনবরা,எடின்பரோ,ಎಡಿನ್‌ಬರ್ಗ್‌‌,എഡിൻബറോ,เอดินบะระ,အက်ဒင်ဗာရာမြို့,ედინბურგი,エディンバラ,爱丁堡,에든버러', 55.9520600, -3.1964800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60497, 'Edgworth', 'Edgworth', '', 53.6463600, -2.3940100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60498, 'Edgware', 'Edgware', 'Edgware,adjwar,ai qi wei er,ejaveyara,ejjiu~ea,עדזשווער,ادجوار,ایجویر، لنڈن,एजवेयर,エッジウェア,埃奇韋爾', 51.6128000, -0.2753900, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60499, 'Edgmond', 'Edgmond', 'Edgmond', 52.7740000, -2.4096700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60500, 'Edenfield', 'Edenfield', '', 53.6667400, -2.3048100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60501, 'Edenbridge', 'Edenbridge', 'adnbryj  knt,ادنبریج، کنت', 51.1917200, 0.0672900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60502, 'Eckington', 'Eckington', 'Eckington', 52.0666700, -2.1166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60503, 'Eccleston', 'Eccleston', 'Eccleston', 53.6423600, -2.7216200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60504, 'Eccleston', 'Eccleston', '', 53.4500000, -2.7833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60505, 'Eccleston', 'Eccleston', 'aklstwn,اكلستون', 53.1500000, -2.8833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60506, 'Eccleshall', 'Eccleshall', 'Eccleshall,akshal,اکسهال', 52.8578900, -2.2497100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60507, 'Eccles', 'Eccles', 'Eccles,aklz  mnchstr bzrg,اکلز، منچستر بزرگ', 53.4833300, -2.3333300, 'GB', '2014-04-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60508, 'Ebbw Vale', 'Ebbw Vale', 'Ebbu-Vejl,Ebu Veilis,Ebu Vejl,Glyn Ebwy,Еббу-Вейл,Ебу Вейл', 51.7771400, -3.2079200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60509, 'Eaton Socon', 'Eaton Socon', 'Eaton Socon', 52.2175200, -0.2892500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60510, 'Eaton Bray', 'Eaton Bray', '', 51.8769700, -0.5916700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60511, 'Eaton', 'Eaton', '', 53.1833300, -2.2000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60512, 'Eattington', 'Eattington', 'Ettington', 52.1333300, -1.6000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60513, 'Eastwood', 'Eastwood', 'Eastwood,Eastwood i Nottinghamshire,ایستوود، ناتینگهام‌شر', 53.0000000, -1.3000000, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60514, 'East Wittering', 'East Wittering', 'East Wittering', 50.7696900, -0.8744400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60515, 'East Wemyss', 'East Wemyss', 'East Wemyss', 56.1601800, -3.0642200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60516, 'East Tilbury', 'East Tilbury', '', 51.4805300, 0.4171400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60517, 'Eastry', 'Eastry', '', 51.2463900, 1.3077600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60518, 'Eastrington', 'Eastrington', '', 53.7603800, -0.7932500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60519, 'Retford', 'Retford', 'East Retford,rtfwrd,رتفورد', 53.3221300, -0.9431500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60520, 'East Peckham', 'East Peckham', '', 51.2123400, 0.3862400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60521, 'Easton on the Hill', 'Easton on the Hill', 'Easton,Easton on the Hill', 52.6273300, -0.5057100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60522, 'Easton', 'Easton', 'Easton', 50.5333300, -2.4500000, 'GB', '2013-04-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60523, 'Eastoft', 'Eastoft', 'Eastoft', 53.6362400, -0.7849200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60524, 'East Molesey', 'East Molesey', 'Molesey', 51.3987200, -0.3491600, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60525, 'East Markham', 'East Markham', 'East Markham,Markham', 53.2522100, -0.8938500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60526, 'East Linton', 'East Linton', 'East Linton', 55.9873700, -2.6568200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60527, 'Eastleigh', 'Eastleigh', 'Eastleigh,Istli,yi si te li,Истли,ایست‌لی,伊斯特利', 50.9666700, -1.3500000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60528, 'East Leake', 'East Leake', '', 52.8301500, -1.1810300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60529, 'East Kilbride', 'East Kilbride', 'Cille Bhrighde an Ear,Cille Bhrìghde an Ear,Cille Bhríghde an Ear,East Kilbride,East Kilbridge,Ist Kilbraidas,Ist Kilbrajd,Ist Kilbrayd,Ist-Kilbrajd,Keeill Vreeshey Hiar,ayst kylbrayd,dong ji er bu lai de,iseuteukilbeulaideu,İst Kilbrayd,Іст-Кілбрайд,Ист Килбрайд,Ист Килбрајд,ایست کیلبراید,ایسٹ کلبرائیڈ,イースト・キルブライド,東基爾布萊德,이스트킬브라이드', 55.7641200, -4.1766900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60530, 'East Horsley', 'East Horsley', 'East Horsley,Horsley', 51.2735800, -0.4320700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60531, 'East Harptree', 'East Harptree', '', 51.3011100, -2.6216700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60532, 'East Harling', 'East Harling', 'East Harling', 52.4384300, 0.9335300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60533, 'East Hanney', 'East Hanney', 'East Hanney,Hanney', 51.6344300, -1.3951800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60534, 'East Ham', 'East Ham', 'ayst ham,yi si te han mu,ایست هام,イースト・ハム,伊斯特漢姆', 51.5333300, 0.0500000, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60535, 'East Grinstead', 'East Grinstead', 'East Grinstead,ayst grynstyd,isuto・gurinsuteddo,ایست گرینستید,イースト・グリンステッド', 51.1238200, -0.0061000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60536, 'East Dereham', 'East Dereham', 'Dereham,East Dereham', 52.6833300, 0.9333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60537, 'East Dean', 'East Dean', 'East Dean', 51.0397900, -1.6094100, 'GB', '2011-03-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60538, 'Eastchurch', 'Eastchurch', '', 51.4067300, 0.8576600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60539, 'East Chevington', 'East Chevington', '', 55.2833300, -1.5833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60540, 'East Calder', 'East Calder', 'East Calder', 55.8918600, -3.4637200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60541, 'East Bridgford', 'East Bridgford', 'East Bridgford', 52.9795400, -0.9656300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60542, 'Eastbourne', 'Eastbourne', 'Eastbourne,Istborn,Istbornas,isutobon,yi si te ben,Істборн,Истборн,ایست‌بورن,イーストボーン,伊斯特本', 50.7687100, 0.2845300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60543, 'East Boldon', 'East Boldon', 'East Boldon,The Boldons', 54.9445200, -1.4281500, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60544, 'East Bergholt', 'East Bergholt', '', 51.9778500, 1.0176100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60545, 'Easingwold', 'Easingwold', 'Easingwold,aysyngwwd,ایسینگوود', 54.1201000, -1.1939000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60546, 'Easington', 'Easington', 'Easington', 54.7852800, -1.3591700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60547, 'Easington', 'Easington', '', 53.6535900, 0.1150100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60548, 'Earlston', 'Earlston', 'Dun Airchill,Dùn Airchill,Dún Airchill,Earlston,e er si dun,厄尔斯顿', 55.6385600, -2.6749500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60549, 'Earls Colne', 'Earls Colne', '', 51.9274400, 0.7010700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60550, 'Earls Barton', 'Earls Barton', '', 52.2662700, -0.7524800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60551, 'Earley', 'Earley', 'ayrly  brkshr,ایرلی، برکشر', 51.4408500, -0.9238400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60552, 'Earith', 'Earith', 'Earith', 52.3542200, 0.0305600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60553, 'Earby', 'Earby', '', 53.9154600, -2.1428500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60554, 'Ealing', 'Ealing', 'Barrio de Ealing,Borgo londinese di Ealing,Ealing,Ealing keruelet,Ealing kerület,London Borough of Ealing,aylng  lndn,aylyng,ilinga,illing,iringu,yi ling,אילינג,ایلنگ، لندن,ایلینگ,ईलिंग,イーリング,伊灵,일링', 51.5121600, -0.3020400, 'GB', '2015-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60555, 'Eaglesham', 'Eaglesham', 'Baile na h-Eaglais', 55.7411900, -4.2745900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60556, 'Dyserth', 'Dyserth', 'Dyserth', 53.3003200, -3.4126200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60557, 'Dymchurch', 'Dymchurch', 'Dymchurch', 51.0254400, 0.9939200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60558, 'Dyce', 'Dyce', 'Dyce', 57.2052200, -2.1767600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60559, 'Duxford', 'Duxford', 'Duxford,QFO', 52.0939300, 0.1591700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60560, 'Dursley', 'Dursley', 'Dursley,dwrsly,fyrnwn drsly,دورسلی,فيرنون درسلي', 51.6813900, -2.3533300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60561, 'Durrington', 'Durrington', 'Durrington', 51.1987100, -1.7718500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60562, 'Durnford', 'Durnford', '', 51.1333300, -1.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60563, 'Durham', 'Durham', 'Daram,Daramas,Darem,Darhem,Dunelmum,Dunholm,Duram,Durham,Dūnholm,Gorad Darehm,MME,da la mo,daramu,de xram,deoleom,drm,dui heng,dwrham,Горад Дарэм,Дарам,Дарем,Дърам,Դարհեմ,דרהאם,درم,دورهام,ڈرہم، انگلستان,เดอรัม,ダラム,對衡,達拉謨,더럼', 54.7767600, -1.5756600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60564, 'Duntocher', 'Duntocher', 'Duntocher', 55.9243700, -4.4154500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60565, 'Dunswell', 'Dunswell', '', 53.8010600, -0.3713900, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60566, 'Dunstable', 'Dunstable', 'Danstabl,Dunstable,Ntansteimpl,danstybl,dansutaburu,deng si te bu er,dwnstabl,Ντάνστεϊμπλ,Данстабл,دانستیبل,دونستابل,ダンスタブル,鄧斯特布爾', 51.8857100, -0.5228800, 'GB', '2014-08-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60567, 'Duns', 'Duns', 'An Dun,An Dún,Duns,Na Duintean,Na Dùintean,deng si,邓斯', 55.7770400, -2.3457500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60568, 'Dunoon', 'Dunoon', 'Dun Omhain,Dùn Omhain,Dún Omhain', 55.9503100, -4.9273400, 'GB', '2017-07-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60569, 'Dunnington', 'Dunnington', 'Dunnington', 53.9500000, -0.2500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60570, 'Dunloy', 'Dunloy', '', 55.0110000, -6.4108700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60571, 'Dunlop', 'Dunlop', '', 55.7119800, -4.5362200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60572, 'Dunkeswell', 'Dunkeswell', '', 50.8630100, -3.2228900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60573, 'Dunipace', 'Dunipace', 'Dunipace', 56.0270000, -3.9147100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60574, 'Dunholme', 'Dunholme', 'Dunholm,Dunholme', 53.3006700, -0.4654100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60575, 'Dungiven', 'Dungiven', 'Dun Geimhin,Dungiven,Dungivun,Dún Geimhin,dun''givem,Дънгивън,दुन्गिवें', 54.9333300, -6.9166700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60576, 'Dungannon', 'Dungannon', 'Dangannon,Danganonas,Dun Geanainn,Dunganun,Dún Geanainn,deng gan nen,Данганнон,Дънганън,鄧甘嫩', 54.5034400, -6.7672300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60577, 'Dunfermline', 'Dunfermline', 'Danfermlin,Danfermlinas,Danfrmlin,Dun Pharlain,Dunfaurlin,Dunfermline,Dunfurmlin,Dùn Phàrlain,Dún Phárlain,Gorad Danfermlin,dan feir mlin,danfamurin,deng fu mu lin,dmfrlyn,Горад Данфермлін,Данфермлин,Данфермлін,Дънфърмлин,Դանֆրմլին,دانفرم‌لاین,دمفرلين,ڈنفرملائن,ดันเฟิร์มลิน,ダンファームリン,鄧弗姆林', 56.0715600, -3.4588700, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60578, 'Dundry', 'Dundry', '', 51.3988000, -2.6396400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60579, 'Dundrum', 'Dundrum', '', 54.2575000, -5.8445500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60580, 'Dundonald', 'Dundonald', 'Dundonald', 55.5793900, -4.5947300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60581, 'Dundonald', 'Dundonald', 'Dun Donaill,Dundonal''d,Dundonald,Dún Dónaill,Дундональд,Дъндоналд', 54.5919600, -5.7980300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60582, 'Dundee', 'Dundee', 'DND,Dandi,Dandī,Dun De,Dun Deagh,Dundee,Dundi,Dùn Dè,Dùn Dèagh,Dún Déagh,Gorad Dandy,Ntanti,Taodunum,dan di,dandi,dandy,deng de,deng di,deondi,dndy,Νταντί,Горад Данды,Данди,Данді,Дънди,Դանդի,דנדי,داندی,دندي,ڈنڈی شہر,ڈنڈی، سکاٹ لینڈ,डंडी,ดันดี,დანდი,ダンディー,登地,邓迪,던디', 56.4691300, -2.9748900, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60583, 'Dunchurch', 'Dunchurch', 'Dunchurch', 52.3375700, -1.2913600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60584, 'Dunblane', 'Dunblane', 'Danblejn,Dun Bhlathain,Dunblane,Dùn Bhlàthain,deng bu lan,Данблейн,鄧布蘭', 56.1884300, -3.9641700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60585, 'Dunbar', 'Dunbar', 'Danbar,Dun Barra,Dunbar,Dùn Barra,Dún Barra,deng ba,Данбар,鄧巴', 56.0006200, -2.5141800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60586, 'Dumfries', 'Dumfries', 'Damfris,Damfrisas,Dumfrijs,Dun Phris,Dùn Phrìs,Dún Phris,Gorad Damfrys,damfrys,danfurizu,deng fu li si,deompeuliseu,Горад Дамфрыс,Дамфрис,Дамфріс,Дъмфрийс,دامفریس,ダンフリーズ,鄧弗里斯,덤프리스', 55.0695900, -3.6113900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60587, 'Dumbarton', 'Dumbarton', 'Dambarton,Dambartonas,Dumbairton,Dumbarton,Dun Breatann,Dùn Breatann,Gorad Dambartan,dambrtwn,danbaton,deng ba dun,dmbartwn,Горад Дамбартан,Дамбартон,دامبرتون,دمبارتون,ダンバートン,登巴頓,邓巴顿', 55.9443300, -4.5706100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60588, 'Dulverton', 'Dulverton', 'Dulverton,dalwrtwn,دالورتون', 51.0400700, -3.5503500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60589, 'Duloe', 'Duloe', '', 50.3833300, -4.4833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60590, 'Dukinfield', 'Dukinfield', 'dakynfyld,داکینفیلد', 53.4749700, -2.0880900, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60591, 'Dufftown', 'Dufftown', 'Baile Bhainidh,Baile Bháinidh,Daftaun,Dufftown,Дафтаун', 57.4457100, -3.1270800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60592, 'Duffield', 'Duffield', 'Duffield', 52.9862700, -1.4886500, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60593, 'Dudley', 'Dudley', 'Dadli,Dadlis,Dudley,Dudli,Ntantlei,da de li,dad liy,dadly  anglstan,dadori,Ντάντλεϊ,Дадли,Дадлі,Дъдли,Դադլի,دادلی، انگلستان,ดัดลีย์,ダドリー,達德利', 52.5000000, -2.0833300, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60594, 'Ducklington', 'Ducklington', '', 51.7676300, -1.4841800, 'GB', '2011-02-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60595, 'Drybrook', 'Drybrook', 'Drybrook', 51.8555000, -2.5168100, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60596, 'Drumnadrochit', 'Drumnadrochit', 'Drumnadrochit', 57.3343800, -4.4798900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60597, 'Droylsden', 'Droylsden', 'Droylesden,Droylsden', 53.4800500, -2.1454300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60598, 'Dronfield', 'Dronfield', 'Dronfield,drwnfyld,درونفیلد', 53.3022100, -1.4750700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60599, 'Dromore', 'Dromore', '', 54.5133100, -7.4588600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60600, 'Droitwich', 'Droitwich', '', 52.2666700, -2.1500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60601, 'Drighlington', 'Drighlington', 'Drighlington,Drightlington,Driglington', 53.7559200, -1.6644300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60602, 'Dreghorn', 'Dreghorn', 'Dreghorn', 55.6080700, -4.6222600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60603, 'Draycott', 'Draycott', '', 51.2561500, -2.7511600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60604, 'Draperstown', 'Draperstown', 'Draperstown', 54.8000000, -6.7666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60605, 'Downton', 'Downton', '', 52.3666700, -2.8333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60606, 'Downton', 'Downton', '', 50.9936600, -1.7512900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60607, 'Downpatrick', 'Downpatrick', 'Daunpatrik,Dun Padraig,Dún Pádraig,daunpaeteulig,tang pa te li ke,Даунпатрик,ڈاونپیٹرک,唐帕特里克,다운패트릭', 54.3281400, -5.7152900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60608, 'Downham Market', 'Downham Market', 'dawnham markt,داونهام مارکت', 52.6071400, 0.3837500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60609, 'Doveridge', 'Doveridge', '', 52.9052600, -1.8248000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60610, 'Dovercourt', 'Dovercourt', '', 51.9364900, 1.2783100, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60611, 'Dover', 'Dover', 'Dofras,Douvres,Dover,Dovero,Dubris,Duvr,Duvur,Gorad Duur,Ntover,QQD,doba,dobeo,dovhara,du hua,duo fu er,duvri,dwbr,dwfr,dwwr,Ντόβερ,Горад Дуўр,Довер,Дувр,Дувър,דובר,آبنائے ڈوور,دوفر,دوور,डोव्हर,დუვრი,ドーバー,多佛尔,度華,도버', 51.1259800, 1.3125700, 'GB', '2017-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60612, 'Dove Holes', 'Dove Holes', '', 53.2982800, -1.8877500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60613, 'Doune', 'Doune', 'An Dun,An Dùn,An Dún', 56.1899500, -4.0528800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60614, 'Douglas', 'Douglas', 'Douglas', 55.5500000, -3.8500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60615, 'Dorstone', 'Dorstone', '', 52.0666700, -3.0000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60616, 'Dorridge', 'Dorridge', 'Dorridge,Durridge', 52.3725900, -1.7531800, 'GB', '2016-11-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60617, 'Dornoch', 'Dornoch', 'DOC,Dornach,Dornoch,Dornokh,Dòrnach,Dórnach,duo nuo he,Дорнох,多诺赫', 57.8805000, -4.0287900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60618, 'Dormansland', 'Dormansland', 'Dormans,Dormans Land', 51.1602400, 0.0061800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60619, 'Dorking', 'Dorking', 'Dorking,doking,dwrkyng,Доркинг,Դորկինգ,دورکینگ,도킹', 51.2322800, -0.3338000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60620, 'Dorchester', 'Dorchester', 'Dorchester,Dorchester i Dorset,Dorchestur,Dornwaraceaster,Durnovaria,dao che si te,docheseuteo,dochesuta,duo er qie si te,dwrchstr  dwrst,Дорчестер,Дорчестър,دورچستر، دورست,ڈورچسٹر، ڈورسٹ,ドーチェスター,多爾切斯特,道徹斯特,도체스터', 50.7166700, -2.4333300, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60621, 'Donnington', 'Donnington', '', 52.0000000, -2.4166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60622, 'Donisthorpe', 'Donisthorpe', 'Donisthorpe', 52.7240100, -1.5380000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60623, 'Donington', 'Donington', '', 52.9046100, -0.2050500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60624, 'Doncaster', 'Doncaster', 'DSA,Denocestria,Doncaster,Donkaster,Donkasteris,Donkastur,Gorad Dankastehr,dongkeoseuteo,donkasuta,dwnkastr,dxng khas texr,tang ka shi da,tang ka si te,Горад Данкастэр,Донкастер,Донкастър,دونكاستر,دونکاستر,ดองคัสเตอร์,ドンカスター,唐卡士打,唐卡斯特,동커스터', 53.5228500, -1.1311600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60625, 'Donaghadee', 'Donaghadee', 'Domhnach Daoi,Donakhadi,Донахади', 54.6412600, -5.5359100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60626, 'Dollar', 'Dollar', '', 56.1624500, -3.6713500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60627, 'Dolgellau', 'Dolgellau', 'Dolgelaj,Dolgellau,Dolgelley,Dolgelly,duo er gai lai,Долгелай,多爾蓋萊', 52.7422200, -3.8861100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60628, 'Dodworth', 'Dodworth', 'Dodworth', 53.5430600, -1.5277900, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60629, 'Doddington', 'Doddington', '', 55.5854800, -2.0041500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60630, 'Doddington', 'Doddington', '', 52.4967100, 0.0601700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60631, 'Dobwalls', 'Dobwalls', '', 50.4576800, -4.5173500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60632, 'Doagh', 'Doagh', 'Doagh', 54.7500000, -6.0833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60633, 'Ditchling', 'Ditchling', 'Ditchelling,Ditchling,ditchiringu,ディッチリング', 50.9210000, -0.1153600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60634, 'Ditchingham', 'Ditchingham', 'Ditchingham', 52.4672900, 1.4437000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60635, 'Distington', 'Distington', '', 54.5973300, -3.5388000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60636, 'Diss', 'Diss', 'Diss,Diss i England,dys  nwrfk,دیس، نورفک', 52.3767500, 1.1091000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60637, 'Disley', 'Disley', 'Disley', 53.3586500, -2.0384800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60638, 'Dinton', 'Dinton', 'Dinton', 51.0833300, -1.9833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60639, 'Dinnington', 'Dinnington', '', 55.0542800, -1.6754200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60640, 'Dinnington', 'Dinnington', 'Dinnington', 53.3666700, -1.2000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60641, 'Dinmore', 'Dinmore', '', 52.1500000, -2.7500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60642, 'Dingwall', 'Dingwall', 'Dinguol,Dinguoll,Dingvolas,Dingvoll,Dingwall,Inbhir Pheofharain,ding wo er,Дингуол,Дингуолл,Дінгволл,丁沃尔', 57.5953100, -4.4272100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60643, 'Dinas Powys', 'Dinas Powys', 'Dinas Powis,Dinas Powys', 51.4348600, -3.2139800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60644, 'Diggle', 'Diggle', '', 53.5674400, -1.9972300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60645, 'Didcot', 'Didcot', 'Didkot,XPW,dydkat,Дидкот,Дідкот,دیدکات', 51.6092800, -1.2421400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60646, 'Dickleburgh', 'Dickleburgh', '', 52.3965000, 1.1849800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60647, 'Dewsbury', 'Dewsbury', 'D''jusberi,Dewsbury,Diusberis,Djusburi,Djuzberi,ZEQ,di si bo li,dwzbry,Дьюсбери,Дюсбъри,Дјузбери,دوزبری,迪斯伯里', 53.6907600, -1.6290700, 'GB', '2015-02-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60648, 'Devizes', 'Devizes', 'Devizes,Divisae,dwayzz,دوایزز', 51.3508400, -1.9942100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60649, 'Desford', 'Desford', 'Desford', 52.6259800, -1.2939500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60650, 'Desborough', 'Desborough', 'Desborough,dsbwrw,دسبورو', 52.4418300, -0.8212600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60651, 'Derwen', 'Derwen', '', 53.0333300, -3.4000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60652, 'Dersingham', 'Dersingham', 'Dersingham', 52.8454900, 0.5033900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60653, 'Deri', 'Deri', '', 51.7081200, -3.2631200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60654, 'Derby', 'Derby', 'Darbi,Deoraby,Derbi,Derbia,Derbis,Derby,Derby i Derbyshire,Dérbi,Dārbi,Dēoraby,Gorad Dehrbi,Ntermpi,dabi,dar bi,darbi,darby  anglstan,de bi,deobi,drby,dyrby,Ντέρμπι,Горад Дэрбі,Дарби,Дерби,Дербі,Դերբի,דארבי,דרבי,داربی، انگلستان,ديربي,ڈربی,डर्बी,ডার্বি,ดาร์บี,ደርቢ,ダービー,德比,더비', 52.9227700, -1.4766300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60655, 'Denton', 'Denton', '', 54.5666700, -1.6666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60656, 'Denton', 'Denton', '', 53.4567800, -2.1182200, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60657, 'Denny', 'Denny', 'Denny', 56.0235000, -3.9081200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60658, 'Denholme', 'Denholme', 'Denholme', 53.8018900, -1.8950300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60659, 'Denham', 'Denham', 'Denham,dnhm,دنهم', 51.5666700, -0.5000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60660, 'Denby Dale', 'Denby Dale', '', 53.5722800, -1.6589500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60661, 'Denbigh', 'Denbigh', 'Denbi,Denbigh,Dinbych,Денби,ڈینبی', 53.1833300, -3.4166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60662, 'Delph', 'Delph', 'Delph', 53.5666700, -2.0166700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60663, 'Delabole', 'Delabole', '', 50.6234700, -4.7319000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60664, 'Deighton', 'Deighton', '', 53.9000000, -1.0500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60665, 'Deganwy', 'Deganwy', 'Deganwy', 53.3044600, -3.8273500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60666, 'Dedham', 'Dedham', 'Dedham', 51.9589200, 0.9933600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60667, 'Deddington', 'Deddington', 'Deddington', 51.9806000, -1.3205500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60668, 'Debenham', 'Debenham', 'Debenham', 52.2242200, 1.1817200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60669, 'Dearham', 'Dearham', '', 54.7117500, -3.4436400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60670, 'Deanshanger', 'Deanshanger', 'Deanshanger,Denshanger', 52.0499600, -0.8866300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60671, 'Deal', 'Deal', '', 51.2232200, 1.4043200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60672, 'Dawlish', 'Dawlish', 'Dawlish,dawlysh,داولیش', 50.5811800, -3.4664400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60673, 'Daventry', 'Daventry', 'Daventri,Daventry,Dejvuntri,dawntry,Давентри,Дейвънтри,داونتری', 52.2568800, -1.1606600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60674, 'Datchworth', 'Datchworth', 'Datchworth', 51.8512600, -0.1595600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60675, 'Datchet', 'Datchet', 'dtsht,دتشت', 51.4839000, -0.5789300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60676, 'Darwen', 'Darwen', 'Darven,Darwen,Ntargouin,darwn,Ντάργουιν,Дарвен,دارون', 53.6980300, -2.4649400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60677, 'Darvel', 'Darvel', 'Darbhail,Darvel,Дарвел', 55.6097600, -4.2814200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60678, 'Darton', 'Darton', 'Darton', 53.5870500, -1.5267600, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60679, 'Dartmouth', 'Dartmouth', 'Daerentamuda,Dartmouth,Dartmouth i Devon,Dartmut,Derstemuta,Dærentamūða,Ntartmouth,dartmwth  dwwn,dateumeoseu,Ντάρτμουθ,Дартмут,دارتموث، دوون,ഡാർട്മൗത്,다트머스', 50.3522000, -3.5794000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60680, 'Dartford', 'Dartford', 'Dartford,Dartfordas,Dartforde,da te fu de,dartfwrd,dateupeodeu,Дартфорд,Дартфорде,دارتفورد,達特福德,다트퍼드', 51.4465700, 0.2142300, 'GB', '2015-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60681, 'Darrington', 'Darrington', '', 53.6756600, -1.2690100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60682, 'Darlington', 'Darlington', 'Darlington,Darlingtonas,Ntarlin''nkton,XVG,da ling dun,dallingteon,darinton,darlynghtwn,darlyngtwn,Ντάρλινγκτον,Дарлингтон,Дарлінгтон,دارلينغتون,دارلینگتون,ダーリントン,达灵顿,達靈頓,달링턴', 54.5242900, -1.5503900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60683, 'Darlaston', 'Darlaston', 'Darlaston', 52.5666700, -2.0333300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60684, 'Darfield', 'Darfield', 'Darfield,Darsfield', 53.5339000, -1.3759500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60685, 'Daresbury', 'Daresbury', 'Daresbury,Dehrsbjori,Дэрсбёри', 53.3418400, -2.6350000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60686, 'Darenth', 'Darenth', '', 51.4213700, 0.2578400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60687, 'Danbury', 'Danbury', '', 51.7164500, 0.5824500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60688, 'Dalton in Furness', 'Dalton in Furness', 'Dalton,Dalton in Furness', 54.1579600, -3.1797700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60689, 'Dalston', 'Dalston', 'Dalston', 54.8420700, -2.9845900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60690, 'Dalserf', 'Dalserf', 'Dalserf', 55.7333300, -3.9166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60691, 'Dalrymple', 'Dalrymple', 'Dalrymple', 55.3975700, -4.5916900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60692, 'Dalry', 'Dalry', 'Dail Ruigh,Dail Ruighe', 55.7095600, -4.7216700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60693, 'Dalmellington', 'Dalmellington', 'Dalmellington', 55.3241900, -4.4020000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60694, 'Dalkeith', 'Dalkeith', 'Dail Che,Dail Cheith,Dail Chè,Dail Chèith,Dalkeith,Dalkit,Dalkitas,Dawkeith,Далкит,Далкіт', 55.8931700, -3.0680600, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60695, 'Dale', 'Dale', 'Dale', 51.7091700, -5.1733300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60696, 'Dalbeattie', 'Dalbeattie', 'Dail Bheithe,Dalbeattie,Dalbitti,Далбитти', 54.9327800, -3.8227100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60697, 'Dagenham', 'Dagenham', 'da gen lin,daegeoneom,dagenamu,dagnham,dajnham,deganahama,داجنهام,داگنهام,डेगनहम,ダゲナム,達根林,대거넘', 51.5500000, 0.1666700, 'GB', '2012-04-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60698, 'Cwmbran', 'Cwmbran', 'Cwm-bran,Cwm-brân,Cwmbran,Cwmbrân,Kumbran,Kumbranas,kumbeulan,kwmbrn,Кумбран,کومبرن,쿰브란', 51.6544600, -3.0228100, 'GB', '2014-01-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60699, 'Cwmafan', 'Cwmafan', 'Cwm-avan,Cwmafan,Cwmavon', 51.6167100, -3.7620500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60700, 'Cwm', 'Cwm', '', 53.2833300, -3.4000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60701, 'Cwm', 'Cwm', '', 51.7400000, -3.1802800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60702, 'Cuxton', 'Cuxton', '', 51.3743000, 0.4568800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60703, 'Cushendall', 'Cushendall', '', 55.0803300, -6.0629100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60704, 'Curry Rivel', 'Curry Rivel', '', 51.0230600, -2.8675300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60705, 'Currie', 'Currie', 'Currie', 55.8964000, -3.3084500, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60706, 'Cupar', 'Cupar', 'Cubar,Cupar,Cupar Fiobha,Cupar Fìobha,Cúbar,ku po,庫珀', 56.3187600, -3.0120400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60707, 'Cumnock', 'Cumnock', 'Cumnag,Cumnock', 55.4544500, -4.2664400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60708, 'Cumbernauld', 'Cumbernauld', 'Comar nan Allt,Cummernaud,Kambernold,Kambernoldas,Kumburnold,kambrnwld,kan bo nuo er de,kanbanorudo,kham bexr nx ld,Камбернолд,Къмбърнолд,کامبرنولد,کمبرنالڈ,คัมเบอร์นอลด์,カンバーノールド,坎伯諾爾德', 55.9468500, -3.9905100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60709, 'Cults', 'Cults', 'Cuits,Cults', 57.1166700, -2.1666700, 'GB', '2013-05-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60710, 'Culmore', 'Culmore', 'Culmore', 55.0500000, -7.2666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60711, 'Cullybackey', 'Cullybackey', 'Cullybacky', 54.8887500, -6.3470100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60712, 'Cullompton', 'Cullompton', 'Cullompton,kalwmptwn,کالومپتون', 50.8553000, -3.3926800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60713, 'Cullingworth', 'Cullingworth', '', 53.8244400, -1.8973000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60714, 'Cullen', 'Cullen', 'Cullen,Inbhir Cuilinn,Kallen,Каллен', 57.6904500, -2.8181800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60715, 'Culcheth', 'Culcheth', 'kwltshth,كولتشث', 53.4511000, -2.5210400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60716, 'Cuffley', 'Cuffley', '', 51.7079900, -0.1120900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60717, 'Cudworth', 'Cudworth', '', 53.5713100, -1.4159500, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60718, 'Cuddington', 'Cuddington', '', 53.2448800, -2.6187900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60719, 'Cuckfield', 'Cuckfield', '', 51.0107300, -0.1406800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60720, 'Crynant', 'Crynant', '', 51.7288900, -3.7480600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60721, 'Crymych', 'Crymych', 'Crymmych,Crymmych Arms,Crymych', 51.9736100, -4.6472200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60722, 'Crumlin', 'Crumlin', '', 54.6205400, -6.2141400, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60723, 'Crumlin', 'Crumlin', 'Crumlin', 51.6777800, -3.1352800, 'GB', '2016-02-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60724, 'Croydon', 'Croydon', 'Croydon,Croydon Grants,Croydon  London,Krojdun,Kroydon,ke luo yi deng,krwydwn,kuroidon,Кройдън,کرویدون,クロイドン,克羅伊登', 51.3833300, -0.1000000, 'GB', '2017-03-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60725, 'Croxton', 'Croxton', '', 53.5964000, -0.3483000, 'GB', '2015-12-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60726, 'Crowthorne', 'Crowthorne', 'Crowthorne', 51.3702700, -0.7921900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60727, 'Crowle', 'Crowle', '', 53.6075300, -0.8325600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60728, 'Crowland', 'Crowland', 'Crowland,Croyland,krwlnd,کرولند', 52.6757100, -0.1684900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60729, 'Crowborough', 'Crowborough', 'Krouboro,krwbwrw,Кроуборо,کروبورو', 51.0609800, 0.1634200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60730, 'Croston', 'Croston', '', 53.6621700, -2.7752300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60731, 'Crossmaglen', 'Crossmaglen', 'Crossmaglen', 54.0833300, -6.6000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60732, 'Crosskeys', 'Crosskeys', 'Crosskeys', 51.6191700, -3.1236100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60733, 'Crosshouse', 'Crosshouse', 'Crosshouse', 55.6125800, -4.5509100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60734, 'Cross Hands', 'Cross Hands', 'Cross Hands', 51.7930600, -4.0875000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60735, 'Crossgates', 'Crossgates', 'Crossgates', 56.0836600, -3.3771200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60736, 'Crossgar', 'Crossgar', '', 54.3967500, -5.7606100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60737, 'Crossford', 'Crossford', 'Crossford', 56.0630300, -3.4967400, 'GB', '2017-06-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60738, 'Cropwell Bishop', 'Cropwell Bishop', 'Cropwell Bishop', 52.9148000, -0.9848200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60739, 'Crook', 'Crook', 'Crook,Crook i County Durham', 54.7125200, -1.7497000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60740, 'Crondall', 'Crondall', 'Crondall', 51.2328500, -0.8632900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60741, 'Cromford', 'Cromford', 'qrwmpwrd,קרומפורד', 53.1084800, -1.5601400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60742, 'Cromer', 'Cromer', 'krwmr,کرومر', 52.9312300, 1.2989200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60743, 'Crofton', 'Crofton', '', 53.6563900, -1.4296800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60744, 'Croft', 'Croft', 'Croft', 53.4333300, -2.5500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60745, 'Croft', 'Croft', 'Croft', 52.5566800, -1.2464300, 'GB', '2011-03-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60746, 'Cringleford', 'Cringleford', '', 52.6048200, 1.2433400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60747, 'Crigglestone', 'Crigglestone', '', 53.6424000, -1.5291600, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60748, 'Crieff', 'Crieff', 'Craoibh,Kriff,Krijf,keulipeu,Крийф,Крифф,Кріфф,크리프', 56.3726800, -3.8389100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60749, 'Cricklade', 'Cricklade', 'Kriklejd,keulikeulleideu,kryklyd,Криклейд,کریکلید,크리클레이드', 51.6406100, -1.8573800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60750, 'Crickhowell', 'Crickhowell', 'Crickhowell,Crucywel,Crughywel,Cucywel,Krikkhauul,Крикхауъл', 51.8599200, -3.1377100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60751, 'Crick', 'Crick', '', 52.3480800, -1.1370800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60752, 'Criccieth', 'Criccieth', 'Cricieth,Krikijt,Крикийт', 52.9205300, -4.2346000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60753, 'Crewkerne', 'Crewkerne', 'Crewkerne,krwkrn,کروکرن', 50.8829800, -2.7958800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60754, 'Crewe', 'Crewe', 'Crewe,Krju,Kru,XVC,ke lu,keulu,krw  chshr,kuru,Кру,Крю,کرو، چشر,クルー,克魯,크루', 53.0978700, -2.4416100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60755, 'Creswell', 'Creswell', 'Cresswell,Creswell', 53.2628700, -1.2198700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60756, 'Cresswell', 'Cresswell', '', 55.2166700, -1.5500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60757, 'Creech Saint Michael', 'Creech Saint Michael', '', 51.0233300, -3.0383300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60758, 'Crediton', 'Crediton', 'Crediton,Cridia,Cridiantun,Cridiantūn,krdytwn,کردیتون', 50.7833300, -3.6500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60759, 'Credenhill', 'Credenhill', 'Credenhill', 52.0835100, -2.8080400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60760, 'Cray', 'Cray', '', 51.9000000, -3.6166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60761, 'Crawley', 'Crawley', 'Crawley,Krolis,Krouli,ke lao li,Кроули,克劳利', 51.1130300, -0.1831200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60762, 'Craven Arms', 'Craven Arms', 'Craven Arms,krywn armz,کریون آرمز', 52.4430800, -2.8356200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60763, 'Cranwell', 'Cranwell', 'Cranwell', 53.0368100, -0.4617600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60764, 'Cranleigh', 'Cranleigh', '', 51.1420900, -0.4837400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60765, 'Cranfield', 'Cranfield', '', 52.0686900, -0.6088400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60766, 'Cranbrook', 'Cranbrook', 'Cranbrook i Kent,kranbrwk  knt,کرانبروک، کنت', 51.0966200, 0.5356700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60767, 'Cramlington', 'Cramlington', 'Cramlington,Kramlington,kramlyngtwn,Крамлингтон,کراملینگتون', 55.0865200, -1.5859800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60768, 'Crail', 'Crail', 'Cathair Aile', 56.2604200, -2.6267600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60769, 'Coylton', 'Coylton', '', 55.4452800, -4.5195000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60770, 'Coxhoe', 'Coxhoe', 'Coxhoe', 54.7147500, -1.5035600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60771, 'Cowley', 'Cowley', '', 51.7321300, -1.2063100, 'GB', '2014-09-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60772, 'Cowie', 'Cowie', 'Cowie', 56.0797400, -3.8675300, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60773, 'Cowfold', 'Cowfold', 'Cowfold', 50.9894500, -0.2724300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60774, 'Cowes', 'Cowes', 'Cowes,Kaus,Kouz,West Cowes,kwwz,Каус,Коуз,کووز', 50.7630600, -1.2977200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60775, 'Cowdenbeath', 'Cowdenbeath', 'Cowdenbeath,Cul Dun Beithe,Cùl Dùn Beithe,Cúl Dún Beithe,Kaudenbit,Kovdenbit,Кауденбит,Ковденбіт', 56.1119400, -3.3442600, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60776, 'Cowbridge', 'Cowbridge', 'Cowbridge,Koubridzh,Pontfaen,Y Bont-faen,Коубридж', 51.4602800, -3.4416700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60777, 'Cowbit', 'Cowbit', 'Cowbit', 52.7452300, -0.1297800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60778, 'Coventry', 'Coventry', 'CVT,Coventria,Coventry,Gorad Koventry,Koventri,Koventrija,Koventris,Kovuntri,kao wen chui,kawntry,khx wen thri,kobeonteuli,kovhentri,kovu~entori,kwfntry,qwbntry,Κόβεντρι,Горад Ковентры,Ковентри,Ковентрі,Ковънтри,קובנטרי,كوفنتري,کاونتری,کونٹری,कॉव्हेंट्री,คอเวนทรี,ကိုဗင်ထရီမြို့,კოვენტრი,コヴェントリー,考文垂,코번트리', 52.4065600, -1.5121700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60779, 'Cove', 'Cove', '', 57.1000000, -2.0833300, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60780, 'Coupar Angus', 'Coupar Angus', 'Coupar Angus', 56.5455200, -3.2677400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60781, 'Countesthorpe', 'Countesthorpe', 'Countesthorpe', 52.5537900, -1.1452600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60782, 'Coundon', 'Coundon', 'Coundon', 54.6628000, -1.6268800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60783, 'Coulsdon', 'Coulsdon', 'Coulsdon,kwlsdwn,کولسدون', 51.3200200, -0.1408800, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60784, 'Cottingham', 'Cottingham', '', 53.7805700, -0.4154200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60785, 'Cottingham', 'Cottingham', 'Cottingham', 52.5024300, -0.7554000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60786, 'Cottesmore', 'Cottesmore', '', 52.7138400, -0.6633000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60787, 'Cottenham', 'Cottenham', '', 52.2874300, 0.1254000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60788, 'Cotgrave', 'Cotgrave', '', 52.9085900, -1.0375200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60789, 'Costessey', 'Costessey', 'Costessey', 52.6591400, 1.2097000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60790, 'Cosham', 'Cosham', '', 50.8465400, -1.0634400, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60791, 'Cosby', 'Cosby', 'Cosby', 52.5512700, -1.1939500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60792, 'Corston', 'Corston', '', 51.3850000, -2.4402800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60793, 'Corsley', 'Corsley', 'Corsley', 51.2193300, -2.2464000, 'GB', '2016-02-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60794, 'Corsham', 'Corsham', 'Corsham,Corsham Regis,kwrshham,کورشهام', 51.4343300, -2.1843700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60795, 'Corsenside', 'Corsenside', '', 55.1833300, -2.1666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60796, 'Corse', 'Corse', 'Corse', 51.9594300, -2.3063600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60797, 'Corris', 'Corris', 'Corris', 52.6514500, -3.8431500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60798, 'Cornholme', 'Cornholme', 'Cornholme', 53.7323000, -2.1385100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60799, 'Corfe Castle', 'Corfe Castle', 'Corfe', 50.6394700, -2.0567200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60800, 'Corby', 'Corby', 'Corby,Korbi,kobi,kwrby,Корби,کوربی,コービー', 52.4963700, -0.6893900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60801, 'Corbridge', 'Corbridge', 'Corbridge,kwrbryj,کوربریج', 54.9736500, -2.0179800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60802, 'Coppull', 'Coppull', '', 53.6252700, -2.6585400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60803, 'Copplestone', 'Copplestone', 'Copplestone', 50.8107300, -3.7460700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60804, 'Copmanthorpe', 'Copmanthorpe', 'Copmanthorpe', 53.9141900, -1.1420900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60805, 'Cople', 'Cople', '', 52.1234200, -0.3893300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60806, 'Cooling', 'Cooling', '', 51.4547400, 0.5239500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60807, 'Cookstown', 'Cookstown', 'An Chorr Chriochach,An Chorr Chríochach,Kukstaun,ku ke si dui,Кукстаун,庫克斯敦', 54.6430500, -6.7459500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60808, 'Cookley', 'Cookley', 'Cookley', 52.3166700, 1.4500000, 'GB', '2014-04-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60809, 'Cookham', 'Cookham', 'Cookham,kwhm,كوهم', 51.5593600, -0.7081000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60810, 'Conwy', 'Conwy', 'Aberconway,Conway,Conwy,Konui,Konvi,Konvis,kang wei,kanvi,knwy,kon''u~i,kon-wi,qwnwwy,Конві,Конуи,קונווי,كنوي,ಕಾನ್ವಿ,コンウィ,康維,콘위', 53.2807700, -3.8303900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60811, 'Consett', 'Consett', 'Consett,Konset,Konsett,Консет,Консетт', 54.8540400, -1.8316000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60812, 'Conon Bridge', 'Conon Bridge', 'Conan Bridge,Conon Bridge', 57.5663000, -4.4367800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60813, 'Connor', 'Connor', '', 54.8000000, -6.2000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60814, 'Conisbrough', 'Conisbrough', 'Conisborough,Conisbrough,kwnysbwrw,کونیسبورو', 53.4818800, -1.2321400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60815, 'Coningsby', 'Coningsby', 'QCY', 53.1059800, -0.1759500, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60816, 'Congresbury', 'Congresbury', '', 51.3713500, -2.8101800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60817, 'Congleton', 'Congleton', 'Konglton,kwngltwn,Конглтон,کونگلتون', 53.1631400, -2.2125300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60818, 'Comrie', 'Comrie', 'Comraigh,Cuimrigh', 56.3688000, -3.9788200, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60819, 'Compton Martin', 'Compton Martin', '', 51.3105600, -2.6552800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60820, 'Compton Dando', 'Compton Dando', '', 51.3790900, -2.5144500, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60821, 'Compton', 'Compton', '', 51.5158500, -1.2551000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60822, 'Compton', 'Compton', '', 51.0238500, -1.3371300, 'GB', '2015-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60823, 'Comberton', 'Comberton', '', 52.1870900, 0.0190500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60824, 'Comber', 'Comber', 'An Comar,Komber,Komberis,Kombur,Комбер,Комбър', 54.5493700, -5.7437900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60825, 'Combe Martin', 'Combe Martin', 'Combe Martin', 51.1987300, -4.0234300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60826, 'Colyton', 'Colyton', '', 50.7400600, -3.0702100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60827, 'Colwyn Bay', 'Colwyn Bay', 'Bae Colwyn,Colwyn Bay,Koluin Bej,Kolvin Bejus,Kolvin Bėjus,Kolvin-Bej,ke er wen wan,Колвін-Бей,Колуин Бей,科爾溫灣', 53.2948300, -3.7267400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60828, 'Colwich', 'Colwich', 'Colwich', 52.7876400, -1.9820600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60829, 'Coltishall', 'Coltishall', 'CLF,Coltishall', 52.7280400, 1.3665300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60830, 'Colsterworth', 'Colsterworth', 'Colsterworth', 52.8066000, -0.6205600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60831, 'Colne', 'Colne', 'kwln  lankashr,کولن، لانکاشر', 53.8571300, -2.1685100, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60832, 'Colnbrook', 'Colnbrook', 'klnbrwk,كلنبروك', 51.4838400, -0.5214200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60833, 'Colmworth', 'Colmworth', '', 52.2168100, -0.3782600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60834, 'Collington', 'Collington', '', 52.2500000, -2.5166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60835, 'Collingham', 'Collingham', '', 53.9116700, -1.4117400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60836, 'Collingbourne Kingston', 'Collingbourne Kingston', 'Collingbourne Kingston', 51.3010500, -1.6587600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60837, 'Colinton', 'Colinton', 'Colinton', 55.9073900, -3.2560900, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60838, 'Colerne', 'Colerne', 'Colerne', 51.4383300, -2.2628000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60839, 'Coleraine', 'Coleraine', 'Coleraine,Cuil Raithin,Cuil Rathin,Cúil Raithin,Cúil Rathin,Districtul Coleraine,Kolrehjn,Kolreinas,Kolrejn,Koulrejn,ke er lei yin,kwlryn,kwlyryn,Колрейн,Колрэйн,Коулрейн,كوليرين,کولرین,科爾雷因', 55.1333300, -6.6666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60840, 'Coleford', 'Coleford', 'Coleford', 51.7953500, -2.6135400, 'GB', '2012-06-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60841, 'Coldstream', 'Coldstream', 'An Sruthan Fuar,Cauldstream,Coldstream,Koldstrim,ke er de si te li mu,Колдстрим,Колдстрім,Քոլդստրիմ,科尔德斯特里姆', 55.6511100, -2.2529500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60842, 'Cold Norton', 'Cold Norton', 'Cold Norton', 51.6720900, 0.6699700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60843, 'Cold Ashton', 'Cold Ashton', '', 51.4508300, -2.3613900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60844, 'Cold Ash', 'Cold Ash', 'Cold Ash', 51.4242600, -1.2646300, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60845, 'Colchester', 'Colchester', 'CLB,Camulodunum,Colchester,Colneceaster,Kolcesteris,Kolchest"r,Kolchester,Kolčesteris,gao che shi da,ke er qie si te,kolcheseuteo,koruchesuta,kwlchstr,kwlshystr,kwltshystr,qwlzstr,Колчестер,Колчестър,Կոլչեստր,קולצסטר,كولتشيستر,كولشيستر,کولچستر,コルチェスター,科尔切斯特,高車士打,콜체스터', 51.8892100, 0.9042100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60846, 'Coity', 'Coity', 'Coity,Coyty', 51.5220000, -3.5553100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60847, 'Coggeshall', 'Coggeshall', 'Coggeshall,kwjshal,کوجشال', 51.8707700, 0.6853600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60848, 'Cogenhoe', 'Cogenhoe', 'Cogenhoe,Coggenhoe', 52.2375800, -0.7838100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60849, 'Coedpoeth', 'Coedpoeth', '', 53.0539100, -3.0623400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60850, 'Codsall', 'Codsall', 'Codsall', 52.6298900, -2.2014800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60851, 'Codicote', 'Codicote', 'Codicote', 51.8505200, -0.2367000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60852, 'Codford', 'Codford', '', 51.1500000, -2.0500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60853, 'Coddington', 'Coddington', '', 53.0833300, -2.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60854, 'Cockfield', 'Cockfield', '', 54.6137300, -1.8089700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60855, 'Cockermouth', 'Cockermouth', 'Cockermouth,ke ke mao si,kokkamasu,kwkrmwth,کوکرموث,コッカーマス,科克茅斯', 54.6620900, -3.3608600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60856, 'Cockenzie', 'Cockenzie', 'Cockenzie,Cockenzie and Port Seton', 55.9682300, -2.9656200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60857, 'Cobham', 'Cobham', 'Church Cobham,Cobham', 51.3299700, -0.4113000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60858, 'Coates', 'Coates', 'Coates', 51.7075000, -2.0338900, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60859, 'Coatbridge', 'Coatbridge', 'Coatbridge,Coatbrig,Drochaid a Chota,Drochaid a Chòta,Drochaid an Chota,Drochaid an Chóta,Kotbridzh,Koutbridzas,Koutbridžas,ke te bu li qi,kwtbryj,Котбридж,Котбрідж,کوتبریج,کوٹبرج,科特布里奇', 55.8621600, -4.0246900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60860, 'Coalville', 'Coalville', 'Coalville,Koulvil,Коулвил', 52.7224700, -1.3702000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60861, 'Coalisland', 'Coalisland', 'Kolajlend,Koulajland,Oilean an Ghuail,Oileán an Ghuail,Колайленд,Коулайланд', 54.5418000, -6.7016600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60862, 'Coalburn', 'Coalburn', '', 55.5929500, -3.8863700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60863, 'Clydebank', 'Clydebank', 'Bruach Chluaidh,Clydebank,Klajdbank,Klaydbank,ke lai de ban ke,keullaideubaengkeu,klaydbnk,Клайдбанк,کلایدبنک,克萊德班克,클라이드뱅크', 55.9013700, -4.4057000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60864, 'Clydach', 'Clydach', '', 51.6833300, -3.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60865, 'Clutton', 'Clutton', '', 51.3294400, -2.5430600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60866, 'Clowne', 'Clowne', '', 53.2744900, -1.2640600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60867, 'Clophill', 'Clophill', '', 52.0272700, -0.4237700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60868, 'Clive', 'Clive', 'Clive', 52.8133500, -2.7229500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60869, 'Clitheroe', 'Clitheroe', 'Clitheroe,klydhrw,klytrw,كليذرو,کلیترو', 53.8666700, -2.4000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60870, 'Clipsham', 'Clipsham', 'Clipsham', 52.7360800, -0.5654500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60871, 'Clifton', 'Clifton', '', 52.0399000, -0.3005100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60872, 'Clifford', 'Clifford', '', 52.1000000, -3.1000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60873, 'Cliffe', 'Cliffe', 'Cliffe,Cliffe-at-Hoo', 51.4622400, 0.4983300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60874, 'Cleveleys', 'Cleveleys', '', 53.8775000, -3.0398700, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60875, 'Clevedon', 'Clevedon', 'Clevedon,Klijvdun,klywdwn,Клийвдън,کلیودون', 51.4422700, -2.8578600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60876, 'Cleobury Mortimer', 'Cleobury Mortimer', 'Cleobury Mortimer,klywbwry mwrtymr,کلئوبوری مورتیمر', 52.3785300, -2.4819600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60877, 'Clenchwarton', 'Clenchwarton', 'Clenchwarton', 52.7560400, 0.3579000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60878, 'Cleland', 'Cleland', '', 55.8024300, -3.9142000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60879, 'Cleethorpes', 'Cleethorpes', 'Cleethorpes,Klitkhorps,Klitorpsas,Meggies,klytwrps,Клитхорпс,کلیتورپس', 53.5604700, -0.0322500, 'GB', '2015-06-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60880, 'Cleckheaton', 'Cleckheaton', '', 53.7240500, -1.7129400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60881, 'Cleator Moor', 'Cleator Moor', 'Klitor-Mur,klytwr mwr,Клитор-Мур,کلیتور مور', 54.5214300, -3.5159000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60882, 'Clayton West', 'Clayton West', 'Clayton,Clayton West', 53.5950100, -1.6110700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60883, 'Clayton le Moors', 'Clayton le Moors', 'Clayton le Moor,Clayton le Moors', 53.7666700, -2.3833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60884, 'Clayton', 'Clayton', '', 53.7666700, -1.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60885, 'Claypole', 'Claypole', '', 53.0314400, -0.7340700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60886, 'Claydon', 'Claydon', '', 52.1481300, -1.3329500, 'GB', '2011-02-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60887, 'Claydon', 'Claydon', 'Claydon', 52.1067200, 1.1113400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60888, 'Clare', 'Clare', 'klr  safk,کلر، سافک', 52.0786100, 0.5816700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60889, 'Clarborough', 'Clarborough', '', 53.3454900, -0.9038200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60890, 'Clapham', 'Clapham', '', 52.1608500, -0.4952900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60891, 'Clacton-on-Sea', 'Clacton-on-Sea', 'Clacton,Clacton al Mar,Clacton-on-Sea,Klakton na Moru,Klakton-on-Si,Pajurio Klaktonas,Pajūrio Klaktonas,klktwn-an-sy,Клактон на Мору,Клактон-он-Си,کلکتون-آن-سی', 51.7896700, 1.1559700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60892, 'Clackmannan', 'Clackmannan', 'Clackmannan', 56.1074300, -3.7509800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60893, 'Cirencester', 'Cirencester', 'Chirenchester,Cicester,Cirenceaster,Cirencester,Ciricestria,Sajrensester,Sajrunsestur,sairensesuta,sileonseseuteo,Сайренсестер,Сайрънсестър,Чиренчестер,سایرن‌سستر,サイレンセスター,시런세스터', 51.7192700, -1.9714500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60894, 'Cinderford', 'Cinderford', 'kyndrfwrd,کیندرفورد', 51.8242100, -2.4987000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60895, 'Church Stretton', 'Church Stretton', 'Cerc Stretonas,Church Stretton,chrwch astrtwn,Čerč Stretonas,چروچ استرتون', 52.5377800, -2.8014900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60896, 'Churchill', 'Churchill', '', 51.3429100, -2.7833800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60897, 'Honeybourne', 'Honeybourne', 'Church Honeybourne,Honeybourne', 52.0951300, -1.8312900, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60898, 'Church Fenton', 'Church Fenton', 'Church Fenton', 53.8262600, -1.2189000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60899, 'Churchdown', 'Churchdown', '', 51.8773900, -2.1708700, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60900, 'Church', 'Church', 'Church', 53.7517700, -2.3912100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60901, 'Chulmleigh', 'Chulmleigh', '', 50.9128900, -3.8693800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60902, 'Chudleigh Knighton', 'Chudleigh Knighton', 'Chudleigh Knighton', 50.5850700, -3.6318700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60903, 'Chudleigh', 'Chudleigh', 'Chudleigh,chadly,چادلی', 50.6049600, -3.6003100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60904, 'Chryston', 'Chryston', 'Chryston', 55.9028000, -4.1075900, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60905, 'Christchurch', 'Christchurch', 'Christchurch i Dorset,Kraistcercas,Kraistčerčas,Krajstcherch,Krajstchurch,chrystchwrch  dwrst,ke lai si te che qi,keulaiseuteucheochi,kuraisutochachi,Крайстчерч,Крайстчърч,چریستچورچ، دورست,کرائسٹ چرچ، ڈورسٹ,ڪرائسٽ چرچ، ڊورسٽ,クライストチャーチ,克賴斯特徹奇,크라이스트처치', 50.7358300, -1.7812900, 'GB', '2015-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60906, 'Chorleywood', 'Chorleywood', 'Chorleywood,chwrlywwd,چورلیوود', 51.6547200, -0.5140400, 'GB', '2016-04-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60907, 'Chorley', 'Chorley', 'Corlis,chwrly,Čorlis,چورلی', 53.6500000, -2.6166700, 'GB', '2012-08-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60908, 'Choppington', 'Choppington', 'Choppington', 55.1500400, -1.6033200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60909, 'Cholsey', 'Cholsey', 'Cholsey', 51.5728000, -1.1535600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60910, 'Chobham', 'Chobham', '', 51.3483600, -0.6063900, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60911, 'Chislehurst', 'Chislehurst', 'Chislehurst,Chizlkherst,cisalaharsta,zyzlhrst,Чизлхерст,ציזלהרסט,چزلہرسٹ، لندن,चिसलहर्स्ट', 51.4170900, 0.0685800, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60912, 'Chirnside', 'Chirnside', 'Chirnside', 55.8021500, -2.2092700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60913, 'Chirk', 'Chirk', 'Cerkas,Chirk,Churk,Y Waun,Čerkas,Чърк', 52.9358600, -3.0573800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60914, 'Chipping Sodbury', 'Chipping Sodbury', 'chypyng swbwry,چیپینگ سوبوری', 51.5381300, -2.3937900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60915, 'Chipping Ongar', 'Chipping Ongar', 'Chipping Ongar,Ongar,chypyng awngar,چیپینگ اونگار', 51.7037900, 0.2454800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60916, 'Chipping Norton', 'Chipping Norton', '', 51.9410900, -1.5453000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60917, 'Chipping Campden', 'Chipping Campden', 'Chiping Kampdun,chypyng kmpdn,Чипинг Кампдън,چیپینگ کمپدن,チッピング・カムデン', 52.0496400, -1.7767000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60918, 'Chippenham', 'Chippenham', 'Chippenem,Chippenham,Cipenhamas,Cippanhamm,chypnham,tshbnham,Čipenhamas,Чиппенем,تشبنهام,چیپنهام', 51.4600000, -2.1247200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60919, 'Chinnor', 'Chinnor', 'Chinnor', 51.7017700, -0.9116100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60920, 'Chinley', 'Chinley', '', 53.3402500, -1.9390000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60921, 'Chilworth', 'Chilworth', 'Chilworth,Saint Martha', 51.2163500, -0.5312900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60922, 'Chilton Foliat', 'Chilton Foliat', 'Chilton Foliat', 51.4324500, -1.5391200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60923, 'Child Okeford', 'Child Okeford', 'Child Okeford', 50.9137000, -2.2367900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60924, 'Chilcompton', 'Chilcompton', '', 51.2639100, -2.5050200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60925, 'Chigwell', 'Chigwell', 'Chigwell', 51.6199900, 0.0759600, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60926, 'Chiddingfold', 'Chiddingfold', '', 51.1186600, -0.6226200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60927, 'Chicksands', 'Chicksands', '', 52.0458500, -0.3639000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60928, 'Chicklade', 'Chicklade', '', 51.1091700, -2.1266700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60929, 'Chickerell', 'Chickerell', 'Chickerell,West Chickerel', 50.6242900, -2.5028000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60930, 'Chichester', 'Chichester', 'Chichester,Chichestur,Cicesteris,Cicestria,QUG,chi chi s texr,chicheseuteo,chichesuta,chychstr,qi qie si te,tshytshstr,Čičesteris,Чичестер,Чичестър,Чічестер,Չիչեստեր,تشيتشستر,چیچستر,چیچیسٹر,ชิชิสเตอร์,ቺቸስተር,チチェスター,奇切斯特,치체스터', 50.8367300, -0.7800300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60931, 'Chicheley', 'Chicheley', 'Chicheley', 52.1030300, -0.6864700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60932, 'Chew Magna', 'Chew Magna', 'Chew Magna,Great Chew', 51.3661100, -2.6102800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60933, 'Chetwynd', 'Chetwynd', '', 52.7833300, -2.4000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60934, 'Chester-le-Street', 'Chester-le-Street', 'chstr ly astryt,qie si te lei jie,چستر لی استریت,切斯特勒街', 54.8586200, -1.5740800, 'GB', '2015-06-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60935, 'Chesterfield', 'Chesterfield', 'Cesterfildas,Chesterfield,Chesterfild,Chesturfijld,ZFI,che shi da fei te,cheseuteopildeu,chesutafirudo,chstrfyld,Česterfildas,Честерфилд,Честърфийлд,Չեստըրֆիլտ,چسترفیلد,چیسٹرفیلڈ,ჩესტერფილდი,チェスターフィールド,車士打菲特,체스터필드', 53.2500000, -1.4166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60936, 'Chester', 'Chester', 'CEG,Caer,Cesteris,Cestria,Chester,Chestur,Deva,Tsester,Yn Chaayr,Yn Çhaayr,che shi da,ches texr,cheseuteo,chesuta,chstr,qie si te,tshstr,zstr,Česteris,Τσέστερ,Честер,Честър,Չեստեր,צסטר,تشستر,چستر,چیسٹر,เชสเตอร์,ချက်စတာမြို့,ቸስተር,チェスター,切斯特,車士打,체스터', 53.1905000, -2.8918900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60937, 'Chessington', 'Chessington', 'Chessington,cesingtana,चेसिंग्टन', 51.3624000, -0.3042700, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60938, 'Cheshunt', 'Cheshunt', 'Chesant,Cheshunt,chznt,qie sen te,Чесант,چزنت,切森特', 51.7002000, -0.0302600, 'GB', '2015-07-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60939, 'Chesham', 'Chesham', 'Chesham,Chesum,chshham,Чесъм,چشهام', 51.7000000, -0.6000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60940, 'Chertsey', 'Chertsey', 'Chertsey,chrtsy,qie te xi,چرتسی,切特西', 51.3881200, -0.5078200, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60941, 'Cherry Burton', 'Cherry Burton', '', 53.8666700, -0.5000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60942, 'Chepstow', 'Chepstow', 'Cas-gwent,Chepstou,Chepstow,cepsto,qie pu si tuo,Чепстоу,चेप्स्टो,切普斯托', 51.6408700, -2.6768300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60943, 'Cheltenham', 'Cheltenham', 'CHW,Celtnamas,Cheltenam,Cheltenham,Cheltnem,Cheltnum,chelteuneom,cheltnam,cherutonamu,chltnham,qie er teng na mu,shltnham,Čeltnamas,Челтенам,Челтнем,Челтнъм,צ''לטנהאם,شلتنهام,چلتنهام,เชลต์นัม,チェルトナム,切爾滕納姆,첼트넘', 51.9000600, -2.0797200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60944, 'Chelsea', 'Chelsea', 'Celsi,Chelsea,Chelsi,Tselsi,che lu shi,chelsi,cherushi,chlsy,qie er xi,tshylsy  lndn,Çelsi,Τσέλσι,Челси,Челсі,تشيلسي، لندن,چلسی,チェルシー,切爾西,車路士,첼시', 51.4875500, -0.1693600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60945, 'Chelmsford', 'Chelmsford', 'Celmsfordas,Celmsfuords,Chelmsford,chelleumseupeodeu,cherumusufodo,chlmzfwrd,qie er mu si fu de,tshylmsfwrd,zlmspwrd,Čelmsfordas,Čelmsfuords,Челмсфорд,צלמספורד,تشيلمسفورد,چلمزفورد,چلمسفورڈ,ቸልምስፎርድ,チェルムスフォード,切爾姆斯福德,첼름스퍼드', 51.7357500, 0.4695800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60946, 'Chelford', 'Chelford', '', 53.2709000, -2.2832900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60947, 'Cheddleton', 'Cheddleton', '', 53.0691000, -2.0422800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60948, 'Cheddington', 'Cheddington', '', 51.8478400, -0.6642900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60949, 'Cheddar', 'Cheddar', 'Chedder,cheda,chedeo,shydr,Чеддер,شيدر,チェダー,체더', 51.2753700, -2.7766200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60950, 'Cheam', 'Cheam', 'Cheam', 51.3617900, -0.2197700, 'GB', '2015-07-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60951, 'Cheadle Hulme', 'Cheadle Hulme', '', 53.3761000, -2.1897000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60952, 'Cheadle', 'Cheadle', 'Cheadle', 52.9833300, -1.9833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60953, 'Chatteris', 'Chatteris', 'Caterisas,chatrys,Čaterisas,چاتریس', 52.4562400, 0.0523600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60954, 'Chatham', 'Chatham', 'Catamas,Chatam,Chatem,Chatham,Chatham i Kent,chaeteom,chatamu,chatham  knt,Čatamas,Чатам,Чатем,چاتهام، کنت,チャタム,채텀', 51.3789100, 0.5278600, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60955, 'Chatburn', 'Chatburn', '', 53.8922800, -2.3549500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60956, 'Chasetown', 'Chasetown', 'Chasetown', 52.6723200, -1.9253500, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60957, 'Chartham', 'Chartham', '', 51.2562000, 1.0183600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60958, 'Charmouth', 'Charmouth', 'Charmouth', 50.7388900, -2.9005500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60959, 'Charminster', 'Charminster', 'Charminster', 50.7333300, -2.4500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60960, 'Charlton Marshall', 'Charlton Marshall', 'Charlton Marshall', 50.8359100, -2.1423100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60961, 'Charlton Kings', 'Charlton Kings', '', 51.8837400, -2.0423900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60962, 'Charlton', 'Charlton', '', 51.5991700, -2.0563900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60963, 'Charlbury', 'Charlbury', 'Charlbury,charlbwry,چارلبوری', 51.8727000, -1.4824700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60964, 'Charing', 'Charing', '', 51.2107300, 0.7946600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60965, 'Charfield', 'Charfield', 'Charfield', 51.6272200, -2.4066700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60966, 'Chard', 'Chard', 'Chard,chard  samrst,چارد، سامرست', 50.8727000, -2.9659700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60967, 'Chapletown', 'Chapletown', 'Chapeltown', 53.4650600, -1.4721700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60968, 'Chapel Saint Leonards', 'Chapel Saint Leonards', '', 53.2166700, 0.3166700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60969, 'Chapelhall', 'Chapelhall', '', 55.8434900, -3.9488100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60970, 'Chapel en le Frith', 'Chapel en le Frith', '', 53.3240700, -1.9129100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60971, 'Chalgrove', 'Chalgrove', '', 51.6647600, -1.0764000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60972, 'Chalford', 'Chalford', 'Chalford', 51.7258300, -2.1513900, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60973, 'Chalfont Saint Peter', 'Chalfont Saint Peter', 'Chalfont Saint Peter,Chalfont St Peter', 51.6088500, -0.5561800, 'GB', '2014-03-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60974, 'Chalfont St Giles', 'Chalfont St Giles', 'Chalfont St Giles', 51.6318400, -0.5702600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60975, 'Chale', 'Chale', '', 50.5956100, -1.3183600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60976, 'Chagford', 'Chagford', 'chagfwrd,چاگفورد', 50.6750400, -3.8393600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60977, 'Chacewater', 'Chacewater', 'Chacewater', 50.2567500, -5.1575700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60978, 'Cemaes Bay', 'Cemaes Bay', 'Cemaes,Cemaes Bay,Cemmaes', 53.4121100, -4.4519000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60979, 'Caythorpe', 'Caythorpe', 'Caythorpe', 53.0166700, -0.6000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60980, 'Cawthorne', 'Cawthorne', '', 53.5668700, -1.5725900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60981, 'Cawston', 'Cawston', 'Cawston', 52.7666700, 1.1666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60982, 'Cawood', 'Cawood', 'Cawood', 53.8330300, -1.1296200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60983, 'Catterick', 'Catterick', 'Katterik,Каттерик', 54.3754200, -1.6332800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60984, 'Catterall', 'Catterall', '', 53.8796500, -2.7647800, 'GB', '2010-09-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60985, 'Catrine', 'Catrine', 'Catrine', 55.5042200, -4.3302600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60986, 'Caton', 'Caton', '', 54.0762400, -2.7190300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60987, 'Catford', 'Catford', 'ka te fu de,卡特福德', 51.4449100, -0.0204300, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60988, 'Caterham', 'Caterham', '', 51.2823000, -0.0788900, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60989, 'Castor', 'Castor', 'Castor', 52.5731900, -0.3460300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60990, 'Castlewellan', 'Castlewellan', 'Caislean Uidhilin,Caisleán Uidhilín,Castlewellan,kastlevellana,कास्त्लेवेल्लन', 54.2569000, -5.9444600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60991, 'Castlethorpe', 'Castlethorpe', 'Castlethorpe', 52.0923000, -0.8353900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60992, 'Castleside', 'Castleside', 'Castleside', 54.8342900, -1.8784900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60993, 'Castlerock', 'Castlerock', 'Castlerock', 55.1500000, -6.7833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60994, 'Castlereagh', 'Castlereagh', '', 54.5735000, -5.8847200, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60995, 'Castlemartin', 'Castlemartin', 'Castlemartin', 51.6452800, -5.0169400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60996, 'Castle Hedingham', 'Castle Hedingham', '', 51.9901500, 0.5988200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60997, 'Castleford', 'Castleford', 'Kasulford,kslfwrd,Касълфорд,کسلفورد', 53.7258700, -1.3625600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60998, 'Castle Douglas', 'Castle Douglas', 'Caisteal Dhughlais,Caisteal Dhùghlais,Caisteal Dhúghlais,Castle Douglas', 54.9409500, -3.9278400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(60999, 'Castle Donington', 'Castle Donington', 'Castle Donington,Castle Donnington', 52.8429100, -1.3418800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61000, 'Castlederg', 'Castlederg', 'Castlederg', 54.7069900, -7.5933600, 'GB', '2016-12-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61001, 'Castledawson', 'Castledawson', '', 54.7772300, -6.5622700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61002, 'Castle Cary', 'Castle Cary', 'Castle Cary,kstl kry,کستل کری', 51.0900000, -2.5141700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61003, 'Carterton', 'Carterton', 'Carterton i Oxfordshire,kartrtwn  aksfwrdshr,کارترتون، آکسفوردشر', 51.7590500, -1.5943500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61004, 'Carshalton', 'Carshalton', 'Carshalton,karshaltwn,کارشالتون', 51.3682900, -0.1675500, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61005, 'Carryduff', 'Carryduff', '', 54.5179900, -5.8871300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61006, 'Carron', 'Carron', 'Carron', 56.0261100, -3.7925100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61007, 'Carrington', 'Carrington', '', 53.4333300, -2.3833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61008, 'Carrickfergus', 'Carrickfergus', 'Carraig Fhearghais,Districtul Carrickfergus,Karikfergusas,Karikfurgus,Karrikfergus,ka li ke fu ge si,kyrkfyrgs,Карикфъргъс,Каррикфергус,کیرکفیرگس,卡里克弗格斯', 54.7158000, -5.8058000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61009, 'Carnwath', 'Carnwath', 'Carnwath', 55.7003600, -3.6257900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61010, 'Carnoustie', 'Carnoustie', 'Carn Fheusda,Carn Fheusta,Carnoustie,Càrn Fheusda,Cárn Fheusta,Karnousti,Karnusti,kanuseuti,kanusuti,Карноусті,Карнусти,カーヌスティ,카누스티', 56.5026300, -2.7053000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61011, 'Carnmoney', 'Carnmoney', 'Carmoney,Carnmoney', 54.6833300, -5.9500000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61012, 'Carnlough', 'Carnlough', '', 54.9918500, -5.9903800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61013, 'Carnforth', 'Carnforth', 'Carnforth,karnfwrth,کارنفورث', 54.1316300, -2.7691400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61014, 'Carnaby', 'Carnaby', '', 54.0607000, -0.2595700, 'GB', '2017-06-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61015, 'Carmunnock', 'Carmunnock', 'Carmunnock', 55.7906200, -4.2358400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61016, 'Carmarthen', 'Carmarthen', 'Caerfyrddin,Caermarthen,Carmarthen,Karmardenas,Karmarten,Karmartun,Karvyrdhin,ka ma sen,kamadeon,kamazen,Кармартен,Кармартън,カーマーゼン,卡马森,카마던', 51.8555200, -4.3053500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61017, 'Carluke', 'Carluke', 'Carluke,Cathair MoLuaig,Karluk,Карлук', 55.7359500, -3.8301900, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61018, 'Carlton', 'Carlton', '', 54.5900400, -1.3911700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61019, 'Carlisle', 'Carlisle', 'CAX,Caerliwelydd,Carliolum,Carlisle,Cathair Luail,Karlail,Karlailas,Karlajl,Karlayl,Luel,ka lai er,kallail,karairu,karlayl,karlayl  kambrya,kharlil,Καρλάιλ,Карлайл,Карлајл,Կարլայլ,كارلايل,کارلایل، کامبریا,คาร์ไลล์,კარლაილი,カーライル,卡萊爾,칼라일', 54.8951000, -2.9382000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61020, 'Carfin', 'Carfin', 'Carfin', 55.8050200, -3.9607600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61021, 'Cardross', 'Cardross', 'Cardross', 55.9618400, -4.6531600, 'GB', '2017-07-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61022, 'Cardington', 'Cardington', '', 52.5500000, -2.7333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61023, 'Cardington', 'Cardington', '', 52.1174200, -0.4128900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61024, 'Cardigan', 'Cardigan', 'Aberteifi,Cardigan,Ceretica,Kardigan,kadigan,Кардиган,カーディガン', 52.0837300, -4.6622800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61025, 'Cardiff', 'Cardiff', 'CWL,Caerdydd,Cairdiff,Cardiff,Cardiffa,Cayr Deeth,Gorad Kardyf,Kadif,Kardif,Kardifa,Kardifas,Kardiff,Kardip,Kardydh,Karntif,Kerdiz,Kārdifa,jia de fu,kadifu,kadipeu,karadifa,kardifa,kardipha,kardyf,kartihp,khardif f,Κάρντιφ,Горад Кардыф,Кардиф,Кардифф,Кардіфф,Քարդիֆ,קארדיף,كارديف,کاردیف,کارڈف,कार्डिफ,कार्डिफ़,কার্ডিফ,ਕਾਰਡਿਫ਼,கார்டிஃப்,കാർഡിഫ്,คาร์ดิฟฟ์,ကားဒစ်မြို့,კარდიფი,カーディフ,加的夫,카디프', 51.4800000, -3.1800000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61026, 'Cardenden', 'Cardenden', 'Cardenden', 56.1431000, -3.2568700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61027, 'Carcroft', 'Carcroft', '', 53.5828200, -1.1764800, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61028, 'Capel Saint Mary', 'Capel Saint Mary', 'Capel,Capel Saint Mary', 52.0036900, 1.0448200, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61029, 'Capel', 'Capel', '', 51.1494200, -0.3237500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61030, 'Cantley', 'Cantley', '', 53.5000000, -1.0500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61031, 'Canterbury', 'Canterbury', 'Caergaint,Canterbury,Cantorbery,Cantorbéry,Cantuaria,Cantuária,Cantwaraburg,Cantwarebyrig,Durovernum,Durovernum Canticorum,Gorad Kentehrbery,Kantaraborg,Kanterberi,Kantermperi,Kenterberi,Kenterberija,Kenterberis,Kenturburi,gen de bo li,kaenteobeli,kan te bo lei,kantaberi,kantrbyry,kntrbry,qntrbry,Κάντερμπερι,Горад Кентэрберы,Кантербери,Кентербери,Кентербері,Кентърбъри,Քենթերբերի,קנטרברי,كانتربيري,کنتربری,カンタベリー,坎特伯雷,根德伯里,캔터베리', 51.2790400, 1.0799200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61032, 'Cannock', 'Cannock', 'Cannock,Kannok,Kanok,Kanokas,Kanuk,kaeneog,kanwk,Каннок,Канок,Канък,کانوک,캐넉', 52.6904500, -2.0308500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61033, 'Canewdon', 'Canewdon', 'Canewdon,Canewelon', 51.6175900, 0.7445800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61034, 'Camrose', 'Camrose', '', 51.8413900, -5.0100000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61035, 'Campsall', 'Campsall', '', 53.6191700, -1.1800200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61036, 'Campbeltown', 'Campbeltown', 'Balley Keeill Charane,CAL,Cammeltoun,Campbeltown,Ceann Loch Chille Chiarain,Ceann Loch Chille Chiaráin,Kehmpbeltaun,Kempbeltaun,kan bei er cheng,kyanberutaun,Кемпбелтаун,Кэмпбелтаун,キャンベルタウン,坎貝爾城', 55.4258300, -5.6076400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61037, 'Camerton', 'Camerton', '', 51.3161100, -2.4561100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61038, 'Camelford', 'Camelford', 'Camelford,Gafolford,Ryskammel,kmlfwrd,کملفورد', 50.6218500, -4.6796300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61039, 'Cambuslang', 'Cambuslang', 'Camas Lang,Camas Long,Kambusleng,kmbslng,Камбусленг,کمبسلنگ', 55.8096600, -4.1609600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61040, 'Cambridge', 'Cambridge', 'CBG,Caergrawnt,Cambridge,Cantabrigia,Gorad Kembrydzh,Grantanbrycg,Kambrij,Kejmbridzh,Kembric,Kembridz,Kembridza,Kembridzas,Kembridzh,Kembridža,Kembridžas,Kembrigo,Kembriĝo,Kempritz,Kiam-khiau,Kiam-khiâu,jian qiao,kambrydj,keimbeuliji,kembridj,kembrij,kembrija,kenburijji,khem bridc,kmbryj,kyamabrija,kymbrj,qyymbrydg'',Κέμπριτζ,Горад Кембрыдж,Кеймбридж,Кембридж,Кембриџ,Кембриҷ,Кембрідж,Քեմբրիջ,קיימברידג'',كامبريدج,کمبریج,کیمبرج,केंब्रिज,ক্যামব্রিজ,ಕೇಂಬ್ರಿಜ್,കേംബ്രിഡ്ജ്,เคมบริดจ์,ကိန်းဘရစ်ချ်မြို့,კემბრიჯი,ケンブリッジ,劍橋,케임브리지', 52.2000000, 0.1166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61041, 'Camborne', 'Camborne', 'Cambron,Kamborn,Kamm-Bron,Kammbronn,kambwrn,Камборн,کامبورن', 50.2130600, -5.2973100, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61042, 'Camberley', 'Camberley', 'Camberley,Camberly,Kemberli,kan bo li,Кемберли,坎伯利', 51.3370500, -0.7426100, 'GB', '2015-11-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61043, 'Calverton', 'Calverton', 'Calverton,Claverton', 53.0372800, -1.0826300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61044, 'Calverton', 'Calverton', '', 52.0411900, -0.8504100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61045, 'Calne', 'Calne', 'Calne,ka en,kaln,kan,كان,کالن,卡恩', 51.4387900, -2.0057100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61046, 'Callow', 'Callow', '', 52.0166700, -2.7333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61047, 'Callington', 'Callington', '', 50.5014700, -4.3131400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61048, 'Callander', 'Callander', 'Calasraid,Callander', 56.2441000, -4.2163700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61049, 'Caldicot', 'Caldicot', 'Caldicot', 51.5866100, -2.7573600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61050, 'Caldercruix', 'Caldercruix', '', 55.8888600, -3.8866400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61051, 'Caistor', 'Caistor', 'Caistor,kaystwr,کایستور', 53.4967300, -0.3153800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61052, 'Caister-on-Sea', 'Caister-on-Sea', 'Caister,Caister next Yarmouth', 52.6480900, 1.7264800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61053, 'Cairnryan', 'Cairnryan', 'Cairnryan,Machair an Sgithich', 54.9710400, -5.0198200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61054, 'Cairneyhill', 'Cairneyhill', 'Cairneyhill', 56.0590800, -3.5351800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61055, 'Caerwent', 'Caerwent', 'Caerwent', 51.6112000, -2.7686500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61056, 'Caerphilly', 'Caerphilly', 'Caerffili,Caerphilly,Kerfili,Керфили', 51.5745200, -3.2180000, 'GB', '2011-09-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61057, 'Caernarfon', 'Caernarfon', 'Caernarfon,Carnarvon,Karnarvon,Karnarvun,Kernarvonas,ka na fen,kanabeon,kanavu~on,khay r nar wxn,Карнарвон,Карнарвън,קרנארפון,คายร์นาร์วอน,カーナーヴォン,卡納芬,카나번', 53.1412600, -4.2701600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61058, 'Caerleon', 'Caerleon', 'Caerleon,Caerllion,karlywn,كارليون', 51.6095200, -2.9537800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61059, 'Caergwrle', 'Caergwrle', '', 53.1095300, -3.0380800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61060, 'Cadnam', 'Cadnam', '', 50.9204700, -1.5797000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61061, 'Caddington', 'Caddington', '', 51.8662100, -0.4567900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61062, 'Byfleet', 'Byfleet', 'Byfleet', 51.3401800, -0.4725400, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61063, 'Byfield', 'Byfield', 'Byfield', 52.1754600, -1.2456600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61064, 'Buxton', 'Buxton', 'Aquae Arnemetiae,ba ke si dun,beogseuteon,bwkstwn,بوکستون,巴克斯頓,벅스턴', 53.2574100, -1.9098200, 'GB', '2010-11-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61065, 'Buxton', 'Buxton', '', 52.7525500, 1.2998200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61066, 'Buxted', 'Buxted', 'Buxted', 50.9900300, 0.1344100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61067, 'Butterwick', 'Butterwick', 'Butterwick', 52.9833300, 0.0666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61068, 'Butcombe', 'Butcombe', '', 51.3519400, -2.6977800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61069, 'Bushmills', 'Bushmills', 'Bushmils,Muileann na Buaise,busmillsa,Бушмилс,बुश्मिल्ल्स', 55.2049300, -6.5191800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61070, 'Bushey', 'Bushey', 'Bushey,Bushey Heath', 51.6431600, -0.3605300, 'GB', '2012-06-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61071, 'Busby', 'Busby', '', 55.7799500, -4.2771100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61072, 'Burythorpe', 'Burythorpe', 'Burythorpe', 54.0701700, -0.7936800, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61073, 'Bury St Edmunds', 'Bury St Edmunds', 'BEQ,Beri-Sent-Edmends,Beri-Sent-Ehdmends,Burgus Sancti Edmundi,Bury Saint Edmunds,Bury St,Bury St Edmunds,Bury St. Edmunds,bary snt admwndz,beliseinteuedeumeonjeu,Бери-Сент-Эдмендс,Бері-Сент-Едмендс,باری سنت ادموندز,베리세인트에드먼즈', 52.2463000, 0.7111100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61074, 'Bury', 'Bury', 'Beri,Beris,Bury,bei li,beli,beri,bo li,bry,Бери,Бері,بری,ベリー,伯里,貝利,베리', 53.6000000, -2.3000000, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61075, 'Burwell', 'Burwell', '', 53.2930500, 0.0346300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61076, 'Burwell', 'Burwell', 'bwrwl,بورول', 52.2763200, 0.3273200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61077, 'Burwash', 'Burwash', '', 50.9975500, 0.3850400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61078, 'Burtonwood', 'Burtonwood', '', 53.4294800, -2.6585200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61079, 'Burton upon Trent', 'Burton upon Trent', 'Berton-apon-Trent,Bertonas prie Trento,Burton upon Trent,Burton-on-Trent,Burton-upon-Trent,Burtun upon Trent,bartwn apwn trnt,beoteon-eoponteulenteu,te lun he pan bo dun,Бертон-апон-Трент,Бъртън ъпон Трент,بارتون آپون ترنت,特倫河畔伯頓,버턴어폰트렌트', 52.8072800, -1.6426300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61080, 'Burton upon Stather', 'Burton upon Stather', 'Burton,Burton upon Stather', 53.6491100, -0.6845300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61081, 'Burton Pidsea', 'Burton Pidsea', '', 53.7632700, -0.1070300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61082, 'Burton on the Wolds', 'Burton on the Wolds', 'Burton,Burton on the Wolds', 52.7857400, -1.1298800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61083, 'Burton Latimer', 'Burton Latimer', 'Burton Latimer', 52.3636800, -0.6785300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61084, 'Burton Joyce', 'Burton Joyce', '', 52.9882500, -1.0340700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61085, 'Burton Constable', 'Burton Constable', '', 53.8166700, -0.2000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61086, 'Burton', 'Burton', 'Burton', 53.2666700, -0.5666700, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61087, 'Burton', 'Burton', 'Burton', 51.7155600, -4.9222200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61088, 'Burstwick', 'Burstwick', '', 53.7321100, -0.1395600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61089, 'Bursledon', 'Bursledon', '', 50.8865800, -1.3159600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61090, 'Burscough', 'Burscough', '', 53.5964000, -2.8397200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61091, 'Burry Port', 'Burry Port', 'Buri Port,Burry Port,Porth Tywyn,Бъри Порт', 51.6843500, -4.2468700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61092, 'Burrington', 'Burrington', '', 52.3500000, -2.8166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61093, 'Burrington', 'Burrington', '', 51.3288400, -2.7486800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61094, 'Burringham', 'Burringham', '', 53.5740200, -0.7395700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61095, 'Burntwood', 'Burntwood', 'barntwwd,بارنتوود', 52.6807500, -1.9275900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61096, 'Burntisland', 'Burntisland', 'Berntajlend,Burntajland,Burntisland,Eilean a Chroinn,Бернтайленд,Бърнтайланд', 56.0624800, -3.2317600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61097, 'Burnopfield', 'Burnopfield', 'Burnopfield', 54.9062400, -1.7248600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61098, 'Burnley', 'Burnley', 'Bernlei,Bernli,Bernlis,Burnley,Burnli,ban ni,banri,beonli,bo en li,brnly,Μπέρνλεϊ,Бернли,Бернлі,Бърнли,ברנלי,برنلی,バーンリー,伯恩利,般尼,번리', 53.8000000, -2.2333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61099, 'Burniston', 'Burniston', 'Burniston', 54.3238500, -0.4481300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61100, 'Burnham-on-Sea', 'Burnham-on-Sea', 'Burnham', 51.2386200, -2.9978000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61101, 'Burnham-on-Crouch', 'Burnham-on-Crouch', 'Burnham,Burnham-on-Crouch', 51.6327200, 0.8148800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61102, 'Burneside', 'Burneside', '', 54.3527100, -2.7615100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61103, 'Burley in Wharfedale', 'Burley in Wharfedale', 'Burley,Burley in Wharfedale', 53.9102000, -1.7579800, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61104, 'Burley', 'Burley', 'Burley,Burley-on-the-Hill', 52.6851200, -0.6960900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61105, 'Burley', 'Burley', 'Burley', 50.8280000, -1.6997700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61106, 'Burham', 'Burham', '', 51.3324300, 0.4783300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61107, 'Burgh le Marsh', 'Burgh le Marsh', '', 53.1615800, 0.2448400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61108, 'Burghead', 'Burghead', 'Am Broch,Burg Head,Burghead,Burgheid,The Broch', 57.7011300, -3.4899200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61109, 'Burgess Hill', 'Burgess Hill', 'Burgess Hill', 50.9584300, -0.1328700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61110, 'Burford', 'Burford', 'Beorgford,Burford,bafodo,beopeodeu,bo fu de,bwrfwrd,Бърфорд,بورفورد,バーフォード,伯福德,버퍼드', 51.8091500, -1.6362800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61111, 'Bures Saint Mary', 'Bures Saint Mary', 'Bures,Bures Saint Mary', 51.9724000, 0.7748800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61112, 'Burbage', 'Burbage', 'Burbage', 51.3518400, -1.6708700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61113, 'Buntingford', 'Buntingford', 'bantyngfwrd,بانتینگفورد', 51.9461200, -0.0184100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61114, 'Bungay', 'Bungay', 'bangy  safk,بانگی، سافک', 52.4543400, 1.4381800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61115, 'Bunbury', 'Bunbury', '', 53.1155900, -2.6515100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61116, 'Bulkington', 'Bulkington', '', 51.3236100, -2.0836100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61117, 'Bulford', 'Bulford', 'Bulford', 51.1893000, -1.7600900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61118, 'Builth Wells', 'Builth Wells', 'Bilt Uels,Builth,Builth Wells,Llanfair-ym-Muallt,Билт Уелс', 52.1494000, -3.4046900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61119, 'Bugthorpe', 'Bugthorpe', '', 54.0108200, -0.8226000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61120, 'Bugle', 'Bugle', '', 50.3957700, -4.7933400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61121, 'Bugbrooke', 'Bugbrooke', 'Bugbrooke', 52.2100600, -1.0130400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61122, 'Budleigh Salterton', 'Budleigh Salterton', 'Budleigh,Budleigh Salterton,bwdly saltrtwn,بودلی سالترتون', 50.6298300, -3.3218100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61123, 'Bude', 'Bude', 'B''jud,Bud,Porth Bud,Porthbud,Бьюд', 50.8243500, -4.5413000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61124, 'Bucknell', 'Bucknell', '', 52.3599700, -2.9506600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61125, 'Buckley', 'Buckley', 'Buckley,Bukli,Bwcle,Бъкли', 53.1666700, -3.0833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61126, 'Buckingham', 'Buckingham', 'Bakingem,Buckingham,Buckinghamia,bai jin han,bakyngham,Бакингем,باکینگهام,بکنگھم,白金漢', 51.9996800, -0.9877900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61127, 'Buckie', 'Buckie', 'Baki,Bucaidh,Buckie,Баки', 57.6757000, -2.9623800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61128, 'Buckhurst Hill', 'Buckhurst Hill', '', 51.6240900, 0.0326200, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61129, 'Buckhaven', 'Buckhaven', 'Buckhaven', 56.1714900, -3.0337700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61130, 'Buckfastleigh', 'Buckfastleigh', 'Buffestra,bakfstly,باکفستلی', 50.4813200, -3.7791300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61131, 'Buckden', 'Buckden', 'bwkdn,بوكدن', 52.2941500, -0.2491200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61132, 'Bubwith', 'Bubwith', '', 53.8190500, -0.9196800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61133, 'Brynmawr', 'Brynmawr', 'Brinmaur,Brinmavr,Bryn-mawr,Brynmawr,brynmwr,Бринмаур,Брінмавр,برینمور', 51.8000000, -3.1833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61134, 'Bryneglwys', 'Bryneglwys', '', 53.0166700, -3.2833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61135, 'Brynamman', 'Brynamman', 'Brynamman', 51.8000000, -3.8666700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61136, 'Bryn', 'Bryn', '', 51.6163900, -3.7116700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61137, 'Brymbo', 'Brymbo', 'Brymbo', 53.0666700, -3.0666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61138, 'Bruton', 'Bruton', 'Bruton,brwtwn  samrst,بروتون، سامرست', 51.1125000, -2.4527800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61139, 'Brundall', 'Brundall', '', 52.6242600, 1.4350900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61140, 'Broxburn', 'Broxburn', 'Broaxburn,Broksbern,Broksbernas,Broxburn i West Lothian,Srath Bhroc,braksbrn,Броксберн,براکسبرن', 55.9341500, -3.4713300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61141, 'Broxbourne', 'Broxbourne', '', 51.7471200, -0.0192300, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61142, 'Brownhills', 'Brownhills', 'Braunkhills,Brownhills,Браунхиллс', 52.6333300, -1.9333300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61143, 'Broughton Astley', 'Broughton Astley', 'Broughton Astley', 52.5278700, -1.2176800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61144, 'Broughton', 'Broughton', '', 53.5666700, -0.5500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61145, 'Broughton', 'Broughton', 'Broughton', 53.1630300, -2.9930900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61146, 'Broughton', 'Broughton', 'Broughton', 52.3733100, -0.7749300, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61147, 'Broughton', 'Broughton', '', 52.0503800, -0.6935100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61148, 'Broughshane', 'Broughshane', '', 54.8926000, -6.2089900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61149, 'Brough', 'Brough', '', 53.7286100, -0.5721500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61150, 'Brotton', 'Brotton', '', 54.5666100, -0.9392900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61151, 'Broseley', 'Broseley', 'Broseley,brwsly,brwzly,بروزلی,بروسلي', 52.6132100, -2.4826900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61152, 'Brora', 'Brora', 'Brora,Brura,Brùra,Brúra,bu luo la,布罗拉', 58.0098900, -3.8518200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61153, 'Broomfleet', 'Broomfleet', '', 53.7333300, -0.6666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61154, 'Brooke', 'Brooke', '', 52.6431700, -0.7463800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61155, 'Brooke', 'Brooke', 'Brooke', 52.5417500, 1.3707600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61156, 'Bromyard', 'Bromyard', 'Bromyard', 52.1901900, -2.5087500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61157, 'Bromsgrove', 'Bromsgrove', 'Bromsgrovas,beulomseugeulobeu,brwmzgrw,برومزگرو,브롬스그로브', 52.3357400, -2.0598300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61158, 'Brompton', 'Brompton', 'Brompton', 54.3601500, -1.4242200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61159, 'Bromley', 'Bromley', 'Bromley,Bromley keruelet,Bromley kerület,Bromli,beulomli,bromali,brwmly,bu luo mu li,buromuri,Бромли,Бромлі,بروملی,ब्रॉमली,ブロムリー,布羅姆利,브롬리', 51.4060600, 0.0151900, 'GB', '2015-10-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61160, 'Bromham', 'Bromham', '', 52.1450800, -0.5290600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61161, 'Bromfield', 'Bromfield', '', 52.3833300, -2.7666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61162, 'Bromborough', 'Bromborough', 'Brambourg,Bromborough,Broombro', 53.3485000, -2.9793500, 'GB', '2013-10-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61163, 'Brockley', 'Brockley', '', 51.4000000, -2.7666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61164, 'Brockhampton', 'Brockhampton', '', 51.9833300, -2.5833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61165, 'Brockenhurst', 'Brockenhurst', 'Brockenhurst', 50.8193600, -1.5730300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61166, 'Broadway', 'Broadway', 'Broadway,burodou~ei,ブロードウェイ', 52.0382500, -1.8607900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61167, 'Broadwater', 'Broadwater', '', 50.8288700, -0.3759400, 'GB', '2014-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61168, 'Broadstone', 'Broadstone', '', 50.7571700, -1.9940600, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61169, 'Broadstairs', 'Broadstairs', 'Broadstairs,Brodstejrz,Brodsters,Бродстейрз,Бродстерс', 51.3590800, 1.4393800, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61170, 'Broad Blunsdon', 'Broad Blunsdon', '', 51.6133900, -1.7787000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61171, 'Brixworth', 'Brixworth', 'Brixworth', 52.3291200, -0.9035000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61172, 'Brixton', 'Brixton', 'Brixton', 50.3500000, -4.0333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61173, 'Brixham', 'Brixham', 'Briksam,Brixham,bryksham,bu li ke se mu,Бриксам,بریکسهام,布里克瑟姆', 50.3943100, -3.5158500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61174, 'Briton Ferry', 'Briton Ferry', 'Briton Feris,Briton Ferry,Britun Feri,Llansawel,Бритън Фери', 51.6310600, -3.8189800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61175, 'Briston', 'Briston', 'Briston', 52.8536900, 1.0589900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61176, 'Bristol', 'Bristol', 'BRS,Bricgstōƿ,Briosto,Briostó,Bristo,Bristol,Bristol'',Bristole,Bristolis,Bristolium,Bristolo,Briston,Bristul,Bristullu,Bristón,Bryste,Brístol,Gorad Brystal'',beuliseuteul,bris txl,bristala,brystwl,bu li si tuo er,burisutoru,Μπρίστολ,Бристол,Бристоль,Бристъл,Горад Брысталь,Բրիստոլ,בריסטאל,בריסטול,برسٹل نگر,بريستول,بریستول,ब्रिस्टल,ಬ್ರಿಸ್ಟಲ್‌,บริสตอล,ბრისტოლი,ブリストル,布里斯托尔,브리스틀', 51.4552300, -2.5966500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61177, 'Brinscall', 'Brinscall', '', 53.6890000, -2.5720800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61178, 'Brinklow', 'Brinklow', 'Brinklow', 52.4109100, -1.3640000, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61179, 'Brimscombe', 'Brimscombe', '', 51.7197300, -2.1855300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61180, 'Brill', 'Brill', 'Brill,bryl,بريل', 51.8166700, -1.0500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61181, 'Brigstock', 'Brigstock', '', 52.4577500, -0.6083400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61182, 'Brignall', 'Brignall', 'Brignall', 54.5053400, -1.8889600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61183, 'Brighton', 'Brighton', 'BSH,Braiton,Braitona,Braitonas,Brajton,Brajtono,Brajtun,Brighton,Brightonia,Gorad Brajtan,bai li dun,beulaiteon,bir tan,bra''itana,brayatana,braytwn,bryytwn,bu lai dun,buraiton,Μπράιτον,Брайтон,Брайтън,Брајтон,Горад Брайтан,Բրայթոն,ברייטון,برائٹن,برايتون,برایتون,ब्रायटन,ব্রাইটন,ไบรตัน,ბრაიტონი,ブライトン,布赖顿,白禮頓,브라이턴', 50.8283800, -0.1394700, 'GB', '2017-06-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61184, 'Brightlingsea', 'Brightlingsea', 'braytlyngsy,برایتلینگسی', 51.8116400, 1.0233600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61185, 'Brighstone', 'Brighstone', 'Brighstone,Brightstone', 50.6426300, -1.3947900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61186, 'Brighouse', 'Brighouse', 'Brigaus,Бригаус,بریج‌هاوس', 53.7032200, -1.7842800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61187, 'Brigg', 'Brigg', 'Brigg i North Lincolnshire,bryj,بریج', 53.5520100, -0.4921400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61188, 'Brierley Hill', 'Brierley Hill', 'Brierley Hill', 52.4817300, -2.1213900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61189, 'Brierfield', 'Brierfield', '', 53.8246800, -2.2341500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61190, 'Bridport', 'Bridport', 'Bridport,brydpwrt,Бридпорт,Брідпорт,بریدپورت', 50.7338000, -2.7583100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61191, 'Bridlington', 'Bridlington', 'brydlyngtwn,بریدلینگتون', 54.0830600, -0.1919200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61192, 'Bridgwater', 'Bridgwater', 'Bridgewater,Bridgwater,Bridzhuoter,Bridzhuotur,Bruga Walteri,UBW,beulijiwoteo,Бриджуотер,Бриджуотър,برج واٹر، سومرسیٹ,بریج‌واتر,ბრიჯუოტერი,브리지워터', 51.1283700, -3.0035600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61193, 'Bridgnorth', 'Bridgnorth', 'Bridgnorth,Cwatbrycg,بریج‌نورث', 52.5366100, -2.4203300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61194, 'Bridge of Weir', 'Bridge of Weir', 'Bridge of Weir', 55.8558200, -4.5789400, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61195, 'Bridge of Earn', 'Bridge of Earn', 'Bridge of Earn', 56.3484200, -3.4065000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61196, 'Bridge of Allan', 'Bridge of Allan', 'Bridge of Allan', 56.1540200, -3.9463100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61197, 'Bridgend', 'Bridgend', 'Bridgend,Bridgend County Borough,Bridzendas,Bridzhend,Bridžendas,Pen-y-bont ar Ogwr,beulijendeu,burijendo,Бридженд,ブリジェンド,브리젠드', 51.5058300, -3.5772200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61198, 'Bridge', 'Bridge', '', 51.2451300, 1.1264000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61199, 'Brewood', 'Brewood', 'Brewood,Brewood and Coven', 52.6771200, -2.1741400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61200, 'Brentwood', 'Brentwood', 'Brentud,Brentvud,Brentwood,Brentwood i Essex,beulenteuudeu,brntwwd  asks,bu lun te wu de,Брентвуд,Брентуд,برنتوود، اسکس,برینٹووڈ، ایسیکس,布倫特伍德,브렌트우드', 51.6212700, 0.3055600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61201, 'Brent Knoll', 'Brent Knoll', 'Brent Knoll', 51.2521900, -2.9574400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61202, 'Brentford', 'Brentford', 'Brentford,beulenteupeodeu,bin fu te,brentafarda,brentapharda,brntfwrd,burentofodo,Брентфорд,برنتفورد,برینٹفرڈ,ब्रेंटफर्ड,ब्रेंटफ़र्ड,ブレントフォード,賓福特,브렌트퍼드', 51.4861900, -0.3083000, 'GB', '2012-03-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61203, 'Brenchley', 'Brenchley', '', 51.1514100, 0.3982500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61204, 'Bremhill', 'Bremhill', 'Bremhill', 51.4566700, -2.0302800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61205, 'Bredon', 'Bredon', '', 52.0300800, -2.1167100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61206, 'Bredbury', 'Bredbury', 'Bredbury', 53.4166700, -2.1166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61207, 'Brecon', 'Brecon', 'Aberhonddu,Brecknock,Brecon,Brekon,Brekun,Brycheiniog,HMS Brecon,beulekon,brykwn,bu lei ken,Брекон,Брекън,بريكون,布雷肯,브레콘', 51.9461200, -3.3888700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61208, 'Brechin', 'Brechin', 'Brechin,Breichinn,Brichinas,Brikhin,Брихин', 56.7299300, -2.6572900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61209, 'Bream', 'Bream', 'Bream', 51.7482200, -2.5774700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61210, 'Brayton', 'Brayton', 'Brajton,Brayton,Брайтон', 53.7651000, -1.0892100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61211, 'Bray', 'Bray', 'bray,براي', 51.5034000, -0.6876800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61212, 'Braunton', 'Braunton', 'Brantona,Braunton,Браунтон', 51.1084700, -4.1613100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61213, 'Braunston', 'Braunston', 'Braunston', 52.2897900, -1.2026600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61214, 'Bratton', 'Bratton', '', 51.2705600, -2.1244400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61215, 'Brantingham', 'Brantingham', '', 53.7518100, -0.5770400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61216, 'Branston', 'Branston', 'Branston', 53.1954400, -0.4748200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61217, 'Bransgore', 'Bransgore', 'Bransgore', 50.7815300, -1.7377100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61218, 'Bransford', 'Bransford', 'Bransford', 52.1722700, -2.3015900, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61219, 'Brandon', 'Brandon', 'Brandon', 54.7500000, -1.6166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61220, 'Brandon', 'Brandon', '', 52.3843200, -1.3996000, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61221, 'Brandesburton', 'Brandesburton', 'Brandesburton,Brandsburton', 53.9111000, -0.3012200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61222, 'Brampton', 'Brampton', 'Brampton', 54.9500000, -2.7333300, 'GB', '2012-05-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61223, 'Brampton', 'Brampton', 'Brampton,Brauntone', 52.3203900, -0.2200700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61224, 'Bramley', 'Bramley', '', 53.4166700, -1.2666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61225, 'Bramley', 'Bramley', 'Bramley', 51.3267700, -1.0593800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61226, 'Bramley', 'Bramley', '', 51.1945100, -0.5592700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61227, 'Bramhope', 'Bramhope', 'Bramhope', 53.8848900, -1.6164100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61228, 'Bramham', 'Bramham', '', 53.8811800, -1.3545200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61229, 'Bramhall', 'Bramhall', '', 53.3580100, -2.1653900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61230, 'Bramford', 'Bramford', 'Bramford', 52.0763100, 1.0968700, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61231, 'Braintree', 'Braintree', 'Braintree,Braintree i Essex,Brejntrij,WXF,brayntry  asks,Брейнтрий,براینتری، اسکس', 51.8781900, 0.5529200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61232, 'Bradwell', 'Bradwell', '', 52.0485700, -0.7877100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61233, 'Bradninch', 'Bradninch', 'Bradninch', 50.8249100, -3.4246500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61234, 'Bradley', 'Bradley', '', 53.5500000, -0.1333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61235, 'Brading', 'Brading', 'Brading,bradyng,برادینگ', 50.6799000, -1.1457100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61236, 'Bradford-on-Avon', 'Bradford-on-Avon', 'Bradford-on-Avon', 51.3477200, -2.2506500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61237, 'Bradford', 'Bradford', 'BRF,Bradanford,Bradford,Bradfordas,Brantfornt,Bredford,Bredforda,Brehdford,Brədford,Gorad Brehdfard,ba la fu te,beulaedeupeodeu,bradfwrd,brdpwrd,bredpordi,bu la de fu de,buraddofodo,Μπράντφορντ,Брадфорд,Бредфорд,Брэдфорд,Горад Брэдфард,Բրեդֆորդ,בראדפארד,ברדפורד,برادفورد,بریڈفورڈ,ბრედფორდი,ብራድፎርድ,ブラッドフォード,巴拉福特,布拉德福德,브래드퍼드', 53.7939100, -1.7520600, 'GB', '2013-05-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61238, 'Bradfield', 'Bradfield', '', 53.4166700, -1.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61239, 'Bradfield', 'Bradfield', '', 51.4491400, -1.1308200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61240, 'Bracknell', 'Bracknell', 'Bracknell,Braknel,braknl,bu la ke nei er,Бракнел,براکنل,布拉克內爾', 51.4136300, -0.7505400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61241, 'Brackley', 'Brackley', 'Brackley,brakly,براکلی', 52.0333300, -1.1500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61242, 'Bozeat', 'Bozeat', 'Bozeat', 52.2227000, -0.6732600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61243, 'Boyton', 'Boyton', '', 50.7000000, -4.3833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61244, 'Boynton', 'Boynton', '', 54.0974600, -0.2647900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61245, 'Boxted', 'Boxted', 'Boxted', 51.9487800, 0.9100200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61246, 'Boxley', 'Boxley', '', 51.3023900, 0.5421900, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61247, 'Boxgrove', 'Boxgrove', 'Boxgrove', 50.8588400, -0.7136000, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61248, 'Box', 'Box', 'Box,bokkusu,ボックス', 51.4147200, -2.2455600, 'GB', '2013-02-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61249, 'Bow Street', 'Bow Street', '', 52.4421300, -4.0278300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61250, 'Bowes', 'Bowes', '', 54.5164000, -2.0159900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61251, 'Bower Chalke', 'Bower Chalke', '', 51.0000000, -1.9666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61252, 'Bowdon', 'Bowdon', '', 53.3764400, -2.3653200, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61253, 'Bow Brickhill', 'Bow Brickhill', 'Bow Brickhill', 52.0028000, -0.6806400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61254, 'Bow', 'Bow', 'Bow,Nymet Tracey', 50.8000000, -3.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61255, 'Bovington Camp', 'Bovington Camp', '', 50.6978200, -2.2350600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61256, 'Bovingdon', 'Bovingdon', 'Bovingdon', 51.7231200, -0.5367000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61257, 'Bovey Tracey', 'Bovey Tracey', 'bwwy trysy,بووی تریسی', 50.5925900, -3.6754300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61258, 'Bourton on the Water', 'Bourton on the Water', 'Bourton on the Water', 51.8858400, -1.7549200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61259, 'Bourton', 'Bourton', 'Bourton', 51.0744400, -2.3277800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61260, 'Bournemouth', 'Bournemouth', 'BOH,Bornemouth,Bornmut,Bornmutas,Bournemouth,bo en mao si,bonmasu,bonmeoseu,bor nmath,bornmuti,bwrnmwth,Борнмут,Борнмът,بورنموث,বোর্ন্‌মাথ,โบร์นมัท,ბორნმუთი,ボーンマス,伯恩茅斯,본머스', 50.7204800, -1.8795000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61261, 'Bourne End', 'Bourne End', 'bwrn and,بورن اند', 51.5762200, -0.7129100, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61262, 'Bourne', 'Bourne', 'Bourn,Bourne,Bourne i Lincolnshire,بورن، لینکلن‌شر', 52.7666700, -0.3833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61263, 'Boughton', 'Boughton', 'Boughton', 53.2000000, -0.9833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61264, 'Bottisham', 'Bottisham', 'Bottisham', 52.2228000, 0.2587800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61265, 'Bottesford', 'Bottesford', '', 53.5500000, -0.6500000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61266, 'Bottesford', 'Bottesford', 'Bottesford,Bottesford i Leicestershire', 52.9413100, -0.8006000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61267, 'Botley', 'Botley', 'Botley', 50.9143300, -1.2698400, 'GB', '2011-02-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61268, 'Bothwell', 'Bothwell', 'Bosuehll,Bothwell,bwtwl,Босуэлл,بوتول', 55.8027200, -4.0683500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61269, 'Botesdale', 'Botesdale', 'Botesdale', 52.3421600, 1.0040500, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61270, 'Boston Spa', 'Boston Spa', '', 53.9041900, -1.3452300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61271, 'Boston', 'Boston', 'Boston,Boston i England,Bostonas,boseuteon,bosuton,bwstn,Бостон,بوستون، لینکلن‌شر,بوسطن,ボストン,보스턴', 52.9763300, -0.0266400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61272, 'Bosham', 'Bosham', 'Bosham', 50.8308800, -0.8538400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61273, 'Borth', 'Borth', 'Borth,Morfa Borth', 52.4888700, -4.0503900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61274, 'Borrowash', 'Borrowash', '', 52.9067300, -1.3841100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61275, 'Borough Green', 'Borough Green', '', 51.2915800, 0.3047800, 'GB', '2011-02-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61276, 'Boroughbridge', 'Boroughbridge', 'bwrwbryj,بوروبریج', 54.0895000, -1.4011000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61277, 'Borehamwood', 'Borehamwood', 'Borehamwood,bo lei mu wu de,博勒姆伍德', 51.6546800, -0.2776200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61278, 'Boreham', 'Boreham', '', 51.7595500, 0.5411600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61279, 'Boreham', 'Boreham', '', 51.1994400, -2.1655600, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61280, 'Bootle', 'Bootle', 'Bootle,Butl,Butlis,bu te er,bwtl  anglstan,Бутл,بوتل، انگلستان,布特爾', 53.4666700, -3.0166700, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61281, 'Boosbeck', 'Boosbeck', 'Boosbeck', 54.5426500, -0.9813900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61282, 'Bonnyrigg', 'Bonnyrigg', 'Bonnirigg,Боннірігг', 55.8732900, -3.1051000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61283, 'Bonnybridge', 'Bonnybridge', 'Bonnybridge', 56.0015200, -3.8886000, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61284, 'Bonhill', 'Bonhill', 'Bonhill', 55.9794400, -4.5638000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61285, 'Bo’ness', 'Bo''ness', 'Bo''ness,Borrowstounness,Bo’ness', 56.0166700, -3.6166700, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61286, 'Bolton upon Dearne', 'Bolton upon Dearne', 'Bolton upon Dearne', 53.5166700, -1.3166700, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61287, 'Bolton le Sands', 'Bolton le Sands', 'Bolton le Sands', 54.0963200, -2.8001700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61288, 'Bolton', 'Bolton', 'Bolton,Boltonas,Boltonium,Boltun,bao dun,bo er dun,bol tan,bolteon,boruton,bwltn,bwltwn,Болтон,Болтън,Բոլթոն,بولتن,بولتون,โบลตัน,ბოლტონი,ボルトン,保頓,博尔顿,볼턴', 53.5833300, -2.4333300, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61289, 'Bolsover', 'Bolsover', '', 53.2284600, -1.2920400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61290, 'Bollington', 'Bollington', 'bwlyngtwn,بولینگتون', 53.2944600, -2.1096300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61291, 'The Boldons', 'The Boldons', 'Boldon,The Boldons', 54.9426000, -1.4534900, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61292, 'Bognor Regis', 'Bognor Regis', 'Bognor,Bognor Regis,Bognor Ridzis,Bognor Ridzisas,Bognor Ridžisas,bagnwr rjys,bo ge nuo li ji si,Богнор Риџис,باگنور رجیس,博格諾里吉斯', 50.7820600, -0.6797800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61293, 'Bodmin', 'Bodmin', 'Bodamina,Bodmin,Bosvenegh,bo de ming,bwdmyn,Бодмин,بودمین,博德明', 50.4715100, -4.7243000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61294, 'Bodenham', 'Bodenham', 'Bodenham', 52.1500000, -2.6833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61295, 'Bodelwyddan', 'Bodelwyddan', 'Bodelwyddan,Bodlewyddan', 53.2682700, -3.5007800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61296, 'Bodedern', 'Bodedern', 'Bodedera,Bodedern', 53.2923200, -4.5030300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61297, 'Boddam', 'Boddam', 'Boddam', 57.4707600, -1.7800900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61298, 'Blyton', 'Blyton', '', 53.4438400, -0.7175300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61299, 'Blyth', 'Blyth', 'Blit,Blyth,Blyth i Northumberland,Blythe,Блит,بلایث، نورث‌آمبرلند', 55.1270800, -1.5085600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61300, 'Bluntisham', 'Bluntisham', 'Bluntisham', 52.3547900, 0.0085400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61301, 'Blunham', 'Blunham', '', 52.1469500, -0.3217800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61302, 'Bloxwich', 'Bloxwich', 'Bloxwich', 52.6180600, -2.0043100, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61303, 'Bloxham', 'Bloxham', '', 52.0203900, -1.3732100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61304, 'Blockley', 'Blockley', 'Blockley', 52.0122000, -1.7626800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61305, 'Blisworth', 'Blisworth', '', 52.1749800, -0.9413100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61306, 'Blindley Heath', 'Blindley Heath', '', 51.1934400, -0.0511600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61307, 'Blidworth', 'Blidworth', '', 53.0984900, -1.1168900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61308, 'Blewbury', 'Blewbury', 'Blewbury', 51.5688000, -1.2326100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61309, 'Bletchley', 'Bletchley', 'Blechli,blchly,bu lai qi li,Блечли,بلچلی,布莱奇利', 51.9933400, -0.7347100, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61310, 'Bletchingley', 'Bletchingley', '', 51.2405900, -0.1003800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61311, 'Blean', 'Blean', '', 51.3067900, 1.0430100, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61312, 'Bleadon', 'Bleadon', '', 51.3086100, -2.9475000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61313, 'Blaydon-on-Tyne', 'Blaydon-on-Tyne', 'Blaydon', 54.9646100, -1.7139200, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61314, 'Blandford Forum', 'Blandford Forum', 'Blandford,Blandford Forum,Blandford-Forum,blndfwrd fwrm,Бландфорд Форъм,Бландфорд-Форум,بلندفورد فورم', 50.8607300, -2.1617400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61315, 'Blakemere', 'Blakemere', 'Blakemere', 52.0652900, -2.9342500, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61316, 'Blairgowrie', 'Blairgowrie', '', 56.5915700, -3.3404500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61317, 'Blagdon', 'Blagdon', '', 51.3268800, -2.7173100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61318, 'Blaenavon', 'Blaenavon', '', 51.7740200, -3.0853700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61319, 'Blaenau-Ffestiniog', 'Blaenau-Ffestiniog', 'Blaenau Festiniog,Blaenau-Ffestiniog', 52.9946400, -3.9369700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61320, 'Blackwood', 'Blackwood', 'Blackwood', 55.6666700, -3.9166700, 'GB', '2014-04-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61321, 'Blackwell', 'Blackwell', 'Blackwell', 53.1166700, -1.3333300, 'GB', '2012-08-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61322, 'Blackrod', 'Blackrod', 'blkrwd,بلکرود', 53.5922900, -2.5802600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61323, 'Blackpool', 'Blackpool', 'BLK,Blackpool,Blakpul,Blakpulas,Blehkpul,Blekpul,Bləkpul,beullaegpul,blakbwl,blyakapula,burakkupuru,hei tan,Блакпул,Блекпул,Блэкпул,بلاكبول,بلک‌پول,ব্ল্যাকপুল,แบล็กพูล,ბლეკპული,ブラックプール,黑潭,블랙풀', 53.8166700, -3.0500000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61324, 'Black Notley', 'Black Notley', '', 51.8530100, 0.5684600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61325, 'Blackburn', 'Blackburn', 'Blackburn', 57.2037600, -2.2884200, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61326, 'Blackburn', 'Blackburn', 'Blackburn', 55.8666700, -3.6333300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61327, 'Blackburn', 'Blackburn', 'Blackburn,Blakbernas,Blakboern,Blakbörn,Blehkbern,Blekbern,Blekburn,beullaegbeon,blk‌brn,blqbrn,bu lai ke ben,bu li ban,burakkuban,Блекберн,Блекбърн,Блэкберн,Բլեկբերն,בלקברן,بلک‌برن,แบล็กเบิร์น,ブラックバーン,布力般,布莱克本,布萊克本,블랙번', 53.7500000, -2.4833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61328, 'Blaby', 'Blaby', 'Blaby', 52.5757700, -1.1640300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61329, 'Bitton', 'Bitton', '', 51.4247900, -2.4596500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61330, 'Bishton', 'Bishton', 'Bishton', 51.5819400, -2.8783300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61331, 'Bishopton', 'Bishopton', '', 55.9096900, -4.5056000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61332, 'Bishopton', 'Bishopton', '', 54.5833300, -1.4333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61333, 'Bishopthorpe', 'Bishopthorpe', 'Bishopthorne,Bishopthorpe', 53.9191000, -1.0991500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61334, 'Bishops Waltham', 'Bishops Waltham', 'Bishop''s Waltham,Bishops Waltham,byshaps waltam,بیشاپس والتام', 50.9559500, -1.2147600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61335, 'Bishopstrow', 'Bishopstrow', 'Bishopstrow', 51.1930600, -2.1552800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61336, 'Bishopstone', 'Bishopstone', '', 51.5513000, -1.6470100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61337, 'Bishopstone', 'Bishopstone', '', 51.0302800, -1.9026900, 'GB', '2012-05-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61338, 'Bishopston', 'Bishopston', 'Bishopston', 51.5775000, -4.0480600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61339, 'Bishopstoke', 'Bishopstoke', '', 50.9664300, -1.3283200, 'GB', '2011-02-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61340, 'Bishopsteignton', 'Bishopsteignton', 'Bishopsteignton', 50.5519300, -3.5385200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61341, 'Bishops Stortford', 'Bishops Stortford', 'Bishop''s Stortford,Bishops Stortford,Bishops Strotford,Bishop’s Stortford,Bisop''s Stortfornt,bi xiao pu si tuo fu de,byshaps astwrtfwrd,Μπίσοπς Στόρτφορντ,بیشاپس استورتفورد,畢曉普斯托福德', 51.8711300, 0.1586800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61342, 'Bishops Lydeard', 'Bishops Lydeard', 'Bishops Lydeard', 51.0591700, -3.1877800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61343, 'Bishops Cleeve', 'Bishops Cleeve', 'Bishop''s Cleeve', 51.9474900, -2.0627700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61344, 'Bishop''s Castle', 'Bishop''s Castle', 'Bishop''s Castle,Bishops Castle', 52.4920800, -3.0021000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61345, 'Bishop Middleham', 'Bishop Middleham', 'Bishop Middleham', 54.6777800, -1.4882600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61346, 'Bishopbriggs', 'Bishopbriggs', 'Bishopbriggs,Bisopbriqqs,Bişopbriqqs,Coille Dobhair,byshab bryghz,byshap brygz,Бишопбриггс,Бішопбріггс,بيشاب بريغز,بیشاپ بریگز', 55.9066900, -4.2186900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61347, 'Bishop Auckland', 'Bishop Auckland', 'Bishop Auckland,Bishop-Oklend,byshap awklnd,Бишоп-Окленд,بیشاپ اوکلند', 54.6555400, -1.6770600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61348, 'Bisham', 'Bisham', '', 51.5610400, -0.7778800, 'GB', '2015-05-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61349, 'Birtley', 'Birtley', '', 55.0833300, -2.1833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61350, 'Birmingham', 'Birmingham', 'BHX,Birmin''gxam,Birmingam,Birmingamas,Birmingem,Birmingema,Birmingham,Birminghamia,Birminghem,Gorad Birmingem,Mpermincham,bamingamu,barming''hyam,barmingahama,barmingahema,barmingham,barminghama,beoming-eom,birmingemi,bo ming han,bo ming han shi,brmngm,brmynghham,byrmngam,parminkam,Μπέρμιγχαμ,Бирмингам,Бирмингем,Бірмінгем,Горад Бірмінгем,Բիրմինգհեմ,בירמינגהאם,ברמינגהאם,برمنگم,برمينغهام,بیرمنگام,बर्मिंगहॅम,बर्मिंघम,बर्मिङ्घम्,બર્મિંગહામ,பர்மிங்காம்,బర్మింగ్‌హామ్,ಬರ್ಮಿಂಗ್ಹ್ಯಾಮ್,เบอร์มิงแฮม,ბირმინგემი,በርሚንግሃም,バーミンガム,伯明翰,伯明翰市,버밍엄', 52.4814200, -1.8998300, 'GB', '2012-09-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61351, 'Birkenhead', 'Birkenhead', 'Berkenged,Berkenhedas,Berkenkhed,Birkenhead,Birkenkhed,Kione Beih,Penbedw,bakenheddo,beokeonhedeu,bexr khen hed,Беркенгед,Беркенхед,Биркенхед,برکن‌هد,ബ്രിക്കൻഹെഡ്,เบอร์เคนเฮด,バーケンヘッド,버컨헤드', 53.3933700, -3.0147900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61352, 'Birdwell', 'Birdwell', '', 53.5139800, -1.4792900, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61353, 'Birdsall', 'Birdsall', 'Birdsall', 54.0849200, -0.7512800, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61354, 'Birdham', 'Birdham', 'Birdham', 50.7960600, -0.8306700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61355, 'Bircotes', 'Bircotes', 'Bircotes', 53.4193300, -1.0490500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61356, 'Birchington-on-Sea', 'Birchington-on-Sea', 'Birchington', 51.3757500, 1.3048000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61357, 'Bingley', 'Bingley', 'Bingli,byngly,Бингли,بنگلے,بینگلی', 53.8486100, -1.8385700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61358, 'Bingham', 'Bingham', 'Bingham i Nottinghamshire,بنگہم، ناٹنگھم شائر,بینگهام، ناتینگهام‌شر', 52.9497800, -0.9590700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61359, 'Binfield', 'Binfield', 'bynfyld,بينفيلد', 51.4315900, -0.7881000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61360, 'Bilston', 'Bilston', 'Bilston,bylstwn,بیلستون', 52.5656800, -2.0736700, 'GB', '2016-04-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61361, 'Bilsthorpe', 'Bilsthorpe', 'Bilsthorpe', 53.1402400, -1.0339200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61362, 'Billingshurst', 'Billingshurst', '', 51.0231200, -0.4535900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61363, 'Billinghay', 'Billinghay', 'Billinghay', 53.0795900, -0.2768900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61364, 'Billingham', 'Billingham', 'Bilincham,Bilingam,Billingem,Billingham,Billingham-on-Tees,bi lin han mu,bylyngam,Μπίλιγχαμ,Билингам,Биллингем,بیلینگام,比林漢姆', 54.5888100, -1.2903400, 'GB', '2013-08-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61365, 'Billinge', 'Billinge', '', 53.4979500, -2.7081000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61366, 'Billingborough', 'Billingborough', 'Billingborough', 52.8938400, -0.3418600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61367, 'Billericay', 'Billericay', 'Billericay,Billerikej,bylrykay,Биллерикей,بیلریکای', 51.6286700, 0.4196300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61368, 'Bildeston', 'Bildeston', 'Bildeston', 52.1065800, 0.9091600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61369, 'Biggleswade', 'Biggleswade', 'byglswyd,بیگلسوید', 52.0865200, -0.2649300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61370, 'Biggin Hill', 'Biggin Hill', '', 51.3132900, 0.0343300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61371, 'Biggar', 'Biggar', 'Bigear,Biggar', 55.6229700, -3.5245500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61372, 'Bidford-on-Avon', 'Bidford-on-Avon', 'Bidford,Bidford-on-Avon', 52.1696400, -1.8595500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61373, 'Bideford', 'Bideford', 'Bajdford,Bediforda,Bideford,bydfwrd,Байдфорд,بیدفورد', 51.0167800, -4.2083200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61374, 'Biddulph', 'Biddulph', 'bydwlf,بیدولف', 53.1172400, -2.1758400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61375, 'Biddestone', 'Biddestone', 'Biddestone,Biddlestone', 51.4608300, -2.1983300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61376, 'Biddenham', 'Biddenham', '', 52.1384700, -0.5068700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61377, 'Biddenden', 'Biddenden', 'Biddenden', 51.1148900, 0.6381900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61378, 'Bicton', 'Bicton', '', 52.7282900, -2.8164900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61379, 'Bicknacre', 'Bicknacre', 'Bickacre,Bicknacre', 51.6940300, 0.5851900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61380, 'Bickley', 'Bickley', '', 53.0333300, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61381, 'Bickenhill', 'Bickenhill', 'Bickenhill', 52.4397400, -1.7254500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61382, 'Bicester', 'Bicester', 'bysstr,بیسستر,بیسسٹر', 51.8999800, -1.1535700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61383, 'Bexleyheath', 'Bexleyheath', 'begseullihiseu,beksalihitha,بیکزلیہیتھ,बेक्सलीहीथ,벡슬리히스', 51.4629100, 0.1394300, 'GB', '2011-02-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61384, 'Bexley', 'Bexley', 'Bexley,Bexley keruelet,Bexley kerület,London Borough of Bexley,Londonska opshtina Beksli,bksly,bykzly  lndn,Лондонска општина Бексли,بکسلی,بیکزلی، لندن', 51.4416200, 0.1486600, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61385, 'Bexhill-on-Sea', 'Bexhill-on-Sea', 'Bexhill,Bexhill-on-Sea', 50.8502300, 0.4709500, 'GB', '2015-04-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61386, 'Bewdley', 'Bewdley', 'Bewdley,bi you de li,bwdly,بودلی,比尤德利', 52.3757000, -2.3183300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61387, 'Beverley', 'Beverley', 'Beverley,Bevurli,bebeolli,bei fu li,bwrly,Бевърли,بورلی,貝弗利,베벌리', 53.8458700, -0.4233200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61388, 'Betws-y-Coed', 'Betws-y-Coed', 'Betws-y-Coed', 53.0938200, -3.8066800, 'GB', '2015-06-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61389, 'Betws', 'Betws', 'Bettws,Betws', 51.5691700, -3.5883300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61390, 'Betley', 'Betley', '', 53.0343900, -2.3686500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61391, 'Bethesda', 'Bethesda', 'Bethesda', 53.1815000, -4.0582800, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61392, 'Berwick-Upon-Tweed', 'Berwick-Upon-Tweed', 'Bervik-apon-Tvid,Berwick,Berwick on Tweed,Berwick-Upon-Tweed,Berwick-upon-Tweed,Бервик-апон-Твид', 55.7653600, -2.0118600, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61393, 'Berrington', 'Berrington', '', 52.6500000, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61394, 'Berkswell', 'Berkswell', 'Berkeswell,Berkswell', 52.4090200, -1.6422000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61395, 'Berkhamsted', 'Berkhamsted', 'Beorhdanstaedae,Beorhðanstædæ,Berkhampstead,Berkhamstead,Berkhamsted,Berkkhemsted,Berko,Burkkhamsted,bo ke han si de,brkmstd,Беркхемстед,Бъркхамстед,برکمستد,伯克翰斯德', 51.7604000, -0.5652800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61396, 'Berkeley', 'Berkeley', 'Berkeley,Berkli,brkly  glastrshr,Беркли,برکلی، گلاسترشر', 51.6911100, -2.4591700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61397, 'Bere Regis', 'Bere Regis', 'Bere Regis', 50.7537100, -2.2155300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61398, 'Bere Alston', 'Bere Alston', 'Bere Alston', 50.4823300, -4.1903400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61399, 'Bentley', 'Bentley', 'Bentley', 53.5333300, -1.1500000, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61400, 'Benson', 'Benson', 'BEX', 51.6207300, -1.1097900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61401, 'Bempton', 'Bempton', '', 54.1303600, -0.1785300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61402, 'Bembridge', 'Bembridge', 'BBP,Bembridzh,Бембридж', 50.6863400, -1.0827500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61403, 'Belvedere', 'Belvedere', 'Belvedere', 51.4911400, 0.1513600, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61404, 'Belton', 'Belton', '', 53.5500000, -0.8166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61405, 'Belper', 'Belper', 'Belper,Belpur,blpr,Белпер,Белпър,בלפר', 53.0233000, -1.4811900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61406, 'Bellshill', 'Bellshill', 'Bellshill', 55.8166700, -4.0166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61407, 'Bellingham', 'Bellingham', 'Bellingham', 55.1446400, -2.2538300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61408, 'Bellaghy', 'Bellaghy', '', 54.8087000, -6.5191800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61409, 'Belford', 'Belford', 'Belford', 55.6000000, -1.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61410, 'Belfast', 'Belfast', 'BFS,Beal Feirste,Beeal Feirshtey,Belfast,Belfast City,Belfasta,Belfastas,Belfasto,Belfastum,Belffast,Belfāsta,Belpas,Beul-Feirste,Bèlfast,Béal Feirste,Bélfast,Gorad Belfast,Mpelphast,baelpaseuteu,bei er fa si te,belaphasta,belfast,belpaseuteu,berufasuto,blfast,pelpast,Μπέλφαστ,Белфаст,Горад Белфаст,Բելֆաստ,בלפאסט,בעלפאסט,بلفاست,بیلفاسٹ,बेलफास्ट,বেলফাস্ট,பெல்பாஸ்ட்,ಬೆಲ್‌ಫಾಸ್ಟ್‌,เบลฟัสต์,ဗဲလဖတ်မြို့,ბელფასტი,ベルファスト,貝爾法斯特,贝尔法斯特,밸파스트,벨파스트', 54.5968200, -5.9254100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61411, 'Belbroughton', 'Belbroughton', 'Belbroughton', 52.3917700, -2.1188400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61412, 'Beith', 'Beith', 'Beithe', 55.7492300, -4.6368000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61413, 'Beighton', 'Beighton', 'Beighton', 53.3333300, -1.3333300, 'GB', '2013-08-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61414, 'Beeston', 'Beeston', '', 53.1166700, -2.6833300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61415, 'Beeford', 'Beeford', '', 53.9699900, -0.2891300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61416, 'Bedworth', 'Bedworth', 'Bedvors,Bedvortas,Bedworth,bdwwrth,Бедворс,بدوورث', 52.4791000, -1.4690900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61417, 'Bedwas', 'Bedwas', 'Bedwas', 51.5918300, -3.1988600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61418, 'Bedlington', 'Bedlington', 'wst bdlyngtwn,وست بدلینگتون', 55.1306100, -1.5931900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61419, 'Bedford', 'Bedford', 'Bedford,Bedfordia,XQD,bdfwrd  anglstan,bedeupeodeu,bydfwrd,Бедфорд,בעדפארד,بدفورد، انگلستان,بيدفورد,베드퍼드', 52.1345900, -0.4663200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61420, 'Bedale', 'Bedale', 'Bedale,bydyl,بیدیل', 54.2881100, -1.5918100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61421, 'Beckingham', 'Beckingham', 'Beckingham', 53.4000000, -0.8333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61422, 'Beckenham', 'Beckenham', 'Beckenham,bekenahama,bekkunamu,bknham,بکنهام,بیکنہیم، لندن,बेकेनहम,ベックナム', 51.4087800, -0.0252600, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61423, 'Beccles', 'Beccles', 'bkls,بکلس', 52.4593600, 1.5646500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61424, 'Bebington', 'Bebington', 'Bebington,Bebington and Bromborough,bbyngtwn,bei bin dun,Бебингтон,ببینگتون,貝賓頓', 53.3500000, -3.0166700, 'GB', '2013-10-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61425, 'Beaumaris', 'Beaumaris', 'Biumaris,Biwmares,Biwmaris,Bomaris,bo ma li si,Биумарис,Бомарис,波馬利斯', 53.2631500, -4.0923300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61426, 'Beauly', 'Beauly', 'A Mhanachainn', 57.4834500, -4.4614400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61427, 'Bearsden', 'Bearsden', 'Bearsden,Bersden,Birsden,Cille Phadraig Ur,Cille Phàdraig Ùr,Cille Phádraig Úr,New Kilpatrick,brzdn,Берсден,Бірсден,برزدن', 55.9153600, -4.3327900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61428, 'Beaminster', 'Beaminster', 'Beminster,bymynstr,Беминстер,بیمینستر', 50.8090000, -2.7391000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61429, 'Beadnell', 'Beadnell', '', 55.5567000, -1.6325000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61430, 'Beaconsfield', 'Beaconsfield', 'Beaconsfield,Bekunsfijld,bi ken si fei er de,bkwnzfyld,bykwnsfyld  kybk,Бекънсфийлд,بيكونسفيلد، كيبك,بکونزفیلد,比肯斯菲尔德', 51.6121900, -0.6473200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61431, 'Bayston Hill', 'Bayston Hill', '', 52.6755000, -2.7615600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61432, 'Bawtry', 'Bawtry', 'Bawtry,bawtry,باوتری', 53.4314600, -1.0187800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61433, 'Battlesden', 'Battlesden', '', 51.9481400, -0.5956400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61434, 'Battle', 'Battle', 'Battl,Battle,Battle i East Sussex,Batul,ba te er,baeteul,batl  sasks shrqy,batoru,Баттл,Батъл,باتل، ساسکس شرقی,バトル,巴特尔,배틀', 50.9173200, 0.4841700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61435, 'Batley', 'Batley', 'Batley,Batli,ba te li,batly,Батли,باتلی,巴特利', 53.7029100, -1.6337000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61436, 'Bathgate', 'Bathgate', 'Batgejt,Bathgate,Both Cheit,Both Chéit,ba si gai te,baeseugeiteu,bsgyt,Батгейт,بسگیت,巴斯蓋特,배스게이트', 55.9020400, -3.6439800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61437, 'Bathford', 'Bathford', 'Bathford', 51.4002000, -2.3016100, 'GB', '2017-04-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61438, 'Bath', 'Bath', 'Aquae Sulis,Ba,Badanceaster,Bat,Bata,Batas,Bath,Baðanceaster,Bāta,Caerfaddon,Gorad Bat,QQX,ba si,baseu,basu,bath,bati,bʼt,Μπαθ,Бат,Горад Бат,Բաթ,באת,باتھ,باتھ، سومرسیٹ,باث,บาธ,ბათი,バース,巴斯,바스', 51.3751000, -2.3617200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61439, 'Baston', 'Baston', 'Baston', 52.7131100, -0.3517300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61440, 'Bassingham', 'Bassingham', 'Bassingham', 53.1288100, -0.6376500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61441, 'Bassingbourn', 'Bassingbourn', '', 52.0782100, -0.0539000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61442, 'Baslow', 'Baslow', 'Baslow', 53.2481100, -1.6224600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61443, 'Basingstoke', 'Basingstoke', 'Basingstoke,Behjsingstok,Beisin''nkstoouk,Bejzingstouk,XQB,basyngstwk,bei xin si tuo ke,beijingusutoku,beisingseutokeu,byysyngstwq,Μπεϊσινγκστόουκ,Бејзингстоук,Бэйсингсток,בייסינגסטוק,باسینگستوک,ベイジングストーク,貝辛斯托克,베이싱스토크', 51.2624900, -1.0870800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61444, 'Old Basing', 'Old Basing', 'Basing', 51.2666700, -1.0333300, 'GB', '2013-07-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61445, 'Basildon', 'Basildon', 'Basildon,Bazildon,Bazildonas,Bazildun,Gorad Bazildan,ba xi er deng,baejildeon,bajirudon,bzyldwn,Базилдон,Базилдън,Басилдон,Горад Базілдан,بزیلدون,バジルドン,巴西爾登,배질던', 51.5684400, 0.4578200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61446, 'Upper Basildon', 'Upper Basildon', '', 51.4816500, -1.1407500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61447, 'Basford', 'Basford', '', 52.9666700, -1.1833300, 'GB', '2017-06-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61448, 'Baschurch', 'Baschurch', 'Baschurch', 52.7884800, -2.8528400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61449, 'Barton upon Humber', 'Barton upon Humber', 'Barton,Barton upon Humber', 53.6800400, -0.4376500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61450, 'Barton under Needwood', 'Barton under Needwood', 'Barton,Barton under Needwood', 52.7626800, -1.7240000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61451, 'Barton-le-Clay', 'Barton-le-Clay', 'Barton', 51.9659800, -0.4273100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61452, 'Barston', 'Barston', 'Barston', 52.3999100, -1.6955000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61453, 'Barry', 'Barry', 'Bari,Baris,Barri,Barry,Barry i Wales,Beri,Y Barri,ba li,bry  wlz,Бари,Барри,Баррі,Бери,בארי,بری، ولز,巴里', 51.3997900, -3.2838000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61454, 'Barrow upon Soar', 'Barrow upon Soar', 'Barrow,Barrow upon Soar', 52.7517800, -1.1460100, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61455, 'Barrow upon Humber', 'Barrow upon Humber', 'Barrow,Barrow upon Humber,Barrow-on-Humber', 53.6755000, -0.3806200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61456, 'Barrow in Furness', 'Barrow in Furness', 'BWF,Barrow,Barrow in Furness', 54.1109400, -3.2275800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61457, 'Barrowford', 'Barrowford', 'Barrowford', 53.8465000, -2.2183800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61458, 'Barrowby', 'Barrowby', 'Barrowby', 52.9163600, -0.6909400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61459, 'Barrhead', 'Barrhead', 'Barhedas,Barrkhed,Ceann a Bhairr,Ceann a Bharra,Ceann a Bhàirr,Ceann a Bhárra,barhd,Баррхед,بارهد', 55.7991600, -4.3928500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61460, 'Barnt Green', 'Barnt Green', 'Barnt Green', 52.3590200, -2.0071500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61461, 'Barnstaple', 'Barnstaple', 'Bardanstapol,Barnastapula,Barnstapl,Barnstaple,Barnstaplis,Barnstupul,banseuteopeul,barnstapl,Барнстапл,Барнстъпъл,بارنستاپل,반스터플', 51.0802200, -4.0580800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61462, 'Barnsley', 'Barnsley', 'Barnsley,Barnsli,Barnslis,Barnzli,Beornesleah,Beorneslēah,Gorad Barnsli,ba en si li,ban shi li,banjeulli,banzuri,barnzly,Барнзли,Барнсли,Барнслі,Горад Барнслі,بارنزلي,بارنزلی,バーンズリー,巴恩斯利,班士利,반즐리', 53.5500000, -1.4833300, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61463, 'Barnoldswick', 'Barnoldswick', 'Barnoldswick,barnwldzwyk,بارنولدزویک', 53.9171100, -2.1870500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61464, 'Barningham', 'Barningham', '', 54.4880900, -1.8700800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61465, 'Barnham', 'Barnham', '', 50.8312000, -0.6378900, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61466, 'Barnetby le Wold', 'Barnetby le Wold', 'Barnetby,Barnetby le Wold', 53.5748000, -0.4060700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61467, 'Barnet', 'Barnet', 'Barnet,Barnet keruelet,Barnet kerület,Barneto,Buirg Londan Barnet,Chipping Barnet,High Barnet,La Barnette,London Borough of Barnet,Londonska opshtina Barnet,Municipio de Barnet,ba ni te qu,barneta,barnٹ  lndn,Барнет,Лондонска општина Барнет,Բարնեթ,בארנט,לאנדאנער בארא פון בארנעט,بارنٹ، لندن,बार्नेट,バーネット・ロンドン特別区,巴尼特區', 51.6500000, -0.2000000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61468, 'Barnburgh', 'Barnburgh', 'Barnburgh', 53.5240800, -1.2730000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61469, 'Barnard Castle', 'Barnard Castle', 'brnard kstl,برنارد کستل', 54.5415000, -1.9190000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61470, 'Barnack', 'Barnack', 'Barnack,brnk,برنك', 52.6318100, -0.4082100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61471, 'Barmston', 'Barmston', '', 54.0141200, -0.2285700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61472, 'Barmouth', 'Barmouth', 'Abermaw,Barmouth,Barmut,Bermo,Бармут,Бармът', 52.7237700, -4.0574800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61473, 'Barmby on the Marsh', 'Barmby on the Marsh', 'Barmby,Barmby on the Marsh', 53.7489600, -0.9560700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61474, 'Barlestone', 'Barlestone', 'Barlestone', 52.6471800, -1.3701300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61475, 'Barlborough', 'Barlborough', 'Barlborough', 53.2879500, -1.2881500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61476, 'Barlaston', 'Barlaston', '', 52.9420000, -2.1705000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61477, 'Barkisland', 'Barkisland', '', 53.6761400, -1.9184000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61478, 'Barking', 'Barking', 'Barking,Barking Town,Barking i England,bakingu,barkinga,barkyng,بارکینگ,बार्किंग,バーキング', 51.5333300, 0.0833300, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61479, 'Barkham', 'Barkham', 'Barkham', 51.3980500, -0.8759000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61480, 'Bargoed', 'Bargoed', 'Bargoed', 51.6833300, -3.2333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61481, 'Bardsey', 'Bardsey', '', 53.8849200, -1.4453900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61482, 'Bardon Mill', 'Bardon Mill', 'Bardon Mill', 54.9754700, -2.3430900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61483, 'Bardney', 'Bardney', 'Bardney,Beordan ieg,Beordan īeg', 53.2100500, -0.3237100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61484, 'Banwell', 'Banwell', '', 51.3289400, -2.8691400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61485, 'Banstead', 'Banstead', 'Bansted,Банстед', 51.3223300, -0.2068500, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61486, 'Bannockburn', 'Bannockburn', 'Allt a Bhonnaich,Bannockburn,Banukburn,Банъкбърн', 56.0897800, -3.9109200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61487, 'Banks', 'Banks', 'Banks', 53.6833300, -2.9166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61488, 'Bankfoot', 'Bankfoot', 'Bankfoot', 56.5005800, -3.5170700, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61489, 'Banham', 'Banham', 'Banham', 52.4524000, 1.0368300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61490, 'Bangor', 'Bangor', 'Bangor,Bangor i Nord-Irland,Bangoras,Beannchar,ban ge,banga,bngwr  kanty dawn,Бангор,بنگور، کانتی داون,バンガー,班戈', 54.6533800, -5.6689500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61491, 'Bangor', 'Bangor', 'Ban''nkor,Bangor,Bangoras,baeng-go-eo,ban ge,banga,banghwr,bangori,banjwr,bngwr,bngwr  wlz,byngwr,Μπάνγκορ,Бангор,Բանգոր,בנגור,بانجور,بانغور,بنگور، ولز,بینگور,بینگور، گوینڈ,ბანგორი,バンガー,班戈,뱅고어', 53.2275200, -4.1293600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61492, 'Banff', 'Banff', 'Banbh,Banbh ,Banff a Macduff,Banff i Macduff,Banff i Skottland,ban fu,banfu,バンフ,班夫', 57.6647700, -2.5296400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61493, 'Banchory', 'Banchory', 'Banchory,Banchry,Beannchar,ban ke li,班科里', 57.0516800, -2.4882400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61494, 'Banbury', 'Banbury', 'Banberi,Banberis,Banburi,Banbury,banberi,bnbry,Банбери,Банбъри,Բանբերի,بنبری,バンベリー', 52.0632000, -1.3422200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61495, 'Banbridge', 'Banbridge', 'Banbridzh,Банбридж', 54.3500000, -6.2833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61496, 'Bampton', 'Bampton', 'Bampton,Бамптон', 51.7263400, -1.5454700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61497, 'Bamburgh', 'Bamburgh', 'Bamburgh,Bamburgo,Dun Guaire,Dún Guaire', 55.6065200, -1.7170400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61498, 'Balsham', 'Balsham', '', 52.1323800, 0.3158600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61499, 'Balmullo', 'Balmullo', '', 56.3769400, -2.9294000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61500, 'Balmedie', 'Balmedie', '', 57.2505200, -2.0616300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61501, 'Ballywalter', 'Ballywalter', '', 54.5432900, -5.4847500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61502, 'Ballynahinch', 'Ballynahinch', 'Baile na hInse,Balinakhinch,Ballinakhinch,Ballynahinch,Балинахинч,Баллинахинч', 54.4023000, -5.8971700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61503, 'Ballymoney', 'Ballymoney', 'Baile Monaidh,Balimuni,Ballimoni,Districtul Ballymoney,Балимъни,Баллимони', 55.0708000, -6.5100900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61504, 'Ballymena', 'Ballymena', 'An Baile Meanach,An Baile Meánach,Balimena,Balimina,Ballimina,Behllimena,Districtul Ballymena,ba li mi na,baellimina,bylymyna,Балимина,Баллимина,Бэллимена,באלמינה,بيليمينا,巴利米納,밸리미나', 54.8635700, -6.2762800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61505, 'Ballykelly', 'Ballykelly', 'BOL', 55.0442500, -7.0185500, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61506, 'Ballygowan', 'Ballygowan', '', 54.5016500, -5.7916800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61507, 'Ballyclare', 'Ballyclare', 'Balikleras,Balikleur,Balliklehr,Ballyclare,Bealach Clair,Bealach Cláir,Баликлеър,Балликлэр', 54.7508900, -5.9994400, 'GB', '2016-12-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61508, 'Ballycastle', 'Ballycastle', 'Baile an Chaistil,Balikasul,Ballikasl,Ballycastle,Баликасъл,Балликасл', 55.2044400, -6.2429800, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61509, 'Balloch', 'Balloch', 'Balloch', 56.0000000, -4.5833300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61510, 'Ballingry', 'Ballingry', '', 56.1639200, -3.3284100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61511, 'Ballinamallard', 'Ballinamallard', 'Ballanamallard,Ballinamallard', 54.4000000, -7.5833300, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61512, 'Ballater', 'Ballater', 'Ballater,Bealadair,ba lei te,巴勒特', 57.0501100, -3.0379800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61513, 'Balintore', 'Balintore', 'Balintore', 57.7556400, -3.9123200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61514, 'Balfron', 'Balfron', 'Balfron', 56.0680900, -4.3355900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61515, 'Balerno', 'Balerno', '', 55.8843700, -3.3397500, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61516, 'Baldock', 'Baldock', 'Baldock', 51.9878100, -0.1883500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61517, 'Balcombe', 'Balcombe', '', 51.0572600, -0.1345000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61518, 'Bala', 'Bala', 'Bala,Y Bala,Бала', 52.9111100, -3.5972200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61519, 'Bakewell', 'Bakewell', '', 53.2133800, -1.6748100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61520, 'Bainton', 'Bainton', '', 53.9500000, -0.5333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61521, 'Baildon', 'Baildon', '', 53.8471100, -1.7878500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61522, 'Bagworth', 'Bagworth', '', 52.6726500, -1.3427400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61523, 'Bagshot', 'Bagshot', '', 51.3606900, -0.6880200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61524, 'Bagillt', 'Bagillt', 'Bagillt,Bagilt', 53.2654000, -3.1655100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61525, 'Badsworth', 'Badsworth', '', 53.6287600, -1.3012800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61526, 'Badsey', 'Badsey', '', 52.0881900, -1.8992500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61527, 'Bacup', 'Bacup', 'bykap,بیکاپ', 53.7033600, -2.2007000, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61528, 'Bacton', 'Bacton', 'Bacton', 52.2666700, 1.0166700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61529, 'Bacton', 'Bacton', '', 51.9833300, -2.9166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61530, 'Backworth', 'Backworth', '', 55.0422900, -1.5277900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61531, 'Ayr', 'Ayr', 'Ayr,Ayr - Inbhir Air,Ayr - Inbhir Àir,Ehr,Er,Eras,Eyr,Inbhir Air,Inbhir Àir,Inbhir Áir,ai er,ayr,ea,Ер,Эр,אייר,آئر,ایر,エア,艾尔', 55.4627300, -4.6339300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61532, 'Aylsham', 'Aylsham', 'aylsham,آیلشام', 52.7967200, 1.2510700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61533, 'Aylesford', 'Aylesford', 'AEgelesthrep,Ægelesþrep', 51.3037400, 0.4793600, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61534, 'Aylesbury', 'Aylesbury', 'AEgelesburg,Aelesburia,Aylesbury,Ehjlsberi,Eilsberis,Ejlsberi,Gorad Ehjlsbery,ai er si bo li,arisubari,aylzbry,eiljeubeli,Ægelesburg,Горад Эйлсберы,Ејлсбери,Эйлсбери,آیلزبری,أيلزبري,アリスバーリー,艾爾斯伯里,에일즈베리', 51.8166500, -0.8145800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61535, 'Axminster', 'Axminster', 'Aksminster,Axanmynster,Axeminstra,Axminster,Axminstersky koberec,Axminsterský koberec,aksmynstr,Аксмінстер,اکسمینستر', 50.7825900, -2.9978700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61536, 'Axbridge', 'Axbridge', 'Axa,Axbridge,aksryj,اکسریج', 51.2846600, -2.8207800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61537, 'Awsworth', 'Awsworth', 'Awsworth', 52.9891200, -1.2835400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61538, 'Aviemore', 'Aviemore', 'An Aghaidh Mhor,An Aghaidh Mhòr,An Aghaidh Mhór,a wei mo er,阿维莫尔', 57.1955300, -3.8259000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61539, 'Avening', 'Avening', 'Avening', 51.6801000, -2.1690300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61540, 'Aveley', 'Aveley', '', 51.4998700, 0.2517400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61541, 'Avebury', 'Avebury', 'Avebury,Aveburyn kivikehae,Aveburyn kivikehä,SU 103699', 51.4166700, -1.8666700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61542, 'Audley', 'Audley', 'Audley', 53.0500000, -2.3000000, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61543, 'Audlem', 'Audlem', 'awdlm,اودلم', 52.9895600, -2.5070600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61544, 'Auckley', 'Auckley', '', 53.5038600, -1.0217400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61545, 'Auchtermuchty', 'Auchtermuchty', '', 56.2915800, -3.2342800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61546, 'Auchterarder', 'Auchterarder', 'Auchterarder', 56.2961200, -3.7069200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61547, 'Auchinleck', 'Auchinleck', 'Auchinleck', 55.4715700, -4.2933700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61548, 'Atworth', 'Atworth', 'Atworth', 51.3923400, -2.1929700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61549, 'Atwick', 'Atwick', '', 53.9401200, -0.1890000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61550, 'Attleborough', 'Attleborough', 'atlbrw,اتلبرو', 52.5177900, 1.0157200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61551, 'Attleborough', 'Attleborough', '', 52.5129300, -1.4548700, 'GB', '2011-03-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61552, 'Atherton', 'Atherton', '', 53.5237100, -2.4935400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61553, 'Atherstone', 'Atherstone', 'Atherstone', 52.5753600, -1.5469300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61554, 'Astwood Bank', 'Astwood Bank', 'Astwood Bank', 52.2599300, -1.9375400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61555, 'Astwood', 'Astwood', 'Astwood', 52.1000000, -0.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61556, 'Astwick', 'Astwick', '', 52.0323000, -0.2312700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61557, 'Aston Clinton', 'Aston Clinton', '', 51.8002000, -0.7254000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61558, 'Astley', 'Astley', '', 52.7666700, -2.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61559, 'Aspley Guise', 'Aspley Guise', '', 52.0119900, -0.6330000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61560, 'Aspatria', 'Aspatria', 'Aspatria,aspatrya,اسپاتریا', 54.7657400, -3.3278300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61561, 'Aslockton', 'Aslockton', 'Aslockton,Aslocton', 52.9529900, -0.8970000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61562, 'Askham Richard', 'Askham Richard', '', 53.9249100, -1.1848100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61563, 'Askern', 'Askern', '', 53.6163900, -1.1523700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61564, 'Askam in Furness', 'Askam in Furness', 'Askam,Askam in Furness', 54.1871800, -3.2046700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61565, 'Ashwell', 'Ashwell', '', 52.7129800, -0.7196900, 'GB', '2015-02-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61566, 'Ashwell', 'Ashwell', 'Ashwell', 52.0386600, -0.1539800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61567, 'Ashurst', 'Ashurst', '', 50.9323600, -0.3237500, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61568, 'Ashton-under-Lyne', 'Ashton-under-Lyne', 'Ashton,Ashton-under-Lyne,Ehshton-ander-Lajn,ashtwn-andr-lyn,Эштон-андер-Лайн,اشتون-آندر-لین', 53.4887600, -2.0989000, 'GB', '2010-10-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61569, 'Ashton Keynes', 'Ashton Keynes', '', 51.6452100, -1.9323200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61570, 'Ashton in Makerfield', 'Ashton in Makerfield', 'Ashton,Ashton in Makerfield', 53.4833300, -2.6500000, 'GB', '2014-05-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61571, 'Ashtead', 'Ashtead', '', 51.3087300, -0.2997200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61572, 'Ashley', 'Ashley', '', 53.3500000, -2.3333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61573, 'Ashington', 'Ashington', 'Ashington,ashyngtwn,اشینگتون', 55.1771900, -1.5641200, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61574, 'Ashington', 'Ashington', '', 50.9331200, -0.3908700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61575, 'Ashill', 'Ashill', '', 52.6043500, 0.7857400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61576, 'Ashford', 'Ashford', 'Ashford i Surrey', 51.4317300, -0.4576100, 'GB', '2017-04-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61577, 'Ashford', 'Ashford', 'Asfordas,Ashford,Ashford i Kent,Ašfordas,Ehshford,Eshford,QDH,a shen fu de,aesyupeodeu,ashfwrd  knt,Ешфорд,Эшфорд,اشفورد، کنت,阿什福德,애슈퍼드', 51.1464800, 0.8737600, 'GB', '2014-08-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61578, 'Ashby de la Zouch', 'Ashby de la Zouch', '', 52.7463200, -1.4732000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61579, 'Ashburton', 'Ashburton', 'Ashburton,Ashburton i Devon,ashbwrtwn  dwwn,اشبورتون، دوون', 50.5155900, -3.7557200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61580, 'Ashbourne', 'Ashbourne', 'Ashbourne', 53.0166700, -1.7333300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61581, 'Ash', 'Ash', '', 52.9500000, -2.6500000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61582, 'Ascot', 'Ascot', 'Ascot,Askot,Askut,askwt,ya shi gu,Аскот,Аскът,أسكوت,雅士谷', 51.4108200, -0.6748000, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61583, 'Arundel', 'Arundel', 'Arundel,Erandel,a lun de er,arwndl,Аръндел,Ерандел,آروندل,阿倫德爾', 50.8542300, -0.5539300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61584, 'Arnside', 'Arnside', '', 54.2017900, -2.8337400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61585, 'Arnold', 'Arnold', 'Arnol''d,Arnold,Арнолд,Арнольд,آرنلڈ، ناٹنگھمشائر', 53.0000000, -1.1333300, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61586, 'Armthorpe', 'Armthorpe', '', 53.5351800, -1.0534100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61587, 'Armitage', 'Armitage', 'Armitage', 52.7419300, -1.8826600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61588, 'Armagh', 'Armagh', 'Ard Maghey,Ard Mhacha,Arma,Armagh,a ma,ama,arma,armagh,Арма,Արմա,آرما,آرماغ,آرماہ,アーマー,阿馬,아마', 54.3500000, -6.6666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61589, 'Armadale', 'Armadale', 'Armadale', 55.8833300, -3.7000000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61590, 'Arlesey', 'Arlesey', 'Arlesley,arlsy,ارلسی', 52.0071300, -0.2656500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61591, 'Ardrossan', 'Ardrossan', 'Aird Rosain,Ard Rushen,Ardrossan,Gorad Ardrosan,Àird Rosain,Áird Rosain,Ардроссан,Горад Ардросан', 55.6501800, -4.8065900, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61592, 'Ardrishaig', 'Ardrishaig', 'Ardrishaig', 56.0156600, -5.4480600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61593, 'Ardingly', 'Ardingly', '', 51.0486500, -0.0771600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61594, 'Ardglass', 'Ardglass', 'Ard Ghlais,ardglasa,अर्द्ग्लास', 54.2631200, -5.6098100, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61595, 'Ardersier', 'Ardersier', 'Ardersier,Campbelltown', 57.5668100, -4.0378400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61596, 'Arbroath', 'Arbroath', 'Aiberbrothock,Arbroath,Arbrot,Arbrotas,Arbrout,Obar Bhrothaig,a bu luo si,arbrwth,Арброт,Арброут,آربروث,阿布羅斯', 56.5631700, -2.5873600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61597, 'Appley Bridge', 'Appley Bridge', '', 53.5778100, -2.7209000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61598, 'Appleton', 'Appleton', '', 53.3524000, -2.5718300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61599, 'Appledore', 'Appledore', 'Appledore', 51.0500000, -4.2000000, 'GB', '2013-04-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61600, 'Appleby', 'Appleby', '', 53.6219800, -0.5661200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61601, 'Antrim', 'Antrim', 'Antrim,Antrimas,Aontroim,Districtul Antrim,antorimu,Антрим,アントリム', 54.7000000, -6.2000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61602, 'Anstruther', 'Anstruther', 'Ansruthair,Anster,Anstruthair,Anstruther,West Anstruther,Ànsruthair,Ánstruthair', 56.2231500, -2.7022900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61603, 'Anstey', 'Anstey', 'Anstey,Ansty', 52.6736800, -1.1884100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61604, 'Ansty', 'Ansty', 'Anstey,Ansty', 51.0363900, -2.0638900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61605, 'Annfield Plain', 'Annfield Plain', '', 54.8574900, -1.7382700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61606, 'Annan', 'Annan', 'Anan,Annan,Inbhir Anainn,anan,Анан,아난', 54.9883900, -3.2564700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61607, 'Annalong', 'Annalong', '', 54.1082300, -5.8996600, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61608, 'Annahilt', 'Annahilt', 'Annahilt', 54.4333300, -6.0000000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61609, 'Andover', 'Andover', 'Andover,Andover i Hampshire,aendobeo,andovu~a,andwwr  hmpshr,endovara,Андовер,اندوور، همپشر,एंडोवर,แอนโดเวอร์,アンドーヴァー,앤도버', 51.2113500, -1.4939300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61610, 'Ancroft', 'Ancroft', '', 55.7000000, -2.0000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61611, 'Ancaster', 'Ancaster', '', 52.9827600, -0.5359300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61612, 'Ampthill', 'Ampthill', '', 52.0269400, -0.4956700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61613, 'Ammanford', 'Ammanford', 'Amanford,Ammanford,Rhydaman,Аманфорд,Амманфорд', 51.7927900, -3.9883300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61614, 'Amlwch', 'Amlwch', '', 53.4098600, -4.3471200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61615, 'Amesbury', 'Amesbury', 'Amesbury,Ehjmsberi,Ejmsberi,ai mu si bo li,amsbwry,eimjeubeoli,Еймсбері,Эймсбери,آمسبوری,埃姆斯伯里,에임즈버리', 51.1750900, -1.7806400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61616, 'Amersham', 'Amersham', 'Amersham,Амершам', 51.6666700, -0.6166700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61617, 'Ambrosden', 'Ambrosden', '', 51.8708700, -1.1212900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61618, 'Ambleside', 'Ambleside', 'Ambleside,Amblsajd,amblsayd,an bu sai de,Амблсайд,امبلساید,安布賽德', 54.4326100, -2.9616700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61619, 'Amble', 'Amble', 'Amble,Amble by the Sea,امبل، نورث‌آمبرلند', 55.3333300, -1.5833300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61620, 'Alyth', 'Alyth', 'Alyth', 56.6220900, -3.2300500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61621, 'Alveston', 'Alveston', 'Alveston', 51.5880600, -2.5313900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61622, 'Alveley', 'Alveley', 'Alveley', 52.4570900, -2.3543400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61623, 'Alvechurch', 'Alvechurch', 'Alvechurch', 52.3517300, -1.9653100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61624, 'Alva', 'Alva', 'Alva', 56.1528400, -3.8050500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61625, 'Altrincham', 'Altrincham', 'Altrincham,altrynkham,ao er te ling e mu,آلترینکهام,奥尔特灵厄姆', 53.3875200, -2.3484800, 'GB', '2017-07-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61626, 'Alton', 'Alton', 'Alton,Alton i Hampshire,Oltun,altwn  hmpshr,Алтон,Олтън,آلتون، همپشر,الٹن، ہیمپشائر', 51.1493100, -0.9746900, 'GB', '2010-08-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61627, 'Althorne', 'Althorne', '', 51.6572200, 0.7608500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61628, 'Alston', 'Alston', 'Alston i Cumbria,alstwn  kambrya,آلستون، کامبریا', 54.8090000, -2.4393100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61629, 'Alsager', 'Alsager', 'alsyjr,السیجر', 53.0961700, -2.3064900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61630, 'Alrewas', 'Alrewas', '', 52.7327800, -1.7496800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61631, 'Alresford', 'Alresford', '', 51.8538900, 1.0020300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61632, 'Alnwick', 'Alnwick', 'Alnik,Alnwick,alnwyk,anikku,aynk,Алник,آلنویک,ألنويك,اینک,アニック', 55.4131800, -1.7056300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61633, 'Alnmouth', 'Alnmouth', 'Alnmouth', 55.4000000, -1.6000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61634, 'Alness', 'Alness', 'Alanais,a er nei si,阿尔内斯', 57.6959600, -4.2551000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61635, 'Almondsbury', 'Almondsbury', '', 51.5540700, -2.5711400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61636, 'Almondbank', 'Almondbank', '', 56.4172900, -3.5173300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61637, 'Alloa', 'Alloa', 'Alamhagh,Allmhagh Mor,Allmhagh Mòr,Alloa,Aloa,alwa,Аллоа,Алоа,الوآ', 56.1158600, -3.7899700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61638, 'Allington', 'Allington', '', 51.1500000, -1.7000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61639, 'Allhallows', 'Allhallows', '', 51.4686600, 0.6368600, 'GB', '2015-05-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61640, 'Allanton', 'Allanton', 'Allanton', 55.7833300, -2.2166700, 'GB', '2012-01-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61641, 'Alfreton', 'Alfreton', 'Alfreton,Алфретон', 53.0976600, -1.3837600, 'GB', '2015-07-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61642, 'Alford', 'Alford', 'Alford', 57.2325700, -2.7029800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61643, 'Alford', 'Alford', 'Alford', 53.2594300, 0.1762500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61644, 'Alexandria', 'Alexandria', 'Alexandria', 55.9937900, -4.5864000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61645, 'Aldridge', 'Aldridge', 'Aldridge,Oldridzas,Oldridžas', 52.6054900, -1.9171500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61646, 'Aldford', 'Aldford', 'Aldford', 53.1276200, -2.8681200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61647, 'Aldershot', 'Aldershot', 'Aldershot,Oldershot,Oldersotas,Olderšotas,aldrshat,aldrshwt,ao er de xiao te,arudashotto,oldeosyos,Олдершот,אלדרשוט,ألدرشوت,الدرشات,アルダーショット,奧爾德肖特,올더숏', 51.2482700, -0.7638900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61648, 'Alderley Edge', 'Alderley Edge', 'aldrly adj,إلدرلي إدج', 53.3039300, -2.2377300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61649, 'Alderholt', 'Alderholt', 'Alderholt', 50.9119500, -1.8308300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61650, 'Alderbury', 'Alderbury', '', 51.0435400, -1.7338200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61651, 'Aldeburgh', 'Aldeburgh', 'Aldeburgh,Oldboro,adlbwrw,orudobara,Олдборо,ادلبورو,オールドバラ', 52.1525900, 1.6012400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61652, 'Aldbrough', 'Aldbrough', '', 53.8289300, -0.1146700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61653, 'Aldbourne', 'Aldbourne', 'Aldbourne', 51.4809800, -1.6182700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61654, 'Alconbury', 'Alconbury', '', 52.3690000, -0.2600900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61655, 'Alcester', 'Alcester', 'Alcester,alkstr,آلکستر', 52.2166700, -1.8666700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61656, 'Albrighton', 'Albrighton', '', 52.6364000, -2.2796600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61657, 'Airth', 'Airth', '', 56.0698300, -3.7720900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61658, 'Airmyn', 'Airmyn', '', 53.7207400, -0.8995900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61659, 'Airdrie', 'Airdrie', 'Airdrie,Airdrie i North Lanarkshire,An Ard Ruigh,An t-Ard Ruigh,An t-Árd Ruigh,An Àrd Ruigh,Ejrdri,Erdris,ai er de li,ardry,eeodeuli,Ейрдрі,اردری,埃爾德里,에어드리', 55.8660200, -3.9802500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61660, 'Ahoghill', 'Ahoghill', 'Ahoghill', 54.8666700, -6.3666700, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61661, 'Adwick le Street', 'Adwick le Street', '', 53.5707700, -1.1845400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61662, 'Adlington', 'Adlington', 'Adlington,Adlington i Lancashire,adlyngtwn  lankashr,Адлингтон,ادلینگتون، لانکاشر', 53.6132300, -2.6067600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61663, 'Addlestone', 'Addlestone', 'Addlestone', 51.3713500, -0.4935300, 'GB', '2011-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61664, 'Addingham', 'Addingham', '', 53.9445200, -1.8842400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61665, 'Adderbury', 'Adderbury', 'Adderbury', 52.0169000, -1.3119200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61666, 'Acton', 'Acton', 'Acton', 52.4500000, -3.0166700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61667, 'Acton', 'Acton', 'Acton i London,Akton,Aktun,aiktana,aktwn  lndn,akuton,e dun,Актон,Актън,آکتون، لندن,ایکٹون، لندن,ऐक्टन,アクトン,厄頓', 51.5090100, -0.2762000, 'GB', '2010-09-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61668, 'Acomb', 'Acomb', '', 54.9922900, -2.1122900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61669, 'Acocks Green', 'Acocks Green', 'Acocks Green', 52.4500000, -1.8166700, 'GB', '2017-06-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61670, 'Acle', 'Acle', '', 52.6368100, 1.5475700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61671, 'Acklington', 'Acklington', 'Acklington', 55.3000000, -1.6333300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61672, 'Acklam', 'Acklam', '', 54.0474500, -0.8038000, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61673, 'Accrington', 'Accrington', 'Akkrington,Akringtonas,a ke ning dun,aekeulingteon,ai ning dun,akryngtwn,akrynjtwn,Аккрингтон,آکرینگتون,أكرينجتون,艾寧頓,阿克寧頓,애크링턴', 53.7537900, -2.3586300, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61674, 'Abram', 'Abram', '', 53.5085500, -2.5926600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61675, 'Aboyne', 'Aboyne', 'Abeidh,Aboine,Aboyne,Abyne,Abèidh,Abéidh', 57.0754600, -2.7802300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61676, 'Abingdon', 'Abingdon', 'AEbbandun,Abindonia,Abingdon,Abingdon i Oxfordshire,Abingdon-on-Thames,Abingdonas,Abingdun,abindon=on=temuzu,abyngdn  aksfwrdshr,aebingdeon-ontemseu,tai wu shi he pan a bin dun,Æbbandūn,Абингдон,Абингдън,ابینگدن، آکسفوردشر,ایبینگڈن-آن-ٹیمز,アビンドン＝オン＝テムズ,泰晤士河畔阿賓頓,애빙던온템스', 51.6710900, -1.2827800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61677, 'Aberystwyth', 'Aberystwyth', 'Aberistuit,Aberistvit,Aberistvitas,Aberystwyth,Aburistuit,a bo li si te wei si,aberisutou~isu,abrystwyth,ebeoliseuteuwiseu,Аберистуит,Аберіствіт,Абъристуит,آبريستويث,آبریستویث,アベリストウィス,阿伯里斯特威斯,에버리스트위스', 52.4154800, -4.0829200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61678, 'Abertillery', 'Abertillery', 'Abertilleri,Abertillery,Abertyleri,Aburtiluri,a bei di lei li,Абертиллери,Абертіллері,Абъртилъри,阿貝迪勒利', 51.7298100, -3.1343200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61679, 'Aberporth', 'Aberporth', '', 52.1324800, -4.5417300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61680, 'Abernethy', 'Abernethy', '', 56.3324700, -3.3122600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61681, 'Abernant', 'Abernant', '', 51.8813900, -4.4155600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61682, 'Aberlour', 'Aberlour', 'Charlestown of Aberlour,Obar Lobhair', 57.4707600, -3.2250900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61683, 'Aberlady', 'Aberlady', 'Aberlady,Obar Liobhaite,Obar Líobhaite', 56.0088400, -2.8585100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61684, 'Aberkenfig', 'Aberkenfig', 'Aberkenfig', 51.5400000, -3.5955600, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61685, 'Abergele', 'Abergele', 'Abergele,Abergil,Абергеле,Абергіл', 53.2843600, -3.5822000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61686, 'Abergavenny', 'Abergavenny', 'Abergavenis,Abergavenni,Abergavenny,Abergejvenni,Aburgaveni,Gobannium,Y Fenni,ebargaveni,Абергавенни,Абергейвенні,Абъргавени,एबर्गावेनी', 51.8209800, -3.0174300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61687, 'Aberford', 'Aberford', 'Aberford', 53.8260400, -1.3423100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61688, 'Aberfeldy', 'Aberfeldy', 'Aberfeldy', 56.6219600, -3.8669300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61689, 'Aberfan', 'Aberfan', 'Aberfam,Aberfan', 51.6889200, -3.3417800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61690, 'Aberdour', 'Aberdour', 'Aberdour,Obar Dhobhair,Obar Dobhair', 56.0541700, -3.3005800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61691, 'Aberdeen', 'Aberdeen', 'A-pak-ten,ABZ,Aberdeen,Aberdin,Aberdina,Aberdins,Aberdon,Aberdonia,Aberdynas,Aberdzin,Aberdīna,Aberdīns,Aburdijn,Aiberdeen,Amperntin,Devanha,Obar Dheathain,a bo ding,abadin,aberdin,aberdini,abrdyn,aebeodin,ebaradina,ya ba dian,Â-pak-tên,Αμπερντήν,Абердзін,Абердин,Абърдийн,Աբերդին,אבערדין,אברדין,أبردين,ابردین,ابرڈین,अ‍ॅबर्डीन,एबरडीन,অ্যাবরদিন,అబెర్డీన్,അബർഡീൻ,แอเบอร์ดีน,အဘာဒင်းမြို့,აბერდინი,アバディーン,阿伯丁,鴨巴甸,애버딘', 57.1436900, -2.0981400, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61692, 'Aberdare', 'Aberdare', 'Aberdar,Aberdare,Aberdare - Aberdar,Aberdare - Aberdâr,Aberdehjr,Aberdehr,Aberder,Aberderas,Aberdâr,Aburdeur,a bo dai er,aebeodeeo,Абердер,Абердэйр,Абердэр,Абърдеър,阿伯代爾,애버데어', 51.7143800, -3.4491800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61693, 'Abercynon', 'Abercynon', 'Abercynon,Aberkunon,Aberoynon,Аберкънон', 51.6454800, -3.3272700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61694, 'Aberchirder', 'Aberchirder', '', 57.5601200, -2.6285600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61695, 'Abercarn', 'Abercarn', 'Abercarn,Aberearne', 51.6473300, -3.1347600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61696, 'Abercanaid', 'Abercanaid', 'Abercanaid', 51.7236100, -3.3661100, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61697, 'Aberaeron', 'Aberaeron', 'Aberaeron,Aberajron,Aberaron,Aberayron,a bei la ni,Аберайрон,Аберарон,阿貝拉尼', 52.2424700, -4.2587100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61698, 'Aber', 'Aber', '', 53.2333300, -4.0166700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61699, 'Abbotts Ann', 'Abbotts Ann', 'Abbots Ann,Abbotts Ann', 51.1901600, -1.5323400, 'GB', '2014-09-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61700, 'Abbots Langley', 'Abbots Langley', 'Abbots Langley,Ebbots-Lengli,Ебботс-Ленглі', 51.7057300, -0.4175700, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61701, 'Abbotskerswell', 'Abbotskerswell', 'Abbotskerswell', 50.5081600, -3.6134200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61702, 'Abbots Bromley', 'Abbots Bromley', '', 52.8170500, -1.8769400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61703, 'Abbey Dore', 'Abbey Dore', 'Abbey Dore', 51.9666700, -2.9000000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61704, 'Benllech', 'Benllech', 'Benllech', 53.3204400, -4.2260700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61705, 'Crosby', 'Crosby', '', 53.4777800, -3.0333300, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61706, 'Overcombe', 'Overcombe', 'Overcombe', 50.6350900, -2.4320700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61707, 'Lynemouth', 'Lynemouth', 'Lynemouth', 55.2130600, -1.5425000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61708, 'Hadston', 'Hadston', '', 55.2942800, -1.6039200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61709, 'East Cowes', 'East Cowes', 'East Cowes,Ist-Kaus,ayst kwwz,Ист-Каус,ایست کووز', 50.7577400, -1.2881500, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61710, 'Shiremoor', 'Shiremoor', 'Shiremoor', 55.0353500, -1.5095000, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61711, 'Looe', 'Looe', 'East Looe,Logh,lw,لو', 50.3577800, -4.4541800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61712, 'Pensilva', 'Pensilva', '', 50.5030200, -4.4149100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61713, 'Flexbury', 'Flexbury', '', 50.8350900, -4.5449900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61714, 'Steynton', 'Steynton', 'Steynton', 51.7291700, -5.0172200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61715, 'Hundleton', 'Hundleton', '', 51.6669400, -4.9491700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61716, 'Glandwr', 'Glandwr', '', 51.9283300, -4.6333300, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61717, 'Trimsaran', 'Trimsaran', '', 51.7198800, -4.2416800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61718, 'Tumble', 'Tumble', 'Tumble,y Tymbl', 51.7836100, -4.1097200, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61719, 'Llangynog', 'Llangynog', '', 51.8211100, -4.4097200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61720, 'Crofty', 'Crofty', '', 51.6344800, -4.1293700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61721, 'Pennard', 'Pennard', 'Pennard', 51.5762700, -4.0869100, 'GB', '2017-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61722, 'Southgate', 'Southgate', '', 51.5694400, -4.0897200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61723, 'Three Crosses', 'Three Crosses', '', 51.6286500, -4.0626300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61724, 'Grovesend', 'Grovesend', 'Grovesend', 51.6847200, -4.0383300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61725, 'Pontlliw', 'Pontlliw', 'Pontlliw', 51.6913900, -4.0105600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61726, 'Ambleston', 'Ambleston', 'Ambleston', 51.8958300, -4.9072200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61727, 'Scleddau', 'Scleddau', '', 51.9683300, -4.9933300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61728, 'Hook', 'Hook', '', 51.7650000, -4.9316700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61729, 'Croeserw', 'Croeserw', 'Croeserw', 51.6447200, -3.6402800, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61730, 'Pont Rhyd-y-cyff', 'Pont Rhyd-y-cyff', '', 51.5869400, -3.6363900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61731, 'Price Town', 'Price Town', '', 51.6183200, -3.5366200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61732, 'Ogmore Vale', 'Ogmore Vale', '', 51.6023000, -3.5421700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61733, 'Tonypandy', 'Tonypandy', 'Tonupandi,tang ni pan di,Тонъпанди,湯尼潘帝', 51.6220200, -3.4554400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61734, 'Clydach Vale', 'Clydach Vale', '', 51.6266500, -3.4801500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61735, 'Cefn Cribwr', 'Cefn Cribwr', '', 51.5316700, -3.6527800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61736, 'Merthyr Mawr', 'Merthyr Mawr', 'Merthyr Mawr', 51.4861100, -3.6086100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61737, 'Brynna', 'Brynna', '', 51.5384500, -3.4637800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61738, 'Abertridwr', 'Abertridwr', 'Abertridwr', 51.5958300, -3.2683300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61739, 'Beddau', 'Beddau', '', 51.5539800, -3.3581400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61740, 'Blackwood', 'Blackwood', 'Blekud,Blekvud,Coed Duon,Coed-duon,Блеквуд,Блекуд', 51.6677800, -3.2075000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61741, 'Cwmbach', 'Cwmbach', '', 51.7055600, -3.4094400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61742, 'Blaengwynfi', 'Blaengwynfi', 'Blaengwynfi', 51.6562300, -3.6037100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61743, 'New Inn', 'New Inn', 'New Inn', 51.6905600, -3.0091700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61744, 'Rogiet', 'Rogiet', 'Rogiet', 51.5885400, -2.7786800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61745, 'Eastington', 'Eastington', 'Eastington', 51.7472200, -2.3263900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61746, 'Whitley', 'Whitley', 'Whitley', 51.3952800, -2.1644400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61747, 'Woolavington', 'Woolavington', '', 51.1649300, -2.9381400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61748, 'Kewstoke', 'Kewstoke', '', 51.3653000, -2.9590100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61749, 'Pucklechurch', 'Pucklechurch', 'Pucklechurch', 51.4858300, -2.4338900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61750, 'Peasedown Saint John', 'Peasedown Saint John', '', 51.3166700, -2.4241700, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61751, 'Severn Beach', 'Severn Beach', 'Severn Beach', 51.5603600, -2.6627900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61752, 'Easton-in-Gordano', 'Easton-in-Gordano', '', 51.4759200, -2.6998700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61753, 'Bishop Sutton', 'Bishop Sutton', 'Bishop Sutton', 51.3344400, -2.5947200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61754, 'Chapmanslade', 'Chapmanslade', 'Chapmanslade', 51.2291700, -2.2488900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61755, 'Stockton', 'Stockton', '', 51.1452800, -2.0319400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61756, 'Boyton', 'Boyton', '', 51.1550000, -2.0711100, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61757, 'Marston', 'Marston', '', 51.3108300, -2.0497200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61758, 'Neston', 'Neston', '', 51.4122200, -2.2005600, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61759, 'Camden Town', 'Camden Town', 'Camden,kaemdeontaun,kang deng zhen,קמדן טאון,کیمڈن ٹاؤن,カムデン・タウン,康登鎮,캠던타운', 51.5405700, -0.1433400, 'GB', '2015-10-05', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61760, 'Camberwell', 'Camberwell', 'Kamberuehll,kan bo wei er,kembaravela,Камберуэлл,केम्बरवेल,坎伯韦尔', 51.4739000, -0.0938100, 'GB', '2010-10-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61761, 'Telford', 'Telford', 'Gorad Tehlfard,Telford,Telfordas,te er fu de,terufodo,tlfwrd,Горад Тэлфард,Телфорд,Թելֆորդ,تلفورد,テルフォード,特爾福德', 52.6765900, -2.4492600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61762, 'Craigavon', 'Craigavon', 'Craigavon,Creag Abhann,Districtul Craigavon,Krejgavon,Krejgejvun,ke lei jia wen,krygaywn,qryygbwn,Крейгавон,Крейгейвън,Крејгавон,קרייגבון,کریگایون,کریگ‌آوون,克雷加文', 54.4470900, -6.3870000, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61763, 'Caol', 'Caol', '', 56.8372100, -5.1006200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61764, 'Wideopen', 'Wideopen', '', 55.0451400, -1.6224600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61765, 'Hazlerigg', 'Hazlerigg', 'Hazelrigg,Hazlerigg', 55.0413500, -1.6391200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61766, 'Lamesley', 'Lamesley', '', 54.9156700, -1.6094500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61767, 'Walton', 'Walton', '', 53.9250100, -1.3274600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61768, 'Clifford', 'Clifford', '', 53.8951300, -1.3455700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61769, 'East Keswick', 'East Keswick', '', 53.8943000, -1.4522100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61770, 'Shadwell', 'Shadwell', '', 53.8546000, -1.4726000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61771, 'Barlby', 'Barlby', '', 53.7996400, -1.0406100, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61772, 'Bar Hill', 'Bar Hill', 'Bar Hill', 52.2489900, 0.0288300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61773, 'Camber', 'Camber', '', 50.9347300, 0.7984800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61774, 'Winchelsea Beach', 'Winchelsea Beach', '', 50.9169100, 0.7215800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61775, 'Kesgrave', 'Kesgrave', '', 52.0624100, 1.2365000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61776, 'Blackmoorfoot', 'Blackmoorfoot', '', 53.6142300, -1.8558800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61777, 'Meltham Mills', 'Meltham Mills', '', 53.5938800, -1.8398900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61778, 'Polzeath', 'Polzeath', '', 50.5695600, -4.9175900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61779, 'Rock', 'Rock', '', 50.5497800, -4.9046200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61780, 'Camblesforth', 'Camblesforth', '', 53.7268000, -1.0199800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61781, 'Fontwell', 'Fontwell', '', 50.8552000, -0.6483100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61782, 'Sharlston', 'Sharlston', '', 53.6695600, -1.4129400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61783, 'Kennington', 'Kennington', 'کیننگٹن', 51.4879600, -0.1056600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61784, 'Bayswater', 'Bayswater', 'beizuu~ota,bezavotara,byyzwwtr,בייזווטר,بیزواٹر,बेज़वॉटर,ベイズウォーター', 51.5111600, -0.1842600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61785, 'Lambeth', 'Lambeth', 'Lambeth,Waterloo', 51.4963500, -0.1115200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61786, 'Tywyn', 'Tywyn', 'Tuuin,Тъуин', 52.5857800, -4.0927600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61787, 'West End of London', 'West End of London', 'West End', 51.5141400, -0.1551000, 'GB', '2016-03-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61788, 'Tankerton', 'Tankerton', '', 51.3637000, 1.0491300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61789, 'Thorpe Hamlet', 'Thorpe Hamlet', 'Thorpe,Thorpe Hamlet', 52.6277000, 1.3117500, 'GB', '2015-06-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61790, 'Cheadle Heath', 'Cheadle Heath', '', 53.4018600, -2.1908800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61791, 'Cameley', 'Cameley', '', 51.3161600, -2.5607900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61792, 'Bradley Cross', 'Bradley Cross', '', 51.2748800, -2.7625600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61793, 'South Chailey', 'South Chailey', '', 50.9383100, -0.0210500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61794, 'Copthorne', 'Copthorne', '', 51.1392900, -0.1174200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61795, 'Muirhead', 'Muirhead', '', 55.8980300, -4.1058000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61796, 'Yateley', 'Yateley', 'yatly,یاتلی', 51.3430500, -0.8298500, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61797, 'Oakmere', 'Oakmere', '', 53.2199600, -2.6405400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61798, 'East Ayton', 'East Ayton', '', 54.2548000, -0.4748300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61799, 'Westcliff-on-Sea', 'Westcliff-on-Sea', 'Westcliff,Westcliff-on-Sea', 51.5442400, 0.6917900, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61800, 'Didsbury', 'Didsbury', '', 53.4169800, -2.2314500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61801, 'Hellaby', 'Hellaby', '', 53.4225700, -1.2412500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61802, 'Langstone', 'Langstone', '', 51.6055400, -2.9120600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61803, 'Tintern', 'Tintern', 'Tintern,Tyndyrn,Тинтерн', 51.6967700, -2.6814200, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61804, 'Barham', 'Barham', '', 51.2057000, 1.1573400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61805, 'Bowthorpe', 'Bowthorpe', '', 52.6388400, 1.2188500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61806, 'Hedge End', 'Hedge End', '', 50.9123400, -1.3007600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61807, 'Moodiesburn', 'Moodiesburn', '', 55.9150100, -4.0833100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61808, 'Virginia Water', 'Virginia Water', 'Virdzhinija Uoter,Вирджиния Уотер', 51.4034300, -0.5665100, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61809, 'Churt', 'Churt', '', 51.1360300, -0.7753400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61810, 'Danby', 'Danby', '', 54.4660600, -0.9107300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61811, 'Wychbold', 'Wychbold', '', 52.2904500, -2.1155500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61812, 'Gerrards Cross', 'Gerrards Cross', 'ghrrrds kras,غررردس كراس', 51.5861000, -0.5554300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61813, 'Maidenbower', 'Maidenbower', '', 51.1078100, -0.1528600, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61814, 'Furnace Green', 'Furnace Green', '', 51.1074200, -0.1688900, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61815, 'Broadfield', 'Broadfield', '', 51.0971400, -0.2066400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61816, 'Bewbush', 'Bewbush', '', 51.1032900, -0.2231200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61817, 'Gossops Green', 'Gossops Green', '', 51.1110500, -0.2172800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61818, 'Langley Green', 'Langley Green', '', 51.1281700, -0.1983500, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61819, 'St. Buryan', 'St. Buryan', '', 50.0744100, -5.6226000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61820, 'Erskine', 'Erskine', 'Arascain,Erskin,Erskine,arskyn,Ерскін,ارسکین', 55.9005000, -4.4502800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61821, 'Hale', 'Hale', '', 53.3783100, -2.3327100, 'GB', '2010-04-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61822, 'Bidford-on-avon', 'Bidford-on-avon', '', 52.1672500, -1.8565200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61823, 'Westhill', 'Westhill', '', 57.1526300, -2.2796600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61824, 'Clarkston', 'Clarkston', '', 55.7859400, -4.2765100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61825, 'Smithton', 'Smithton', '', 57.4795600, -4.1514100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61826, 'Kings Hill', 'Kings Hill', 'Kings Hill', 51.2743700, 0.4023700, 'GB', '2015-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61827, 'Crouch End', 'Crouch End', '', 51.5797100, -0.1237300, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61828, 'Clerkenwell', 'Clerkenwell', 'Klarkenuehll,klarkanavela,klrknwyl  lndn,Кларкенуэлл,کلرکنویل، لندن,क्लर्कनवेल', 51.5243800, -0.1102200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61829, 'Belsize Park', 'Belsize Park', '', 51.5476700, -0.1722800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61830, 'Barnsbury', 'Barnsbury', '', 51.5406700, -0.1167500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61831, 'Little Chalfont', 'Little Chalfont', '', 51.6682900, -0.5703800, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61832, 'Amersham on the Hill', 'Amersham on the Hill', '', 51.6746800, -0.6074200, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61833, 'Barbican', 'Barbican', '', 51.5198800, -0.0944600, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61834, 'Battersea', 'Battersea', 'ba te xi,baeteosi,baitarasi,बैटरसी,巴特锡,배터시', 51.4747500, -0.1554700, 'GB', '2012-05-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61835, 'Grange Hill', 'Grange Hill', '', 51.6118500, 0.0861200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61836, 'Collier Row', 'Collier Row', '', 51.5989300, 0.1660000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61837, 'Elm Park', 'Elm Park', '', 51.5497000, 0.2013600, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61838, 'Cranham', 'Cranham', '', 51.5656500, 0.2659000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61839, 'Chafford Hundred', 'Chafford Hundred', '', 51.4892000, 0.2944000, 'GB', '2016-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61840, 'Chadwell St Mary', 'Chadwell St Mary', '', 51.4814000, 0.3634300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61841, 'Culverstone Green', 'Culverstone Green', '', 51.3408500, 0.3468600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61842, 'Kingston upon Thames', 'Kingston upon Thames', 'Kingston,Kingston-apon-Tems,Kingston-na-Temzi,Kingston-upon-Thames,Kingstonium ad Tamesim,kingseuteon-eopontemseu,kingstana apona temsa,kyngstwn apwn tymz,tai wu shi he pan jin si dun,Кингстон-апон-Темс,Кінгстон-на-Темзі,کینگستون آپون تیمز,किंग्स्टन अपॉन टेम्स,泰晤士河畔金斯頓,킹스턴어폰템스', 51.4125900, -0.2974000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61843, 'Ditton Hill', 'Ditton Hill', '', 51.3794700, -0.3128100, 'GB', '2013-09-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61844, 'Hinchley Wood', 'Hinchley Wood', '', 51.3746100, -0.3383800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61845, 'South Croydon', 'South Croydon', 'South Croydon', 51.3621700, -0.0942100, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61846, 'Hornchurch', 'Hornchurch', 'honchachi,ホーンチャーチ', 51.5568500, 0.2166400, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61847, 'Hainault', 'Hainault', '', 51.6083600, 0.1071600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61848, 'Surbiton', 'Surbiton', 'Serbiton,sarbitana,sarbytwn,Сербитон,ساربیتون,सर्बिटन', 51.3914800, -0.2982500, 'GB', '2012-03-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61849, 'Ewell', 'Ewell', '', 51.3494800, -0.2494000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61850, 'Harold Wood', 'Harold Wood', '', 51.5946200, 0.2329400, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61851, 'Chadwell Heath', 'Chadwell Heath', 'caidavela hitha,चैडवेल हीथ', 51.5712100, 0.1327100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61852, 'Becontree', 'Becontree', 'bekanatri,बेकनट्री', 51.5529000, 0.1290000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61853, 'Brixton', 'Brixton', 'Brikston,beuligseuteon,brikstana,brykstwn,bryqstwn,bu li ke si dun,burikusuton,Брикстон,בריקסטון,برکسٹن,بریکستون,ब्रिक्स्टन,ブリクストン,布里克斯頓,브릭스턴', 51.4659300, -0.1065200, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61854, 'Bethnal Green', 'Bethnal Green', 'beseuneolgeulin,bethanala grina,بینتھل گرین,बेथनल ग्रीन,বেথনাল গ্রিন,베스널그린', 51.5271800, -0.0610900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61855, 'Cheetham Hill', 'Cheetham Hill', '', 53.4986200, -2.2384600, 'GB', '2010-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61856, 'Failsworth', 'Failsworth', 'Fehjlzuort,Фэйлзуорт', 53.5048400, -2.1656800, 'GB', '2012-04-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61857, 'Crumpsall', 'Crumpsall', '', 53.5182700, -2.2444700, 'GB', '2010-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61858, 'Blackley', 'Blackley', '', 53.5176500, -2.2144300, 'GB', '2010-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61859, 'Radcliffe', 'Radcliffe', '', 53.5617800, -2.3245500, 'GB', '2012-04-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61860, 'Heywood', 'Heywood', 'Heywood,Heywood i Stor-Manchester,Monkey Town,hywwd  mnchstr bzrg,هیوود، منچستر بزرگ', 53.5924500, -2.2194100, 'GB', '2010-04-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61861, 'Hollingworth', 'Hollingworth', '', 53.4630000, -1.9910000, 'GB', '2017-05-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61862, 'Chorlton cum Hardy', 'Chorlton cum Hardy', 'Chorlton,Chorlton cum Hardy,Chorlton-cum-Hardy', 53.4350500, -2.2631000, 'GB', '2010-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61863, 'Burnage', 'Burnage', '', 53.4326500, -2.1996700, 'GB', '2010-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61864, 'Fallowfield', 'Fallowfield', '', 53.4398100, -2.2157200, 'GB', '2010-03-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61865, 'Heaton Chapel', 'Heaton Chapel', '', 53.4301500, -2.1753800, 'GB', '2010-04-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61866, 'Haughton Green', 'Haughton Green', '', 53.4411800, -2.0982700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61867, 'Hulme', 'Hulme', '', 53.4657200, -2.2488500, 'GB', '2010-04-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61868, 'Longsight', 'Longsight', '', 53.4580100, -2.2010400, 'GB', '2010-04-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61869, 'Heavitree', 'Heavitree', '', 50.7204400, -3.4964600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61870, 'Ferndown', 'Ferndown', 'Ferndaun,frndawn,Ферндаун,فرنداون', 50.8074300, -1.8997500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61871, 'Clayton-le-Woods', 'Clayton-le-Woods', '', 53.6968900, -2.6681800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61872, 'Portland', 'Portland', 'Isle of Portland,Portland', 50.5674800, -2.4447200, 'GB', '2015-04-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61873, 'Canary Wharf', 'Canary Wharf', 'Kanari-Uorf,Kanehri-Uorf,jin si que ma tou,kanali wopeu,knary warf,kynry warf  lndn,qnry wwrp,Канэри-Уорф,קנרי וורף,كناري وارف,کینری وارف، لندن,カナリー・ワーフ,金丝雀码头,카나리 워프', 51.5051900, -0.0208500, 'GB', '2015-09-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61874, 'Coatham Mundeville', 'Coatham Mundeville', '', 54.5800200, -1.5564500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61875, 'Billington', 'Billington', '', 53.8157000, -2.4236000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61876, 'Brixton Hill', 'Brixton Hill', '', 51.4521300, -0.1230000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61877, 'Nether Heyford', 'Nether Heyford', '', 52.2212300, -1.0345200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61878, 'Featherstone', 'Featherstone', '', 52.6448300, -2.0931500, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61879, 'Belmont', 'Belmont', '', 52.0427200, -2.7416900, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61880, 'Calcot', 'Calcot', 'Calcot,Calcot Row', 51.4405800, -1.0509100, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61881, 'Benwell', 'Benwell', '', 54.9729600, -1.6692600, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61882, 'Earl Shilton', 'Earl Shilton', 'ayrl shyltwn,ایرل شیلتون', 52.5768200, -1.3153600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61883, 'St. Georges', 'St. Georges', '', 51.3622400, -2.8979900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61884, 'Carden', 'Carden', '', 53.0721400, -2.7973500, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61885, 'Bay Horse', 'Bay Horse', '', 53.9686700, -2.7760300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61886, 'Adlington', 'Adlington', '', 53.3204200, -2.1365800, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61887, 'Colden Common', 'Colden Common', '', 50.9948300, -1.3114300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61888, 'Winterbourne', 'Winterbourne', '', 51.5232700, -2.5043700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61889, 'Charvil', 'Charvil', '', 51.4757300, -0.8859100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61890, 'Essington', 'Essington', '', 52.6291000, -2.0577000, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61891, 'Bordon', 'Bordon', '', 51.1135700, -0.8624500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61892, 'Knaphill', 'Knaphill', '', 51.3201000, -0.6158400, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61893, 'Lytham St Annes', 'Lytham St Annes', 'Lidum Sejnt Anns,Lytham,Lytham St Annes,Lytham St. Annes,St Annes,lytham snt ans,Лидъм Сейнт Аннс,لیتهام سنت آنس', 53.7426000, -2.9970000, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61894, 'Curdworth', 'Curdworth', '', 52.5338200, -1.7368700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61895, 'Chorlton', 'Chorlton', '', 53.0502900, -2.4054100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61896, 'Little Hallingbury', 'Little Hallingbury', '', 51.8332400, 0.1815100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61897, 'Hoole', 'Hoole', '', 53.1998000, -2.8768900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61898, 'Eight Ash Green', 'Eight Ash Green', '', 51.8958700, 0.8228000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61899, 'Peaslake', 'Peaslake', '', 51.1915600, -0.4465800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61900, 'Woodbury', 'Woodbury', '', 50.6766400, -3.4016000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61901, 'Larkfield', 'Larkfield', '', 51.3014300, 0.4485500, 'GB', '2017-06-10', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61902, 'Catcliffe', 'Catcliffe', '', 53.3931600, -1.3620700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61903, 'Walton', 'Walton', '', 53.6488600, -1.4658200, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61904, 'Hadley Wood', 'Hadley Wood', '', 51.6666900, -0.1698100, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61905, 'Greenhill', 'Greenhill', '', 51.5834200, -0.3386000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61906, 'Grappenhall', 'Grappenhall', '', 53.3720400, -2.5467500, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61907, 'Prenton', 'Prenton', 'Prenton', 53.3676200, -3.0547900, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61908, 'Silver End', 'Silver End', '', 51.8473400, 0.6239900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61909, 'Great Marton', 'Great Marton', '', 53.8118500, -3.0226100, 'GB', '2010-04-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61910, 'Whiston', 'Whiston', 'Whiston i Merseyside,wi s tan,wytsn  mrzysayd,ویتسن، مرزیساید,วิสตัน', 53.4199700, -2.7890700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61911, 'Eaglescliffe', 'Eaglescliffe', '', 54.5252100, -1.3504300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61912, 'Mottram St. Andrew', 'Mottram St. Andrew', '', 53.3061600, -2.1814700, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61913, 'Barnwood', 'Barnwood', '', 51.8639300, -2.2008700, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61914, 'Chapel Allerton', 'Chapel Allerton', 'Chapel A,Chapel Allerton', 53.8290100, -1.5383400, 'GB', '2008-07-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61915, 'Ash', 'Ash', '', 51.2788300, 1.2797400, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61916, 'Greenfield', 'Greenfield', '', 52.0027800, -0.4660500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61917, 'Byram', 'Byram', 'Byram,Byram cum Sutton', 53.7239400, -1.2612800, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61918, 'New Marske', 'New Marske', '', 54.5784800, -1.0422400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61919, 'Winscombe', 'Winscombe', '', 51.3181000, -2.8322400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61920, 'Newcastle', 'Newcastle', 'An Caislean Nua,An Caisleán Nua,N''jukasl,Newcastle,Njukasul,Ньюкасл,Нюкасъл', 54.2180400, -5.8897900, 'GB', '2016-12-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61921, 'Chiseldon', 'Chiseldon', '', 51.5160600, -1.7320600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61922, 'Milton of Campsie', 'Milton of Campsie', '', 55.9612000, -4.1650800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61923, 'Southchurch Village', 'Southchurch Village', '', 51.5404900, 0.7293500, 'GB', '2010-01-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61924, 'Darras Hall', 'Darras Hall', '', 55.0356000, -1.7642500, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61925, 'Bodle Street', 'Bodle Street', 'Bodle Street,Bodle Street Green', 50.9129900, 0.3433200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61926, 'Donnington', 'Donnington', '', 51.9513500, -1.7214200, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61927, 'Babworth', 'Babworth', '', 53.3179900, -0.9758300, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61928, 'Appleton Thorn', 'Appleton Thorn', '', 53.3504500, -2.5448800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61929, 'Guilden Sutton', 'Guilden Sutton', '', 53.2080900, -2.8298400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61930, 'Blacon', 'Blacon', '', 53.2083200, -2.9253000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61931, 'Chelmsley Wood', 'Chelmsley Wood', '', 52.4781000, -1.7381300, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61932, 'Crawley Down', 'Crawley Down', '', 51.1206100, -0.0773000, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61933, 'Roslin', 'Roslin', 'Roslin,Rosslyn', 55.8574900, -3.1689500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61934, 'Bilston', 'Bilston', '', 55.8703000, -3.1781400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61935, 'Grange-over-Sands', 'Grange-over-Sands', '', 54.1850800, -2.9248800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61936, 'Cowplain', 'Cowplain', '', 50.8941100, -1.0182400, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61937, 'Ruardean', 'Ruardean', '', 51.8550100, -2.5505400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61938, 'Canford Heath', 'Canford Heath', '', 50.7510000, -1.9686200, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61939, 'High Barnet', 'High Barnet', '', 51.6562100, -0.2076800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61940, 'Balsall Common', 'Balsall Common', '', 52.3918600, -1.6504000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61941, 'Ingleton', 'Ingleton', '', 54.1539200, -2.4684900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61942, 'Eton Wick', 'Eton Wick', '', 51.4972200, -0.6343700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61943, 'St Mary''s', 'St Mary''s', 'Ennor,Saint Mary''s,St Mary''s', 49.9171900, -6.2951700, 'GB', '2014-06-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61944, 'Penparcau', 'Penparcau', '', 52.4033300, -4.0741700, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61945, 'Chalton', 'Chalton', '', 51.9279000, -0.5014700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61946, 'Husborne Crawley', 'Husborne Crawley', '', 52.0163700, -0.6105600, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61947, 'Blackheath', 'Blackheath', 'beullaeghiseu,blakhyth,بلاكهيث,블랙히스', 51.4647000, 0.0079000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61948, 'Stewartby', 'Stewartby', '', 52.0704400, -0.5149000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61949, 'Kempston Hardwick', 'Kempston Hardwick', '', 52.0895600, -0.4990800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61950, 'Bilsdale', 'Bilsdale', '', 54.3735600, -1.1192300, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61951, 'Hameldon Hill', 'Hameldon Hill', '', 53.7557000, -2.2919000, 'GB', '2010-05-24', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61952, 'Mendip', 'Mendip', '', 51.2372000, -2.6266000, 'GB', '2010-05-25', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61953, 'Eversley', 'Eversley', '', 51.3538700, -0.8888800, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61954, 'Y Felinheli', 'Y Felinheli', 'Felinheli,Port Dinorwic,Y Felinheli', 53.1873700, -4.2047600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61955, 'St Mary''s Bay', 'St Mary''s Bay', '', 51.0100300, 0.9771000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61956, 'Murton', 'Murton', '', 53.9660700, -1.0107000, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61957, 'Aylesham', 'Aylesham', '', 51.2253900, 1.2015700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61958, 'Lightwater', 'Lightwater', '', 51.3484600, -0.6714700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61959, 'Gartcosh', 'Gartcosh', '', 55.8884100, -4.0817000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61960, 'Kelloe', 'Kelloe', '', 54.7189400, -1.4749500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61961, 'Easington Colliery', 'Easington Colliery', '', 54.7879200, -1.3281900, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61962, 'Llanrhaeadr-ym-Mochnant', 'Llanrhaeadr-ym-Mochnant', '', 52.8250700, -3.3022500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61963, 'Lower Earley', 'Lower Earley', '', 51.4270800, -0.9197900, 'GB', '2011-03-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61964, 'Isle Of Mull', 'Isle Of Mull', 'Isle of Mull,Muile', 56.4470300, -5.7740400, 'GB', '2014-12-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61965, 'Iver Heath', 'Iver Heath', '', 51.5364200, -0.5179000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61966, 'Bartley Green', 'Bartley Green', '', 52.4353200, -1.9970700, 'GB', '2010-05-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61967, 'Grimethorpe', 'Grimethorpe', '', 53.5765000, -1.3768800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61968, 'Abbey Wood', 'Abbey Wood', 'ایبی وڈ', 51.4868800, 0.1074700, 'GB', '2010-05-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61969, 'Ovington', 'Ovington', '', 54.5279100, -1.7982400, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61970, 'Grimbsy', 'Grimbsy', '', 53.5598900, -0.0988800, 'GB', '2010-07-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61971, 'Summerhouse', 'Summerhouse', '', 54.5672800, -1.6892300, 'GB', '2011-07-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61972, 'Seer Green', 'Seer Green', '', 51.6179600, -0.6059200, 'GB', '2010-08-21', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61973, 'Elmstead Market', 'Elmstead Market', '', 51.8821900, 0.9948200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61974, 'Danderhall', 'Danderhall', '', 55.9143400, -3.1106200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61975, 'Denmead', 'Denmead', '', 50.9039500, -1.0674400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61976, 'Nanpean', 'Nanpean', '', 50.3688400, -4.8693500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61977, 'Cross Hills', 'Cross Hills', '', 53.9060600, -1.9849200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61978, 'Netherseal', 'Netherseal', '', 52.7154000, -1.5772200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61979, 'Canvey Island', 'Canvey Island', 'Canvey saar,Kanvi,Oilean Canvey,Oileán Canvey,jzyrkh kanwy,Канви,جزیرخ کانوی', 51.5219900, 0.5809000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61980, 'Shotts', 'Shotts', 'Na Seots,Shotts', 55.8195100, -3.7974900, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61981, 'North Duffield', 'North Duffield', '', 53.8257900, -0.9641400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61982, 'Earlsfield', 'Earlsfield', '', 51.4439000, -0.1854000, 'GB', '2011-11-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61983, 'Eastriggs', 'Eastriggs', '', 54.9859700, -3.1805100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61984, 'Westergate', 'Westergate', '', 50.8398800, -0.6712300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61985, 'Peacehaven', 'Peacehaven', 'New Anzac-on-Sea,Peacehaven,pyshywn,پیسهیون', 50.7927000, -0.0065200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61986, 'North Baddesley', 'North Baddesley', '', 50.9774500, -1.4454700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61987, 'Bedlinog', 'Bedlinog', '', 51.7043200, -3.3130600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61988, 'Appleby-in-Westmorland', 'Appleby-in-Westmorland', 'Appleby,aepeulbiin-weseuteumeolleondeu,aplby-ayn-wstmwrlnd,wei si mo lan a pu bi,اپلبی-این-وستمورلند,威斯摩蘭阿普比,애플비인웨스트멀런드', 54.5770400, -2.4897800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61989, 'Bracebridge Heath', 'Bracebridge Heath', '', 53.1964700, -0.5342100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61990, 'Glapwell', 'Glapwell', '', 53.1891700, -1.2833400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61991, 'Asfordby', 'Asfordby', '', 52.7633100, -0.9585600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61992, 'Stansted Mountfitchet', 'Stansted Mountfitchet', '', 51.9012000, 0.1989600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61993, 'Letchworth Garden City', 'Letchworth Garden City', 'Letchworth,Letchworth Garden City', 51.9793800, -0.2266400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61994, 'Pevensey Bay', 'Pevensey Bay', '', 50.8124200, 0.3486400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61995, 'Cradley Heath', 'Cradley Heath', '', 52.4721400, -2.0821200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61996, 'Shirley', 'Shirley', '', 52.4107400, -1.8195200, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61997, 'Stanley', 'Stanley', '', 54.8679600, -1.6984600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61998, 'Stockton Heath', 'Stockton Heath', '', 53.3708400, -2.5740600, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(61999, 'Waterloo', 'Waterloo', '', 53.4745400, -3.0301700, 'GB', '2012-03-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62000, 'Pontyclun', 'Pontyclun', 'Pont-y-clun', 51.5216200, -3.3914500, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62001, 'Pentre', 'Pentre', '', 51.6542900, -3.4913300, 'GB', '2012-04-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62002, 'Catterick Garrison', 'Catterick Garrison', '', 54.3774800, -1.7223200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62003, 'Maple Cross', 'Maple Cross', '', 51.6250000, -0.5080000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62004, 'Rossendale', 'Rossendale', 'Borough of Rossendale,Rossendale,Rossendale District', 53.6845600, -2.2769000, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62005, 'Thornton-Cleveleys', 'Thornton-Cleveleys', 'Thornton-Cleveleys', 53.8738900, -3.0224400, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62006, 'Deeside', 'Deeside', 'Deeside,Glannau Dyfrdwy', 53.2005300, -3.0384100, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62007, 'High Peak', 'High Peak', 'Dark Peak,High Peak,High Peak District,High Peak Hundred', 53.3679700, -1.8453600, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62008, 'Romney Marsh', 'Romney Marsh', 'Romney Marsh', 51.0229900, 0.9150400, 'GB', '2013-07-11', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62009, 'Hayling Island', 'Hayling Island', 'Hayling Island,Insula Hayling,Khejling,Хејлинг', 50.7838000, -0.9686900, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62010, 'Isle of Lewis', 'Isle of Lewis', 'Eilean Leodhais,Isle of Lewis,Leodhas,Lewis,Leòdhas', 58.2190100, -6.3880300, 'GB', '2014-03-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62011, 'Shetland', 'Shetland', 'Shetland', 60.1545600, -1.1489900, 'GB', '2012-07-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62012, 'Isle of Bute', 'Isle of Bute', 'Bure,Bute,Isle of Bute', 55.8366300, -5.0558600, 'GB', '2014-05-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62013, 'Orkney', 'Orkney', 'Arcaibh,Arknejskija astravy,Illes Orcades,Illes Òrcades,Inizi Orch,Inse Orc,Isole Orcadi,Orcadas,Orcades,Orcades insulae,Orcanege,Orkadak,Orkades,Orkadoj,Orkady,Orkneje,Orknejs''ki ostrovi,Orknejskie ostrova,Orkneju salas,Orknejy sakuadaekhtae,Orkney,Orkney Adalari,Orkney Adaları,Orkney Islands,Orkney saared,Orkney-eilanden,Orkney-eilannen,Orkney-szigetek,Orkneyan kgziner,Orkneyjar,Orkneyoearna,Orkneyoerne,Orkneysaaret,Orkneyski otoci,Orkneyöarna,Orkneyøerne,Orkni,Orknijska ostrva,Orknio salos,Orkniski Ostrovi,Orknoyane,Orknoyene,Orknoyggjar,Orknøyane,Orknøyene,Yn Orkaid,Ynysoedd Erch,ao ke ni qun dao,awrkny,jzr awrkny,okeuni jedo,okuni zhu dao,xxrkni y,Órcadas,Órcades,Ορκάδες,Аркнейскія астравы,Оркнейские острова,Оркнейські острови,Оркнейы сакъадæхтæ,Оркни,Оркниски Острови,Оркнијска острва,Օրկնեյան կղզիներ,אורקני,اورکنی,اورکنے,جزر أوركني,ออร์กนีย์,ኦርክኒ,オークニー諸島,奥克尼群岛,오크니 제도', 58.9846500, -2.9595300, 'GB', '2012-06-01', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62014, 'Hope Valley', 'Hope Valley', 'Hope Valley', 53.3481900, -1.7448500, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62015, 'Isle of Arran', 'Isle of Arran', 'Arran,Eilean Arainn,Isle of Arran', 55.5814500, -5.2123300, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62016, 'Stoke-sub-Hamdon', 'Stoke-sub-Hamdon', 'Stoke-sub-Hamdon', 50.9539700, -2.7497100, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62017, 'Tintagel', 'Tintagel', 'Dyntagell,Tintagel,Tintankel,Tre war Venydh,Trevena,ting ta zhe,tintajeru,tyntghl,Τίνταγκελ,טינטאגל,تينتغل,ティンタジェル,廷塔哲', 50.6631700, -4.7504700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62018, 'Isle of North Uist', 'Isle of North Uist', 'Isle of North Uist,North Uist,Uibhist a Tuath', 57.6058100, -7.3402400, 'GB', '2014-03-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62019, 'Isle of South Uist', 'Isle of South Uist', 'Isle of South Uist,South Uist,Uibhist a Deas', 57.2456200, -7.3333700, 'GB', '2014-03-08', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62020, 'Menstrie', 'Menstrie', 'Meanstraidh,Menstrie', 56.1513800, -3.8546600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62021, 'Isle of Cumbrae', 'Isle of Cumbrae', 'Cumaradh Mor,Cumaradh Mòr,Cumbrae,Great Cumbrae,Isle of Cumbrae', 55.7693300, -4.9191300, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62022, 'Isles of Scilly', 'Isles of Scilly', 'Enesek Syllan,Isles of Scilly,Syllan', 49.9251500, -6.2989400, 'GB', '2016-06-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62023, 'Harris', 'Harris', 'Harris,Isle of Harris,Na Hearadh', 57.8993400, -6.8028500, 'GB', '2015-02-22', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62024, 'Rosewell', 'Rosewell', 'Rosewell', 55.8507500, -3.1362500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62025, 'Isle of Islay', 'Isle of Islay', 'Ile,Islay,Isle of Islay,Queen of the Hebrides,Ìle', 55.7852600, -6.2388600, 'GB', '2013-01-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62026, 'Dyffryn Ardudwy', 'Dyffryn Ardudwy', 'Dyffryn Ardudwy', 52.7774800, -4.0646800, 'GB', '2012-06-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62027, 'Merriott', 'Merriott', 'Merriott', 50.9127500, -2.7953800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62028, 'Barra', 'Barra', 'BRR,Barra,Barraigh,Eilean Bharraigh,Isle of Barra', 56.9803500, -7.4573100, 'GB', '2013-02-02', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62029, 'Benbecula', 'Benbecula', 'Benbecula,Isle of Benbecula', 57.4473700, -7.3427300, 'GB', '2014-12-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62030, 'Holloway', 'Holloway', 'Holloway', 51.5523700, -0.1249700, 'GB', '2012-06-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62031, 'Penyffordd', 'Penyffordd', '', 53.1482900, -3.0458400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62032, 'Water Eaton', 'Water Eaton', '', 51.9869700, -0.7218800, 'GB', '2013-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62033, 'Harringay', 'Harringay', '', 51.5824000, -0.0995600, 'GB', '2013-07-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62034, 'Sonning Common', 'Sonning Common', '', 51.5187300, -0.9775300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62035, 'Four Lanes', 'Four Lanes', '', 50.2016300, -5.2401400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62036, 'Dalgety Bay', 'Dalgety Bay', '', 56.0349600, -3.3504900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62037, 'Tweedbank', 'Tweedbank', '', 55.6044900, -2.7669200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62038, 'Abridge', 'Abridge', '', 51.6495000, 0.1203300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62039, 'Lower Broadheath', 'Lower Broadheath', '', 52.2137900, -2.2772400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62040, 'Chopwell', 'Chopwell', '', 54.9179700, -1.8201300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62041, 'Hinton', 'Hinton', '', 52.1679800, -1.2183700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62042, 'Cambourne', 'Cambourne', 'Kamburn,kmbwrn,Камбурн,كمبورن', 52.2211500, -0.0702500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62043, 'Cotheridge', 'Cotheridge', '', 52.1923500, -2.3129200, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62044, 'Fulking', 'Fulking', '', 50.8896000, -0.2268900, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62045, 'Ealing Broadway', 'Ealing Broadway', '', 51.5156600, -0.3007900, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62046, 'Moreton Jeffries', 'Moreton Jeffries', '', 52.1358600, -2.5796000, 'GB', '2014-08-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62047, 'Frilford', 'Frilford', '', 51.6710100, -1.3635900, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62048, 'Perranarworthal', 'Perranarworthal', 'Perenoworthal', 50.2057500, -5.1199300, 'GB', '2014-08-28', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62049, 'Mount Hawke', 'Mount Hawke', '', 50.2822900, -5.2085500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62050, 'Anna Valley', 'Anna Valley', '', 51.1931700, -1.5071900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62051, 'East Ruston', 'East Ruston', '', 52.7953400, 1.4756900, 'GB', '2014-12-30', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62052, 'Bradley', 'Bradley', '', 53.0115300, -1.6687200, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62053, 'Stanton Drew', 'Stanton Drew', '', 51.3674900, -2.5864600, 'GB', '2014-12-31', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62054, 'Hoveton', 'Hoveton', '', 52.7149000, 1.4105400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62055, 'Rodsley', 'Rodsley', '', 52.9600900, -1.7000100, 'GB', '2015-01-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62056, 'Yeldersley', 'Yeldersley', '', 52.9894700, -1.6616800, 'GB', '2015-01-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62057, 'Greenham', 'Greenham', '', 51.3868900, -1.3114500, 'GB', '2015-01-03', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62058, 'Surlingham', 'Surlingham', '', 52.6070600, 1.4200700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62059, 'Rockland Saint Mary', 'Rockland Saint Mary', '', 52.5864700, 1.4081400, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62060, 'Hellington', 'Hellington', '', 52.5789800, 1.4132900, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62061, 'Uckington', 'Uckington', '', 51.9230400, -2.1254300, 'GB', '2015-01-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62062, 'Shipton', 'Shipton', '', 51.8674600, -1.9441500, 'GB', '2015-06-29', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62063, 'Milland', 'Milland', '', 51.0311700, -0.8037600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62064, 'Lindford', 'Lindford', '', 51.1189100, -0.8465500, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62065, 'Bridge Sollers', 'Bridge Sollers', '', 52.0766000, -2.8609900, 'GB', '2015-02-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62066, 'Barton', 'Barton', '', 52.1832500, 0.0578100, 'GB', '2015-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62067, 'Grantchester', 'Grantchester', '', 52.1809300, 0.0907200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62068, 'Angram Grange', 'Angram Grange', '', 54.1857200, -1.2124000, 'GB', '2015-02-16', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62069, 'Deiniolen', 'Deiniolen', '', 53.1481900, -4.1318500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62070, 'Wimpole', 'Wimpole', '', 52.1307700, -0.0339000, 'GB', '2015-02-17', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62071, 'Headley', 'Headley', '', 51.2806000, -0.2769800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62072, 'Thorpe Bassett', 'Thorpe Bassett', '', 54.1485600, -0.6858700, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62073, 'Marishes', 'Marishes', '', 54.2035700, -0.7492200, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62074, 'Huttons Ambo', 'Huttons Ambo', '', 54.1032400, -0.8474100, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62075, 'Tidbury Green', 'Tidbury Green', '', 52.3809200, -1.8561700, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62076, 'Dickens Heath', 'Dickens Heath', '', 52.3856800, -1.8393500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62077, 'Cheswick Green', 'Cheswick Green', '', 52.3803700, -1.8137300, 'GB', '2015-02-18', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62078, 'Five Oak Green', 'Five Oak Green', '', 51.1833800, 0.3551700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62079, 'Town Row', 'Town Row', '', 51.0530200, 0.2321700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62080, 'Ynysybwl', 'Ynysybwl', '', 51.6392200, -3.3603600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62081, 'Wormley', 'Wormley', '', 51.1362200, -0.6467300, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62082, 'Windygates', 'Windygates', '', 56.1954600, -3.0527400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62083, 'Swarthmoor', 'Swarthmoor', '', 54.1846600, -3.1170700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62084, 'Talysarn', 'Talysarn', '', 53.0536500, -4.2576700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62085, 'Carronshore', 'Carronshore', '', 56.0314600, -3.7829000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62086, 'West Kingsdown', 'West Kingsdown', '', 51.3428100, 0.2612700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62087, 'Bellsbank', 'Bellsbank', '', 55.3131000, -4.3986900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62088, 'Rusthall', 'Rusthall', '', 51.1364300, 0.2293100, 'GB', '2015-05-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62089, 'Logan', 'Logan', '', 55.4546600, -4.2351400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62090, 'East Rainton', 'East Rainton', '', 54.8251300, -1.4803600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62091, 'Capel le Ferne', 'Capel le Ferne', '', 51.1033900, 1.2116500, 'GB', '2017-06-13', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62092, 'Wood Street Village', 'Wood Street Village', '', 51.2509800, -0.6369500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62093, 'Fairlands', 'Fairlands', '', 51.2617800, -0.6214100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62094, 'Wolvercote', 'Wolvercote', '', 51.7840600, -1.2933800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62095, 'Stratton', 'Stratton', '', 51.7339400, -1.9796800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62096, 'Gronant', 'Gronant', '', 53.3366900, -3.3603100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62097, 'Shortlands', 'Shortlands', '', 51.3991400, 0.0044000, 'GB', '2015-09-23', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62098, 'Hockley Heath', 'Hockley Heath', '', 52.3529400, -1.7781600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62099, 'St Just', 'St Just', 'LEQ', 50.1237900, -5.6806500, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62100, 'Fleckney', 'Fleckney', '', 52.5349700, -1.0459800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62101, 'Aston-on-Trent', 'Aston-on-Trent', '', 52.8617200, -1.3864200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62540, 'Santiago de Baney', 'Santiago de Baney', 'Baney,Bany,Laka-Baney,Santiago de Baney', 3.6992000, 8.9084000, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62541, 'San Antonio de Palé', 'San Antonio de Pale', 'NBN,Pagalu,Pale,Palé,San Antonio,San Antonio de Pale,San Antonio de Palé,San Antonio de Praia,San-Antonio-de-Pale,St Antony,san''antonio・de・pare,san-antoniodepalle,sn ʼntwnyw dh pʼlh,Сан-Антонио-де-Пале,Сан-Антоніо-де-Пале,סן אנטוניו דה פאלה,サンアントニオ・デ・パレ,산안토니오데팔레', -1.4068000, 5.6317800, 'GQ', '2015-11-29', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62542, 'Río Campo', 'Rio Campo', 'Rio Campo,Río Campo', 2.3381200, 9.8221200, 'GQ', '2012-01-18', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62543, 'Rebola', 'Rebola', 'Rebola', 3.7166700, 8.8333300, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62544, 'Nsok', 'Nsok', 'Ensorc,N''Zork,Nsoc,Nsok,Nsorc,Nsork,N’Zork', 1.1298500, 11.2660300, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62545, 'Nsang', 'Nsang', 'Ensang,Nsang', 2.0247500, 10.9459900, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62546, 'Ncue', 'Ncue', 'Ncue,Nkue,Nkue Mision,Nkue Misión,San Francisco Javier', 2.0164300, 10.4706600, 'GQ', '2011-10-27', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62547, 'Mongomo', 'Mongomo', 'GEM,Margomo,Mongomo,Mongomo de Guadalupe', 1.6274200, 11.3134600, 'GQ', '2015-11-29', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62548, 'Mikomeseng', 'Mikomeseng', 'Mekomeseng,Micomeseng,Mikamesen,Mikomesen,Mikomeseng', 2.1360900, 10.6132200, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62549, 'Mbini', 'Mbini', 'Benito,Mbini,Rio Benito,Río Benito,San Benito', 1.5826700, 9.6147800, 'GQ', '2014-10-08', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62550, 'Machinda', 'Machinda', 'Machinda', 1.8826200, 9.9513300, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62551, 'Evinayong', 'Evinayong', 'Ebinayon,Ebinayong,Ebineyon,Ebinoyon,Evinayong', 1.4367700, 10.5512400, 'GQ', '2012-01-18', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62552, 'Ebebiyin', 'Ebebiyin', 'Ebebiin,Ebebijinas,Ebebiyin,Ebebiyín,Ebibeyin,Ebibeying,Ehbeb''in,ai bei bi yin,ebebiin,ebebiini,Ебебіїн,Эбебьин,ებებიინი,エベビイン,埃贝比因,에베비인', 2.1510600, 11.3352800, 'GQ', '2014-04-26', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62553, 'Malabo', 'Malabo', 'Ciudad de Malabo,Malaba,Malabas,Malabo,Malabó,Malampo,Port Clarence,Rev Malebo,SSG,Santa Isabel,ma la bo,mala bo,malabo,malabw,malapo,mallabo,marabo,mlabw,Μαλάμπο,Малаба,Малабо,Մալաբո,מלאבו,مالابو,مالابۆ,ملابو,मलाबो,ਮਲਾਬੋ,மலாபோ,มาลาโบ,མ་ལ་བོ།,მალაბო,ማላቦ,マラボ,馬拉博,말라보', 3.7500000, 8.7833300, 'GQ', '2014-04-27', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62554, 'Luba', 'Luba', 'Ciudad de Luba,Luba,San Carlos,lu ba,luba,ruba,Луба,ルバ,盧巴,루바', 3.4568300, 8.5546500, 'GQ', '2012-01-18', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62555, 'Bitica', 'Bitica', 'Bitica,Bitika', 1.4261000, 9.6231600, 'GQ', '2012-01-18', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62556, 'Bicurga', 'Bicurga', 'Bicurga,Bikurga', 1.5811300, 10.4671600, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62557, 'Bata', 'Bata', 'BSG,Bata,Batao,Gorad Bata,Kokapipa,ba ta,bata,Бата,Горад Бата,באטה,باتا,ბატა,バタ,巴塔,바타', 1.8639100, 9.7658200, 'GQ', '2011-10-27', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62558, 'Ayene', 'Ayene', 'Ayene,Ayene-Enduguensan', 1.8559200, 10.6899400, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62559, 'Añisoc', 'Anisoc', 'Anisoc,Anisok,Añisoc,Añisok', 1.8658000, 10.7689200, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62560, 'Acurenam', 'Acurenam', 'Acurenam,Acurenan,Acurnam,Akourenam,Akournam,Akurenam,Akurenan,Akurnam', 1.0322500, 10.6488200, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62561, 'Aconibe', 'Aconibe', 'Aconibe,Akonebe', 1.2968300, 10.9369100, 'GQ', '2013-06-07', 68);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62292, 'Tonate', 'Tonate', 'Tonale,Tonate', 5.0117100, -52.4724100, 'GF', '2016-06-22', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62293, 'Sinnamary', 'Sinnamary', 'Sinamary,Sinnama,Sinnamari,Sinnamary', 5.3767600, -52.9567900, 'GF', '2015-07-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62294, 'Saint-Laurent-du-Maroni', 'Saint-Laurent-du-Maroni', 'LDX,Laurent,Maroni,Saint Laurent,Saint-Laurent-du-Maroni,Sainte Laurent,Sen Loran di Maroni,Sen Loren du Maroni,Sen-Loran-dju-Maroni,ma luo ni he pan sheng luo lang,san lwran dw marwny,san=roran=de~yu=maroni,sn lwran dw mrwny,Сен Лоран ди Марони,Сен-Лоран-дю-Марони,Сен-Лоран-дю-Мароні,سان لوران دو ماروني,سن لوران دو مرونی,سینٹ-لارنٹ-دو-مارونی,サン＝ローラン＝デュ＝マロニ,马罗尼河畔圣洛朗', 5.5010100, -54.0294100, 'GF', '2017-07-08', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62295, 'Saint-Georges', 'Saint-Georges', 'OYP,Oyapock,Saint Georges,Saint-Georges,Saint-Georges-de-l''Oyapock,San Jorge de Oyapoque,Sen-Zhorzh,Sen-Zhorzh-de-Luapok,saengjoleuju,Сен-Жорж,Сен-Жорж-де-Луапок,생조르주', 3.8885700, -51.8024300, 'GF', '2017-02-04', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62296, 'Roura', 'Roura', 'Roura', 4.7251900, -52.3261600, 'GF', '2015-06-08', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62297, 'Rémire', 'Remire', 'Ramire,Remire,Rémire,Rémiré', 4.8844100, -52.2786800, 'GF', '2016-06-22', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62298, 'Régina', 'Regina', 'REI,Regina,Régina', 4.3130000, -52.1308300, 'GF', '2017-07-08', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62299, 'Rémire-Montjoly', 'Remire-Montjoly', 'Montjoli', 4.9166700, -52.2666700, 'GF', '2011-12-14', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62300, 'Matoury', 'Matoury', 'Matoary,Matoury', 4.8487200, -52.3256500, 'GF', '2015-06-08', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62301, 'Maripasoula', 'Maripasoula', 'MPY,Maripasoula,Maripasula,marybaswla,marypasywla,Марипасула,ماريباسولا,ماریپاسئولا', 3.6415500, -54.0316700, 'GF', '2015-08-07', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62302, 'Mana', 'Mana', 'Mana', 5.6676600, -53.7782800, 'GF', '2015-07-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62303, 'Macouria', 'Macouria', 'Macouria', 4.9121600, -52.3743200, 'GF', '2016-06-22', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62304, 'Kourou', 'Kourou', 'Bourg de Kourou,Kouro,Kourou,Kur,Kuru,QKR,ku lu,kuru,kwrwa,Кур,Куру,كوروا,クールー,库鲁', 5.1628100, -52.6426500, 'GF', '2015-10-08', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62305, 'Iracoubo', 'Iracoubo', 'Iracoubo', 5.4787100, -53.2052400, 'GF', '2015-07-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62306, 'Grand-Santi', 'Grand-Santi', 'GSI,Grand-Santi', 4.2729500, -54.3814600, 'GF', '2016-04-24', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62307, 'Cayenne', 'Cayenne', 'CAY,Caiena,Caienna,Cajen-a,Cajena,Cayena,Cayene,Cayenne,Gorad Kaena,Kaenna,Kagien,Kajen,Kajena,Kajenna,Kajennae,Kajenneh,Kajeno,Kayen,Kayene,Kayenna,kai yun,kaien''nu,kaiyana,kayen,kayena,kayn,kayyn,Καγιέν,Горад Каена,Кайен,Кайеннæ,Кайенна,Кайеннэ,Каєнна,Кајена,Կայեննա,קאיין,كايين,کائین,کاین,कायेन,ਕੈਯਨ,கயேன்,กาแยน,კაიენა,カイエンヌ,開雲,카옌', 4.9333300, -52.3333300, 'GF', '2012-02-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62308, 'Camopi', 'Camopi', 'Camopi,Kamopi,kamwby,Камопи,Камопі,كاموبي', 3.1688700, -52.3352500, 'GF', '2015-07-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62309, 'Apatou', 'Apatou', 'Apatou,Apatu,a pa tu,abatw,Апату,أباتو,阿帕图', 5.1552600, -54.3431100, 'GF', '2015-07-03', 77);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62404, 'Wellingara Ba', 'Wellingara Ba', 'Sitafuma,Wellingara Ba,Willingara', 13.4166700, -15.4000000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62405, 'Wassu', 'Wassu', '', 13.6909400, -14.8788400, 'GM', '2011-08-02', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62406, 'Toniataba', 'Toniataba', 'Toniataba,Tonitaba', 13.4333300, -15.5833300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62407, 'Sutukung', 'Sutukung', 'Surukung,Sutukung', 13.4666700, -15.2666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62408, 'Sutukoba', 'Sutukoba', 'Sutuko,Sutukoba', 13.5000000, -14.0166700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62409, 'Sun Kunda', 'Sun Kunda', 'Song Kunda,Sun Kunda', 13.3833300, -13.8500000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62410, 'Sukuta', 'Sukuta', 'Sukuta,Sukutta', 13.6166700, -14.9166700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62411, 'Sukuta', 'Sukuta', 'Dembadu,Sabiji,Sukuta,Sukuto,Sukutta', 13.4103300, -16.7081500, 'GM', '2011-02-02', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62412, 'Sudowol', 'Sudowol', '', 13.3666700, -13.9666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62413, 'Somita', 'Somita', '', 13.2058300, -16.3055600, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62414, 'Soma', 'Soma', 'Soma,soma,suo ma,ソマ,索馬,소마', 13.4333300, -15.5333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62415, 'Si Kunda', 'Si Kunda', '', 13.4333300, -15.5666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62416, 'Saruja', 'Saruja', '', 13.5500000, -14.9166700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62417, 'Sara Kunda', 'Sara Kunda', 'Sara Kunda,Sarra Kunda', 13.5333300, -15.4166700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62418, 'Sankwia', 'Sankwia', 'Sankuia,Sankwia', 13.4666700, -15.5166700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62419, 'Sami', 'Sami', '', 13.5833300, -15.2000000, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62420, 'Sabi', 'Sabi', '', 13.2333300, -14.2000000, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62421, 'Saba', 'Saba', '', 13.5163900, -16.0491700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62422, 'Perai', 'Perai', 'Perai,Pirai,Priakunda', 13.3833300, -14.0333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62423, 'Pateh Sam', 'Pateh Sam', 'Pate,Pateh Sam', 13.6166700, -15.0666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62424, 'Nyamanari', 'Nyamanari', '', 13.3333300, -13.8666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62425, 'No Kunda', 'No Kunda', '', 13.5666700, -15.8333300, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62426, 'Nioro', 'Nioro', '', 13.3500000, -15.7500000, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62427, 'Mansa Konko', 'Mansa Konko', 'Mansa Konko', 13.4432500, -15.5357000, 'GM', '2017-01-04', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62428, 'Lamin', 'Lamin', '', 13.3522200, -16.4338900, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62429, 'Kunting', 'Kunting', '', 13.5333300, -14.6666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62430, 'Kuntaur', 'Kuntaur', 'Kuntaur', 13.6708500, -14.8897700, 'GM', '2014-10-08', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62431, 'Kumbija', 'Kumbija', 'Kumbija,Kumbita', 13.2666700, -14.1833300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62432, 'Koina', 'Koina', '', 13.4833300, -13.8666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62433, 'Kerewan', 'Kerewan', 'Kerevane,Kerewan', 13.4898000, -16.0887900, 'GM', '2011-02-02', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62434, 'Keneba', 'Keneba', 'Keneba,Kenniba', 13.3288900, -16.0150000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62435, 'Katchang', 'Katchang', 'Kashan,Katchang', 13.5000000, -15.7500000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62436, 'Kass Wollof', 'Kass Wollof', 'Kass,Kass Wollof,Samba N''Yang,Samba N’Yang', 13.7833300, -14.9333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62437, 'Karantaba', 'Karantaba', 'Gunjur,Karantaba', 13.6666700, -15.0333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62438, 'Karantaba', 'Karantaba', '', 13.4333300, -15.5166700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62439, 'Kaiaf', 'Kaiaf', '', 13.4000000, -15.6166700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62440, 'Jifarong', 'Jifarong', 'Jifarong,Jiffarong', 13.3000000, -15.8666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62441, 'Jenoi', 'Jenoi', 'Ginoi,Jenoi', 13.4833300, -15.5666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62442, 'Jarreng', 'Jarreng', '', 13.6166700, -15.1833300, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62443, 'Jali', 'Jali', '', 13.3500000, -15.9666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62444, 'Jakhaly', 'Jakhaly', '', 13.5500000, -14.9666700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62445, 'Gunjur Kuta', 'Gunjur Kuta', '', 13.5333300, -14.1166700, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62446, 'Gunjur', 'Gunjur', 'Gunjur,Kungeru', 13.5227800, -16.0277800, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62447, 'Gunjur', 'Gunjur', '', 13.2019400, -16.7338900, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62448, 'Georgetown', 'Georgetown', 'Georgetown,Jan Jan Bureh,Old Fort George', 13.5403900, -14.7637400, 'GM', '2015-11-09', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62449, 'Galleh Manda', 'Galleh Manda', 'Galleh Manda,Manda', 13.4333300, -14.7833300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62450, 'Farafenni', 'Farafenni', 'Farafenis,Farafenni,fa la fen ni,farafeni,palapeni,פאראפני,ファラフェニ,法拉芬尼,파라페니', 13.5666700, -15.6000000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62451, 'Essau', 'Essau', 'Essau', 13.4838900, -16.5347200, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62452, 'Diabugu Basilla', 'Diabugu Basilla', '', 13.3333300, -13.9500000, 'GM', '2006-01-27', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62453, 'Diabugu', 'Diabugu', 'Diabugu,Dirboko', 13.3833300, -14.4000000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62454, 'Denton', 'Denton', 'Denton,Sare Ram', 13.5000000, -14.9333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62455, 'Demba Kunda', 'Demba Kunda', 'Demba Kunda,Morbugu', 13.2500000, -14.2666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62456, 'Daru Rilwan', 'Daru Rilwan', '', 13.5500000, -15.9833300, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62457, 'Dankunku', 'Dankunku', 'Dankunko,Dankunku', 13.5666700, -15.3166700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62458, 'Daba Kunda', 'Daba Kunda', 'Daba Kunda,Doba Kunda,Dula Kunda', 13.3166700, -14.3000000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62459, 'Chilla', 'Chilla', '', 13.5500000, -16.2833300, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62460, 'Bureng', 'Bureng', 'Buraing,Bureng', 13.4166700, -15.2833300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62461, 'Brikama Nding', 'Brikama Nding', '', 13.5333300, -14.9333300, 'GM', '2006-01-17', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62462, 'Brikama', 'Brikama', 'Brikama,Brikame,beulikama,brykama,bu li ka ma,burikama,Брикама,Брикаме,بریکاما,ブリカマ,布里卡馬,브리카마', 13.2713600, -16.6494400, 'GM', '2011-02-02', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62463, 'Brifu', 'Brifu', 'Brifu', 13.5000000, -13.9333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62464, 'Basse Santa Su', 'Basse Santa Su', 'Bas Santa Su,Basse,Basse Santa Su,ba sai sheng su,basesantasu,バセ・サンタ・ス,巴塞聖蘇,바세산타수', 13.3099500, -14.2137300, 'GM', '2011-02-02', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62465, 'Barra', 'Barra', 'Barra', 13.4827800, -16.5455600, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62466, 'Baro Kunda', 'Baro Kunda', 'Baro Kunda,Barukunda', 13.4833300, -15.2666700, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62467, 'Bantanto', 'Bantanto', 'Bantanto', 13.4166700, -14.6500000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62468, 'Bansang', 'Bansang', 'Bansang,Bansang Tenda,Barsangsang', 13.4333300, -14.6500000, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62469, 'Banjul', 'Banjul', 'BJL,Bandzhul,Bandzul,Bandzula,Bandzulis,Bandżul,Bandžula,Bandžulis,Banjoul,Banjul,Banjulo,Banyul,Banzhul,Banĵulo,Bathurst,Bathurstopolis,Gorad Banzhul,Mpanzoul,bajula,ban cul,ban zhu,ban zhu er,banjul,banjula,banjuli,banjuru,banjwl,bngwl,pancul,Μπανζούλ,Банджул,Банжул,Банџул,Банҷул,Горад Банжул,Բանջուլ,באנזשול,בנגול,بانجول,बंजुल,बाञ्जुल,ਬੰਜੁਲ,பஞ்சுல்,บันจูล,བཱན་ཇཱུ་ལ།,ბანჯული,ባንጁል,バンジュール,班珠尔,班竹,반줄', 13.4527400, -16.5780300, 'GM', '2015-11-01', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62470, 'Bambali', 'Bambali', 'Bambale,Bambali,Bombale', 13.4833300, -15.3333300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62471, 'Bakau', 'Bakau', 'Bakau,ba kao,bakau,bakaw,باكاو,巴考,바카우', 13.4780600, -16.6819400, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62472, 'Bakadagy', 'Bakadagy', 'Bakadagy,Bakadaji', 13.3000000, -14.3833300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62473, 'Abuko', 'Abuko', 'Abuko', 13.4041700, -16.6558300, 'GM', '2012-01-18', 81);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62187, 'Abastumani', 'Abastumani', 'Abastumani', 41.7075000, 42.8457100, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62188, 'Zugdidi', 'Zugdidi', 'Sugdidi,Zugdidi,Zugdidis,Zygdidi,zugdidi,zwgdydy,Зугдиди,זוגדידי,ზუგდიდი', 42.5088000, 41.8708800, 'GE', '2015-06-04', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62189, 'Zhinvali', 'Zhinvali', 'Zhinvali,Zhinvani,Жинвали', 42.1318100, 44.7726400, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62190, 'Zestap’oni', 'Zestap''oni', 'Dshugeli,Dzhugeli,Kvirily,Namaneva,Sestafoni,Zestafoni,Zestap''oni,Zestaponi,Zestap’oni,Zetaponi,Zistafoni,Зестафони', 42.1100000, 43.0525000, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62191, 'Zahesi', 'Zahesi', 'Zages,Zahesi', 41.8245800, 44.7536100, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62192, 'Vani', 'Vani', 'Bzvani,Vani,vani,Вани,ვანი', 42.0832000, 42.5216300, 'GE', '2014-09-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62193, 'Vale', 'Vale', 'Vale,Вале', 41.6155800, 42.8722400, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62194, 'Urek’i', 'Urek''i', 'Urek''i,Ureki,Urek’i,Уреки,ურეკი', 41.9955600, 41.7786100, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62195, 'Tsnori', 'Tsnori', 'Cnori,Sakobosubani,Tsnori,Tsnoristskali,Цнори', 41.6208800, 45.9694300, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62196, 'Tsqnet’i', 'Tsqnet''i', 'Ckhneti,Tskhneti,Tskneti,Tsqnet''i,Tsqnet’i,Цхнети', 41.6947200, 44.6986100, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62197, 'Ts’khinvali', 'Ts''khinvali', 'Chreba,Ckhinval,Ckhinvali,Stalinir,Staliniri,Stavinir,Ts''khinvali,Tskhinval,Ts’khinvali,Цхинвал,Цхинвали', 42.2276400, 43.9686100, 'GE', '2015-08-21', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62198, 'Tsinandali', 'Tsinandali', 'Cinandali,Tsinandali,Tsinondali,tsʼinandali,Цинандали,წინანდალი', 41.8931500, 45.5712900, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62199, 'Tsikhisdziri', 'Tsikhisdziri', 'Tsikhisdziri,Tskhirish,tsikhisdziri,ციხისძირი', 41.7665900, 41.7551700, 'GE', '2015-11-09', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62200, 'Tsalka', 'Tsalka', 'Barmaksiz,Barmaksus,Barmaksys,Calka,Calkae,Khram,Talka,Tsalka,Zalka,cha er ka,tsalka,Țalka,Τσάλκα,Цалкæ,Цалка,Ծալկա,تسالکا,წალკა,察爾卡', 41.5946000, 44.0890900, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62201, 'Tsalenjikha', 'Tsalenjikha', 'Calendzhikha,Tsalendzhikha,Tsalenjikha,Цаленджиха,წალენჯიხა', 42.6044400, 42.0682500, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62202, 'Tsaghveri', 'Tsaghveri', 'Cagveri,Kurgan Tsagveri,Tsaghveri,Tsagveri,Цагвери,წაღვერი', 41.8036500, 43.4819400, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62203, 'Tqvarch''eli', 'Tqvarch''eli', 'Tkuarchal,Tkvarcheli,Tkvarchely,Tkwartscheli,Ткуарчал', 42.8403500, 41.6800700, 'GE', '2014-01-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62204, 'Tqibuli', 'Tqibuli', 'Tkbuli,Tkibuli,Tkvibeli,Tkvibuli,Tkwibuli,Tqibuli,Ткибули', 42.3512100, 42.9987400, 'GE', '2014-03-15', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62205, 'T’ianet’i', 'T''ianet''i', 'T''ianet''i,Tianeti,Tianety,Tioneti,Tionety,T’ianet’i,Тианети', 42.1083300, 44.9638900, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62206, 'T’et’ri Tsqaro', 'T''et''ri Tsqaro', 'Agbulag,Agbulak,Agbulakh,Agbularh,Baly Kluch,Belyy-Klyuch,T''et''ri Tsqaro,Tetri-Ckaro,Tetri-Tskaro,T’et’ri Tsqaro,Тетри-Цкаро', 41.5444800, 44.4615300, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62207, 'Telavi', 'Telavi', 'T''elavi,Telav,Telavi,Telavis,Telawi,Telev,Thelavi,telavi,Телави,თელავი', 41.9197800, 45.4731500, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62208, 'Tbilisi', 'Tbilisi', 'Gorad Tbilisi,TBS,Tbilis,Tbilisi,Tbilisi - tbilisi,Tbilisi - თბილისი,Tbilisi osh,Tbilisis,Tbiliso,Tbilissi,Tbilisy,Tbiliszi,Tbilsi,Tblisi,Thbilisi,Tibilisi,Tiblisi,Tiblissi,Tiblíssi,Tibîlîsî,Tiflis,Tiphlida,Tpilisi,Triphelis,Ttuplis,Tíblisi,Tíflis,Tıflis,di bi li si,karti,tbilisi,tblys,tblysy,tbylysy,teubillisi,tfls,tflys,thbi li si,thbilisi,tipilici,tobirishi,Τιφλίδα,Горад Тбілісі,Тбилис,Тбилиси,Тбилиси ош,Тбилисӣ,Тбілісі,Ттуплис,Қарҭ,Թբիլիսի,טביליסי,تبليسي,تبلیس,تبلیسی,تبىلىسى,تفلیس,طفلس,ܛܒܝܠܝܣܝ,त्बिलिसी,थ्बिलीसी,তিবি‌লিসি,திபிலீசி,ทบิลิซิ,ཁྲེ་བྷི་ལི་སི།,თბილისი,ქართი,ትብሊሲ,トビリシ,第比利斯,트빌리시', 41.6941100, 44.8336800, 'GE', '2016-01-20', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62209, 'Surami', 'Surami', 'Ssuromi,Suram,Surami,Сурами', 42.0243100, 43.5555600, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62210, 'Sokhumi', 'Sokhumi', 'Akva,Aҟəa,SUI,Sochumi,Sohum,Sohumi,Sokhumi,Soukhoumi,Ssuchum,Suchum,Suchumi,Suhhumi,Suhumi,Suhumo,Sujumi,Sukhum,Sukhumi,Suĥumo,su hu mi,sufumi,suhumi,swhwmy,Аҟәа,Сухум,Сухуми,סוחומי,スフミ,苏呼米,수후미', 43.0069700, 40.9893000, 'GE', '2014-03-15', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62211, 'Sighnaghi', 'Sighnaghi', 'Sighnaghi,Signachis,Signag,Signag'',Signagi,Signakh,Signakhi,Sigunakh,Siğnaği,Ssignachi,sighnaghi,syghnaghy,syqnaqy,xi ge na ji,Сигнахи,Сигънах,Сиҕнаҕь,Сігнагі,Սիղնաղ,سیغناغی,سیقناقی,სიღნაღი,西格納吉', 41.6204600, 45.9219800, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62212, 'Shuakhevi', 'Shuakhevi', 'Shuakhevi,shuakhevi,Шуахеви,შუახევი', 41.6300000, 42.1908300, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62213, 'Shorapani', 'Shorapani', 'Schorapani,Schorpani,Sharadan'',Sharadan’,Shorapan'',Shorapani,Shorapan’,Shorpani', 42.0898000, 43.0866200, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62214, 'Naghvarevi', 'Naghvarevi', 'Naghvarevi,Saulaveri,Schaumjani,Shaumiani,Shaumjani,Shaumyani,Shulaveri,Shulavery,Шаумяни', 41.3527200, 44.7617800, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62215, 'Senak’i', 'Senak''i', 'Achal Senaki,Akhalsenaki,Micha-Zchakaja,Mikha Tskhakaya,Novo-Senaki,Senak''i,Senaki,Senak’i,Tskhakaya,Tskhakuya,Сенаки,სენაკი', 42.2704200, 42.0675000, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62216, 'Samtredia', 'Samtredia', 'Samtredia,Ssamtredia,Самтредиа', 42.1537000, 42.3351700, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62217, 'Sagarejo', 'Sagarejo', 'Sagaredzho,Sagarejo,sagarejo,Сагареджо,საგარეჯო', 41.7339700, 45.3314900, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62218, 'Rust’avi', 'Rust''avi', 'Roustavi,Rust''avi,Rustavi,Rustavis,Rustawi,Rusthavi,Rust’avi,rustavi,rwstwwy,Рустави,רוסתווי,რუსთავი', 41.5494900, 44.9932300, 'GE', '2014-03-15', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62219, 'Qvareli', 'Qvareli', 'Kvareli,Kvarely,Qvareli,Кварели', 41.9549300, 45.8171600, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62220, 'P’ot’i', 'P''ot''i', 'P''ot''i,Poti,P’ot’i,poti,Поти,ფოთი', 42.1461600, 41.6719700, 'GE', '2017-07-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62221, 'P’asanauri', 'P''asanauri', 'P''asanauri,PASANAURI,Pasanaur,Pasanauri,Pasanuri,Passanauri,P’asanauri,ПАСАНАУРИ', 42.3506000, 44.6891200, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62222, 'Ozurgeti', 'Ozurgeti', 'Gorad Azurgeci,Macharadse,Makharadze,Osurgeti,Ozoergeti,Ozourgueti,Ozourguéti,Ozournketi,Ozurget''i,Ozurgethi,Ozurgeti,Ozurgetis,Ozurgety,Ozurgueti,ao zu er gai di,azrgty,azwrgty,ojuleugeti,ozurgeti,ozurugeti,Οζουργκέτι,Горад Азургеці,Озургети,Озургеті,Օզուրգեթ,אוזורגתי,ازرگتی,ازورگتی,ოზურგეთი,オズルゲティ,奧祖爾蓋蒂,오주르게티', 41.9244200, 42.0068200, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62223, 'Orsant’ia', 'Orsant''ia', 'Orsant''ia,Orsantia,Orsant’ia,Орсантиа,ორსანტია', 42.4677700, 41.6737700, 'GE', '2017-05-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62224, 'Oni', 'Oni', 'On,Oni,ao ni,awny,awny  grjstan,awny  jarjya,oni,Он,Они,Оні,Օնի,אוני,اونی,اونی، جارجیا,اونی، گرجستان,ონი,奥尼', 42.5794400, 43.4425000, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62225, 'Ochkhamuri', 'Ochkhamuri', 'Och''khamuri,Ochkamuri,Ochkhamuri,ochkhamuri,Очхамури,ოჩხამური', 41.8597500, 41.8530900, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62226, 'Och’amch’ire', 'Och''amch''ire', 'Och''amch''ire,Ochamchira,Ochemchiri,Ochemchiry,Ochemechiri,Och’amch’ire,Otschemtschiri,Очамчира', 42.7123200, 41.4686300, 'GE', '2014-01-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62227, 'Ninotsminda', 'Ninotsminda', 'Bogdanovka,Ninocminda,Ninotsminda,Ниноцминда,ეიეოწმინდა', 41.2645800, 43.5916100, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62228, 'Mtskheta', 'Mtskheta', 'Ckheta,Gorad Mckheta,Mccheta,Mcheta,Mckheta,Mcĥeta,Miskheta,Msxeta,Mtheta,Mtscheta,Mtsheta,Mtshetha,Mtsketa,Mtskhera,Mtskheta,Mtskhetha,Mtzkhet,Mzcheta,Mțheta,meucheuheta,mhmyt almdynt wmthf mtskhyta,mtskheta,mtskhta,mu ci he ta,mutsuheta,mzhth,Μτσκέτα,Горад Мцхета,Мцхета,Цхета,Մցխեթ,מצחתה,متسختا,محمية المدينة ومتحف متسخيتا,მცხეთა,ムツヘタ,姆茨赫塔,므츠헤타', 41.8451400, 44.7187500, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62229, 'Mest’ia', 'Mest''ia', 'Mest''ia,Mestia,Mestiya,Mestno,Mest’ia,Seti,Местиа,მესტია', 43.0458100, 42.7278000, 'GE', '2014-09-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62230, 'Mart’vili', 'Mart''vili', 'Gegechkari,Gegechkori,Mart''vili,Martvili,Mart’vili,Мартвили,მარტვილი', 42.4143600, 42.3792400, 'GE', '2014-09-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62231, 'Marneuli', 'Marneuli', 'Borchalo,Marneuli,Sarvan,Sarwan,Марнеули', 41.4758800, 44.8089500, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62232, 'Manglisi', 'Manglisi', 'Manglis,Manglisi,Манглиси', 41.6969800, 44.3844800, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62233, 'Makhinjauri', 'Makhinjauri', 'Makhindzhauri,Makhinjauri,makhinjauri,Махинджаури,მახინჯაური', 41.6738500, 41.6940100, 'GE', '2014-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62234, 'Lent’ekhi', 'Lent''ekhi', 'Leksura,Lent''ekhi,Lentekhi,Lent’ekhi,lentʼekhi,Лентехи,ლენტეხი', 42.7889300, 42.7222600, 'GE', '2015-02-06', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62235, 'Lanchkhuti', 'Lanchkhuti', 'Lanch''khut''i,Lanchkhuti,lanchkhuti,Ланчхути,ლანჩხუთი', 42.0902700, 42.0323900, 'GE', '2014-09-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62236, 'Lagodekhi', 'Lagodekhi', 'Lagodechis,Lagodekhi,lagodekhi,lgwdhy,Лагодехи,לגודחי,ლაგოდეხი', 41.8268100, 46.2766700, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62237, 'Kveda Chkhorots’q’u', 'Kveda Chkhorots''q''u', 'Kveda Chkhorots''q''u,Kveda Chkhorotsku,Kveda Chkhorots’q’u,ქვედა ჩხოროწყუ', 42.4810300, 42.0966100, 'GE', '2013-12-10', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62238, 'Kutaisi', 'Kutaisi', 'KUT,Khuthaisi,Koetaisi,Koutaissi,Koutaïssi,Kutais,Kutaisi,Kutaisk,Kutaiso,Kutaissi,Kutayis,Kutayıs,Kutaïsi,kutaishi,kutaisi,Кутаиси,Кутаїсі,כותאיסי,קוטאיסי,ქუთაისი,クタイシ,쿠타이시', 42.2679100, 42.6945900, 'GE', '2014-11-02', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62239, 'K’ulashi', 'K''ulashi', 'K''ulashi,Kulashi,K’ulashi,kʼulashi,Кулаши,კულაში', 42.2040500, 42.3428900, 'GE', '2014-09-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62240, 'Kobuleti', 'Kobuleti', 'K''obulet''i,Khobulethi,Koboeleti,Kobulet,Kobuleti,Kobuletis,Kobulyety,kbwlty,ke bu lie ji,kobuleti,kobulleti,koburechi,kwbwlty,Кобулет,Кобулети,Кобулеті,Қобулеҭ,Քոբուլեթ,כובולתי,کبولتی,کوبولتی,ქობულეთი,コブレチ,科布列季,코불레티', 41.8200000, 41.7752800, 'GE', '2014-01-31', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62241, 'Khulo', 'Khulo', 'Chulo,Daba,Khulo,khulo,Хуло,ხულო', 41.6435300, 42.3039700, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62242, 'Khoni', 'Khoni', 'Choni,Khoni,Koni,Tsulukidze,Zulukidse,khoni,Хони,ხონი', 42.3226000, 42.4206100, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62243, 'Khobi', 'Khobi', 'Khobi,Khopi,khobi,Хоби,ხობი', 42.3155800, 41.8987100, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62244, 'Khelvachauri', 'Khelvachauri', 'Khelvach''auri,Khelvachauri,khelvachauri,Хелвачаури,ხელვაჩაური', 41.5855600, 41.6688900, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62245, 'Khashuri', 'Khashuri', 'Chaschuri,Chasjoeri,Chasjuri,Chasuri,Chasuris,Chaszuri,Chašuri,Chašuris,Hasuri,Haxuri,Hašuri,Hașuri,Jashuri,Khachouri,Khachuri,Khashur,Khashuri,Khasuri,Khašuri,Mikhailovo,Mikhaylovo,Stalinissi,Xasuri,ha shu li,khashuri,khashwry,Хашур,Хашури,Хашурі,Խաշուրի,חאשורי,خاشوری,ხაშური,哈舒里', 41.9941400, 43.5999400, 'GE', '2014-03-15', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62246, 'Keda', 'Keda', 'K''eda,Keda,keda,Кеда,ქედა', 41.5969400, 41.9413900, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62247, 'Step’antsminda', 'Step''antsminda', 'Kasbek,Kazbeg,Kazbegi,Kazbek,Qazbegi,Step''antsminda,Stepancminda,Stepantsminda,Step’antsminda,Казбеги,Степанцминда', 42.6566700, 44.6433300, 'GE', '2016-10-21', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62248, 'Kats’khi', 'Kats''khi', '', 42.2923600, 43.2088800, 'GE', '2017-05-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62249, 'Kaspi', 'Kaspi', 'Kasni,Kasp,Kaspi,Kaspis,Kuaspi,ka si pi,kaspy,Касп,Каспи,Къаспи,Կասպի,کاسپی,კასპი,卡斯皮', 41.9252000, 44.4256800, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62250, 'Java', 'Java', 'Chvrivi,Dzhava,Java,java,Джава,ჯავა', 42.3997200, 43.9366700, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62251, 'Gurjaani', 'Gurjaani', 'Gurdjaani,Gurdzhaani,Gurdzhani,Gurjaani,gurjaani,Гурджаани,გურჯაანი', 41.7429200, 45.8011100, 'GE', '2013-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62252, 'Gulrip’shi', 'Gulrip''shi', 'Gul''ripsh,Gulrifsh,Gulrip''shi,Gulrip’shi,Gul’ripsh,Kvemo-Gul''ripsh,Kvemo-Gul''ripshi,Kvemo-Gul’ripsh,Kvemo-Gul’ripshi,Nizhniy Gul''ripsh,Nizhniy Gul’ripsh,Nizhniye Gul''ripsh,Nizhniye Gul’ripsh,Гульрипш', 42.9269400, 41.0963900, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62253, 'Gudauta', 'Gudauta', 'Goedaoeta,Gorad Gudauta,Goudaouta,Gudaut''a,Gudauta,Gudautae,Gudauti,Gudauto,Gudauty,Qudauta,gu da wu ta,gudauta,gwdawta,Горад Гудаута,Гудаутæ,Гудаута,Гудауто,Гәдоуҭа,Ґудаута,Գուդաութա,גודאותה,گوداوتا,გუდაუთა,グダウタ,古達烏塔', 43.1054700, 40.6206700, 'GE', '2014-02-07', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62254, 'Gudauri', 'Gudauri', 'Goudaour,Gudaur,Gudauri,Gudouri,Гудаури', 42.4779700, 44.4761600, 'GE', '2014-12-11', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62255, 'Gori', 'Gori', 'Gori,gori,გორი', 42.5166700, 43.1666700, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62256, 'Gori', 'Gori', 'Gori,Goris,ge li,goli,gori,gwry,Гори,גורי,گوری,გორი,ゴリ,哥里,고리', 41.9842200, 44.1157800, 'GE', '2013-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62257, 'Gardabani', 'Gardabani', 'Gardaban,Gardabani,Karaya,Karayazi,Karayazy,Qaratəpə,Qardabani,gardabani,gardabany,grdabany,jia er da ba ni,Гардабани,Ґардабані,Գարդաբան,گاردابانی,گردابانی,გარდაბანი,加爾達巴尼', 41.4605400, 45.0928300, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62258, 'Gantiadi', 'Gantiadi', 'Candrypsh,Gant''iadi,Gantiadi,Gantiandi,Pilenkova,Pilenkovo,Pilyenkovo,Seleniye Pilenkovo,gantiadi,Гантианди,Цандрыпш,განთიადი', 43.3811100, 40.0794400, 'GE', '2014-02-07', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62259, 'Gali', 'Gali', 'Gal,Gali,Galis,Gorad Gal,Qali,gali,galli,galy,gari,jia li,Гал,Гали,Горад Гал,Գալի,גאלי,گالی,გალი,ガリ,加利,갈리', 42.6265500, 41.7380800, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62260, 'Gagra', 'Gagra', 'Gagra,Gagrae,Gagre,Gagri,Gagry,Gorad Gagra,Nkankra,Qaqra,gageula,gagra,gagura,ggrh,ghaghra,jia ge la,kak ra,Γκάγκρα,Гагрæ,Гагра,Гагре,Горад Гагра,Գագրա,גגרה,غاغرا,گاگرا,গাগ্‌রা,กากรา,გაგრა,ガグラ,加格拉,가그라', 43.2785800, 40.2712400, 'GE', '2014-11-18', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62261, 'Jvari', 'Jvari', 'Dzhvara,Dzhvari,Dzhvary,Dzhvarzeni,Jvari,jvari,Джвари,ჯვარი', 42.7169300, 42.0520000, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62262, 'Dzegvi', 'Dzegvi', 'Dzegvi,Dzgevi,Дзегви', 41.8456900, 44.6009700, 'GE', '2017-06-06', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62263, 'Dranda', 'Dranda', 'Dranda,Drandi,Drandy,Дранда', 42.8716700, 41.1533300, 'GE', '2013-08-21', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62264, 'Dmanisi', 'Dmanisi', 'Dmanisi,Dumanisi,Дманиси', 41.5251400, 44.3472000, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62265, 'Dioknisi', 'Dioknisi', '', 41.6293300, 42.3917100, 'GE', '2014-08-05', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62266, 'Didi Lilo', 'Didi Lilo', 'Didi Lilo,Didi-Lilo,Lilo,Диди-Лило', 41.7361100, 44.9647200, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62267, 'Chakvi', 'Chakvi', 'Ch''ak''vi,Chakva,Chakvi,Чаква', 41.7252800, 41.7327800, 'GE', '2015-11-09', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62268, 'Borjomi', 'Borjomi', 'Borcomi,Bordjomi,Bordschomi,Bordshomi,Bordzjomi,Bordzomi,Bordżomi,Bordžomi,Borjam,Borjomi,Borjomi - borjomi,Borjomi - ბორჯომი,Borshom,Borzhom,Borzhomi,Borzom,Borzomis,Boržomis,bo er ruo mi,boleujomi,borjomi,borujomi,brjwmy,bwrgwmy,bwrjwmy,Боржом,Боржоми,Боржомі,Բորժոմ,בורגומי,برجومی,بورجومی,ბორჯომი,ボルジョミ,博爾若米,보르조미', 41.8527200, 43.4128400, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62269, 'Bolnisi', 'Bolnisi', 'Bolnis,Bolnisi,Bolnisis,Bolnissi,Katharinenfeld,Luxemburg,Luxemburgi,Lyuksemburg,Lyuksemburg-Gruzinskiy,Lyuksemburgi,Lyuksemburi,Yekaterinofel''d,Yekaterinofel’d,bo er ni xi,bolnisi,bwlnyshy,bwlnysy,Болниси,Болнісі,Բոլնիս,בולניסי,بولنیسی,بولنیشی,ბოლნისი,博爾尼西', 41.4479400, 44.5383800, 'GE', '2014-03-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62270, 'Bich’vinta', 'Bich''vinta', 'Bich''vinta,Bichvinta,Bich’vinta,Bitchvinta,Picunda,Pitsoenda,Pitsunda,Pitsundo,Pitsundskiy,Pitsvints,Pitunda,Pițunda,byzwwynth,Пицунда,ביצווינתה,ბიჭვინთა', 43.1619700, 40.3410200, 'GE', '2014-11-18', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62271, 'Batumi', 'Batumi', 'BUS,Bat''umi,Bathumi,Batoemi,Batomis,Batoum,Batoumi,Batum,Batumi,Batumis,Batumo,Batûm,ba tong,bato~umi,batumi,batwmy,btwmy,Μπατούμι,Батуми,Батумі,Баҭым,Բաթում,בטומי,בתומי,باتومی,باطومي,बातुमी,ბათუმი,バトゥミ,巴统,바투미', 41.6422800, 41.6339200, 'GE', '2014-11-18', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62272, 'Bakuriani', 'Bakuriani', 'Bakuiani,Bakuriani,Бакуриани', 41.7497200, 43.5325000, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62273, 'Bagdadi', 'Bagdadi', '', 41.8166700, 46.0333300, 'GE', '2007-05-30', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62274, 'Aspindza', 'Aspindza', 'Aspindza,Аспиндза,ასპინძა', 41.5738900, 43.2482600, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62275, 'Ambrolauri', 'Ambrolauri', 'Ambralauri,Ambrolaoeri,Ambrolaur,Ambrolauri,Ambrolauris,Gorad Ambralaury,ambeulollauli,ambrolauri,ambrwlaywry,an bu luo lao li,Амбролаур,Амбролаури,Амбролаурі,Горад Амбралауры,Ամբրոլաուր,אמברולאורי,آمبرولائوری,ამბროლაური,安布羅勞里,암브롤라우리', 42.5211100, 43.1622200, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62276, 'Akhmet’a', 'Akhmet''a', 'Akhmet''a,Akhmeta,Akhmeti,Akhmety,Akhmet’a,akhmetʼa,Ахмета,ახმეტა', 42.0311100, 45.2075000, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62277, 'Akhaltsikhe', 'Akhaltsikhe', 'Achalciche,Achalcichė,Achaltsiche,Achalziche,Achalzych,Ahalcihe,Ahalciho,Ahaltihe,Ahalțihe,Ahhaltsihhe,Ahiska,Ahıska,Ajaltsije,Akhalcikhe,Akhalts''ikhe,Akhaltsikh,Akhaltsikhe,Akhaltsikhé,Akhaltsykha,Akhaltsykhe,Aĥalciĥo,Gorad Akhalcykheh,a ha er qi he,ahalchihe,aharutsu~ihe,akhalt sykh,akhaltsikhe,akhaltsykhh,Ахалцихе,Ахалціхе,Горад Ахалцыхэ,Ախալցխա,אחלציחה,آخالت سیکه,آخالتسيخه,آخالتسیخه,آخالتسیخے,ახალციხე,アハルツィヘ,阿哈爾齊赫,아할치헤', 41.6390100, 42.9826200, 'GE', '2014-07-08', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62278, 'Akhalk’alak’i', 'Akhalk''alak''i', 'Achalkalaki,Akhalk''alak''i,Akhalkalak,Akhalkalaki,Arkhalkalaki,Ахалкалаки', 41.4051400, 43.4862900, 'GE', '2010-06-18', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62279, 'Stantsiya Novyy Afon', 'Stantsiya Novyy Afon', 'Novyj Afon,Novyy Afon,Psirtskha,Psyrtskha,Stantsiya Akhali-Afoni,Новый Афон', 43.0805600, 40.8383300, 'GE', '2013-10-29', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62280, 'Akhalgori', 'Akhalgori', 'Akhalgori,Leningori,Ленингори', 42.1259700, 44.4833300, 'GE', '2016-03-06', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62281, 'Akhaldaba', 'Akhaldaba', 'Akhaldaba,akhaldaba,Ахалдаба,ახალდაბა', 41.9294500, 43.4876200, 'GE', '2016-03-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62282, 'Akhaldaba', 'Akhaldaba', 'Akhaldaba,akhaldaba,Ахалдаба,ახალდაბა', 41.6539500, 42.1516300, 'GE', '2012-01-17', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62283, 'Agara', 'Agara', 'Agara,Агара', 42.0376100, 43.8238200, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62284, 'Adigeni', 'Adigeni', 'Adigeni,Адигени', 41.6819100, 42.6986700, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62285, 'Abasha', 'Abasha', 'Abacha,Abascha,Abasha,abasha,Абаша,აბაშა', 42.2095900, 42.2211100, 'GE', '2014-03-15', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62286, 'P’rimorsk’oe', 'P''rimorsk''oe', 'Barnitsats,P''rimorsk''oe,Primorskoye,P’rimorsk’oe,პრიმორსკოე', 43.0923600, 40.6965000, 'GE', '2014-02-10', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62287, 'Tsqaltubo', 'Tsqaltubo', 'Ckhaltubo,Tskaltubo,Tskhaltubo,Tsqaltubo,Цхалтубо', 42.3412900, 42.5976000, 'GE', '2014-06-26', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62288, 'Naruja', 'Naruja', 'Naruja,Sovkhoz Narudzhskiy,naruja,ნარუჯა', 41.9069400, 41.9541700, 'GE', '2012-01-19', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62289, 'Bakurianis Andeziti', 'Bakurianis Andeziti', 'Bakurianis Andeziti,Bakurianskij Andezit,bakʼurianis andezitʼi,Бакурианский Андезит,ბაკურიანის ანდეზიტი', 41.7337100, 43.4724200, 'GE', '2014-06-27', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62290, 'Kelasuri', 'Kelasuri', 'Kelasuri,Келасури', 42.9787700, 41.0706700, 'GE', '2012-06-14', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62291, 'Kharagauli', 'Kharagauli', '', 42.0213700, 43.1977300, 'GE', '2011-02-16', 82);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62318, 'Yendi', 'Yendi', 'Jendi,Yendi', 9.4427200, -0.0099100, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62319, 'Winneba', 'Winneba', 'Simpa,Vinnebe,Winneba,Winnebah,Виннебе', 5.3511300, -0.6231300, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62320, 'Wenchi', 'Wenchi', 'Wenchi', 7.7391600, -2.1045600, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62321, 'Wa', 'Wa', 'Va,Wa,wa,Ва,وا، گھانا,วา,와', 10.0606900, -2.5019200, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62322, 'Teshi Old Town', 'Teshi Old Town', 'Tassi,Teshhi,Teshi Old Town,Teshie,Тещи', 5.5836500, -0.1072200, 'GH', '2013-02-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62323, 'Tema', 'Tema', 'Tema,Temma,Toma,te ma,tema,tma,Тема,تما,テマ,特马,테마', 5.6698000, -0.0165700, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62324, 'Techiman', 'Techiman', 'Takyiman,Techiman,Tekyiman,Tekyiman-Brong', 7.5861700, -1.9413700, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62325, 'Tarkwa', 'Tarkwa', 'Tarkwa,Tarquah', 5.3064400, -1.9847400, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62326, 'Tamale', 'Tamale', 'TML,Tamale,Тамале', 9.4007900, -0.8393000, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62327, 'Takoradi', 'Takoradi', 'TKD,Takoradi', 4.8844700, -1.7553600, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62328, 'Tafo', 'Tafo', 'Old Tafo,Tafo', 6.7345300, -1.6127500, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62329, 'Swedru', 'Swedru', 'Agona,Agona Swedru,Jwewuhu,Swedru', 5.5371100, -0.6998400, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62330, 'Sunyani', 'Sunyani', 'NYI,Sun''jani,Sunjanis,Sunyani,su ni ya ni,suniani,Суньяні,蘇尼亞尼,수니아니', 7.3399100, -2.3267600, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62331, 'Suhum', 'Suhum', 'Suhum', 6.0408900, -0.4500400, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62332, 'Shama Junction', 'Shama Junction', 'Shama,Shama Junction', 5.0087200, -1.6301100, 'GH', '2013-11-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62333, 'Sekondi-Takoradi', 'Sekondi-Takoradi', 'Gorad Sekandy-Takarady,Sekondi,Sekondi Takoradi,Sekondi-Takoradi,Sekondis-Takoradis,Sékondi,se kan di-ta ko ra di,sekonditakoladi,skwndy-takwrady,sqwndy-tqwrdy,sykwndy takwrady,Горад Секанды-Такарады,Секонди,Секонди Такоради,Секонди-Такоради,Секонді-Такораді,סקונדי-טקורדי,سيكوندي تاكورادي,سکوندی-تاکورادی,سیکونڈی-ٹاکوراڈی,เซกันดี-ตาโกราดี,セコンディ・タコラディ,塞康第─塔科拉迪,세콘디타코라디', 4.9340000, -1.7137000, 'GH', '2012-06-05', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62334, 'Savelugu', 'Savelugu', 'Saveluga,Savelugu', 9.6244100, -0.8253000, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62335, 'Saltpond', 'Saltpond', 'Achimfu,Saltpond', 5.2091300, -1.0605800, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62336, 'Salaga', 'Salaga', 'Salaga', 8.5508300, -0.5187500, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62337, 'Prestea', 'Prestea', 'Esamang,Prestea', 5.4327400, -2.1428400, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62338, 'Kasoa', 'Kasoa', 'Kasoa,Oduponkpehe', 5.5344900, -0.4167900, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62339, 'Akim Oda', 'Akim Oda', 'Akim Oda,Insuaim,Nsuaem,Oda,Ода', 5.9266500, -0.9857700, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62340, 'Obuasi', 'Obuasi', 'Oboase,Obuasi,Obuasis,Obuassi,Обуаси', 6.2060200, -1.6619100, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62341, 'Nungua', 'Nungua', 'Nungoa,Nungua,Nungwa', 5.6010500, -0.0771300, 'GH', '2013-02-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62342, 'Nsawam', 'Nsawam', 'Nsawam', 5.8089300, -0.3502600, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62343, 'Nkawkaw', 'Nkawkaw', 'Nkawkaw,Nkokoo', 6.5512100, -0.7662000, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62344, 'Navrongo', 'Navrongo', 'Navrongo', 10.8955700, -1.0921000, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62345, 'Mumford', 'Mumford', 'Gamma,Gammah,Jumba,Mumford,Mumfort', 5.2617600, -0.7589700, 'GH', '2014-01-24', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62346, 'Mpraeso', 'Mpraeso', 'Mpraeso', 6.5932100, -0.7346200, 'GH', '2012-02-02', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62347, 'Mampong', 'Mampong', 'Mampon,Mampon Asante,Mampong', 7.0627300, -1.4001000, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62348, 'Medina Estates', 'Medina Estates', 'Madina,Medina Estates', 5.6658000, -0.1630700, 'GH', '2013-02-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62349, 'Kumasi', 'Kumasi', 'Coomassie,Gorad Kumasi,KMS,Kumase,Kumasi,Kumasi shaary,Kumasis,Kumassi,Kumasy,ku ma xi,kumashi,kumasi,kwmasy,Горад Кумасі,Кумаси,Кумаси шаары,Кумасі,Կումասի,كوماسي,کوماسی,ਕੁਮਾਸੀ,クマシ,库马西,쿠마시', 6.6884800, -1.6244300, 'GH', '2011-11-01', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62350, 'Kpandu', 'Kpandu', 'Gabi,Kpando,Kpandu,Tsakpe', 6.9953600, 0.2930600, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62351, 'Kpandae', 'Kpandae', 'Kpandae,Kpandai', 8.4688500, -0.0112700, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62352, 'Konongo', 'Konongo', 'Konongo,Konongo-Odumase', 6.6166700, -1.2166700, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62353, 'Koforidua', 'Koforidua', 'Koforidua,ke fu li du ya,kopolidua,kwfwrydwa,kwfwrydwya,Кофоридуа,کوفوریدوئا,کوفوریدوا,科福里杜亞,코포리두아', 6.0940800, -0.2591300, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62354, 'Kintampo', 'Kintampo', 'Kintampo', 8.0562700, -1.7305800, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62355, 'Kibi', 'Kibi', 'Kibbi,Kibi,Kyebi', 6.1649400, -0.5537600, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62356, 'Kete Krachi', 'Kete Krachi', 'Kete Krachi,Kete Krakye,Kete-Kratschi,Kete-Ktachi,Krachi,Krete Kratschi', 7.7939100, -0.0498000, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62357, 'Keta', 'Keta', 'Keta,Kitta,Kwitta,Quittah', 5.9179300, 0.9878900, 'GH', '2013-04-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62358, 'Hohoe', 'Hohoe', 'Chochoe,Chokhoe,Hohoe,Khokhoe', 7.1518100, 0.4736200, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62359, 'Ho', 'Ho', 'Ho,Hohoe,Kho,No,ho,hw. ghna,Но,Хо,هو٬ غنا,ہو، گھانا,ホ,호', 6.6008400, 0.4713000, 'GH', '2012-06-05', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62360, 'Gbawe', 'Gbawe', 'Gbawe', 5.5771400, -0.3103500, 'GH', '2013-04-03', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62361, 'Foso', 'Foso', 'Foso', 5.7011900, -1.2865700, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62362, 'Elmina', 'Elmina', 'Dena,Edina,Ehlmina,Elmina,Saint George Del Mina,Sao Jorge da Mina,São Jorge da Mina,aylmyna,elmina,erumina,Елмина,Элмина,אלמינה,ایلمینا,エルミナ,엘미나', 5.0847000, -1.3509300, 'GH', '2014-04-09', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62363, 'Ejura', 'Ejura', 'Ejura', 7.3855800, -1.3561700, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62364, 'Dunkwa', 'Dunkwa', 'Dunkwa,Dunkwa-on-Offin', 5.9656200, -1.7799500, 'GH', '2016-03-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62365, 'Duayaw Nkwanta', 'Duayaw Nkwanta', 'Duayaw Nkwanta,Nkwanta', 7.1724200, -2.1028100, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62366, 'Dome', 'Dome', 'Dam,Dom,Dome,Дом', 5.6500300, -0.2361000, 'GH', '2013-02-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62367, 'Cape Coast', 'Cape Coast', 'Cabo Corso,Cape Coast,Cape Coast Castle,Igua Ogwa,Keip Kostas,Kejp-Kost,Ogwa,hai an jiao,keipeukoseuteu,kyp kwst,Кейп-Кост,کیپ کوست,کیپ کوسٹ,ケープ・コースト,海岸角,케이프코스트', 5.1053500, -1.2466000, 'GH', '2011-02-04', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62368, 'Bolgatanga', 'Bolgatanga', 'Bolagatanga,Bolgatanga,Bolgatange,bo er jia tan jia,bolgatang-ga,borugatanga,Болгатанга,Болгатанге,ボルガタンガ,博爾加坦加,볼가탕가', 10.7855600, -0.8513900, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62369, 'Bibiani', 'Bibiani', 'Babianeha,Bebiani,Bebianiha,Bibiani', 6.4634600, -2.3193800, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62370, 'Berekum', 'Berekum', 'Berekum', 7.4534000, -2.5840400, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62371, 'Bekwai', 'Bekwai', 'Bekawi,Bekwai', 6.4533500, -1.5774100, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62372, 'Begoro', 'Begoro', 'Begoro', 6.3870600, -0.3773800, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62373, 'Bechem', 'Bechem', 'Bechem', 7.0903400, -2.0249800, 'GH', '2012-05-05', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62374, 'Bawku', 'Bawku', 'Bawku', 11.0616000, -0.2416900, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62375, 'Axim', 'Axim', 'Axim', 4.8699200, -2.2404600, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62376, 'Asamankese', 'Asamankese', 'Asamankese', 5.8600600, -0.6635000, 'GH', '2013-11-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62377, 'Apam', 'Apam', 'Apam,Appam,Апам', 5.2848300, -0.7371100, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62378, 'Anloga', 'Anloga', 'Anloga,Awunaga', 5.7947300, 0.8972800, 'GH', '2013-07-22', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62379, 'Akwatia', 'Akwatia', 'Akwatia', 6.0402400, -0.8087600, 'GH', '2013-10-30', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62380, 'Akropong', 'Akropong', 'Akropong,Akropong-Akwapim,Akuropon', 5.9746200, -0.0854200, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62381, 'Akim Swedru', 'Akim Swedru', 'Akim Swedru', 5.8938000, -1.0163600, 'GH', '2012-02-02', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62382, 'Agogo', 'Agogo', 'Agogo', 6.8000400, -1.0819300, 'GH', '2013-10-29', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62383, 'Achiaman', 'Achiaman', '', 5.7000000, -0.3333300, 'GH', '2013-02-08', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62384, 'Accra', 'Accra', 'ACC,Aakra,Aakrá,Accra,Acra,Akara,Akkr,Akkra,Akkrae,Akra,Akrao,Akʻra,Gorad Akra,Nkran,a ke la,akara,akeula,akra,akura,xak kra,yەkra,΄Aκκρα,Άκκρα,Аккрæ,Аккра,Акра,Горад Акра,Աքրա,אקרא,אקרה,آکرا,أكرا,ئەکرا,اكرا,اکرا,عکرہ,अक्रा,आक्रा,আক্রা,ਅਕਰਾ,ଆକ୍ରା,அக்ரா,അക്ര,อักกรา,ཨ་ཁ་ར།,အက်ခရာမြို့,აკრა,አክራ,アクラ,阿克拉,아크라', 5.5560200, -0.1969000, 'GH', '2015-05-13', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62385, 'Aburi', 'Aburi', 'Aburi', 5.8480200, -0.1744900, 'GH', '2012-11-19', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62386, 'Aboso', 'Aboso', 'Aboso,Abosso', 5.3617000, -1.9473200, 'GH', '2012-01-18', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62387, 'Mamponteng', 'Mamponteng', '', 6.7333300, -1.5500000, 'GH', '2013-05-28', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62388, 'Wassa-Akropong', 'Wassa-Akropong', '', 5.7872200, -2.0836100, 'GH', '2014-06-09', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62389, 'Odumase Krobo', 'Odumase Krobo', '', 6.5333300, -0.8166700, 'GH', '2016-08-04', 84);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62390, 'Gibraltar', 'Gibraltar', 'Calpe,Cebelitarik,Cebelitarık,Djibraltar,GIB,Gibbilterra,Gibilterra,Gibraltar,Gibraltaras,Gibraltaro,Gibraltár,Gíbraltar,Kamaka,Xibraltar,Xibraltar - Gibraltar,gybrltr,jibeulolteo,jiburarutaru,mhmyt jbl tarq,zhi bu luo tuo,Ĝibraltaro,Γιβραλτάρ,Гибралтар,Ґібралтар,גיברלטר,جبل‌الطارق,محمية جبل طارق,ジブラルタル,直布罗陀,지브롤터', 36.1447400, -5.3525700, 'GI', '2017-06-22', 85);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62562, 'Zonianá', 'Zoniana', 'Zoniana,Zonianá,Ζωνιανά', 35.2950200, 24.8294400, 'GR', '2012-03-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62563, 'Zevgolateió', 'Zevgolateio', 'Tranozevgolateio,Zevgolateio,Zevgolateion,Zevgolateíon,Zevgolatio,Zevgolation,Zevgolatió,Zevgolatíon,Ζευγολατειό,Τρανοζευγολατειό', 37.9333300, 22.8000000, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62564, 'Zarós', 'Zaros', 'Zaros,Zarós,Ζαρός', 35.1303000, 24.9041200, 'GR', '2013-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62565, 'Zárkos', 'Zarkos', 'Zarko,Zarkon,Zarkos,Zárkon,Zárkos,Ζάρκος', 39.6086000, 22.1233600, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62566, 'Zakynthos', 'Zakynthos', 'ZTH,Zacinto,Zakinthos,Zakintos,Zakynthos,Zante,Zákinthos,Zákynthos,jakintoseu,zakintosu,zakynthws,zha jin suo si,Ζάκυνθος,Закинтос,زاكينثوس,ザキントス,扎金索斯,자킨토스', 37.7802200, 20.8955500, 'GR', '2016-04-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62567, 'Zacháro', 'Zacharo', 'Zacharo,Zacháro,Zakharo,Zakháro,Ζαχάρω', 37.4833300, 21.6500000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62568, 'Zagorá', 'Zagora', 'Zagora,Zagorá,Ζαγορά', 39.4500000, 23.1000000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62569, 'Gýtheio', 'Gytheio', 'Githion,Gytheio,Gytheion,Gythelon,Gythio,Gythion,Gythium,Gýtheio,Gýtheion,Gýthelon,Yithio,Yithion,Yíthio,Yíthion,Γύθειο,Γύθειον', 36.7550000, 22.5641700, 'GR', '2015-05-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62570, 'Yimnón', 'Yimnon', 'Gymno,Gymnon,Yimnon,Yimnón,Γυμνό,Γυμνόν', 38.4404800, 23.8840000, 'GR', '2015-01-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62571, 'Giánnouli', 'Giannouli', 'Giannouli,Giánnouli,Yiannouli,Yiánnouli,Γιάννουλη', 39.6671700, 22.3959700, 'GR', '2015-10-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62572, 'Gérgeri', 'Gergeri', 'Gergeri,Gérgeri,Yeryeri,Yéryeri,Γέργερη', 35.1328100, 24.9496300, 'GR', '2013-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62573, 'Geráni', 'Gerani', 'Gerani,Geráni,Yeranion,Yeránion,Γεράνι', 35.5000000, 23.8666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62574, 'Geráki', 'Geraki', 'Geraki,Gerakion,Geráki,Gerákion,Ybraki,Yeraki,Yerakion,Yeráki,Yerákion,Γεράκι,Γεράκιον', 36.9922700, 22.7066300, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62575, 'Géfyra', 'Gefyra', 'Gefyra,Géfyra,Yefira,Yéfira,Γέφυρα', 36.6871500, 23.0350900, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62576, 'Xylókastro', 'Xylokastro', 'Xilokastron,Xilókastron,Xylokastro,Xylokastron,Xylókastro,Xylókastron,Ξυλόκαστρο,Ξυλόκαστρον', 38.0776200, 22.6316600, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62577, 'Vrontádos', 'Vrontados', 'Vrondadhes,Vrondadhos,Vrondhades,Vrondhádes,Vrondádhes,Vrondádhos,Vrontados,Vrontádos,Βροντάδος', 38.4087600, 26.1294800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62578, 'Vrýses', 'Vryses', 'Vrisai,Vrises,Vrysai,Vryses,Vrísai,Vríses,Vrýsai,Vrýses,Βρύσες', 35.3758500, 24.2010900, 'GR', '2015-11-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62579, 'Vraná', 'Vrana', 'Vrana,Vranas,Vraná,Βρανάς', 38.1249700, 23.9519800, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62580, 'Vrachnaíika', 'Vrachnaiika', 'Agios Vasileios,Ayios Vasilios,Brachnaiika,Vrachnaiika,Vrachnaíika,Vrachneika,Vrakhnaiika,Vrakhnaíika,Vrakhneika,Vrakhnéïka,Áyios Vasílios,Άγιος Βασίλειος,Βραχνέικα,Βραχναίικα', 38.1625300, 21.6669300, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62581, 'Vrakháti', 'Vrakhati', 'Vrachati,Vrachation,Vrachatis,Vrakhati,Vrakhation,Vrakháti,Vrakhátion,Βραχάτης,Βραχάτι,Βραχάτιον', 37.9589500, 22.8057300, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62582, 'Vounoplagiá', 'Vounoplagia', 'Vounoplagia,Vounoplagiá,Vounoplayia,Vounoplayiá,Zelova,Zélova,Βουνοπλαγιά', 39.6916100, 20.7859700, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62583, 'Vouliagméni', 'Vouliagmeni', 'Vouliagmeni,Vouliagméni,Βουλιαγμένη', 37.8142300, 23.7789200, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62584, 'Voúla', 'Voula', 'Voula,Voúla,Vule,Βούλα,Вуле', 37.8422100, 23.7765100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62585, 'Vónitsa', 'Vonitsa', 'Bonitsa,Vonitsa,Vónitsa,Βόνιτσα', 38.9163900, 20.8863900, 'GR', '2015-09-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62586, 'Volos', 'Volos', 'Bolus,Iolcus,VOL,Volo,Volos,Vólos,Wolos,wwlws,Βόλος,Волос,וולוס', 39.3610300, 22.9424800, 'GR', '2016-12-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62587, 'Vokhaïkó', 'Vokhaiko', 'Ayios Dhimitrios,Krokidhas,Krokidhás,Vochaiko,Vokhaikon,Vokhaïkón,Áyios Dhimítrios,Βοχαϊκό', 37.9484300, 22.7920300, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62588, 'Vlachópoulo', 'Vlachopoulo', 'Vlachopoulo,Vlachopoulon,Vlachópoulo,Vlachópoulon,Vlakhopoulon,Vlakhópoulon,Βλαχόπουλο,Βλαχόπουλον', 37.0318600, 21.7915800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62589, 'Vlachiótis', 'Vlachiotis', 'Vlachiotis,Vlachiótis,Vlakhioti,Vlakhiotika,Vlakhiotis,Vlakhióti,Vlakhiótika,Vlakhiótis,Βλαχιώτης', 36.8609400, 22.7083100, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62590, 'Výronas', 'Vyronas', 'Viron,Vyron,Vyronas,Víron,Výronas,Βύρων,Βύρωνας', 37.9610500, 23.7530000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62591, 'Vília', 'Vilia', 'Bilia,Vilia,Villia,Vília,Βίλια', 38.1671600, 23.3365900, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62592, 'Aktaío', 'Aktaio', 'Aktaio,Aktaío,Vernardeika,Vernardhaiika,Vernardhaíika,Vernardheika,Vernardhéïka,Ακταίο,Βερναρδέικα', 38.3044400, 21.7944000, 'GR', '2015-12-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62593, 'Verdikoússa', 'Verdikoussa', 'Verdhikousa,Verdhikoussa,Verdhikoúsa,Verdhikoússa,Verdikoussa,Verdikoússa,Βερδικούσσα', 39.7817500, 21.9772800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62594, 'Vélo', 'Velo', 'Vello,Vellon,Velo,Velon,Véllo,Véllon,Vélo,Vélon,Βέλο,Βέλον', 37.9761000, 22.7598500, 'GR', '2014-08-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62595, 'Velestíno', 'Velestino', 'Pherai,Velestina,Velestino,Velestinon,Velestíno,Velestínon,Βελεστίνο,Βελεστίνον,Велестино', 39.3818100, 22.7461600, 'GR', '2015-04-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62596, 'Vágia', 'Vagia', 'Bagia,Vagia,Vayia,Vágia,Váyia,Βάγια', 38.3174800, 23.1775200, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62597, 'Vathí', 'Vathi', 'Bathy,Vathi,Vathi Avlidhos,Vathy,Vathí,Vathí Avlídhos,Βαθύ', 38.4049000, 23.6033200, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62598, 'Vathý', 'Vathy', 'Vathi,Vathy,Vathí,Vathý,Βαθύ', 37.7642000, 23.4801100, 'GR', '2016-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62599, 'Vathý', 'Vathy', 'Ano Vathi,Ano Vathy,Vathi,Vathy,Vathí,Vathý,Vati,bati,wa xi,Áno Vathí,Άνω Βαθύ,Βαθύ,Вати,Ваті,瓦西,바티', 37.7469200, 26.9831600, 'GR', '2016-10-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62600, 'Vasilikón', 'Vasilikon', 'Vasiliko,Vasilikon,Vasilikón,Βασιλικό,Βασιλικόν', 38.4258600, 23.6718900, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62601, 'Vasilikí', 'Vasiliki', 'Vasiliki,Vasilikí,Voivoda,Voïvóda,Βασιλική', 39.6398400, 21.7044800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62602, 'Varvásaina', 'Varvasaina', 'Varvasaina,Varvásaina,Βαρβάσαινα', 37.6710600, 21.4988600, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62603, 'Vartholomió', 'Vartholomio', 'Vartholomi,Vartholomio,Vartholomion,Vartholomió,Vartholomión,Βαρθολομιό,Βαρθολομιόν', 37.8621900, 21.2057500, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62604, 'Varnávas', 'Varnavas', 'Barnabas,Varnavas,Varnávas,Βαρνάβας', 38.2235800, 23.9230700, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62605, 'Vareiá', 'Vareia', 'Bareia,Vareia,Vareiá,Varia,Variá,Varyia,Varyiá,Βαρειά', 39.0794100, 26.5777700, 'GR', '2014-05-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62606, 'Vári', 'Vari', 'Vari,Vári,Βάρη', 37.8332000, 23.8031100, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62607, 'Vári', 'Vari', 'Vari,Vári,Βάρη', 37.3985900, 24.9490400, 'GR', '2017-04-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62608, 'Várda', 'Varda', 'Ano Manolas,Varda,Vardha,Várda,Várdha,Áno Manolás,Βάρδα', 38.0305800, 21.3650600, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62609, 'Vanáton', 'Vanaton', 'Vanato,Vanaton,Vanáton,Βανάτο,Βανάτον', 37.7944600, 20.8518800, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62610, 'Vamvakoú', 'Vamvakou', 'Bairakli,Baïraklí,Vamvakou,Vamvakoú,Βαμβακού', 39.3370800, 22.4198300, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62611, 'Valsamáta', 'Valsamata', 'Valsamata,Valsamáta,Βαλσαμάτα', 38.1760000, 20.5839200, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62612, 'Tsikalariá', 'Tsikalaria', 'Tsikalaria,Tsikalariá,Tsikalaryia,Tsikalaryiá,Τσικαλαριά', 35.4762300, 24.0627400, 'GR', '2013-12-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62613, 'Tsarítsani', 'Tsaritsani', 'Tsaritsani,Tsarítsani,Τσαρίτσανη', 39.8811700, 22.2275800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62614, 'Trípoli', 'Tripoli', 'Tripole,Tripole Arkadias,Tripoli,Tripolis,Tripolitza,Tripolizza,Trípoli,Trípolis,Τρίπολη,Τρίπολη Αρκαδίας,Триполи', 37.5088900, 22.3794400, 'GR', '2012-02-28', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62615, 'Tríkeri', 'Trikeri', 'Trikeri,Trikerion,Trikkeri,Tríkeri,Tríkerion,Tríkkeri,Τρίκερι', 39.1011400, 23.0766900, 'GR', '2015-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62616, 'Tríkala', 'Trikala', 'Tirhala,Trikala,Trikalon,Trikkaion,Trikkala,Trikkaíon,Trikálon,Tríkala,Tríkkala,Tırhala,trhalh,Τρίκαλα,Трикала,ترحاله', 39.5549300, 21.7683700, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62617, 'Triandaíika', 'Triandaiika', 'Triandaiika,Triandaíika,Triandeika,Triandéïka,Triantaiika,Τριανταίικα', 38.6553000, 21.3831500, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62618, 'Ialysós', 'Ialysos', 'Ialisos,Ialissos,Ialisós,Ialysos,Ialysou,Ialyssos,Ialyssós,Ialysós,Lalisos,Trianda,Trianta,Triánda,Triánta,Ιαλυσού,Ιαλυσός,Τριάντα,Лалисос,Трианта', 36.4135200, 28.1551600, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62619, 'Traganón', 'Traganon', 'Tragano,Traganon,Traganón,Τραγανό,Τραγανόν', 37.8978900, 21.3124500, 'GR', '2017-07-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62620, 'Tolón', 'Tolon', 'Tolo,Tolon,Tolos,Tolón,Tolós,Τολo,Τολό,Τολόν', 37.5202100, 22.8586000, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62621, 'Týrnavos', 'Tyrnavos', 'Tirnavos,Tyrnavo,Tyrnavos,Tírnavos,Týrnavos,Τύρναβος', 39.7377800, 22.2891700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62622, 'Tínos', 'Tinos', 'Saint Nicholas,Tenos,Tinos,Τήνος', 37.5375300, 25.1634300, 'GR', '2016-11-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62623, 'Tympáki', 'Tympaki', 'Dhivaki,Dhiváki,Timbakion,Timbákion,Tybaki,Tympaki,Tympakion,Tympáki,Tympákion,Τυμπάκι,Τυμπάκιον', 35.0728600, 24.7685100, 'GR', '2015-11-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62624, 'Tílisos', 'Tilisos', 'Tilisos,Tilissos,Tylisos,Tylissos,Tílisos,Tílissos,Τύλισος', 35.2960700, 25.0158700, 'GR', '2012-03-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62625, 'Thrapsanón', 'Thrapsanon', 'Thrapsano,Thrapsanon,Thrapsanos,Thrapsanó,Thrapsanón,Thrapsanós,Θραψανόν', 35.1879800, 25.2809100, 'GR', '2012-03-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62626, 'Thouría', 'Thouria', 'Thouria,Thouría,Θουρία', 37.0835600, 22.0489100, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62627, 'Thívai', 'Thivai', 'Teba,Tebas,Tebo,Teboj,Thebae,Thebai,Theben,Thebes,Thiva,Thivai,Thèbes,Thíva,Thívai,Thēbai,Θήβα,Θήβαι,Θηβαι', 38.3250000, 23.3188900, 'GR', '2014-03-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62628, 'Firá', 'Fira', 'FIRA,Fira,Firá,JTR,Thera,Thira,Thira (Fira),Thíra,Tira,Θήρα,Θηρα,ΦΗΡΑ,Φηρά,Тира,Фира', 36.4210700, 25.4308700, 'GR', '2017-01-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62629, 'Thymianá', 'Thymiana', 'Chorio Thymiana,Chorió Thymianá,Effymiana,Effymianá,Evfimiana,Evfimianá,Thimiana,Thimianá,Thymiana,Thymianá,Θυμιανά', 38.3143900, 26.1325900, 'GR', '2014-08-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62630, 'Thesprotikó', 'Thesprotiko', 'Dhelovon,Dhélovon,Thesprotiko,Thesprotikon,Thesprotikó,Thesprotikón,Θεσπρωτικό,Θεσπρωτικόν', 39.2511400, 20.7852800, 'GR', '2014-07-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62631, 'Thespiés', 'Thespies', 'Erimokastron,Erimókastron,Thespiae,Thespiai,Thespiaí,Thespies,Thespiés,Θεσπιές,Θεσπιαί', 38.3030000, 23.1501600, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62632, 'Thérmo', 'Thermo', 'Kefalovrison,Kefalóvrison,Thermo,Thermon,Thérmo,Thérmon,Θέρμο,Θέρμον', 38.5735800, 21.6662800, 'GR', '2017-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62633, 'Terpsithéa', 'Terpsithea', 'Baislar,Baïslár,Kaislar,Kaïslár,Terpsithea,Terpsithéa,Καϊσλάρ,Μπαϊσλάρ,Τερψιθέα', 39.6189800, 22.3508700, 'GR', '2015-10-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62634, 'Témeni', 'Temeni', 'Temeni,Témeni,Τέμενη', 38.2370700, 22.1253300, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62635, 'Távros', 'Tavros', 'Nea Sfayia,Néa Sfayía,Tavros,Távros,Ταύρος', 37.9706400, 23.6904300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62636, 'Steíri', 'Steiri', 'Steiri,Steirion,Steíri,Steírion,Stiri,Stirion,Stíri,Stírion,Στείρι,Στείριον', 38.4083100, 22.7116200, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62637, 'Stýpsi', 'Stypsi', 'Stipsi,Stipsos,Stypsi,Stípsi,Stýpsi,Στύψη', 39.3112100, 26.2205600, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62638, 'Stylída', 'Stylida', 'Stilida,Stilis,Stilís,Stylida,Stylis,Stylída,Στυλίδα,Στυλίς,Стилида', 38.9166700, 22.6166700, 'GR', '2014-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62639, 'Stefanovíkeio', 'Stefanovikeio', 'Hajimisi,Hajímisi,Stefanavikion,Stefanavíkion,Stefanovikeio,Stefanovikeion,Stefanoviki,Stefanovikion,Stefanovíki,Stefanovíkion,Στεφανοβίκειο,Στεφανοβίκειον,Στεφανοβίκι,Στεφανοβίκιον', 39.4635400, 22.7419800, 'GR', '2015-04-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62640, 'Stavrós', 'Stavros', 'Beki,Bekí,Stavros,Stavrós,Σταυρός', 38.8964100, 22.3708200, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62641, 'Stavráki', 'Stavraki', 'Stavraki,Stavrakion,Stavráki,Stavrákion,Σταυράκι,Σταυράκιον', 39.6561400, 20.8180600, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62642, 'Stános', 'Stanos', 'Stano,Stanos,Stáno,Stános,Στάνος', 38.8045300, 21.1746100, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62643, 'Stamáta', 'Stamata', 'Stamata,Stamáta,Σταμάτα', 38.1254600, 23.8803800, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62644, 'Stalís', 'Stalis', 'Stalida,Stalis,Σταλίς,Σταλιδα', 35.2925700, 25.4329200, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62645, 'Spétses', 'Spetses', 'Pityoussa,Spetes,Spetsai,Spetses,Spezzia,Spétsai,Spétses,Πιτυούσσα,Σπέτες,Σπέτσαι,Σπέτσες', 37.2619100, 23.1594300, 'GR', '2014-08-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62646, 'Sperchógeia', 'Sperchogeia', 'Sperchogeia,Sperchógeia,Sperkhoyia,Sperkhóyia,Σπερχόγεια', 37.0740500, 22.0624800, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62647, 'Spercheiáda', 'Spercheiada', 'Spercheiada,Spercheias,Spercheiáda,Sperkhias,Sperkhiás,Σπερχειάδα,Σπερχειάς', 38.9065600, 22.1279200, 'GR', '2014-09-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62648, 'Spáta', 'Spata', 'Spata,Spáta,Σπάτα', 37.9616300, 23.9151400, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62649, 'Spárti', 'Sparti', 'Esparta,Lacedaemon,Lacedemonia,Lakedaimon,Lakedaímon,SPJ,Sparta,Sparte,Sparti,Sparto,Spartē,Spárti,Λακεδαιμων,Σπάρτη,Σπαρτη,Спарта', 37.0744600, 22.4300900, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62650, 'Soúrpi', 'Sourpi', 'Sourpi,Soúrpi,Σούρπη', 39.1031900, 22.8978900, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62651, 'Soúda', 'Souda', 'Souda,Soudha,Soúda,Soúdha,Σούδα', 35.4871700, 24.0734400, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62652, 'Sofikón', 'Sofikon', 'Sofiko,Sofikon,Sofikón,Sophiko,Σοφικό,Σοφικόν', 37.7941200, 23.0520400, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62653, 'Sofádes', 'Sofades', 'Sofades,Sofadhes,Sofádes,Sofádhes,Sophades,Σοφάδες', 39.3333300, 22.1000000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62654, 'Skópelos', 'Skopelos', 'Skopelos,Skopelos Town,Skópelos,Σκόπελος', 39.1214400, 23.7268600, 'GR', '2016-01-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62655, 'Skópelos', 'Skopelos', 'Skopelos,Skópelos,Σκόπελος', 39.0292200, 26.4483600, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62656, 'Skýros', 'Skyros', 'Skiros,Skyros,Skíros,Skýros,Σκύρος', 38.9041700, 24.5630600, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62657, 'Skiáthos', 'Skiathos', 'JSI,Skiathos,Skiathos City,Σκιάθος', 39.1622700, 23.4908900, 'GR', '2017-06-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62658, 'Schísma Eloúndas', 'Schisma Eloundas', 'Schisma Eloundas,Schisma Elountas,Skhisma,Skhísma,Σχίσμα Ελούντας', 35.2575700, 25.7279600, 'GR', '2015-09-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62659, 'Schimatári', 'Schimatari', 'Schimatari,Schimatarion,Schimatári,Skhimatari,Skhimatarion,Skhimatári,Skhimatárion,Skimatari,Σχηματάρι,Σχηματάριον', 38.3500000, 23.5833300, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62660, 'Skarmagkás', 'Skarmagkas', 'Scaramanga,Skaramagkas,Skaramanga,Skaramangas,Skaramangá,Skaramangás,Skaramankas,Skarmagkas,Skarmagkás,Skarmankas,Σκαραμαγκάς,Σκαρμαγκάς', 38.0113300, 23.6030300, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62661, 'Skála Oropoú', 'Skala Oropou', 'Scalaorapou,Skala Oropou,Skála Oropoú,Σκάλα Όρωπού', 38.3196400, 23.7876300, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62662, 'Skalánion', 'Skalanion', 'Skalani,Skalanion,Skaláni,Skalánion,Σκαλάνιον', 35.2826200, 25.1868400, 'GR', '2012-03-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62663, 'Skála', 'Skala', 'Scala,Skala,Skála,Σκάλα', 37.3221800, 26.5430000, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62664, 'Skála', 'Skala', 'Skala,Skála,Σκάλα', 36.8500000, 22.6666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62665, 'Sitia', 'Sitia', 'JSH,Siteia,Siteía,Sitia,Sitija,Sitía,sytya,xi di ya,Σητεία,Сития,Ситија,Сітія,سيتيا,سیتیا,锡蒂亚', 35.2078300, 26.1046700, 'GR', '2015-09-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62666, 'Sísion', 'Sision', 'Kato Sisi,Káto Sísi,Sisi,Sision,Sissi,Sísion,Σίσι,Σίσιον', 35.3077000, 25.5202100, 'GR', '2014-07-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62667, 'Synoikismós Chavaríou', 'Synoikismos Chavariou', 'Sinoikismos Khavarion,Sinoikismós Khavárion,Sionoikizmos Khavari,Sionoikizmós Khávari,Synoikismos Chavariou,Synoikismós Chavaríou,Συνοικισμός Χαβαρίου', 37.8557500, 21.3878900, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62668, 'Sými', 'Symi', 'Simi,Sombeki,Syme,Symi,Sími,Sými,Σύμη,Сими', 36.6154700, 27.8361900, 'GR', '2016-12-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62669, 'Sylivainiótika', 'Sylivainiotika', 'Silivaina,Silivainiotika,Silivainiótika,Siliveniotika,Siliveniótika,Silívaina,Sklivaina,Sklívaina,Sylivainiotika,Sylivainiótika,Συλιβαινιώτικα', 38.1613900, 22.3315600, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62670, 'Sykoúrio', 'Sykourio', 'Mega Keserli,Méga Keserlí,Sikourion,Sikoúrion,Sykourio,Sykourion,Sykoúrio,Sykoúrion,Συκούριο,Συκούριον', 39.7594700, 22.5800000, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62671, 'Sikyón', 'Sikyon', 'Sicion,Sición,Sicyon,Sicyone,Sikion,Sikión,Sikyon,Sikyona,Vasiliko,Vasilikon,Vasilikos,Vasilikón,Βασιλικό,Βασιλικόν,Βασιλικός,Σικυών,Σικυώνα,Сикион', 37.9823000, 22.7246200, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62672, 'Síkinos', 'Sikinos', 'Kastro Sikinou,Kastron,Kástro Sikínou,Kástron,Sikinos,Síkinos,Σίκινος', 36.7000000, 25.1166700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62673, 'Sykiá', 'Sykia', 'Sikea,Sikéa,Sykea,Sykia,Sykiá,Sykéa,Συκέα,Συκιά', 36.7639800, 22.9430200, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62674, 'Sérifos', 'Serifos', 'Serifo,Serifos,Seriphos,Sèrifos,Sérifos,Σέριφος,Серифос,Серіфос', 37.1539700, 24.5061400, 'GR', '2014-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62675, 'Selínia', 'Selinia', 'Selinia,Selínia,Σελήνια', 37.9332000, 23.5314700, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62676, 'Savália', 'Savalia', 'Sabalia,Savallia,Savvalia,Savvália,Savállia,Σαβάλια', 37.8215800, 21.2942500, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62677, 'Sardínia', 'Sardinia', 'Sardhinia,Sardhinina,Sardhínia,Sardhínina,Sardinia,Sardínia,Σαρδίνια', 38.8900300, 21.2061900, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62678, 'Samos', 'Samos', 'Kato Vathi,Kato Vathy,Kato Vathý,Liman Vatheos,Liman Vathéos,Limen Vatheos,Limenas Vatheos,Limin Vatheos,Limén Vathéos,Limín Vathéos,Port Vathi,SMI,Samos,Sámos,Vathy,Vathy harbor,Κάτω Βαθύ,Λιμένας Βαθέος,Λιμήν Βαθέος,Σάμος,Самос', 37.7574400, 26.9761600, 'GR', '2016-11-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62679, 'Sámi', 'Sami', 'Aigialos,Aigialós,Aiyialos,Aiyialós,Gialos,Sami,Samos,Sámi,Yialos,Yialós,Γιαλός,Σάμη', 38.2508100, 20.6468600, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62391, 'Upernavik', 'Upernavik', 'Gorad Upernavik,JUV,Summer Place,Upernavik,Upernavikas,Upernaviks,Upernivik,abrnawyk,uperunabiku,wu pei na wei ke,Горад Упернавік,Упернавик,Упернавік,آبرناويك,უპერნავიკი,ウペルナビク,乌佩纳维克', 72.7868400, -56.1548500, 'GL', '2011-02-16', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62392, 'Sisimiut', 'Sisimiut', 'Amerdlok,Gorad Sisimiut,Holstanburg,Holsteinborg,Holsteinsborg,Holstenborg,Holstensborg,Holstānburg,JHS,Sisimiut,Sisimiutas,Sisimiuts,Sisimjut,shishimiuto,sisimiuteu,sysymywt,xi xi miao te,Горад Сісіміўт,Сисимиут,Сисимјут,Сісіміут,סיסימיוט,سيسيميوت,سیسیمیوت,სისიმიუტი,シシミウト,西西缪特,시시미우트', 66.9394600, -53.6735000, 'GL', '2011-02-16', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62393, 'Qasigiannguit', 'Qasigiannguit', 'Christianshaab,Christianshab,Christianshåb,JCH,Kasigianguit,Kasigianguits,Kasigiannguit,Kasigijanguit,Qasigianguit,Qasigiannguit,ka xi jiang ji te,kashigianguito,Касигианнгуит,Касигијангуит,კასიგიანგუიტი,カシギアングイト,卡西江吉特', 68.8192600, -51.1922100, 'GL', '2011-02-16', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62394, 'Qaqortoq', 'Qaqortoq', 'Gorad Kakartok,JJU,Julian Haab,Julianehaab,Julianehab,Julianehåb,Kakortak,Kakortok,Kakortokas,Kakortoks,Qaqortoq,ka ke er tuo ke,kakotokku,kakwrtwk,kwakoleutog,Горад Какарток,Какорток,קואקורטוק,كاكورتوك,კაკორტოკი,カコトック,卡科尔托克,콰코르톡', 60.7166700, -46.0333300, 'GL', '2012-01-18', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62395, 'Paamiut', 'Paamiut', 'Frederikshab,Frederikshåb,JFR,Paamiut,Paamiuts,Pamiut,Pamiutas,bamywt,pa miao te,pamyuto,Паамиут,Пааміут,Памиут,פאאמיוט,باميوت,პაამიუტი,パーミュート,帕缪特', 61.9940200, -49.6677600, 'GL', '2013-04-13', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62396, 'Nuuk', 'Nuuk', 'GOH,Godhopa,Godthaab,Godthab,Godthåb,Gorad Nuk,Nououk,Nuk,Nuka,Nukas,Nuko,Nuuk,Nuuk (Godthab),Nuuk (Godthåb),Nuuks,Nūka,nu ke,nuk,nuka,nukeu,nuku,nwk,nwʼwq,Νουούκ,Горад Нук,Нук,Нуук,Նուուկ,נואוק,نوك,نوک,नूक,ਨੂਕ,ନୁକ,நூக்,นุก,ნუუკი,ᓅᒃ,ヌーク,努克,누크', 64.1834700, -51.7215700, 'GL', '2014-05-11', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62397, 'Narsaq', 'Narsaq', 'JNS,Narsak,Narsaks,Narsaq,Narssaq,na sa ke,narsak,narusaku,Нарсак,נארסאק,نارساك,ნარსაკი,ナルサーク,纳萨克', 60.9151700, -46.0526300, 'GL', '2013-04-27', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62398, 'Nanortalik', 'Nanortalik', 'Ilivileq,JNN,Nanortalik,Nanortaliks,Nennortalik,na nuo ta li ke,nanoleutallikeu,Нанорталик,ნანორტალიკი,纳诺塔利克,나노르탈리크', 60.1431700, -45.2371500, 'GL', '2012-12-09', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62399, 'Maniitsoq', 'Maniitsoq', 'Gorad Manitsok,JSU,Maitsoq,Maniitsok,Maniitsoq,Manitsok,Manitsoks,Manitsoq,Sukkertoppen,manitosokku,manytswk,mnytswq,Горад Манітсок,Маниитсок,Манитсок,מניטסוק,مانيتسوك,მანიიტსოკი,マニートソック', 65.4166700, -52.9000000, 'GL', '2012-01-18', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62400, 'Ilulissat', 'Ilulissat', 'Gorad Ilulisat,Ilulisat,Ilulisatas,Ilulisats,Ilulissat,JAV,Jakobshavn,Pagetonas kai Fiord Iloulissat,aylwlysat,illulisateu,irurisatto,yi lu li sa te,İlulissat,Παγετώνας και Φιόρδ Ιλούλισσατ,Ілуліссат,Горад Ілулісат,Илулисат,Илулиссат,אילוליסאט,إيلوليسات,ილულისატი,イルリサット,伊卢利萨特,일루리사트', 69.2166700, -51.1000000, 'GL', '2012-01-18', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62401, 'Tasiilaq', 'Tasiilaq', 'AGM,Ammassalik,Angmagssalik,Angmagsslik,Angmassalik,Tasiilak,Tasiilaq,Tasilak,Tasilakas,Tasilaks,tashiraku,tasillakeu,tasylak,Тасиилак,Тасилак,Տասիիլաք,טאסיאילק,تاسيلاك,ტასიილაკი,タシーラク,타실라크', 65.6145100, -37.6367600, 'GL', '2016-05-05', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62402, 'Aasiaat', 'Aasiaat', 'Aasiaat,Aasiat,Asijat,Ausiait,Egedesminde,JEG,Osiotas,Uosiuots,ashiato,asiateu,asyat,ya xi ya te,Аасиаат,Аасіат,Асијат,אסיאת,آسيات,აასიაატი,アシアート,亞西亞特,아시아트', 68.7098100, -52.8698800, 'GL', '2013-08-17', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62403, 'Uummannaq', 'Uummannaq', 'UMD,Umanak,Umanakas,Umanaks,Umanaq,Uummannak,Uummannaq,umaleunakeu,umanakku,wu ma na ke,Ũmánaq,Уманак,Уумманнак,უუმანაკი,ウマナック,烏瑪納克,우마르나크', 70.6747200, -52.1263900, 'GL', '2013-08-05', 87);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62180, 'Victoria', 'Victoria', 'Grand Pauve,Grand Pauvre,Saint Mark,Saint Mark Village,Saint Marks', 12.1902100, -61.7067700, 'GD', '2013-06-27', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62181, 'Sauteurs', 'Sauteurs', 'Sauteurs,Sautiers', 12.2183300, -61.6391700, 'GD', '2013-11-21', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62182, 'Saint George''s', 'Saint George''s', 'Fort Royal,Georgetown,Grenada City,Lewis,Port Louis,Port Royal,Saint George,Saint George''s,Saint George.s,Saint-Georges,Sent Dzordzas,Sent Džordžas,Sent Tzortzes,Sent-Dzhorzhes,St Georges,St. George''s,seinteujojiseu,sentojojizu,snt g''wrg'',Σεντ Τζόρτζες,Сент-Джоржес,סנט ג''ורג'',セントジョージズ,세인트조지스', 12.0528800, -61.7522600, 'GD', '2017-05-24', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62183, 'Saint David’s', 'Saint David''s', '', 12.0490300, -61.6687500, 'GD', '2013-07-07', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62184, 'Hillsborough', 'Hillsborough', '', 12.4829200, -61.4559700, 'GD', '2013-06-28', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62185, 'Grenville', 'Grenville', 'Grenville,La Baye', 12.1227800, -61.6249800, 'GD', '2013-06-27', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62186, 'Gouyave', 'Gouyave', 'Charlotte Town,Gouave,Gouyave,Goyave,Guyave', 12.1646200, -61.7296500, 'GD', '2012-02-19', 88);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62515, 'Vieux-Habitants', 'Vieux-Habitants', 'Les Habitants,Vez-Abitan,Vieux-Habitants,Вєз-Абітан', 16.0586600, -61.7666700, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62516, 'Trois-Rivières', 'Trois-Rivieres', 'Les Trois Rivieres,Les Trois Rivières,Trois-Rivieres,Trois-Rivières', 15.9759500, -61.6449200, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62517, 'Petites Anses', 'Petites Anses', 'HTB,Le Bourg,Petites Anses,Petites-Anses,Terr-de-Ba,Terre-de-Bas,Vostrau Tehr-deh-Bas,tyr-dw-ba,Востраў Тэр-дэ-Бас,Терр-де-Ба,تير-دو-با', 15.8499300, -61.6445700, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62518, 'Saint-François', 'Saint-Francois', 'SFC,Saint-Francois,Saint-François', 16.2523600, -61.2733200, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62519, 'Sainte-Rose', 'Sainte-Rose', 'Sainte-Rose,Sent-Roz,Сент-Роз', 16.3326400, -61.6969000, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62520, 'Sainte-Anne', 'Sainte-Anne', 'Sainte-Anne', 16.2256400, -61.3809800, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62521, 'Saint-Claude', 'Saint-Claude', 'Saint-Claude', 16.0251500, -61.6997500, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62522, 'Port-Louis', 'Port-Louis', 'Port-Louis', 16.4174900, -61.5304500, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62523, 'Pointe-Noire', 'Pointe-Noire', 'La Pointe-Noire,Point Noire,Pointe-Noire', 16.2321800, -61.7891700, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62524, 'Pointe-à-Pitre', 'Pointe-a-Pitre', 'La Pointe a Pitre,La Pointe à Pitre,PTP,Poent a Pitr,Pointe a Pitre,Pointe-a-Pitre,Pointe-à-Pitre,Pouant-a-Pitr,Puant a Pitras,Puehnt-a-Pitr,Puent-a-Pitr,bwant-ah-bytr,pi te er jiao cheng,powantapitoru,Πουάντ-α-Πιτρ,Поент а Питр,Пуент-а-Пітр,Пуэнт-а-Питр,פואנט-א-פיטר,بوانت-آه-بيتر,ポワンタピートル,皮特尔角城', 16.2412500, -61.5361400, 'GP', '2016-08-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62525, 'Petit-Canal', 'Petit-Canal', 'Peti-Kanal'',Petit Canat,Petit-Canal,byty-kanal,Петі-Каналь,بيتي-كانال', 16.3791300, -61.4871600, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62526, 'Petit-Bourg', 'Petit-Bourg', 'Peti-Bur,Petit-Bourg,Pti Bur,Pti-Burg,byty-bwr,pwty bwr,Петі-Бур,Пти Бур,Пти-Бург,بيتي-بور,پوتی بور', 16.1916300, -61.5914000, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62527, 'Les Abymes', 'Les Abymes', 'Abeymes,Abymes,Les Abymes,Lez-Abim,PTP,lzabym,lzbym,rezabimu,sa lai bi mei,Лез-Абім,לז אבים,لزابيم,لزبیم,レザビーム,薩萊比梅', 16.2730000, -61.5050700, 'GP', '2017-05-22', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62528, 'Le Moule', 'Le Moule', 'Le Moule,Le Mul,Le-Mul'',Moule,lw mwl,Ле Мул,Ле-Муль,لو مول', 16.3316400, -61.3465600, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62529, 'Le Gosier', 'Le Gosier', 'Gosier,Gozier,Le Gosier,Le Gozje,Le-Goz''e,lw ghwsyyh,lw gwsyh,Ле Гозје,Ле-Гозьє,لو غوسييه,لو گوسیه', 16.2061800, -61.4930600, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62530, 'Lamentin', 'Lamentin', 'Lamentin,Le Lamentin', 16.2704700, -61.6316600, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62531, 'Beauséjour', 'Beausejour', 'Beausejour,Beauséjour,Grande Anse,La Grande Anse', 16.3041300, -61.0737500, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62532, 'Grand-Bourg', 'Grand-Bourg', 'Gran-Bur,Grand Buras,Grand-Bourg,ghran-bwr,guran=buru,Гран-Бур,גראן-בור,غران-بور,グラン＝ブール', 15.8840200, -61.3148000, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62533, 'Gourbeyre', 'Gourbeyre', 'Gourbevre,Gourbeyre,Gurbejr,ghwrbyr,Гурбейр,غوربير', 15.9945400, -61.6920300, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62534, 'Capesterre-Belle-Eau', 'Capesterre-Belle-Eau', 'Capesterre,Capesterre-Belle-Eau,Kapester-Bel-O,Kapesterr-Bel''-O,kabstr-byl-aw,Капестер-Бел-О,Капестерр-Бель-О,كابستر-بيل-أو', 16.0449500, -61.5642500, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62535, 'Bouillante', 'Bouillante', 'Bouillante,Bujant,bwyant,Буянт,بويانت', 16.1304300, -61.7689500, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62536, 'Basse-Terre', 'Basse-Terre', 'BBR,Bas Ter,Bas Teras,Bas-Ter,Bas-Tero,Bas-ter,Bassa-Terra,Basse Terre,Basse-Terre,Bastera,Bastēra,Bâssa-Tèrra,Gorad Bas-Tehr,ba si te er,bas-tr,bas-tyr,base-tera,baseuteleu,basuteru,paster,Μπας-Τερ,Бас Тер,Бас-Тер,Бас-тер,Горад Бас-Тэр,Բաս Տեր,באס טר,باس-تر,باس-تير,باس-تیر,बासे-तेर,பாஸ்தெர்,บัส-แตร์,ბას-ტერი,バステール,巴斯特尔,바스테르', 15.9985400, -61.7254800, 'GP', '2011-12-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62537, 'Baillif', 'Baillif', 'Baif,Baillif,Le Baillif,bayf,Баїф,بايف', 16.0203700, -61.7461100, 'GP', '2017-05-08', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62538, 'Baie-Mahault', 'Baie-Mahault', 'Bai-Mao,Baie-Mahault,Baj Mao,La Baie Mahault,bay-maww,khlyj myw,Баї-Мао,Бај Мао,باي-ماؤو,خلیج مئو', 16.2673800, -61.5854300, 'GP', '2012-01-18', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62539, 'Anse-Bertrand', 'Anse-Bertrand', 'Ans-Bertran,Anse-Bertrand,ans-brtran,ansu=berutoran,Анс-Бертран,آنس-برتران,アンス＝ベルトラン', 16.4723900, -61.5073900, 'GP', '2017-06-07', 89);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62310, 'Torteval', 'Torteval', 'Saint Phillipe de Torteval,Torteval,Torteval Church', 49.4333300, -2.6500000, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62311, 'Saint Sampson', 'Saint Sampson', 'Saint Sampson,Saint Sampson''s,Saint Sampson’s,St. Sampson', 49.4838900, -2.5233300, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62312, 'Saint Peter Port', 'Saint Peter Port', 'GCI,Gorad Sent-Pitehr-Port,Saint Peter Port,Saint Pierre Port,Saint-Pierre-Port,Sanktapetrurbo,Sejnt Pitur Port,Sent Piter Port,Sent Piter Portas,Sent-Piter-Port,Sentpiterporta,Sentpīterporta,St Peter Port,St. Peter Port,san bytr bwrt,seinteupiteopoteu,sent pi texr phxrt,sheng bi de gang,sn ptr pwrt,snt pytr pwrt,Горад Сент-Пітэр-Порт,Сейнт Питър Порт,Сент Питер Порт,Сент-Питер-Порт,Сент-Пітер-Порт,סנט פיטר פורט,سان بيتر بورت,سن پتر پورت,سینٹ پیٹر پورٹ,เซนต์ปีเตอร์พอร์ต,სენტ-პიტერ-პორტი,セント・ピーター・ポート,圣彼得港,세인트피터포트', 49.4598100, -2.5352700, 'GG', '2013-11-01', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62313, 'St Anne', 'St Anne', 'Saint Anne,Saint Annes,St. Anne', 49.7154900, -2.2075700, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62314, 'Saint Saviour', 'Saint Saviour', 'Saint Saviour,St. Saviour', 49.4569400, -2.6358300, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62315, 'Castel', 'Castel', '', 49.4675700, -2.6001500, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62316, 'St. Andrew`s', 'St. Andrew`s', '', 49.4519500, -2.5728600, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62317, 'St Martin', 'St Martin', '', 49.4371300, -2.5547900, 'GG', '2016-11-03', 92);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62474, 'Youkounkoun', 'Youkounkoun', 'Youkounkoun', 12.5311000, -13.1224000, 'GN', '2012-06-18', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62475, 'Yomou', 'Yomou', 'Yomou', 7.5674800, -9.2628300, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62476, 'Tougué', 'Tougue', 'Tongue,Tougue,Tougué', 11.4450300, -11.6642200, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62477, 'Tondon', 'Tondon', 'Tendon,Tondon', 10.3666700, -13.3500000, 'GN', '2012-06-14', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62478, 'Tokonou', 'Tokonou', '', 9.6500000, -9.7833300, 'GN', '2012-06-14', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62479, 'Télimélé', 'Telimele', 'Telimele,Télimélé', 10.9000000, -13.0333300, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62480, 'Siguiri', 'Siguiri', 'GII,Sigiri,Siguiri,Сигири', 11.4228200, -9.1685200, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62481, 'Sanguéya', 'Sangueya', 'Sanguea,Sangueya,Sanguéa,Sanguéya', 10.7000000, -14.3666700, 'GN', '2012-06-14', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62482, 'Pita', 'Pita', '', 11.0591500, -12.3949800, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62483, 'Nzérékoré', 'Nzerekore', 'NZE,Nzerekore,Nzerekorė,Nzérékoré,eunjelekole,nzerekore,Нзерекоре,Նզերեկորե,نزیریکورے,ンゼレコレ,은제레코레', 7.7562400, -8.8179000, 'GN', '2013-05-10', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62484, 'Mandiana', 'Mandiana', 'Mandiana', 10.6257700, -8.6941300, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62485, 'Mamou', 'Mamou', '', 10.3754600, -12.0914800, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62486, 'Mali', 'Mali', 'Mali,Meli', 12.0790000, -12.2982000, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62487, 'Macenta', 'Macenta', 'MCA,Macenta,Magenta,Masenta,Масента', 8.5435100, -9.4709900, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62488, 'Lola', 'Lola', 'Lola', 7.8000000, -8.5333300, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62489, 'Labé', 'Labe', 'LEK,Laba,Labe,Labé,Лаба', 11.3182300, -12.2833200, 'GN', '2013-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62490, 'Kouroussa', 'Kouroussa', 'Kouroussa,Kurussa', 10.6500000, -9.8833300, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62491, 'Koundara', 'Koundara', 'Koundara,SBI', 12.4833300, -13.3000000, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62492, 'Koubia', 'Koubia', 'Koubia', 11.5863200, -11.8948500, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62493, 'Kissidougou', 'Kissidougou', 'KSI,Kisidugu,Kissidougou,Kissidugu,Кисидугу', 9.1848000, -10.0998700, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62494, 'Kindia', 'Kindia', 'Kindia,Kindla,Киндиа', 10.0569200, -12.8657600, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62495, 'Kimbo', 'Kimbo', '', 10.4000000, -13.5500000, 'GN', '2012-06-14', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62496, 'Kérouané', 'Kerouane', 'Kerouane,Kérouané', 9.2666700, -9.0166700, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62497, 'Kankan', 'Kankan', 'KNN,Kankan,Kankanas,kangkan,kankan,Канкан,کانکان,カンカン,캉칸', 10.3854200, -9.3056800, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62498, 'Kamsar', 'Kamsar', 'Kamissar,Kamsar,Kansar,Komsar,Port Kamsar,ka mu sa er,Комсар,卡姆薩爾', 10.6666700, -14.6000000, 'GN', '2012-06-14', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62499, 'Gueckedou', 'Gueckedou', 'Gueckedou,Guekedou,Guéckédou,Guékédou', 8.5674400, -10.1336000, 'GN', '2012-06-19', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62500, 'Gaoual', 'Gaoual', 'Gaoual', 11.7500000, -13.2000000, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62501, 'Fria', 'Fria', 'FIG,Firiya,Fria,Фриа', 10.3667600, -13.5825300, 'GN', '2015-03-06', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62502, 'Forécariah', 'Forecariah', 'Forecaria,Forecariah,Forikaria,Forécariah', 9.4305600, -13.0880600, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62503, 'Faranah', 'Faranah', 'FAA,Faranah', 10.0403600, -10.7434300, 'GN', '2012-06-15', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62504, 'Dubréka', 'Dubreka', 'Debreeka,Dubreka,Dubréka', 9.7911100, -13.5233300, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62505, 'Dinguiraye', 'Dinguiraye', 'Dinguiray,Dinguiraye', 11.2906200, -10.7121000, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62506, 'Dalaba', 'Dalaba', 'Dalaba', 10.6924900, -12.2496700, 'GN', '2015-03-06', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62507, 'Dabola', 'Dabola', 'Dabola,Дабола', 10.7433000, -11.1077800, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62508, 'Coyah', 'Coyah', 'Coya,Coyah,Koyah', 9.7064300, -13.3846500, 'GN', '2015-03-06', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62509, 'Conakry', 'Conakry', 'CKY,Conacri,Conakry,Konakri,Konakrio,Konakris,Konakry,ke na ke li,konakeuli,konakuri,Κόνακρι,Конакри,קונאקרי,コナクリ,科納克里,코나크리', 9.5379500, -13.6772900, 'GN', '2010-05-30', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62510, 'Camayenne', 'Camayenne', 'Camayen,Camayenne', 9.5350000, -13.6877800, 'GN', '2012-01-18', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62511, 'Boké', 'Boke', 'Boke,Boké,Boque,Boqué', 10.9321700, -14.2905500, 'GN', '2015-03-05', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62512, 'Boffa', 'Boffa', 'Boffa,Bomma', 10.1666700, -14.0333300, 'GN', '2012-07-07', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62513, 'Beyla', 'Beyla', 'Beyla', 8.6901100, -8.6486900, 'GN', '2015-03-06', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62514, 'Lélouma', 'Lelouma', 'Lelouma,Lélouma', 11.4238300, -12.6818300, 'GN', '2015-03-06', 93);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62102, 'Ravenshead', 'Ravenshead', '', 53.0865000, -1.1602600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62103, 'Flimwell', 'Flimwell', '', 51.0550200, 0.4453100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62104, 'Houghton', 'Houghton', '', 52.3328200, -0.1206800, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62105, 'Bulphan', 'Bulphan', '', 51.5461200, 0.3606600, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62106, 'Holywell Green', 'Holywell Green', '', 53.6740600, -1.8668200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62107, 'Keyworth', 'Keyworth', '', 52.8712200, -1.0899100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62108, 'Cockington', 'Cockington', '', 50.4633500, -3.5569100, 'GB', '2016-09-07', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62109, 'Culloden', 'Culloden', '', 57.4869900, -4.1415000, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62110, 'Greasby', 'Greasby', '', 53.3730000, -3.1233000, 'GB', '2016-10-26', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62111, 'Ailsworth', 'Ailsworth', '', 52.5758500, -0.3503200, 'GB', '2016-11-04', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62112, 'Aylburton', 'Aylburton', '', 51.7150600, -2.5531200, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62113, 'Monkton_Farleigh', 'Monkton_Farleigh', '', 51.3881200, -2.2807800, 'GB', '2017-04-27', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62114, 'Bowburn', 'Bowburn', '', 54.7385000, -1.5252100, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62115, 'Walton', 'Walton', '', 53.2228400, -1.4608400, 'GB', '2017-05-19', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62116, 'Great Haywood', 'Great Haywood', '', 52.8078500, -2.0002400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62117, 'Hyde Heath', 'Hyde Heath', '', 51.6933600, -0.6543700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62118, 'Ratby', 'Ratby', '', 52.6498900, -1.2413700, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62119, 'Tal-y-bont', 'Tal-y-bont', '', 52.7747100, -4.0922400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62120, 'Stakeford', 'Stakeford', '', 55.1611000, -1.5752900, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62121, 'Linwood', 'Linwood', '', 55.8483400, -4.4933700, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62122, 'Coven', 'Coven', '', 52.6558700, -2.1353000, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62123, 'Highland', 'Highland', '', 57.4856600, -4.2282300, 'GB', '2017-06-09', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62124, 'Winchburgh', 'Winchburgh', '', 55.9579500, -3.4646400, 'GB', '2017-06-12', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62125, 'Addiebrownhill', 'Addiebrownhill', '', 55.8428900, -3.6166700, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62126, 'Ashgill', 'Ashgill', '', 55.7311900, -3.9301900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62127, 'Balloch', 'Balloch', '', 57.4919400, -4.1171300, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62128, 'Banknock', 'Banknock', '', 55.9896700, -3.9561100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62129, 'Bargeddie', 'Bargeddie', '', 55.8536600, -4.0784600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62130, 'Blantyre', 'Blantyre', '', 55.7963400, -4.0948500, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62131, 'Brightons', 'Brightons', '', 55.9802800, -3.7161300, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62132, 'Head of Muir', 'Head of Muir', '', 56.0062300, -3.9135800, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62133, 'Allanton', 'Allanton', '', 55.7994500, -3.8349200, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62134, 'Calderbank', 'Calderbank', '', 55.8431800, -3.9707000, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62135, 'Blackridge', 'Blackridge', '', 55.8852300, -3.7747900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62136, 'Salsburgh', 'Salsburgh', '', 55.8427700, -3.8726400, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62137, 'Croy', 'Croy', '', 55.9606400, -4.0393200, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62138, 'Drongan', 'Drongan', '', 55.4349800, -4.4555100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62139, 'Cruden Bay', 'Cruden Bay', '', 57.4179700, -1.8531300, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62140, 'Fallin', 'Fallin', '', 56.1047900, -3.8761600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62141, 'Glenmavis', 'Glenmavis', '', 55.8891300, -3.9872600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62142, 'Hallglen', 'Hallglen', '', 55.9857300, -3.7853500, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62143, 'Kingswells', 'Kingswells', '', 57.1579800, -2.2242600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62144, 'Milton of Leys', 'Milton of Leys', '', 57.4512500, -4.1759200, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62145, 'Mossblown', 'Mossblown', '', 55.4894100, -4.5278700, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62146, 'Plains', 'Plains', '', 55.8804400, -3.9234900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62147, 'Ratho Station', 'Ratho Station', '', 55.9367000, -3.3889000, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62148, 'Seafield', 'Seafield', '', 55.8779100, -3.5878100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62149, 'Stoneyburn', 'Stoneyburn', '', 55.8437100, -3.6386200, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62150, 'Twechar', 'Twechar', '', 55.9541500, -4.0821900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62151, 'Waterfoot', 'Waterfoot', '', 55.7693800, -4.2837200, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62152, 'Tullibody', 'Tullibody', '', 56.1336400, -3.8383500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62153, 'Vale of Leven', 'Vale of Leven', '', 55.9713200, -4.5792800, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62154, 'Whitecraig', 'Whitecraig', '', 55.9193700, -3.0423100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62155, 'Dennyloanhead', 'Dennyloanhead', '', 55.9988600, -3.9130600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62156, 'Maryburgh', 'Maryburgh', '', 57.5742000, -4.4417800, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62157, 'East Whitburn', 'East Whitburn', '', 55.8685500, -3.6629500, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62158, 'Faifley', 'Faifley', '', 55.9285300, -4.3850900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62159, 'Laurieston', 'Laurieston', '', 55.9956200, -3.7480100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62160, 'Lenzie', 'Lenzie', '', 55.9276200, -4.1539900, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62161, 'Maddiston', 'Maddiston', '', 55.9736500, -3.6990000, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62162, 'Mayfield', 'Mayfield', '', 55.8717200, -3.0387500, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62163, 'New Stevenston', 'New Stevenston', '', 55.8166900, -3.9735700, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62164, 'Polbeth', 'Polbeth', '', 55.8607200, -3.5490100, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62165, 'Redding', 'Redding', '', 55.9886100, -3.7323000, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62166, 'Reddingmuirhead', 'Reddingmuirhead', '', 55.9802600, -3.7485300, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62167, 'Stenhousemuir', 'Stenhousemuir', '', 56.0267600, -3.8146200, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62168, 'Thornliebank', 'Thornliebank', '', 55.8045400, -4.3174600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62169, 'Viewpark', 'Viewpark', '', 55.8273700, -4.0573000, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62170, 'Westhill', 'Westhill', '', 57.4732300, -4.1489300, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62171, 'Westquarter', 'Westquarter', '', 55.9914200, -3.7401600, 'GB', '2017-06-14', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62172, 'Netherlee', 'Netherlee', '', 55.8015700, -4.2732500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62173, 'Greenhill', 'Greenhill', '', 55.9920400, -3.8909600, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62174, 'Coaltown of Balgonie', 'Coaltown of Balgonie', '', 56.1847400, -3.1257800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62175, 'Maxwellheugh', 'Maxwellheugh', '', 55.5925300, -2.4287100, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62176, 'Torrance', 'Torrance', '', 55.9399500, -4.2102500, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62177, 'Shieldhill', 'Shieldhill', '', 55.9727700, -3.7678800, 'GB', '2017-06-15', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62178, 'Denton Holme', 'Denton Holme', '', 54.8850000, -2.9410000, 'GB', '2017-06-20', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62179, 'Bickleigh', 'Bickleigh', '', 50.8564600, -3.5084200, 'GB', '2017-07-06', 235);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62680, 'Salamína', 'Salamina', 'Koulouri,Koúlouri,Salamina,Salamis,Salamís,Σαλαμίνα,Σαλαμίς,Саламина', 37.9642700, 23.4964900, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62681, 'Royítika', 'Royitika', 'Rogitika,Roitika,Royitika,Royítika,Roḯtika,Ροίτικα,Ρογίτικα', 38.1826800, 21.6841400, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62682, 'Roviés', 'Rovies', 'Roviai,Roviais,Roviaí,Roviaís,Rovies,Roviés,Ροβιές,Ροβιαί', 38.8097100, 23.2307300, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62683, 'Neápolis', 'Neapolis', 'Neapoli,Neapolis,Rousaiika,Rousaíïka,Rouseika,Roussaiika,Roussaíika,Rouséïka,Νεάπολη,Ρουσέϊκα,Ρουσσαίικα', 38.6714400, 21.3627400, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62684, 'Rodotópi', 'Rodotopi', 'Rodhotopi,Rodhotopion,Rodhotovi,Rodhotópi,Rodhotópion,Rodhotóvi,Rodotopi,Rodotopion,Rodotópi,Rodotópion,Ροδοτόπι,Ροδοτόπιον', 39.7082200, 20.7265600, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62685, 'Rododáfni', 'Rododafni', 'Mourla,Mourlá,Rodhodhafni,Rodhodháfni,Rododafni,Μουρλά,Ροδοδάφνη', 38.2697600, 22.0487500, 'GR', '2015-05-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62686, 'Rodhítsa', 'Rodhitsa', 'Rodhista,Rodhitsa,Rodhísta,Rodhítsa,Roditsa,Sarmousakli,Sarmusakli,Sarmusaklí,Ροδίτσα', 38.8882900, 22.4641000, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62687, 'Rizómylos', 'Rizomylos', 'Rizomilos,Rizomylos,Rizómilos,Rizómylos,Ριζόμυλος', 39.4276300, 22.7471700, 'GR', '2015-04-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62688, 'Rízoma', 'Rizoma', 'Rizoma,Rízoma,Sklataina,Sklátaina,Ρίζωμα', 39.6643200, 21.7354100, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62689, 'Río', 'Rio', 'Rhion,Rio,Rion,Río,Ríon,Ρίο,Ρίον', 38.2955800, 21.7850400, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62690, 'Rethymno', 'Rethymno', 'Resmo,Rethimno,Rethimnon,Rethymne,Rethymno,Rethymnon,Rethýmne,Retimnas,Retimno,Retimnon,Retimo,Retino,Rhithymna,Réthimno,Réthimnon,Réthymno,Réthymnon,Rétino,ZRE,letimno,luo xi mu nuo,retimuno,rt''ymnw,rtymnwn,rythymnw,Ρέθυμνο,Ρέθυμνον,Ретимно,Ретимнон,רת''ימנו,رتیمنون,ريثيمنو,レティムノ,罗希姆诺,레팀노', 35.3655500, 24.4823200, 'GR', '2015-11-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62691, 'Rafína', 'Rafina', 'Arafin,Aráfin,Rafina,Rafína,Triglia,Tríglia,Αράφην,Ραφήνα', 38.0181200, 24.0059900, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62692, 'Pteleós', 'Pteleos', 'Ftelio,Ftelió,Pteleon,Pteleos,Pteleón,Pteleós,Πτελεόν,Πτελεός', 39.0526100, 22.9527100, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62693, 'Psychikó', 'Psychiko', 'Psichiko,Psikhiko,Psikhikon,Psikhikó,Psikhikón,Psychico,Psychiko,Psychikó,Psykiko,Ψυχικό', 38.0132400, 23.7722300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62694, 'Psachná', 'Psachna', 'Psachna,Psachná,Psakhna,Psakhná,Ψαχνά', 38.5785200, 23.6432600, 'GR', '2017-03-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62695, 'Prokópi', 'Prokopi', 'Prokopi,Prokopion,Prokópi,Prokópion,Προκόπι,Προκόπιον', 38.7340200, 23.4906000, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62696, 'Profítis Ilías', 'Profitis Ilias', 'Kami Kasteli,Kanli Kastellion,Kanlí Kastéllion,Profitis Ilias,Profítis Ilías,Prophetes Elias,Προφήτης Ηλίας', 35.2055500, 25.0998500, 'GR', '2012-03-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62697, 'Préveza', 'Preveza', 'PVK,Prevesa,Preveza,Preveze,Preweza,Préveza,Prévéza,prwzh,Πρέβεζα,پروزه', 38.9561700, 20.7505000, 'GR', '2017-01-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62698, 'Prámanta', 'Pramanta', 'Pramanda,Pramanta,Prámanda,Prámanta,Πράμαντα', 39.5230600, 21.1013900, 'GR', '2015-02-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62699, 'Pórto Chéli', 'Porto Cheli', 'Kheli,Khéli,PKH,Porto Cheli,Porto Chelion,Porto Heli,Porto-Kheli,Portocheli,Portochelion,Portochéli,Portochélion,Portokhelion,Portokhélion,Pórto Chéli,Pórto Chélion,Pórto-Khéli,Πορτοχέλι,Πορτοχέλιον,Πόρτο Χέλι,Πόρτο Χέλιον', 37.3278600, 23.1438400, 'GR', '2016-12-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62700, 'Portariá', 'Portaria', 'Portaria,Portariá,Πορταριά', 39.3895000, 22.9994800, 'GR', '2015-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62701, 'Póros', 'Poros', 'Poros,Póros,Πόρος', 38.1536900, 20.7712000, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62702, 'Póros', 'Poros', 'Poros,Póros,Πόρος', 37.4994400, 23.4536100, 'GR', '2014-09-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62703, 'Politiká', 'Politika', 'Politika,Politiká,Πολιτικά', 38.5967300, 23.5445700, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62704, 'Polichnítos', 'Polichnitos', 'Polichnitos,Polichnítos,Polikhnitos,Polikhnítos,Πολιχνίτος', 39.0791100, 26.1821500, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62705, 'Polydéndri', 'Polydendri', 'Mazi,Polidhendhri,Polidhendri,Polidhendrion,Polidhéndhri,Polidhéndri,Polidhéndrion,Polydendri,Polydendrion,Polydéndri,Polydéndrion,Μάζι,Πολυδένδρι,Πολυδένδριον', 38.2160000, 23.8680600, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62706, 'Plomári', 'Plomari', 'Plomari,Plomarion,Plomári,Plomárion,Ploumarion,Potamos,Potamós,Πλωμάρι,Πλωμάριον', 38.9752700, 26.3713700, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62707, 'Platýkampos', 'Platykampos', 'Kato Platikambos,Káto Platíkambos,Platikambos,Platykampos,Platíkambos,Platýkampos,Topuslar,Topuslár,Πλατύκαμπος', 39.6166700, 22.5333300, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62708, 'Platariá', 'Plataria', 'Plataria,Platariá,Πλαταριά', 39.4504400, 20.2778100, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62709, 'Plátanos', 'Platanos', 'Platanos,Plátanos,Πλάτανος', 37.6673100, 21.6110800, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62710, 'Pigí', 'Pigi', 'Megali Poliana,Megali Poliána,Megali Pouliana,Megáli Pouliána,Pigi,Pigí,Piyi,Piyí,Poliana Megali,Poliána Megáli,Πηγή', 39.5106100, 21.7010300, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62711, 'Pithári', 'Pithari', 'Pithari,Pitharion,Pithári,Pithárion,Πιθάρι,Πιθάριον', 35.5167200, 24.0865300, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62712, 'Pythagóreio', 'Pythagoreio', 'Pithagorion,Pithagórion,Pythagoreio,Pythagoreion,Pythagoria,Pythagorio,Pythagorion,Pythagóreio,Pythagóreion,Teganion,Tegánion,Tiganian,Tiganion,Tigánian,Tigánion,Πυθαγόρειο', 37.6910200, 26.9434100, 'GR', '2014-08-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62713, 'Pyrgetós', 'Pyrgetos', 'Piryetos,Piryetós,Pyrgetos,Pyrgetós,Πυργετός', 39.9186900, 22.5933900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62714, 'Pyrgetós', 'Pyrgetos', 'Piryetos,Piryetós,Pyrgetos,Pyrgetós,Πυργετός', 39.5527600, 21.7484600, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62715, 'Pýrgos', 'Pyrgos', 'PYR,Pirgos,Pyrgos,Pírgos,Πύργος,Пиргос', 37.6751300, 21.4410200, 'GR', '2017-01-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62716, 'Pýrgos', 'Pyrgos', 'Pirgos,Pyrgos,Pírgos,Pýrgos,Πύργος', 35.0061100, 25.1519100, 'GR', '2013-07-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62717, 'Piraeus', 'Piraeus', 'El Pireo,El Pireu,Gorad Pirehj,Il Pireo,Le Piree,Le Pirée,Lo Pireu,Lo Pirèu,O Pireo,Peiraeus,Peiraia,Peiraias,Peiraiefs,Peiraieus,Peiraievs,Peiraiá,Peiraiás,Peiraiéfs,Piraeus,Piraievs,Piraiévs,Piraus,Pire,Pireas,Pireefs,Pirej,Pireja,Pirejas,Pireo,Pireu,Pireus,Pireusz,Piräus,Piræus,Piréefs,Pirėjas,bi lei ai fu si,byrayws,phiri xas,pileaseu,pireusu,pyrh,Πειραιάς,Πειραιεύς,Горад Пірэй,Пирей,Пирея,Пиреј,Пірей,פיראוס,بيرايوس,پیره,ไพรีอัส,ピレウス,比雷埃夫斯,피레아스', 37.9474500, 23.6370800, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62718, 'Pýlos', 'Pylos', 'Navarino,Neon Kastrov,Néon Kastrov,Pilos,Pylos,Pílos,Πύλος', 36.9129800, 21.6965000, 'GR', '2015-09-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62719, 'Pylí', 'Pyli', 'Pili,Pilion,Pilí,Pilíon,Pyli,Pylion,Pylli,Pylí,Pylíon,Πυλί,Πυλίον', 36.8447200, 27.1593200, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62720, 'Pýli', 'Pyli', 'Pili,Porta Pazar,Porta Pazari,Pyli,Píli,Pórta Pazár,Pórta Pazári,Pýli,Πύλη', 39.4580600, 21.6188900, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62721, 'Pikérmi', 'Pikermi', 'Kato Pikermi,Káto Pikérmi,Passadhes,Passádhes,Pikermi,Pikermion,Pikérmi,Pikérmion,Πικέρμι,Πικέρμιον', 38.0016100, 23.9407500, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62722, 'Petroúpolis', 'Petroupolis', 'Kipoupolis,Kipoúpolis,Petroupoli,Petroupolis,Πετρούπολη,Петроуполис', 38.0418700, 23.6849400, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62723, 'Pétra', 'Petra', 'Petra,Petras,Pétra,Πέτρα', 39.3268200, 26.1764800, 'GR', '2016-12-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62724, 'Péta', 'Peta', 'Peta,Petas,Péta,Pétas,Πέτα', 39.1666700, 21.0347200, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62725, 'Periyiáli', 'Periyiali', 'Perigiali,Perigialion,Periyali,Periyiali,Periyialion,Periyiáli,Periyiálion,Περιγιάλι,Περιγιάλιον', 37.9404100, 22.8394600, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62726, 'Perivóli', 'Perivoli', 'Perivoli,Perivolion,Perivóli,Perivólion,Περιβόλι,Περιβόλιον', 39.4193600, 20.0146900, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62727, 'Perivólia', 'Perivolia', 'Perivolia,Perivólia,Περιβόλια', 35.4849100, 23.9942100, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62728, 'Peristéri', 'Peristeri', 'Peristeri,Peristeri Attikes,Peristerion,Peristéri,Peristérion,Περιστέρι,Περιστέρι Αττικής,Περιστέριον,Перистерион', 38.0153900, 23.6918700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62729, 'Pérdika', 'Perdika', 'Arpitsa,Arpítsa,Perdhika,Perdika,Perdikas,Pérdhika,Pérdika,Pérdikas,Πέρδικα', 39.3696700, 20.3041900, 'GR', '2014-08-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62730, 'Pérama', 'Perama', 'Perama,Pérama,Πέραμα', 39.6933100, 20.8465600, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62731, 'Pérama', 'Perama', 'Perama,Pérama,Πέραμα,Перама', 37.9677500, 23.5721000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62732, 'Pérama', 'Perama', 'Perama,Pérama,Перама', 35.3703000, 24.7034500, 'GR', '2012-03-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62733, 'Perachóra', 'Perachora', 'Perachora,Perachóra,Perakhora,Perakhóra,Περαχώρα', 38.0302100, 22.9490200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62734, 'Pentéli', 'Penteli', 'Pendeli,Pendéli,Penteli,Pentéli,Πεντέλη', 38.0500000, 23.8666700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62735, 'Pelópi', 'Pelopi', 'Krekouki,Krekoúki,Pelopi,Pelopion,Pelópi,Pelópion,Πελόπι,Πελόπιον', 37.6744400, 21.5934400, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62736, 'Pelasgía', 'Pelasgia', 'Gardhiki,Gardhíki,Gardiki,Pelasgia,Pelasgía,Pelasyia,Pelasyía,Γαρδίκι,Πελασγία', 38.9481300, 22.8398000, 'GR', '2015-12-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62737, 'Pediní', 'Pedini', 'Pedhini,Pedhiní,Pedini,Pediní,Πεδινή', 39.5999400, 20.8426100, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62738, 'Gáïos', 'Gaios', 'Gaios,Gáïos,Pakhi,Pakhí,Paxoi,Paxoí,Γάϊος', 39.1972200, 20.1855600, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62739, 'Pátra', 'Patra', 'Patra,Patrae,Patrai,Patras,Patrasse,Patrasso,Patres,Patrás,Pátra,Pátrai,Pátras,pa te lei,patora,ptrs,Πάτρα,Патра,פטרס,パトラ,帕特雷', 38.2444400, 21.7344400, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62740, 'Pátmos', 'Patmos', 'Chora,Khora,Khóra,Patmo,Patmos,Πάτμος,Χώρα,Патмос', 37.3089500, 26.5472300, 'GR', '2014-08-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62741, 'Patitírion', 'Patitirion', 'Patitiri,Patitirion,Patitíri,Patitírion,Πατητήρι,Πατητήριον', 39.1465700, 23.8649400, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62742, 'Pásion', 'Pasion', 'Pasio,Pasion,Paso,Pasó,Pásion,Πάσιο,Πάσιον', 38.0129400, 22.7281400, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62743, 'Páros', 'Paros', 'Paroikia,Paroikía,Paros,Páros,Πάρος', 37.0833300, 25.1500000, 'GR', '2016-11-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62744, 'Párga', 'Parga', 'Barga,Parga,Párga,barghh,parghh,Πάργα,Парга,بارغه,پارغه', 39.2857200, 20.4004400, 'GR', '2014-07-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62745, 'Paravóla', 'Paravola', 'Parabola,Paravola,Paravóla,Παραβόλα', 38.6147200, 21.5204600, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62746, 'Proástio', 'Proastio', 'Paraprastaina,Paraprástaina,Proastio,Proastion,Proástio,Proástion,Προάστιο,Προάστιον', 39.4868200, 21.9028800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62747, 'Parapótamos', 'Parapotamos', 'Parapotamos,Parapótamos,Varfani,Várfani,Παραπόταμος', 39.5485800, 20.3243600, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62748, 'Paramythiá', 'Paramythia', 'Paramithia,Paramithiá,Paramythia,Paramythiá,Paramythía,Παραμυθιά', 39.4711100, 20.5111100, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62749, 'Paralía Avlídhos', 'Paralia Avlidhos', 'Dhramesi,Dhrámesi,Dramesi,Paralia,Paralia Avlidas,Paralia Avlidhos,Paralia Avlidos,Paralía,Paralía Avlídhos,Δράμεσι,Παραλία,Παραλία Αυλίδας,Παραλία Αυλίδος', 38.3800200, 23.6284200, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62750, 'Paralía', 'Paralia', 'Paralia,Paralia Mintilogliou,Paralia Patras,Paralia Patron,Paralía,Παραλία,Παραλία Μιντιλογλίου,Παραλία Πάτρας,Παραλία Πατρών', 38.1983300, 21.7026300, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62751, 'Pappádos', 'Pappados', 'Pappadhos,Pappados,Pappádhos,Pappádos,Παππάδος', 39.0390500, 26.4559800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62752, 'Pappadátes', 'Pappadates', 'Papadatai,Papadhates,Papadhátes,Papadátai,Pappadatai,Pappadates,Pappadhatai,Pappadhátai,Pappadátai,Pappadátes,Παππαδάται,Παππαδάτες', 39.3144400, 20.7931400, 'GR', '2014-07-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62753, 'Pappadhátai', 'Pappadhatai', 'Papadatai,Papadates,Papadhatais,Papadhátais,Pappadatai,Pappadates,Pappadhatai,Pappadhátai,Παπαδάται,Παπαδάτες,Παππαδάται,Παππαδάτες', 38.5281600, 21.4501600, 'GR', '2017-06-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62754, 'Pánormos', 'Panormos', 'Kastelli Milopotamou,Kastélli Milopotámou,Panormo Rethymnis,Panormon,Panormos,Pánormon,Pánormos,Πάνορμο Ρεθύμνης,Πάνορμος', 35.4181500, 24.6909100, 'GR', '2013-10-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62755, 'Panaitólion', 'Panaitolion', 'Moustafouli,Moustafoulion,Moustafoúli,Moustafóulion,Panaitolio,Panaitolion,Panaitólion,Παναιτώλιο,Παναιτώλιον', 38.5831600, 21.4472900, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62756, 'Pámfila', 'Pamfila', 'Pafla,Pamfila,Pamfilla,Pamfylla,Páfla,Pámfila,Pámfilla,Pámfylla,Πάμφιλα', 39.1569700, 26.5217000, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62757, 'Pallíni', 'Pallini', 'Ano Kharvati,Pallini,Pallíni,Áno Kharváti,Παλλήνη', 38.0051400, 23.8830200, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62758, 'Palamás', 'Palamas', 'Palamas,Palamás,Παλαμάς', 39.4666700, 22.0833300, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62759, 'Pálairos', 'Palairos', 'Palairos,Pálairos,Zavedha,Zavédha,Πάλαιρος', 38.7830000, 20.8818300, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62760, 'Palaiópyrgos', 'Palaiopyrgos', 'Palaiopirgos,Palaiopyrgos,Palaiópirgos,Palaiópyrgos,Paliopirgos,Paliópirgos,Zavlania,Zavlánia,Παλαιόπυργος', 39.6084500, 21.8172000, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62761, 'Palaió Fáliro', 'Palaio Faliro', 'Alt Phaleron,Old Faliron,Palaio Faliro,Palaion Faliron,Palaió Fáliro,Palaión Fáliron,Paleo Faliro,Palio Faliro,Παλαιό Φάληρο,Παλαιόν Φάληρον,Παλιό Φάληρο', 37.9281200, 23.7010500, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62762, 'Palaiomonástiro', 'Palaiomonastiro', 'Beletsi,Belétsi,Palaiomonastiro,Palaiomonastiron,Palaiomonástiro,Palaiomonástiron,Paliomonastiri,Paliomonastirion,Paliomonastíri,Paliomonastírion,Παλαιομονάστηρο,Παλαιομονάστηρον', 39.4626900, 21.6579300, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62763, 'Palaiókipos', 'Palaiokipos', 'Palaiokipos,Palaiókipos,Παλαιόκηπος', 39.0556300, 26.4505300, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62764, 'Palaióchora', 'Palaiochora', 'Palaiochora,Palaiokhora,Palaiokhóra,Palaióchora,Paleochora,Selino Kasteli,Selino Kastelli,Sélino Kastélli,Παλαιόχωρα', 35.2312800, 23.6818500, 'GR', '2015-09-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62765, 'Palekastro', 'Palekastro', 'Palaikastro,Palaikastron,Palaiokastro,Palaiokastron,Palaiókastro,Palaiókastron,Palaíkastro,Palaíkastron,Palekastro,Palékastro,Παλαίκαστρο,Παλαίκαστρον,Παλαιόκαστρον', 35.1979300, 26.2542900, 'GR', '2013-11-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62766, 'Psará', 'Psara', 'Palaia Psara,Palaiá Psará,Psara,Psará,Ψαρά,Псара', 38.5409700, 25.5628700, 'GR', '2014-08-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62767, 'Palaiá Fókaia', 'Palaia Fokaia', 'Fokaia,Fókaia,Palaia Fokaia,Palaiá Fókaia,Παλαιά Φώκαια,Φώκαια', 37.7199800, 23.9479200, 'GR', '2014-09-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62768, 'Palaiá Epídavros', 'Palaia Epidavros', 'Epidavros,Epídavros,Palaia Epidavros,Palaia Epidhavros,Palaiá Epídavros,Palaiá Epídhavros,Παλαιά Επίδαυρος', 37.6384700, 23.1560900, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62769, 'Paianía', 'Paiania', 'Liopesi,Liópesi,Paiania,Paianía,Παιανία', 37.9552700, 23.8544300, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62770, 'Oxílithos', 'Oxilithos', 'Oxilithos,Oxylithos,Oxílithos,Οξύλιθος', 38.5798800, 24.1118400, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62771, 'Ovriá', 'Ovria', 'Obria,Obrya,Ovria,Ovriá,Οβριά,Οβρυά', 38.1886600, 21.7290300, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62772, 'Oropós', 'Oropos', 'Oropos,Oropus,Oropós,Ωρωπός', 38.3032600, 23.7554900, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62773, 'Orchomenós', 'Orchomenos', 'Adamas,Adhamas,Adhámas,Adámas,Athamas,Athámas,Orchomene,Orchomenos,Orchomenus,Orchomenós,Orchomène,Orcomeno,Orcómeno,Orkhomen,Orkhomenos,Orkhomenós,Skripou,Skripoú,Αδάμας,Ορχομενός,Орхомен', 38.4929000, 22.9796200, 'GR', '2012-11-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62774, 'Oreoí', 'Oreoi', 'Oreoi,Oreoí,Ωρεοί', 38.9503400, 23.0919100, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62775, 'Omvriakí', 'Omvriaki', 'Ombriake,Omvriaki,Omvriakí,Ομβριακή', 39.1011800, 22.2710600, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62776, 'Oinoússes', 'Oinousses', 'Chorio Oinoussai,Chorió Oinoússai,Egnousa,Eγνούσα,Inousses,Inoússes,Inuses,Inusses,Mandraki,Mandráki,Oinousa,Oinousai,Oinoussai,Oinousses,Oinoúsai,Oinoússai,Oinoússes,Οινούσσαι,Οινούσσες,Инусес,Инуссес', 38.5145800, 26.2224100, 'GR', '2014-08-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62777, 'Oinófyta', 'Oinofyta', 'Oinofita,Oinofyta,Oinophyta,Oinófita,Oinófyta,Staniates,Staniátes,Οινόφυτα', 38.3116300, 23.6400000, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62778, 'Papágou', 'Papagou', 'Oikismos Papagou,Oikismós Papágou,Papagos,Papagou,Papágos,Papágou,Οικισμός Παπάγου,Παπάγου', 37.9864200, 23.7934700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62779, 'Oía', 'Oia', 'Apano Meria,Epano Meria,Epáno Meriá,Ia,Ija,Oia,Oía,Οία,Ия', 36.4626000, 25.3763700, 'GR', '2016-12-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62780, 'Níkaia', 'Nikaia', 'Nebegler,Nebeglér,Nikaia,Níkaia,Νίκαια', 39.5666700, 22.4666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62781, 'Níkaia', 'Nikaia', 'Nea Kokkinia,Neokokinis,Nikaia,Nikea,Néa Kokkiniá,Níkaia,Νέα Κοκκινιά,Νίκαια', 37.9666700, 23.6500000, 'GR', '2014-05-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62782, 'Nerokoúros', 'Nerokouros', 'Nerokouros,Nerokourou,Nerokoúros,Nerokoúrou,Νεροκούρος,Νεροκούρου', 35.4758700, 24.0399500, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62783, 'Néon Monastírion', 'Neon Monastirion', 'Neo Monastiri,Neo Monastirio,Neon Monastirion,Néon Monastírion,Tsomba,Tsómba,Νέο Μοναστήρι,Νέο Μοναστήριο,Νέον Μοναστήριον', 39.2398800, 22.2746500, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62784, 'Néon Karlovásion', 'Neon Karlovasion', 'Karlovasi,Karlovassi,Neon Karlovasi,Neon Karlovasion,Néon Karlovásion,Néon Karlóvasi,Καρλόβασι,Νέον Καρλοβάσιον', 37.7920900, 26.7049000, 'GR', '2016-12-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62785, 'Neochorópoulo', 'Neochoropoulo', 'Neochoropoulo,Neochoropoulon,Neochorópoulo,Neochorópoulon,Neokhori,Neokhoropoulon,Neokhorópoulon,Neokhóri,Νεοχωρόπουλο,Νεοχωρόπουλον', 39.6255300, 20.8355800, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62786, 'Oichalía', 'Oichalia', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhori,Neokhorion,Neokhórion,Niokhori,Niokhóri,Oichalia,Oichalía,Οιχαλία', 39.6082700, 21.9799600, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62787, 'Neochóri', 'Neochori', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhori,Neokhorion,Neokhóri,Neokhórion,Νεοχώρι,Νεοχώριον', 39.0702500, 21.0189200, 'GR', '2014-09-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62788, 'Neochórion', 'Neochorion', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhori,Neokhorion,Neokhóri,Neokhórion,Νεοχώρι', 38.4084700, 21.2751100, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62789, 'Neochóri', 'Neochori', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhori,Neokhorion,Neokhóri,Neokhórion,Νεοχώρι,Νεοχώριον', 37.9079400, 21.2039200, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62790, 'Neméa', 'Nemea', 'Agios Georgios,Ayios Yeoryios,Nemea,Nemia,Neméa,Áyios Yeóryios,Άγιος Γεώργιος,Νεμέα,Νεμηα', 37.8206800, 22.6610200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62791, 'Néa Tírins', 'Nea Tirins', 'Kofini,Kofinion,Kofíni,Kofínion,Nea Tirins,Nea Tiryns,Nea Tiryntha,Néa Tírins,Νέα Τίρυνθα,Νέα Τίρυνς', 37.6079300, 22.8199600, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62792, 'Néa Stíra', 'Nea Stira', 'Nea Stira,Nea Styra,Néa Stíra,Νέα Στύρα', 38.1793500, 24.2084200, 'GR', '2015-09-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62793, 'Néa Smýrni', 'Nea Smyrni', 'Nea Smirni,Nea Smyrne,Nea Smyrni,Néa Smírni,Néa Smýrni,Νέα Σμύρνη', 37.9450400, 23.7141600, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62794, 'Néa Seléfkeia', 'Nea Selefkeia', 'Nea Selefkeia,Nea Selevkia,Néa Seléfkeia,Néa Selévkia,Νέα Σελεύκεια', 39.5246100, 20.2551900, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62795, 'Neápoli', 'Neapoli', 'Neapoli,Neapolis,Neápoli,Neápolis,Νεάπολη,Νεάπολις', 35.2562700, 25.6041500, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62796, 'Néa Péramos', 'Nea Peramos', 'Megalo Pefko,Megalo Pevko,Megálo Péfko,Megálo Pévko,Nea Peramos,Néa Péramos,Μεγάλο Πεύκο,Νέα Πέραμος', 38.0064700, 23.4234800, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62797, 'Néa Palátia', 'Nea Palatia', 'Nea Palatia,Néa Palátia,Νέα Παλάτια', 38.3194200, 23.7964900, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62798, 'Néa Manoláda', 'Nea Manolada', 'Nea Manolada,Nea Manolas,Néa Manoláda,Néa Manolás,Νέα Μανολάδα,Νέα Μανολάς', 38.0537800, 21.3818900, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62799, 'Néa Mákri', 'Nea Makri', 'Ayios Konstandinos,Nea Makre,Nea Makri,Néa Mákri,Áyios Konstandínos,Νέα Μάκρη', 38.0873300, 23.9764200, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62800, 'Ílion', 'Ilion', 'Ilion,Kato Liosia,Káto Liósia,Nea Liosia,Néa Liósia,Ílion,Ίλιον,Νέα Λιόσια', 38.0333300, 23.7000000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62801, 'Néa Lámpsakos', 'Nea Lampsakos', 'Nea Lampsakos,Νέα Λάμψακος', 38.4372900, 23.6282400, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62802, 'Néa Kíos', 'Nea Kios', 'Nea Kios,Néa Kíos,Νέα Κίος', 37.5902300, 22.7434200, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62803, 'Néa Ionía', 'Nea Ionia', 'Nea Ionia,Néa Ionía,Podharadhes,Podharádhes,Νέα Ιωνία', 38.0357000, 23.7573300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62804, 'Néa Filadélfeia', 'Nea Filadelfeia', 'Filadelfia,Nea Filadelfeia,Nea Filadhelfia,Néa Filadhélfia,Néa Filadélfeia,Podhoniftis,Podhoníftis,Νέα Φιλαδέλφεια', 38.0349100, 23.7381100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62805, 'Néa Erythraía', 'Nea Erythraia', 'Nea Erithraia,Nea Erythraia,Néa Erithraía,Néa Erythraía,Νέα Ερυθραία', 38.0927000, 23.8222300, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62806, 'Néa Artáki', 'Nea Artaki', 'Nea Artaki,Néa Artáki,Νέα Αρτάκη', 38.5202700, 23.6329600, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62807, 'Néa Anchiálos', 'Nea Anchialos', 'Nea Anchialos,Nea Ankhialos,Néa Anchiálos,Néa Ankhíalos,Νέα Αγχίαλος,Νέα Αγχιάλος', 39.2801500, 22.8181900, 'GR', '2015-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62808, 'Náxos', 'Naxos', 'Chora,Chora Naxou,JNX,Naxia,Naxos,Naxos City,Náxia,Náxos,Νάξος,Χώρα,Χώρα Νάξου', 37.1055600, 25.3763900, 'GR', '2016-01-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62809, 'Náfplio', 'Nafplio', 'Anabolu,Mora Yenisehri,Mora Yenişehri,Nafplio,Nafplion,Napoli di Romania,Nauplia,Nauplie,Nauplion,Navplio,Navplion,Náfplio,Náfplion,Návplio,Návplion,anabwly,nafupurio,Ναύπλιο,Ναύπλιον,Нафплион,انابولی,ナフプリオ', 37.5686300, 22.8069100, 'GR', '2016-05-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62810, 'Náfpaktos', 'Nafpaktos', 'Epakhtos,Inebahti,Inebahtı,Lepanto,Nafpaktos,Naupacte,Naupactus,Naupaetus,Navpakt,Navpaktos,Náfpaktos,Návpaktos,aynh bhty,Ναύπακτος,Навпакт,اینه بحتی', 38.3916700, 21.8275000, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62811, 'Náousa', 'Naousa', 'Naousa,Nausa,Náousa,Νάουσα', 37.1218100, 25.2401400, 'GR', '2016-12-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62812, 'Mouzourás', 'Mouzouras', 'Mouzouras,Mouzourás,Muzuras,Μουζουράς', 35.5388500, 24.1555400, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62813, 'Mouzáki', 'Mouzaki', 'Mouzaki,Mouzakion,Mouzáki,Mouzákion,Μουζάκι,Μουζάκιον', 39.4297200, 21.6636100, 'GR', '2014-08-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62814, 'Mouzaki', 'Mouzaki', 'Mouzaki,Mouzáki,Μουζάκι', 37.7356500, 20.8229100, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62815, 'Mourniés', 'Mournies', 'Mourniai,Mourniaí,Mournies,Mournion,Mourniés,Mournión,Μουρνιές,Μουρνιαί', 35.4822800, 24.0125300, 'GR', '2012-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62816, 'Moúlki', 'Moulki', 'Moulki,Moulkio,Moulkion,Moúlki,Moúlkion,Μούλκι,Μούλκιο,Μούλκιον', 37.9931900, 22.7253100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62817, 'Moskháton', 'Moskhaton', 'Moschato,Moschaton,Moscháto,Moscháton,Μοσχάτο,Μοσχάτον', 37.9478900, 23.6788000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62818, 'Mória', 'Moria', 'Morea,Moria,Mória,Μόρια', 39.1324800, 26.5169800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62819, 'Morfovoúni', 'Morfovouni', 'Morfovouni,Morfovounion,Morfovoúni,Morfovoúnion,Vounesi,Vounési,Βουνέσι,Μορφοβούνι,Μορφοβούνιον', 39.3525000, 21.7500000, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62820, 'Monastiráki', 'Monastiraki', 'Monastiraki,Monastirakion,Monastiráki,Monastirákion,Μοναστηράκι,Μοναστηράκιον', 38.8505300, 20.9445800, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62821, 'Mólos', 'Molos', 'Molos,Mólos,Μώλος', 38.8099800, 22.6454400, 'GR', '2014-10-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62822, 'Moláoi', 'Molaoi', 'Mola,Molaoi,Moláoi,Μολάοι', 36.8075700, 22.8513200, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62823, 'Mokhós', 'Mokhos', 'Mochos,Mokho,Mokhos,Mokhós,Μοχός', 35.2634200, 25.4230500, 'GR', '2012-03-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62824, 'Moíres', 'Moires', 'Mires,Moirai,Moirais,Moires,Moírai,Moírais,Moíres,Míres,Μοίραι,Μοίρες', 35.0514300, 24.8733000, 'GR', '2015-11-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62825, 'Mitrópoli', 'Mitropoli', 'Mitropoli,Mitropolis,Mitrópoli,Mitrópolis,Paliokastron,Paliókastron,Μητρόπολη,Μητρόπολις', 39.3393300, 21.8375100, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62826, 'Mytilinioí', 'Mytilinioi', 'Mitilinioi,Mitilinioí,Mitilinoi,Mitilinoí,Mytilenioi,Mytilinioi,Mytilinioí,Μυτιληνιοί', 37.7271600, 26.9074700, 'GR', '2014-08-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62827, 'Mytilene', 'Mytilene', 'Kastro,MJT,Metilene,Midilli,Mitilena,Mitilene,Mitileno,Mitilini,Mitilíni,Mitilėnė,Mitylena,Mitylene,Mytilena,Mytilene,Mytilini,Mytilène,Mytiléna,Mytilíni,mi di li ni,mitillene,mitirini,mwtylnh,mytylnh,Μυτιλήνη,Митилена,Митилини,Мітіліні,מיטילנה,موتیلنه,ሚጢሊኒ,ミティリーニ,米蒂利尼,미틸레네', 39.1077200, 26.5552900, 'GR', '2016-12-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62828, 'Mytikas', 'Mytikas', 'Mitikas,Mytikas,Mítikas,Μύτικας', 38.4437300, 23.6536500, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62829, 'Míthymna', 'Mithymna', 'Methymna,Mithimna,Molivdhos,Molivo,Molivos,Molova,Molyvos,Míthimna,Mólivdhos,Mólivos,mwlwh,Μήθυμνα,مولوه', 39.3678100, 26.1763900, 'GR', '2016-12-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62830, 'Myrsíni', 'Myrsini', 'Mirsini,Mirsíni,Myrsini,Myrsíni,Souleimanaga,Souleïmánaga,Suleimanaga,Suleïmánaga,Μυρσίνη', 37.9211700, 21.2370000, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62831, 'Mýrina', 'Myrina', 'Kastro,Kastron,Kástron,Mirina,Myrina,Mírina,Mýrina,Μύρινα', 39.8748300, 25.0635900, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62832, 'Mindilóglion', 'Mindiloglion', 'Midilogli,Mindilogli,Mindiloglion,Mindilógli,Mindilóglion,Mintilogli,Mintilógli,Μιντιλόγλι', 38.1838700, 21.7013300, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62833, 'Mílos', 'Milos', 'MLO,Melos,Milo,Milos,Mílos,mlws,Μήλος,Милос,Мілос,מלוס', 36.7453600, 24.4265000, 'GR', '2015-05-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62834, 'Mykonos', 'Mykonos', 'Chora,JMK,Kamenaki,Khora,Khóra,Mikonos,Myconos,Mykoni,Mykonos,Mykonos Town,Míkonos,Μύκονος,Χωρα,Χώρα', 37.4452900, 25.3287200, 'GR', '2016-01-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62835, 'Megísti', 'Megisti', 'Castelrosso,KZS,Kastellorizon,Kastellórizon,Kastelorizo,Megisti,Megísti,Meyisti,Meyísti,Μεγίστη', 36.1488900, 29.5936100, 'GR', '2017-01-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62836, 'Metsovo', 'Metsovo', 'Aminciu,Mecovo,Mecovon,Metsovo,Metsovon,Metsowo,Metzovo,Mezzovo,Métsovo,mytswfw,Μέτζοβο,Μέτσοβο,Μέτσοβον,Ме́цово,Мецово,Мецовон,ميتسوفو', 39.7694400, 21.1822200, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62837, 'Methóni', 'Methoni', 'Methone,Modo,Modó,Μεθώνη', 36.8197300, 21.7048600, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62838, 'Messíni', 'Messini', 'Messeni,Messini,Messíni,Nisi,Nision,Nisíon,Μεσσήνη', 37.0511100, 22.0077800, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62839, 'Mesolóngi', 'Mesolongi', 'Mesolonghi,Mesolongi,Mesolongion,Mesolónghi,Mesolóngi,Mesolóngion,Messolonghi,Messolongi,Messolóngi,Missolonghi,Μεσολόγγι,Μεσολόγγιον', 38.3713800, 21.4315100, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62840, 'Mesariá', 'Mesaria', 'Mesaria,Mesariá,Messaria,Messariá,Μεσαριά', 36.3989300, 25.4480700, 'GR', '2016-12-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62841, 'Agía Triáda', 'Agia Triada', 'Agia Triada,Agia Trias,Agía Triáda,Agía Triás,Merichovon,Merikhovon,Meríchovon,Meríkhovon,Mirikhovon,Miríkhovon,Αγία Τριάδα,Αγία Τριάς', 39.4636100, 21.8984800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62842, 'Menídi', 'Menidi', 'Menidhi,Menidhion,Menidi,Menidion,Menídhion,Menídi,Menídion,Μενίδι,Μενίδιον', 39.0421300, 21.1187500, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62843, 'Melíssia', 'Melissia', 'Melissia,Melissija,Melíssia,Μελίσσια,Мелиссия', 38.0500000, 23.8333300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62844, 'Meligalás', 'Meligalas', 'Meligala,Meligalas,Meligalá,Meligalás,Μελιγαλάς', 37.2166700, 21.9666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62845, 'Mégara', 'Megara', 'Megara,Megare,Mégara,Mégare,megala,Μέγαρα,Мегара,메가라', 37.9947100, 23.3432400, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62846, 'Megalópoli', 'Megalopoli', 'Megalopole,Megalopoli,Megalopolis,Megalópoli,Megalópolis,mglwpwlys,Μεγαλόπολη,מגלופוליס', 37.4011100, 22.1422200, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62847, 'Megálo Chorió', 'Megalo Chorio', 'Megalo Chorio,Megalo Chorion,Megalo Khorio,Megalocorio,Megalon Chorion,Megalon Khorion,Megálo Chorió,Megálo Chorión,Megálo Khorió,Megálon Choríon,Megálon Khoríon,Μεγάλο Χωριό', 36.4491700, 27.3483300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62848, 'Megalochóri', 'Megalochori', 'Boukhounitsa,Boukhounítsa,Megalo Khorio,Megalochori,Megalochorion,Megalochóri,Megalochórion,Megalokhorion,Megalokhórion,Megálo Khorió,Μεγαλοχώρι,Μεγαλοχώριον', 39.5598200, 21.8419500, 'GR', '2015-11-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62849, 'Megáli Khóra', 'Megali Khora', 'Megale Chora,Megali Chora,Megali Khora,Megáli Khóra,Zapandi,Zapandion,Zapándi,Zapándion,Μεγάλη Χώρα', 38.6462900, 21.3730900, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62850, 'Megála Kalývia', 'Megala Kalyvia', 'Megala Kalivia,Megala Kalyvia,Megála Kalívia,Megála Kalývia,Μεγάλα Καλύβια', 39.4969300, 21.7880200, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62851, 'Mavrommáti', 'Mavrommati', 'Mavromati,Mavrommati,Mavrommation,Mavrommáti,Mavrommátion,Mavromáti,Μαυρομμάτι,Μαυρομμάτιον', 39.4238600, 21.6937900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62852, 'Mataránga', 'Mataranga', 'Mataragka,Mataranka,Ματαράγκα', 38.5235900, 21.4732500, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62853, 'Martínon', 'Martinon', 'Martino,Martinon,Martínon,Μαρτίνο,Μαρτίνον', 38.5681700, 23.2145800, 'GR', '2014-09-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62854, 'Marmárion', 'Marmarion', 'Marmari,Marmarion,Marmári,Μαρμάρι,Μαρμάριον', 38.0483900, 24.3203900, 'GR', '2013-11-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62855, 'Markópoulo Oropoú', 'Markopoulo Oropou', 'Markopoulo Oropou,Markopoulon,Markopoulon Oropion,Markopoulon Oropou,Markópoulo Oropoú,Markópoulon,Markópoulon Oropoú,Markópoulon Óropion,Μαρκόπουλο Ωρωπού', 38.2898000, 23.8247500, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62856, 'Markópoulo', 'Markopoulo', 'Markopoulo,Markopoulo Mesogaias,Markopoulon,Markopulo,Markópoulo,Markópoulon,Mavrovouni,Mavrovoúni,Μαρκόπουλο Μεσογαίας,Μαρκόπουλον', 37.8833300, 23.9333300, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62857, 'Marathónas', 'Marathonas', 'Marafon,Marathon,Marathona,Marathonas,Marathón,Marathóna,Marathónas,Marato,Maraton,Maratona,Marató,Maratón,ma la song,maraton,Μαραθών,Μαραθώνας,Маратон,Марафон,マラトン,马拉松', 38.1531700, 23.9627800, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62858, 'Marathókampos', 'Marathokampos', 'Marathocampos,Marathokambos,Marathokambou,Marathokampos,Marathokámbou,Marathókambos,Marathókampos,Μαραθόκαμπος', 37.7267400, 26.6896400, 'GR', '2016-10-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62859, 'Manoláda', 'Manolada', 'Manolada,Manolas,Manoláda,Manolás,Μανολάδα,Μανολάς', 38.0470800, 21.3481400, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62860, 'Mandráki', 'Mandraki', 'Mandracchio,Mandrakhi,Mandraki,Mandrakion,Mandrákhi,Mandráki,Mandrákion,Μανδράκι,Мандраки', 36.6113900, 27.1333300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62861, 'Mándra', 'Mandra', 'Mandhra,Mandra,Mándhra,Mándra,Μάνδρα', 38.0666700, 23.5000000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62862, 'Mantoúdi', 'Mantoudi', 'Mandoudhion,Mandoúdhion,Mantoudi,Mantoudion,Mantoúdi,Mantoúdion,Mantudi,Μαντούδι,Μαντούδιον', 38.7980800, 23.4796700, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62863, 'Mantamádos', 'Mantamados', 'Mandamadhos,Mandamado,Mandamados,Mandamádhos,Mandamádos,Mandhamadhos,Mandhamádhos,Mantamados,Mantamádos,Μανταμάδος', 39.3100300, 26.3362900, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62864, 'Mália', 'Malia', 'Malia,Malija,Mália,Μάλια,Малия', 35.2836700, 25.4626200, 'GR', '2015-09-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62865, 'Malesína', 'Malesina', 'Malesina,Malesína,Μαλεσίνα', 38.6222500, 23.2337000, 'GR', '2014-09-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62866, 'Malakónta', 'Malakonta', 'Malakonta,Μαλακώντα', 38.4000000, 23.7666700, 'GR', '2015-01-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62867, 'Makrísia', 'Makrisia', 'Makrisia,Makrísia,Μακρίσια', 37.6095700, 21.6050900, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62868, 'Makrychóri', 'Makrychori', 'Makrikhori,Makrikhorion,Makrikhóri,Makrikhórion,Makrychori,Makrychorion,Makrychóri,Μακρυχώρι,Μακρυχώριον', 39.8000000, 22.4833300, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62869, 'Makrychóri', 'Makrychori', 'Makrikhori,Makrikhorion,Makrikhóri,Makrikhórion,Makrychori,Makrychorion,Makrychóri,Makrychórion,Μακρυχώρι,Μακρυχώριον', 39.4397800, 21.9658200, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62870, 'Makrakómi', 'Makrakomi', 'Makrakomi,Makrakómi,Varibopi,Varibópi,Varympopi,Βαρυμπόπη,Μακρακώμη', 38.9415000, 22.1153500, 'GR', '2014-10-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62871, 'Magoúla', 'Magoula', 'Magoula,Magoúla,Μαγούλα', 38.4117800, 23.8212800, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62872, 'Magoúla', 'Magoula', 'Magoula,Magoúla,Μαγούλα', 38.0798900, 23.5210800, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62873, 'Magoúla', 'Magoula', 'Magoula,Magoúla,Μαγούλα', 37.0800700, 22.4046900, 'GR', '2014-04-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62874, 'Artémida', 'Artemida', 'Artemi,Artemida,Artemis,Artémida,Loutsa,Loútsa,Ártemis,Άρτεμη,Άρτεμις,Αρτέμιδα,Λούτσα', 37.9672700, 23.9968400, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62875, 'Loutráki', 'Loutraki', 'LOUTRAKI,Loutraki,Loutrakion,Loutráki,Loutrákion,Lutraki,ΛΟΥΤΡΑΚΙ,Λουτράκι,Λουτράκιον', 37.9783000, 22.9778100, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62876, 'Loutrá Aidhipsoú', 'Loutra Aidhipsou', 'Loutra Aidipsou,Λουτρά Αιδηψού', 38.8569500, 23.0473900, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62877, 'Loutrá', 'Loutra', 'Loutra,Loutrá,Λουτρά', 39.0569500, 26.5447600, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62878, 'Loúros', 'Louros', 'Louron,Louros,Loúron,Loúros,Λούρος', 39.1660000, 20.7560800, 'GR', '2014-07-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62879, 'Loukísia', 'Loukisia', 'Loukisia,Loukísia,Λουκίσια', 38.4794600, 23.4479600, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62880, 'Lixoúri', 'Lixouri', 'Lixouri,Lixourion,Lixoúri,Lixoúrion,Lixuri,Ληξούρι,Ληξούριον', 38.2013300, 20.4370600, 'GR', '2015-06-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62881, 'Livanátes', 'Livanates', 'Livanataes,Livanatai,Livanatais,Livanates,Livanátai,Livanátais,Livanátes,Λιβανάται,Λιβανάτες', 38.7110000, 23.0503000, 'GR', '2014-09-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62882, 'Lithakiá', 'Lithakia', 'Lithakia,Lithakiá,Λιθακιά', 37.7193500, 20.8301300, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62883, 'Leipsoí', 'Leipsoi', 'Leigoi,Leipsoi,Leipsoí,Lipso,Lipsoi,Lipsos,Lipsoí,Lipsó,Lipsós,Λειψοί', 37.2833300, 26.7666700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62884, 'Limnokhórion', 'Limnokhorion', 'Limnochori,Limnokhori,Limnokhorion,Limnokhóri,Limnokhórion,Stringleika,Stringléïka,Λιμνοχώρι', 38.1411500, 21.4804700, 'GR', '2013-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62885, 'Límni', 'Limni', 'Aegae,Limne,Limni,Límni,Λίμνη', 38.7666700, 23.3166700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62886, 'Limín Mesoyaías', 'Limin Mesoyaias', 'Limin Markopoulou,Limin Mesogaias,Limin Mesoyaias,Limín Mesoyaías,Porto Rafti,Pórto Ráfti,Schneiderhafen,Λιμήν Μαρκοπούλου,Λιμήν Μεσογαίας,Πόρτο Ράφτη', 37.8910800, 24.0030700, 'GR', '2014-09-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62887, 'Limín Khersonísou', 'Limin Khersonisou', 'Limenas Chersonisou,Limenas Hersonissou,Limin Chersonisou,Λιμένας Χερσονήσου,Λιμήν Χερσονήσου', 35.3229700, 25.3927500, 'GR', '2015-09-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62888, 'Lykóvrysi', 'Lykovrysi', 'Likovrisi,Likóvrisi,Lycovrissi,Lykobryse,Lykovrisi,Lykovrysi,Lykóvrysi,Λυκόβρυση', 38.0693300, 23.7822300, 'GR', '2016-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62889, 'Ligourión', 'Ligourion', 'Ligourion,Ligourión,Liguri,Lygourio,Λυγουριό', 37.6123300, 23.0377300, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62890, 'Lidoríki', 'Lidoriki', 'Lidhorikion,Lidhoríkion,Lidoriki,Lidorikion,Lidoríki,Lidoríkion,Λιδορίκιον,Λιδωρίκι', 38.5238900, 22.1997200, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62891, 'Lianokládhion', 'Lianokladhion', 'Leianokladi,Λειανοκλάδι', 38.9165500, 22.3033600, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62892, 'Lefkímmi', 'Lefkimmi', 'Agioi Theodoroi,Ayios Theodhoros,Lefkimmi,Lefkímmi,Levkimmi,Levkímmi,Ágioi Theódoroi,Áyios Theódhoros,Λευκίμμη', 39.4233600, 20.0709400, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62893, 'Lefkáda', 'Lefkada', 'Lefkada,Lefkados,Lefkas,Lefkáda,Lefkádos,Lefkás,Leukas,Levkadha,Levkas,Levkádha,Levkás,lai fu ka zha,lepeukada,Λευκάδα,Λευκάς,Лефкада,Лефкас,莱夫卡扎,레프카다', 38.8303600, 20.7044200, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62894, 'Levídion', 'Levidion', 'Levidhi,Levidhion,Levidi,Levídhi,Levídhion,Λεβίδι', 37.6826900, 22.2958600, 'GR', '2015-11-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62895, 'Livadeiá', 'Livadeia', 'Leivadia,Levadeia,Levadhia,Levadia,Levadija,Levàdia,Levádeia,Levádhia,Livadeia,Livadeiá,Livadia,Livadija,Livadiá,lai wa gu,libadia,lyfadhya,rivu~adia,ywadya,Λεβάδεια,Λειβαδιά,Λιβαδειά,Левадия,Ливадия,Лівадія,ليفاذيا,یوادیا,リヴァディア,莱瓦贾,리바디아', 38.4361600, 22.8766500, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62896, 'Lepenoú', 'Lepenou', 'Lepenou,Lepenoú,Λεπενού', 38.7083900, 21.2897000, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62897, 'Leonídio', 'Leonidio', 'Isonidhion,Isonidion,Isonídhion,Isonídion,Leonidhion,Leonidi,Leonidio,Leonidion,Leonídhion,Leonídi,Leonídio,Leonídion,Λεωνίδιο,Λεωνίδιον', 37.1667900, 22.8577300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62898, 'Leondárion', 'Leondarion', 'Kambas,Kambás,Kanca,Kandza,Kantza,Ktima Kantza,Kándza,Kántza,Leondarion,Leondárion,Leontario,Leontarion,Liontari,Liotari,Κάντζα,Κτήμα Κάντζα,Λεοντάριο,Λεοντάριον,Λιοντάρι,Канца,Лиота́ри', 37.9870000, 23.8551800, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62899, 'Lékhaio', 'Lekhaio', 'Kolombotsi,Kolombótsi,Lechaio,Lechaion,Lekhaion,Lékhaion,Λέχαιο,Λέχαιον', 37.9327900, 22.8500200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62900, 'Lechainá', 'Lechaina', 'Lechaina,Lechainá,Lekhaena,Lekhaina,Lekhainá,Λεχαινά', 37.9333300, 21.2666700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62901, 'Lávrio', 'Lavrio', 'Ergasteria,Ergastiria,Ergastíria,Laurium,Lavrio,Lavrion,Lavrium,Lávrio,Lávrion,Λαύριο,Λαύριον,Лаврион', 37.7144500, 24.0564700, 'GR', '2017-05-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62902, 'Lárisa', 'Larisa', 'Larisa,Larissa,Lárisa,Lárissa,Yenisehir,Yenişehir,Λάρισα,Лариса', 39.6368900, 22.4176100, 'GR', '2015-10-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62903, 'Lápas', 'Lapas', 'Lapas,Lappa,Lápas,Láppa,Λάπας', 38.0975500, 21.4186100, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62904, 'Langádhia', 'Langadhia', 'Lagkadia,Langadhia,Langadia,Langádhia,Lankadia,Λαγκάδια', 37.6818600, 22.0300200, 'GR', '2013-11-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62905, 'Lamía', 'Lamia', 'Izdin,Lamia,Lamija,Lamía,lmyaʾ,Λαμία,Ламия,لمياء', 38.9000000, 22.4333300, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62906, 'Lálas', 'Lalas', 'Lala,Lalas,Lála,Lálas,Λάλας', 37.7093600, 21.7211700, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62907, 'Lakkí', 'Lakki', 'Lakki,Lakkion,Lakkí,Lakkíon,Port Laki,Portolago,Temania,Λακκί,Λακκίον', 37.1334400, 26.8523700, 'GR', '2016-10-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62908, 'Krousón', 'Krouson', 'Krouson,Krousonas,Krousson,Kroussón,Krousón,Kroúsonas,Κρουσών', 35.2306200, 24.9829100, 'GR', '2012-03-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62909, 'Krokeés', 'Krokees', 'Krokeai,Krokeaí,Krokees,Krokeés,Levetsova,Levétsova,Κροκεές,Κροκεαί', 36.8829700, 22.5468300, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62910, 'Taxiárches', 'Taxiarches', 'Kritsini,Kritsinion,Kritsíni,Kritsínion,Taxiarchai,Taxiarches,Taxiárchai,Taxiárches,Ταξιάρχαι,Ταξιάρχες', 39.5756500, 21.8924500, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62911, 'Kritsá', 'Kritsa', 'Kritsa,Kritsá,Κριτσά', 35.1582100, 25.6445900, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62912, 'Kryonéri', 'Kryoneri', 'Bafi,Báfi,Krionerion,Krionérion,Kryoneri,Kryonerion,Kryonéri,Κρυονέρι,Κρυονέριον', 38.1371200, 23.8305500, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62913, 'Kríkellos', 'Krikellos', 'Krikellon,Krikellos,Krikelo,Kríkellon,Kríkellos,Kríkelo,Κρίκελλος', 38.9453200, 21.1791000, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62914, 'Kréstena', 'Krestena', 'Krestaina,Krestena,Kréstaina,Kréstena,Selinous,Selinoús,Κρέσταινα,Κρέστενα,Крѐстена', 37.5919300, 21.6203400, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62915, 'Kranídi', 'Kranidi', 'Kranidhion,Kranidi,Kranidion,Kranídhion,Kranídi,Kranídion,Κρανίδι,Κρανίδιον', 37.3797400, 23.1596900, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62916, 'Kraniá Elassónas', 'Krania Elassonas', 'Kranea Deskatis,Kranea Dheskatis,Kranea Elassonos,Krania,Krania Dheskatis,Krania Elassonas,Kraniá,Kraniá Dheskátis,Kraniá Elassónas,Kranéa Deskátis,Kranéa Dheskátis,Kranéa Elassónos,Κρανέα Ελασσόνος,Κρανιά Ελασσόνας', 39.9509400, 21.9707800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62917, 'Kouvarás', 'Kouvaras', 'Koubaras,Kouvaras,Kouvarás,Κουβαράς', 37.8271100, 23.9671500, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62918, 'Koutsopódi', 'Koutsopodi', 'Koutsopodhion,Koutsopodi,Koutsopódhion,Koutsopódi,Kutsopodi,Κουτσοπόδι', 37.6842600, 22.7135500, 'GR', '2014-07-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62919, 'Koutselió', 'Koutselio', 'Koutselio,Koutselion,Koutselió,Koutselión,Koutsilio,Koutsilió,Koutsolio,Koutsolió,Κουτσελιό,Κουτσελιόν', 39.5880800, 20.9119700, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62920, 'Metamórfosi', 'Metamorfosi', 'Koukouvaounai,Koukouvaounes,Koukouváounai,Koukouváounes,Metamorfosi,Κουκουβάουναι,Κουκουβάουνες,Μεταμόρφωση', 38.0657600, 23.7635600, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62921, 'Kostakioí', 'Kostakioi', 'Kostakioi,Kostakioí,Κωστακιοί', 39.1367200, 20.9576100, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62922, 'Kos', 'Kos', 'Coo,KGS,Kos,Kos Stadt,Kos Town,Poli Kos,Póli Kos,Κως,Кос', 36.8933300, 27.2888900, 'GR', '2017-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62923, 'Koropí', 'Koropi', 'Kekropia,Koropi,Koropia,Koropion,Koropí,Koropíon,Κεκρωπία,Κοροπίον,Κορωπί,Κορωπία,Κορωπίον', 37.8988600, 23.8718100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62924, 'Koróni', 'Koroni', 'Koroni,Koróni,Κορώνη', 36.7952600, 21.9579400, 'GR', '2015-03-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62925, 'Kórinthos', 'Korinthos', 'Aebura,Corint,Corinth,Corinthe,Corinthus,Corintia,Corinto,Ephyra,Korinf,Korint,Korinth,Korinthe,Korinthos,Korintti,Korynt,Kórinthos,Nea Korinthos,ke lin si,korintosu,qwryntws,Κόρινθος,Νέα Κόρινθος,Коринф,Корінѳъ,קורינתוס,コリントス,科林斯', 37.9400700, 22.9513000, 'GR', '2016-06-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62926, 'Domvraína', 'Domvraina', 'Dhomvraina,Dhomvraína,Dhomvrena,Dhómvrena,Domvraina,Domvraína,Domvrena,Korini,Koríni,Δομβραίνα', 38.2530000, 22.9821100, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62927, 'Kompóti', 'Kompoti', 'Komboti,Kombotion,Kombóti,Kombótion,Kompoti,Kompotion,Kompóti,Kompótion,Κομπότι,Κομπότιον', 39.1025500, 21.0838900, 'GR', '2014-09-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62928, 'Kolympári', 'Kolympari', 'Kolimbari,Kolimbári,Kolimvari,Kolimvarion,Kolimvári,Kolimvárion,Kolymbari,Kolympari,Kolympári,Kolymvarion,Kolymvárion,Κολυμβάρι,Κολυμβάριον,Κολυμπάρι', 35.5411500, 23.7799500, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62929, 'Kokkónion', 'Kokkonion', 'Kokkoni,Kokkonion,Kokkóni,Kokkónion,Kokoni,Kokóni,Κοκκώνι,Κοκκώνιον', 37.9706100, 22.7801800, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62930, 'Kokkíni Cháni', 'Kokkini Chani', 'Chani tou Kokkini,Chanion tou Kokkini,Khanion tou Kokkini,Khánion toú Kokkíni,Kokkini Chani,Kokkini Khanion,Kokkíni Khánion,Metokhi Kokkini,Metókhi Kokkíni,Κοκκίνη Χάνι,Χάνι του Κοκκίνη,Χάνιον του Κοκκίνη', 35.3282700, 25.2581000, 'GR', '2015-10-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62931, 'Kokkári', 'Kokkari', 'Kokari,Kokkari,Kokkarion,Kokkári,Kokkárion,Κοκκάρι,Κοκκάριον', 37.7790800, 26.8917900, 'GR', '2016-10-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62932, 'Koilás', 'Koilas', 'Koilada,Koilas,Koilás,Κοιλάδα,Κοιλάς', 37.4123000, 23.1255300, 'GR', '2015-12-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62933, 'Kýthnos', 'Kythnos', 'Kithnos,Kythnos,Kíthnos,Kýthnos,Thermia,Κύθνος', 37.4166700, 24.4333300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62934, 'Kýthira', 'Kythira', 'Cythera,Kithira,Kythira,Kíthira,Kýthira,Κύθηρα', 36.1495500, 22.9897900, 'GR', '2014-08-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62935, 'Kíssamos', 'Kissamos', 'Cisamus,Cissamos,Císsamos,Kasteli,Kasteli Kisamou,Kastelli,Kastelli Kissamou,Kastellion,Kastélli,Kastéllion,Kisamos,Kissamos,Kissamou,Kíssamos,Κίσαμος,Κίσσαμος,Καστέλι,Καστέλι Κισάμου,Καστέλλι,Κισσάμου,Кисамос', 35.4945900, 23.6537500, 'GR', '2015-09-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62936, 'Kírra', 'Kirra', 'Kirra,Kírra,Xeropigadho,Xeropígadho,Κίρρα', 38.4294400, 22.4444300, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62937, 'Kyriáki', 'Kyriaki', 'Kiriaki,Kiriakion,Kiriáki,Kiriákion,Kyriaki,Kyriakion,Kyriáki,Kyriákion,Κυριάκι,Κυριάκιον', 38.3536500, 22.7884100, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62938, 'Kyrás Vrýsi', 'Kyras Vrysi', 'Kira Vrisi,Kiras Vrisi,Kirá Vrísi,Kirás Vrísi,Kyras Vrysi,Kyrás Vrýsi,Κυράς Βρύση', 37.9129500, 22.9865100, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62939, 'Kipséli', 'Kipseli', 'Kipseli,Kypseli,Κυψέλη,Кипсели', 38.0028800, 23.7375500, 'GR', '2014-05-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62940, 'Kypséli', 'Kypseli', 'Khalasmeni,Khalasméni,Kipseli,Kipséli,Kypseli,Kypséli,Κυψέλη', 37.7602100, 23.4544800, 'GR', '2014-08-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62941, 'Kyparissía', 'Kyparissia', 'Kiparissia,Kiparissía,Kyparissia,Kyparissía,Κυπαρισσία', 37.2511100, 21.6736100, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62942, 'Kinéta', 'Kineta', 'Kineta,Kinéta,Κινέτα', 37.9684300, 23.2135100, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62943, 'Kímolos', 'Kimolos', 'Kimolas,Kimolo,Kimolos,Kímolas,Kímolos,Κίμωλος', 36.7936800, 24.5757700, 'GR', '2014-03-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62944, 'Kými', 'Kymi', 'Kimi,Kumi,Kyme,Kymi,Kími,Kými,Κύμη', 38.6347700, 24.1028700, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62945, 'Kyllíni', 'Kyllini', 'KYLLINIS,Killini,Killíni,Kylini,Kyllene,Kyllini,Kyllíni,Kylíni,ΚΥΛΛΗΝΗΣ,Κυλλήνη', 37.9354200, 21.1450300, 'GR', '2015-09-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62946, 'Kifisiá', 'Kifisia', 'Kefissia,Kephisia,Kephissia,Kifisia,Kifisija,Kifisià,Kifissia,Kēfissia,Κηφισιά,Кифисия,Кифисија,Кіфісія', 38.0743800, 23.8110600, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62947, 'Kiáto', 'Kiato', 'Kiato,Kiaton,Kiáto,Kiáton,Sikion,Sikionia,Sikionía,Sikonia,Κιάτο', 38.0132100, 22.7483900, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62948, 'Chóra Sfakíon', 'Chora Sfakion', 'Chora Sfakion,Chóra Sfakíon,Hora Sfakia,Hora Sfakion,Khora Sfakion,Khóra Sfakíon,Sfakia,Sfakiá,Sphakia,Χώρα Σφακίων', 35.2017600, 24.1371100, 'GR', '2013-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62949, 'Chóra', 'Chora', 'Chora,Chóra,Khora,Khóra,Χώρα', 37.7037400, 26.9045400, 'GR', '2016-10-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62950, 'Chóra', 'Chora', 'Chora,Chóra,Khora,Khóra,Ligoudhista,Ligoudhísta,Ligoudista,Lygudista,Λιγούδιστα,Χώρα', 37.0510600, 21.7169000, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62951, 'Cholargós', 'Cholargos', 'Cholargos,Cholargós,Holargos,Kholargos,Kholargós,Χολαργός', 38.0000000, 23.8000000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62952, 'Chios', 'Chios', 'Castro,Chio,Chios,Chora,Chíos,Chóra,Hios,JKH,Kastro,Kastron,Khios,Khora,Khíos,Khóra,Kástro,Quios,Quíos,Sakiz,Sakız,Scio,Xios,Xíos,el Xiu,hioseu,Κάστρο,Καστρο,Χίος,Χωρα,Χώρα,Хиос,Хіос,히오스', 38.3677800, 26.1358300, 'GR', '2016-12-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62953, 'Khiliomódhi', 'Khiliomodhi', 'Chiliomodi,Chiliomodion,Khiliomodhion,Khiliomodi,Khiliomodion,Khiliomódhion,Χιλιομόδι,Χιλιομόδιον,Хилиомоди', 37.8101600, 22.8697200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62954, 'Chávari', 'Chavari', 'Chavari,Chavarion,Chavárion,Chávari,Khavari,Khavarion,Khavárion,Khávari,Χαβάρι,Χαβάριον', 37.8484200, 21.3840300, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62955, 'Chaniá', 'Chania', 'CHQ,Candia,Canea,Chania,Chanion,Chaniá,Cydonia,Càndia,Hania,Hanio,Hanià,Hanya,Khan''ja,Khania,Khaniá,Kreta,La Canea,La Canee,La Canée,Ĥanio,Χανίων,Χανιά,Ханья', 35.5112400, 24.0292100, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62956, 'Khalkoútsion', 'Khalkoutsion', 'Chalkoutsi,Chalkoutsion,Khalkoutsi,Khalkoutsion,Khalkoútsi,Khalkoútsion,Χαλκούτσι,Χαλκούτσιον', 38.3326300, 23.7318800, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62957, 'Chalkída', 'Chalkida', 'Calcide,Calcis,Chalcis,Chalkida,Chalkis,Chalkída,Chalkís,Euripos,Khalkida,Khalkis,Khalkís,klqys,Χαλκίδα,Χαλκίς,Халкида,כלקיס', 38.4635400, 23.6028400, 'GR', '2016-12-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62958, 'Chalkiádes', 'Chalkiades', 'Chalkiades,Chalkiádes,Khalkiadhes,Khalkiádhes,Yeorgousioi,Χαλκιάδες', 39.1598100, 20.9329200, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62959, 'Chálki', 'Chalki', 'Chalki,Chálki,Khalki,Khálki,Maimouli,Maïmoúli,Χάλκη', 39.5685300, 22.5401700, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62960, 'Chálki', 'Chalki', 'Calchi,Chalki,Chálki,Χάλκη', 36.2224300, 27.6119100, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62961, 'Chalandrítsa', 'Chalandritsa', 'Chalandritsa,Chalandrítsa,Khalandritsa,Khalandrítsa,Χαλανδρίτσα', 38.1166700, 21.7833300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62962, 'Khalándrion', 'Khalandrion', 'Chalandri,Chalandrion,Flya,Khalandhrion,Khalandri,Khalándhrion,Khalándri,Phlya,Φλύα,Χαλάνδρι,Χαλάνδριον', 38.0236900, 23.8006800, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62963, 'Chairóneia', 'Chaironeia', 'Chaeronea,Chaironeia,Chairóneia,Kapraina,Khaironia,Khairónia,Kápraina,Χαιρώνεια', 38.4955100, 22.8442400, 'GR', '2016-12-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62964, 'Chaïdári', 'Chaidari', 'Chaidari,Chaïdári,Khaidhari,Khaidharion,Khaïdhári,Khaïdhárion,Χαϊδάρι', 38.0113500, 23.6659700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62965, 'Keratsíni', 'Keratsini', 'Agios Georgios Keratsiniou,Ayios Yeoryios,Ayios Yeoryios Keratsiniou,Hagios Georgios Keratsiniou,Keratsini,Keratsinion,Keratsiniou,Keratsiníou,Keratsíni,Keratsínion,Tseratsinion,Áyios Yeóryios,Άγιος Γεώργιος Κερατσινίου,Κερατσίνι,Κερατσίνιον,Τσερατσίνιον', 37.9625000, 23.6197200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62966, 'Keratéa', 'Keratea', 'Keratea,Keratéa,Κερατέα', 37.8058500, 23.9774000, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62967, 'Kerasochóri', 'Kerasochori', 'Kerasochori,Kerasochorion,Kerasochóri,Kerasochórion,Kerasokhori,Kerasokhorion,Kerasokhóri,Kerasokhórion,Kerasovon,Kerásovon,Κερασοχώρι', 39.0055600, 21.6377800, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62968, 'Kentrí', 'Kentri', 'Kendri,Kendrion,Kendrí,Kendríon,Kentri,Kentrion,Kentrí,Kentríon,Κεντρί,Κεντρίον', 35.0325800, 25.7528000, 'GR', '2015-09-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62969, 'Kéfalos', 'Kefalos', 'Cefalo,Cephalo,Kefalos,Kephalo,Kéfalos,Képhalo,Κέφαλος', 36.7450700, 26.9596100, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62970, 'Kéa', 'Kea', 'Kea,Kéa,Zea,Κέα', 37.6333300, 24.3500000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62971, 'Kavásila', 'Kavasila', 'Kabasilas,Kavasila,Kavasilas,Kavásila,Kavásilas,Καβάσιλα,Καβάσιλας', 37.8758100, 21.2642200, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62972, 'Katsikás', 'Katsikas', 'Katsika,Katsikas,Katsiká,Katsikás,Κατσικάς', 39.6228100, 20.8875800, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62973, 'Katoúna', 'Katouna', 'Katouna,Katoúna,Κατούνα', 38.7854700, 21.1141700, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62974, 'Káto Tithoréa', 'Kato Tithorea', 'Kato Tithorea,Kifisokhori,Kifisokhorion,Kifisokhóri,Kifisokhórion,Kifissokhori,Kifissokhóri,Káto Tithoréa,Κάτω Τιθορέα', 38.6075100, 22.7134800, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62975, 'Káto Soúlion', 'Kato Soulion', 'Kato Souli,Kato Soulion,Káto Soúli,Káto Soúlion,Κάτω Σούλι,Κάτω Σούλιον', 38.1680300, 24.0162800, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62976, 'Káto Mazaráki', 'Kato Mazaraki', 'Kato Mazaraki,Kato Mazarakion,Káto Mazaráki,Káto Mazarákion,Mazaraki,Mazaráki,Κάτω Μαζαράκι,Κάτω Μαζαράκιον', 38.0703500, 21.6509700, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62977, 'Káto Lekhónia', 'Kato Lekhonia', 'Kato Lechonia,Lekhonia,Lekhónia,Κάτω Λεχώνια', 39.3309100, 23.0395700, 'GR', '2015-01-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62978, 'Katochí', 'Katochi', 'Katoche,Katochi,Katokhi,Katokhí,Κατοχή', 38.4123700, 21.2525800, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62979, 'Káto Glykóvrysi', 'Kato Glykovrysi', 'Kato Glikovrisi,Kato Glykovrysi,Kato Vezani,Káto Glikóvrisi,Káto Glykóvrysi,Káto Vezáni,Κάτω Γλυκόβρυση', 36.8279100, 22.7773200, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62980, 'Káto Dhiminió', 'Kato Dhiminio', 'Kato Dhiminio,Kato Dhiminion,Kato Diminio,Káto Dhiminió,Káto Dhiminión,Κάτω Διμηνιό', 38.0249000, 22.7329400, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62981, 'Káto Asítai', 'Kato Asitai', 'Kato Asitai,Kato Asitais,Káto Asítai,Káto Asítais,Κάτω Ασίται', 35.2027100, 24.9982700, 'GR', '2013-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62982, 'Káto Achaḯa', 'Kato Achaia', 'Kato Achagia,Kato Achaia,Kato Akhaia,Káto Achagiá,Káto Achaḯa,Káto Akhaïa,Κάτω Αχαΐα', 38.1500000, 21.5500000, 'GR', '2016-03-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62983, 'Katastárion', 'Katastarion', 'Katastari,Katastarion,Katastári,Katastárion,Καταστάρι,Καταστάριον', 37.8301200, 20.7575500, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62984, 'Kastrí', 'Kastri', 'Kastri,Kastrion,Kastrí,Kastríon,Καστρί', 34.8346000, 24.0857200, 'GR', '2015-09-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62985, 'Kastráki', 'Kastraki', 'Kastraki,Kastrakion,Kastráki,Kastrákion,Καστράκι,Καστράκιον', 39.7169200, 21.6186500, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62986, 'Kastélli', 'Kastelli', 'Kasteli,Kastelli,Kastellion,Kastellion Pedhiadhos,Kastellion Pediada,Kastéli,Kastélli,Kastéllion,Kastéllion Pedhiádhos,Kastéllion Pedíada,Καστέλλι,Καστέλλιον', 35.2090200, 25.3377300, 'GR', '2012-03-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62987, 'Kastélla', 'Kastella', 'Kastella,Kastélla,Καστέλλα', 38.5704800, 23.6313100, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62988, 'Karpochóri', 'Karpochori', 'Gerbesi,Gerbetsi,Gerbétsi,Gérbesi,Karpochori,Karpochorion,Karpochóri,Karpochórion,Karpokhori,Karpokhorion,Karpokhóri,Karpokhórion,Καρποχώρι,Καρποχώριον', 39.3357500, 22.0112900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62989, 'Karpenísi', 'Karpenisi', 'Karpenisi,Karpenision,Karpenísi,Karpenísion,Καρπενήσι,Καρπενήσιον', 38.9121800, 21.7983600, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62990, 'Karpathos', 'Karpathos', 'AOK,Karpathos,Pegadia,Pigadhia,Pigadia,Pigádhia,Κάρπαθος', 35.5070100, 27.2132200, 'GR', '2015-11-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62991, 'Kárystos', 'Karystos', 'Karistos,Karysto,Karystos,Káristos,Kárystos,Κάρυστος', 38.0133300, 24.4161100, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62992, 'Karyés', 'Karyes', 'Arakhova,Arákhova,Kariai,Kariaí,Karyai,Karyaí,Karyes,Karyés,Καρυές,Καρυαί', 37.2911900, 22.5006600, 'GR', '2016-06-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62993, 'Karditsomagoúla', 'Karditsomagoula', 'Kardhitsomagoula,Kardhitsomagoúla,Karditsomagoula,Karditsomagoúla,Καρδιτσομαγούλα', 39.3906100, 21.9233000, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62994, 'Kardítsa', 'Karditsa', 'Kardhitsa,Kardhítsa,Kardica,Karditsa,Kardiça,Kardítsa,ka er ji cha,Καρδίτσα,Кардица,卡尔季察', 39.3648500, 21.9219100, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62995, 'Kardamýli', 'Kardamyli', 'Cardamyle,Kardamili,Kardamyle,Kardamyli,Kardamýli,Kardhamili,Kardhamíli,Καρδαμυλι,Καρδαμύλη,Кардамили', 36.8877800, 22.2331700, 'GR', '2015-05-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62996, 'Kardamás', 'Kardamas', 'Kardamas,Kardamás,Kardhamas,Kardhamás,Καρδαμάς', 37.7672900, 21.3394600, 'GR', '2015-09-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62997, 'Kardámaina', 'Kardamaina', 'Cardamena,Chorio Kardamaina,Chorió Kardámaina,Kardamaina,Kardamena,Kardhamaina,Kardhámaina,Kardámaina,Καρδάμαινα', 36.7830500, 27.1428900, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62998, 'Karátoula', 'Karatoula', 'Karatoula,Karatoulas,Karátoula,Karátoulas,Καράτουλα,Καράτουλας', 37.7356400, 21.5357800, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(62999, 'Pefkochóri', 'Pefkochori', 'Kapsochora,Pefkochori,Pefkohori,Pefkokhori,Pevkokhori,Καψόχωρα,Πευκοχώρι,Певкохори,Пефкохори', 39.9878400, 23.6121900, 'GR', '2014-08-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63000, 'Kaparéllion', 'Kaparellion', 'Kapareli,Kapareli Plataion,Kaparellion,Kaparéli,Kaparéli Plataión,Kaparéllion,Καπαρέλλιον', 38.2369700, 23.2141100, 'GR', '2014-03-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63001, 'Kapandríti', 'Kapandriti', 'Kapandhrition,Kapandhrítion,Kapandriti,Kapandrition,Kapandríti,Kapandrítion,Καπανδρίτι,Καπανδρίτιον', 38.2157900, 23.8793800, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63002, 'Kandíla', 'Kandila', 'Kandela,Kandhila,Kandhíla,Kandila,Kandíla,Κανδήλα', 38.7056400, 20.9474900, 'GR', '2014-04-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63003, 'Kanaláki', 'Kanalaki', 'Kanalaki,Kanallaki,Kanallakion,Kanalláki,Kanallákion,Kanaláki,Καναλάκι,Καναλλάκιον', 39.2336100, 20.6000000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63004, 'Kanália', 'Kanalia', 'Kanalia,Kanália,Κανάλια', 39.4992800, 22.8858900, 'GR', '2015-04-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63005, 'Kaména Voúrla', 'Kamena Vourla', 'Kamena Bourla,Kamena Vourla,Kammena Vourla,Kamména Voúrla,Καμένα Βούρλα', 38.7784400, 22.7857300, 'GR', '2014-10-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63006, 'Kamaterón', 'Kamateron', 'Kamatero,Kamateró,Καματερό', 38.0558600, 23.7051500, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63007, 'Kamárai', 'Kamarai', 'Kamarai,Kamarais,Kamárai,Kamárais,Καμάραι', 38.2988100, 21.9989200, 'GR', '2015-05-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63008, 'Kalpáki', 'Kalpaki', 'Kalpaki,Kalpakion,Kalpáki,Kalpákion,Καλπάκι', 39.8877800, 20.6238900, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63009, 'Kalloní', 'Kalloni', 'Akhiron,Akhirón,Kalloni,Kalloní,Καλλονή', 39.2331800, 26.2072400, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63010, 'Kallíthiro', 'Kallithiro', 'Kallithiro,Kallithiron,Kallíthiro,Kallíthiron,Sekliza,Sékliza,Καλλίθηρο,Καλλίθηρον', 39.2809900, 21.9049100, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63011, 'Kallithéa', 'Kallithea', 'Kalitea,Kaliteja,Kalithea,Kalithéa,Kalitėja,Kallifeja,Kalliteja,Kallithea,Kallithéa,kalythya,kalyth‌a,Καλλιθέα,Калитеа,Каллифея,Каллітея,كاليثيا,کالیته‌آ', 37.9500000, 23.7000000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63012, 'Kallifóni', 'Kallifoni', 'Kallifoneion,Kallifoni,Kallifonio,Kallifonion,Kallifóneion,Kallifóni,Kallifónio,Kallifónion,Καλλιφώνι,Καλλιφώνιον', 39.2771200, 21.9612800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63013, 'Kalývia Thorikoú', 'Kalyvia Thorikou', 'Kalivia,Kalivia Thorikou,Kalyvia,Kalyvia Thorikou,Kalívia,Kalívia Thorikoú,Kalývia Thorikoú,Kouvara,Kouvará,Thorikou,Thorikoú,Καλύβια,Καλύβια Θορικού', 37.8389400, 23.9250500, 'GR', '2014-09-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63014, 'Kalýves', 'Kalyves', 'Kalivai,Kalivia,Kalivia Vamou,Kalyvai,Kalyves,Kalyvès,Kalívai,Kalívia,Kalívia Vámou,Vamou,Vámou,Καλύβαι,Καλύβες', 35.4504600, 24.1750700, 'GR', '2015-11-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63015, 'Kálymnos', 'Kalymnos', 'Calino,Kalimnos,Kalymnos,Kálimnos,Kálymnos,Pothaia,Pothia,Póthia,Κάλυμνος,Πόθια', 36.9544700, 26.9769000, 'GR', '2016-02-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63016, 'Kalávryta', 'Kalavryta', 'Kalabryta,Kalavrita,Kalavryta,Kalávrita,Kalávryta,Καλάβρυτα', 38.0322200, 22.1125000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63017, 'Kálamos', 'Kalamos', 'Kalamos,Kálamos,Peraia,Κάλαμος,Περαία', 38.2844700, 23.8630800, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63018, 'Kalamiá', 'Kalamia', 'Kalamia,Kalamies,Kalamiá,Kalamiés,Konesoi,Konésoï,Καλαμιά', 39.1652800, 20.9320600, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63019, 'Kalampáka', 'Kalampaka', 'Kalabaka,Kalabáka,Kalambaka,Kalambáka,Kalampaka,Kalampáka,Καλαμπάκα', 39.7044400, 21.6269400, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63020, 'Kalamata', 'Kalamata', 'KLX,Kalamae,Kalamai,Kalamata,Kalamatas,Kalamato,Kalamáta,Kalmata,Kalámai,kalamata,Καλάμαι,Καλαμάτα,Каламата,كالاماتا', 37.0391300, 22.1126500, 'GR', '2016-12-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63021, 'Álimos', 'Alimos', 'Alimos,Kalamaki,Kalamakion,Kalamáki,Kalamákion,Álimos,Άλιμος,Καλαμάκι,Καλαμάκιον', 37.9103300, 23.7236100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63022, 'Kaisarianí', 'Kaisariani', 'Kaisariane,Kaisariani,Kaisarianí,Kesariani,Καισαριανή,Кесариани', 37.9634000, 23.7652300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63023, 'Kainoúryion', 'Kainouryion', 'Kainourgio,Kainourgion,Καινούργιο,Καινούργιον', 38.7928300, 22.7247000, 'GR', '2014-10-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63024, 'Kainoúryion', 'Kainouryion', 'Kainourgio,Kainourgion,Kainourion,Kainouryion,Kainoúrion,Kainoúryion,Καινούργιο,Καινούργιον', 38.6045300, 21.4877600, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63025, 'Itháki', 'Ithaki', 'Ithaca,Ithake,Vathi,Vathí,Ιθάκη', 38.3642100, 20.7184800, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63026, 'Itéa', 'Itea', 'Itea,Itéa,Katseri,Katserí,Kotseri,Kotserion,Kotserí,Kotseríon,Ιτέα', 39.4566900, 22.1657700, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63027, 'Itéa', 'Itea', 'Itea,Itéa,Ιτέα,Итеа', 38.4320100, 22.4244300, 'GR', '2013-12-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63028, 'Istiaía', 'Istiaia', 'Istiaia,Istiaía,Istiea,Xirochori,Xirokhori,Xirokhorion,Xirokhóri,Xirokhórion,Ιστιαία,Ξηροχώρι', 38.9552000, 23.1521000, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63029, 'Isthmía', 'Isthmia', 'Isthmia,Isthmos,Isthmía,Isthmós,Ισθμία', 37.9135600, 23.0046000, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63030, 'Irákleio', 'Irakleio', 'Irakleio,Iraklion,Irákleio,Iráklion,Ηράκλειο', 38.0528200, 23.7652300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63031, 'Irákleion', 'Irakleion', 'Candia,Candie,Càndia,Erakleion,HER,Heracleum,Heracliao,Heraclion,Heraclião,Heraclión,Herakleion,Heraklion,Herákleion,Héraklion,Iraclio,Iraclion,Irakleio,Irakleio Kritis,Irakleion,Iraklija,Iraklio,Iraklion,Iráclio,Irákleio,Irákleion,Iráklio,Iráklion,Kandiye,Khandax,Megalokastro,Megalokastron,hrqlywn,irakurion,yi la ke li weng,Ērakleion,Ηράκλειο,Ηράκλειο Κρήτης,Ираклио,Ираклион,הרקליון,イラクリオン,伊拉克利翁', 35.3278700, 25.1434100, 'GR', '2014-01-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63032, 'Íos', 'Ios', 'Ios,Nio,Íos,Ίος', 36.7333300, 25.2833300, 'GR', '2013-09-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63033, 'Ioánnina', 'Ioannina', 'Giannena,Giannina,IOA,Ioaa,Ioanina,Ioannina,Ioánina,Ioánnina,Ioäa,Janina,Yanina,Yannina,Yanya,yue a ni na,Γιάννενα,Γιάννινα,Ιωάννινα,Янина,约阿尼纳', 39.6648600, 20.8518900, 'GR', '2015-03-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63034, 'Igoumenítsa', 'Igoumenitsa', 'Gomenizza,Igoemenitsa,Igoumenitsa,Igoumenítsa,Igumenica,Igumenitsa,Ηγουμενίτσα,Игуменица', 39.5034200, 20.2672800, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63035, 'Ierápetra', 'Ierapetra', 'Hierapetra,Ierapetra,Ierapitna,Ierápetra,Kasteli,Yerapetra,Yirapetra,Yirápetra,Ιεράπετρα,Иерапетра', 35.0118600, 25.7423400, 'GR', '2015-09-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63036, 'Ýdra', 'Ydra', 'Hydra,Idhra,Ydra,Ídhra,Ýdra,Ύδρα', 37.3497600, 23.4656000, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63037, 'Grizáno', 'Grizano', 'Gritzanon,Grizano,Grizanon,Grizáno,Grítzanon,Grízanon,Γριζάνο,Γριζάνον', 39.6319200, 22.0525800, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63038, 'Grammenítsa', 'Grammenitsa', 'Gramenitsa,Gramenítsa,Grammenitsa,Grammenítsa,Γραμμενίτσα', 39.1844400, 20.9793300, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63039, 'Grammatikó', 'Grammatiko', 'Grammatiko,Grammatikon,Grammatikó,Grammatikón,Γραμματικό,Γραμματικόν', 38.2025100, 23.9650400, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63040, 'Gra Liyiá', 'Gra Liyia', 'Gra Liyia,Gra Liyiá,Gra Lygia,Metokhi Gra Liyia,Metókhi Grá Liyiá,Γρα Λυγιά', 35.0146700, 25.6912700, 'GR', '2015-09-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63041, 'Graikochóri', 'Graikochori', 'Graikochori,Graikochorion,Graikochóri,Graikochórion,Graikokhorion,Graikokhórion,Grekokhori,Grekokhóri,Γραικοχώρι,Γραικοχώριον', 39.4978900, 20.2760800, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63042, 'Goúrnes', 'Gournes', 'Gournai,Gournais,Gournes,Gournes Pediadas,Gournes Pediados,Gouvai,Goúrnai,Goúrnais,Goúrnes,Goúvai,Γούρνες,Γούρνες Πεδιάδας,Γούρνες Πεδιάδος', 35.3262600, 25.2774000, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63043, 'Goúmero', 'Goumero', 'Goumero,Goumeron,Goúmero,Goúmeron,Γούμερο,Γούμερον', 37.7623600, 21.6185300, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63044, 'Gónnoi', 'Gonnoi', 'Dereli,Derelí,Dhereli,Dherelí,Gonnoi,Gonnos,Gónnoi,Gónnos,Γόννοι', 39.8615300, 22.4764700, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63045, 'Gómfoi', 'Gomfoi', 'Gomfoi,Gómfoi,Rapsista,Rápsista,Γόμφοι', 39.4641300, 21.6934200, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63046, 'Glyfáda', 'Glyfada', 'Aixone,Glifadha,Glifádha,Glyfada,Glyfáda,Γλυφάδα,Γλυφαδα', 37.8628900, 23.7580200, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63047, 'Gázi', 'Gazi', 'Gazi,Gazion,Gázi,Gázion,Γάζι,Γάζιον', 35.3253100, 25.0669400, 'GR', '2015-12-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63048, 'Gavaloú', 'Gavalou', 'Gabalou,Gavalou,Gavaloú,Gavalu,Γαβαλού', 38.5290300, 21.5322600, 'GR', '2014-10-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63049, 'Gastoúni', 'Gastouni', 'Gastouni,Gastoúni,Gastuni,Γαστούνη', 37.8500000, 21.2500000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63050, 'Gargaliánoi', 'Gargalianoi', 'Gargaliani,Gargalianoi,Gargaliánoi,Γαργαλιάνοι', 37.0651800, 21.6380900, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63051, 'Galaxídhion', 'Galaxidhion', 'Galaksidi,Galaxidhion,Galaxidi,Galaxidion,Galaxídhion,Γαλαξίδι,Γαλαξίδιον,Галаксиди', 38.3806700, 22.3800100, 'GR', '2015-05-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63052, 'Galátsi', 'Galatsi', 'Galatsi,Galatsion,Galátsi,Galátsion,Γαλάτσι,Γαλάτσιον', 38.0166700, 23.7500000, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63053, 'Galatás', 'Galatas', 'Galatas,Galatás,Γαλατάς', 38.3574200, 21.5622200, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63054, 'Galatás', 'Galatas', 'Galatas,Galatás,Γαλατάς', 37.4961800, 23.4488600, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63055, 'Galatás', 'Galatas', 'Galatas,Galatás,Γαλατάς', 35.4986400, 23.9634100, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63056, 'Gaïtánion', 'Gaitanion', 'Gaitani,Gaitanion,Gaïtáni,Gaïtánion,Γαϊτάνι', 37.7913400, 20.8740700, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63057, 'Fry', 'Fry', 'Fri,Fry,Frý,Ofri,Φρυ,Фри', 35.4162300, 26.9232800, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63058, 'Folégandros', 'Folegandros', 'Folegandhros,Folegandros,Folégandhros,Folégandros,Polykandro,Φολέγανδρος,Фолегандрос', 36.6279400, 24.9202100, 'GR', '2014-09-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63059, 'Fyteíes', 'Fyteies', 'Fitiai,Fitíai,Fyteiai,Fyteies,Fyteíai,Fyteíes,Mahalas,Mahalás,Makhala,Makhalas,Makhalás,Φυτείαι,Φυτείες', 38.6952400, 21.1846700, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63060, 'Filótion', 'Filotion', 'Filoti,Filotion,Filóti,Filótion,Philotium,Φιλότι,Φιλότιον', 37.0516700, 25.4982900, 'GR', '2015-10-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63061, 'Filothéi', 'Filothei', 'Filothei,Filothéi,Nea Alexandia,Néa Alexándia,Φιλοθέη', 38.0252400, 23.7825700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63062, 'Fílla', 'Filla', 'Filla,Fylla,Fílla,Phylla,Φύλλα', 38.4417700, 23.6830600, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63063, 'Filippiáda', 'Filippiada', 'Filippiada,Filippias,Filippiáda,Filippiás,Nea Filippias,Néa Filippiás,Philippiada,Philippiáda,Φιλιππιάδα,Φιλιππιάς', 39.2047200, 20.8822200, 'GR', '2015-03-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63064, 'Filiatrá', 'Filiatra', 'Filiatra,Filiatrá,Philiatra,Φιλιατρά', 37.1563700, 21.5853200, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63065, 'Filiátes', 'Filiates', 'Filiatai,Filiates,Filiátai,Filiátes,Φιλιάτες', 39.6011100, 20.3119400, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63066, 'Fylí', 'Fyli', 'Fili,Filí,Fyli,Fylí,Khasia,Khasiá,Phyle,Φυλή,Фили', 38.1023500, 23.6690100, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63067, 'Fíki', 'Fiki', 'Fiki,Fyki,Fíki,Fýki,Φήκη', 39.5160200, 21.6555600, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63068, 'Fársala', 'Farsala', 'Farsala,Farsalia,Farsalos,Farsàlia,Fársala,Fársalos,Pharsale,Pharsalus,Φάρσαλα', 39.2947200, 22.3847200, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63069, 'Fáros', 'Faros', 'Faros,Fáros,Gerali,Pharos,Yerali,Yeralion,Yeralí,Yeralíon,Γεραλί,Φάρος', 38.3995900, 23.6227500, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63070, 'Farkadóna', 'Farkadona', 'Farkadhon,Farkadhón,Farkadona,Farkadóna,Tsiotion,Tsiótion,Φαρκαδόνα', 39.6000000, 22.0666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63071, 'Magoúla', 'Magoula', 'Fanar Magoula,Fanarion,Fanarion Magoulas,Fanár Magoúla,Fanárion,Fanárion Magoúlas,Magoula,Magoulas,Magoúla,Magoúlas,Μαγούλα', 39.4539500, 21.8035100, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63072, 'Fálanna', 'Falanna', 'Falaina,Falani,Falanna,Fálaina,Fálani,Fálanna,Phalanna,Tatar,Tatár,Φάλανη,Φάλαννα', 39.7198600, 22.3973300, 'GR', '2015-10-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63073, 'Examília', 'Examilia', 'Eksamilia,Examilia,Examilion,Examillia,Examília,Examílion,Examíllia,Εξαμίλια', 37.8973600, 22.9283200, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63074, 'Evxinoúpolis', 'Evxinoupolis', 'Efxeinoupoli,Ευξεινούπολη', 39.1841400, 22.7383100, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63075, 'Ermoúpolis', 'Ermoupolis', 'Ermoupoli,Ermoupolis,Ermoúpoli,Hermoupolis,Hermoúpolis,Hermupolis,Siros,Síros,Ερμούπολη,Ερμούπολις', 37.4422700, 24.9424800, 'GR', '2013-12-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63076, 'Ermióni', 'Ermioni', 'Ermioni,Ermióni,Hermioni,Kastri,Kastrí,Ερμιόνη', 37.3849200, 23.2468600, 'GR', '2016-05-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63077, 'Erythrés', 'Erythres', 'Eleutherae,Erithrai,Erithraí,Erythrai,Erythres,Erythrés,Kriekouki,Kriekoúki,Ερυθρές,Ερυθραί,Κριεκούκι', 38.2174100, 23.3223400, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63078, 'Erétria', 'Eretria', 'Ehretrija,Eretria,Eretrie,Erétria,Nea Psara,Néa Psará,Érétrie,Ερέτρια,Эретрия', 38.4009700, 23.8022000, 'GR', '2015-01-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63079, 'Eresós', 'Eresos', 'Eresos,Eressos,Eressós,Eresós,Erissos,Ερεσός', 39.1697300, 25.9343700, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63080, 'Epitálio', 'Epitalio', 'Agoulinitsa,Agoulinítsa,Agulinitza,Epitalio,Epitalion,Epitálio,Epitálion,Επιτάλιο,Επιτάλιον', 37.6267500, 21.4952800, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63081, 'Ano Arhanes', 'Ano Arhanes', 'Ano Archanes,Ano Arkhanai,Ano Arkhanes,Ano Arkhánai,Epano Archanai,Epano Arkhanai,Epáno Arkhánai,Áno Arkhánes,Άνω Αρχάνες,Επάνω Αρχάναι', 35.2333300, 25.1666700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63082, 'Emporeío', 'Emporeio', 'Emborio,Emborion,Emboríon,Emporeio,Emporeion,Emporeío,Emporeíon,Εμπορείο,Εμπορείον', 36.3581600, 25.4461500, 'GR', '2016-12-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63083, 'Émponas', 'Emponas', 'Ambonus,Embona,Embonas,Empona,Emponas,Émbona,Émponas,Έμπωνας', 36.2268300, 27.8564500, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63084, 'Eloúnda', 'Elounda', 'Ehlunda,Elouda,Elounda,Elounta,Eloúnda,Ελούντα,Элунда', 35.2650000, 25.7212700, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63085, 'Ellinikó', 'Elliniko', 'Elliniko,Ellinikon,Ellinikó,Ellinikón,Ελληνικό,Ελληνικόν', 37.8901300, 23.7440600, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63086, 'Elefsína', 'Elefsina', 'Elefis,Elefsina,Elefsis,Elefsína,Elefsís,Eleusis,Elevsis,Elevsís,Lepsina,Ελευσίνα,Ελευσίς', 38.0413500, 23.5429500, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63087, 'Eleoúsa', 'Eleousa', 'Eleousa,Eleoúsa,Mega Bisdhouni,Mega Bisdhounion,Mega Bisdhoúni,Mega Bisdouni,Megalo Bisdouni,Méga Bisdhoúnion,Méga Bisdoúni,Ελεούσα,Μέγα Μπισδούνι,Μεγάλο Μπισδούνι', 39.7063900, 20.7925000, 'GR', '2015-03-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63088, 'Eleoúsa', 'Eleousa', 'Eleousa,Eleoúsa,Ελεούσα', 39.1527800, 20.9621400, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63089, 'Eláteia', 'Elateia', 'Dhrakhmani,Dhrakhmáni,Elateia,Elatia,Eláteia,Elátia,Ελάτεια', 38.6277000, 22.7649200, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63090, 'Elassóna', 'Elassona', 'Elasson,Elassona,Elassón,Elassóna,Ελασσόνα,Ελασσών', 39.8947200, 22.1886100, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63091, 'Ekáli', 'Ekali', 'Ekale,Ekali,Ekáli,Εκάλη', 38.1103500, 23.8350500, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63092, 'Voulgaréli', 'Voulgareli', 'Dhrosopiyi,Dhrosopiyí,Drosopigi,Drosopigí,Voulgareli,Voulgarelion,Voulgaréli,Voulgarélion,Vourgareli,Vourgarelion,Vourgaréli,Vourgarélion,Βουλγαρέλι', 39.3719400, 21.1833300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63093, 'Dhrosiá', 'Dhrosia', 'Chalia,Chalía,Chália,Dhrosia,Dhrosiá,Drosia,Drosia Evvoias,Drossia,Drossiá,Khalia,Khalía,Δροσιά,Δροσιά Εύβοιας,Χάλια,Χαλία', 38.4841300, 23.5477400, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63094, 'Drosiá', 'Drosia', 'Dhrosia,Dhrosiá,Drosia,Drosiá,Rossochori,Rossokhorion,Rossokhoríon,Δροσιά,Ρωσσοχώρι', 38.1197700, 23.8642800, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63095, 'Drépanon', 'Drepanon', 'Dhrepanon,Dhrépanon,Drepano,Drepanon,Drepanou,Drépanon,Khaidari,Khaidharion,Khaïdhárion,Δρέπανο,Δρέπανον', 37.5388800, 22.8932300, 'GR', '2017-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63096, 'Dhráfi', 'Dhrafi', 'Dhrafi,Dhráfi,Drafi,Drafí,Ntrafi,Ντράφι', 38.0237500, 23.9078800, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63097, 'Domokós', 'Domokos', 'Dhomokos,Dhomokós,Domokos,Domokós,Δομοκός', 39.1272200, 22.3002800, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63098, 'Dhokímion', 'Dhokimion', 'Dokimio,Dokimion,Δοκίμιο,Δοκίμιον', 38.6135200, 21.3807200, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63099, 'Dístomo', 'Distomo', 'Dhistomon,Dhístomon,Distomo,Dístomo,Δίστομο', 38.4333300, 22.6666700, 'GR', '2013-12-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63100, 'Diónysos', 'Dionysos', 'Dhionisos,Dhiónisos,Dionysos,Diónysos,Διόνυσος', 38.1045800, 23.8793800, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63101, 'Dimitsána', 'Dimitsana', 'Dhimitsana,Dhimitsána,Dimitsana,Dimitsána,Δημητσάνα', 37.5952400, 22.0402500, 'GR', '2017-03-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63102, 'Dílesi', 'Dilesi', 'Dhilesi,Dhilion,Dhílesi,Dhílion,Dilesi,Δήλεσι', 38.3376200, 23.6707700, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63103, 'Dídyma', 'Didyma', 'Dhidhima,Dhidhimoi,Dhídhima,Dhídhimoi,Didyma,Dídyma,Δίδυμα', 37.4625000, 23.1718300, 'GR', '2016-05-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63104, 'Deskáti', 'Deskati', 'Deskate,Deskati,Deskáti,Dheskati,Dheskáti,Dhiskata,Dhiskáta,Diskata,Δεσκάτη', 39.9225000, 21.8027800, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63105, 'Delphi', 'Delphi', 'Del''fi,Del''fy,Delfi,Delfoi,Delfos,Delfoí,Delfy,Delphes,Delphi,Delphoi,Dhelfoi,Dhelfoí,de er fei,derupoi,dlfy,dlpy,Δελφοί,Делфи,Дельфи,Дельфы,דלפי,דעלפי,دلفی,デルポイ,德尔斐,德尔菲', 38.4794200, 22.4935700, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63106, 'Darátsos', 'Daratsos', 'Daratsos,Darátsos,Dharatsos,Dharátsos,Karatsos,Karátsos,Δαράτσος', 35.4995500, 23.9748800, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63107, 'Dhafní', 'Dhafni', 'Dafni,Daphne,Daphni,Dhafni,Dhafní,Katsipodhion,Katsipódhion,Vlikha,Δάφνη', 37.9500200, 23.7343700, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63108, 'Rodópoli', 'Rodopoli', 'Bala,Bála,Rodopoli,Rodópoli,Μπάλα,Ροδόπολη', 38.1166900, 23.8757200, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63109, 'Ágios Geórgios', 'Agios Georgios', 'Agios Georgios,Ayios Yeoryios,Ágios Geórgios,Áyios Yeóryios,Άγιος Γεώργιος', 38.3934300, 22.9318900, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63110, 'Áyios Vasílios', 'Ayios Vasilios', 'Agios Vasileios,Άγιος Βασίλειος', 37.7976300, 22.7972700, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63111, 'Áyios Thomás', 'Ayios Thomas', 'Agios Thomas,Liatani,Liátani,Άγιος Θωμάς,Λιάτανη', 38.2771700, 23.5890600, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63112, 'Ágios Stéfanos', 'Agios Stefanos', 'Agios Stefanos,Agios Stephanos,Ayios Stefanos,Ágios Stéfanos,Áyios Stéfanos,Άγιος Στέφανος', 38.1465700, 23.8560800, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63113, 'Áyios Nikólaos', 'Ayios Nikolaos', 'Agios Nikolaos,Άγιος Νικόλαος', 38.4205100, 23.6477200, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63114, 'Arkoúdi', 'Arkoudi', 'Arkoudi,Arkoúdi,Ayios Nikolaos,Áyios Nikólaos,Αρκούδι', 37.8468100, 21.1102200, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63115, 'Ágios Nikólaos', 'Agios Nikolaos', 'Aghios Nicolaos,Aghios Nikolaos,Agios Nikolaos,Agios Nikolaos Lasithiou,Agios-Nikolaos,Ayios Nikolaos,Lato-Kamara,Ágios Nikólaos,Áyios Nikólaos,Άγιος Νικόλαος,Άγιος Νικόλαος Λασιθίου,Агиос-Николаос', 35.1910600, 25.7152400, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63116, 'Áyios Konstandínos', 'Ayios Konstandinos', 'Agios Konstantinos,Άγιος Κωνσταντίνος', 38.7561200, 22.8575700, 'GR', '2014-10-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63117, 'Áyios Konstandínos', 'Ayios Konstandinos', 'Agios Konstantinos,Άγιος Κωνσταντίνος', 38.6333700, 21.3995000, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63118, 'Agios Kirykos', 'Agios Kirykos', 'Agios Kirykos,Angeriko,Ayios Kirikos,JIK,Kirikos,Kírikos,Áyios Kírikos,Άγιος Κήρυκος', 37.6147200, 26.2944400, 'GR', '2016-09-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63119, 'Ágios Efstrátios', 'Agios Efstratios', 'Agios Efstratios,Ayios Evstratios,Ayios Stratis,Ágios Efstrátios,Áyios Evstrátios,Áyios Stratis,Άγιος Ευστράτιος', 39.5388900, 24.9916700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63120, 'Agios Dimitrios', 'Agios Dimitrios', 'Agios Dimitrios,Ayios Dhimitrios,Brakhami,Brakhámi,Áyios Dhimítrios,Άγιος Δημήτριος', 37.9333300, 23.7333300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63121, 'Ágios Andréas', 'Agios Andreas', 'Agios Andreas,Anthini,Ayios Andhreas,Ayios Andreas,Ágios Andréas,Áyios Andhréas,Áyios Andréas,Άγιος Ανδρέας,Ανθηνη', 37.3451900, 22.7646600, 'GR', '2014-04-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63122, 'Áyios Adhrianós', 'Ayios Adhrianos', 'Agios Adrianos,Ayios Adhrianos,Katsingri,Katsingrion,Katsíngrion,Áyios Adhrianós,Άγιος Αδριανός', 37.5997500, 22.8456000, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63123, 'Ágioi Theódoroi', 'Agioi Theodoroi', 'Agii Theodori,Agioi Theodoroi,Ayioi Theodhoroi,Ayioi Theodoroi,Ágioi Theódoroi,Áyioi Theódhoroi,Άγιοι Θεόδωροι', 37.9273600, 23.1422100, 'GR', '2016-03-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63124, 'Ágioi Déka', 'Agioi Deka', 'Agioi Deka,Ayioi Dheka,Hagios Deka,Ágioi Déka,Áyioi Dhéka,Άγιοι Δέκα', 35.0666700, 24.9666700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63125, 'Áyioi Apóstoloi', 'Ayioi Apostoloi', 'Aghioi Apostoloi,Agii Apostoli,Agioi Apostoloi,Άγιοι Απόστολοι', 38.2916900, 23.9101100, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63126, 'Agía Varvára', 'Agia Varvara', 'Agia Barbara,Agia Varvara,Agía Varvára,Ayia Varvara,Ayía Varvára,Αγία Βαρβάρα', 37.9893800, 23.6601100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63127, 'Agía Varvára', 'Agia Varvara', 'Agia Varvara,Agía Varvára,Ayia Varvara,Ayía Varvára,Αγία Βαρβάρα', 35.1371500, 25.0013100, 'GR', '2013-07-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63128, 'Agía Triáda', 'Agia Triada', 'Agia Triada,Agia Trias,Agía Triáda,Agía Triás,Ayia Stevenikon,Ayia Trias,Ayía Steveníkon,Ayía Triás,Stevenikon,Steveníkon,Αγία Τριάδα,Αγία Τριάς', 38.3550500, 22.9088100, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63129, 'Ayía Triás', 'Ayia Trias', 'Agia Triada,Ayia Trias,Ayía Triás,Merbakas,Mérbakas,Αγία Τριάδα', 37.6370700, 22.8050400, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63130, 'Agiásos', 'Agiasos', 'Agiasos,Agiásos,Ayiasissios,Ayiasos,Ayiassios,Ayiassos,Ayiásissios,Ayiásos,Ayiássios,Ayiássos,Αγιάσος', 39.0829500, 26.3721800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63131, 'Agía Paraskeví', 'Agia Paraskevi', 'Agia Paraskevi,Agía Paraskeví,Ayia Paraskevi,Ayía Paraskeví,Αγία Παρασκευή', 39.2479200, 26.2717800, 'GR', '2016-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63132, 'Agía Paraskeví', 'Agia Paraskevi', 'Agia Paraskeue,Agia Paraskevi,Agía Paraskeví,Ayia Paraskevi,Ayía Paraskeví,Αγία Παρασκευή', 38.0166700, 23.8333300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63133, 'Agía Marína', 'Agia Marina', 'Agia Marina,Agía Marína,Ayia Marina,Ayía Marína,Lero,Αγία Μαρίνα', 37.1543000, 26.8516200, 'GR', '2012-08-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63134, 'Agía Marína', 'Agia Marina', 'Agia Marina,Agía Marína,Ayia Marina,Ayía Marína,Αγία Μαρίνα', 35.5177800, 23.9267500, 'GR', '2015-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63135, 'Agía Galíni', 'Agia Galini', 'Agia Galini,Agía Galíni,Ayia Galini,Ayía Galíni,Αγία Γαλήνη', 35.0970700, 24.6881800, 'GR', '2013-05-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63136, 'Agiá', 'Agia', 'Agia,Agiá,Agyia,Ayia,Ayiá,Αγιά', 39.7190100, 22.7586900, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63137, 'Avlónas', 'Avlonas', 'Avlon,Avlona,Avlonas,Avlón,Avlónas,Kakosalesi,Kakosálesi,Salesi,Salisati,Sálesi,Αυλών,Αυλώνα,Αυλώνας,Κακοσάλεσι,Σάλεσι,Σαλισάτι', 38.2514900, 23.6955400, 'GR', '2015-11-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63138, 'Atsipópoulo', 'Atsipopoulo', 'Atsipopoulo,Atsipopoulon,Atsipópoulon,Atsotopoulon,Atsotópoulon,Ατσιπόπουλο,Ατσιπόπουλον', 35.3525300, 24.4337800, 'GR', '2015-11-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63139, 'Athens', 'Athens', 'ATH,Afina,Afini,Afiny,An Aithin,Ateena,Atehny,Aten,Atena,Atenai,Atenas,Atenas - Athena,Atenas - Αθήνα,Atene,Atenes,Ateni,Ateno,Atenoj,Ateny,Athen,Athena,Athenae,Athenai,Athene,Athenes,Athens,Atheny,Athina,Athinai,Athinia,Athènes,Athén,Athénes,Athény,Athína,Athínai,Atina,Atény,Atēnas,Atėnai,Aþena,Kota Athena,Lungsod ng Athina,Lungsod ng Athína,atene,atene si,ateni,athensa,athyna,atn,etens,xethens,ya dian,Αθήνα,Αθήναι,Αθηνα,Αθηναι,Атина,Атэны,Афины,Афіни,Аѳины,Աթենք,אתונה,آتن,أثينا,ئافېنا,ܐܬܝܢܐ,अथेन्स,ஏதென்ஸ்,เอเธนส์,ათენი,Ἀθῆναι,アテネ,雅典,아테네,아테네 시', 37.9794500, 23.7162200, 'GR', '2015-12-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63140, 'Athíkia', 'Athikia', 'Athikia,Athíkia,Αθίκια', 37.8167500, 22.9293900, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63141, 'Atalánti', 'Atalanti', 'Atalandi,Atalante,Atalanti,Atalándi,Atalánti,Αταλάντη', 38.6511100, 22.9991700, 'GR', '2014-09-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63142, 'Ástros', 'Astros', 'Astros,Ástros,Άστρος', 37.4039500, 22.7211800, 'GR', '2016-05-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63143, 'Astypálaia', 'Astypalaia', 'Astipalaia,Astipálaia,Astypalaea,Astypalaia,Astypálaia,Castello,JTY,Kastello,Kastéllo,Αστυπάλαια', 36.5500000, 26.3500000, 'GR', '2017-01-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63144, 'Astakós', 'Astakos', 'Astako,Astakos,Αστακός', 38.5355600, 21.0813500, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63145, 'Ássos', 'Assos', 'Assos,Ássos,Άσσος', 37.9395500, 22.8222300, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63146, 'Asprópyrgos', 'Aspropyrgos', 'Aspropirgos,Aspropyrgos,Asprópirgos,Asprópyrgos,Kalivia,Kalivia Khasias,Kalyvia Chasias,Kalívia,Kalívia Khasiás,Ασπρόπυργος,Καλύβια Χασιάς', 38.0613400, 23.5897100, 'GR', '2014-08-28', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63147, 'Asprángeloi', 'Asprangeloi', 'Asprangeli,Asprangeloi,Asprángeloi,Dovra,Dóvra,Ntovra,Ασπράγγελοι,Δοβρά,Ντοβρά', 39.8232800, 20.7286200, 'GR', '2015-03-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63148, 'Asopós', 'Asopos', 'Asopos,Asopós,Kondevianika,Kondeviánika,Ασωπός', 36.7298600, 22.8545500, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63149, 'Asopía', 'Asopia', 'Asopia,Asopía,Khlembotsarion,Khlembotsárion,Khlemvotzari,Ασωπία', 38.2988200, 23.5018900, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63150, 'Asíni', 'Asini', 'Asini,Assini,Assíni,Asíni,Ασίνη', 37.5443100, 22.8643500, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63151, 'Asímion', 'Asimion', 'Asemion,Asimi,Asimion,Asími,Asímion,Ασήμιον', 35.0432100, 25.0927700, 'GR', '2013-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63152, 'Argyroúpoli', 'Argyroupoli', 'Argyroupoli,Argyroupolis,Argyroúpoli,Aryiroupolis,Aryiroúpolis,Αργυρούπολη', 37.9059400, 23.7503500, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63153, 'Argyropoúli', 'Argyropouli', 'Argyropouleion,Argyropouli,Argyropoulion,Argyropoúli,Argyropoúlion,Aryiropoulion,Aryiropoúlion,Karatsoli,Karatsóli,Αργυροπούλειον,Αργυροπούλι,Αργυροπούλιον', 39.8256700, 22.3068900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63154, 'Artesianó', 'Artesiano', 'Artesiano,Artesianon,Artesianó,Artesianón,Pitsari,Pitsári,Αρτεσιανό,Αρτεσιανόν', 39.4019400, 21.8964900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63155, 'Árta', 'Arta', 'Arta,arta,Árta,Άρτα,Арта,آرتا', 39.1601400, 20.9856100, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63156, 'Árma', 'Arma', 'Arma,Dhritsa,Dhritsia,Dhrítsa,Eleon,Eleón,Árma,Άρμα', 38.3512100, 23.4859900, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63157, 'Archontochóri', 'Archontochori', 'Archontochori,Archontochorion,Archontochóri,Archontochórion,Arkhondokhori,Arkhondokhorion,Arkhondokhóri,Arkhondokhórion,Zavitsa,Zavítsa,Αρχοντοχώρι,Αρχοντοχώριον', 38.7005300, 21.0389600, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63158, 'Archaía Olympía', 'Archaia Olympia', 'Ancient Olympia,Archaia Olympia,Arkhaia Olimbia,Arkhaía Olimbía,Olimbia Arkhaia,Olimbía Arkhaía,Olimpija,Olymbia,Olymbía,Olympia,Olympie,Αρχαία Ολυμπία,Ολυμπια,Олимпия', 37.6478800, 21.6271000, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63159, 'Arkhaía Kórinthos', 'Arkhaia Korinthos', 'Ancient Corinth,Archaia Korinthos,Arkhaia Korinthos,Arkhaía Kórinthos,Korinthos,Kórinthos,Old Corinth,Palaia,Palaia Korinthos,Palaiá,Palaiá Kórinthos,Palia Korinthos,Αρχαία Κόρινθος,Παλαιά Κόρινθος,Παλιά Κόρινθος', 37.9095300, 22.8835300, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63160, 'Arkalochóri', 'Arkalochori', 'Arkalachorion,Arkalochori,Arkalochorion,Arkalochóri,Arkalochórion,Arkalokhori,Arkalokhorion,Arkalokhóri,Arkalokhórion,Αρκαλαχώριον,Αρκαλοχώρι,Αρκαλοχώριον', 35.1463400, 25.2653800, 'GR', '2013-07-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63161, 'Áris', 'Aris', 'Aris,Aslanaga,Aslánaga,Mesopotamia,Mesopotamiá,Áris,Άρις', 37.0992000, 22.0044300, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63162, 'Aria', 'Aria', 'Aria,Ária,Άρια', 37.5737200, 22.8353900, 'GR', '2014-07-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63163, 'Argostólion', 'Argostolion', 'Argostoli,Argostolion,Argostóli,Αργοστόλι,Αργοστόλιον', 38.1810900, 20.4890300, 'GR', '2014-07-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63164, 'Árgos', 'Argos', 'Argas,Argo,Argos,Ciutat d''Argos,a er ge si,Árgos,Άργος,Аргос,ארגוס,阿尔戈斯', 37.6333300, 22.7333300, 'GR', '2014-07-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63165, 'Argalastí', 'Argalasti', 'Argalasti,Argalastí,Αργαλαστή', 39.2262700, 23.2186800, 'GR', '2015-09-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63166, 'Arfará', 'Arfara', 'Arfara,Arfará,Arphara,Αρφαρά', 37.1561900, 22.0448500, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63167, 'Aráchova', 'Arachova', 'Arachova,Arajova,Arakhova,Aráchova,Arájova,Arákhova,Rachova,Αράχοβα,Αράχωβα,Ράχωβα', 38.4795800, 22.5835000, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63168, 'Anthiró', 'Anthiro', 'Antheron,Antherón,Anthiro,Anthiron,Anthiró,Anthirón,Bukovitsa,Bukovítsa,Ανθηρό', 39.3472200, 21.4583300, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63169, 'Anthíli', 'Anthili', 'Anthele,Anthili,Anthíli,Imir-Bei,Imír-Béï,Ανθήλη', 38.8500000, 22.4790600, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63170, 'Anógeia', 'Anogeia', 'Anogeia,Anoghia,Anogia,Anoyia,Anógeia,Anógia,Anóyia,Ανώγεια', 35.2908400, 24.8841200, 'GR', '2013-01-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63171, 'Áno Sýros', 'Ano Syros', 'Ano Siros,Ano Syra,Ano Syros,Siros,Syra,Syros,Síros,Áno Síros,Áno Sýros,Άνω Σύρος', 37.4499700, 24.9356200, 'GR', '2014-03-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63172, 'Áno Merá', 'Ano Mera', 'Ano Mera,Áno Merá,Άνω Μερά', 37.4490400, 25.3909500, 'GR', '2015-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63173, 'Áno Liósia', 'Ano Liosia', 'Ano Liosia,Áno Liósia,Άνω Λιόσια', 38.0833300, 23.7000000, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63174, 'Áno Lekhónia', 'Ano Lekhonia', 'Ano Lechonia,Άνω Λεχώνια', 39.3276300, 23.0539500, 'GR', '2015-01-15', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63175, 'Kopanáki', 'Kopanaki', 'Ano Kopanaki,Ano Kopanakion,Epano Kopanaki,Epáno Kopanáki,Kopanaki,Kopanakion,Kopanáki,Kopanákion,Áno Kopanáki,Áno Kopanákion,Κοπανάκι,Κοπανάκιον', 37.2891300, 21.8185400, 'GR', '2016-07-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63176, 'Áno Kastrítsi', 'Ano Kastritsi', 'Ano Kastritsi,Ano Kastritsion,Kastritsi,Kastrítsi,Áno Kastrítsi,Áno Kastrítsion,Άνω Καστρίτσι,Άνω Καστρίτσιον', 38.2722800, 21.8360000, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63177, 'Áno Kalentíni', 'Ano Kalentini', 'Ano Kalendini,Ano Kalentini,Kalendini,Kalendíni,Áno Kalendíni,Áno Kalentíni,Άνω Καλεντίνη', 39.2500000, 21.1852800, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63178, 'Anoixi', 'Anoixi', 'Anixi,Anoixi,Anoixis,Boyati,Boyiati,Boyiáti,Boyáti,Oion,Oíon,Palaion Boyati,Palaion Boyation,Palaión Boyáti,Palaión Boyátion,Ánoixis,Άνοιξη,Άνοιξις', 38.1326700, 23.8587400, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63179, 'Megalochóri', 'Megalochori', 'Agkistri,Agkistrion,Agkístri,Agkístrion,Angistri,Angistrion,Angístri,Angístrion,Ankistri,Ankistrion,Megalochori,Megalohori,Megalokhori,Megalokhóri,Milos,Mylos,Αγκίστρι,Αγκίστριον,Μεγαλοχώρι,Μύλος', 37.7105100, 23.3465900, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63180, 'Angelókastro', 'Angelokastro', 'Angelokastro,Angelokastron,Angelókastro,Angelókastron,Αγγελόκαστρο,Αγγελόκαστρον', 38.5658500, 21.2963100, 'GR', '2014-10-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63181, 'Anéza', 'Aneza', 'Aneza,Anéza,Ανέζα', 39.0865800, 20.9230000, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63182, 'Andros', 'Andros', 'ANDROU,Andros,Kastron,Kástron,Άνδρος,ΑΝΔΡΟΥ', 37.8333300, 24.9333300, 'GR', '2016-03-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63183, 'Andravída', 'Andravida', 'Andrabida,Andravidha,Andravídha,Andrvida,Ανδραβίδα', 37.9058800, 21.2693600, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63184, 'Antirrio', 'Antirrio', 'Andirio,Andirrio,Andirrion,Andírio,Andírrion,Antirhion,Antirio,Antirion,Antirrhium,Antirrio,Antirrio Aitoloakarnanias,Antirrion,Antírrio,antyryw,Αντίρριο,Αντίρριο Αιτωλοακαρνανίας,Антіріо,أنتيريو', 38.3301400, 21.7641300, 'GR', '2014-06-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63185, 'Antíparos', 'Antiparos', 'Andiparos,Andíparos,Antiparos,Antíparos,Kastro,Kástro,Αντίπαρος', 37.0333300, 25.0833300, 'GR', '2012-11-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63186, 'Antimácheia', 'Antimacheia', 'Andemaki,Andimakhia,Andimákhia,Antimacheia,Antimachia,Antimakhia,Antimácheia,Αντιμάχεια', 36.8088800, 27.0976400, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63187, 'Antikyra', 'Antikyra', 'Andikira,Andikíra,Antikyra,Αντίκυρα,Αντικύρα', 38.3833300, 22.6333300, 'GR', '2015-09-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63188, 'Anávra', 'Anavra', 'Anabra,Anavra,Anávra,Chamasi,Chamási,Tsamasi,Tsamási,Ανάβρα', 39.1899600, 22.0930800, 'GR', '2014-09-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63189, 'Anávyssos', 'Anavyssos', 'Anaflystos,Anavissos,Anavyssos,Anáflystos,Anávissos,Anávyssos,Ανάβυσσος,Ανάφλυστος', 37.7341400, 23.9438900, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63190, 'Anatolí', 'Anatoli', 'Anatoli,Anatolí,Ανατολή', 39.6353100, 20.8657800, 'GR', '2015-03-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63191, 'Anáfi', 'Anafi', 'Anafi,Anaphe,Anaphi,Anáfi,Khora,Khóra,Ανάφη', 36.3500000, 25.7666700, 'GR', '2016-12-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63192, 'Amorgós', 'Amorgos', 'Amorgos,Amorgós,Kastro,Kastron,Khora,Khóra,Αμoργός', 36.8317500, 25.8982100, 'GR', '2014-07-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63193, 'Ámfissa', 'Amfissa', 'Amfissa,Ámfissa,Άμφισσα', 38.5281300, 22.3771300, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63194, 'Amfilochía', 'Amfilochia', 'Amfilochia,Amfilochía,Amfilokhia,Amfilokhía,Amphilochia,Karvasaras,Karvasarás,Αμφιλοχία', 38.8594400, 21.1663900, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63195, 'Amfíkleia', 'Amfikleia', 'Amfikleia,Amfiklia,Amfíkleia,Amfíklia,Amphicleia,Dadi,Dadion,Dhadhion,Dhadhíon,Αμφίκλεια,Δαδί,Δαδίον', 38.6391200, 22.5917100, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63196, 'Ampelóna', 'Ampelona', 'Ambelon,Ambelón,Ampelon,Ampelona,Ampelóna,Kazaklar,Kazaklár,Αμπελόνα,Αμπελών', 39.7448100, 22.3657500, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63197, 'Ambelókipoi', 'Ambelokipoi', 'Ambelokipoi,Ambelókipoi,Ampelokepoi,Ampelokipoi,Roidhon,Róïdhon,Αμπελόκηποι', 37.7580900, 20.8724800, 'GR', '2014-06-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63198, 'Ampelákia', 'Ampelakia', 'Ambelaki,Ambelakia,Ambeláki,Ambelákia,Ampelakia,Ampelákia,Αμπελάκια', 37.9505500, 23.5280300, 'GR', '2016-01-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63199, 'Maroúsi', 'Marousi', 'Amarousio,Amarousion,Amaroúsion,Marousi,Maroussi,Maroúsi,Αμαρούσιον,Μαρούσι', 38.0500000, 23.8000000, 'GR', '2014-12-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63200, 'Amárynthos', 'Amarynthos', 'Amarinthos,Amarynthos,Amárinthos,Amárynthos,Kato Vathia,Káto Váthia,Αμάρυνθος', 38.3930000, 23.8849200, 'GR', '2015-01-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63201, 'Amaliáda', 'Amaliada', 'Amaliada,Amalias,Amaliáda,Amaliás,Αμαλιάδα,Αμαλιάς', 37.7984200, 21.3506800, 'GR', '2015-09-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63202, 'Almyrós', 'Almyros', 'Almiros,Almirós,Almyros,Almyrós,Αλμυρός', 39.1822200, 22.7594400, 'GR', '2014-06-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63203, 'Álli Meriá', 'Alli Meria', 'Alli Meria,Álli Meriá,Άλλη Μεριά', 39.3703900, 22.9835000, 'GR', '2015-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63204, 'Alivéri', 'Aliveri', 'Aliberion,Aliveri,Aliverion,Alivéri,Alivérion,Αλιβέρι,Αλιβέριον', 38.4166700, 24.0333300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63205, 'Alíartos', 'Aliartos', 'Aliartos,Alíartos,Krimbas,Krimbás,Moulki,Moulkion,Moúlki,Moúlkion,Αλίαρτος,Μούλκιον', 38.3666700, 23.1000000, 'GR', '2012-11-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63206, 'Alfeioúsa', 'Alfeiousa', 'Alfeiousa,Alfeioúsa,Alfiousa,Alfioúsa,Volantza,Volántza,Αλφειούσα', 37.6401900, 21.5375000, 'GR', '2015-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63207, 'Akráta', 'Akrata', 'Akrata,Akráta,Ακράτα', 38.1546900, 22.3183000, 'GR', '2014-06-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63208, 'Akraifnía', 'Akraifnia', 'Akraifnia,Akraifnion,Akraifnía,Akraiphnion,Akraífnion,Kardhitsa,Kardhítsa,Ακραίφνιον,Ακραιφνία', 38.4566300, 23.2209300, 'GR', '2015-11-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63209, 'Acharnés', 'Acharnes', 'Acharnae,Acharnai,Acharne,Acharnes,Akharnai,Akharnaí,Menidhi,Menidhion,Menidi,Menidion,Menioi,Menídhi,Menídhion,Meníoi,Αχαρνές,Αχαρναί,Μενίδι,Μενίδιον', 38.0833300, 23.7333300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63210, 'Aíyira', 'Aiyira', 'Aigeira,Aivira,Aiyira,Aívira,Aíyira,Αιγείρα', 38.1484600, 22.3542600, 'GR', '2014-06-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63211, 'Aígio', 'Aigio', 'Aegion,Aegium,Aighion,Aigio,Aigion,Aiyion,Aígio,Aígion,Aíyion,Egion,Ehjo,Vostitsa,Vostitza,Vostizza,Vostítsa,Αίγιο,Αίγιον,Αἴγιον,Βοστίτσα,Эйо', 38.2486100, 22.0819400, 'GR', '2015-05-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63212, 'Aegina', 'Aegina', 'Aegina,Aigina,Aiyina,Aígina,Aíyina,Egina,Αίγινα', 37.7466700, 23.4275000, 'GR', '2014-11-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63213, 'Aitolikó', 'Aitoliko', 'Aetoliko,Aitoliko,Aitolikon,Aitolikó,Aitolikón,Etolikon,Αιτωλικό,Αιτωλικόν', 38.4370400, 21.3535800, 'GR', '2015-07-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63214, 'Aigáleo', 'Aigaleo', 'Aegaleo,Aigaleo,Aigáleo,Egaleo,Αιγάλεω', 37.9833300, 23.6833300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63215, 'Aidipsós', 'Aidipsos', 'Aedipsos,Aidhipsos,Aidhipsou,Aidhipsoú,Aidhipsós,Aidipsos,Aidipsós,Edepso,Edipsos,Ehdipsos,Αιδηψός,Едіпсос,Эдипсос', 38.8792400, 23.0469100, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63216, 'Aiánteio', 'Aianteio', 'Aiandion,Aianteio,Aianteion,Aiantion,Aiándion,Aiánteion,Aiántion,Moulki,Moúlki,Αιάντειο,Αιάντειον', 37.9213500, 23.4587700, 'GR', '2014-09-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63217, 'Agrínio', 'Agrinio', 'AGQ,Agrinio,Agrinion,Agrinium,Agrínio,Agrínion,Αγρίνιο,Αγρίνιον,Агринион', 38.6213900, 21.4077800, 'GR', '2017-01-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63218, 'Agriá', 'Agria', 'Agria,Agriá,Αγριά', 39.3407800, 23.0125800, 'GR', '2015-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63219, 'Agnanteró', 'Agnantero', 'Agnanderon,Agnanderón,Agnantero,Agnanteron,Agnanteró,Agnanterón,Mesdanion,Mesdhani,Mesdháni,Mesdánion,Αγναντερό,Αγναντερόν', 39.4858600, 21.8478900, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63220, 'Afrátion', 'Afration', 'Afrati,Afration,Afráti,Afrátion,Αφράτι,Αφράτιον', 38.4521200, 23.6877500, 'GR', '2015-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63221, 'Afidnés', 'Afidnes', 'Afidhnai,Afidnai,Afidnes,Afidni,Afidnés,Afídhnai,Kiourka,Kioúrka,Αφίδναι,Αφίδνες,Αφίδνη,Αφιδνές,Κιούρκα', 38.2033200, 23.8398200, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63222, 'Adámas', 'Adamas', 'Adamantas,Adamas,Adhamas,Adhámas,Adámas,Αδάμαντας,Αδάμας,Адамас', 36.7250600, 24.4468500, 'GR', '2015-05-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63223, 'Ródos', 'Rodos', 'RHO,Rhodes,Rhodes Town,Rhodos,Rodas,Rodes,Rodhos,Rodi,Rodos,Rodos Town,Ródhos,Ródos,Ρόδος,Родос', 36.4355600, 28.2219900, 'GR', '2017-07-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63224, 'Néa Alikarnassós', 'Nea Alikarnassos', 'Alikarnassos,Alikarnassós,Nea Alikarnasos,Nea Alikarnassos,Néa Alikarnassós,Néa Alikarnasós,Νέα Αλικαρνασσός', 35.3397700, 25.1589500, 'GR', '2013-01-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63225, 'Kremastí', 'Kremasti', 'Kremaste,Kremasti,Kremastí,Κρεμαστή', 36.4098100, 28.1192000, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63226, 'Afántou', 'Afantou', 'Afandou,Afándou,Aphantou,Αφάντου', 36.2935400, 28.1622500, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63227, 'Archángelos', 'Archangelos', 'Archangelos,Arkhangelos,Arkhángelos,Αρχάγγελος', 36.2149200, 28.1148700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63228, 'Lárdos', 'Lardos', 'Lardos,Lárdos,Λάρδος,Лардос', 36.0941900, 28.0156500, 'GR', '2015-08-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63229, 'Zipári', 'Zipari', 'Zeparion,Zipari,Ziparion,Zipári,Zipárion,Ζηπάριον,Ζιπάρι,Ζιπάριον', 36.8769600, 27.2053200, 'GR', '2016-11-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63230, 'Néos Oropós', 'Neos Oropos', 'Neos Oropos,Néos Oropós,Νέος Όρωπός,Νέος Ωρωπός', 39.1506400, 20.7363600, 'GR', '2014-07-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63231, 'Zygós', 'Zygos', 'Zigos,Zigós,Zygos,Zygós,Ζυγός', 41.0132000, 24.3813200, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63232, 'Akrolímni', 'Akrolimni', 'Akrolimni,Akrolímni,Golo-Selo,Gymna,Gymná,Gólo-Sélo,Yimna,Yimná,Ακρολίμνη', 40.6802000, 22.2645000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63233, 'Giannitsá', 'Giannitsa', 'Giannitsa,Giannitsá,Janica,Yannitsa,Yenitsa,Yenitsá,Yiannitsa,Yiannitsá,Γιαννιτσά,Яница', 40.7919400, 22.4075000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63234, 'Gerakaroú', 'Gerakarou', 'Gerakarou,Yerakarou,Γερακαρού', 40.6266600, 23.2156600, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63235, 'Genisséa', 'Genissea', 'Genisea,Genissea,Genisséa,Yenidje,Yenidze,Yenisaia,Yenisaía,Yenisea,Yeniséa,Yenje Karasu,Γενισέα,Γενισσέα', 41.0616500, 24.9624800, 'GR', '2017-01-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63236, 'Géfyra', 'Gefyra', 'Gefyra,Géfyra,Topsin,Topsín,Yefira,Yéfira,Γέφυρα', 40.7325300, 22.6935900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63237, 'Xiropótamos', 'Xiropotamos', 'Visotsani,Visotsáni,Xiropotamos,Xiropótamos,Ξηροπόταμος', 41.1920600, 24.1038500, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63238, 'Xinó Neró', 'Xino Nero', 'Ano Vermpiani,Ekshi Su,Exi Sou,Exi Su,Exí Su,Gorno Vurbeni,Ksino Nero,Nkorno Varmpiani,Xino Nero,Xinon Neron,Xinó Neró,Xinón Nerón,Άνω Βέρμπιανη,Γκόρνο Βάρμπιανη,Εξί Σου,Ξινό Νερό,Ξινόν Νερόν,Горно Върбени,Екши Су,Ксин̀о Нер̀о', 40.6902800, 21.6232400, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63239, 'Xilópolis', 'Xilopolis', 'Lingovani,Lingováni,Xylopolis,Ξυλόπολις', 40.9271300, 23.1794400, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63240, 'Xylaganí', 'Xylagani', 'Xilagani,Xilaganí,Xylagani,Xylaganí,Ξυλαγανή', 40.9743700, 25.4202200, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63241, 'Xánthi', 'Xanthi', 'Eskije,Ksanti,Skecha,Xanthe,Xanthi,Xanthē,Xánthi,Ξάνθη,Ксанти', 41.1348800, 24.8880000, 'GR', '2017-01-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63242, 'Vrontoú', 'Vrontou', 'Kalivia Vrondous,Kalívia Vrondoús,Vrondou,Vrondoú,Vrondu,Vrontou,Vrontoú,Βροντού', 40.1935600, 22.4320300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63243, 'Vólakas', 'Volakas', 'Bolax,Volakas,Volax,Vólakas,Vólax,Βώλακας,Βώλαξ', 41.3166100, 24.0021500, 'GR', '2017-02-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63244, 'Vergína', 'Vergina', 'AEges,Kutles,Kutlesh,Kútles,Verghina,Vergina,Vergína,Veria,Veryina,Veryína,vu~erugina,Æges,Βεργίνα,Вергина,Кутлеш,ヴェルギナ', 40.4865400, 22.3173500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63245, 'Véroia', 'Veroia', 'Verija,Veroia,Verroia,Véroia,Vérroia,Βέροια,Верия', 40.5243700, 22.2024200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63246, 'Velventós', 'Velventos', 'Velvendhos,Velvendhós,Velvendo,Velvendos,Velvendós,Velventos,Velventós,Βελβεντός', 40.2553200, 22.0754300, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63247, 'Vathýlakkos', 'Vathylakkos', 'Vathilakkon,Vathilakkos,Vathylakkos,Vathílakkon,Vathílakkos,Vathýlakkos,Βαθύλακκος', 40.7694200, 22.7088000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63248, 'Vasiliká', 'Vasilika', 'Basilika,Vasilika,Vasiliká,Βασιλικά', 40.4796600, 23.1369500, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63249, 'Vamvakófyto', 'Vamvakofyto', 'Saviako,Saviakon,Saviákon,Vainvakofiton,Vainvakófiton,Vamvakofiton,Vamvakofyto,Vamvakofyton,Vamvakófiton,Vamvakófyto,Vamvakófyton,Βαμβακόφυτο,Βαμβακόφυτον,Σάβιακο', 41.1791600, 23.3960200, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63250, 'Valteró', 'Valtero', 'Barakli,Baraklí,Valtero,Valteron,Valteró,Valterón,Βαλτερό,Βαλτερόν', 41.1792700, 23.3202200, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63251, 'Tsotíli', 'Tsotili', 'Tsotili,Tsotilion,Tsotíli,Tsotílion,Τσοτίλι,Τσοτίλιον', 40.2614700, 21.3253300, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63252, 'Trílofos', 'Trilofos', 'Spates,Trilofo,Trilofon,Trilofos,Trílofo,Trílofon,Zomvatoi,Zoumbates,Zoumbátes,Zoumpat,Zoumpates,Ζομβάτοι,Ζουμπάτ,Ζουμπάτες,Σπάτες,Τρίλοφο,Τρίλοφον,Τρίλοφος', 40.4689800, 22.9718000, 'GR', '2015-01-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63253, 'Tríkala', 'Trikala', 'Trikala,Trikkala,Tríkala,Tríkkala,Τρίκαλα,Трикала', 40.5981400, 22.5573300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63254, 'Tycheró', 'Tychero', 'Tikheron,Tikherón,Tikhion,Tychero,Tycheron,Tycheró,Tycherón,Tíkhion,Τυχερό,Τυχερόν', 41.0287800, 26.2945500, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63255, 'Thessaloníki', 'Thessaloniki', 'Ftohomana,Ftohomána,I Protevoussa ton Prosfigon,I Protévoussa ton Prosfígon,SKG,Salonic,Salonica,Salonicco,Salonik,Salonika,Salonikai,Salonike,Saloniki,Salonique,Saloníki,Saluniccu,Salónica,Saruna,Selanik,Selânik,Solun,Soluň,Solún,Săruna,THessalonika,Tesalonica,Tesaloniki,Tesalonîkî,Tesalónica,Tessalonica,Tessalònica,Thessalonica,Thessalonike,Thessaloniki,Thessalonique,Thessaloníki,Thessaloníkē,sai sa luo ni ji,salwnyk,slwnyqh,slwnyqy,tessaroniki,Þessalóníka,Θεσσαλονίκη,Σαλονίκη,Σαλονικη,Салоники,Салоніки,Солун,Ѳessalonika,Ѳєссалонїка,סלוניקה,סלוניקי,سالونيك,テッサロニキ,塞萨洛尼基', 40.6436100, 22.9308600, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63256, 'Thérmi', 'Thermi', 'Sedes,Sedhes,Sédhes,Thermi,Thérmi,Θέρμη', 40.5471200, 23.0196700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63257, 'Thásos', 'Thasos', 'Limenas Thasou,Limin,Limín,Thasas,Thasos,Thassos,Thásos,Θάσος,Λιμένας Θάσου', 40.7780600, 24.7094400, 'GR', '2014-08-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63258, 'Terpní', 'Terpni', 'Chernishha,Cherpishha,Cherpishta,Cherpista,Cherpísta,Terpni,Terpní,Tserpista,Tsiarpista,Τερπνή,Τσερπίστα,Τσιαρπίστα,Чернища,Черпишта,Черпища', 40.9164300, 23.4813700, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63259, 'Svorónos', 'Svoronos', 'Kolokouri,Kolokourion,Kolokoúri,Kolokoúrion,Svoronos,Svorónos,Σβορώνος', 40.2680500, 22.4636600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63260, 'Strymonikó', 'Strymoniko', 'Orliakon,Strimonikon,Strimonikón,Strymoniko,Strymonikon,Strymonikó,Strymonikón,Órliakon,Στρυμονικό,Στρυμονικόν', 41.0414400, 23.3148700, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63261, 'Stratónion', 'Stratonion', 'Stratoni,Stratonion,Στρατώνι,Στρατώνιον,Стратони', 40.5140600, 23.8247100, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63262, 'Stavroúpoli', 'Stavroupoli', 'Stavroupoli,Stavroupolis,Stavroúpoli,Stavroúpolis,Σταυρούπολη', 40.6694400, 22.9380600, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63263, 'Stavrós', 'Stavros', 'Kato Stavros,Káto Stavrós,Stavros,Stavrós,Σταυρός', 40.6649800, 23.7001500, 'GR', '2016-12-16', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63264, 'Stavrós', 'Stavros', 'Stavros,Stavrós,Σταυρός', 40.5893900, 22.3086100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63265, 'Sourotí', 'Souroti', 'Sourote,Souroti,Sourotí,Σουρωτή', 40.4727400, 23.0919700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63266, 'Souflí', 'Soufli', 'Soflu,Sofulu,Soufli,Souflion,Souflí,Souflíon,Souphlion,Σουφλί,Σουφλίον,Софлу', 41.1919400, 26.2994400, 'GR', '2016-06-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63267, 'Sosándra', 'Sosandra', 'Prebodhista,Prebódhista,Sosandhra,Sosandra,Sossandra,Sosándhra,Sosándra,Σωσάνδρα', 40.9989400, 22.0325400, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63268, 'Sochós', 'Sochos', 'Sochos,Sochós,Sokhos,Sokhós,Zokhos,Zokhós,Σοχός', 40.8178800, 23.3554600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63269, 'Smínthi', 'Sminthi', 'Sminthi,Smínthi,Σμίνθη', 41.2333300, 24.8666700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63270, 'Skoútari', 'Skoutari', 'Kiopeki,Kopeki,Kopekí,Skoutari,Skoútari,Κιοπεκή,Σκούταρι', 41.0187100, 23.5197100, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63271, 'Skotoússa', 'Skotoussa', 'Prosenik,Prosnik,Prósnik,Skotousa,Skotoussa,Skotoúsa,Skotoússa,Skotusa,Σκοτούσα,Σκοτούσσα,Просеник,Скотуса', 41.1284400, 23.3817400, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63272, 'Skýdra', 'Skydra', 'Skhidra,Skhídra,Skidhra,Skydra,Skídhra,Skýdra,Vertekop,Vertekóp,Σκύδρα', 40.7672200, 22.1519400, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63273, 'Leptokaryá', 'Leptokarya', 'Leptokarja,Leptokarya,Leptokaryá,Skala Leptokarias,Skala Leptokaryas,Skála Leptokariás,Skála Leptokaryás,Λεπτοκαρυά', 40.0603200, 22.5612000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63274, 'Sitagroí', 'Sitagroi', 'Minare Chiflik,Minaré Chiflík,Sitagroi,Sitagroí,Σιταγροί', 41.1106700, 24.0275500, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63275, 'Síndos', 'Sindos', 'Sindhos,Sindos,Síndhos,Síndos,Tekeli,Tekelí,Σίνδος', 40.6704500, 22.8054500, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63276, 'Sykiá', 'Sykia', 'Sikea,Sikia,Sikiá,Sikéa,Sykea,Sykia,Sykiá,Συκέα,Συκιά', 40.0387400, 23.9404600, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63277, 'Sykiés', 'Sykies', 'Sikeai,Sikéai,Sykeai,Sykies,Sykiés,Sykéai,Συκιές', 40.6494400, 22.9508300, 'GR', '2014-01-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63278, 'Sidirókastro', 'Sidirokastro', 'Sideorastron,Sidhirokastron,Sidhirókastron,Sidirokastro,Sidirokastron,Sidirókastro,Sidirókastron,Σιδηρόκαστρο,Σιδηρόκαστρον', 41.2349900, 23.3889900, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63279, 'Siátista', 'Siatista', 'Khora,Khóra,Siatista,Siátista,Σιάτιστα', 40.2619400, 21.5441700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63280, 'Sfendámi', 'Sfendami', 'Paliani,Páliani,Sfendami,Sfendamion,Sfendhami,Sfendhamion,Sfendhámi,Sfendhámion,Sfendámi,Sfendámion,Stendhami,Stendhámi,Σφενδάμι,Σφενδάμιον', 40.4130700, 22.5467700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63281, 'Sevastianá', 'Sevastiana', 'Sevastiana,Sevastianá,Σεβαστιανά', 40.7687400, 22.1234600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63282, 'Sérvia', 'Servia', 'Selfije,Servia,Sérvia,Σέρβια', 40.1797200, 21.9944400, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63283, 'Sérres', 'Serres', 'Ser,Seres,Serez,Serra,Serrae,Serrai,Serre,Serres,Serrès,Sjar,Szeresz,Széresz,Sérrai,Sérres,Sѣru,sai lei,seleseu,seres,seresu,Σέρρα,Σέρραι,Σέρρες,Сер,Серре,Серрес,Сяр,Сѣръ,סֶרֶס,セレス,塞雷,세레스', 41.0849900, 23.5475700, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63284, 'Sélero', 'Selero', 'Goekceler,Gökçeler,Selero,Seleron,Sélero,Séleron,Σέλερο,Σέλερον', 41.1338200, 24.9940800, 'GR', '2017-01-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63285, 'Sárti', 'Sarti', 'Nea Afisia,Nea Afissia,Néa Afisiá,Néa Afissiá,Sarti,Sárti,Νέα Αφησιά,Σάρτη,Сарти', 40.0936900, 23.9785900, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63286, 'Sápes', 'Sapes', 'Sapai,Sapes,Sappai,Sápai,Sápes,Σάπαι,Σάπες', 41.0286100, 25.6930600, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63287, 'Samothráki', 'Samothraki', 'Samothrace,Samothracia,Samothrake,Samothraki,Samothrakē,Samothráki,Σαμοθράκη', 40.4733300, 25.5222200, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63288, 'Rodolívos', 'Rodolivos', 'Radoliovo,Radulevo,Rodholivos,Rodholívos,Rodoleivos,Rodolivos,Rodolívos,Ροδολίβος,Ροδολείβος,Радолиово,Радулево', 40.9205500, 23.9748900, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63289, 'Rizó', 'Rizo', 'Rizo,Rizon,Rizovon,Rizó,Rizón,Rízovon,Ριζό,Ριζόν', 40.7333100, 22.1367400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63290, 'Rizómata', 'Rizomata', 'Bostiani,Bóstiani,Rizomata,Rizómata,Ριζώματα', 40.3506100, 22.2107900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63291, 'Rízia', 'Rizia', 'Rizia,Rízia,Ρίζια', 41.6249000, 26.4277100, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63292, 'Rizári', 'Rizari', 'Orizarion,Orizárion,Rizari,Rizario,Rizarion,Rizári,Rizário,Rizárion,Ριζάρι,Ριζάριον', 40.7837300, 22.0880000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63293, 'Ritíni', 'Ritini', 'Rendini,Rendíni,Ritini,Ritíni,Ρητίνη', 40.2883500, 22.2836100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63294, 'Péfka', 'Pefka', 'Pefka,Péfka,Rendziki,Rendzíki,Rentzikion,Rentzíkion,Retziki,Retzikion,Retzíki,Retzíkion,Πεύκα,Ρετζίκι', 40.6580600, 22.9937800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63295, 'Ptolemaḯda', 'Ptolemaida', 'Kailar,Kailaria,Kajlar,Kajljari,Kayilar,Kayılar,Kaïlária,Ptolemaida,Ptolemaidha,Ptolemais,Ptolemak,Ptolemaída,Ptolemaḯda,Ptolemaḯs,Ptolemeda,Πτολεμαΐδα,Кайляри,Кајлар,Птолемаида,Птолемеда', 40.5147200, 21.6786100, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63296, 'Fteliá', 'Ftelia', 'Eftelia,Efteliá,Ftelia,Fteliá,Ptelea,Pteléa,Φτελιά', 41.0826600, 24.1896800, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63297, 'Provatás', 'Provatas', 'Geni Kioi,Genikio,Neochori,Provatas,Provatás,Yenikoi,Yeníkoï,Γενή Κιόι,Γενίκιο,Νεοχώρι,Προβατάς', 41.0682500, 23.3903000, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63298, 'Próti', 'Proti', 'Kioupkioi,Kjupk''oj,Kup Koi,Kup Koj,Kup Kóï,Kupkoj,Proti,Próti,Κιούπκιοϊ,Πρώτη,Ќуп Ќој,Ќупќој,Кюпкьой,Проти', 40.9441100, 24.0011800, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63299, 'Prosotsáni', 'Prosotsani', 'Pirsopolis,Pirsópolis,Prosotsane,Prosotsani,Prosotsáni,Προσοτσάνη', 41.1833300, 23.9666700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63300, 'Prómachoi', 'Promachoi', 'Bachovo,Bakhovon,Bákhovon,Promachoi,Promakho,Promakhoi,Prómachoi,Prómakho,Prómakhoi,Μπάχοβο,Πρόμαχοι', 41.0251700, 22.0043700, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63301, 'Próchoma', 'Prochoma', 'Doganji,Doganjí,Prochoma,Prokhoma,Próchoma,Prókhoma,Πρόχωμα', 40.7982600, 22.6665900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63302, 'Profítis Ilías', 'Profitis Ilias', 'Profitis Ilias,Profítis Ilías,Προφήτης Ηλίας', 40.8137300, 22.1616600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63303, 'Potamiá', 'Potamia', 'Potamia,Ποταμιά', 40.7163300, 24.7285900, 'GR', '2014-08-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63304, 'Portariá', 'Portaria', 'Portaria,Portariá,Potaria,Πορταριά,Ποταριά', 40.2840500, 23.2954900, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63305, 'Pontisméno', 'Pontismeno', 'Ernikoi,Erníkoï,Pondismenon,Pondisménon,Pontismeno,Pontismenon,Pontisméno,Pontisménon,Ποντισμένο,Ποντισμένον', 41.2088500, 23.2832500, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63306, 'Polýgyros', 'Polygyros', 'Derigovo,Piliyiros,Pilíyiros,Poligero,Poligiros,Poliiros,Polijiros,Poliyiros,Polygyros,Polyjyros,Polígiros,Políyiros,Polýgyros,Polýjyros,bo li yi luo si,polliiloseu,porigirosu,Πολύγυρος,Деригово,Полигеро,Полигирос,Полийирос,Поліїрос,ポリギロス,波利伊罗斯,폴리이로스', 40.3770400, 23.4413500, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63307, 'Políchni', 'Polichni', 'Karaisin,Karaïsín,Polikhni,Políkhni,Полихни', 40.6667100, 22.9488100, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63308, 'Polýkastro', 'Polykastro', 'Karasouli,Karasoúli,Mavrosouli,Mavrosoúli,Policastron,Polikastron,Polykastro,Polykastron,Políkastron,Polýkastro,Polýkastron,Πολύκαστρο,Πολύκαστρον', 40.9944400, 22.5690900, 'GR', '2014-01-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63309, 'Polykárpi', 'Polykarpi', 'Poliani,Polikarpi,Polikarpion,Polikárpi,Polikárpion,Polykarpi,Polykarpion,Polykárpi,Polykárpion,Póliani,Πολυκάρπι,Πολυκάρπιον', 40.9259800, 22.0163400, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63310, 'Plagiári', 'Plagiari', 'Plagiari,Plagiarion,Plagiári,Plagiárion,Playiari,Playiarion,Playiári,Playiárion,Uzun-Ali,Uzún-Alí,Πλαγιάρι,Πλαγιάριον', 40.4727600, 22.9579000, 'GR', '2015-01-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63311, 'Platý', 'Platy', 'Plati,Platy,Platí,Platý,Πλατύ', 40.6424100, 22.5345800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63312, 'Platanórevma', 'Platanorevma', 'Orta-Koi,Ortá-Kóï,Platanorema,Platanorevma,Platanorrevma,Platanórema,Platanórevma,Platanórrevma,Πλατανόρευμα', 40.2008300, 22.0248800, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63313, 'Chalástra', 'Chalastra', 'Chalastra,Chalástra,Khalastra,Khalástra,Kouloukia,Kouloúkia,Pirgos,Pyrgos,Pírgos,Pýrgos,Χαλάστρα,Пиргос', 40.6264300, 22.7329100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63314, 'Pylaía', 'Pylaia', 'Kapoutsidhes,Kapoutsídhes,Pilaia,Pilaía,Pilea,Pylaia,Pylaía,Strefa,Stréfa,Πυλαία,Пилеа', 40.5991800, 22.9861300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63315, 'Petroússa', 'Petroussa', 'Petrousa,Petroussa,Petroúsa,Petroússa,Plevna,Plévna,Πετρούσσα', 41.1947000, 24.0173100, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63316, 'Petrochóri', 'Petrochori', 'Eriki,Eríki,Kayalar,Kayalár,Petrochori,Petrochorion,Petrochóri,Petrochórion,Petrokhori,Petrokhorion,Petrokhóri,Petrokhórion,Πετροχώρι,Πετροχώριον', 41.0874200, 24.8409200, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63317, 'Peteinós', 'Peteinos', 'Peteinos,Peteinós,Petinos,Petinós,Πετεινός', 41.1005600, 24.8984700, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63318, 'Peristerá', 'Peristera', 'Peristera,Peristerá,Περιστερά', 40.5488100, 23.1654000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63319, 'Perístasi', 'Peristasi', 'Peristasi,Peristasis,Perístasi,Perístasis,Περίσταση,Περίστασις', 40.2744300, 22.5416400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63320, 'Peraía', 'Peraia', 'Peraia,Peraía,Περαία', 40.4987400, 22.9261700, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63321, 'Péplos', 'Peplos', 'Peplos,Péplos,Πέπλος', 40.9575500, 26.2657700, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63322, 'Pentaplátano', 'Pentaplatano', 'Pendaplatanon,Pendaplátanon,Pentaplatano,Pentaplatanon,Pentaplátano,Pentaplátanon,Pilorik,Piloriyi,Piloriyion,Pilorík,Piloríyi,Piloríyion,Πενταπλάτανο,Πενταπλάτανον', 40.8190200, 22.4190300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63323, 'Pentálofos', 'Pentalofos', 'Gradhemborion,Gradhembórion,Pendalofos,Pendálofos,Pentalofos,Pentálofos,Πεντάλοφος', 40.7429600, 22.8525600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63324, 'Pélla', 'Pella', 'Archaia Pella,Pela,Pella,Pélla,Αρχαία Πέλλα,Πέλλα,Пела,Пелла', 40.7616900, 22.5263700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63325, 'Pedinó', 'Pedino', 'Hasan Obasi,Hasán Óbasi,Pedhinon,Pedhinón,Pedino,Pedinon,Pedinó,Pedinón,Πεδινό,Πεδινόν', 40.9101300, 22.8725300, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63326, 'Patrída', 'Patrida', 'Patrida,Patris,Patrída,Patrís,Tourkokhori,Tourkokhorion,Tourkokhóri,Tourkokhórion,Πατρίδα,Πατρίς', 40.5607100, 22.1854500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63327, 'Paranésti', 'Paranesti', 'Boukia,Boúkia,Paranesti,Paranestion,Paranésti,Paranéstion,Παρανέστι', 41.2666700, 24.5000000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63328, 'Paralía', 'Paralia', 'Paralia,Paralia Katerinis,Paralía,Skala Vromeris,Skála Vromerís,Vromeroskala,Vromeróskala,Vromoskala,Vromóskala,Παραλία,Παραλία Κατερίνης', 40.2671000, 22.5961500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63329, 'Panórama', 'Panorama', 'Arsakli,Arsaklí,Panorama,Panórama,Πανόραμα', 40.5877900, 23.0315000, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63330, 'Palaió Tsiflíki', 'Palaio Tsifliki', 'Palaio Tsifliki,PalaioTsifliki,Palaion Chiflikion,Palaion Tsiflikion,PalaionTsiflikion,PalaióTsiflíki,Palaión Chiflíkion,PalaiónTsiflíkion,Palio Chiflik,Palios,Palió Chiflík,Paliós,Παλαιό Τσιφλίκι,Παλαιόν Τσιφλίκιον', 40.9049500, 24.3508300, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63331, 'Axós', 'Axos', 'Axos,Axós,Eskije,Eskijé,Neon Palaion,Néon Palaión,Palaion,Palaión,Αξός', 40.8022300, 22.3615800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63332, 'Palaiokómi', 'Palaiokomi', 'Palaikomi,Palaikómi,Palaiokomi,Palaiokómi,Paleokomi,Prevista,Provishha,Παλαιοκώμη,Πρέβιστα,Палеокоми,Провища', 40.8706800, 23.9012100, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63333, 'Palaiochóri', 'Palaiochori', 'Palaiochori,Palaiochorion,Palaiochóri,Palaiochórion,Palaiokhori,Palaiokhorion,Palaiokhóri,Palaiokhórion,Παλαιοχώρι,Παλαιοχώριον', 40.9433800, 24.1774700, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63334, 'Palaiochóri', 'Palaiochori', 'Palaiochori,Palaiochorion,Palaiochóri,Palaiochórion,Palaiokhorion,Palaiokhórion,Paliokhorion,Paliokhórion,Παλαιοχώρι,Παλαιοχώριον', 40.4918600, 23.6492800, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63335, 'Palaífyto', 'Palaifyto', 'Lozanovon,Lozánovon,Palaifiton,Palaifyto,Palaifyton,Palaífiton,Palaífyto,Palaífyton,Παλαίφυτο,Παλαίφυτον', 40.7828300, 22.2738800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63336, 'Páchni', 'Pachni', 'Pachni,Pakhni,Pasavik,Pasavík,Páchni,Pákhni,Πάχνη', 41.3050600, 24.8943800, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63337, 'Ouranoupolis', 'Ouranoupolis', 'Ouranopoli,Ouranopolis,Ouranoupoli,Ouranópolis,Pirgos,Prosforion,Prosforiou,Prosforíou,Prosfórion,Pírgos,Ουρανούπολη,Ουρανόπολη,Ουρανόπολις', 40.3333300, 23.9833300, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63338, 'Ormýlia', 'Ormylia', 'Ormilia,Ormilija,Ormylia,Ormília,Ormýlia,Ορμύλια,Ормилия', 40.2945100, 23.5433200, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63339, 'Orestiáda', 'Orestiada', 'Nea Orestias,Néa Orestiás,Orestiada,Orestias,Orestiáda,Orestiás,Ορεστιάδα,Ορεστιάς', 41.5030600, 26.5297200, 'GR', '2013-12-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63340, 'Oraiókastro', 'Oraiokastro', 'Dautbali,Daütbalí,Oraiokastro,Oraiokastron,Oraiókastro,Oraiókastron,Oreorastron,Ωραιόκαστρο,Ωραιόκαστρον', 40.7308300, 22.9172200, 'GR', '2014-08-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63341, 'Nisí', 'Nisi', 'Nisi,Nision,Nisí,Nisíon,Νησί,Νησίον', 40.6361000, 22.3888400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63342, 'Níkiti', 'Nikiti', 'Nikitas,Nikiti,Nikítas,Níkiti,Νικήτη', 40.2220400, 23.6683700, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63343, 'Nikísiani', 'Nikisiani', 'Nikishhan,Nikishjan,Nikisiani,Nikísiani,Νικήσιανη,Никишјан,Никищан', 40.9473900, 24.1431100, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63344, 'Nigríta', 'Nigrita', 'Igrita,Negrita,Nigrita,Nigríta,Ιγρίτα,Νεγρίτα,Νιγρίτα,Нигрита', 40.9052800, 23.4994400, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63345, 'Nestório', 'Nestorio', 'Agios Nestor,Ayios Nestor,Nestorio,Nestorion,Nestrami,Nestramion,Nestrámion,Nestório,Nestórion,Áyios Néstor,Άγιος Νέστωρ,Νεστράμι,Νεστράμιον,Νεστόριο,Νεστόριον', 40.4127800, 21.0622200, 'GR', '2015-04-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63346, 'Néos Skopós', 'Neos Skopos', 'Keshishluk,Kisiklik,Kisiklík,Neos Skopos,Néos Skopós,Toumbista,Toumbísta,Νέος Σκοπός,Νεός Σκοπός,Кешишлък,Неос Скопос', 41.0239000, 23.6092700, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63347, 'Néos Mylótopos', 'Neos Mylotopos', 'Milotopos,Milótopos,Neos Milotopos,Neos Mylotopos,Néos Milótopos,Néos Mylótopos,Voudhrista,Voúdhrista,Νέος Μυλότοπος', 40.8187200, 22.3548900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63348, 'Néos Marmarás', 'Neos Marmaras', 'Marmaras,Marmarás,Neos Marmaras,Néos Marmarás,Νέος Μαρμαράς', 40.0961000, 23.7832300, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63349, 'Néo Soúli', 'Neo Souli', 'Neo Souli,Neon Souli,Neon Soulion,Néo Soúli,Néon Soúli,Néon Soúlion,Soumpaskioi,Subashk''oj,Subashkoi,Subáshkoï,Νέο Σούλι,Νέον Σούλιον,Σουμπάσκιοϊ,Субашкьой', 41.0939700, 23.6437600, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63350, 'Néo Rýsi', 'Neo Rysi', 'Neo Rysi,Neon Rision,Neon Rission,Neon Rysion,Néo Rýsi,Néon Rísion,Néon Ríssion,Néon Rýsion,Purnar,Purnár,Νέο Ρύσι,Νέον Ρύσιον', 40.4960500, 22.9879400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63351, 'Néo Petrítsi', 'Neo Petritsi', 'Neo Petrici,Neo Petritsi,Neon Petritsi,Neon Petritsion,Néon Petrítsi,Néon Petrítsion,Veterna,Vetren,Vetrina,Vétrina,Βέτερνα,Βέτρινα,Νέο Πετρίτσι,Νέον Πετρίτσιον,Нео Петрици', 41.2745900, 23.2938100, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63352, 'Néo Agionéri', 'Neo Agioneri', 'Neo Agioneri,Neon Agionerion,Neon Ayionerion,Néo Agionéri,Néon Agionérion,Néon Ayionérion,Νέο Αγιονέρι,Νέον Αγιονέριον', 40.8082600, 22.7073300, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63353, 'Neochoroúda', 'Neochorouda', 'Neochorouda,Neochoroúda,Neokhoroudha,Neokhoroúdha,Νεοχωρούδα', 40.7381700, 22.8755700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63354, 'Neochóri', 'Neochori', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhorion,Neokhórion,Νεοχώρι,Νεοχώριον', 41.5113100, 26.4574000, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63355, 'Neochóri', 'Neochori', 'Neochori,Neochorion,Neochóri,Neochórion,Neokhorion,Neokhórion,Νεοχώρι,Νεοχώριον', 41.0523100, 23.5799700, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63356, 'Néoi Epivátes', 'Neoi Epivates', 'Neoi Epivatai,Neoi Epivates,Neoi Epivaton,Néoi Epivátai,Néoi Epivátes,Néoi Épiváton,Νέοι Επιβάται,Νέοι Επιβάτες', 40.4986300, 22.9119200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63357, 'Néa Zíchni', 'Nea Zichni', 'Ichna,Nea Zichni,Nea Zikhna,Nea Zikhni,Neja Zikhni,Néa Zíchni,Néa Zíkhna,Néa Zíkhni,Zichne,Zichni,Zileia,Ziliachova,Ziliahova,Zilija,Ziliáhova,Ziljakhova,Ίχνα,Ζήλεια,Ζίχνε,Ζίχνη,Ζιλιάχοβα,Νέα Ζίχνη,Зилия,Зиляхова,Неа Зихни,Неја Зихни', 41.0320400, 23.8287000, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63358, 'Néa Výssa', 'Nea Vyssa', 'Akhirokhorion,Akhirokhórion,Nea Visa,Nea Vissa,Nea Vissi,Nea Vyssa,Néa Vísa,Néa Víssa,Néa Víssi,Néa Výssa,Νέα Βύσσα', 41.5844900, 26.5431800, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63359, 'Néa Tríglia', 'Nea Triglia', 'Nea Triglia,Néa Tríglia,Suflar,Suflár,Νέα Τρίγλια', 40.3057500, 23.2066000, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63360, 'Néa Sánta', 'Nea Santa', 'Nea Sanda,Nea Santa,Néa Sánda,Volovot,Volovót,Νέα Σάντα', 40.8408400, 22.9216300, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63361, 'Néa Róda', 'Nea Roda', 'Nea Roda,Nea Rodha,Néa Róda,Néa Ródha,Provlax,Próvlax,Νέα Ρόδα', 40.3811900, 23.9237400, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63362, 'Néa Poteídaia', 'Nea Poteidaia', 'Nea Poteidaia,Nea Potidaia,Nea Potidhaia,Nea-Potideja,Néa Poteídaia,Néa Potídhaia,Potidaia,Νέα Ποτίδαια,Νέα Ποτείδαια,Ποτίδαια,Неа-Потидея', 40.1940900, 23.3283200, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63363, 'Néa Plágia', 'Nea Plagia', 'Nea Plagia,Nea Playia,Néa Plágia,Néa Pláyia,Νέα Πλάγια', 40.2653700, 23.2037600, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63364, 'Néa Péramos', 'Nea Peramos', 'Nea Peramos,Néa Péramos,Νέα Πέραμος', 40.8385400, 24.3013000, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63365, 'Néa Pélla', 'Nea Pella', 'Nea Pella,Néa Pélla,Νέα Πέλλα', 40.7651600, 22.4917300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63366, 'Ólynthos', 'Olynthos', 'Mariana,Nea Olinthos,Nea Olynthos,Néa Ólinthos,Olinf,Olinfos,Olint,Olinto,Olynth,Olynthe,Olynthos,Olynthus,Ólynthos,Όλυνθος,Μαριανά,Νέα Όλυνθος,Олинт,Олинф,Олінфос', 40.2914700, 23.3420500, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63367, 'Néa Moudhaniá', 'Nea Moudhania', 'Karyi-Liman,Karyí-Limán,Moudania,Nea Moudania,Nea Mudanija,Nea-Mudanija,Μουδανιά,Νέα Μουδανιά,Неа Мудания,Неа-Муданія', 40.2439000, 23.2848400, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63368, 'Néa Michanióna', 'Nea Michaniona', 'Michianio,Nea Mechaniona,Nea Michaniona,Nea Mikhaniona,Néa Michanióna,Néa Mikhanióna,Νέα Μηχανιώνα', 40.4637100, 22.8617000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63369, 'Néa Mesimvría', 'Nea Mesimvria', 'Nea Mesimvria,Néa Mesimvría,Νέα Μεσημβρία', 40.7515800, 22.7690400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63370, 'Néa Málgara', 'Nea Malgara', 'Nea Malgara,Néa Málgara,Νέα Μάλγαρα', 40.6098500, 22.6819600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63371, 'Néa Magnisía', 'Nea Magnisia', 'Arapli,Araplí,Lakhanokipoi,Lakhanokipos,Lakhanókipoi,Lakhanókipos,Nea Magnesia,Nea Magnisia,Néa Magnisía,Νέα Μαγνησία,Νεά Μαγνησία', 40.6878500, 22.8458200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63372, 'Néa Karváli', 'Nea Karvali', 'Nea Karvali,Néa Karváli,Tsabranas,Tsabranás,Νέα Καρβάλη', 40.9614800, 24.5113200, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63373, 'Néa Karyá', 'Nea Karya', 'Nea Karia,Nea Karya,Nea Korna,Néa Kariá,Néa Karyá,Néa Korná,Νέα Καρυά', 40.9062100, 24.7072600, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63374, 'Néa Kallikráteia', 'Nea Kallikrateia', 'Nea Kallikrateia,Nea Kallikratia,Néa Kallikráteia,Néa Kallikrátia,Νέα Καλλικράτεια', 40.3131200, 23.0634300, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63375, 'Néa Iraklítsa', 'Nea Iraklitsa', 'Nea Irakleitsa,Nea Iraklitsa,Nea Praklitsa,Néa Irakleítsa,Néa Iraklítsa,Néa Praklitsa,Νέα Ηρακλίτσα,Νέα Ηρακλείτσα', 40.8644200, 24.3165000, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63376, 'Néa Fókaia', 'Nea Fokaia', 'Ayios Pavlos,Nea Fokaia,Néa Fókaia,Áyios Pávlos,Νέα Φώκαια', 40.1333300, 23.3975400, 'GR', '2014-08-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63377, 'Néa Éfesos', 'Nea Efesos', 'Nea Efesos,Néa Éfesos,Spi,Stipi,Stoupi,Stoupion,Stoupí,Stoupíon,Νέα Έφεσος', 40.2292300, 22.4981100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63378, 'Néa Apollonía', 'Nea Apollonia', 'Egri Bujak,Egrí Buják,Nea Apollonia,Néa Apollonía,Νέα Απολλωνία', 40.6255800, 23.4407400, 'GR', '2015-05-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63379, 'Náousa', 'Naousa', 'Naousa,Náousa,Νάουσα', 40.6294400, 22.0680600, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63380, 'Mikrópolis', 'Mikropolis', 'Karlikova,Karlíkova,Mikropolis,Μικρόπολις', 41.1935100, 23.8157000, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63381, 'Mikró Monastíri', 'Mikro Monastiri', 'Mikro Monastiri,Mikro Monastirion,Mikron Monastirion,Mikró Monastíri,Mikró Monastírion,Mikrón Monastírion,Μικρό Μοναστήρι,Μικρόν Μοναστήριον', 40.7043000, 22.5411200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63382, 'Mikrókampos', 'Mikrokampos', 'Hojalar,Hojalár,Mikrokambos,Mikrokampos,Mikrókambos,Mikrókampos,Μικρόκαμπος', 40.8409800, 22.7748300, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63383, 'Mýki', 'Myki', 'Miki,Myki,Míki,Mýki,Μύκη', 41.2438400, 24.9208400, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63384, 'Mesopotamía', 'Mesopotamia', 'Cetiroku,Chetirok,Mesopotamia,Mesopotamija,Mesopotamiá,Mesopotamía,Tseteraki,Tseteráki,Tsetiraki,Tsetiroki,Çetiroku,Μεσοποταμία,Μεσοποταμιά,Τσετεράκη,Τσετιράκη,Τσετιρόκι,Месопотамия,Месопотамија,Четирок', 40.5025200, 21.1611000, 'GR', '2015-04-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63385, 'Mesiméri', 'Mesimeri', 'Mesimeri,Mesimerion,Mesiméri,Mesimérion,Μεσημέρι,Μεσημέριον', 40.4134400, 23.0075000, 'GR', '2014-04-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63386, 'Meneméni', 'Menemeni', 'Menemeni,Meneméni,Nea Mainemeni,Nea Manemeni,Néa Maineméni,Μενεμένη', 40.6582900, 22.8971200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63387, 'Melíti', 'Meliti', 'Meliti,Melíti,Vostarani,Vostaráni,Vosterani,Βοσταράνη,Βοστεράνη,Μελίτη', 40.8343400, 21.5842600, 'GR', '2015-04-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63388, 'Melissochóri', 'Melissochori', 'Baltza,Báltza,Melissochori,Melissochorion,Melissochóri,Melissochórion,Melissokhorion,Melissokhórion,Μελισσοχώρι,Μελισσοχώριον', 40.7679600, 22.9285800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63389, 'Melíki', 'Meliki', 'Meliki,Melíki,Μελίκη', 40.5168500, 22.3959900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63390, 'Megáli Panagía', 'Megali Panagia', 'Megali Panagia,Megali Panayia,Megáli Panagía,Megáli Panayía,Revenikia,Reveníkia,Μεγάλη Παναγία', 40.4450500, 23.6799900, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63391, 'Mavrovoúni', 'Mavrovouni', 'Mavrovouni,Mavrovounion,Mavrovoúni,Mavrovoúnion,Trebolits,Tripolis,Trébolits,Trípolis,Μαυροβούνι,Μαυροβούνιον', 40.7824300, 22.1562900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63392, 'Mavrothálassa', 'Mavrothalassa', 'Mavrothalassa,Mavrothálassa,Mounouchi,Mounoukhi,Mounoúkhi,Munukh,Μαυροθάλασσα,Μουνούχι,Мунух', 40.8942700, 23.7504800, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63393, 'Mavrochóri', 'Mavrochori', 'Mavrochori,Mavrochorion,Mavrochóri,Mavrochórion,Mavrokhori,Mavrokhorion,Mavrokhóri,Mavrokhórion,Mavrovo,Mavrovon,Mávrovon,Μαυροχώρι,Μαυροχώριον,Μαύροβο,Ма̀врово,Маврово,Маврохори', 40.5122400, 21.3203800, 'GR', '2015-04-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63394, 'Marína', 'Marina', 'Marina,Marína,Μαρίνα', 40.6920000, 22.1009900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63395, 'Maniákoi', 'Maniakoi', 'Maniaki,Maniakoi,Maniáki,Maniákoi,Manjak,Μανιάκοι,Маняк,Манјак', 40.5006400, 21.2444600, 'GR', '2015-04-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63396, 'Mándalo', 'Mandalo', 'Mandalo,Mandalon,Mandalovon,Mandhalon,Mandhalos,Mandálovon,Mándalo,Mándalon,Mándhalon,Mándhalos,Μάνδαλο,Μάνδαλον', 40.8567700, 22.2126400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63397, 'Díon', 'Dion', 'Ayios Dhimitrios,Dion,Díon,Malathria,Malathriá,Malatrja,Δίον', 40.1716900, 22.4846300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63398, 'Makrochóri', 'Makrochori', 'Makrochori,Makrochorion,Makrochóri,Makrochórion,Makrokhori,Makrokhorion,Makrokhóri,Makrokhórion,Mikrogouzi,Mikrogouzion,Mikrogoúzi,Mikrogoúzion,Μακροχώρι,Μακροχώριον', 40.5512500, 22.2495500, 'GR', '2016-03-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63399, 'Makrýgialos', 'Makrygialos', 'Makriyialos,Makrygialos,Makríyialos,Makrýgialos,Μακρύγιαλος', 40.4155100, 22.6039200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63400, 'Loutrós', 'Loutros', 'Loutros,Loutrós,Λουτρός', 40.5887300, 22.3997600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63401, 'Lófos', 'Lofos', 'Lofos,Lófos,Ziaziakon,Ziáziakon,Zjazjakon,Λόφος', 40.2439500, 22.3803300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63402, 'Livádi', 'Livadi', 'Livadhion,Livadi,Livadion,Livádhion,Livádi,Livádion,Λιβάδι,Λιβάδιον', 40.1262500, 22.1575300, 'GR', '2015-02-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63403, 'Livaderó', 'Livadero', 'Livadero,Livaderon,Livaderó,Livaderón,Livadheron,Livadherón,Mokron Khortolivadho,Mókron Khortolívadho,Λιβαδερό,Λιβαδερόν', 40.0345500, 21.9427900, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63404, 'Litóchoro', 'Litochoro', 'Letokhori,Litochoro,Litochoron,Litohoron,Litokhoron,Litóchoro,Litóchoron,Litókhoron,Λιτόχωρο,Λιτόχωρον', 40.1005600, 22.4977800, 'GR', '2014-01-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63405, 'Lití', 'Liti', 'Aivation,Aïvátion,Liti,Lití,Λητή', 40.7453300, 22.9798200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63406, 'Limenária', 'Limenaria', 'Hamidieh,Kastro,Limenaria,Λιμενάρια', 40.6274100, 24.5765000, 'GR', '2017-01-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63407, 'Lýkeio', 'Lykeio', 'Likion,Lykeio,Lykeion,Líkion,Lýkeio,Lýkeion,Λύκειο,Λύκειον', 41.0641300, 25.6857000, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63408, 'Lianovérgi', 'Lianovergi', 'Leianovergi,Leianovergion,Leianovérgi,Leianovérgion,Lianovergi,Lianovergion,Lianoverion,Lianoveryi,Lianoveryion,Lianovérgi,Lianovérgion,Lianovérion,Lianovéryi,Lianovéryion,Λιανοβέργι,Λιανοβέργιον', 40.6352600, 22.5082000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63409, 'Lefkónas', 'Lefkonas', 'Kavakli,Kavaklí,Lefkon,Lefkonas,Lefkónas,Levkon,Levkonas,Levkón,Levkónas,Καβακλί,Λευκών,Λευκώνας', 41.1002900, 23.4965800, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63410, 'Lagyná', 'Lagyna', 'Lagyna,Lagyná,Laina,Layina,Layiná,Laïná,Λαγυνά', 40.7235100, 23.0042000, 'GR', '2014-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63411, 'Lávara', 'Lavara', 'Lavara,Lávara,Λάβαρα', 41.2695700, 26.3852200, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63412, 'Lagkadás', 'Lagkadas', 'Lagkadas,Lagkadás,Lankadas,Λαγκαδάς', 40.7500000, 23.0666700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63413, 'Lákkoma', 'Lakkoma', 'Akmanjali,Akmanjalí,Lakkoma,Lákkoma,Λάκκωμα', 40.3913900, 23.0557800, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63414, 'Laimós', 'Laimos', 'Laimos,Laimós,Rambi,Rampi,Rámbi,Saouftsi,Λαιμός,Ράμπι,Σαούφτσι', 40.8362800, 21.1406100, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63415, 'Lagós', 'Lagos', 'Lagos,Lagós,Λαγός', 41.4510200, 26.4606700, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63416, 'Krókos', 'Krokos', 'Govlitsa,Govlítsa,Krokos,Krókos,Κρόκος', 40.2634900, 21.8176000, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63417, 'Krithiá', 'Krithia', 'Krithea,Krithia,Krithiá,Krithéa,Yeni-Koi,Yení-Koḯ,Κριθιά', 40.8418400, 22.9829200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63418, 'Kristóni', 'Kristoni', 'Kriston,Kristoni,Kristón,Kristóni,Sari-Gol,Sarí-Gol,Κρηστώνη', 40.9596200, 22.8592900, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63419, 'Krinídes', 'Krinides', 'Krinides,Krinidhes,Krinídes,Krinídhes,Rahcha,Ráhcha,Κρηνίδες', 41.0139600, 24.2964700, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63420, 'Krýa Vrýsi', 'Krya Vrysi', 'Kria Vrisi,Krya Vrysi,Kría Vrísi,Krýa Vrýsi,Plasna,Plásna,Κρύα Βρύση', 40.6873800, 22.3051600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63421, 'Kozáni', 'Kozani', 'KZI,Kozane,Kozani,Kozhani,Kozáni,Κοζάνη,Кожани,Козани', 40.3006900, 21.7889600, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63422, 'Kouloúra', 'Kouloura', 'Kouloura,Kouloúra,Κουλούρα', 40.5465200, 22.3179500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63423, 'Koufália', 'Koufalia', 'Koufalia,Koufália,Κουφάλια', 40.7777800, 22.5719400, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63424, 'Korinós', 'Korinos', 'Korinos,Korinós,Κορινός', 40.3165900, 22.5881700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63425, 'Koryfí', 'Koryfi', 'Korifi,Korifí,Koryfi,Koryfí,Κορυφή', 40.6028600, 22.5068100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63426, 'Kopanós', 'Kopanos', 'Ano Kopanos,Kopanos,Kopanós,Áno Kopanós,Κοπανός', 40.6338200, 22.1289300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63427, 'Kónitsa', 'Konitsa', 'Konitsa,Kónitsa,Κόνιτσα', 40.0486100, 20.7566700, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63428, 'Kontariótissa', 'Kontariotissa', 'Kondariotissa,Kondariótissa,Kontariotissa,Kontariótissa,Koundouriotissa,Koundouriótissa,Κονταριώτισσα', 40.2275400, 22.4610000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63429, 'Komotiní', 'Komotini', 'Gjumjurdzhina,Guemuelcine,Gumulcine,Gumuljina,Gumuljína,Gümülcine,Komotene,Komotina,Komotinai,Komotine,Komotini,Komotiní,Komotinē,Komotinė,Komotēnē,Koumoutzina,Nkioumoultzina,ke mo di ni,kmwtyny,komotini,kwmwtyny,qwomwotiyniy,Γκιουμουλτζίνα,Κομοτηνά,Κομοτηνή,Κομοτηναί,Κουμουτζηνά,Гюмюрджина,Комотини,Комотіні,קוֹמוֹטִינִי,كوموتيني,کموتینی,コモティニ,科莫蒂尼,코모티니', 41.1191700, 25.4053500, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63430, 'Komniná', 'Komnina', 'Komnina,Komninon,Komniná,Komninón,Uchana,Úchana,Κομνηνά', 40.5905700, 21.7767100, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63431, 'Kolchikón', 'Kolchikon', 'Balaftsa,Baláftsa,Kolchiko,Kolchikó,Κολχικό', 40.7566200, 23.1337700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63432, 'Kolindrós', 'Kolindros', 'Kolindhro,Kolindhró,Kolindros,Kolindrós,Κολινδρός', 40.4788800, 22.4831900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63433, 'Kokkinóchoma', 'Kokkinochoma', 'Kinali,Kokkinochoma,Kokkinokhoma,Kokkinóchoma,Kokkinókhoma,Kínali,Κοκκινόχωμα', 40.9269000, 24.3080500, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63434, 'Koímisi', 'Koimisi', 'Koimisi,Koimisis,Koímisi,Koímisis,Spatovon,Spátovon,Κοίμηση,Κοίμησις', 41.2128200, 23.3003500, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63435, 'Koíla', 'Koila', 'Islamli,Islamlí,Koila,Koíla,Lamnidhes,Lamnídhes,Κοίλα', 40.3305500, 21.7910200, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63436, 'Kleítos', 'Kleitos', 'Haidarli,Haïdarlí,Kleitos,Kleítos,Klitos,Klítos,Κλείτος', 40.4314000, 21.8580600, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63437, 'Kleidí', 'Kleidi', 'Kleidi,Kleidion,Kleidí,Kleidíon,Klidhi,Klidhion,Klidhí,Klidhíon,Κλειδί,Κλειδίον', 40.5663200, 22.5903300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63438, 'Kítros', 'Kitros', 'Kitros,Kítros,Pidhna,Pidna,Pídhna,Κίτρος', 40.3739900, 22.5786200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63439, 'Kýria', 'Kyria', 'Kiria,Kyrgia,Kyria,Kíria,Kýria,Organji,Organjion,Organjí,Organjíon,Organtzi,Organtzí,Κύργια,Κύρια', 41.0990000, 24.2891500, 'GR', '2017-04-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63440, 'Kyprínos', 'Kyprinos', 'Kiprinos,Kiprínos,Kyprinos,Kyprínos,Κυπρίνος', 41.5754200, 26.2290500, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63441, 'Kimméria', 'Kimmeria', 'Kimmeria,Kimméria,Κιμμέρια', 41.1478800, 24.9386900, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63442, 'Kýmina', 'Kymina', 'Kimina,Kymina,Kímina,Kýmina,Yunjidhes,Yunjídhes,Κύμινα', 40.6135400, 22.6927800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63443, 'Kilkís', 'Kilkis', 'Kilkis,Kilkís,Kukus,Kukush,Kukuš,Nomos Kilkis,Prefectura Kilkis,Prefektura Kukush,Κιλκίς,Νομός Κιλκίς,Кукуш,Префектура Кукуш', 40.9930200, 22.8743300, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63444, 'Chrysoúpolis', 'Chrysoupolis', 'Chrysoupoli,Chrysoupolis,Chrysoúpoli,Chrysoúpolis,Khrisoupolis,Khrisoúpolis,Khrysoupolis,Sapaioi,Sapaíoi,Sari Saban,Sarí Sabán,Χρυσούπολη,Χρυσούπολης', 40.9855600, 24.6938900, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63445, 'Chrysó', 'Chryso', 'Chryso,Chryson,Chrysó,Khriso,Khrison,Khrisos,Khrisó,Khrisón,Khrisós,Khryso,Khrýso,Topolen,Topoliani,Topoljan,Topóliani,Τοπολιάνη,Χρυσό,Χρυσόν,Тополѐн,Тополян,Тополјан,Хрисо', 41.0580600, 23.6510800, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63446, 'Chrysochóri', 'Chrysochori', 'Chrysochori,Chrysochorion,Chrysochóri,Chrysochórion,Khrisokhori,Khrisokhorion,Khrisokhóri,Khrisokhórion,Organjilar,Organjilár,Χρυσοχώρι,Χρυσοχώριον', 40.9332800, 24.7108800, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63447, 'Chrysochórafa', 'Chrysochorafa', 'Chaznatar,Chrysochorafa,Chrysochórafa,Haznatar,Haznatár,Khrisokhorafa,Khrisokhórafa,Χαζνατάρ,Χρυσοχώραφα', 41.1809700, 23.2355100, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63448, 'Chortiátis', 'Chortiatis', 'Chortiati,Chortiatis,Chortiáti,Chortiátis,Khortiatis,Khortiátis,Χορτιάτη,Χορτιάτης', 40.6095400, 23.1001400, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63449, 'Choristí', 'Choristi', 'Chatalja,Chatálja,Choristi,Choristí,Khoristi,Khoristí,Χωριστή', 41.1305600, 24.2084300, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63450, 'Charopó', 'Charopo', 'Charopo,Charopon,Charopó,Charopón,Karopo,Karopó,Kharopo,Kharopon,Kharopó,Kharopón,Radovon,Rádovon,Χαροπό,Χαροπόν,Χαρωπό,Χαρωπόν', 41.2603100, 23.3727900, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63451, 'Chalkidóna', 'Chalkidona', 'Chalkidon,Chalkidona,Chalkidón,Chalkidóna,Khalkidhon,Khalkidhón,Nea Khalkidhon,Néa Khalkidhón,Χαλκηδόνα', 40.7318400, 22.5999200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63452, 'Keramotí', 'Keramoti', 'Keramoti,Keramotí,Κεραμοτή,Κεραμωτή', 40.8559100, 24.7059500, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63453, 'Kavýli', 'Kavyli', 'Kavili,Kavyli,Kavíli,Kavýli,Καβύλη', 41.5622500, 26.5147000, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63454, 'Kavallári', 'Kavallari', 'Kavalari,Kavallari,Kavallarion,Kavallárion,Kavalári,Καβαλλάρι', 40.7153900, 23.0458800, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63455, 'Kavála', 'Kavala', 'Cavala,Cavalla,KVA,Kaballa,Kavala,Kavalla,Kavála,Kaválla,Kawala,Neapolis,ka wa la,kavu~ara,qwlt,Καβάλα,Кава̀ла,Кавала,قولة,カヴァラ,卡瓦拉', 40.9395900, 24.4068700, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63456, 'Káto Scholári', 'Kato Scholari', 'Adali,Adalí,Kato Scholari,Kato Scholarion,Kato Skholarion,Káto Scholári,Káto Scholárion,Káto Skholárion,Κάτω Σχολάρι,Κάτω Σχολάριον', 40.4290600, 23.0297800, 'GR', '2015-01-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63457, 'Káto Nevrokópi', 'Kato Nevrokopi', 'Kato Nevrokopi,Kato Nevrokopion,Káto Nevrokópi,Káto Nevrokópion,Zernova,Zirnovon,Zírnovon,Κάτω Νευροκόπι', 41.3500000, 23.8666700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63458, 'Káto Miliá', 'Kato Milia', 'Kato Melea,Kato Milea,Kato Milia,Káto Miliá,Káto Miléa,Κάτω Μέλεα,Κάτω Μηλιά', 40.2540300, 22.3434200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63459, 'Loutráki', 'Loutraki', 'Kato Loutraki,Kato Loutrakion,Kato Pozar,Káto Loutráki,Káto Loutrákion,Káto Pózar,Loutraki,Loutrakion,Loutráki,Loutrákion,Pozar,Κάτω Λουτράκι,Κάτω Λουτράκιον,Κάτω Πόζαρ,Λουτράκι,Λουτράκιον,Ποζάρ,Πόζαρ', 40.9711600, 21.9465900, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63460, 'Káto Lipochóri', 'Kato Lipochori', 'Kato Lipochori,Kato Lipochorion,Kato Lipokhorion,Káto Lipochóri,Káto Lipochórion,Káto Lipokhórion,Lipochorion,Lipochórion,Κάτω Λιποχώρι,Κάτω Λιποχώριον', 40.7575400, 22.1796200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63461, 'Káto Kamíla', 'Kato Kamila', 'Dolna Kamila,Kato Kamila,Káto Kamíla,Osman Kamila,Κάτω Καμήλα,Οσμάν Καμήλα,Долна Камила', 41.0211900, 23.4833600, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63462, 'Kateríni', 'Katerini', 'Aikaterini,Aikateríni,Katerina,Katerini,Kateríni,Κατερίνη,Катерини', 40.2695600, 22.5060800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63463, 'Kastoria', 'Kastoria', 'Castoria,Castória,KSO,Kastoria,Kastorija,Kastorià,Kastoriá,Kastoriꙗ,Kastoryja,Kesrie,Kesriye,Kostur,Kosturi,ka si tuo li ya,kaseutolia,kasutoria,kostur,qstwryh,Καστοριά,Καστορια,Кастория,Касторыя,Касторія,Касторїꙗ,Костур,קסטוריה,カストリア,卡斯托里亚,카스토리아', 40.5216500, 21.2634100, 'GR', '2016-11-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63464, 'Kastaniés', 'Kastanies', 'Kastaneai,Kastanies,Kastaniés,Kastanéai,Καστανέαι,Καστανιές', 41.6455100, 26.4767600, 'GR', '2015-09-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63465, 'Kassándreia', 'Kassandreia', 'Kasandrija,Kassandra,Kassandreia,Kassandria,Kassándra,Kassándreia,Valta,Válta,Κασσάνδρεια,Касандрия', 40.0483500, 23.4136200, 'GR', '2014-08-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63466, 'Símantra', 'Simantra', 'Karkara,Karkára,Simantra,Símantra,Σήμαντρα', 40.3456300, 23.3102600, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63467, 'Karítsa', 'Karitsa', 'Karica,Karitsa,Karítsa,Καρίτσα', 40.1874500, 22.4817100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63468, 'Karyótissa', 'Karyotissa', 'Kariotissa,Kariótissa,Karyotissa,Karyótissa,Καρυώτισσα', 40.7691500, 22.3133100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63469, 'Karyes', 'Karyes', 'Kariai,Kariaí,Karyaes,Karyes,Καρυές', 40.2571500, 24.2449800, 'GR', '2010-12-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63470, 'Kardiá', 'Kardia', 'Karajohali,Karajohalí,Kardhia,Kardhiá,Kardia,Kardiá,Καρδιά', 40.4690900, 22.9937800, 'GR', '2015-01-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63471, 'Kampánis', 'Kampanis', 'Kambanis,Kambánis,Kampanis,Kampánis,Karaja Kadi,Karajá Kadí,Valtoi,Váltoi,Καμπάνης', 40.8895100, 22.9168200, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63472, 'Kamariótissa', 'Kamariotissa', 'Kamariotissa,Kamariótissa,Καμαριώτισσα', 40.4750100, 25.4745600, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63473, 'Kalós Agrós', 'Kalos Agros', 'Kalos Agros,Kalós Agrós,Osmanitsa,Osmanítsa,Καλός Αγρός', 41.1054300, 24.0857000, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63474, 'Kalochóri', 'Kalochori', 'Kalochori,Kalochorion,Kalochóri,Kalochórion,Kalokhorion,Kalokhórion,Kaskarika,Kaskaríka,Καλοχώρι,Καλοχώριον', 40.6418900, 22.8573400, 'GR', '2014-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63475, 'Kallithéa', 'Kallithea', 'Kalitea,Kallifeja,Kallithea,Kallithéa,Vromeri,Vromerí,Καλλιθέα,Каллифея', 40.2739000, 22.5777500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63476, 'Kallithéa', 'Kallithea', 'Kalitea,Kallifeja,Kallithea,Maltepe,Meltepe,Metokhi Rossikon,Metókhi Rossikón,Máltepe,Méltepe,Nea Floyita,Néa Floyitá,Καλλιθέα,Калитеа,Каллифея', 40.0737400, 23.4463700, 'GR', '2014-08-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63477, 'Kallífytos', 'Kallifytos', 'Kallifiton,Kallifitos,Kallifytos,Kallífiton,Kallífitos,Kallífytos,Ravika,Ravíka,Καλλίφυτος', 41.1728000, 24.2152700, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63478, 'Kalí Vrýsi', 'Kali Vrysi', 'Gornitsa,Górnitsa,Kali Vrisi,Kali Vrisis,Kali Vrysi,Kalí Vrísi,Kalí Vrísis,Kalí Vrýsi,Καλή Βρύση', 41.1465300, 23.9066700, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63479, 'Kalýves Polygýrou', 'Kalyves Polygyrou', 'Kalivai Poliyirou,Kalives Poligiru,Kalivia Poliyirou,Kalyvai Polygyrou,Kalyves Polygyrou,Kalívai Poliyírou,Kalívia Poliyírou,Kalýves Polygýrou,Καλύβαι Πολυγύρου,Καλύβες Πολυγύρου,Каливес Полигиру', 40.2865900, 23.3903300, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63480, 'Ágios Spyrídon', 'Agios Spyridon', 'Agios Spyridon,Kalivia Kondariotissis,Kalivia Koundouriotissas,Kalivia Koundouriotissis,Kalivija Kontariotisis,Kalyvia Kontariotissis,Kalívia Kondariotíssis,Kalívia Koundouriotíssis,Kalívia Koundouriótissas,Kalývia Kontariotíssis,Kolibi na Kontariotisa,Ágios Spyrídon,Άγιος Σπυρίδων', 40.2077800, 22.4431100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63481, 'Kalývia', 'Kalyvia', 'Kalivia,Kalyvia,Kalívia,Kalývia,Καλύβια', 40.7550800, 22.2175300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63482, 'Prínos', 'Prinos', 'Kalivai,Kalives,Kalyvai,Kalyves,Kalívai,Kalíves,Kalývai,Kalýves,Prinos,Καλύβαι,Καλύβες,Πρίνος', 40.7409000, 24.5778700, 'GR', '2014-08-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63483, 'Kalí', 'Kali', 'Kalendra,Kali,Kaléndra,Kalí,Καλή', 40.8193100, 22.1776100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63484, 'Kalampáki', 'Kalampaki', 'Kalabaki,Kalabakion,Kalabáki,Kalabákion,Kalambaki,Kalambakion,Kalambáki,Kalambákion,Kalampaki,Kalampakion,Kalampáki,Καλαμπάκι,Καλαμπάκιον', 41.0500000, 24.1833300, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63485, 'Kalamariá', 'Kalamaria', 'Kalamaria,Kalamarija,Kalamariá,Kalamarya,Καλαμαριά,Каламария', 40.5825000, 22.9502800, 'GR', '2015-05-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63486, 'Kalá Déndra', 'Kala Dendra', 'Kala Dendra,Kala Dhendhra,Kala Dhendra,Kalendra,Kalentra,Kalá Dhéndhra,Kalá Dhéndra,Kalá Déndra,Kaléndra,Καλά Δένδρα,Καλένδρα,Καλέντρα,Календра', 41.0994100, 23.4239600, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63487, 'Léchovo', 'Lechovo', 'Iroiko,Iroikon,Iroïkón,Kantil-Kioi,Lechovo,Lechovon,Lehove,Lehovo,Lehovë,Lekhovo,Lekhovon,Léchovo,Léchovon,Lékhovon,Ηρωικό,Καντίλ-Κιόι,Λέχοβο,Λέχοβον,Лехово', 40.5844200, 21.4921800, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63488, 'Irákleia', 'Irakleia', 'Barakli Cuma,Beirakli Juma,Beiraklí Juma,Dolna DZumaja,Dolna Dzhumaja,Giumala de Jos,Irakleia,Iraklia,Iraklija,Irákleia,Iráklia,Jumaya,Jumayá,Tzoumagia,Tzoumagia-Bairakli,Ηράκλεια,Τζουμαγιά,Τζουμαγιά-Μπαϊρακλή,Долна Џумаја,Долна Джумая,Ираклия', 41.1821700, 23.2824300, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63489, 'Ierissós', 'Ierissos', 'Erissos,Hierissos,Ierisos,Ierissos,Ierissós,Ierisós,Jerisos,Ιερισσός,Йерисос', 40.3974800, 23.8750500, 'GR', '2017-01-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63490, 'Íasmos', 'Iasmos', 'Iasmos,Íasmos,Ίασμος', 41.1274700, 25.1857300, 'GR', '2014-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63491, 'Grevená', 'Grevena', 'Grebena,Γρεβενά', 40.0845200, 21.4274400, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63492, 'Gouménissa', 'Goumenissa', 'Goumenissa,Goumenitsa,Gouménissa,Gouménitsa,Γουμένισσα', 40.9460400, 22.4497400, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63493, 'Gázoros', 'Gazoros', 'Gazoros,Gázoros,Porna,Pórna,Γάζωρος', 41.0255700, 23.7757400, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63494, 'Gallikós', 'Gallikos', 'Gallikon,Gallikos,Gallikón,Gallikós,Salamanli,Salamanlí,Γαλλικός', 40.8581700, 22.8760400, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63495, 'Galátista', 'Galatista', 'Anthemous,Anthemoús,Galachishta,Galatishha,Galatista,Galátista,Γαλάτιστα,Галатища,Галачишта', 40.4682000, 23.2801500, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63496, 'Galatiní', 'Galatini', 'Galatini,Galatiní,Kontsikon,Kontsikón,Γαλατινή', 40.3196600, 21.5514800, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63497, 'Galatádes', 'Galatades', 'Galatades,Galatadhes,Galatádes,Galatádhes,Kadinovon,Kadínovon,Γαλατάδες', 40.7559000, 22.2806200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63498, 'Fotolívos', 'Fotolivos', 'Fotolivi,Fotolivos,Fotolívi,Fotolívos,Φωτολίβος', 41.0601300, 24.0472400, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63499, 'Néa Flogitá', 'Nea Flogita', 'Flogita,Floyita,Floyitá,Nea Flogita,Néa Flogitá,Phlogeta,Νέα Φλογητά,Φλογητά', 40.2610800, 23.2210700, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63500, 'Flórina', 'Florina', 'Florina,Follorina,Lerin,Plorina,lerin,Φλώρινα,Лерин', 40.7819700, 21.4098100, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63501, 'Filótas', 'Filotas', 'Chaldzhievo,Chaljilar,Chaljilár,Filotas,Filótas,Tsaltzilar,Τσαλτζιλάρ,Φιλώτας,Чалджиево', 40.6252000, 21.7085100, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63502, 'Fillýra', 'Fillyra', 'Fillira,Fillyra,Fillíra,Fillýra,Xidhia,Xídhia,Φιλλύρα', 41.1166700, 25.6333300, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63503, 'Fíliro', 'Filiro', 'Filiron,Filiros,Filyro,Fíliron,Fíliros,Yalijik,Yalijík,Φίλυρο', 40.6915100, 23.0046000, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63504, 'Féres', 'Feres', 'Ferai,Feres,Ferrai,Férai,Féres,Férrai,Pherrai,Φέραι,Φέρες', 40.8930500, 26.1723400, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63505, 'Exaplátanos', 'Exaplatanos', 'Exaplatanon,Exaplatanos,Exaplátanon,Exaplátanos,Kapiniani,Kapíniani,Εξαπλάτανος', 40.9764300, 22.1295800, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63506, 'Evropós', 'Evropos', 'Asiklar,Asiklár,Evropos,Evropós,Ευρωπός', 40.8970300, 22.5527700, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63507, 'Évosmos', 'Evosmos', 'Evosmo,Evosmon,Evosmos,Nea Coclutsa,Neos Koukloutzas,Néos Koukloutzás,Taousan Lofos,Taousán Lófos,Évosmo,Évosmon,Évosmos,Εύοσμος', 40.6705600, 22.9083300, 'GR', '2013-12-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63508, 'Évlalo', 'Evlalo', 'Evlalo,Evlalon,Évlalo,Évlalon,Εύλαλο', 40.9833300, 24.8000000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63509, 'Efkarpía', 'Efkarpia', 'Efkarpia,Efkarpía,Evkarpia,Evkarpía,Lembet,Lembét,Ευκαρπία', 40.6879700, 22.9534800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63510, 'Erátyra', 'Eratyra', 'Eratira,Eratyra,Erátira,Erátyra,Katokhori,Katokhóri,Selitsa,Sélitsa,Εράτυρα', 40.3425300, 21.5133300, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63511, 'Episkopí', 'Episkopi', 'Episkopi,Episkopí,Επισκοπή', 40.6874800, 22.1364000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63512, 'Epanomí', 'Epanomi', 'Epanomi,Epanomí,Épanomí,Επανομή', 40.4261400, 22.9278200, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63513, 'Empório', 'Emporio', 'Emborion,Emboriya,Embórion,Emporio,Emporion,Empório,Empórion,Εμπόριο,Εμπόριον', 40.4886600, 21.5576800, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63514, 'Eleftheroúpolis', 'Eleftheroupolis', 'Eleftheroupoli,Eleftheroupolis,Eleftheroúpoli,Eleftheroúpolis,Elevtheroupolis,Elevtheroúpolis,Pravion,Právion,Ελευθερούπολη,Ελευθερούπολης', 40.9138900, 24.2513900, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63515, 'Eleftherés', 'Eleftheres', 'Eleftherai,Eleftheres,Eleftherés,Elevtherai,Elevtheraí,Ελευθερές,Ελευθεραί', 40.8466600, 24.2543100, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63516, 'Elaiochóri', 'Elaiochori', 'Elaiochori,Elaiochorion,Elaiochóri,Elaiochórion,Elaiokhori,Elaiokhorion,Elaiokhóri,Elaiokhórion,Kotskar,Kotskari,Kotskári,Ελαιοχώρι,Ελαιοχώριον,Κοτσκάρ', 40.8203000, 24.2437300, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63517, 'Echínos', 'Echinos', 'Echinos,Echínos,Ekhinos,Ekhínos,Sahin Koeyue,Şahin Köyü,Εχίνος', 41.2755800, 24.9723700, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63518, 'Édessa', 'Edessa', 'Edessa,Edhessa,Voden,Vodena,Vodená,Édessa,Édhessa,Έδεσσα,Воден', 40.8026000, 22.0475100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63519, 'Dráma', 'Drama', 'Dhrama,Dhráma,Drama,Dráma,dhrama,drama,drmh,Δράμα,Драма,דרמה,ذراما', 41.1528300, 24.1473000, 'GR', '2015-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63520, 'Drosáto', 'Drosato', 'Dhrosaton,Dhrosáton,Drosato,Drosaton,Drosáto,Drosáton,Potaros,Potarós,Δροσάτο,Δροσάτον', 41.1664100, 22.8029800, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63521, 'Drymós', 'Drymos', 'Dhrimos,Dhrimós,Drimiglava,Drimíglava,Drymos,Drymós,Sidhirokefalon,Sidhirokéfalon,Δρυμός', 40.7809900, 22.9588900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63522, 'Dravískos', 'Draviskos', 'Dhraviskos,Dhravískos,Draviskos,Dravískos,Zdravik,Zdrávik,Δραβήσκος,Δραβίσκος,Ζδράβικ', 40.9239300, 23.8711900, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63523, 'Didymóteicho', 'Didymoteicho', 'Dhidhimotikhon,Dhidhimótikhon,Didymoteicho,Didymoteichon,Didymoteichou,Didymoteikhon,Didymoteíchou,Didymotichon,Didymóteicho,Didymóteichon,Didymóteikhon,Dimotika,Διδυμότειχο', 41.3480600, 26.4961100, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63524, 'Diavatós', 'Diavatos', 'Dhiavatos,Dhiavatós,Diavatos,Diavatós,Διαβατός', 40.5460600, 22.2668600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63525, 'Diavatá', 'Diavata', 'Dhiavata,Dhiavatá,Diavata,Diavatá,Dudular,Dudulár,Nea Ionia,Néa Ioniá,Διαβατά', 40.6874400, 22.8579900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63526, 'Ágios Geórgios', 'Agios Georgios', 'Agios Georgios,Ayios Yeoryios,Yiannissa,Yiánnissa,Ágios Geórgios,Áyios Yeóryios,Άγιος Γεώργιος', 40.6021500, 22.1943000, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63527, 'Ágios Vasíleios', 'Agios Vasileios', 'Agios Vasileios,Ayios Vasilios,Ágios Vasíleios,Áyios Vasílios,Άγιος Βασίλειος', 40.6642400, 23.1137300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63528, 'Ágios Pétros', 'Agios Petros', 'Agios Petros,Ayios Petros,Petrovon,Pétrovon,Ágios Pétros,Áyios Pétros,Άγιος Πέτρος', 40.8672500, 22.5829800, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63529, 'Ágios Nikólaos', 'Agios Nikolaos', 'Agios Nikolaos,Ayios Nikolaos,Ágios Nikólaos,Áyios Nikólaos,Άγιος Νικόλαος', 40.2492600, 23.6961600, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63530, 'Ágios Loukás', 'Agios Loukas', 'Agios Loukas,Ayios Loukas,Ágios Loukás,Áyios Loukás,Άγιος Λουκάς', 40.7179900, 22.2954500, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63531, 'Ágios Athanásios', 'Agios Athanasios', 'Agios Athanasios,Ayios Athanasios,Boriani,Bóriani,Ágios Athanásios,Áyios Athanásios,Άγιος Αθανάσιος', 41.0746300, 24.2454500, 'GR', '2013-12-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63532, 'Ágios Athanásios', 'Agios Athanasios', 'Agios Athanasios,Ayios Athanasios,Kavakli,Kavaklí,Ágios Athanásios,Áyios Athanásios,Άγιος Αθανάσιος', 40.7159800, 22.7284100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63533, 'Ágio Pnévma', 'Agio Pnevma', 'Agio Pnevma,Agion Pnevma,Ayion Pnevma,Monikon,Monoikon,Monospito,Monospiton,Mónoikon,Veznik,Veznikioi,Veznikon,Vezníkon,Ágio Pnévma,Ágion Pnévma,Áyion Pnévma,Άγιο Πνεύμα,Άγιον Πνεύμα,Βεζνίκιοϊ,Βεζνίκον,Μονόσπιτο,Μονόσπιτον,Μόνοικον,Агио Пневма,Везник,Моникон', 41.1014200, 23.6799200, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63534, 'Agía Triáda', 'Agia Triada', 'Agia Triada,Agia Trias,Agía Triáda,Agía Triás,Ayia Trias,Ayía Triás,Skala Agias Triados,Skala Ayias Triadhos,Skála Agías Triádos,Skála Ayías Triádhos,Αγία Τριάδα,Αγία Τριάς', 40.5000300, 22.8735100, 'GR', '2014-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63535, 'Agía Paraskeví', 'Agia Paraskevi', 'Agia Paraskevi,Agía Paraskeví,Ayia Paraskevi,Ayía Paraskeví,Αγία Παρασκευή', 40.4815000, 23.0486300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63536, 'Axioúpoli', 'Axioupoli', 'Axioupoli,Axioupolis,Axioúpoli,Axioúpolis,Boemitsa,Bóëmitsa,Αξιούπολη,Αξιούπολις', 40.9858200, 22.5416500, 'GR', '2014-01-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63537, 'Ávato', 'Avato', 'Avato,Avaton,Ávato,Ávaton,Άβατο,Άβατον', 40.9627900, 24.8044100, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63538, 'Áthyra', 'Athyra', 'Athira,Athiras,Athyra,Athíras,Bozets,Bózets,Áthira,Áthyra,Άθυρα', 40.8261500, 22.5927900, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63539, 'Asvestochóri', 'Asvestochori', 'Asvestochori,Asvestochorion,Asvestochóri,Asvestochórion,Kirec Kjoj,Kirets Kioi,Kireç Kjoj,Neochori,Nova Sel,Ασβεστοχώρι,Ασβεστοχώριον,Κιρέτς Κιόι,Νεοχώρι,Νόβα Σελ', 40.6412500, 23.0252800, 'GR', '2017-07-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63540, 'Ássiros', 'Assiros', 'Assiros,Yuvesna,Yuvésna,Ássiros,Άσσηρος', 40.8214300, 23.0300800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63541, 'Asproválta', 'Asprovalta', 'Asprovalta,Asproválta,Ασπροβάλτα', 40.7304900, 23.7118000, 'GR', '2014-06-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63542, 'Askós', 'Askos', 'Askos,Askós,Yiakinia,Yiakínia,Ασκός', 40.7510500, 23.3872100, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63543, 'Arsénio', 'Arsenio', 'Arseni,Arsenio,Arsenion,Arsenios,Arsénio,Arsénion,Arsénios,Αρσένι,Αρσένιο,Αρσένιον', 40.7141200, 22.1592300, 'GR', '2017-03-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63544, 'Arrianá', 'Arriana', 'Arriana,Arrianá,Kozlukebir,Kuzlu Kebir,Kuzlú Kebír,Αρριανά', 41.0813100, 25.6949400, 'GR', '2013-12-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63545, 'Árnissa', 'Arnissa', 'Arnissa,Ostrova,Ostrovo,Ostrovon,awstrwwh,Árnissa,Óstrovon,Άρνισσα,اوسترووه', 40.7955500, 21.8357700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63546, 'Arnaía', 'Arnaia', 'Arnaia,Laringovi,Laringóvi,Lerigovo,Αρναία', 40.4865200, 23.5953700, 'GR', '2014-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63547, 'Arísvi', 'Arisvi', 'Arisvi,Arísvi,Irjan,Irján,Αρίσβη', 41.0700000, 25.5904100, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63548, 'Aridaía', 'Aridaia', 'Ardea,Ardhea,Ardhéa,Aridaea,Aridaia,Aridaía,Aridea,Aridhaia,Aridhaía,Soumposko,Soumposkon,Soumpotsko,Suboskon,Subotsko,Súboskon,Αρδέα,Αριδαία,Σουμπόσκο,Σουμπόσκον,Σούμποσκο,Σούμποσκον,Σούμποτσκο,Аридеа,Съботско', 40.9730600, 22.0563900, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63549, 'Argos Orestiko', 'Argos Orestiko', 'Argos Orestiko,Argos Orestikon,Chroupista,Hurpiste,Hurpişte,Khroupista,Khroúpista,Krupishta,Árgos Orestikón,Άργος Ορεστικό,Άργος Ορεστικόν,Χρούπιστα', 40.4535400, 21.2588900, 'GR', '2016-11-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63550, 'Aravissós', 'Aravissos', 'Aravissos,Aravissós,Obar,Ombar,Óbar,Ómbar,Αραβησσός', 40.8435200, 22.3017800, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63551, 'Áratos', 'Aratos', 'Aratos,Karajakoi,Karajákoï,Áratos,Άρατος', 41.0813900, 25.5518600, 'GR', '2013-10-07', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63552, 'Ápsalos', 'Apsalos', 'Apsalos,Dragomanitsa,Dragománitsa,Ápsalos,Άψαλος,Δραγομανίτσα', 40.8924000, 22.0570900, 'GR', '2015-05-03', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63553, 'Mitroúsi', 'Mitrousi', 'Ano Khomondhos,Ano Mitrousi,Ano Mitrousion,Ano Mitrousis,Mitrousi,Mitrousion,Mitroúsi,Mitroúsion,Áno Khomóndhos,Áno Mitroúsi,Áno Mitroúsion,Áno Mitroúsis,Άνω Μητρούσι,Μητρούσι,Μητρούσιον', 41.0704100, 23.4606400, 'GR', '2014-08-24', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63554, 'Áno Kómi', 'Ano Komi', 'Ano Komi,Ano Vanitsa,Áno Kómi,Áno Vánitsa,Άνω Κώμη', 40.2266000, 21.8282700, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63555, 'Angelochóri', 'Angelochori', 'Angelochori,Angelochorion,Angelochóri,Angelochórion,Angelokhorion,Angelokhórion,Vetista,Vetísta,Αγγελοχώρι,Αγγελοχώριον', 40.6786200, 22.1993300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63556, 'Agkathiá', 'Agkathia', 'Agkathia,Agkathiá,Angathia,Angathiá,Ankathia,Grijali,Grijáli,Αγκαθιά', 40.5553500, 22.4708300, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63557, 'Anatolikó', 'Anatoliko', 'Anatoliko,Anatolikon,Anatolikó,Anatolikón,Valmada,Valmadha,Valmáda,Valmádha,Ανατολικό,Ανατολικόν', 40.6615200, 22.7119000, 'GR', '2014-04-29', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63558, 'Anaráchi', 'Anarachi', 'Anarachi,Anarrache,Anarrakhi,Anarrákhi,Anaráchi,Devri,Dévri,Αναράχη,Αναρράχη', 40.4923400, 21.5727900, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63559, 'Ammochóri', 'Ammochori', 'Ammochori,Ammochorion,Ammochóri,Ammochórion,Ammokhorion,Ammokhórion,Pesonitsa,Pesosnitsa,Pesósnitsa,Αμμοχώρι,Αμμοχώριον,Πεσόνιτσα,Πεσόσνιτσα', 40.7820300, 21.4845800, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63560, 'Amýntaio', 'Amyntaio', 'Amindaion,Amindeo,Amyndeo,Amyntaio,Amíndaion,Amýntaio,Sorovits,Sourovits,Sourovitsevo,Surovichevo,Syrovitsevo,Sórovits,Αμύνταιο,Σουροβίτσεβο,Σούροβιτς,Συροβίτσεβο,Σόροβιτς,Ам̀индео,Аминдео,Суровичево', 40.6896700, 21.6797400, 'GR', '2015-04-11', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63561, 'Amygdaleónas', 'Amygdaleonas', 'Amigdhaleon,Amigdhaleonas,Amigdhaleón,Amigdhaleónas,Amygdaleon,Amygdaleonas,Amygdaleón,Amygdaleónas,Batem Chiflik,Batém Chiflík,Αμυγδαλεών,Αμυγδαλεώνας', 40.9634600, 24.3600700, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63562, 'Ampeleíes', 'Ampeleies', 'Ambeliai,Ambelies,Ambeliés,Ambelíai,Ampeleiai,Ampeleies,Ampeleíai,Ampeleíes,Krusari,Krusári,Αμπελείαι,Αμπελείες', 40.8341700, 22.3876700, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63563, 'Alistráti', 'Alistrati', 'Alistrat,Alistrati,Alistratik,Alistráti,Αλιστράτη,Алистрат,Алистратик', 41.0644300, 23.9575100, 'GR', '2014-08-18', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63564, 'Alexandroupoli', 'Alexandroupoli', 'AXD,Alejandropolis,Alejandrópolis,Aleksandrupolis,Alessandropoli,Alexandhroupolis,Alexandhroúpolis,Alexandropolis,Alexandroupoli,Alexandroupolis,Alexandroúpoli,Alexandroúpolis,Dedeagac,Dedeagach,Dedeagatch,Dedeağaç,Dedéagach,alyksandrwbwly,Αλεξανδρούπολη,Αλεξανδρούπολις,Александруполис,Дедеагач,أليكساندروبولي', 40.8499500, 25.8764400, 'GR', '2016-11-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63565, 'Alexándreia', 'Alexandreia', 'Alexandreia,Alexandria,Alexándreia,Alexándria,Gida,Gidha,Gidhas,Gidhá,Gidhás,Yidha,Yidhas,Yidhá,Yidhás,Αλεξάνδρεια', 40.6266700, 22.4441700, 'GR', '2012-03-04', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63566, 'Akriní', 'Akrini', 'Akrini,Akriní,Ineova,Ineóva,Ακρινή', 40.4349200, 21.9060900, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63567, 'Aigínio', 'Aiginio', 'Aiginio,Aiginion,Aigínio,Aigínion,Aiyinion,Aiylnion,Aiyínion,Eginion,Libanovo,Libanovon,Libánovon,Αιγίνιο,Αιγίνιον', 40.5013900, 22.5400000, 'GR', '2012-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63568, 'Aianí', 'Aiani', 'Aiani,Aianí,Kalliani,Kallianí,Αιανή', 40.1638100, 21.8194500, 'GR', '2014-06-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63569, 'Áfytos', 'Afytos', 'Afitos,Afytos,Athitos,Athytos,Áfitos,Áfytos,Áthitos,Άθυτος,Άφυτος', 40.0991500, 23.4367000, 'GR', '2014-08-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63570, 'Ádendro', 'Adendro', 'Adendro,Adendron,Adhendhron,Adhendron,Kirjilar,Kirjilár,Ádendro,Ádendron,Ádhendhron,Ádhendron,Άδενδρο,Άδενδρον', 40.6713100, 22.6046600, 'GR', '2014-03-08', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63571, 'Eirinoúpoli', 'Eirinoupoli', 'Eirinoupoli,Eirinoúpoli', 40.6780600, 22.1927800, 'GR', '2012-01-20', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63572, 'Ágios Pávlos', 'Agios Pavlos', 'Agios Pavlos,Agios Paylos,Ágios Pávlos,Άγιος Πάυλος,Άγιος Παύλος', 40.6407500, 22.9603900, 'GR', '2014-03-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63573, 'Triandría', 'Triandria', 'Triandria,Triandría,Τριανδρία', 40.6150000, 22.9762000, 'GR', '2015-05-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63574, 'Melíssi', 'Melissi', 'Melissi,Melission,Melíssi,Melíssion,Μελίσσι,Μελίσσιον', 40.7740600, 22.3530400, 'GR', '2014-03-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63575, 'Virós', 'Viros', 'Ano Virou,Biros,Viros,Virós,Áno Viroú,Βιρός', 39.5834000, 19.8827000, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63576, 'Potamós', 'Potamos', 'Potamos,Ποταμός', 39.6242000, 19.8782600, 'GR', '2014-06-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63577, 'Kontokáli', 'Kontokali', 'Kondokali,Kondokalion,Kondokálion,Kondókali,Kontokali,Kontokalion,Kontokáli,Kontokálion,Κοντοκάλι,Κοντοκάλιον', 39.6443600, 19.8519400, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63578, 'Kynopiástes', 'Kynopiastes', 'Kinopiastai,Kinopiastais,Kinopiástai,Kinopiástais,Kynopiastai,Kynopiastes,Kynopiástai,Κυνοπιάσται,Κυνοπιάστες', 39.5678500, 19.8836200, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63579, 'Corfu', 'Corfu', 'CFU,Corcyra,Corfou,Corfu,Corfù,Corfú,Kerkira,Kerkyra,Korfu,Krf,Kérkyra,ke ji la shi,keleukila,kerukira,qwrpw,shhr kwrfw,Κέρκυρα,Керкира,Керкіра,Корфу,Крф,קורפו,شهر کورفو,ケルキラ,克基拉市,케르키라', 39.6206900, 19.9197500, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63580, 'Kanáli', 'Kanali', 'Kanali,Kanali Lemendion,Kanalion,Kanalion Lemendion,Kanalion Lemention,Kanáli Lemendíon,Kanálion,Kanálion Lemendíon,Kanálion Lementíon,Κανάλι,Κανάλιον', 39.6055600, 19.8925000, 'GR', '2014-06-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63581, 'Ágios Matthaíos', 'Agios Matthaios', 'Aghios Matheos,Agios Mathaios,Agios Matthaios,Ayios Matthaios,Mathaios,Ágios Matthaíos,Áyios Matthaíos,Άγιος Ματθαίος', 39.4950600, 19.8733600, 'GR', '2014-10-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63582, 'Alepoú', 'Alepou', 'Alepou,Alepoú,Αλεπού', 39.6159400, 19.8956400, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63583, 'Vrilissia', 'Vrilissia', 'Vrilissia,Βριλήσσια', 38.0338100, 23.8296200, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63584, 'Faliraki', 'Faliraki', 'Faliraki,Φαληράκι,Фалираки', 36.3398100, 28.1994200, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63585, 'Acharávi', 'Acharavi', 'Acharavi,Αχαράβη', 39.7936000, 19.8173600, 'GR', '2014-06-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63586, 'Agios Georgis', 'Agios Georgis', 'Aghios Georgios,Agios Georgios,Agios-Georgios,Агиос Георгиос,Агиос-Георгиос', 39.7236300, 19.6996900, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63587, 'Nikiti', 'Nikiti', 'Elia Nikiti,Nikiti,Νικήτη,Никити', 40.2211600, 23.6666100, 'GR', '2017-05-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63588, 'Georgioupolis', 'Georgioupolis', 'Georgiopoli,Георгиополи', 35.3622500, 24.2601300, 'GR', '2014-05-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63589, 'Ornós', 'Ornos', 'Ornos,Ορνός', 37.4239100, 25.3224800, 'GR', '2015-08-14', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63590, 'Pánormos', 'Panormos', 'Brosta,Panormos,Μπροστά,Πάνορμος', 36.9715600, 26.9372700, 'GR', '2016-02-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63591, 'Káto Goúves', 'Kato Gouves', 'Kato Gouves,Κάτω Γούβες', 35.3293400, 25.3135300, 'GR', '2015-10-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63592, 'Saronída', 'Saronida', 'Nkiourntas,Saronida,Saronis,Saronída,Saronís,Γκιουρντάς,Σαρωνίδα,Σαρωνίς', 37.7480900, 23.9105900, 'GR', '2015-12-06', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63593, 'Ymittos', 'Ymittos', 'Imittos,Ymetto,Ymittos Attikis,amytws,Υμηττός Αττικής,إميتوس', 37.9534200, 23.7489700, 'GR', '2012-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63594, 'Gérakas', 'Gerakas', 'Gerakas,Gérakas,Γέρακας', 38.0227700, 23.8576000, 'GR', '2014-09-10', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63595, 'Megálo Chorió', 'Megalo Chorio', 'Megalo Chorio,Megálo Chorió,Μεγάλο Χωριό', 37.4582000, 26.9727200, 'GR', '2016-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63596, 'Paralía Ofryníou', 'Paralia Ofryniou', 'Paralia Ofryniou,Touzla,Παραλία Οφρυνίου,Τούζλα', 40.7666300, 23.9003900, 'GR', '2014-08-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63597, 'Agía Kyriakí', 'Agia Kyriaki', 'Agia Kyriaki,Agía Kyriakí,Αγία Κυριακή', 39.5226400, 20.8835800, 'GR', '2015-02-02', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63598, 'Agía Foteiní', 'Agia Foteini', 'Agia Foteini,Agía Foteiní,Αγία Φωτεινή', 35.2545900, 24.6349500, 'GR', '2013-01-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63599, 'Ilioúpoli', 'Ilioupoli', 'Ilioupoli,Ilioúpoli,Ηλιούπολη', 37.9314900, 23.7677900, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63600, 'Korydallós', 'Korydallos', 'Korydallos,Korydallós,Κορυδαλλός', 37.9846800, 23.6471100, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63601, 'Zográfos', 'Zografos', 'Zografos,Zografou,Zográfos,Ζωγράφος,Ζωγράφου', 37.9757400, 23.7691100, 'GR', '2016-06-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63602, 'Péfki', 'Pefki', 'Pefki,Pevki,Péfki,Pévki,Πεύκη', 38.0601900, 23.7926400, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63603, 'Ágioi Anárgyroi', 'Agioi Anargyroi', 'Agioi Anargyroi,Ágioi Anárgyroi,Άγιοι Ανάργυροι', 38.0301300, 23.7237900, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63604, 'Ampelókipoi', 'Ampelokipoi', 'Ampelokipoi,Ampelókipoi,Αμπελόκηποι', 40.6530400, 22.9262400, 'GR', '2014-01-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63605, 'Foúrnoi', 'Fournoi', 'Fournoi,Foúrnoi,Φούρνοι', 37.5785000, 26.4806900, 'GR', '2016-06-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63606, 'Néa Potídhaia', 'Nea Potidhaia', 'Nea Potidaia,Nea Potidea,Potidaia,Νέα Ποτίδαια,Ποτίδαια', 40.1942800, 23.3287400, 'GR', '2016-01-05', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63607, 'Agios Ioannis Rentis', 'Agios Ioannis Rentis', 'Agios Ioannis Rentis,Rentis,Άγιος Ιωάννης Ρέντης,Ρέντης', 37.9649100, 23.6651100, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63608, 'Violí Charáki', 'Violi Charaki', 'Violi Charaki,Violí Charáki,Βιολί Χαράκι', 35.3586400, 24.4385700, 'GR', '2015-11-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63609, 'Néa Anatolí', 'Nea Anatoli', 'Nea Anatoli,Néa Anatolí,Νέα Ανατολή', 35.0092000, 25.6617000, 'GR', '2015-09-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63610, 'Drapetsóna', 'Drapetsona', 'Drapetsona,Δραπετσώνα', 37.9498800, 23.6230900, 'GR', '2013-12-31', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63611, 'Néo Psychikó', 'Neo Psychiko', 'Neo Psychiko,Νέο Ψυχικό', 38.0062400, 23.7837300, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63612, 'Chlói', 'Chloi', 'Chloi,Chlói,Khloi,Neo Tsifliki,Neon Tsiflikion,Nov chiflik,Νέο Τσιφλίκι,Νέον Τσιφλίκιον,Χλόη,Χλόι,Нов чифлик,Хлои', 40.5391800, 21.2592300, 'GR', '2015-04-01', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63613, 'Varybóbi', 'Varybobi', 'Varympompi,Βαρυμπόμπη', 38.1272300, 23.7872900, 'GR', '2014-05-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63614, 'Aghios Panteleímon', 'Aghios Panteleimon', 'Agios Panteleimon Marathona,Agios Panteleimon Marathóna,Άγιος Παντελεήμων Μαραθώνα', 38.1164300, 23.9818200, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63615, 'Anthoúsa', 'Anthousa', 'Anthousa,Anthoussa,Anthoúsa,Panagia Anthousis,Ανθούσα,Παναγιά Ανθούσης', 38.0254400, 23.8761700, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63616, 'Néa Vrasná', 'Nea Vrasna', 'Nea Vrasna,Νέα Βρασνά,Неа Врасна', 40.7059200, 23.6985000, 'GR', '2014-06-13', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63617, 'Néa Ionía', 'Nea Ionia', 'Nea Ionia,Nea Jonija,Nea-Ionija,Néa Ionía,Νέα Ιωνία,Неа Йония,Неа-Іонія', 39.3790400, 22.9275200, 'GR', '2015-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63618, 'Zefyri', 'Zefyri', 'Zefiri,Zefyri,Ζεφύρι', 38.0664700, 23.7170100, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63619, 'Thrakomakedónes', 'Thrakomakedones', 'Thrakomakedones,Θρακομακεδόνες', 38.1296400, 23.7575100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63620, 'Néa Pentéli', 'Nea Penteli', 'Nea Penteli,Νέα Πεντέλη', 38.0605900, 23.8592600, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63621, 'Néa Chalkidóna', 'Nea Chalkidona', 'Nea Chalkidona,Νέα Χαλκηδόνα', 38.0271000, 23.7305100, 'GR', '2014-08-26', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63622, 'Kítsi', 'Kitsi', 'Kitsi,Κίτσι', 37.8518100, 23.8406800, 'GR', '2014-05-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63623, 'Agía Marína', 'Agia Marina', 'Agia Marina,Ayia Marina,Αγία Μαρίνα', 37.8203600, 23.8442400, 'GR', '2014-05-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63624, 'Agios Dimítrios Kropiás', 'Agios Dimitrios Kropias', 'Agios Dimitrios Kropias,Άγιος Δημήτριος Κρωπίας', 37.8061200, 23.8579300, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63625, 'Karellás', 'Karellas', 'Karellas,Καρελλάς', 37.9344500, 23.8648400, 'GR', '2014-05-19', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63626, 'Neos Voutzás', 'Neos Voutzas', 'Neos Voutzas,Νέος Βουτζάς', 38.0431200, 23.9774900, 'GR', '2014-05-21', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63627, 'Argithéa', 'Argithea', 'Argithea,Αργιθέα', 37.9768800, 23.8871500, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63628, 'Dióni', 'Dioni', 'Dioni,Διώνη', 38.0232800, 23.9328600, 'GR', '2014-05-22', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63629, 'Vlycháda', 'Vlychada', 'Vlychada,Βλυχάδα', 38.0273400, 23.4366300, 'GR', '2014-05-23', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63630, 'Pérama', 'Perama', 'Perama,Πέραμα', 39.5828900, 19.9122000, 'GR', '2014-06-12', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63631, 'Loutrá Oraías Elénis', 'Loutra Oraias Elenis', 'Loutra Elenis,Loutra Oraias Elenis,Λουτρά Ελένης,Λουτρά Ωραίας Ελένης', 37.8646600, 22.9961400, 'GR', '2014-08-25', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63632, 'Paralía Vérgas', 'Paralia Vergas', 'Agrilia,Agriliá,Paralia Vergas,Αγριλιά,Παραλία Βέργας', 37.0070800, 22.1567600, 'GR', '2015-01-17', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63633, 'Kardamítsia', 'Kardamitsia', 'Kardamitsia,Καρδαμίτσια', 39.6781600, 20.8195600, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63634, 'Tsiflikópoulo', 'Tsiflikopoulo', 'Tsiflikopoulo,Τσιφλικόπουλο', 39.6562400, 20.8388200, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63635, 'Eksochí', 'Eksochi', 'Eksochi,Exochi,Εξοχή', 39.6874400, 20.8224000, 'GR', '2015-03-30', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63636, 'Pláka Dílesi', 'Plaka Dilesi', 'Plaaka Dilesi,Plaka Dilesi,Πλαάκα Δήλεσι', 38.3495000, 23.6505600, 'GR', '2015-04-27', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63637, 'Anakasiá', 'Anakasia', 'Anakasia,Ανακασιά', 39.3811200, 22.9748400, 'GR', '2015-09-09', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63638, 'Iliokentima', 'Iliokentima', 'Heliokentima,Iliokentima,Ηλιοκέντημα', 40.9493100, 24.7885900, 'GR', '2017-07-28', 86);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63980, 'Piti Village', 'Piti Village', 'Petey,Piti Vilage,Piti Village', 13.4625600, 144.6933100, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63981, 'Santa Rita Village', 'Santa Rita Village', 'Santa Rita', 13.3860800, 144.6722600, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63982, 'Sinajana Village', 'Sinajana Village', 'Sinahanna', 13.4633400, 144.7540600, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63983, 'Talofofo Village', 'Talofofo Village', 'Pre-WW2 Part of Inarajan,Talo''fo''fo,Talo`fo`fo', 13.3551300, 144.7583500, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63984, 'Tamuning-Tumon-Harmon Village', 'Tamuning-Tumon-Harmon Village', 'Maria Christina,Timoneng', 13.4877300, 144.7813800, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63985, 'Umatac Village', 'Umatac Village', 'Humatak,Humåtak,San Antonio de Umatag,Umatag,Ville D''Umata', 13.2984300, 144.6631400, 'GU', '2016-07-18', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63986, 'Yigo Village', 'Yigo Village', 'Yigu', 13.5360500, 144.8885500, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63987, 'Yona Village', 'Yona Village', 'Yo'' na,Yo`na,Yo’ ña', 13.4097400, 144.7769700, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63988, 'Merizo Village', 'Merizo Village', 'Maleso,Malesso,Merico', 13.2658400, 144.6690800, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63989, 'Inarajan Village', 'Inarajan Village', 'Inalahan,Inalajan,Inalåhan', 13.2736300, 144.7484500, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63990, 'Agana Heights Village', 'Agana Heights Village', 'Agana Heights,Hagatna Heights,Tutuhan', 13.4655900, 144.7479500, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63991, 'Guam Government House', 'Guam Government House', 'Designer Architect Richard Neutra', 13.4719100, 144.7497800, 'GU', '2011-07-01', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63992, 'Chalan Pago-Ordot Village', 'Chalan Pago-Ordot Village', 'Chalan Pagu,Chalan Pagu-Otdot,Chalan Pågu-Otdot', 13.4474100, 144.7590200, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63993, 'Barrigada Village', 'Barrigada Village', 'Barigada,Barigåda', 13.4691300, 144.7990100, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63994, 'Agat Village', 'Agat Village', 'Hagat,Hågat', 13.3885500, 144.6585200, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63995, 'Asan-Maina Village', 'Asan-Maina Village', 'Assan', 13.4721500, 144.7165400, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63996, 'Dededo Village', 'Dededo Village', 'Dedidu', 13.5177700, 144.8391000, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63997, 'Hagåtña', 'Hagatna', 'Agadna,Agana,Agana -1998,Agania,Aganija,Aganja,Agano,Agaña,Aguana,Akashi,Akashi - JP renamed WW2,Ankana,City of Ignacio de Agana,City of Saint Ignacio de Agana,Ciudad de San Ignacio de Agana,Hagadna,Hagatna,Hagåtña,Haqatna,Jagatna,Khagatna,San Ignacio de Agana *,Ville d''Agana,Vjoska Agan''ja,a jia ni ya,akatna,ha katya,hagania,hagasnya,hagatna,hagatnya,haghatnya,hegatn''ya,Αγκάνα,Вёска Аганья,Хагатна,Хагатња,Հագատնա,هاغاتنيا,هاگاتنا,هاگاتنیا,हेगात्न्या,அகாத்ன,ฮากาตญา,ჰაგატნა,ハガニア,阿加尼亚,하갓냐', 13.4756700, 144.7488600, 'GU', '2011-10-19', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63998, 'Mangilao Village', 'Mangilao Village', 'Manguilao,Manguuao', 13.4476100, 144.8010900, 'GU', '2013-06-30', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63999, 'Mongmong-Toto-Maite Village', 'Mongmong-Toto-Maite Village', '', 13.4685700, 144.7821400, 'GU', '2013-07-07', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64000, 'Hagåtña Village', 'Hagatna Village', 'Agana -1998,Akashi WW2', 13.4727900, 144.7580200, 'GU', '2011-10-19', 90);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63640, 'Zunilito', 'Zunilito', 'Zunilito', 14.6166700, -91.5166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63641, 'Zunil', 'Zunil', 'Zunil', 14.7833300, -91.4833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63642, 'Zaragoza', 'Zaragoza', 'Zaragoza', 14.6544400, -90.8894400, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63643, 'Zapotitlán', 'Zapotitlan', 'Zapotitlan,Zapotitlán', 14.1333300, -89.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63644, 'Zacualpa', 'Zacualpa', 'Zacualpa', 15.0833300, -90.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63645, 'Zacapa', 'Zacapa', 'Sakapa,Zacapa,Сакапа', 14.9722200, -89.5305600, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63646, 'Yupiltepeque', 'Yupiltepeque', 'Tupiltepeque,Yupiltepeque', 14.2000000, -89.7833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63647, 'Yepocapa', 'Yepocapa', 'San Pedro Yepocapa,Yepocapa', 14.5041700, -90.9569400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63648, 'Villa Nueva', 'Villa Nueva', 'Vil''ja-Nuehva,Vilja Nueva,Viljanueva,Villa Nueva,bi ya nu ai wa,wya nwywa  gwatymala,Вилья-Нуэва,Вилянуева,ویا نویوا، گواتیمالا,比亞努埃瓦', 14.5269400, -90.5875000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63649, 'Villa Canales', 'Villa Canales', 'Villa Anales,Villa Canales', 14.4813900, -90.5316700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63650, 'Usumatlán', 'Usumatlan', 'Usumatlan,Usumatlán,Uzumatlan,Uzumatlán', 14.9500000, -89.7833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63651, 'Uspantán', 'Uspantan', 'San Miguel Uspantan,San Miguel Uspantán,Uspantan,Uspantán', 15.3833300, -90.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63652, 'Unión', 'Union', 'La Union,La Unión,Union,Unión', 15.9217600, -91.7764700, 'GT', '2017-07-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63653, 'Tucurú', 'Tucuru', 'San Miguel Tucuru,San Miguel Tucurú,Tucuru,Tucurú', 15.3000000, -90.0666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63654, 'Totonicapán', 'Totonicapan', 'Totonicapan,Totonicapán,Totonikapan,Тотоникапан', 14.9116700, -91.3611100, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63655, 'Todos Santos Cuchumatán', 'Todos Santos Cuchumatan', 'Cuchumatan,Todos Santos,Todos Santos Cuchumatan,Todos Santos Cuchumatanes,Todos Santos Cuchumatán', 15.5084600, -91.6038200, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63656, 'Tejutla', 'Tejutla', 'Tejutla', 15.1225400, -91.8063500, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63657, 'Teculután', 'Teculutan', 'Teculutan,Teculután', 14.9833300, -89.7166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63658, 'Tectitán', 'Tectitan', 'Tectipan,Tectitan,Tectitlan,Tectitán', 15.3063000, -92.0605100, 'GT', '2017-06-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63659, 'Tecpán Guatemala', 'Tecpan Guatemala', 'Tecpam,Tecpan,Tecpan Guatemala,Tecpán,Tecpán Guatemala', 14.7669400, -90.9941700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63660, 'Taxisco', 'Taxisco', 'Taxisco', 14.0671900, -90.4679100, 'GT', '2014-07-01', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63661, 'Tamahú', 'Tamahu', 'Tamahu,Tamahú', 15.3089000, -90.2359900, 'GT', '2014-07-24', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63662, 'Tajumulco', 'Tajumulco', 'Tajumulco', 15.0834900, -91.9222500, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63663, 'Tactic', 'Tactic', 'Tactic', 15.3221800, -90.3544800, 'GT', '2014-07-24', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63664, 'Tacaná', 'Tacana', 'Tacana,Tacaná', 15.2405800, -92.0672100, 'GT', '2017-06-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63665, 'Sumpango', 'Sumpango', 'Sumpango', 14.6463900, -90.7338900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63666, 'Soloma', 'Soloma', 'San Pedro Soloma,Soloma', 15.6584100, -91.4299400, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63667, 'Sololá', 'Solola', 'Solola,Sololá,Солола', 14.7722200, -91.1833300, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63668, 'Siquinalá', 'Siquinala', 'Siquinala,Siquinalá', 14.3061100, -90.9650000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63669, 'Sipacapa', 'Sipacapa', 'Sipacapa', 15.2124600, -91.6341600, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63670, 'Sibinal', 'Sibinal', 'Sabinal,Sibinal,Sivinal', 15.1496300, -92.0489200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63671, 'Sibilia', 'Sibilia', 'Sibilia', 15.0000000, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63672, 'Senahú', 'Senahu', 'Senahu,Senahú', 15.4000000, -89.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63673, 'Sayaxché', 'Sayaxche', 'Sayaxche,Sayaxché,Sayazche,Sayazché', 16.5244600, -90.1880100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63674, 'San Vicente Pacaya', 'San Vicente Pacaya', 'San Vicente,San Vicente Martir,San Vicente Mártir,San Vicente Pacaya', 14.4161100, -90.6391700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63675, 'Santo Tomás La Unión', 'Santo Tomas La Union', 'Santo Tomas La Union,Santo Tomás La Unión', 14.6333300, -91.3833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63676, 'Santo Domingo Xenacoj', 'Santo Domingo Xenacoj', 'Santa Domingo Xenacoj,Santo Domingo Xecanoj,Santo Domingo Xenacoj,Xenacoj,Xenaeoj', 14.6777800, -90.6977800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63677, 'Santo Domingo Suchitepéquez', 'Santo Domingo Suchitepequez', 'Santo Domingo,Santo Domingo Suchitepequez,Santo Domingo Suchitepéquez', 14.4666700, -91.4833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63678, 'Santiago Sacatepéquez', 'Santiago Sacatepequez', 'Santiago,Santiago Sacatepequez,Santiago Sacatepéquez', 14.6352800, -90.6763900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63679, 'Santiago Chimaltenango', 'Santiago Chimaltenango', 'Chimaltenango,Santiago Chimaltenango', 15.4765800, -91.6965600, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63680, 'Santiago Atitlán', 'Santiago Atitlan', 'Atitlan,Atitlán,Santiago', 14.6382300, -91.2290100, 'GT', '2008-03-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63681, 'Santa Rosa de Lima', 'Santa Rosa de Lima', 'Santa Rosa,Santa Rosa de Lima,Santa Rose de Lima', 14.3880600, -90.2955600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63682, 'Santa María Visitación', 'Santa Maria Visitacion', 'Santa Maria Visitacion,Santa María Visitación', 14.7166700, -91.3166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63683, 'Santa María Ixhuatán', 'Santa Maria Ixhuatan', 'Ixhuatan,Ixhuatán,Santa Maria Ixhuatan,Santa María Ixhuatán', 14.1900000, -90.2747200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63684, 'Santa María de Jesús', 'Santa Maria de Jesus', 'Santa Maria,Santa Maria de Jesus,Santa María,Santa María de Jesús', 14.5183300, -90.7266700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63685, 'Santa María Chiquimula', 'Santa Maria Chiquimula', 'Santa Maria Chiquimula,Santa María Chiquimula', 15.0299200, -91.3292000, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63686, 'Santa Lucía Utatlán', 'Santa Lucia Utatlan', 'Santa Lucia,Santa Lucia Utatlan,Santa Lucía,Santa Lucía Utatlán', 14.7666700, -91.2666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63687, 'Santa Lucía Milpas Altas', 'Santa Lucia Milpas Altas', 'Santa Lucia,Santa Lucia Milpas Altas,Santa Lucía,Santa Lucía Milpas Altas', 14.5758300, -90.6786100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63688, 'Santa Lucia La Reforma', 'Santa Lucia La Reforma', 'Santa Lucia La Reforma,Santa Lucía La Reforma', 15.1281900, -91.2361900, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63689, 'Santa Lucía Cotzumalguapa', 'Santa Lucia Cotzumalguapa', 'Santa Lucia,Santa Lucia Cotzumalguapa,Santa Lucía,Santa Lucía Cotzumalguapa', 14.3333300, -91.0166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63690, 'Santa Eulalia', 'Santa Eulalia', 'Santa Eulalia', 15.7306000, -91.4584600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63691, 'Santa Cruz Verapaz', 'Santa Cruz Verapaz', 'Santa Cruz,Santa Cruz Verapaz', 15.3666700, -90.4333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63692, 'Santa Cruz Naranjo', 'Santa Cruz Naranjo', 'Santa Cruz,Santa Cruz Naranjo', 14.3880600, -90.3697200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63693, 'Santa Cruz Muluá', 'Santa Cruz Mulua', 'Mulua,Muluá,Santa Cruz Mulua,Santa Cruz Muluá', 14.5833300, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63694, 'Santa Cruz La Laguna', 'Santa Cruz La Laguna', 'Santa Cruz,Santa Cruz La Laguna', 14.7500000, -91.2166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63695, 'Santa Cruz del Quiché', 'Santa Cruz del Quiche', 'AQB,Santa Cruz del Quiche,Santa Cruz del Quiché,Santa-Krus-del''-Kiche,Санта-Крус-дель-Киче', 15.0308500, -91.1487100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63696, 'Santa Cruz Balanyá', 'Santa Cruz Balanya', 'Santa Cruz Balanya,Santa Cruz Balanyá', 14.6872200, -90.9150000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63697, 'Santa Clara La Laguna', 'Santa Clara La Laguna', 'Santa Clara,Santa Clara La Laguna', 14.7166700, -91.3000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63698, 'Santa Catarina Pinula', 'Santa Catarina Pinula', 'Santa Catarina Pinula', 14.5688900, -90.4952800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63699, 'Santa Catarina Palopó', 'Santa Catarina Palopo', 'Santa Catalina,Santa Catarina,Santa Catarina Palopo,Santa Catarina Palopó', 14.7166700, -91.1333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63700, 'Santa Catarina Mita', 'Santa Catarina Mita', 'Santa Catarina Mita', 14.4500000, -89.7500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63701, 'Santa Catarina Ixtahuacán', 'Santa Catarina Ixtahuacan', 'Santa Catarina Ixtahuacan,Santa Catarina Ixtahuacán', 14.8000000, -91.3666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63702, 'Santa Catarina Barahona', 'Santa Catarina Barahona', 'Santa Catalina,Santa Catarina,Santa Catarina Barahona', 14.5488900, -90.7883300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63703, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 15.3161700, -91.6327900, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63704, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 14.4333300, -91.2333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63705, 'Santa Apolonia', 'Santa Apolonia', 'Santa Apolonia', 14.7913900, -90.9708300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63706, 'Santa Ana Huista', 'Santa Ana Huista', 'Santa Ana Huista', 15.6808500, -91.8200500, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63707, 'Santa Ana', 'Santa Ana', 'Santa Ana', 16.8000000, -89.8333300, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63708, 'San Sebastián Huehuetenango', 'San Sebastian Huehuetenango', 'San Sebastian,San Sebastian Huehuetenango,San Sebastián,San Sebastián Huehuetenango', 15.3876800, -91.6153000, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63709, 'San Sebastián Coatán', 'San Sebastian Coatan', 'San Sebastian Coatan,San Sebastián Coatán', 15.7358400, -91.5628500, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63710, 'San Sebastián', 'San Sebastian', 'San Sebastian,San Sebastián', 14.5666700, -91.6500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63711, 'Sansare', 'Sansare', 'Sansare', 14.7472200, -90.1125000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63712, 'San Raimundo', 'San Raimundo', 'San Raimundo,San Raymundo', 14.7647200, -90.5955600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63713, 'San Rafael Pie de La Cuesta', 'San Rafael Pie de La Cuesta', 'San Rafael,San Rafael Pie Cuesta,San Rafael Pie de La Cuesta,San Rafael Pie la Cuesta,San Rafael Pié la Cuesta', 14.9333300, -91.9166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63714, 'San Rafael Petzal', 'San Rafael Petzal', 'San Rafael,San Rafael Petzal', 15.4048700, -91.6645100, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63715, 'San Rafael Las Flores', 'San Rafael Las Flores', 'San Rafael,San Rafael Las Flores', 14.4813900, -90.1733300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63716, 'San Rafael La Independencia', 'San Rafael La Independencia', 'San Rafael Independencia,San Rafael La Independencia', 15.7015000, -91.5355300, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63717, 'San Pedro Sacatepéquez', 'San Pedro Sacatepequez', 'San Pedra,San Pedro,San Pedro Sacatepequez,San Pedro Sacatepéquez,San Pedro Zacatepec,sheng pei de luo sa ka te pei ke si,聖佩德羅薩卡特佩克斯', 14.9666700, -91.7666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63718, 'San Pedro Sacatepéquez', 'San Pedro Sacatepequez', 'San Pedro Sacatepequez,San Pedro Sacatepéquez', 14.6841700, -90.6441700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63719, 'San Pedro Pinula', 'San Pedro Pinula', 'San Pedro Pinula', 14.6666700, -89.8500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63720, 'San Pedro Necta', 'San Pedro Necta', 'San Pedro Necta', 15.4914200, -91.7655100, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63721, 'San Pedro La Laguna', 'San Pedro La Laguna', 'San Pedro,San Pedro La Laguna', 14.6929700, -91.2720100, 'GT', '2015-03-26', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63722, 'San Pédro Jocopilas', 'San Pedro Jocopilas', 'San Pedro Jocopilas,San Pédro Jocopilas', 15.0952500, -91.1513500, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63723, 'San Pedro Carchá', 'San Pedro Carcha', 'Carcha,Carchá,San Pedro Carcha,San Pedro Carchá', 15.4833300, -90.2666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63724, 'San Pedro Ayampuc', 'San Pedro Ayampuc', 'San Pedro Ayampuc', 14.7866700, -90.4511100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63725, 'San Pablo La Laguna', 'San Pablo La Laguna', 'San Pablo,San Pablo La Laguna,San Pablo Laguna', 14.7166700, -91.2666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63726, 'San Pablo Jocopilas', 'San Pablo Jocopilas', 'San Pablo,San Pablo Jocopilas', 14.5833300, -91.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63727, 'San Pablo', 'San Pablo', 'San Pablo', 14.9328100, -92.0041400, 'GT', '2017-06-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63728, 'San Miguel Sigüilá', 'San Miguel Siguila', 'San Miguel Siguila,San Miguel Sigüilá,Siguila,Sigüilá', 14.9000000, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63729, 'San Miguel Panán', 'San Miguel Panan', 'Panan,Panán,San Miguel Panan,San Miguel Panán', 14.5333300, -91.3666700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63730, 'San Miguel Ixtahuacán', 'San Miguel Ixtahuacan', 'San Miguel,San Miguel Ixtahuacan,San Miguel Ixtahuacán', 15.2724700, -91.7478500, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63731, 'San Miguel Dueñas', 'San Miguel Duenas', 'Duenas,Dueñas,San Miguel Duenas,San Miguel Dueñas', 14.5238900, -90.7983300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63732, 'San Miguel Chicaj', 'San Miguel Chicaj', 'San Miguel Chicaj', 15.1000000, -90.4000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63733, 'San Miguel Acatán', 'San Miguel Acatan', 'San Miguel Acatan,San Miguel Acatán', 15.7040100, -91.5977100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63734, 'San Mateo Ixtatán', 'San Mateo Ixtatan', 'San Mateo Ixtatan,San Mateo Ixtatán', 15.8319400, -91.4780600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63735, 'San Mateo', 'San Mateo', 'San Mateo', 14.8666700, -91.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63736, 'San Martín Zapotitlán', 'San Martin Zapotitlan', 'San Martin,San Martin Zapotitlan,San Martín,San Martín Zapotitlán', 14.6000000, -91.6000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63737, 'San Martín Sacatepéquez', 'San Martin Sacatepequez', 'San Martin,San Martin Sacatepequez,San Martín,San Martín Sacatepéquez', 14.8166700, -91.6500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63738, 'San Martín Jilotepeque', 'San Martin Jilotepeque', 'San Martin Jilotepeque,San Martín Jilotepeque', 14.7877800, -90.7925000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63739, 'San Marcos La Laguna', 'San Marcos La Laguna', 'San Marcos,San Marcos La Laguna', 14.7166700, -91.2666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63740, 'San Marcos', 'San Marcos', 'La Union,San Marcos,San Marcos La Union,San Markosas,San-Markos,sanmaleukoseu,sheng ma ke si,Сан-Маркос,聖馬科斯,산마르코스', 14.9638900, -91.7944400, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63741, 'San Manuel Chaparrón', 'San Manuel Chaparron', 'Chaparron,Chaparrón,San Manuel Chaparron,San Manuel Chaparrón', 14.5166700, -89.7666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63742, 'San Luis Jilotepeque', 'San Luis Jilotepeque', 'Jilotepeque,San Luis,San Luis Jilotepeque', 14.6500000, -89.7333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63743, 'San Luis Ixcán', 'San Luis Ixcan', '', 15.7872200, -91.0950000, 'GT', '2006-01-17', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63744, 'San Luis', 'San Luis', 'San Luis', 16.1988900, -89.4402800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63745, 'San Lucas Tolimán', 'San Lucas Toliman', 'San Lucas,San Lucas Toliman,San Lucas Tolimán', 14.5947100, -91.1465900, 'GT', '2014-07-23', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63746, 'San Lucas Sacatepéquez', 'San Lucas Sacatepequez', 'San Lucas,San Lucas Sacatepequez,San Lucas Sacatepéquez', 14.6097200, -90.6569400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63747, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 15.0308700, -91.7353400, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63748, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 14.4833300, -91.5166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63749, 'San Juan Tecuaco', 'San Juan Tecuaco', 'San Juan Tecuaco,Tecuaco', 14.0822200, -90.2611100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63750, 'San Juan Sacatepéquez', 'San Juan Sacatepequez', 'San Juan Sacatepequez,San Juan Sacatepéquez', 14.7188900, -90.6441700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63751, 'San Juan La Laguna', 'San Juan La Laguna', 'San Juan,San Juan La Laguna', 14.7000000, -91.2833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63752, 'San Juan Ixcoy', 'San Juan Ixcoy', 'San Juan Ixcoy', 15.6002200, -91.4463900, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63753, 'San Juan Ermita', 'San Juan Ermita', 'San Juan Ermita,San Juan de la Ermita', 14.7666700, -89.4333300, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63754, 'San Juan Cotzal', 'San Juan Cotzal', 'San Juan Cotzal', 15.4336800, -91.0348100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63755, 'San Juan Chamelco', 'San Juan Chamelco', 'Chamelco,San Juan Chamelco', 15.4333300, -90.3333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63756, 'San Juan Bautista', 'San Juan Bautista', 'San Juan,San Juan Bautista', 14.4166700, -91.1833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63757, 'San Juan Atitán', 'San Juan Atitan', 'San Juan Atitan,San Juan Atitlan,San Juan Atitlán,San Juan Atitán', 15.4288600, -91.6239800, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63758, 'San José Poaquil', 'San Jose Poaquil', 'San Jose Poaquil,San José Poaquil', 14.8197200, -90.9063900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63759, 'San José Pinula', 'San Jose Pinula', 'San Jose Pinula,San José Pinula', 14.5461100, -90.4113900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63760, 'San José Ojetenán', 'San Jose Ojetenan', '', 15.2166700, -91.9666700, 'GT', '2006-01-17', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63761, 'San José Ojetenam', 'San Jose Ojetenam', 'San Jose Ixjoyon,San Jose Ixjoyon Ojetenan,San Jose Ojetenam,San Jose Ojetenan,San José Ixjoyón,San José Ixjoyón Ojetenán,San José Ojetenam,San José Ojetenán', 15.2344300, -91.9731700, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63762, 'San José La Arada', 'San Jose La Arada', 'San Jose Arada,San Jose La Arada,San José Arada,San José La Arada', 14.7166700, -89.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63763, 'San José El Ídolo', 'San Jose El Idolo', 'San Jose El Idolo,San José El Ídolo', 14.4500000, -91.4166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63764, 'San José del Golfo', 'San Jose del Golfo', 'San Jose El Golfo,San Jose del Golfo,San José El Golfo,San José del Golfo', 14.7627800, -90.3763900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63765, 'San José Chacayá', 'San Jose Chacaya', 'San Jose,San Jose Chacaya,San José,San José Chacayá', 14.7666700, -91.2166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63766, 'San José Acatempa', 'San Jose Acatempa', 'Acatempa,San Jose Acatempa,San José Acatempa', 14.2652800, -90.1269400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63767, 'San José', 'San Jose', 'San Jose,San José', 16.9833300, -89.9000000, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63768, 'San Jorge', 'San Jorge', 'San Jorge', 14.9333300, -89.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63769, 'San Jerónimo', 'San Jeronimo', 'San Jeronimo,San Jerónimo', 15.0603200, -90.2405000, 'GT', '2015-04-24', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63770, 'San Jacinto', 'San Jacinto', 'San Jacinto', 14.6666700, -89.5000000, 'GT', '2013-04-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63771, 'San Gaspar Ixchil', 'San Gaspar Ixchil', 'San Gaspar,San Gaspar Ixchil', 15.3879600, -91.7256400, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63772, 'San Gabriel', 'San Gabriel', 'San Gabriel', 14.5166700, -91.5166700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63773, 'San Francisco Zapotitlán', 'San Francisco Zapotitlan', 'San Francisco Zapotitlan,San Francisco Zapotitlán', 14.5833300, -91.5166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63774, 'San Francisco La Unión', 'San Francisco La Union', 'San Francisco La Union,San Francisco La Unión', 14.9166700, -91.5333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63775, 'San Francisco El Alto', 'San Francisco El Alto', 'San Francisco,San Francisco El Alto', 14.9500000, -91.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63776, 'San Francisco', 'San Francisco', 'San Francisco', 16.8000000, -89.9333300, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63777, 'San Felipe', 'San Felipe', 'San Felipe', 14.6166700, -91.6000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63778, 'San Diego', 'San Diego', 'San Diego', 14.7833300, -89.7833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63779, 'San Cristóbal Verapaz', 'San Cristobal Verapaz', 'San Cristobal,San Cristobal Verapaz,San Cristóbal,San Cristóbal Verapaz', 15.3963200, -90.5651300, 'GT', '2014-07-24', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63780, 'San Cristóbal Totonicapán', 'San Cristobal Totonicapan', 'San Cristobal,San Cristobal Totonicapan,San Cristóbal,San Cristóbal Totonicapán', 14.9166700, -91.4333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63781, 'San Cristóbal Cucho', 'San Cristobal Cucho', 'San Cristobal,San Cristobal Cucho,San Cristóbal,San Cristóbal Cucho', 14.9000000, -91.7833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63782, 'San Cristóbal Acasaguastlán', 'San Cristobal Acasaguastlan', 'Acasaguastlan,Acasaguastlán,San Cristobal,San Cristobal Acasaguastlan,San Cristóbal,San Cristóbal Acasaguastlán', 14.9166700, -89.8833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63783, 'San Carlos Sija', 'San Carlos Sija', 'San Carlos,San Carlos Sija,Sija', 14.9833300, -91.5500000, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63784, 'San Carlos Alzatate', 'San Carlos Alzatate', 'Alzatate,San Carlos Alzatate', 14.4977800, -90.0602800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63785, 'San Bernardino', 'San Bernardino', 'San Bernardino', 14.5333300, -91.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63786, 'San Benito', 'San Benito', 'San Benito', 16.9167500, -89.9189800, 'GT', '2015-03-28', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63787, 'San Bartolomé Milpas Altas', 'San Bartolome Milpas Altas', 'San Barlotome Milpas Altas,San Barlotomé Milpas Altas,San Bartolome,San Bartolome Milpas Altas,San Bartolomé,San Bartolomé Milpas Altas', 14.6061100, -90.6800000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63788, 'San Bartolomé Jocotenango', 'San Bartolome Jocotenango', 'San Bartolome Jocotenango,San Bartolomé Jocotenango', 15.1915300, -91.0780600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63789, 'San Bartolo', 'San Bartolo', 'San Bartolo', 15.0843800, -91.4560600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63790, 'Sanarate', 'Sanarate', 'Sanarate', 14.7950000, -90.1922200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63791, 'San Antonio Suchitepéquez', 'San Antonio Suchitepequez', 'San Antonio,San Antonio Suchitepequez,San Antonio Suchitepéquez', 14.5333300, -91.4166700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63792, 'San Antonio Sacatepéquez', 'San Antonio Sacatepequez', 'San Antonio,San Antonio Sacatepequez,San Antonio Sacatepéquez', 14.9666700, -91.7333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63793, 'San Antonio Palopó', 'San Antonio Palopo', 'San Antonio,San Antonio Palopo,San Antonio Palopó', 14.7000000, -91.1166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63794, 'San Antonio La Paz', 'San Antonio La Paz', 'San Antonio La Paz', 14.7497200, -90.2866700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63795, 'San Antonio Ilotenango', 'San Antonio Ilotenango', 'San Antonio Ilotenango', 15.0547200, -91.2298600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63796, 'San Antonio Huista', 'San Antonio Huista', 'San Antonio Huista', 15.6501000, -91.7716300, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63797, 'San Antonio Aguas Calientes', 'San Antonio Aguas Calientes', 'San Antonio,San Antonio Aguas Calientes', 14.5397200, -90.7694400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63798, 'San Andrés Xecul', 'San Andres Xecul', 'San Andres,San Andres Xecul,San Andrés,San Andrés Xecul', 14.9000000, -91.4833300, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63799, 'San Andrés Villa Seca', 'San Andres Villa Seca', 'San Andres,San Andres Villa Seca,San Andrés,San Andrés Villa Seca', 14.5666700, -91.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63800, 'San Andrés Semetabaj', 'San Andres Semetabaj', 'San Andres,San Andres Semetabaj,San Andrés,San Andrés Semetabaj', 14.7500000, -91.1333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63801, 'San Andrés Sajcabajá', 'San Andres Sajcabaja', 'San Andres Sajcabaja,San Andrés Sajcabajá', 15.2166700, -90.9166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63802, 'San Andrés Itzapa', 'San Andres Itzapa', 'Itzapa,San Andres Itzapa,San Andrés Itzapa', 14.6200000, -90.8441700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63803, 'San Andrés', 'San Andres', 'San Andres,San Andrés,sheng an de lei si,聖安德雷斯', 16.9666700, -89.9166700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63804, 'San Agustín Acasaguastlán', 'San Agustin Acasaguastlan', 'San Agustin,San Agustin Acasaguastlan,San Agustín,San Agustín Acasaguastlán', 14.9500000, -89.9666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63805, 'Samayac', 'Samayac', '', 14.5808400, -91.4613500, 'GT', '2008-07-25', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63806, 'Salcajá', 'Salcaja', 'Salcaja,Salcajá', 14.8833300, -91.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63807, 'Salamá', 'Salama', 'Salama,Salamá', 15.1027800, -90.3180600, 'GT', '2013-08-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63808, 'Sacapulas', 'Sacapulas', 'Sacapulas', 15.2880100, -91.0891400, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63809, 'Río Hondo', 'Rio Hondo', 'Rio Hondo,Río Hondo', 15.0666700, -89.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63810, 'Río Bravo', 'Rio Bravo', 'Rio Bravo,Río Bravo', 14.4004200, -91.3171300, 'GT', '2014-07-20', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63811, 'Río Blanco', 'Rio Blanco', 'Rio Blanco,Río Blanco', 15.0382000, -91.6846300, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63812, 'Retalhuleu', 'Retalhuleu', 'RER,Retalhuleo,Retalhuleu,Retalhuley,Retaluleu,Реталулеу', 14.5361100, -91.6777800, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63813, 'Raxruhá', 'Raxruha', 'Raxrruja,Raxrrujá,Raxruha,Raxruhá,Raxruja,Raxrujá', 15.8666700, -90.0333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63814, 'Rabinal', 'Rabinal', 'Rabinal', 15.1000000, -90.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63815, 'Quezaltepeque', 'Quezaltepeque', 'Quetzaltepeque,Quezaltepeque', 14.6333300, -89.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63816, 'Quetzaltenango', 'Quetzaltenango', 'AAZ,Kecaltenangas,Kecaltenango,Kesal''tenango,Ketsaltenan''nko,Ketzaltenango,Quetzaltenanco,Quetzaltenango,Quetzaltenānco,Quexaltenango,Quezaltenango,ke sa er te nan ge,keteusaltenang-go,ketsu~arutenango,Κετσαλτενάνγκο,Кесальтенанго,Кецалтенанго,ケツァルテナンゴ,克薩爾特南戈,케트살테낭고', 14.8347200, -91.5180600, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63817, 'Quesada', 'Quesada', 'Quesada,Quezada', 14.2702800, -90.0402800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63818, 'Purulhá', 'Purulha', 'Purulha,Purulhá', 15.2666700, -90.2000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63819, 'Puerto San José', 'Puerto San Jose', 'GSJ,Puerto San Chose,Puerto San Chosė,Puerto San Jose,Puerto San José,Puerto de San Jose,Puerto de San José,San Jose,San Jose de Guatemala,San José,San José de Guatemala,sheng he sai gang,پورتو سان ہوزے,聖何塞港', 13.9274000, -90.8216600, 'GT', '2013-06-22', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63820, 'Puerto Barrios', 'Puerto Barrios', 'PBR,Puehrto-Barrios,Puerto Barijosas,Puerto Barios,Puerto Barrios,ba li ao si gang,Пуерто Бариос,Пуэрто-Барриос,פוארטו באריוס,巴里奧斯港', 15.7277800, -88.5944400, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63821, 'Pueblo Nuevo Viñas', 'Pueblo Nuevo Vinas', 'Pueblo Nuevo,Pueblo Nuevo Vinas,Pueblo Nuevo Viñas', 14.2258300, -90.4741700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63822, 'Tiquisate', 'Tiquisate', 'Pueblo Nuevo,Pueblo Nuevo Tiquisate,Tiquisate,Tiquizate', 14.2835600, -91.3606300, 'GT', '2014-07-20', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63823, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 14.6500000, -91.5333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63824, 'Poptún', 'Poptun', 'Poctum,Poctun,Poctún,Poptun,Poptún,Santa Barbara,Santa Bárbara', 16.3311100, -89.4169400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63825, 'Pochuta', 'Pochuta', 'Pochuta', 14.5500000, -91.0833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63826, 'Playa Grande', 'Playa Grande', 'PKJ,Playa Grande', 15.9333300, -90.7333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63827, 'Petapa', 'Petapa', 'Petapa,San Miguel Petapa', 14.5027800, -90.5516700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63828, 'Patzún', 'Patzun', 'Patzun,Patzún', 14.6833300, -91.0166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63829, 'Patzité', 'Patzite', 'Patzite,Patzité', 14.9666700, -91.2166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63830, 'Patzicía', 'Patzicia', 'Patzicia,Patzicía', 14.6316700, -90.9269400, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63831, 'Patulul', 'Patulul', 'Patulul', 14.4166700, -91.1666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63832, 'Pastores', 'Pastores', 'Pastores', 14.5966700, -90.7547200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63833, 'Pasaco', 'Pasaco', 'Pasaco', 13.9772200, -90.2063900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63834, 'Parramos', 'Parramos', 'Parramos', 14.6077800, -90.8030600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63835, 'Panzós', 'Panzos', 'Panzos,Panzós', 15.4000000, -89.6666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63836, 'Panajachel', 'Panajachel', 'Panajachel', 14.7333300, -91.1500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63837, 'Palín', 'Palin', 'Palin,Palín', 14.4055600, -90.6983300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63838, 'Palestina de los Altos', 'Palestina de los Altos', 'Palestina,Palestina de los Altos', 14.9333300, -91.7000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63839, 'Palencia', 'Palencia', 'Palencia', 14.6647200, -90.3586100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63840, 'Pajapita', 'Pajapita', 'Pajapita', 14.7215200, -92.0352100, 'GT', '2014-10-01', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63841, 'Pachalun', 'Pachalun', 'Pachalum,Pachalun', 14.9247200, -90.6627800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63842, 'Ostuncalco', 'Ostuncalco', 'Ostuncalco,San Juan Ostuncalco', 14.8666700, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63843, 'Oratorio', 'Oratorio', 'El Oratorio,Oratorio', 14.2280600, -90.1758300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63844, 'Olopa', 'Olopa', 'Olopa', 14.6833300, -89.3500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63845, 'Olintepeque', 'Olintepeque', 'Olintepeque', 14.8833300, -91.5166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63846, 'Ocós', 'Ocos', 'Ocos,Ocós,Puerto De Ocos', 14.5099800, -92.1929800, 'GT', '2014-10-01', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63847, 'Nuevo San Carlos', 'Nuevo San Carlos', 'Nuevo San Carlos', 14.6000000, -91.7000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63848, 'Nuevo Progreso', 'Nuevo Progreso', 'Nuevo Progreso,Nuevo Progresso', 14.8000000, -91.9166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63849, 'Nueva Santa Rosa', 'Nueva Santa Rosa', 'Nueva Santa Rosa', 14.3811100, -90.2761100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63850, 'Nueva Concepción', 'Nueva Concepcion', 'Concepcion,Concepcion La Grande,Concepción,Concepción La Grande,Nueva Concepcion,Nueva Concepción', 14.2000000, -91.3000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63851, 'Nentón', 'Nenton', 'Nenton,Nentón', 15.8007000, -91.7546400, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63852, 'Nebaj', 'Nebaj', 'Nebaj', 15.4061400, -91.1468200, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63853, 'Nahualá', 'Nahuala', 'Nahuala,Nahualá', 14.8500000, -91.3166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63854, 'Moyuta', 'Moyuta', 'Moyuta,Moyutla,Pueblo Moyuta', 14.0386100, -90.0808300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63855, 'Morazán', 'Morazan', 'Morazan,Morazán', 14.9327800, -90.1430600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63856, 'Morales', 'Morales', 'Morales', 15.4833300, -88.8166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63857, 'Monjas', 'Monjas', 'Monjas', 14.5000000, -89.8666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63858, 'Momostenango', 'Momostenango', 'Momostenango', 15.0443700, -91.4086400, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63859, 'Mixco', 'Mixco', 'Mishko,Mixco,Мишко', 14.6333300, -90.6063900, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63860, 'Mazatenango', 'Mazatenango', 'Masatenango,Mazatenango,Масатенанго', 14.5341700, -91.5033300, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63861, 'Mataquescuintla', 'Mataquescuintla', 'Mataquescuintla,Mataquesquintla', 14.5291700, -90.1841700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63862, 'Masagua', 'Masagua', 'Masagua', 14.2030600, -90.8480600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63863, 'Malacatancito', 'Malacatancito', 'Malacatancito,Santa AnaMalacatan,Santa AnaMalacatán', 15.2445700, -91.4990100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63864, 'Malacatán', 'Malacatan', 'Malacatan,Malacatán', 14.9106500, -92.0579500, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63865, 'Magdalena Milpas Altas', 'Magdalena Milpas Altas', 'Magdalena,Magdalena Milpas Altas', 14.5452800, -90.6752800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63866, 'Los Amates', 'Los Amates', 'Los Amates', 15.2564500, -89.0972300, 'GT', '2014-07-21', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63867, 'Lívingston', 'Livingston', '', 15.8282600, -88.7503900, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63868, 'La Unión', 'La Union', 'La Union,La Unión', 14.9666700, -89.2833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63869, 'La Tinta', 'La Tinta', 'La Tinta', 15.3166700, -89.8833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63870, 'La Reforma', 'La Reforma', 'La Reforma,Reforma', 14.8000000, -91.8166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63871, 'Lanquín', 'Lanquin', 'Lanquin,Lanquín', 15.5666700, -89.9666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63872, 'La Libertad', 'La Libertad', 'La Libertad,la li bo ta de,拉利伯塔德', 16.7885000, -90.1169800, 'GT', '2017-01-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63873, 'La Libertad', 'La Libertad', 'La Florida,La Libertad', 15.5142100, -91.8694400, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63874, 'La Gomera', 'La Gomera', 'La Gomera', 14.0833300, -91.0500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63875, 'La Esperanza', 'La Esperanza', 'Esperanza,La Esperanza', 14.8666700, -91.5666700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63876, 'La Democracia', 'La Democracia', 'Democracia,La Democracia', 14.2308300, -90.9472200, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63877, 'La Democracia', 'La Democracia', 'La Demacracia,La Democracia', 15.6254400, -91.8867000, 'GT', '2015-03-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63878, 'La Blanca', 'La Blanca', 'Hacienda La Blanca,La Blanca', 14.5788900, -92.1413700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63879, 'Jutiapa', 'Jutiapa', 'Juliapa,Jutiapa,Khutiapa,Хутиапа', 14.2916700, -89.8958300, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63880, 'Joyabaj', 'Joyabaj', 'Joyabaj', 14.9950000, -90.8061100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63881, 'Jocotenango', 'Jocotenango', 'Jocotenango', 14.5819400, -90.7436100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63882, 'Jocotán', 'Jocotan', 'Jocotan,Jocotán', 14.8166700, -89.3833300, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63883, 'Jerez', 'Jerez', 'Jerez', 14.1000000, -89.7500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63884, 'Jalpatagua', 'Jalpatagua', 'Jalpatagua', 14.1416700, -90.0086100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63885, 'Jalapa', 'Jalapa', 'Jalapa,Khalapa,Халапа', 14.6347200, -89.9888900, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63886, 'Jacaltenango', 'Jacaltenango', 'Jacaltenango,Khakal''tenango,Хакальтенанго', 15.6666200, -91.7117700, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63887, 'Iztapa', 'Iztapa', 'Istapa,Iztapa,Iztapa Puerto,Puerto Iztapa,Puerto de Iztapa', 13.9333300, -90.7075000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63888, 'Ixtahuacán', 'Ixtahuacan', 'Istaguacan,Istaguacán,Itzal,Ixtahuacan,Ixtahuacán,San Ildefonso,San Ildefonso Ixtahuacan,San Ildefonso Ixtahuacán', 15.4168800, -91.7692700, 'GT', '2017-04-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63889, 'Ixchiguán', 'Ixchiguan', 'Ixchiguan,Ixchiguán', 15.1637500, -91.9325600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63890, 'Ipala', 'Ipala', 'Ipala,Jilotepeque', 14.6166700, -89.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63891, 'Huité', 'Huite', 'Huite,Huité', 14.9333300, -89.7166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63892, 'Huitán', 'Huitan', 'Huitan,Huitán', 15.0492000, -91.6394400, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63893, 'Huehuetenango', 'Huehuetenango', 'HUG,Huehuetenangas,Huehuetenango,Uehuehtenango,Ueuetenango,ue-uetenang-go,u~eu~etenango,wei wei te nan ge,Уеуетенанго,Уэуэтенанго,ウェウェテナンゴ,韋韋特南戈,우에우에테낭고', 15.3191800, -91.4724100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63894, 'Guazacapán', 'Guazacapan', 'Guazacapan,Guazacapán', 14.0741700, -90.4166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63895, 'Guanagazapa', 'Guanagazapa', 'Guanagazapa', 14.2252800, -90.6433300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63896, 'Gualán', 'Gualan', 'Guala,Gualan,Gualá,Gualán', 15.1195200, -89.3572100, 'GT', '2014-07-21', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63897, 'Granados', 'Granados', 'Granados', 14.9136100, -90.5227800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63898, 'Génova', 'Genova', 'Genova,Génova', 14.6166700, -91.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63899, 'Fraijanes', 'Fraijanes', 'Fraijanes', 14.4652800, -90.4408300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63900, 'Flores Costa Cuca', 'Flores Costa Cuca', 'Flores,Flores Costa Cuca', 14.6323800, -91.8634100, 'GT', '2014-07-23', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63901, 'Flores', 'Flores', 'FRS,Flores,Flores Peten,Flores Petén,Floresas,flwrys  ayl pytyn,fu luo lei si,peulloleseu,phloresa,plwrs,Флорес,פלורס,فلوریس، ایل پیتین,ফ্লোরেস,弗洛雷斯,플로레스', 16.9225800, -89.8994100, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63902, 'Estanzuela', 'Estanzuela', 'Estanzuela', 15.0000000, -89.5666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63903, 'Esquipulas Palo Gordo', 'Esquipulas Palo Gordo', 'Esquipulas Palo Gordo,Palo Gorde,Palo Gordo', 14.9333300, -91.8166700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63904, 'Esquipulas', 'Esquipulas', 'Eskipulasas,Esquipulas,ai si ji pu la si,埃斯基普拉斯', 14.5666700, -89.3500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63905, 'Escuintla', 'Escuintla', 'Ehskuintla,Escuintla,Esquintla,esuku~intora,Эскуинтла,エスクィントラ', 14.3050000, -90.7850000, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63906, 'El Tumbador', 'El Tumbador', 'El Trumbador,El Tumbador,Tumbador', 14.8666700, -91.9333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63907, 'El Tejar', 'El Tejar', 'El Tejar,Tejar', 14.6477800, -90.7927800, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63908, 'El Rodeo', 'El Rodeo', 'El Rodeo,Rodeo', 14.9166700, -91.9666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63909, 'El Quetzal', 'El Quetzal', 'El Quetzal,Quetzal', 14.7666700, -91.8166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63910, 'Guastatoya', 'Guastatoya', 'El Progreso,Guastatoya,Gusfatoya,Progreso', 14.8541700, -90.0694400, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63911, 'El Progreso', 'El Progreso', 'El Progreso,Progreso', 14.3500000, -89.8500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63912, 'El Palmar', 'El Palmar', 'El Palmar,Palmar', 14.6500000, -91.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63913, 'El Jícaro', 'El Jicaro', 'El Jicaro,El Jícaro,Jicaro', 14.9166700, -89.9000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63914, 'El Estor', 'El Estor', 'El Estor', 15.5333300, -89.3500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63915, 'El Chol', 'El Chol', 'El Chol,Santa Cruz El Chol', 14.9641700, -90.4805600, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63916, 'El Chal', 'El Chal', 'El Chal', 16.6666700, -89.6333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63917, 'El Asintal', 'El Asintal', 'Acintal,Asintal,El Acintal,El Asintal', 14.6000000, -91.7333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63918, 'El Adelanto', 'El Adelanto', 'Adelanto,El Adelanto', 14.1666700, -89.8333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63919, 'Dolores', 'Dolores', 'Dolores', 16.5141700, -89.4158300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63920, 'Cuyotenango', 'Cuyotenango', 'Cuyotenango', 14.5333300, -91.5666700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63921, 'Cunén', 'Cunen', 'Cunen,Cunén', 15.3362600, -91.0277600, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63922, 'Cuilco', 'Cuilco', 'Cuilco', 15.4071900, -91.9466700, 'GT', '2017-04-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63923, 'Cuilapa', 'Cuilapa', 'Cuajiniquilapa,Cuilapa', 14.2763900, -90.2988900, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63924, 'Cubulco', 'Cubulco', 'Cubulco', 15.1333300, -90.5833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63925, 'Conguaco', 'Conguaco', 'Conguaco', 14.0441700, -90.0311100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63926, 'Concepción Tutuapa', 'Concepcion Tutuapa', 'Concepcion,Concepcion Tutuapa,Concepción,Concepción Tutuapa,Conception,Conception Tutuapa', 15.2394000, -91.8446000, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63927, 'Concepción Las Minas', 'Concepcion Las Minas', 'Concepcion,Concepcion Las Minas,Concepción,Concepción Las Minas', 14.5166700, -89.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63928, 'Concepción Chiquirichapa', 'Concepcion Chiquirichapa', 'Concepcion,Concepcion Chiquirichapa,Concepción,Concepción Chiquirichapa', 14.8500000, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63929, 'Concepción Huista', 'Concepcion Huista', 'Concepcion,Concepcion Huista,Concepción,Concepción Huista', 15.6237800, -91.6652100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63930, 'Concepción', 'Concepcion', 'Concepcion,Concepción', 14.7833300, -91.1500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63931, 'Comitancillo', 'Comitancillo', 'Comitacillo,Comitancillo', 15.0893700, -91.7497100, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63932, 'Comapa', 'Comapa', 'Comapa', 14.1166700, -89.9166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63933, 'Comalapa', 'Comalapa', 'Comalapa', 14.7411100, -90.8875000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63934, 'Colotenango', 'Colotenango', 'Colotenango', 15.4060200, -91.7126700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63935, 'Colomba', 'Colomba', 'Colomba', 14.7166700, -91.7333300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63936, 'Cobán', 'Coban', 'Coban,Cobán,Koban,Kobanas,ke wan,koban,Кобан,קובאן,科萬,코반', 15.4708300, -90.3708300, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63937, 'Coatepeque', 'Coatepeque', 'CTF,Coatepec,Coatepeque,Koatepeke,Koatepekė,ke a te pei ke,Коатепеке,کواتیپیکے، کویتسالتینانگو,科阿特佩克', 14.7000000, -91.8666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63938, 'Ciudad Vieja', 'Ciudad Vieja', 'Ciudad Vieja', 14.5263900, -90.7597200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63939, 'Ciudad Tecún Umán', 'Ciudad Tecun Uman', 'Ayutla,Ciudad Tecun Uman,Ciudad Tecún Umán', 14.6773700, -92.1403900, 'GT', '2017-06-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63940, 'Melchor de Mencos', 'Melchor de Mencos', 'Allahan,Ciudad Melchor de Mencos,Fallabon,Fallabón,MCR,Melchor Mencos,Melchor de Mencos', 17.0660600, -89.1522900, 'GT', '2013-12-15', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63941, 'Guatemala City', 'Guatemala City', 'Cidade da Guatemala,Citta del Guatemala,Città del Guatemala,Ciudad Guatemala,Ciudad de Guatemala,Ciutat de Guatemala,GUA,Guate,Guatemala,Guatemala City,Guatemala Hiria,Guatemala by,Guatemala la Nueva,Guatemala-Stadt,Guatemala-Urbo,Guatemala-stad,Gvatemala,Gvatemalurbo,Gwatemala,New Guatemala,Nueva Guatemala,Nueva Guatemala de la Asuncion,Nueva Guatemala de la Asunción,Pole tes Gouatemalas,Santiago de Guatimala,gua de ma la shi,guatemarashiti,gwatemalla si,gwatemallasiti,kawtemalasiti,mdynt ghwatymala,shhr gwatmala,Πόλη της Γουατεμάλας,Гватемала,גואטמלה סיטי,גוואטמלה סיטי,شهر گواتمالا,مدينة غواتيمالا,กัวเตมาลาซิตี,グアテマラシティ,瓜地馬拉市,과테말라 시,과테말라시티', 14.6407200, -90.5132700, 'GT', '2017-06-20', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63942, 'Chuarrancho', 'Chuarrancho', 'Chibatutuy,Chuarrancho', 14.8216700, -90.5086100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63943, 'Chisec', 'Chisec', 'Chisec', 15.8166700, -90.2833300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63944, 'Chiquimulilla', 'Chiquimulilla', 'Chiquimulilla', 14.0838000, -90.3854700, 'GT', '2014-07-01', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63945, 'Chiquimula', 'Chiquimula', 'CIQ,Chikimula,Chiquimula,Ciudad Procer,Ciudad Prócer,La Perla de Oriente,Чикимула', 14.8000000, -89.5458300, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63946, 'Chinique', 'Chinique', 'Chinique', 15.0414700, -91.0259400, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63947, 'Chinautla', 'Chinautla', 'Chignautla,Chinautla,Santa Cruz de Chinautla', 14.7083300, -90.4994400, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63948, 'Chimaltenango', 'Chimaltenango', 'Chimal''tenango,Chimaltenango,Santa Ana Chimaltenango,Чимальтенанго', 14.6611100, -90.8194400, 'GT', '2012-12-05', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63949, 'Chichicastenango', 'Chichicastenango', 'Chichicastenango,Chichikastenango,Santo Tomas Chichicastenango,Santo Tomás Chichicastenango,Чичикастенанго', 14.9333300, -91.1166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63950, 'Chiché', 'Chiche', 'Chiche,Chiché', 15.0088500, -91.0637900, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63951, 'Chicamán', 'Chicaman', 'Chicaman,Chicamán', 15.4000000, -90.7666700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63952, 'Chicacao', 'Chicacao', 'Chicacao', 14.5333300, -91.3166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63953, 'Chiantla', 'Chiantla', 'Chiantla', 15.3548400, -91.4580700, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63954, 'Champerico', 'Champerico', 'Champerico,Puerto Champerico,Puerto de Champerico', 14.3000000, -91.9166700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63955, 'Chajul', 'Chajul', 'Chajul', 15.4852300, -91.0352000, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63956, 'Chahal Guatemala', 'Chahal Guatemala', 'Chahal', 15.7912200, -89.6051800, 'GT', '2014-07-02', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63957, 'Catarina', 'Catarina', 'Catarina', 14.8515000, -92.0764600, 'GT', '2014-10-01', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63958, 'Casillas', 'Casillas', 'Casillas', 14.4222200, -90.2441700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63959, 'Cantel', 'Cantel', 'Cantel', 14.8166700, -91.4500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63960, 'Canillá', 'Canilla', 'Canilla,Canillá,Caniya,Caniyá', 15.1666700, -90.8500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63961, 'Camotán', 'Camotan', 'Camotan,Camotán', 14.8166700, -89.3666700, 'GT', '2012-02-07', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63962, 'Cajolá', 'Cajola', 'Cajola,Cajolá', 14.9166700, -91.6166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63963, 'Cahabón', 'Cahabon', 'Cahabon,Cahabón', 15.5666700, -89.8166700, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63964, 'Cabricán', 'Cabrican', 'Cabrican,Cabricán', 15.0748500, -91.6480000, 'GT', '2017-02-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63965, 'Cabañas', 'Cabanas', 'Cabanas,Cabañas', 14.9333300, -89.8000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63966, 'Barillas', 'Barillas', 'Barillas', 15.8036100, -91.3158300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63967, 'Barberena', 'Barberena', 'Barbarena,Barberena', 14.3094400, -90.3611100, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63968, 'Atescatempa', 'Atescatempa', 'Atescatempa', 14.1744400, -89.7425000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63969, 'Asunción Mita', 'Asuncion Mita', 'Asuncion,Asuncion Mita,Asunción Mita,Mita', 14.3308300, -89.7108300, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63970, 'Antigua Guatemala', 'Antigua Guatemala', 'Antigoua Gouatemala,Antigua,Antigua Guatemala,Antigua-Guatemala,Antigua-Gvatemala,Antigva Gvatemala,Antikva Gvatemalo,Huehcauh Cuauhtemallan,Huehcāuh Cuauhtēmallān,Muy Noble y Muy Leal Ciudad de Santiago de los Caballeros,Santiago de los Caballeros de Guatemala,The Most Noble and Most Loyal City of Santiago of the Knights of Goathemala,an de gua,antikuva kuvattamala,Αντίγουα Γουατεμάλα,Антигва Гватемала,Антигуа-Гватемала,Антигуа-Гуатемала,Антіґуа-Ґватемала,אנטיגואה גואטמלה,ஆன்டிகுவா குவாத்தமாலா,ანტიგუა-გვატემალა,アンティグア・グアテマラ,安地瓜', 14.5611100, -90.7344400, 'GT', '2012-01-16', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63971, 'Amatitlán', 'Amatitlan', 'Amatitlan,Amatitlán,San Juan Amatitlan,San Juan Amatitlán', 14.4774000, -90.6348900, 'GT', '2017-01-15', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63972, 'Alotenango', 'Alotenango', 'Alotenango,San Juan Alotenango', 14.4802800, -90.8075000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63973, 'Almolonga', 'Almolonga', 'Almolonga', 14.8166700, -91.5000000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63974, 'Aguacatán', 'Aguacatan', 'Aguacatan,Aguacatán', 15.3422200, -91.3114100, 'GT', '2017-03-04', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63975, 'Agua Blanca', 'Agua Blanca', 'Agua Blanca', 14.5000000, -89.6500000, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63976, 'Acatenango', 'Acatenango', 'Acatenango', 14.5519400, -90.9422200, 'GT', '2015-02-06', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63977, 'San Juan Ostuncalco', 'San Juan Ostuncalco', 'San Juan Ostuncalco', 14.8732800, -91.6897000, 'GT', '2015-02-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63978, 'San José La Máquina', 'San Jose La Maquina', 'San Jose La Maquina,San José La Máquina', 14.3017800, -91.5670700, 'GT', '2015-02-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63979, 'Fray Bartolomé de Las Casas', 'Fray Bartolome de Las Casas', 'Fray Bartolome de Las Casas,Fray Bartolomé de Las Casas', 15.8151600, -89.8893100, 'GT', '2015-02-08', 91);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64001, 'Quinhámel', 'Quinhamel', 'Quinhamel,Quinhameli,Quinhámel', 11.8869400, -15.8555600, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64002, 'Quebo', 'Quebo', 'Quebo', 11.3333300, -14.9333300, 'GW', '2013-08-17', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64003, 'Mansôa', 'Mansoa', 'Mansoa,Mansôa,Porto Mansoa', 12.0733300, -15.3188900, 'GW', '2012-01-18', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64004, 'Gabú', 'Gabu', 'Gaba,Gabu,Gabu-Sara,Gabú,Gabú-Sara,Nova Lamego,Villa Gabu Sara', 12.2800000, -14.2222200, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64005, 'Farim', 'Farim', 'Farim', 12.4838900, -15.2216700, 'GW', '2014-03-07', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64006, 'Catió', 'Catio', 'Catio,Catió', 11.2825000, -15.2547200, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64007, 'Canchungo', 'Canchungo', 'Canchungo,Pinto,Teixeira Pinto', 12.0672200, -16.0333300, 'GW', '2012-01-18', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64008, 'Cacheu', 'Cacheu', 'Cacheu', 12.2744400, -16.1652800, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64009, 'Bubaque', 'Bubaque', 'BQE,Bubaque,Bubaquer', 11.2833300, -15.8333300, 'GW', '2014-08-19', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64010, 'Buba', 'Buba', 'Buba', 11.5888900, -14.9958300, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64011, 'Bolama', 'Bolama', 'Bolama,Bulama,Port Beaver', 11.5769400, -15.4761100, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64012, 'Bissorã', 'Bissora', 'Bissora,Bissoram,Bissorã', 12.2230600, -15.4475000, 'GW', '2014-03-07', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64013, 'Bissau', 'Bissau', 'Bisao,Bisau,Bisau - Bissau,Bisauo,Bisava,Bisaŭo,Biso,Bissa,Bissao,Bissau,Bissá,Bisáu,Gorad Bisau,Mpissaou,OXB,Sao Jose de Bissau,São José de Bissáu,Wisaw,bi shao,bis sea,bis''sa''u,bisa''u,bisau,bsaw,bysaw,bysayw,picavu,Μπισσάου,Бисао,Бисау,Бісау,Горад Бісау,Բիսաու,ביסאו,بساؤ,بيساو,بیسائو,بیساو,बिसाउ,বিসাউ,বিস্সাউ,ਬਿਸਾਊ,பிசாவு,บิสเซา,བི་སའོ།,ბისაუ,ቢሳው,ビサウ,比紹,比绍,비사우', 11.8635700, -15.5976700, 'GW', '2011-03-30', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64014, 'Bafatá', 'Bafata', '', 12.1658300, -14.6616700, 'GW', '2015-04-08', 94);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64015, 'Vreed-en-Hoop', 'Vreed-en-Hoop', 'Vreed en Hoop,Vreed-en-Hoop', 6.8092700, -58.1979800, 'GY', '2013-05-05', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64016, 'Skeldon', 'Skeldon', 'Number 80,SKM,Skeldon,Skeldon Place', 5.8833300, -57.1333300, 'GY', '2012-01-18', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64017, 'Rosignol', 'Rosignol', 'Rosignal,Rosignol', 6.2709500, -57.5369700, 'GY', '2012-06-06', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64018, 'Parika', 'Parika', '', 6.8371200, -58.4294100, 'GY', '2010-07-05', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64019, 'New Amsterdam', 'New Amsterdam', 'Gorad N''ju-Amstehrdam,Naujasis Amsterdamas,New Amsterdam,Nueva Amsterdam,Nueva Ámsterdam,QSX,nyuamseuteleudam,xin a mu si te dan,Горад Нью-Амстэрдам,ניו אמסטרדם,新阿姆斯特丹,뉴암스테르담', 6.2479300, -57.5171000, 'GY', '2013-06-27', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64020, 'Mahdia', 'Mahdia', 'MHA,Mahdia', 5.2666700, -59.1500000, 'GY', '2013-08-11', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64021, 'Mahaicony Village', 'Mahaicony Village', 'Mahaicony,Mahaicony Village', 6.5763300, -57.8048600, 'GY', '2012-06-06', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64022, 'Mahaica Village', 'Mahaica Village', '', 6.6840500, -57.9218100, 'GY', '2013-05-08', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64023, 'Mabaruma', 'Mabaruma', 'Mabaruma,USI', 8.2000000, -59.7833300, 'GY', '2012-01-16', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64024, 'Linden', 'Linden', 'Linden,Линден', 6.0080900, -58.3071400, 'GY', '2013-06-27', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64025, 'Lethem', 'Lethem', 'Bon Success,LTM,Lethem,Lethen', 3.3833300, -59.8000000, 'GY', '2013-06-27', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64026, 'Georgetown', 'Georgetown', 'Demerara,Dzhordzhtaun,Dzordztaun,Dzordztauna,Dzordztaunas,Dzordztauns,Džordžtaun,Džordžtauna,Džordžtaunas,Džordžtauns,GEO,Georgetown,Georgetown i Guyana,Georgiopolis,Georgurbo,Gorad Dzhordzhtaun,Jojton,Jòjtòn,Tzortztaoun,Zhorzhtaun,cxrc thawn,gwrgtʼwn,jarajata''una,jarj ٹawn  gyana,jarjata''una,jojitaun,jorjata''una,jorjtavun,jrj‌tawn,jwrj tawn,jwrj twghn,qiao zhi dui,qiao zhi dun,zuo zhi cheng,Τζορτζτάουν,Τζώρτζταουν,Џорџтаун,Горад Джорджтаўн,Джорджтаун,Жоржтаун,Ջորջթաուն,גורגטאון,جارج ٹاؤن، گیانا,جرج‌تاون,جورج تاون,جورج توغن,جورج‌تاو,जॉर्जटाउन,ਜਾਰਜਟਾਊਨ,ଜର୍ଜଟାଉନ,ஜோர்ஜ்டவுண்,ജോർജ്ജ് ടൗൺ,จอร์จทาวน์,ཅོར་ཅི་ཐོན།,ჯორჯტაუნი,ጆርጅታውን,ジョージタウン,乔治敦,佐治城,조지타운', 6.8044800, -58.1552700, 'GY', '2010-05-30', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64027, 'Bartica', 'Bartica', 'Barteke,Bartica,GFO', 6.4079900, -58.6219200, 'GY', '2014-10-01', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64028, 'Anna Regina', 'Anna Regina', '', 7.2643900, -58.5076900, 'GY', '2010-07-21', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64029, 'Fort Wellington', 'Fort Wellington', 'Fort Wellington,Wellington', 6.3908700, -57.6038100, 'GY', '2014-10-02', 95);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64047, 'Puerto Cortez', 'Puerto Cortez', 'Port Cortez,Puehrto-Kortes,Puerto Caballo,Puerto Cortes,Puerto Cortez,Puerto Cortés,Puerto de Caballos,Пуэрто-Кортес', 15.8256200, -87.9296800, 'HN', '2016-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64048, 'Zopilotepe', 'Zopilotepe', '', 14.6000000, -86.2666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64049, 'Zamora', 'Zamora', '', 15.6333300, -86.0666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64050, 'Zambrano', 'Zambrano', '', 14.2666700, -87.4000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64051, 'Yuscarán', 'Yuscaran', 'Yuscaran,Yuscarán', 13.9438900, -86.8527800, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64052, 'Yoro', 'Yoro', 'ORO,Yoro', 15.1375000, -87.1277800, 'HN', '2017-05-01', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64053, 'Yorito', 'Yorito', 'Yorito', 15.0666700, -87.2833300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64054, 'Yarumela', 'Yarumela', '', 14.3333300, -87.6333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64055, 'Yaruchel', 'Yaruchel', '', 14.5333300, -88.8166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64056, 'Yamaranguila', 'Yamaranguila', 'Yamaranguila', 14.2833300, -88.2500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64057, 'Yaguacire', 'Yaguacire', '', 14.0166700, -87.2166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64058, 'Wawina', 'Wawina', 'Guaguina,Guawina,Wawina', 15.4166700, -84.4333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64059, 'Villanueva', 'Villanueva', 'Villanueva', 15.3166700, -88.0000000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64060, 'Villa Nueva', 'Villa Nueva', 'Villa Nueva,Villanueva Viejo', 14.0333300, -87.1333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64061, 'Villa de San Francisco', 'Villa de San Francisco', 'Villa San Francisco,Villa de San Francisco', 14.1666700, -86.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64062, 'Villa de San Antonio', 'Villa de San Antonio', 'La Villa de San Antonio,San Antonio,Villa San Antonio,Villa de San Antonio', 14.3166700, -87.6166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64063, 'Victoria', 'Victoria', 'Victoria', 15.5038100, -87.8262500, 'HN', '2013-11-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64064, 'Veracruz', 'Veracruz', 'Veracruz', 14.9166700, -88.7833300, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64065, 'Valle de Ángeles', 'Valle de Angeles', '', 14.5000000, -87.6333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64066, 'Valle de Ángeles', 'Valle de Angeles', 'Valle de Angeles,Valle de Ángeles', 14.1500000, -87.0333300, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64067, 'Vallecillo', 'Vallecillo', 'Vallecillo', 14.5166700, -87.4000000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64068, 'Trujillo', 'Trujillo', 'TJI,Truchiljas,Trujillo,Trukhil''jo,Trukhil''o,te lu xi e,teuluhiyo,trwkhyw,trwkhyw  kwlwn,Трухильо,Трухільйо,تروخیو,تروخیو، کولون,特魯希略,트루히요', 15.9166700, -85.9541700, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64069, 'Trojas', 'Trojas', 'Trojas,Trojas Campo', 15.3500000, -86.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64070, 'Trinidad de Copán', 'Trinidad de Copan', 'La Trinidad,Trinidad,Trinidad de Copan,Trinidad de Copán', 14.9500000, -88.7500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64071, 'Trinidad', 'Trinidad', 'Trinidad', 15.1333300, -88.2333300, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64072, 'Travesía', 'Travesia', '', 15.8666700, -87.9000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64073, 'Tras Cerros', 'Tras Cerros', '', 15.3000000, -88.6666700, 'HN', '2006-01-27', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64074, 'Toyós', 'Toyos', '', 15.5500000, -87.6500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64075, 'Tornabé', 'Tornabe', '', 15.7500000, -87.5500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64076, 'Tocoa', 'Tocoa', 'TCF,Tocoa,Tokoa,Токоа', 15.6833300, -86.0000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64077, 'Teupasenti', 'Teupasenti', 'Teupasenti', 14.2166700, -86.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64078, 'Tepusteca', 'Tepusteca', '', 15.4166700, -86.3166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64079, 'Tepanguare', 'Tepanguare', 'Tepanguara,Tepanguare', 14.3333300, -87.7500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64080, 'Tela', 'Tela', 'TEA,Tela', 15.7742500, -87.4673100, 'HN', '2014-07-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64081, 'Tegucigalpa', 'Tegucigalpa', 'Gorad Tehgusigal''pa,TGU,Tegousigalpa,Tegousigoualpa,Tegucigalpa,Tegucigalpo,Tegucigucigalpa,Tegusigal''pa,Tegusigalp,Tegusigalpa,Teguzigalpa,Tenkousinkalpa,Tequsiqalpa,Teuctzincalpan,Tègucigalpa,de gu si jia ba,te gu xi jia er ba,tegushigarupa,tegusigalapa,tegusigalpa,tekucikalpa,tekusikalpa,tgwsygalpa,tgwsyglph,tyghwsyghalba,Τεγκουσιγκάλπα,Τεγουσιγάλπα,Горад Тэгусігальпа,Тегусигалпа,Тегусигальпа,Тегусігальпа,Տեգուսիգալպա,טגוסיגלפה,טעגוסיגאלפע,تيغوسيغالبا,تگوسیگالپا,ٹیگوسیگلپا,तेगुसिगल्पा,তেগুসিগালপা,ਤੇਗੂਸੀਗਾਲਪਾ,டெகுசிகல்பா,ടെഗൂസിഗാൽപ,เตกูซิกัลปา,ཐེ་གུ་སི་གེ་པ།,ტეგუსიგალპა,ቴጉሲጋልፓ,テグシガルパ,德古斯加巴,特古西加爾巴,테구시갈파', 14.0818000, -87.2068100, 'HN', '2010-05-28', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64082, 'Teguajinal', 'Teguajinal', '', 15.3666700, -86.6000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64083, 'Taulabé', 'Taulabe', '', 14.7000000, -87.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64084, 'Taujica', 'Taujica', '', 15.7000000, -85.9166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64085, 'Taragual', 'Taragual', '', 14.7500000, -88.4833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64086, 'Támara', 'Tamara', '', 14.1500000, -87.3333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64087, 'Talanga', 'Talanga', 'Talanga', 14.4000000, -87.0833300, 'HN', '2016-03-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64088, 'Sulaco', 'Sulaco', 'SCD,Sulaco', 14.9166700, -87.2666700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64089, 'Sula', 'Sula', '', 15.2500000, -88.5666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64090, 'Subirana', 'Subirana', '', 15.2000000, -87.4500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64091, 'Sinuapa', 'Sinuapa', 'Sinuapa', 14.4500000, -89.1833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64092, 'Silca', 'Silca', '', 14.8333300, -86.5333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64093, 'Siguatepeque', 'Siguatepeque', 'Siguatepeque', 14.6000000, -87.8333300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64094, 'Sensenti', 'Sensenti', 'Sensenti', 14.4833300, -88.9333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64095, 'Savannah Bight', 'Savannah Bight', 'Sabana Bight,Sabana Bigt,Savannah Bight', 16.4500000, -85.8500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64096, 'Sabá', 'Saba', 'Saba,Sabá,Sava,Savá', 15.4666700, -86.2500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64097, 'San Vicente Centenario', 'San Vicente Centenario', 'San Vicente,San Vicente Centenario,San Vicente del Centenario', 14.8833300, -88.2833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64098, 'Santiago Puringla', 'Santiago Puringla', 'Santiago Puringla,Santiago de Puringla', 14.3500000, -87.9000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64099, 'Santa Rosa de Copán', 'Santa Rosa de Copan', 'SDH,Santa Rosa,Santa Rosa Copan,Santa Rosa Copán,Santa Rosa de Copan,Santa Rosa de Copán,Santa Rosa de Kopan,Santa Rosa de Kopanas,Santa-Rosa-de-Kopan,ke pan sheng sheng luo sha,Санта Роса де Копан,Санта-Роса-де-Копан,科潘省聖羅莎', 14.7666700, -88.7791700, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64100, 'Santa Rosa de Aguán', 'Santa Rosa de Aguan', 'Santa Rosa Aguan,Santa Rosa Aguán,Santa Rosa de Aguan,Santa Rosa de Aguán', 15.9500000, -85.7166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64101, 'Santa Rita', 'Santa Rita', '', 15.1666700, -87.2833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64102, 'Santa Rita', 'Santa Rita', '', 14.9166700, -88.2166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64103, 'Santa Rita, Copan', 'Santa Rita, Copan', 'Santa Rita,Santa Rita de Copan,Santa Rita de Copán', 14.8674800, -89.1000000, 'HN', '2014-08-01', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64104, 'Santa María del Real', 'Santa Maria del Real', 'El Real,Santa Maria de El Real,Santa Maria del Real,Santa María de El Real,Santa María del Real', 14.7666700, -85.9500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64105, 'Santa Lucía', 'Santa Lucia', 'Los Estanquillos,Santa Lucia,Santa Lucía', 14.4166700, -89.2000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64106, 'Santa Lucía', 'Santa Lucia', 'Santa Lucia,Santa Lucía', 14.1000000, -87.1166700, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64107, 'Santa Elena', 'Santa Elena', '', 15.3833300, -88.1333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64108, 'Santa Cruz de Yojoa', 'Santa Cruz de Yojoa', 'Santa Cruz de Yojoa', 14.9833300, -87.9000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64109, 'Santa Cruz', 'Santa Cruz', '', 13.8666700, -86.6333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64110, 'Santa Cruz', 'Santa Cruz', '', 13.2580600, -87.3483300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64111, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 14.9194400, -88.2361100, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64112, 'Santa Ana de Yusguare', 'Santa Ana de Yusguare', 'Santa Ana de Yusguare,Yusguare', 13.3005600, -87.1138900, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64113, 'Santa Ana', 'Santa Ana', '', 15.6500000, -87.0666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64114, 'Santa Ana', 'Santa Ana', 'Santa Ana', 13.9316700, -87.2713900, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64115, 'San Sebastián', 'San Sebastian', 'San Sebastian,San Sebastián', 14.2500000, -87.6333300, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64116, 'San Pedro Zacapa', 'San Pedro Zacapa', 'San Pedro Zacapa,Zacapa', 14.7500000, -88.1166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64117, 'San Pedro Sula', 'San Pedro Sula', 'Gorad San-Pedra-Sula,SAP,San Pedro,San Pedro Sula,San Pedro Zollan,San Pedro Zōllān,San-Pedro-Sula,san bydrw swla,san pe dor su la,sanpedeulosulla,san・pedoro・sura,sheng pei de luo su la,Горад Сан-Педра-Сула,Сан Педро Сула,Сан-Педро-Сула,سان بيدرو سولا,سان پیڈرو سولا,ซานเปโดรซูลา,サン・ペドロ・スーラ,圣佩德罗苏拉,산페드로술라', 15.5041700, -88.0250000, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64118, 'San Pedro de Tutule', 'San Pedro de Tutule', 'San Pedro Tutule,San Pedro de Tutule,Tutule', 14.2500000, -87.8500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64119, 'San Nicolás', 'San Nicolas', 'San Nicolas,San Nicolás', 15.0000000, -88.7500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64120, 'San Nicolás', 'San Nicolas', 'San Nicolas,San Nicolás', 14.9333300, -88.3166700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64121, 'San Nicolás', 'San Nicolas', '', 14.5500000, -86.2500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64122, 'San Matías', 'San Matias', 'San Matias,San Matías', 13.9833300, -86.6333300, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64123, 'San Marcos de Colón', 'San Marcos de Colon', 'San Marco de Colon,San Marcos,San Marcos de Colon,San Marcos de Colón', 13.4333300, -86.8000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64124, 'San Marcos', 'San Marcos', 'San Marcos', 15.3000000, -88.4166700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64125, 'San Marcos', 'San Marcos', 'San Marcos,San Marcos de Ocotepeque', 14.4000000, -88.9500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64126, 'San Manuel', 'San Manuel', 'San Manuel,San Manuel Tehuma', 15.3333300, -87.9166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64127, 'San Luis de Planes', 'San Luis de Planes', 'San Luis Planes,San Luis de Planes', 14.9833300, -88.1333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64128, 'San Luis', 'San Luis', 'San Luis,San Luis Pajon,San Luis Pajón', 15.0833300, -88.3833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64129, 'San Luis', 'San Luis', 'San Luis', 14.7500000, -87.4166700, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64130, 'San Lucas', 'San Lucas', 'San Lucas', 13.7333300, -86.9500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64131, 'San Lorenzo', 'San Lorenzo', '', 13.4241700, -87.4472200, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64132, 'San Juan Pueblo', 'San Juan Pueblo', 'San Juan,San Juan Pueblo', 15.5833300, -87.2333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64133, 'San Juan de Planes', 'San Juan de Planes', 'Planes,Planes de San Juan,San Juan Planes,San Juan de Planes', 14.9333300, -88.7833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64134, 'San Juan de Opoa', 'San Juan de Opoa', 'San Juan Opoa,San Juan de Opoa', 14.7833300, -88.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64135, 'San Juan de Flores', 'San Juan de Flores', 'Cantaranas,Cantarranas,San Juan Flores,San Juan de Flores', 14.2666700, -87.0333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64136, 'San José de Tarros', 'San Jose de Tarros', '', 15.3000000, -88.7000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64137, 'San José de Río Tinto', 'San Jose de Rio Tinto', 'Rio Tinto,Río Tinto,San Jose,San Jose de Rio Tinto,San Jose del Rio Tinto,San José,San José de Río Tinto,San José del Río Tinto', 14.9333300, -85.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64138, 'San José del Potrero', 'San Jose del Potrero', 'San Jose Potrero,San Jose del Potrero,San José Potrero,San José del Potrero', 14.8333300, -87.2833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64139, 'San José del Boquerón', 'San Jose del Boqueron', 'Boqueron,Boquerón,San Jose del Boqueron,San José del Boquerón', 15.4833300, -87.8666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64140, 'San José de Copán', 'San Jose de Copan', 'San Jose,San Jose de Copan,San José,San José de Copán', 14.9000000, -88.7166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64141, 'San José de Comayagua', 'San Jose de Comayagua', 'San Jose Comayagua,San Jose de Comayagua,San José Comayagua,San José de Comayagua', 14.7333300, -88.0333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64142, 'San José de Colinas', 'San Jose de Colinas', 'San Jose Colinas,San Jose de Colinas,San José Colinas,San José de Colinas', 15.0333300, -88.3000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64143, 'San José', 'San Jose', '', 15.3166700, -87.1666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64144, 'San José', 'San Jose', 'San Jose,San José', 14.2500000, -87.9500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64145, 'San Joaquín', 'San Joaquin', '', 15.0500000, -88.9000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64146, 'San Jerónimo', 'San Jeronimo', 'Jeronimo,San Jeronimo,San Jerónimo', 14.9666700, -88.8666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64147, 'San Jerónimo', 'San Jeronimo', 'El Espino,San Geronimo,San Jeronimo,San Jeronimo el Espino,San Jerónimo,San Jerónimo el Espino', 14.6333300, -87.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64148, 'San Jerónimo', 'San Jeronimo', '', 13.1766700, -87.1363900, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64149, 'San Ignacio', 'San Ignacio', 'San Ignacio,San Ignasio', 14.6500000, -87.0333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64150, 'San Francisco de Yojoa', 'San Francisco de Yojoa', 'San Francisco Yojoa,San Francisco de Yojoa', 15.0166700, -87.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64151, 'San Francisco del Valle', 'San Francisco del Valle', 'San Francisco,San Francisco del Valle', 14.4333300, -88.9500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64152, 'San Francisco de la Paz', 'San Francisco de la Paz', 'San Francisco de la Paz,San Francisco la Paz', 14.9000000, -86.2000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64153, 'San Francisco de Coray', 'San Francisco de Coray', 'Coray,San Francisco Coray,San Francisco de Coray', 13.6613900, -87.5327800, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64154, 'San Francisco de Cones', 'San Francisco de Cones', '', 14.5166700, -88.9000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64155, 'San Francisco de Becerra', 'San Francisco de Becerra', 'San Francisco Becerra,San Francisco de Becerra', 14.6333300, -86.1000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64156, 'San Francisco', 'San Francisco', '', 15.6500000, -87.0500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64157, 'San Fernando', 'San Fernando', 'San Fernando', 14.6833300, -89.1166700, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64158, 'San Esteban', 'San Esteban', 'SET,San Esteban', 15.2123100, -85.7699600, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64159, 'Sandy Bay', 'Sandy Bay', 'Sand Bay,Sandy Bay', 16.3292300, -86.5644600, 'HN', '2012-04-26', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64160, 'San Diego', 'San Diego', '', 14.0500000, -86.4666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64161, 'San Buenaventura', 'San Buenaventura', '', 15.0166700, -88.0000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64162, 'San Antonio del Norte', 'San Antonio del Norte', 'San Antonio Norte,San Antonio del Norte', 13.8844400, -87.7030600, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64163, 'San Antonio de la Cuesta', 'San Antonio de la Cuesta', 'San Antonio,San Antonio de la Cuesta', 14.6333300, -87.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64164, 'San Antonio de Cortés', 'San Antonio de Cortes', 'San Antonio de Cortes,San Antonio de Cortés', 15.1166700, -88.0333300, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64165, 'San Antonio', 'San Antonio', '', 15.6000000, -87.1500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64166, 'San Antonio', 'San Antonio', 'San Antonio,San Antonio de Jimia', 15.3333300, -87.1500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64167, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', 14.8166700, -88.9333300, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64168, 'Sambo Creek', 'Sambo Creek', 'Crique,Sambo,Sambo Creeck,Sambo Creek,Zambo,Zambo Crique', 15.8166700, -86.6833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64169, 'Salamá', 'Salama', 'Salama,Salamá', 15.7500000, -85.9666700, 'HN', '2016-03-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64170, 'Salamá', 'Salama', 'Salama,Salamá', 14.8333300, -86.5833300, 'HN', '2016-03-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64171, 'Sabanagrande', 'Sabanagrande', 'Sabanagrande,Sabanu Grande', 13.8077800, -87.2591700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64172, 'Coxen Hole', 'Coxen Hole', 'Coxen Hole,Coxin Hole,RTB,Roatan Town', 16.3175900, -86.5379300, 'HN', '2014-08-19', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64173, 'Río Lindo', 'Rio Lindo', '', 15.0333300, -87.9833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64174, 'Río Esteban', 'Rio Esteban', 'Rio Esteban,Río Esteban,San Esteban', 15.8333300, -86.3000000, 'HN', '2014-10-11', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64175, 'Río Chiquito', 'Rio Chiquito', '', 15.6333300, -88.2500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64176, 'Río Bonito', 'Rio Bonito', '', 14.7666700, -87.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64177, 'Río Blanquito', 'Rio Blanquito', '', 15.7333300, -87.9000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64178, 'Río Abajo', 'Rio Abajo', '', 14.1666700, -87.2166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64179, 'Reitoca', 'Reitoca', 'Reitoca,Reitoco', 13.8258300, -87.4652800, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64180, 'Quimistán', 'Quimistan', 'Ouimistan,Quimistan,Quimistán', 15.3500000, -88.4000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64181, 'Quezailica', 'Quezailica', 'Quesailica,Quezailaca,Quezailica', 14.8833300, -88.7333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64182, 'Quebrada Seca', 'Quebrada Seca', '', 15.6666700, -87.9500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64183, 'Quebradas', 'Quebradas', 'Las Quebradas,Quebradas,Trinidad de Quebradas', 14.5000000, -87.3500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64184, 'Quebrada Larga', 'Quebrada Larga', '', 14.1000000, -86.3666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64185, 'Quebrada de Arena', 'Quebrada de Arena', 'Quebrada Arena,Quebrada de Arena', 15.7666700, -85.9166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64186, 'Punuare', 'Punuare', '', 14.7333300, -85.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64187, 'Punta Piedra', 'Punta Piedra', 'Punta Piedra,Punta Piedras,Punta de Piedra', 15.9000000, -85.2833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64188, 'Punta Ocote', 'Punta Ocote', 'Punta Ocote,Punta de Ocote', 15.2000000, -87.2833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64189, 'Puerto Lempira', 'Puerto Lempira', 'PEU,Puerto Lempira', 15.2666700, -83.7722200, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64190, 'Puerto Castilla', 'Puerto Castilla', 'Puerto Castilla,Puerto Castillo', 16.0166700, -85.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64191, 'Puerto Alto', 'Puerto Alto', 'Puente Alto,Puerto Alto', 15.7000000, -87.8666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64192, 'Pueblo Nuevo', 'Pueblo Nuevo', '', 15.2833300, -88.0166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64193, 'Pueblo Nuevo', 'Pueblo Nuevo', '', 15.0000000, -88.7500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64194, 'Protección', 'Proteccion', 'Proteccion,Protección', 15.0333300, -88.6500000, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64195, 'Prieta', 'Prieta', '', 15.5806000, -86.1366400, 'HN', '2014-05-30', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64196, 'Potrerillos', 'Potrerillos', '', 15.6333300, -88.3000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64197, 'Potrerillos', 'Potrerillos', 'Porterillas,Potrerillos', 15.2333300, -87.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64198, 'Potrerillos', 'Potrerillos', '', 14.5500000, -87.8666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64199, 'Pinalejo', 'Pinalejo', '', 15.3833300, -88.4000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64200, 'Pimienta Vieja', 'Pimienta Vieja', '', 15.2333300, -87.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64201, 'Petoa', 'Petoa', 'Petoa', 15.2666700, -88.2833300, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64202, 'Pespire', 'Pespire', 'Pespire', 13.5922200, -87.3616700, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64203, 'Peña Blanca', 'Pena Blanca', '', 15.5333300, -88.0500000, 'HN', '2011-11-08', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64204, 'Paujiles', 'Paujiles', '', 15.1000000, -87.3500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64205, 'Paptalaya', 'Paptalaya', 'Papalaya,Paptalaya', 15.5000000, -84.3166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64206, 'Oropolí', 'Oropoli', 'Oropoli,Oropolí', 13.8166700, -86.8166700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64207, 'Oropéndolas', 'Oropendolas', 'Las Urupas,Oropendolas,Oropendolo,Oropéndolas', 15.0166700, -87.9333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64208, 'Orocuina', 'Orocuina', 'Orocuina', 13.4816700, -87.1050000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64209, 'Orica', 'Orica', 'Orica', 14.7000000, -86.9500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64210, 'Omoa', 'Omoa', 'Omoa', 15.7666700, -88.0333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64211, 'Olanchito', 'Olanchito', 'OAN,Olanchita,Olanchito,Оланчито', 15.4813100, -86.5741500, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64212, 'Ojos de Agua', 'Ojos de Agua', 'Ojo de Agua,Ojos de Agua', 14.7000000, -88.8166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64213, 'Ojos de Agua', 'Ojos de Agua', '', 14.6000000, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64214, 'Ojojona', 'Ojojona', 'Ojojona', 13.9338900, -87.2958300, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64215, 'Ojo de Agua', 'Ojo de Agua', '', 14.0166700, -86.3500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64216, 'Ocote Paulino', 'Ocote Paulino', 'Ocote Paulino,Ocote Pavlino', 15.4166700, -87.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64217, 'Nuevo Chamelecón', 'Nuevo Chamelecon', 'Nuevo Chamelecon,Nuevo Chamelecón,Nuvo Chameleco', 15.3833300, -88.0166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64218, 'Nueva Ocotepeque', 'Nueva Ocotepeque', 'Nueva Ocotepeque,Ocotepeque', 14.4333300, -89.1833300, 'HN', '2012-01-16', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64219, 'Nueva Jalapa', 'Nueva Jalapa', 'Nueva Jalapa,Nuevo Jalapa', 14.9166700, -88.3333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64220, 'Nueva Esperanza', 'Nueva Esperanza', '', 15.2666700, -87.6000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64221, 'Nueva Armenia', 'Nueva Armenia', '', 15.7955600, -86.4984500, 'HN', '2011-03-29', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64222, 'Nombre de Jesús', 'Nombre de Jesus', 'Nombre Jesus,Nombre Jesús,Nombre de Jesus,Nombre de Jesús', 15.3500000, -86.6833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64223, 'Naranjito', 'Naranjito', 'El Naranjito,Naranjito', 14.9500000, -88.6833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64224, 'Namasigüe', 'Namasigue', 'Namasigue,Namasigüe,Namasique', 13.2047200, -87.1388900, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64225, 'Naco', 'Naco', 'Las Flores de Naco,Naco', 15.3833300, -88.1833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64226, 'Nacaome', 'Nacaome', 'Nacaome', 13.5361100, -87.4875000, 'HN', '2012-01-16', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64227, 'Morocelí', 'Moroceli', 'Moroceh,Moroceli,Morocelí', 14.1166700, -86.8666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64228, 'Morazán', 'Morazan', 'Fransisko Morasan,Morazan,Morazon,Morazán,Morazón,Франсиско Морасан', 15.3166700, -87.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64229, 'Monterrey', 'Monterrey', 'Monte-Rey,Monterey del Norte,Monterrey,Monterrey Sur', 15.5833300, -87.8833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64230, 'Monjarás', 'Monjaras', '', 13.2005600, -87.3741700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64231, 'Mojimán', 'Mojiman', 'Moiiman,Mojiman,Mojimán', 15.2666700, -87.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64232, 'Minas de Oro', 'Minas de Oro', 'Minas de Oro', 14.8000000, -87.3500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64233, 'Mezapa', 'Mezapa', 'Mezapa,Mezapa Boqueron,Mezapa Boquerón', 15.5833300, -87.6500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64234, 'Mateo', 'Mateo', '', 14.0833300, -87.3166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64235, 'Mata de Plátano', 'Mata de Platano', '', 14.6000000, -87.2833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64236, 'Marcovia', 'Marcovia', 'Marcovia', 13.2880600, -87.3097200, 'HN', '2014-04-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64237, 'Marcala', 'Marcala', 'MRJ,Marcala', 14.1500000, -88.0333300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64238, 'Marale', 'Marale', '', 14.8833300, -87.1500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64239, 'Manto', 'Manto', 'Manto', 14.9166700, -86.3833300, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64240, 'Mangulile', 'Mangulile', 'Mangulile', 15.0666700, -86.8000000, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64241, 'Lucerna', 'Lucerna', 'Lucerna', 14.5500000, -88.9333300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64242, 'Los Tangos', 'Los Tangos', '', 15.1500000, -88.6833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64243, 'Los Planes', 'Los Planes', 'Los Planes,Planes', 14.0500000, -88.0166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64244, 'Los Naranjos', 'Los Naranjos', '', 14.9000000, -88.0500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64245, 'Los Llanitos', 'Los Llanitos', 'Los Llanitos,Los Llanos', 13.2869400, -87.3344400, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64246, 'Los Caminos', 'Los Caminos', 'Los Caminos,Los Cominos', 14.9500000, -87.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64247, 'Lomitas', 'Lomitas', '', 15.1000000, -87.2166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64248, 'Loma Alta', 'Loma Alta', '', 15.3966700, -88.5597200, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64249, 'Liure', 'Liure', 'Liure', 13.5358300, -87.0919400, 'HN', '2014-04-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64250, 'Lepaterique', 'Lepaterique', 'Lapaterique,Lepaterique', 14.0666700, -87.4666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64251, 'Lepaera', 'Lepaera', 'Lepaera', 14.7833300, -88.5833300, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64252, 'Lejamaní', 'Lejamani', 'Lejamani,Lejamaní', 14.3666700, -87.7000000, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64253, 'La Zumbadora', 'La Zumbadora', 'La Zumbadora,Sumbadora,Zumbadora', 15.0166700, -88.9000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64254, 'La Virtud', 'La Virtud', 'La Virtud,Virtud', 14.0500000, -88.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64255, 'La Unión', 'La Union', 'La Union,La Unión,Union,Unión', 15.7166700, -87.0000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64256, 'La Unión', 'La Union', 'La Union,La Unión', 14.8166700, -88.4000000, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64257, 'La Trinidad', 'La Trinidad', 'La Trinidad,Trinidad', 15.1000000, -87.2000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64258, 'Las Vegas', 'Las Vegas', '', 15.0166700, -87.4500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64259, 'Las Vegas, Santa Barbara', 'Las Vegas, Santa Barbara', 'Las Vegas  Santa Barbara,Sauce', 14.8764900, -88.0747300, 'HN', '2014-07-23', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64260, 'Las Trojes', 'Las Trojes', 'Las Trojes,Trojes', 14.0666700, -85.9833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64261, 'Las Tejeras', 'Las Tejeras', 'Las Tejeras,Tejeras', 14.8000000, -88.6000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64262, 'Las Lajas', 'Las Lajas', '', 14.7833300, -87.7500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64263, 'San José de Las Conchas', 'San Jose de Las Conchas', 'Las Conchas,Puerto Las Conchas,San Jose de Las Conchas,San José de Las Conchas', 13.3252800, -87.3955600, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64264, 'La Sarrosa', 'La Sarrosa', 'La Sarrosa,La Zarrosa,Sarrosa', 15.2333300, -87.8333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64265, 'Las Ánimas', 'Las Animas', '', 14.2500000, -86.5666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64266, 'La Sabana', 'La Sabana', '', 15.3666700, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64267, 'La Rosa', 'La Rosa', '', 15.3500000, -87.0666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64268, 'La Playona', 'La Playona', '', 15.1166700, -88.9833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64269, 'La Paz', 'La Paz', 'La Paz', 14.3194400, -87.6791700, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64270, 'Langue', 'Langue', 'Langue', 13.6208300, -87.6525000, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64271, 'La Mina', 'La Mina', '', 15.3166700, -87.8333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64272, 'La Masica', 'La Masica', 'La Masica,Masica', 15.6166700, -87.1166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64273, 'Lamaní', 'Lamani', 'Lamani,Lamaní', 14.2000000, -87.6166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64274, 'La Lima', 'La Lima', 'LLH,La Lima,La-Lima,Lima Vieja,Ла-Лима', 15.4333300, -87.9166700, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64275, 'La Libertad', 'La Libertad', 'La Liberdad,La Libertad', 14.8000000, -88.5833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64276, 'La Libertad', 'La Libertad', 'La Libertad', 14.7500000, -87.6166700, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64277, 'La Labor', 'La Labor', 'La Labor', 14.4833300, -89.0000000, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64030, 'Tsuen Wan', 'Tsuen Wan', 'Ch''uan-wan,Ch’üan-wan,Tsuen Wan,Tsun Wan,Tsun Wan Wai,quan wan,荃灣', 22.3706600, 114.1047900, 'HK', '2013-07-07', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64031, 'Yung Shue Wan', 'Yung Shue Wan', 'Rongshu Wan,Yung Shu Wan,Yung Shue Wan,rong shu wan,榕树湾,榕樹灣', 22.2262300, 114.1124100, 'HK', '2014-11-05', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64032, 'Yuen Long Kau Hui', 'Yuen Long Kau Hui', 'Yuen Long Kau Hui,yuan lang jiu xu,元朗舊墟', 22.4500000, 114.0333300, 'HK', '2013-08-11', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64033, 'Wong Tai Sin', 'Wong Tai Sin', '', 22.3500000, 114.1833300, 'HK', '2013-08-08', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64034, 'Wan Chai', 'Wan Chai', 'Wan Chai,Wanchai,wan zi,灣仔', 22.2814200, 114.1725800, 'HK', '2013-07-07', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64035, 'Tuen Mun', 'Tuen Mun', 'Tuen Mun,tun men,Туен Мун,屯門,屯门', 22.3917500, 113.9715700, 'HK', '2013-08-09', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64036, 'Tai Po', 'Tai Po', 'Tai Po Market,Tai Po Old Market,Tai-po-hui,Tai-wo-shi,Taj Po,da bu,da bu xu,dapu,Тај По,大埔,大埔墟,다푸', 22.4500700, 114.1687700, 'HK', '2015-02-07', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64037, 'Tai O', 'Tai O', 'Da''ao,Da’ao,Tai O,Tai O Town,Tai ho,Taj O,da ao,Тай О,大澳', 22.2551500, 113.8630900, 'HK', '2014-11-20', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64038, 'Sok Kwu Wan', 'Sok Kwu Wan', 'Sok Kwu Wan,Sok-Kvu-Van,Suogu Wan,suo gu wan,Сок-Кву-Ван,索罟湾,索罟灣', 22.2045300, 114.1315900, 'HK', '2014-11-05', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64039, 'Sha Tin', 'Sha Tin', 'Sha Tin,Sha Tin New Town,Shatin', 22.3833300, 114.1833300, 'HK', '2013-08-09', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64040, 'Sham Shui Po', 'Sham Shui Po', 'Sam shui po,Shamshuipo,Shan Shin Po,shen shui bu qu,深水埗區', 22.3302300, 114.1594500, 'HK', '2013-07-07', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64041, 'Sai Kung', 'Sai Kung', 'Sai Kung,xi gong,西貢,西贡', 22.3833300, 114.2666700, 'HK', '2013-08-08', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64042, 'Ngong Ping', 'Ngong Ping', 'Ngong Ping,ang ping,昂坪', 22.2555600, 113.9039100, 'HK', '2016-08-29', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64043, 'Kowloon', 'Kowloon', 'Chiu-lung,Czjulun,Kaulunas,Koulun,Kowloon,jiu long,julung,yi fa ban,Цзюлун,九龍,意法半,주룽', 22.3166700, 114.1833300, 'HK', '2013-07-07', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64044, 'Hong Kong', 'Hong Kong', 'Chon''nk Kon''nk,Gankong,Gon Kong,Gonkong,HKG,Hiong-geng,Hiŏng-gē̤ng,Hong Kong,Hongkong,Honkong,Hồng Kông,Khongkong,Khonkong,Victoria,ankan,hamga kamga,hanakana,hang kang,hang kang nagaram,hangakanga,hang‌kang,hankam,heankean,hng kng,hon''ga kon''ga,hong-kʼongi,hongakonga,hongkong,honkongu,hwng kwng,hwng qwng,hwngh kwngh,hwnj kwnj,hxngkng,hʼng qʼng,shyanggang,xiang gang,Χονγκ Κονγκ,Ганконг,Гонконг,Хонгконг,Хонконг,Һoң Koң,Һоң Коң,Հոնկոնգ,האנג קאנג,הונג קונג,شياڭگاڭ,هانگ کانگ,هنگ کنگ,هونج كونج,هونغ كونغ,هونگ کونگ,ھwng kwng,ھونگ کونگ,ھۆng kۆng,ھۆنگ کۆنگ,ہang kang,ہانگ کانگ,ހޮންކޮންގު,हङकङ,हाँग काँग,हांगकांग,हांग् कांग् नगरम्,हॉन्ग कॉन्ग,হংকং,ਹਾਂਗਕਾਂਗ,હોંગકોંગ,ହଂକଂ,ஆங்காங்,హాంగ్‌కాంగ్,ಹಾಂಗ್ ಕಾಂಗ್,ഹോങ്കോങ്,හොංකොං,ฮ่องกง,ཧང་ཀང་།,ཧོང་ཀོང་།,ဟောငကောင,ဟောင်ကောင်,ჰონგ-კონგი,ሆንግ ኮንግ,ហងកង,ហុងកុង,香港,홍콩', 22.2783200, 114.1746900, 'HK', '2017-05-23', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64045, 'Central', 'Central', 'Central''nyj,Centralo,City of Victoria,Victoria,Victoria City,jjung-wan,maiyam,sntral,sntrl,zhong huan,Центральный,סנטרל,سنترال,மையம்,中環,쭝완', 22.2829900, 114.1584600, 'HK', '2017-05-23', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64046, 'Tung Chung', 'Tung Chung', 'Tung Chung,dong yong,东涌,東涌', 22.2878300, 113.9424300, 'HK', '2016-03-27', 100);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(63639, 'Grytviken', 'Grytviken', 'Gritviken,Griutvikenas,Grjutviken,Grutviken,Grytviken,Qryotviken,geuliteubiken,gritavikena,grytwwyqn,gu li de wei ken,guritobiken,krit wi khen,Грутвикен,Грутвікен,Грютвикен,Грютвікен,גריטוויקן,ग्रिटविकेन,กริตวีเคน,グリトビケン,古利德維肯,그리트비켄', -54.2811100, -36.5092000, 'GS', '2010-12-11', 207);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64466, 'Vranjic', 'Vranjic', 'Selo Vranjic,Vranjic,Vranjica', 43.5333300, 16.4666700, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64467, 'Županja', 'Zupanja', 'Zhupanja,Zsupanja,Zsupanya,Zupana,Zupanja,jupanya,Županja,Жупаня,Жупања,ジュパニャ', 45.0775000, 18.6975000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64468, 'Žumberak', 'Zumberak', 'Comuna Zumberak,Comuna Žumberak,Zhumberak,Zsumberk,Zumberak,Žumberak,Жумберак', 45.7500000, 15.4333300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64469, 'Žrnovo', 'Zrnovo', 'Zrnovo,Žrnovo', 42.9511100, 17.1141700, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64470, 'Žrnovnica', 'Zrnovnica', 'Zrnovnica,Žrnovnica', 43.5211100, 16.5591700, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64471, 'Žminj', 'Zminj', 'Comuna Zminj,Comuna Žminj,Geminium,Gimino,Zhmin,Zminj,Žminj,Жмињ', 45.1427800, 13.9088900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64472, 'Zlatar', 'Zlatar', 'Zlatar,Zlator,zi la ta er,zlatar,zlatar  krwasy,Златар,Златор,زلاتار,زلاتار، کرواسی,茲拉塔爾', 46.0941700, 16.0708300, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64473, 'Sveti Ivan Zelina', 'Sveti Ivan Zelina', 'Sveti Ivan Zelina,Sveti-Ivan-Zelina,Szentivanzelina,Szentivánzelina,Zelina,sheng yi wan ze li na,swty aywan zlyna,Свети Иван Зелина,Свети-Иван-Зелина,Светі-Іван-Зеліна,سوتی ایوان زلینا,سڤێتی ایڤان زێلینا,聖伊萬澤利納', 45.9561100, 16.2461100, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64474, 'Ždralovi', 'Zdralovi', 'Zdralovi,Ždralovi', 45.8763900, 16.8750000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64475, 'Zdenci Brdovečki', 'Zdenci Brdovecki', 'Brdovecki Zdenci,Brdovečki Zdenci,Zdenci,Zdenci Brdovecki,Zdenci Brdovečki', 45.8666700, 15.7500000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64476, 'Zdenci', 'Zdenci', 'Zdenci,Zdencze', 45.5891700, 17.9502800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64477, 'Zaprešić', 'Zapresic', 'Zapreshic,Zapreshich,Zapresic,Zapresicius,Zaprešić,Zaprešičius,zabrshytsh,zaprshych,zapureshichi,zha pu lei xi qi,Запрешич,Запрешић,زابرشيتش,زاپرشیچ,زاپرێشیچ,ザプレシチ,扎普雷希奇', 45.8563900, 15.8077800, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64478, 'Žakanje', 'Zakanje', 'Zakanje,Žakanje', 45.6000000, 15.3500000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64479, 'Zagvozd', 'Zagvozd', 'Zagost,Zagvozd', 43.3975000, 17.0569400, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64480, 'Zagreb- Dubrava', 'Zagreb- Dubrava', 'Dubrava,Zagrebacka Dubrava,Zagrebačka Dubrava', 45.8336100, 16.0636100, 'HR', '2015-12-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64481, 'Zagreb', 'Zagreb', 'Agram,Andautonia,Gorad Zagrab,Lungsod ng Zagreb,Sagrab,Sagreb,Sagwzlwgbouh,Sakreb,Ságrab,ZAG,Zabrag,Zabreg,Zagabbria,Zagabria,Zagavria,Zagrab,Zagrabia,Zagreb,Zagreba,Zagrebas,Zagrebi,Zagrebo,Zagrebs,Zagrep,Zagrev,Zagrzeb,Zagrèb,Zagréb,Zagrėbs,Zagàbria,Zahreb,Zankremp,Zaqreb,Zágráb,Záhreb,Záhřeb,cakirep,jagareba,jageulebeu,jagriba,jhagreba,sa ge lei bu,sa kerb,sagreb,zagaraba,zaghrb,zagrb,zagrebi,zagurebu,zajryb,zghrb,Żagreb,Ζάγκρεμπ,Горад Заграб,Загреб,Զագրեբ,זאגרב,זאגרעב,زاجريب,زاغرب,زاگرب,زاگرێب,زغرب,जग्रिब,झाग्रेब,জাগরেব,ਜ਼ਾਗਰਬ,சாகிரேப்,സാഗ്രെബ്,ซาเกร็บ,ཛག་རེབ།,ზაგრები,ዛግሬብ,ザグレブ,萨格勒布,薩格勒布,Ꙁагрєбъ,자그레브', 45.8144400, 15.9779800, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64482, 'Zadvorsko', 'Zadvorsko', 'Zadvorsko', 45.7197800, 15.9088000, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64483, 'Zadvarje', 'Zadvarje', 'Duare,Duari,Zadvarje,Zadvorje', 43.4313900, 16.8897200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64484, 'Zadar', 'Zadar', 'Chadra,Gorad Zadar,Iadera,ZAD,Zadar,Zadara,Zadaras,Zantar,Zara,jadaleu,zadar,zadari,zadaru,zdar,zha da er,zʼdʼr,Ζαντάρ,Горад Задар,Задар,זאדאר,زادار,زدار,ზადარი,ዛዳር,ザダル,扎達爾,자다르', 44.1197200, 15.2422200, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64485, 'Sveti Križ Začretje', 'Sveti Kriz Zacretje', 'Sveti Kriz Zacretje,Sveti Križ Začretje,Zacretje,Začretje', 46.0808300, 15.9111100, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64486, 'Zabok', 'Zabok', 'Zabok,Забок', 46.0294400, 15.9150000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64487, 'Sveti Ivan Žabno', 'Sveti Ivan Zabno', 'Sveti Ivan Zabno,Sveti Ivan Žabno,Zabno,Žabno', 45.9461100, 16.6133300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64488, 'Vukovar', 'Vukovar', 'Cornacum,Gorad Vukavar,Neo-Vukovar,Novi Vukovar,Ovukovar,Stari Vukovar,Ujvukovar,Valko,Valkovar,Valkó,Valkóvár,Vetus-Vukovar,Vukovar,Vukovaras,Vukovari,Vukovár,Wukowar,bukobaleu,fwkwfar,vukovu~aru,wu ke wa er,wwkwar,wwqwbr,Óvukovár,Újvukovár,Вуковар,Горад Вукавар,ווקובר,فوكوفار,ووکوار,ڤوکۆڤار,ヴコヴァル,武科瓦尔,부코바르', 45.3433300, 18.9997200, 'HR', '2012-02-28', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64489, 'Vuka', 'Vuka', 'Vuka', 45.4338900, 18.5050000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64490, 'Vrsi', 'Vrsi', 'Verche,Verché,Vrsi', 44.2647200, 15.2325000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64491, 'Vrsar', 'Vrsar', 'Comuna Vrsar,Orsera,Ursaria,Vrsar,Врсар', 45.1491700, 13.6052800, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64492, 'Vrpolje', 'Vrpolje', 'Vrpolje', 45.2105600, 18.4055600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64493, 'Vrhovine', 'Vrhovine', 'Vrhovine', 44.8516700, 15.4191700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64494, 'Vrgorac', 'Vrgorac', 'Vergoraz,Vrgorac', 43.2058300, 17.3711100, 'HR', '2017-02-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64495, 'Gvozd', 'Gvozd', 'Gvozd,Vrginmost', 45.3530500, 15.8656300, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64496, 'Vrbovsko', 'Vrbovsko', 'Vrbovsko,Врбовско', 45.3686100, 15.0783300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64497, 'Vrbovec', 'Vrbovec', 'Vrbovec,Vurbovec,fu er bo wei ci,vurubovu~etsu,wrbwts,Врбовец,Върбовец,وربوتس,ڤربۆڤێتس,ヴルボヴェツ,弗爾博韋茨', 45.8833300, 16.4216700, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64498, 'Vrbnik', 'Vrbnik', 'Verbenico,Vrbnik', 45.0758300, 14.6725000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64499, 'Vrbje', 'Vrbje', 'Vrbje,Vrblje', 45.1875000, 17.4191700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64500, 'Vrbanja', 'Vrbanja', 'Verbanya,Vrbanja,Vrbanje', 44.9813900, 18.9272200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64501, 'Vratišinec', 'Vratisinec', 'Vratisinec,Vratišinec', 46.4780600, 16.4577800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64502, 'Seget Vranjica', 'Seget Vranjica', 'Seget Vranjica,Vranjca,Vranjica,Vranjča', 43.5099900, 16.1870400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64503, 'Voloder', 'Voloder', 'Voloder', 45.5480600, 16.6788900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64504, 'Vojnić', 'Vojnic', 'Vojnic,Vojnich,Vojnić', 45.3236100, 15.6986100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64505, 'Vodnjan', 'Vodnjan', 'Adinianum,Dignano,Dignano d''Istria,Dignano d’Istria,Vodnan,Vodnjan,fwdnyan,wdnyan,wo de nian,Воднян,Водњан,فودنيان,ودنیان,ڤۆدنیان,沃德年', 44.9594400, 13.8516700, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64506, 'Vođinci', 'Vodinci', 'Vodinci,Vodjinci,Vođinci', 45.2755600, 18.6097200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64507, 'Vodice', 'Vodice', 'Arausa,Vodice,Vodizze,vu~oditsu~e,wdytsh  krwasy,wo di cai,Водице,Водіце,ودیتسه، کرواسی,ڤۆدیتسێ,ヴォディツェ,沃迪采', 43.7608300, 15.7827800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64508, 'Voćin', 'Vocin', 'Vocin,Voćin,Vuchin,Vucsin', 45.6177800, 17.5477800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64509, 'Vladislavci', 'Vladislavci', 'Vladislavci', 45.4594400, 18.5741700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64510, 'Vižinada', 'Vizinada', 'Comuna Vizinada,Comuna Vižinada,Visinada,Visinal,Vizhinada,Vizinada,Vižinada,vu~ijinada,Вижинада,ヴィジナダ', 45.3294400, 13.7586100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64511, 'Visoko', 'Visoko', 'Visoko', 46.0902800, 16.3250000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64512, 'Višnjevac', 'Visnjevac', 'Adolfovac,Adolfovac Pusta,Visnjevac,Višnjevac', 45.5686100, 18.6138900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64513, 'Visignano', 'Visignano', 'Comuna Visnjan,Comuna Višnjan,Vishn''jan,Vishnan,Visignano,Visignano d''Istria,Visignano d’Istria,Visinianum,Visnjan,Vixignan,Višnjan,Вишньян,Вишњан', 45.2763900, 13.7208300, 'HR', '2016-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64514, 'Viškovci', 'Viskovci', 'Viskovci,Viškovci', 45.3450000, 18.4622200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64515, 'Vis', 'Vis', 'Lissa,Vis', 43.0619400, 16.1830600, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64516, 'Virovitica', 'Virovitica', 'Sesta,Veroce,Verocze,Veröcze,Verőce,Virovitica,Virovitisa,Weretz,Werowititz,Вировитица', 45.8319400, 17.3838900, 'HR', '2012-11-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64517, 'Virje', 'Virje', 'Prodaviz,Prodavíz,Virje', 46.0672200, 16.9900000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64518, 'Vir', 'Vir', 'Puntadura,Vir', 44.3030600, 15.0852800, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64519, 'Vinkovci', 'Vinkovci', 'Cibalae,Vinkovcai,Vinkovce,Vinkovci,Vinkovcy,Vinkovcze,Winkowitz,Winkowzi,binkobeuchi,vu~inkovutsu~i,wen ke fu qi,wynkwtsy,Винковци,Винковцы,Вінковці,وینکوتسی,ڤینکۆڤتسی,ヴィンコヴツィ,溫科夫齊,빈코브치', 45.2883300, 18.8047200, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64520, 'Vinica', 'Vinica', 'Vinica', 46.3361100, 16.1494400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64521, 'Vinež', 'Vinez', '', 45.0980600, 14.1069400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64522, 'Viljevo', 'Viljevo', 'Viljevo,Villyo,Villyó,Vilyevo', 45.7513900, 18.0630600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64523, 'Vidovec', 'Vidovec', 'Vidovec', 46.2833300, 16.2411100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64524, 'Velimirovac', 'Velimirovac', '', 45.5236100, 18.1094400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64525, 'Veliko Trojstvo', 'Veliko Trojstvo', 'Trojstvo Veliko,Veliko Trojstvo', 45.9355600, 16.9341700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64526, 'Veliko Trgovišće', 'Veliko Trgovisce', 'Veliko Trgovisce,Veliko Trgoviste,Veliko Trgovište,Veliko Trgovišće', 46.0000000, 15.8500000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64527, 'Veliki Grđevac', 'Veliki Grgevac', 'Velika Grdevas,Velika Grđevas,Veliki Grcevac,Veliki Grdevac,Veliki Grćevac,Veliki Grđevac', 45.7502800, 17.0475000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64528, 'Veliki Drvenik', 'Veliki Drvenik', 'Drivenik,Drvenik,Drvenik Veliki,Veli Drvenik,Veliki Drvenik,Zirona,Вели Дрвеник', 43.4500000, 16.1500000, 'HR', '2012-01-19', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64529, 'Veliki Bukovec', 'Veliki Bukovec', 'Veliki Bukovec', 46.2944400, 16.7130600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64530, 'Velika Trnovitica', 'Velika Trnovitica', 'Trnovitica,Velika Trnovitica', 45.6825000, 16.9538900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64531, 'Velika Pisanica', 'Velika Pisanica', 'Gross-Pisanitz,Nagypiszanica,Piszanicza', 45.8016000, 17.0655100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64532, 'Velika Ostrna', 'Velika Ostrna', 'Ostrna,Ostrna Velika,Velika Ostrna', 45.7875200, 16.2813900, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64533, 'Velika Mlaka', 'Velika Mlaka', 'Velika Mlaka', 45.7363900, 16.0311100, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64534, 'Velika Ludina', 'Velika Ludina', 'Velika Ludina', 45.6000000, 16.6000000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64535, 'Velika Kopanica', 'Velika Kopanica', 'Velica Kopanica,Velika Kopanica', 45.1561100, 18.3930600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64536, 'Velika Gorica', 'Velika Gorica', 'Nagygorica,Nagygoricza,Velika Gorica,Velika Goricja,Velika-Gorica,da ge li cha,wlyka grytsa,Велика Горица,Велика Гориця,Велика-Горица,ولیکا گریتسا,ڤێلیکا گۆریتسا,ヴェリカ・ゴリツァ,大戈里察', 45.7125000, 16.0755600, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64537, 'Velika', 'Velika', 'Comuna Velika,Velika,Velike,Велика', 45.4544400, 17.6613900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64538, 'Vela Luka', 'Vela Luka', 'Bela Luka,Vallegrande,Vela Luka,Vela-Luka,Velika Luka,Velja Luka,Вела-Лука', 42.9633300, 16.7225000, 'HR', '2016-05-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64539, 'Varaždinske Toplice', 'Varazdinske Toplice', 'Aqua Laseca,Aquae Lasae,Toplica,Toplice Varasdinszke,Varasdfuerdo,Varasdfürdő,Varasdteplicz,Varazdinske Toplice,Varazdinske toplice,Varazhdins''ke Toplice,Varazhdinske Toplice,Varazhdinske-Toplice,Varaždinske Toplice,Varaždinske toplice,Warasdin-Toplitz,Warasdin-Töplitz,wa la ri ding tuo pu li cai,warazhdynskh tplytsh,Вараждинске Топлице,Вараждинске-Топлице,Вараждинське Топлице,واراژدینسکه تپلیتسه,ڤاراژدینسکێ تۆپلیتسێ,瓦拉日丁托普利采', 46.2091700, 16.4191700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64540, 'Varaždin', 'Varazdin', 'Aqua Viva,Varasd,Varasdino,Varasdinum,Varazdin,Varazhdin,Varaždin,Waraschdin,Warasdin,Вараждин', 46.3044400, 16.3377800, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64541, 'Valpovo', 'Valpovo', 'Jovalium,Valpach,Valpo,Valpovo,Valpó,Walpowo,Валпово', 45.6608300, 18.4186100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64542, 'Unešić', 'Unesic', 'Unesic,Unešić', 43.7405600, 16.1897200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64543, 'Umag', 'Umag', 'Humacum,Oumank,Umag,Umag Komunela,Umago,awmag,umag,umagu,wu ma ge,ywmag,Ούμαγκ,Умаг,ئوماگ,اوماگ,ウマグ,烏馬格', 45.4313900, 13.5238900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64544, 'Ugljan', 'Ugljan', 'Ugliano,Ugljan,Uljan', 44.1308300, 15.1030600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64545, 'Udbina', 'Udbina', 'Udbina', 44.5305600, 15.7655600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64546, 'Tužno', 'Tuzno', 'Cerje Tuzno,Cerje Tužno,Tuzno,Tužno', 46.2566700, 16.2350000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64547, 'Turjaci', 'Turjaci', 'Turjaci,Turjake', 43.6500000, 16.6691700, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64548, 'Turanj', 'Turanj', 'Torrette,Turanj', 43.9711100, 15.4113900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64549, 'Tuhelj', 'Tuhelj', 'Tuhelj', 46.0769400, 15.7472200, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64550, 'Tučepi', 'Tucepi', 'Tucepa,Tucepi,Tučepi', 43.2722200, 17.0544400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64551, 'Trpinja', 'Trpinja', 'Terpinja,Terpinya,Trpinja', 45.4191700, 18.8991700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64552, 'Trpanj', 'Trpanj', 'Comuna Trpanj,Trappano,Trpan,Trpan'',Trpani,Trpanj,Трпань,Трпањ', 43.0075000, 17.2750000, 'HR', '2016-05-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64553, 'Trogir', 'Trogir', 'Tragurium,Trau,Traù,Trogir,Trogiras,Tronkir,te luo ji er,teulogileu,torogiru,trwgyr,Τρογκίρ,Трогир,Трогір,טרוגיר,تروگیر,ترۆگیر,ტროგირი,トロギル,特罗吉尔,트로기르', 43.5125000, 16.2516700, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64554, 'Trnovec Bartolovečki', 'Trnovec Bartolovecki', 'Bartolovecki Trnovec,Bartolovečki Trnovec,Trnovec,Trnovec Bartolovecki,Trnovec Bartolovečki', 46.2947200, 16.3988900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64555, 'Trnava', 'Trnava', 'Ternava,Trnava', 45.2613900, 18.2530600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64556, 'Trilj', 'Trilj', 'Trilj', 43.6183300, 16.7241700, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64557, 'Tribunj', 'Tribunj', '', 43.7554700, 15.7444400, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64558, 'Tovarnik', 'Tovarnik', 'Tovarnik', 45.1650000, 19.1519400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64559, 'Tounj', 'Tounj', 'Tounj', 45.2514500, 15.3255000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64560, 'Tordinci', 'Tordinci', 'Tordince,Tordinci,Tordincze', 45.3702800, 18.7950000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64561, 'Topusko', 'Topusko', 'Staro Selo Topusko,Topusko,Topuszko,Topuszkó', 45.2930600, 15.9722200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64562, 'Tompojevci', 'Tompojevci', 'Tompojevci', 45.2333300, 19.0919400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64563, 'Korenica', 'Korenica', 'Korenica,Titova Korenica', 44.7438900, 15.7097200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64564, 'Tinjan', 'Tinjan', 'Antignana,Antignano,Tinjan', 45.2180600, 13.8394400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64565, 'Tisno', 'Tisno', 'Stretto,Tijesno,Tisno', 43.8041700, 15.6433300, 'HR', '2016-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64566, 'Tenja', 'Tenja', 'Sveta Ana,Tenja,Tenje,Tenye', 45.4980600, 18.7472200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64567, 'Tar', 'Tar', 'Tar,Torre,Torre di Parenzo', 45.3008300, 13.6252800, 'HR', '2016-05-31', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64568, 'Svetvinčenat', 'Svetvincenat', 'San Vincenti d''Istria,San Vincenti d’Istria,Sanvincenti,Sveti Vincenat,Sveti Vinčenat,Svetvincenat,Svetvinčenat', 45.0880600, 13.8836100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64569, 'Sveti Petar u Šumi', 'Sveti Petar u Sumi', 'Petar u Sumi,Petar u Šumi,San Pietro in Selva,San Pietro in Selve,Sveti Petar,Sveti Petar u Sumi,Sveti Petar u Šumi,Sveti Petor u Sumi,Sveti Petor u Šumi', 45.1836100, 13.8683300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64570, 'Sveti Martin na Muri', 'Sveti Martin na Muri', 'Ormos,Ormós,Sveti Martin,Sveti Martin na Muri,Vrhovljan,Vrhovoljan', 46.5269400, 16.3750000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64571, 'Sveti Ilija', 'Sveti Ilija', 'Sveti Ilija', 46.2469400, 16.3252800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64572, 'Sveti Ðurđ', 'Sveti Durd', '', 46.2844400, 16.6041700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64573, 'Sveta Nedjelja', 'Sveta Nedjelja', 'Nedjelja,Sveta Nedelja,Sveta Nedjelja', 45.7983300, 15.7805600, 'HR', '2016-02-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64574, 'Sveta Marija', 'Sveta Marija', 'Sveta Marija,Sveta Marija na Muri', 46.3355600, 16.7419400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64575, 'Sutivan', 'Sutivan', 'Sutivan', 43.3858300, 16.4769400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64576, 'Supetarska Draga', 'Supetarska Draga', 'Supetar,Supetarska Draga,Valle San Pietro', 44.7975000, 14.7247200, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64577, 'Supetar', 'Supetar', 'Fanum Sancti Petri Brattiae,San Pietro della Brazza,San Pietro di Brazza,Supetar,su pei ta er,supetaru,swptar,Супетар,سوپتار,سوپێتار,スペタル,蘇佩塔爾', 43.3841700, 16.5508300, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64578, 'Sunja', 'Sunja', 'Sunja', 45.3685000, 16.5670200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64579, 'Sukošan', 'Sukosan', 'San Cassiano,Sukosan,Sukošan', 44.0500000, 15.3166700, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64580, 'Suhopolje', 'Suhopolje', 'Suhoplje,Suhopolje,Theresowatz', 45.7997200, 17.4991700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64581, 'Sućuraj', 'Sucuraj', 'Sucuraj,Sućuraj', 43.1252800, 17.1861100, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64582, 'Strmec', 'Strmec', 'Odranski Strmec,Strmec', 45.7084300, 15.9167400, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64583, 'Strizivojna', 'Strizivojna', 'Strizivojna', 45.2261100, 18.4238900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64584, 'Štrigova', 'Strigova', 'Strido,Stridovar,Stridó,Stridóvár,Strigova,Strigovo,Štrigova,Štrigovo', 46.5022200, 16.2883300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64585, 'Strahoninec', 'Strahoninec', 'Strahoninec', 46.3688900, 16.4150000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64586, 'Ston', 'Ston', 'Comuna Ston,Stagno,Stagnum,Ston,suton,Стон,ストン', 42.8386100, 17.6963900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64587, 'Stobreč', 'Stobrec', 'Stobrec,Stobreč', 43.5025000, 16.5222200, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64588, 'Štitar', 'Stitar', 'Stitar,Štitar', 45.0955600, 18.6402800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64589, 'Štefanje', 'Stefanje', 'Stefanje,Stefanje Novo,Štefanje,Štefanje Novo', 45.8047200, 16.7202800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64590, 'Staro Petrovo Selo', 'Staro Petrovo Selo', 'Staro Petrovo Selo', 45.2308300, 17.5202800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64591, 'Stari Perkovci', 'Stari Perkovci', 'Perkovci Stari,Stari Perkovci', 45.2175000, 18.3486100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64592, 'Stari Mikanovci', 'Stari Mikanovci', 'Stari Mikanovci', 45.2816700, 18.5425000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64593, 'Stari Jankovci', 'Stari Jankovci', 'Alt-Jankowitz,Alt-Jankowzi,Jankovci,Ojankovac,Ojankovacz,Stari Jankovci,Sztare Jankovcze,Ójankovác,Ójankovácz', 45.2619400, 18.9144400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64594, 'Starigrad', 'Starigrad', 'Cittavecchia,Stari Grad,Starigrad,Starigrad-Paklenica,Velika Paklenica,Стари Град', 44.2960100, 15.4386500, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64595, 'Stari Grad', 'Stari Grad', 'Cittavecchia,Civitas Vetus,Stari Grad,Stari grad,Starigrad,Starij Grad,seutaligeuladeu,si ta li ge lei,stary grad,Стари Град,Стари град,Стариград,Старий Град,סטארי גראד,ستاری گراد,スタリー・グラード,斯塔里格勒,스타리그라드', 43.1847200, 16.5952800, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64596, 'Stara Gradiška', 'Stara Gradiska', 'Alt-Gradiska,Ogradiska,Stara Gradiska,Stara Gradiška', 45.1486100, 17.2466700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64597, 'Gradina', 'Gradina', 'Gradina,Stara Gradina', 45.8550000, 17.5072200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64598, 'Stankovci', 'Stankovci', 'Stankovci', 43.9097200, 15.6997200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64599, 'Srinjine', 'Srinjine', 'Srinjine', 43.4833300, 16.6000000, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64600, 'Srebreno', 'Srebreno', 'Srebreno,Srebrno', 42.6233300, 18.1961100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64601, 'Sračinec', 'Sracinec', 'Sracinec,Sračinec', 46.3294400, 16.2788900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64602, 'Split', 'Split', 'Gorad Split,SPU,Spalato,Spalatum,Split,Split / Dalmatien,Splita,Splitas,Spàlato,asplyt,sblyt,seupeulliteu,si pu li te,splita,splyt,supurito,Σπλιτ,Горад Спліт,Сплит,Спліт,Սպլիտ,ספליט,اسپلیت,سبليت,سپلٹ، کروشیا,स्प्लिट,სპლიტი,スプリト,斯普利特,스플리트', 43.5089100, 16.4391500, 'HR', '2016-04-29', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64603, 'Špišić-Bukovica', 'Spisic-Bukovica', 'Bakva,Bukovica,Nova Bukovica,Spisic-Bukovica,Spissiczka-Bukovicza,Srpsko Bukovica,Špišić-Bukovica', 45.8572200, 17.2994400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64604, 'Sopje', 'Sopje', 'Sopje,Sorje,Szopje', 45.8011100, 17.7425000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64605, 'Soljani', 'Soljani', 'Soljani', 44.9502800, 18.9702800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64606, 'Solin', 'Solin', 'Salona,Solin,slyn  krwasy,sorin,suo lin,swlyn,Солин,Солін,سلین، کرواسی,سولین,سۆلین,ソリン,索林', 43.5432000, 16.4931400, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64607, 'Sokolovac', 'Sokolovac', 'Sokolovac', 46.1108300, 16.7063900, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64608, 'Šodolovci', 'Sodolovci', 'Sodolovci,Šodolovci', 45.4000000, 18.6202800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64609, 'Smokvica', 'Smokvica', 'Smokvica,Smoquizza', 42.9305600, 16.8963900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64610, 'Slunj', 'Slunj', 'Slun,Slun'',Slunj,Szluin,si lu ni,slwny,Слунь,Слуњ,سلونی,斯盧尼', 45.1150700, 15.5845800, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64611, 'Slobodnica', 'Slobodnica', 'Slobodnica', 45.1622200, 17.9327800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64612, 'Slavonski Brod', 'Slavonski Brod', 'Brod,Bród,Marsonia,Slavons''kij Brod,Slavonski Brod,Slavonski Brodas,Slavonski brod,Slavonski-Brod,Slawonisch Brod,aslawnsky brd,seullabonseukibeulodeu,si la wo ni ya bu luo de,sla wxn ski br xd,slafwnsky brwd,slbwnsqy brwd,Славонски Брод,Славонски брод,Славонски-Брод,Славонський Брод,סלבונסקי ברוד,اسلاونسکی برد,سلافونسكي برود,سلاڤۆنسکی برۆد,สลาวอนสกีบรอด,スラヴォンスキ・ブロド,斯拉沃尼亞布羅德,슬라본스키브로드', 45.1602800, 18.0155600, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64613, 'Požega', 'Pozega', 'Incerum,Poschega,Poschegg,Posega,Pozega,Pozhega,Pozsega,Pozsegavar,Pozsegavár,Požega,Slavonska Pozega,Slavonska Požega,bo re jia,bwzygha,pojega,pwzhhghh,pwzhyga  krwyysha,pzhga  krwasy,Пожега,بوزيغا,پوژهغه,پوژیگا، کرویئشا,پژگا، کرواسی,پۆژێگا,პოჟეგა,ポジェガ,波熱加,포제가', 45.3402800, 17.6852800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64614, 'Slatine', 'Slatine', 'Bagno di Bua,Slatine', 43.4994400, 16.3333300, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64615, 'Slano', 'Slano', 'Slano', 42.7861100, 17.8919400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64616, 'Škrljevo', 'Skrljevo', '', 45.3205300, 14.5326800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64617, 'Skradin', 'Skradin', 'Gorad Skradzin,Scardona,Skradin,si ke la ding,skradyn,Горад Скрадзін,Скрадин,Скрадін,سکرادین,斯克拉丁', 43.8202800, 15.9236100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64618, 'Skrad', 'Skrad', 'Skrad', 45.4277800, 14.9111100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64619, 'Škabrnje', 'Skabrnje', '', 44.0913900, 15.4538900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64620, 'Sisak', 'Sisak', 'Gorad Sisak,Segesta,Sisak,Sisakas,Siscia,Sisek,Sisseg,Sissek,Sziszek,shisaku,sisakeu,sysak,xi sa ke,Σίσακ,Горад Сісак,Сисак,Сісак,سيساك,سیساک,シサク,錫薩克,시사크', 45.4661100, 16.3783300, 'HR', '2012-11-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64621, 'Široko Polje', 'Siroko Polje', 'Siroko Polje,Široko Polje', 45.4052800, 18.4725000, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64622, 'Sirač', 'Sirac', 'Sirac,Sirač', 45.5233300, 17.2550000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64623, 'Sinj', 'Sinj', 'Setovium,Signo,Sin,Sin'',Sinj,shini,sin,syny,syny  krwasy,xi ni,Синь,Сињ,Сінь,סיני,سینی,سینی، کرواسی,シニ,錫尼,신', 43.7036100, 16.6394400, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64624, 'Sikirevci', 'Sikirevci', 'Sikirevci', 45.1088900, 18.4644400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64625, 'Sigetec', 'Sigetec', '', 46.1883300, 16.9358300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64626, 'Sibinj', 'Sibinj', 'Sibinj', 45.1916700, 17.9080600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64627, 'Šibenik', 'Sibenik', 'Sebenico,Sebenicum,Shibenik,Shibeniku,Sibenik,Sibenikas,Szybenik,shibeniku,shybynyk,sibenikeu,sybnyk,sybnyq,xi bei ni ke,Şibenik,Šibenik,Šibenikas,Шибеник,שיבניק,سیبنیک,شيبينيك,شیبێنیک,シベニク,希贝尼克,시베니크', 43.7272200, 15.9058300, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64628, 'Sesvete', 'Sesvete', 'Sesvete,Сесвете', 45.8311100, 16.1163900, 'HR', '2013-05-16', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64629, 'Šestanovac', 'Sestanovac', 'Sestanovac,Šestanovac', 43.4544400, 16.9113900, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64630, 'Šenkovec', 'Senkovec', 'Senkovec,Šenkovec', 46.4088900, 16.4216700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64631, 'Senj', 'Senj', 'Segna,Segno,Sen,Sen'',Senia,Senis,Senj,Senya,Zengg,sai ni,sen,seni,sny,Сен,Сень,Сењ,سنی,سێنی,セニ,塞尼,센', 44.9894400, 14.9058300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64632, 'Semeljci', 'Semeljci', 'Semeljci', 45.3605600, 18.5436100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64633, 'Selnica', 'Selnica', 'Selnica,Szelenczehegy', 46.4930700, 16.3893700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64634, 'Selce', 'Selce', 'Selce,Selze', 45.1563900, 14.7211100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64635, 'Selca', 'Selca', 'Selca', 43.2972200, 16.8508300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64636, 'Satnica Ðakovačka', 'Satnica Dakovacka', 'Dakovacka Satnica,Dakovacka Slatnica,Djakovacka Satnica,Djakovačka Satnica,Satnica Dakovacka,Satnica Djakovacka,Satnica Djakovačka,Satnica Ðakovačka,Szatnicza,Ðakovačka Satnica,Ðakovačka Slatnica', 45.3558300, 18.3780600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64637, 'Sarvaš', 'Sarvas', 'Hirschfeld,Sarvas,Sarvash,Sarvaš,Sarwasch,Szarvas', 45.5272200, 18.8375000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64638, 'Šandrovac', 'Sandrovac', 'Sandorovac,Sandrovac,Šandorovac,Šandrovac', 45.9055600, 17.0211100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64639, 'Samobor', 'Samobor', 'Samobor,Szamobor,Самобор', 45.8030600, 15.7180600, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64640, 'Slavonski Šamac', 'Slavonski Samac', 'Samac,Samac Slavonski,Slavonski Samac,Slavonski Šamac,Šamac,Šamac Slavonski', 45.0666700, 18.4888900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64641, 'Sali', 'Sali', 'Sale,Sali,Сали', 43.9397200, 15.1633300, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64642, 'Saborsko', 'Saborsko', 'Saborski,Saborsko', 44.9833300, 15.4780600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64643, 'Ružić', 'Ruzic', 'Ruzic,Ružić', 43.8241200, 16.2566800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64644, 'Ruščica', 'Ruscica', '', 45.1466700, 18.0794400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64645, 'Runović', 'Runovic', 'Runovic,Runović', 43.3766700, 17.2366700, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64646, 'Rugvica', 'Rugvica', 'Comuna Rugvica,Rugvica,Ругвица', 45.7361100, 16.2330600, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64647, 'Rude', 'Rude', '', 45.7666700, 15.6666700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64648, 'Rubeši', 'Rubesi', '', 45.3669400, 14.3480600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64649, 'Rovišće', 'Rovisce', 'Rovisce,Rovišće', 45.9447200, 16.7350000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64650, 'Rovinj', 'Rovinj', 'Arupinum,Rovigno,Rovigno d''Istria,Rovigno d’Istria,Rovin,Rovin'',Rovini,Rovinj,Rovinji,lobin,luo wei ni,rovu~ini,rwbyny,rwfynj,rwwyny,Ρόβινι,Ровин,Ровинь,Ровињ,Ровінь,רוביני,روفينج,رووینی,ロヴィニ,羅維尼,로빈', 45.0800000, 13.6400000, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64651, 'Rokovci', 'Rokovci', 'Rokovci', 45.2311100, 18.7438900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64652, 'Rogoznica', 'Rogoznica', 'Rogosnizza,Rogoznica', 43.5247200, 15.9700000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64653, 'Rijeka', 'Rijeka', 'Estado libre de Fiume,Fiume,Fkumen,Flumen Sancti Viti,RJK,Reka,Rieka,Rijeka,Rijeko,Rěka,Sankt Veit am Flaum,Sankt Veit am Pflaum,Slobodna Drzava Rijeka,Slobodna Drzhava Rijeka,Slobodna Država Rijeka,Stato libero di Fiume,Vitipolis,rieka,Риека,Ријека,Слободна Држава Ријека,リエカ', 45.3267300, 14.4424100, 'HR', '2017-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64654, 'Ribnik', 'Ribnik', 'Comuna Ribnik,Ribnik,Рибник', 45.5794400, 15.3513900, 'HR', '2016-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64655, 'Rezovac', 'Rezovac', 'Rezovac,Rezovac-Krcevina,Rezovac-Krčevina,Rezovacke Krcevine,Rezovačke Krčevine', 45.7833300, 17.4166700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64656, 'Retkovci', 'Retkovci', 'Retkovci', 45.2333300, 18.6530600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64657, 'Rešetari', 'Resetari', 'Resetari,Rešetari', 45.2623200, 17.4234600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64658, 'Repušnica', 'Repusnica', 'Repusnica,Repušnica', 45.4927800, 16.7308300, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64659, 'Remetinec', 'Remetinec', '', 46.1852800, 16.3277800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64660, 'Reka', 'Reka', 'Reka,Rijeka', 46.1302800, 16.7669400, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64661, 'Ražanac', 'Razanac', 'Razanac,Ražanac', 44.2819400, 15.3480600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64662, 'Ravna Gora', 'Ravna Gora', 'Gora,Ravna Gora', 45.3727800, 14.9352800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64663, 'Rasinja', 'Rasinja', 'Rasinja', 46.1838900, 16.7066700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64664, 'Raša', 'Rasa', 'Arsia,Comuna Rasa,Comuna Raša,Rasa,Rasha,Raša,Раша', 45.0802800, 14.0788900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64665, 'Rakov Potok', 'Rakov Potok', 'Rakov Potok', 45.7380600, 15.7972200, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64666, 'Rakovica', 'Rakovica', 'Rakovica,Раковица', 44.9931500, 15.6502800, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64667, 'Rakovec', 'Rakovec', 'Rakovac,Rakovec', 45.9302800, 16.3225000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64668, 'Rakitje', 'Rakitje', 'Rakitje', 45.7938900, 15.8222200, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64669, 'Radoboj', 'Radoboj', 'Radoboj,Radobolj', 46.1663900, 15.9236100, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64670, 'Rabac', 'Rabac', 'Rabac,Rabac Luka,Rabaz', 45.0794400, 14.1575000, 'HR', '2012-11-14', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64671, 'Rab', 'Rab', 'Arba,Arbe,Pulau Rab,Rab,la bu dao,rabu dao,Ραμπ,Раб,ראב,ラブ島,拉布島', 44.7569400, 14.7608300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64672, 'Punitovci', 'Punitovci', 'Punitovci', 45.4330600, 18.4163900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64673, 'Punat', 'Punat', 'Aleksandrovo,Ponte,Punat,Punca', 45.0147200, 14.6288900, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64674, 'Pula', 'Pula', 'PUY,Pietas Iulia,Pluj,Pola,Poula,Poła,Pul,Pula,Pulj,bwla,pu la,pulla,pura,pwla,pwlh,Πούλα,Пула,Պուլա,פולא,פולה,بولا,پولا,პულა,プーラ,普拉,풀라', 44.8683300, 13.8480600, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64675, 'Pučišća', 'Pucisca', 'Pucisca,Pucisce,Pucischie,Puciste,Pučisča,Pučište,Pučišće', 43.3477800, 16.7338900, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64676, 'Privlaka', 'Privlaka', 'Privlaka', 45.1947200, 18.8375000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64677, 'Privlaka', 'Privlaka', 'Brevilacqua,Prevlaka,Privlaka', 44.2666700, 15.1333300, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64678, 'Primošten', 'Primosten', 'Capocesto,Primoscen,Primoshten,Primosten,Primošten,Primošćen,Примоштен', 43.5863200, 15.9230200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64679, 'Primorski Dolac', 'Primorski Dolac', 'Donji Dolac,Primorski Dolac,Suhi Dolac', 43.6308300, 16.1761100, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64680, 'Prigorje Brdovečko', 'Prigorje Brdovecko', 'Brdovecko Prigorje,Brdovečko Prigorje,Prigorje,Prigorje Brdovecko,Prigorje Brdovečko', 45.8794400, 15.7380600, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64681, 'Pridraga', 'Pridraga', 'Pridraga', 44.1666700, 15.5666700, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64682, 'Pribislavec', 'Pribislavec', 'Pribislavec', 46.3925000, 16.4825000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64683, 'Prgomet', 'Prgomet', 'Prgomet', 43.6063100, 16.2291200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64684, 'Prelog', 'Prelog', 'Perlacum,Perlak,Prelog,Prelonk,prlg  krwasy,pu lei luo ge,Πρέλογκ,Прелог,پرلگ، کرواسی,پرێلۆگ,普雷洛格', 46.3350000, 16.6155600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64685, 'Osljak', 'Osljak', 'Oltre,Preko', 44.0766700, 15.2072200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64686, 'Pregrada', 'Pregrada', 'Pregrada,prgrada,pu lei ge la da,Преграда,پرگرادا,پرێگرادا,普雷格拉達', 46.1641700, 15.7508300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64687, 'Predavac', 'Predavac', 'Predavac,Predavec', 45.9358300, 16.7833300, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64688, 'Povljana', 'Povljana', 'Nova Poljana,Pogliana,Poljana,Polyana,Povljan,Povljana', 44.3466700, 15.1155600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64689, 'Postira', 'Postira', 'Postira,Postire,Selo Postire', 43.3755100, 16.6309100, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64690, 'Posedarje', 'Posedarje', 'Posedarija,Posedarje,Possedaria', 44.2136100, 15.4766700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64691, 'Poreč', 'Porec', 'Parentium,Parenzo,Porec,Porecas,Porech,Porets,Poreč,Porečas,bo lei qi,polechi,porech,poretchi,prch,pwrz,Πόρετς,Пореч,פורץ,پرچ,پۆرێچ,ポレッチ,波雷奇,포레치', 45.2256700, 13.5951100, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64692, 'Popovača', 'Popovaca', 'Popovaca,Popovacha,Popovača', 45.5697200, 16.6250000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64693, 'Popovac', 'Popovac', 'Popovac', 45.8091700, 18.6583300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64694, 'Poljanica Bistranska', 'Poljanica Bistranska', 'Bistranska Poljanica,Poljanica,Poljanica Bistranska', 45.9007600, 15.8758400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64695, 'Poličnik', 'Policnik', 'Polesnik,Polešnik,Policnik,Polisseno,Poličnik', 44.1780600, 15.3755600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64696, 'Polača', 'Polaca', 'Polaca,Polača', 44.0183300, 15.5175000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64697, 'Pokupsko', 'Pokupsko', 'Pokupsko,Popusko', 45.4872200, 15.9933300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64698, 'Pojatno', 'Pojatno', '', 45.9050000, 15.8005600, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64699, 'Podvinje', 'Podvinje', 'Podvinj,Podvinje', 45.1902800, 18.0269400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64700, 'Podturen', 'Podturen', 'Podturen', 46.4647200, 16.5430600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64701, 'Podstrana', 'Podstrana', 'Podstrana,Postrana', 43.4866800, 16.5501300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64702, 'Podravske Sesvete', 'Podravske Sesvete', 'Podravske Sesvete', 46.0050000, 17.2116700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64703, 'Slatina', 'Slatina', 'Podravska Slatina,Slatina,Szalatnok,Szlatina,si la di na,slatyna,slatyna  krwasy,Слатина,سلاتینا,سلاتینا، کرواسی,斯拉蒂納', 45.7033300, 17.7027800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64704, 'Podhum', 'Podhum', 'Podhum,Pothum', 45.3872200, 14.4794400, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64705, 'Podgorač', 'Podgorac', 'Podgorac,Podgoracs,Podgorač,Podgorács,Pogoracs,Pogorács', 45.4586100, 18.2227800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64706, 'Podgora', 'Podgora', 'Podgora', 43.2433300, 17.0772200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64707, 'Podcrkavlje', 'Podcrkavlje', 'Podcrkavje,Podcrkavlje', 45.2238900, 18.0100000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64708, 'Ploče', 'Ploce', 'Kardeljevo,Ploca,Ploce,Ploce Luka,Ploche,Ploča,Ploče,Ploče Luka,Плоче', 43.0561100, 17.4327800, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64709, 'Pleternica', 'Pleternica', 'Peternica,Pleternica,Pleterniceszentmiklos,Pleterniceszentmiklós,Pleternicja,pltrnytsa,pu lai tai er ni cha,pureterunitsu~a,Плетерница,Плетерниця,پلترنیتسا,پلێتێرنیتسا,プレテルニツァ,普萊泰爾尼察', 45.2886100, 17.8063900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64710, 'Plaški', 'Plaski', 'Plaski,Plaški', 45.0763900, 15.3680600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64711, 'Pitomača', 'Pitomaca', 'Pitomaca,Pitomača,Pittomacha', 45.9505600, 17.2294400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64712, 'Piškorevci', 'Piskorevci', 'Piskorevci,Piškorevci', 45.2552800, 18.4041700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64713, 'Pisarovina', 'Pisarovina', 'Pisarovina,Piszarovina', 45.5863900, 15.8591700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64714, 'Pirovac', 'Pirovac', 'Piravac,Pirovac', 43.8191700, 15.6727800, 'HR', '2016-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64715, 'Pićan', 'Pican', 'Padena,Pedena,Pican,Pićan', 45.2061100, 14.0427800, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64716, 'Petrovsko', 'Petrovsko', 'Petrovsko', 46.1680600, 15.8408300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64717, 'Petrinja', 'Petrinja', 'Petrinia,Petrinja,Petrinya', 45.4375000, 16.2900000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64718, 'Petrijevci', 'Petrijevci', 'Petrievcze,Petrijevci,Petrowitz', 45.6127800, 18.5352800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64719, 'Petrijanec', 'Petrijanec', 'Petrijanec,Petriyanets', 46.3491700, 16.2250000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64720, 'Petlovac', 'Petlovac', 'Petlovac', 45.7583300, 18.5280600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64721, 'Peteranec', 'Peteranec', 'Peteranac,Peteranec', 46.1922200, 16.8916700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64722, 'Perušić', 'Perusic', 'Perrussich,Perusic,Perušić', 44.6494400, 15.3833300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64723, 'Peklenica', 'Peklenica', 'Peklenica,Peklenicza', 46.4952800, 16.4761100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64724, 'Pazin', 'Pazin', 'Pazin,Pazinas,Pisino,Pisinum,Pixin,bazyn,pa jin,pajin,pazyn,Пазин,פאזין,بازين,پازین,პაზინი,パジン,帕津,파진', 45.2402800, 13.9366700, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64725, 'Pašman', 'Pasman', 'Pasman,Pašman', 43.9575000, 15.3850000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64726, 'Pakrac', 'Pakrac', 'Pakrac,Pakracz,Pakratz,Pakrác,Pakrácz,Pekercz,Pekrecz,Пакрац', 45.4363900, 17.1888900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64727, 'Pakoštane', 'Pakostane', 'Pacostane,Pakostane,Pakoštane', 43.9122200, 15.5088900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64728, 'Pag', 'Pag', 'Isola di Pago,Pag,Pagas,Pago,Paj,Паг', 44.4450000, 15.0575000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64729, 'Ozalj', 'Ozalj', 'Ozalj', 45.6066700, 15.4619400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64730, 'Otok', 'Otok', 'Atak,Otok,Ottock,Оток', 45.1466700, 18.8838900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64731, 'Otok', 'Otok', 'Isola,Otok,Оток', 43.6864300, 16.7332900, 'HR', '2016-02-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64732, 'Otočac', 'Otocac', 'Otocac,Otochac,Otocsan,Otocsán,Otočac,ao tuo cha ci,atchats,Оточац,ئۆتۆچاتس,اتچاتس,奧托查茨', 44.8694400, 15.2375000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64733, 'Oštarije', 'Ostarije', 'Ostarije,Oštarije', 45.2247200, 15.2733300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64734, 'Osijek', 'Osijek', 'Colonia Aelia Mursa,Esseg,Essegg,Essek,Eszek,Eszék,Mursa,Mursia,OSI,Osek,Osiek,Osigiek,Osijek,Osijeka,Osijekas,Osik,oshieku,xo siyekh,Οσιγιέκ,Осиек,Осијек,โอซีเยค,オシエク', 45.5511100, 18.6938900, 'HR', '2012-11-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64735, 'Oroslavje', 'Oroslavje', 'Oroslavje', 45.9967200, 15.9150700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64736, 'Orle', 'Orle', 'Orle', 45.6833300, 16.2333300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64737, 'Oriovac', 'Oriovac', 'Oriovac,Oriovaci', 45.1661100, 17.7600000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64738, 'Orešje', 'Oresje', '', 45.8161800, 15.8024600, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64739, 'Orehovica', 'Orehovica', 'Orehovica', 46.3316700, 16.5069400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64740, 'Sveti Petar Orehovec', 'Sveti Petar Orehovec', 'Orehovec,Sveti Petar,Sveti Petar Orehovec', 46.0755600, 16.4516700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64741, 'Orebić', 'Orebic', 'Orebic,Orebić,Sabbioncello,Sabioncelo,Sabiončelo', 42.9855600, 17.1747200, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64742, 'Orahovica', 'Orahovica', 'Orahovica,Orowitz,Rahoca,Raholca,Rahóca,Slavonska Orahovica', 45.5400000, 17.8847200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64743, 'Opuzen', 'Opuzen', 'Fort Opus,Opus,Opuzen,Опузен', 43.0152800, 17.5655600, 'HR', '2016-05-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64744, 'Oprtalj', 'Oprtalj', 'Comuna Oprtalj,Oprtal,Oprtal'',Oprtalj,Portole,Portulae,Опрталь,Опртаљ', 45.3816700, 13.8261100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64745, 'Oprisavci', 'Oprisavci', 'Oprisavci,Oprisovci', 45.1511100, 18.2297200, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64746, 'Opatija', 'Opatija', 'Abacija,Abbazia,Abbázia,Opatija,Opatijo,opatiya,Опатия,オパティヤ', 45.3377100, 14.3051500, 'HR', '2017-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64747, 'Omišalj', 'Omisalj', 'Castelmuschio,Omisalj,Omišalj', 45.2113400, 14.5549500, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64748, 'Omiš', 'Omis', 'Almissa,Omis,Omiš,omish,Омиш', 43.4447200, 16.6886100, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64749, 'Okučani', 'Okucani', 'Okucani,Okučani', 45.2603400, 17.1992500, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64750, 'Oklaj', 'Oklaj', 'Oklaj', 43.9505600, 16.0822200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64751, 'Ogulin', 'Ogulin', 'Ogulin,agwlyn,ao gu lin,awghwlyn,Огулин,Огулін,אוגולין,أوغولين,ئۆگولین,اگولین,奧古林', 45.2661100, 15.2286100, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64752, 'Odra', 'Odra', 'Odra', 45.7297900, 15.9924000, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64753, 'Obrovac', 'Obrovac', 'Obbrovazzo,Obrovac,Obrovazzo,abrwats  krwasy,ao bu luo wa ci,Обровац,ئۆبرۆڤاتس,ابرواتس، کرواسی,奧布羅瓦茨', 44.2005600, 15.6822200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64754, 'Nuštar', 'Nustar', 'Berzete-Monostor,Berzete-Monostora,Berzéte-Monostor,Berzéte-Monostora,Monostor,Nustar,Nuštar', 45.3325000, 18.8413900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64755, 'Novska', 'Novska', 'Novska,Novszka,Novzka,Новска', 45.3405600, 16.9769400, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64756, 'Novo Selo Rok', 'Novo Selo Rok', 'Novo Selo,Novo Selo Rok', 46.4283900, 16.4621500, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64757, 'Novoselec', 'Novoselec', 'Novoselec', 45.6525000, 16.5363900, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64758, 'Novo Čiče', 'Novo Cice', 'Novo Cice,Novo Čiče', 45.7000000, 16.1166700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64759, 'Novi Vinodolski', 'Novi Vinodolski', 'Novi,Novi Vinodol,Novi Vinodol''ski,Novi Vinodolski,Novi-Vinodolski,nwy wyndwlsky,xin wei nuo duo er si ji,Нови Винодолски,Нови Винодольски,Нови-Винодолски,Нові-Вінодолскі,نوی ویندولسکی,نۆڤی ڤینۆدۆلسکی,新維諾多爾斯基', 45.1280600, 14.7888900, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64760, 'Novi Marof', 'Novi Marof', 'Novi Marof,Novi Morof', 46.1619400, 16.3302800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64761, 'Novigrad Podravski', 'Novigrad Podravski', 'Novi Grad,Novigrad Podravski,Podravski Novi Grad', 46.0780600, 16.9538900, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64762, 'Novigrad', 'Novigrad', 'Aemonia Nova,Cittanova,Cittanova d''Istria,Cittanova d’Istria,Novigrad,novu~igurado,nuo wei ge lei,Новиград,Новіград,نوی‌گراد، ایالت ایستریا,نۆڤیگراد,ノヴィグラード,諾維格勒', 45.3150000, 13.5580600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64763, 'Novigrad', 'Novigrad', 'Novegradi,Novigrad,Новиград', 44.1838900, 15.5541700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64764, 'Novi Golubovec', 'Novi Golubovec', 'Novi Golubovec', 46.1725200, 15.9809000, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64765, 'Nova Rača', 'Nova Raca', 'Nova Raca,Nova Rača', 45.7969400, 16.9536100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64766, 'Novalja', 'Novalja', 'Novaglia,Novala,Novalja,novu~arya,nuo wa li ya,nwalya,Новаля,Новаља,نوالیا,نۆڤالا,ノヴァリャ,諾瓦利亞', 44.5577800, 14.8866700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64767, 'Nova Kapela', 'Nova Kapela', 'Nova Kapela', 45.1988900, 17.6391700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64768, 'Nova Gradiška', 'Nova Gradiska', 'Neu-Gradischka,Neu-Gradiska,Nova Gradiska,Nova Gradisska,Nova Gradiška,Nova Ujgradiska,Nova Újgradiska,Ujgradiska,Újgradiska', 45.2550000, 17.3830600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64769, 'Nova Bukovica', 'Nova Bukovica', 'Bukovica,Nova Bukovica', 45.6647200, 17.7669400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64770, 'Njivice', 'Njivice', 'Gnivizze,Njivice,Njivice  Krk', 45.1580600, 14.5386100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64771, 'Nin', 'Nin', 'Nin,Nona,Нин', 44.2333300, 15.1833300, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64772, 'Nijemci', 'Nijemci', 'Deutschdorf,Nemci,Nemeti,Nempti,Nijemci,Németi', 45.1402800, 19.0355600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64773, 'Nerežišće', 'Nerezisce', 'Nerezisca,Nerezisce,Nerežišća,Nerežišće,Nersi', 43.3311100, 16.5786100, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64774, 'Negoslavci', 'Negoslavci', 'Negoslavci', 45.2794400, 18.9966700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64775, 'Nedeščina', 'Nedescina', 'Nedescina,Nedešćina,Nedeščina,Santa Domenica,Santa Domenica di Albona,Sveta Nedelja,Sveta Nedelja Labinska,Sveta Nedelja od Labina', 45.1400000, 14.1119400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64776, 'Nedeljanec', 'Nedeljanec', 'Nedeljanec', 46.2877800, 16.2833300, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64777, 'Nedelišće', 'Nedelisce', 'Nedelisce,Nedelišće', 46.3758300, 16.3875000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64778, 'Našice', 'Nasice', 'Naschitz,Nashice,Nasic,Nasice,Nasicz,Nassicze,Našice,Nekcsa,Nekcse,Нашице', 45.4886100, 18.0877800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64779, 'Mursko Središće', 'Mursko Sredisce', 'Muraszerdahely,Mursko Sredisce,Mursko Sredishce,Mursko Sredishhe,Mursko Srediŝĉe,Mursko Središće,Mursko-Sredishche,mu er si ke si lei di shen qie,mwrskw srdyshchh,Мурско Средишће,Мурско Средіще,Мурско-Средишче,مورسکو سردیشچه,مورسکۆ سرێدیشچێ,穆爾斯科斯雷迪什切', 46.5094400, 16.4411100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64780, 'Murter', 'Murter', 'Morter,Murter', 43.8204300, 15.5898800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64781, 'Mrkopalj', 'Mrkopalj', 'Mrkopalj', 45.3155600, 14.8552800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64782, 'Mravince', 'Mravince', 'Mravince', 43.5333300, 16.5219400, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64783, 'Mraclin', 'Mraclin', 'Mraclin', 45.6666700, 16.0955600, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64784, 'Motovun', 'Motovun', 'Mile,Montana,Montona,Motovun,Мотовун', 45.3366700, 13.8286100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64785, 'Mošćenička Draga', 'Moscenicka Draga', 'Draga Santa Marina,Draga Val Santamarina,Moscenicka Draga,Mošćenička Draga,Val Santamarina', 45.2377800, 14.2522200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64786, 'Molve', 'Molve', 'Molve', 46.1091700, 17.0316700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64787, 'Mokošica', 'Mokosica', 'Moccosizza,Mokosica,Mokošica', 42.6755600, 18.0902800, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64788, 'Mirkovci', 'Mirkovci', 'Mirkovci', 45.2697200, 18.8511100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64789, 'Ðulovac', 'Dulovac', 'Djulaves,Dulavec,Dulaves,Dulovac,Miokovicevo,Miokovićevo,Ðulavec,Ðulaves,Ðulovac', 45.6661100, 17.4333300, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64790, 'Milna', 'Milna', 'Milna', 43.3266700, 16.4508300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64791, 'Mikleuš', 'Mikleus', 'Mikleus,Mikleuš,Miklos,Mikloš', 45.6186100, 17.8038900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64792, 'Mihovljan', 'Mihovljan', '', 46.4086100, 16.4480600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64793, 'Mihovljan', 'Mihovljan', 'Mihovlan,Mihovljan', 46.1330600, 15.9722200, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64794, 'Mičevec', 'Micevec', 'Micevec,Mičevec', 45.7500000, 16.0666700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64795, 'Metković', 'Metkovic', 'Metkovic,Metkovich,Metkovicius,Metković,Metkovičius,Portus Narentae,mei te ke wei qi,metokovu~ichi,mtkwych,Меткович,Метковић,متکویچ,مێتکۆڤیچ,メトコヴィチ,梅特科維奇', 43.0541700, 17.6483300, 'HR', '2016-05-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64796, 'Medulin', 'Medulin', 'Medolino,Medulin', 44.8225000, 13.9350000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64797, 'Matulji', 'Matulji', 'Malulji,Mattuglie,Matulge,Matulgi,Matulje,Matulji', 45.3616700, 14.3250000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64798, 'Maruševec', 'Marusevec', 'Marusevac,Marusevec,Maruševac,Maruševec', 46.2888900, 16.1830600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64799, 'Martin', 'Martin', '', 45.4922200, 18.0666700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64800, 'Martijanec', 'Martijanec', 'Martijanec', 46.2658300, 16.5400000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64801, 'Markušica', 'Markusica', 'Markusica,Markušica', 45.3738900, 18.7058300, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64802, 'Markovac Našički', 'Markovac Nasicki', 'Markovac,Markovac Nasicki,Markovac Našički,Nasicki Markovac,Našički Markovac', 45.4938900, 18.1255600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64803, 'Marjanci', 'Marjanci', 'Marijanci,Marjanci', 45.6669400, 18.2922200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64804, 'Marinići', 'Marinici', 'Marinici,Marinići', 45.3650000, 14.3938900, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64805, 'Marina', 'Marina', 'Bossoglina,Marina', 43.5147200, 16.1063900, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64806, 'Marina', 'Marina', '', 43.3500000, 16.4500000, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64807, 'Sveta Marija', 'Sveta Marija', '', 46.3333300, 16.7500000, 'HR', '2017-04-28', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64808, 'Marija Gorica', 'Marija Gorica', 'Marija Gorica', 45.9109700, 15.7277000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64809, 'Marija Bistrica', 'Marija Bistrica', 'Marija Bistrica,Marija-Bistrica,Мария-Бистрица', 46.0061100, 16.1111100, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64810, 'Marčelji', 'Marcelji', 'Marcelji,Marčelji', 45.3961100, 14.3894400, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64811, 'Marčana', 'Marcana', 'Comuna Marcana,Comuna Marčana,Marcana,Marchana,Marzana,Marzana d''Istria,Marzana d’Istria,Marčana,Марчана', 44.9552800, 13.9538900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64812, 'Mali Lošinj', 'Mali Losinj', 'LSZ,Lusinpicolo,Lusinpikolo,Lussinpiccolo,Lussinpíccolo,Lussinum Minus,Mali Loshin'',Mali Losin,Mali Losinj,Mali Lošinj,Mali-Loshin'',maly lshyny,xiao luo xi ni,Łusinpicoło,Мали Лошинь,Мали Лошињ,Мали-Лошинь,Малі-Лошинь,مالی لشینی,مالی لۆشینی,マリ・ロシニ,小洛希尼', 44.5305600, 14.4686100, 'HR', '2016-06-19', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64813, 'Mali Bukovec', 'Mali Bukovec', 'Mali Bukovec', 46.2830600, 16.7391700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64814, 'Mala Subotica', 'Mala Subotica', 'Mala Subotica', 46.3761600, 16.5289300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64815, 'Makarska', 'Makarska', 'Macarsca,Makars''ka,Makarska,Makarska og Podgora,Makarská,Muccurum,ma ka er si ka,makarska,makarusuka,Макарска,Макарська,ماکارسکا,マカルスカ,馬卡爾斯卡', 43.2969400, 17.0177800, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64816, 'Mačkovec', 'Mackovec', 'Mackovec,Mačkovec', 46.4241700, 16.4336100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64817, 'Mače', 'Mace', 'Mace,Mače', 46.0947200, 16.0352800, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64818, 'Lužani', 'Luzani', '', 45.1680600, 17.7069400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64819, 'Lupoglav', 'Lupoglav', 'Lupoblav,Lupoglav,Лупоглав', 45.7963900, 16.3463900, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64820, 'Lumbarda', 'Lumbarda', 'Lumbarda', 42.9227800, 17.1672200, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64821, 'Lukavec', 'Lukavec', 'Gornji Lukavec,Lukanec,Lukavec', 45.7044400, 15.9900000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64822, 'Lukač', 'Lukac', 'Lukac,Lukas,Lukač,Lukaš', 45.8725000, 17.4194400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64823, 'Luka', 'Luka', 'Luka', 45.9579500, 15.8195400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64824, 'Ludbreg', 'Ludbreg', 'Ludbreg,Лудбрег', 46.2519400, 16.6147200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64825, 'Lučko', 'Lucko', 'Lucko,Lučko', 45.7611100, 15.8702800, 'HR', '2012-01-19', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64826, 'Sveti Lovreč Pazenatički', 'Sveti Lovrec Pazenaticki', 'Lovrec,Lovreč,San Lorenzo,San Lorenzo del Pasenatico,Sveti Lovrec,Sveti Lovrec Pazenaticki,Sveti Lovreč,Sveti Lovreč Pazenatički', 45.1758300, 13.7419400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64827, 'Lovreć', 'Lovrec', 'Lovrec,Lovreć', 43.4876100, 16.9863200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64828, 'Lovran', 'Lovran', 'Laurana,Lovran', 45.2919400, 14.2741700, 'HR', '2017-01-05', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64829, 'Lovinac', 'Lovinac', 'Lovinac,Lovinjac', 44.3913900, 15.6855600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64830, 'Lovas', 'Lovas', 'Lovas,Lovasz,Lovász', 45.2263900, 19.1711100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64831, 'Lopatinec', 'Lopatinec', 'Lopatinec', 46.4333300, 16.3833300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64832, 'Lopar', 'Lopar', 'Lopar,Loparo', 44.8325000, 14.7302800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64833, 'Lonjica', 'Lonjica', 'Lojnica,Lonjica', 45.8550000, 16.3300000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64834, 'Lokvičič', 'Lokvicic', '', 43.4634500, 17.0915500, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64835, 'Lokve', 'Lokve', 'Lokve,Loque', 45.3588900, 14.7486100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64836, 'Lobor', 'Lobor', 'Lobor', 46.1527800, 16.0677800, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64837, 'Ljubešćica', 'Ljubescica', 'Ljubescica,Ljubešćica', 46.1666700, 16.3833300, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64838, 'Ližnjan', 'Liznjan', 'Lisignano,Lisignano di Pola,Liznjan,Ližnjan', 44.8283300, 13.9569400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64839, 'Lišane Ostrovičke', 'Lisane Ostrovicke', 'Lisane Ostrovicke,Lišane Ostrovičke,Ostrovicke-Lisane,Ostrovičke-Lišane', 43.9686100, 15.7741700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64840, 'Lipik', 'Lipik', 'Lipik,Lippik,li pi ke,lypyk,ripiku,Липик,Ліпік,لیپیک,リピク,利皮克', 45.4113900, 17.1522200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64841, 'Martinska Ves', 'Martinska Ves', 'Desna Martinska Ves,Lijeva Martinska Ves,Martinska Ves,Martinska Ves Desna,Martinska Ves Lijeva', 45.5836800, 16.3761700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64842, 'Lički Osik', 'Licki Osik', 'Licki Osik,Lički Osik,Teslingrad', 44.6038900, 15.4247200, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64843, 'Levanjska Varoš', 'Levanjska Varos', 'Levacka Varos,Levacka Varoš,Levanjska Varos,Levanjska Varoš', 45.3155600, 18.1836100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64844, 'Lepoglava', 'Lepoglava', 'Lepoglav,Lepoglava,Lepoglov,lai bo ge la wa,lpglawa,Лепоглава,لپگلاوا,لێپۆگلاڤا,萊波格拉瓦', 46.2105600, 16.0355600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64845, 'Lekenik', 'Lekenik', 'Erdetski Lekenik,Lekenik,Turopoljski Lekenik', 45.5855600, 16.2113900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64846, 'Legrad', 'Legrad', 'Legrad', 46.2975000, 16.8566700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64847, 'Lećevica', 'Lecevica', 'Lecevica,Lećevica', 43.6419100, 16.3495400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64848, 'Lastovo', 'Lastovo', 'Lagosta,Lastovo', 42.7680600, 16.9008300, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64849, 'Laslovo', 'Laslovo', 'Laslovo,Laszlofalva,Lászlófalva,Sveti-Ladislav,Szentlaszlo,Szentlászló,Szveti-Ladiszlav', 45.4150000, 18.6961100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64850, 'Lasinja', 'Lasinja', '', 45.5280600, 15.8591100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64851, 'Lanišće', 'Lanisce', 'Comuna Lanisce,Comuna Lanišće,Ianisce,Ianišće,Lanisce,Lanischie,Lanishce,Lanista,Lanišće,Lansice,Lanšiće,lanyshky,Ланишће,لانیشکی', 45.4072200, 14.1163900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64852, 'Ladimirevci', 'Ladimirevci', 'Ladimirevci', 45.6255600, 18.4486100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64853, 'Labin', 'Labin', 'Albona,Albona d''Istria,Albona d’Istria,Labin,la bin,labyn,Лабин,Лабін,لابین,拉賓', 45.0950000, 14.1197200, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64854, 'Kutjevo', 'Kutjevo', 'Goto,Gotó,Kut''evo,Kutevo,Kutjeva,Kutjevo,Kuttyevo,ku te ye wo,kwtyww,Кутьево,Кутєво,Кутјево,کوتیوو,کوتیێڤۆ,庫特耶沃', 45.4261100, 17.8825000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64855, 'Kutina', 'Kutina', 'Kutenya,Kutina,Kuttina,Кутина', 45.4750000, 16.7819400, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64856, 'Kuševac', 'Kusevac', 'Kusevac,Kuševac', 45.3477800, 18.4288900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64857, 'Kuršanec', 'Kursanec', 'Kursanec,Kuršanec', 46.3302800, 16.4016700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64858, 'Kumrovec', 'Kumrovec', 'Kumrovec', 46.0775000, 15.6755600, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64859, 'Kula Norinska', 'Kula Norinska', 'Kula Norinska,Norinska Kula', 43.0311100, 17.6050000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64860, 'Kuče', 'Kuce', 'Kuce,Kuće', 45.6769400, 16.1450000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64861, 'Kućan Marof', 'Kucan Marof', 'Kucan Marof,Kućan Marof', 46.2894400, 16.3722200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64862, 'Kruševo', 'Krusevo', '', 44.1833300, 15.6500000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64863, 'Kruševica', 'Krusevica', '', 45.0775000, 18.4827800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64864, 'Kršan', 'Krsan', 'Chersano,Chersanum,Comuna Krsan,Comuna Kršan,Krsan,Krshan,Kršan,Кршан', 45.1733300, 14.1386100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64865, 'Krnjak', 'Krnjak', 'Comuna Krnjak,Krnak,Krnjak,Крњак', 45.3333300, 15.6000000, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64866, 'Krk', 'Krk', 'Krk,RJK,Veglia,ke er ke,krk,Крк,کرک,克爾克', 45.0274400, 14.5754200, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64867, 'Križevci', 'Krizevci', 'Crisium,Koroes,Koros,Kreutz,Kreuz,Krisevczi,Krizeva,Krizevci,Krizhevci,Krizhevcy,Križeva,Križevci,Körös,Kőrös,ke li re fu qi,keulijebeuchi,Крижевци,Крижевцы,Крижевці,克里熱夫齊,크리제브치', 46.0219400, 16.5425000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64868, 'Križ', 'Kriz', 'Gornji Kriz,Gornji Križ,Kriz,Križ', 45.6650000, 16.5233300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64869, 'Kravarsko', 'Kravarsko', 'Kravarsko', 45.5833300, 16.0500000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64870, 'Krasica', 'Krasica', 'Krasica', 45.3097200, 14.5555600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64871, 'Krašić', 'Krasic', 'Comuna Krasic,Comuna Krašić,Krashic,Krashich,Krasic,Krašić,Крашич,Крашић', 45.6558300, 15.5177800, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64872, 'Krapinske Toplice', 'Krapinske Toplice', 'Krapinske Toplice', 46.0933300, 15.8433300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64873, 'Krapina', 'Krapina', 'Krapina,kurapina,Крапина,クラピナ', 46.1608300, 15.8788900, 'HR', '2012-12-12', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64874, 'Kraljevica', 'Kraljevica', 'Kralevica,Kraljevica,Kraljevjca,Porto Re,ke la lie wei cha,kralywytsa,Кралевица,Кралєвіца,Краљевица,کرالیویتسا,کرالێڤیتسا,克拉列維察', 45.2739500, 14.5683000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64875, 'Kraljevec na Sutli', 'Kraljevec na Sutli', 'Kraljevec,Kraljevec na Sutli', 45.9910600, 15.7247000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64876, 'Kotoriba', 'Kotoriba', 'Kotor,Kotoriba', 46.3550000, 16.8180600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64877, 'Košute', 'Kosute', 'Kosute,Košute', 43.6308300, 16.6950000, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64878, 'Kostrena', 'Kostrena', 'Costrena Santa Lucia,Kostrena,Kostrena Sveta Barbara,Kostrena Sveta Lucija,Santa Lucia Kostrena', 45.3011100, 14.5055600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64879, 'Majur', 'Majur', 'Kostajnicki Majur,Kostajnički Majur,Majur,Majur Kostajnicki,Majur Kostajnički', 45.2550000, 16.5319400, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64880, 'Hrvatska Kostajnica', 'Hrvatska Kostajnica', 'Castanopolis,Hrvatska Kostajnica,Khorvats''ka Kostajnicja,Khrvatska Kostajnica,Khrvatska-Kostajnica,Kostajnica,Kosztainicza,Kosztajnica,ke si ta yi ni cha,khrwatska kstaynytsa,Хорватська Костайниця,Хрватска Костайница,Хрватска Костајница,Хрватска-Костайница,خرواتسکا کستاینیتسا,خرڤاتسکا کۆستاینیتسا,フルヴァツカ・コスタイニツァ,科斯塔伊尼察', 45.2316700, 16.5391700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64881, 'Koška', 'Koska', 'Koska,Koszka,Koška', 45.5452800, 18.2858300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64882, 'Korčula', 'Korcula', 'Curzola,Isola di Curzola,Korchula,Korcula,Korčula,Корчула', 42.9603800, 17.1352500, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64883, 'Koprivnica', 'Koprivnica', 'Caprontza,Copriunisa,Kapronca,Kaproncza,Kopreinitz,Koprivnic,Koprivnica,Koprivnicja,Koprivnicza,Kopriwnitza,ke pu li fu ni cha,kopeulibeunicha,kopurivunitsu~a,kprywnytsa,kwbryfnytsa,Копривница,Копривниця,Копрівніця,كوبريفنيتسا,کپریونیتسا,کۆپریڤنیتسا,კოპრივნიცა,コプリヴニツァ,科普里夫尼察,코프리브니차', 46.1627800, 16.8275000, 'HR', '2015-11-13', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64884, 'Končanica', 'Koncanica', 'Koncanica,Konchanicza,Koncsanica,Končanica', 45.6361100, 17.1663900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64885, 'Komletinci', 'Komletinci', 'Komletinci', 45.1497200, 18.9491700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64886, 'Komiža', 'Komiza', 'Comisa,Komiza,Komizha,Komiža,ke mi zha,kmyzha,komija,Комижа,Коміжа,کمیژا,کۆمیژا,コミジャ,科米扎', 43.0430600, 16.0930600, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64887, 'Komin', 'Komin', 'Komin', 43.0408300, 17.5369400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64888, 'Kolan', 'Kolan', 'Kolan,Kolane', 44.4941700, 14.9613900, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64889, 'Knin', 'Knin', 'Knin,Knini,Tenin,Tininium,ke ning,keunin,knina,knyn,kunin,Книн,Кнін,كنين,کنین,क्निन,クニン,克宁,크닌', 44.0406300, 16.1966200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64890, 'Kneževi Vinogradi', 'Knezevi Vinogradi', 'Knezevi Vinogradi,Kneževi Vinogradi', 45.7502800, 18.7330600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64891, 'Kloštar Podravski', 'Klostar Podravski', 'Klostar,Klostar Podravski,Kloštar,Kloštar Podravski,Kostar,Koštar', 45.9811100, 17.1558300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64892, 'Kloštar Ivanić', 'Klostar Ivanic', 'Klostar Ivanic,Kloštar Ivanić', 45.7405600, 16.4241700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64893, 'Klis', 'Klis', 'Clissa,Klis', 43.5594400, 16.5194400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64894, 'Klinča Sela', 'Klinca Sela', 'Klinca Sela,Klinica Sela,Kliniča Sela,Klinča Sela', 45.6902800, 15.7411100, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64895, 'Klenovnik', 'Klenovnik', 'Klenovnik', 46.2702800, 16.0700000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64896, 'Klanjec', 'Klanjec', 'Klanec,Klanjec,Klanyecz,ke la nie ci,klanyts,Кланец,Кланєц,Клањец,کلانیتس,کلانیێتس,克拉涅茨', 46.0498200, 15.7441800, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64897, 'Klana', 'Klana', 'Clana,Klana', 45.4469400, 14.3769400, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64898, 'Klakar', 'Klakar', 'Klakar', 45.0986100, 18.1322200, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64899, 'Kistanje', 'Kistanje', 'Chistagne,Kistanje', 43.9827800, 15.9650000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64900, 'Kijevo', 'Kijevo', 'Kijevo', 43.9772500, 16.3571000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64901, 'Kerestinec', 'Kerestinec', '', 45.7701000, 15.8086400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64902, 'Kaštel Sućurac', 'Kastel Sucurac', 'Castello Sucurac,Castello Sučurac,Kastel Sucurac,Kaštel Sućurac,Selo Kastel Sucurac,Selo Kaštel Sućurac,Sucurac,Sučurac', 43.5502800, 16.4263900, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64903, 'Kaštel Stari', 'Kastel Stari', 'Castel Vecchio,Kastel Stari,Kaštel Stari,Selo Kastel Stari,Selo Kaštel Stari,Stari', 43.5500000, 16.3500000, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64904, 'Kaštel Štafilić', 'Kastel Stafilic', 'Castel-Stafileo,Caštel-Štafileo,Kastel Stafilic,Kaštel Štafilić,Stafilic,Štafilić', 43.5500000, 16.3333300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64905, 'Kaštel Novi', 'Kastel Novi', 'Kastel Novi,Kaštel Novi,Novi,Selo Kastel Novi,Selo Kaštel Novi', 43.5500000, 16.3333300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64906, 'Kaštel Lukšić', 'Kastel Luksic', 'Kastel Luksic,Kaštel Luksić,Kaštel Lukšić,Luksic,Lukšić,Selo Kastel Luksic,Selo Kaštel Lukšić', 43.5552800, 16.3675000, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64907, 'Kaštel Kambelovac', 'Kastel Kambelovac', 'Kambelovac,Kastel Kambelovac,Kastel Kamblelovac,Kaštel Kambelovac,Kaštel Kamblelovac,Selo Kastel Kambelovac,Selo Kaštel Kambelovac', 43.5500000, 16.3833300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64908, 'Kaštelir', 'Kastelir', 'Castellier,Castellier di Visinada,Kastelir,Kaštelir', 45.3033300, 13.6852800, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64909, 'Kaštel Gomilica', 'Kastel Gomilica', 'Gomilica,Kastel Gomilica,Kaštel Gomilica', 43.5500000, 16.4000000, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64910, 'Kastav', 'Kastav', 'Castua,Kastav,ka si ta fu,kastav,kastaw,kasutavu,Кастав,کاستاو,کاستاڤ,カスタヴ,卡斯塔夫', 45.3752800, 14.3486100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64911, 'Kašina', 'Kasina', 'Gornja Kasina,Gornja Kašina,Kasina,Kašina', 45.9113400, 16.1243600, 'HR', '2016-07-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64912, 'Karojba', 'Karojba', 'Caroiba,Caroiba Subiente,Caroibo,Karojba', 45.3008300, 13.8230600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64913, 'Karlovac', 'Karlovac', 'Karlovac,Karlstadt,Karolyvaros,Karolyváros,Károlyváros,Карловац', 45.4872200, 15.5477800, 'HR', '2015-07-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64914, 'Karlobag', 'Karlobag', 'Bag,Carlopago,Karlobag,Karlopago,Карлобаг', 44.5275000, 15.0738900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64915, 'Karanac', 'Karanac', 'Karanac', 45.7605600, 18.6844400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64916, 'Kaptol', 'Kaptol', 'Kaptol,Pozsega-Szentpeter,Pozsega-Szentpéter', 45.4347200, 17.7261100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64917, 'Kapela', 'Kapela', 'Kapela', 45.9883300, 16.8513900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64918, 'Kanfanar', 'Kanfanar', 'Canfanarium,Canfanaro,Comuna Kanfanar,Kanfanar,Канфанар', 45.1219400, 13.8391700, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64919, 'Kamanje', 'Kamanje', 'Kamanje', 45.6352800, 15.3958300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64920, 'Kalnik', 'Kalnik', 'Kalnik', 46.1283300, 16.4625000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64921, 'Kalinovac', 'Kalinovac', 'Kalinovac', 46.0294400, 17.1155600, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64922, 'Kali', 'Kali', 'Kali', 44.0627800, 15.2055600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64923, 'Josipovac', 'Josipovac', 'Josipovac', 45.5827800, 18.5813900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64924, 'Josipdol', 'Josipdol', 'Josipdol', 45.1850000, 15.2866700, 'HR', '2016-05-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64925, 'Ježdovec', 'Jezdovec', 'Jezdovec,Ježdovec', 45.7833300, 15.8500000, 'HR', '2014-04-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64926, 'Jesenice', 'Jesenice', 'Jasenica,Jasenice,Jesenice', 44.2300000, 15.5775000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64927, 'Jesenice', 'Jesenice', '', 43.4615800, 16.6019700, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64928, 'Jelsa', 'Jelsa', 'Comuna Jelsa,Elsa,Gelsa,Ielsa,Jelsa,Єлса,Јелса', 43.1613900, 16.6930600, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64929, 'Jelisavac', 'Jelisavac', 'Jelisavac,Jelisavec', 45.5288900, 18.1561100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64930, 'Jelenje', 'Jelenje', 'Gellegne,Jelenje', 45.3861100, 14.4511100, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64931, 'Jastrebarsko', 'Jastrebarsko', 'Jaska,Jastrebarcko,Jastrebarsko,Jasztrebarszka,Jazka,Jazterbarzka,Jaztravicz,jstrbrskw,ya si te lei ba si ke,yastrbarskw,Јастребарско,Ястребарско,جستربرسکو,یاستربارسکو,یاسترێبارسکۆ,亞斯特雷巴斯科', 45.6683300, 15.6486100, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64932, 'Jasenovac', 'Jasenovac', 'Comuna Jasenovac,Jasenoc,Jasenovac,Jasenóc,Jaszenovacz,Jeszenovacz,ya sai nuo wa ci,yasenovu~atsu,Јасеновац,Ясеновац,جسنوواک، سسک-موسلونا کاؤنٹی,ヤセノヴァツ,亚塞诺瓦茨', 45.2716700, 16.9116700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64933, 'Jarmina', 'Jarmina', 'Jarmina', 45.3180600, 18.7291700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64934, 'Janjina', 'Janjina', 'Janjina', 42.9252800, 17.4283300, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64935, 'Jalžabet', 'Jalzabet', 'Jalzabet,Jalžabet', 46.2608300, 16.4750000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64936, 'Jalkovec', 'Jalkovec', 'Jalkovec', 46.2808300, 16.3197200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64937, 'Jakšić', 'Jaksic', 'Jaksic,Jakšić', 45.3580600, 17.7638900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64938, 'Jakovlje', 'Jakovlje', 'Jakovje,Jakovlje', 45.9361100, 15.8555900, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64939, 'Jagodnjak', 'Jagodnjak', 'Jagodnja,Jagodnjak', 45.6991700, 18.5769400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64940, 'Jadranovo', 'Jadranovo', 'Diminici,Diminići,Jadranovo,Klostar Siljevicki,Kloštar Šiljevički,Percin,Perčin,Sveti Jakob,Sveti Jakov,Sveti Jakov Siljevica,Sveti Jakov Šiljevica', 45.2311100, 14.6183300, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64941, 'Jablanovec', 'Jablanovec', 'Jablanovec', 45.8758300, 15.8536100, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64942, 'Ivanska', 'Ivanska', 'Ivanska', 45.7788900, 16.8119400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64943, 'Ivanovec', 'Ivanovec', 'Ivanovec', 46.3683300, 16.4766700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64944, 'Ivankovo', 'Ivankovo', 'Ivanka,Ivanka-Szent-Gyorgy,Ivankova,Ivankovo,Ivánka,Ivánka-Szent-György,Iwankowo', 45.2886100, 18.6838900, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64945, 'Ivanić-Grad', 'Ivanic-Grad', 'Ivanic,Ivanic Grad,Ivanic Tvrdjava,Ivanic Var,Ivanic Vár,Ivanic-Grad,Ivanic-grad,Ivanich,Ivanich-Festung,Ivanich-Grad,Ivanics,Ivanić,Ivanić Grad,Ivanić-Grad,Ivanić-grad,Ivanič Tvrdjava,aywanych-grad,yi wan ni qi ge lei,yyvanych-grad,Іванич-Град,Иванич-Град,Иванић-Град,ئیڤانیچ-گراد,ایوانیچ-گراد,伊萬尼奇格勒', 45.7083300, 16.3969400, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64946, 'Ivanec', 'Ivanec', 'Ivanci,Ivanec,Ivanec'',Ivanecz,aywants,yi wan nei ci,Іванець,Иванец,ئیڤانێتس,ایوانتس,伊萬內茨', 46.2230600, 16.1200000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64947, 'Imotski', 'Imotski', 'Emotha,Imoschi,Imots''kij,Imotski,aymtsky,aymwtsky,imotsuki,yi mo ci ji,Імотський,Имотски,إيموتسكي,ئیمۆتسکی,ایمتسکی,イモツキ,伊莫茨基', 43.4466700, 17.2166700, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64948, 'Ilok', 'Ilok', 'Ilok,Ujlak,aylk,iroku,yi luo ke,Újlak,Ілок,Илок,אילוק,ئیلۆک,ایلک,イロク,伊洛克', 45.2222200, 19.3769400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64949, 'Hvar', 'Hvar', 'Hvar,Lesina', 43.1725000, 16.4427800, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64950, 'Hum na Sutli', 'Hum na Sutli', 'Hum,Hum na Sutli', 46.2113900, 15.6908300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64951, 'Breznički Hum', 'Breznicki Hum', 'Breznicki Hum,Breznički Hum,Hum,Hum Breznicki,Hum Breznički', 46.1072200, 16.2766700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64952, 'Hrvace', 'Hrvace', 'Hrvace,Hrvatce,Hrvatice', 43.7633300, 16.6150000, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64953, 'Hreljin', 'Hreljin', 'Hreljin', 45.2825000, 14.5991700, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64954, 'Hrašćina', 'Hrascina', 'Hrascina,Hrašćina', 46.1125000, 16.2275000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64955, 'Horvati', 'Horvati', '', 45.7000000, 15.8166700, 'HR', '2006-01-17', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64956, 'Hodošan', 'Hodosan', 'Hodosan,Hodošan', 46.3952800, 16.6438900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64957, 'Hlebine', 'Hlebine', 'Hlebine', 46.1569400, 16.9627800, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64958, 'Hercegovac', 'Hercegovac', 'Hercegovac', 45.6586100, 17.0136100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64959, 'Gunja', 'Gunja', 'Gunja', 44.8800000, 18.8533300, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64960, 'Gundinci', 'Gundinci', 'Gundinci', 45.1583300, 18.4913900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64961, 'Gudovac', 'Gudovac', 'Gudovac', 45.8802800, 16.7808300, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64962, 'Grubišno Polje', 'Grubisno Polje', 'Grubishno Pole,Grubishno-Pole,Grubisnopolye,ge lu bi shen nuo bo lie,grwbyshnw plyh,Грубишно Поље,Грубишно-Поле,Грубішно-Полє,گروبیشنو پلیه,گروبیشنۆ پۆلێ,格魯比什諾波列', 45.7021400, 17.1726800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64963, 'Grožnjan', 'Groznjan', 'Grisignana,Grozhnjan,Groznjan,Grožnjan,Грожнян', 45.3788900, 13.7238900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64964, 'Grohote', 'Grohote', 'Grhhote,Grohote', 43.3916700, 16.2872200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64965, 'Gradište', 'Gradiste', 'Gradiste,Gradište', 45.1480600, 18.7066700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64966, 'Gradići', 'Gradici', 'Gradici,Gradići', 45.7000000, 16.0500000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64967, 'Gradec', 'Gradec', 'Comuna Gradec,Gradec,Gradec kod Krizevaca,Gradec kod Križevaca,Gradeci,Градец', 45.9111100, 16.4827800, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64968, 'Gradac', 'Gradac', 'Gradac', 43.1058300, 17.3416700, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64969, 'Gračišće', 'Gracisce', 'Gallignana,Gracisce,Gračišće', 45.2188900, 14.0105600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64970, 'Gračec', 'Gracec', '', 45.8333300, 16.3166700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64971, 'Gračac', 'Gracac', 'Gracac,Gračac', 44.2991600, 15.8475200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64972, 'Gospić', 'Gospic', 'Gosnidj,Gospic,Gospich,Gospicius,Gospitsum,Gospić,Gospičius,ge si pi qi,ghwsbytsh,goseupichi,gosupitchi,gspych,gwspych,Госпич,Госпић,غوسبيتش,گسپیچ,گوسپیچ,گۆسپیچ,გოსპიჩი,ゴスピッチ,戈斯皮奇,고스피치', 44.5461100, 15.3747200, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64973, 'Okrug Gornji', 'Okrug Gornji', 'Gornji Okrug,Okrug,Okrug Gornji', 43.4947300, 16.2653100, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64974, 'Gornji Mihaljevec', 'Gornji Mihaljevec', 'Gornji Mihaljevec', 46.4286400, 16.3332800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64975, 'Gornji Kneginec', 'Gornji Kneginec', 'Gornji Kneginec,Kneginec Gornji', 46.2505100, 16.3755500, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64976, 'Gornji Karin', 'Gornji Karin', 'Donji Karin,Gornji Karin,Karin', 44.1359800, 15.6342300, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64977, 'Gornji Bogičevci', 'Gornji Bogicevci', 'Bogicevci Gornji,Bogićevci Gornji,Gornji Bogicevci,Gornji Bogičevci', 45.2594400, 17.2361100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64978, 'Gornje Vratno', 'Gornje Vratno', 'Gornje Vratno,Vratno', 46.3591700, 16.1544400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64979, 'Podbablje', 'Podbablje', 'Gornje Podbablje,Gornje Podbalje,Podbablje,Podbablje Gornje', 43.3931400, 17.1795300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64980, 'Gornje Jesenje', 'Gornje Jesenje', '', 46.2063900, 15.9125000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64981, 'Gornja Vrba', 'Gornja Vrba', 'Gornja Vrba,Vrba Gornja', 45.1552800, 18.0655600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64982, 'Gornja Stubica', 'Gornja Stubica', 'Comuna Gornja Stubica,Gorna Stubica,Gornja Stubica,Gornja Stubicja,Gornja-Stubica,Stubica-Gornja,Горня Стубиця,Горня-Стубица,Горња Стубица', 45.9751900, 16.0193100, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64983, 'Gornja Bistra', 'Gornja Bistra', 'Bistra Gornja,Gornja Bistra', 45.9166700, 15.9000000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64984, 'Gorjani', 'Gorjani', 'Gara,Gorjan,Gorjani', 45.3988900, 18.3722200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64985, 'Goričan', 'Gorican', 'Gorican,Goričan,Muracsany,Muracsány', 46.3841700, 16.6808300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64986, 'Gola', 'Gola', 'Gola', 46.1958300, 17.0580600, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64987, 'Glina', 'Glina', 'Banijska Palanka,Glina,ge li na,glyna,Глина,Ґліна,گلینا,格利納', 45.3380600, 16.0880600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64988, 'Generalski Stol', 'Generalski Stol', 'Comuna Generalski Stol,Generalski Stol,Генералски Стол', 45.3477800, 15.3830600, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64278, 'La Jutosa', 'La Jutosa', 'Jutosa,La Jutosa', 15.6333300, -88.0000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64279, 'La Huesa', 'La Huesa', 'La Bueso,La Huesa', 15.5833300, -87.8833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64280, 'Laguna Verde', 'Laguna Verde', '', 15.2000000, -88.1666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64281, 'Laguna Seca', 'Laguna Seca', '', 14.7000000, -86.1000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64282, 'La Guata', 'La Guata', 'Guata,La Guata', 15.0833300, -86.3833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64283, 'La Guama', 'La Guama', '', 14.8833300, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64284, 'La Guacamaya', 'La Guacamaya', '', 15.2500000, -87.8000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64285, 'La Flecha', 'La Flecha', '', 15.2833300, -88.4833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64286, 'La Estancia', 'La Estancia', '', 15.2833300, -87.5500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64287, 'La Estancia', 'La Estancia', 'Estancia,La Estancia', 15.0500000, -86.3500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64288, 'La Esperanza', 'La Esperanza', 'La Esperanz,La Esperanza', 15.6333300, -85.7666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64289, 'La Esperanza', 'La Esperanza', 'La Esperanza,Nueva Esperanza', 14.3111100, -88.1805600, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64290, 'La Ermita', 'La Ermita', 'Ermita,Hermita,La Ermita', 14.4666700, -87.0666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64291, 'La Entrada', 'La Entrada', 'La Entrada', 15.0500000, -88.7333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64292, 'La Encarnación', 'La Encarnacion', 'La Encarnacion,La Encarnación,La Ercarnacion,La Ercarnación', 14.6666700, -89.0833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64293, 'La Criba', 'La Criba', '', 13.4536100, -87.4133300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64294, 'La Concepción', 'La Concepcion', '', 14.7000000, -86.2333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64295, 'La Ceiba', 'La Ceiba', 'Ceiba,LCE,La Ceiba,La Seiba,La Sejba,La-Sejba,la sai wa,Ла Сейба,Ла-Сейба,ラ・セイバ,拉塞瓦', 15.7597100, -86.7822100, 'HN', '2014-08-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64296, 'La Brea', 'La Brea', '', 15.8000000, -85.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64297, 'Jutiquile', 'Jutiquile', '', 14.7166700, -86.0833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64298, 'Juticalpa', 'Juticalpa', 'Juticalpa', 14.6666700, -86.2194400, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64299, 'Jutiapa', 'Jutiapa', '', 15.7666700, -86.5166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64300, 'Jutiapa', 'Jutiapa', '', 13.9833300, -86.4000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64301, 'Joconal', 'Joconal', 'Goconal,Jaconal,Joconal,Joconales', 15.3544400, -88.6355600, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64302, 'Jocón', 'Jocon', 'El Jocon,Jocon,Jocón', 15.2833300, -86.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64303, 'Jiquinlaca', 'Jiquinlaca', 'Jiquinlaca,Jiquinlace', 14.0000000, -88.3500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64304, 'Jícaro Galán', 'Jicaro Galan', '', 13.5316700, -87.4388900, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64305, 'Jesús de Otoro', 'Jesus de Otoro', 'Jesus de Otoro,Jesús de Otoro', 14.4833300, -87.9833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64306, 'Jericó', 'Jerico', '', 15.9500000, -85.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64307, 'Jamalteca', 'Jamalteca', '', 14.7000000, -87.5833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64308, 'Jacaleapa', 'Jacaleapa', 'Jacaleapa', 14.0166700, -86.6666700, 'HN', '2014-04-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64309, 'Iralaya', 'Iralaya', 'Ilaya,Iralaya,Irlaya', 15.0000000, -83.2333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64310, 'Intibucá', 'Intibuca', '', 14.3166700, -88.1666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64311, 'Ilama', 'Ilama', 'Ilama', 15.0666700, -88.2166700, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64312, 'Güinope', 'Guinope', 'Guinope,Güinope', 13.8833300, -86.9333300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64313, 'Guayape', 'Guayape', 'El Guayabo,Guayape', 14.7166700, -86.8333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64314, 'Guarizama', 'Guarizama', 'Guarizama', 14.9166700, -86.3333300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64315, 'Guanaja', 'Guanaja', 'GJA,Guanaja', 16.4000000, -85.9000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64316, 'Gualjoco', 'Gualjoco', 'Gualjaco,Gualjoco', 14.9500000, -88.2333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64317, 'Gualaco', 'Gualaco', 'GUO,Gualaco', 15.0252100, -86.0707600, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64318, 'Guaimitas', 'Guaimitas', 'Guaimitas,Guaymitas', 15.5000000, -87.7166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64319, 'Guaimaca', 'Guaimaca', 'Guaimaca', 14.5333300, -86.8166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64320, 'Guacamaya', 'Guacamaya', 'Guacamaya,Guacamayas', 15.0166700, -88.1500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64321, 'Gracias', 'Gracias', 'GAC,Gracias,Grasias,Grasjasas,ge la xi ya si,geulasiaseu,grasyas,Грасіас,گراسیاس,格拉西亞斯,그라시아스', 14.5902800, -88.5819400, 'HN', '2013-01-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64322, 'Goascorán', 'Goascoran', 'Goascoran,Goascorán,Guas-Coran', 13.5833300, -87.6166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64323, 'French Harbor', 'French Harbor', 'French Harbor,French Harbour', 16.3500000, -86.4333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64324, 'Francia', 'Francia', '', 15.8500000, -85.5833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64325, 'Florida', 'Florida', 'Florida', 15.0333300, -88.8333300, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64326, 'Flores', 'Flores', '', 14.2833300, -87.5666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64327, 'Esquías', 'Esquias', 'Esquias,Esquías', 14.7333300, -87.3666700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64328, 'Erandique', 'Erandique', 'EDQ,Erandique', 14.2333300, -88.4666700, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64329, 'El Zapotal del Norte', 'El Zapotal del Norte', 'El Zapotal,El Zapotal del Norte,Zapotal del Norte', 15.5166700, -88.0500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64330, 'El Tular', 'El Tular', '', 13.4663900, -87.5152800, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64331, 'El Triunfo de la Cruz', 'El Triunfo de la Cruz', 'El Triunfo,El Triunfo de la Cruz,Triunfo,Triunfo de la Cruz', 15.7666700, -87.4333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64332, 'El Triunfo', 'El Triunfo', 'El Triunfo,Triunfo', 13.1166700, -87.0000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64333, 'El Tránsito', 'El Transito', '', 14.3833300, -88.9166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64334, 'El Tigre', 'El Tigre', 'El Tigre,Tigre', 14.9333300, -87.9833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64335, 'El Terrero', 'El Terrero', '', 14.0666700, -87.0666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64336, 'El Tablón', 'El Tablon', 'El Tablon,El Tablón,Tablon', 14.0333300, -87.1666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64337, 'El Suyatal', 'El Suyatal', 'El Suyatal,Suyatal,Zuyatal', 14.5166700, -87.2166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64338, 'El Socorro', 'El Socorro', 'El Socorro,Socorro', 14.6333300, -87.9166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64339, 'El Sauce', 'El Sauce', 'El Sauce,Sauce', 14.5285000, -87.6657100, 'HN', '2014-07-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64340, 'El Rusio', 'El Rusio', '', 14.4666700, -86.3666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64341, 'El Rosario', 'El Rosario', '', 14.8000000, -87.7666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64342, 'El Rincón', 'El Rincon', '', 14.5833300, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64343, 'El Rancho', 'El Rancho', '', 15.6666700, -87.9500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64344, 'El Rancho', 'El Rancho', 'El Rancho,Rancho Grande', 14.6833300, -87.5000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64345, 'El Puente', 'El Puente', '', 13.2833300, -87.1166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64346, 'El Progreso', 'El Progreso', 'Ehl''-Progreso,El Progreso,El Progress,Progreso,Эль-Прогресо', 15.4000000, -87.8000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64347, 'El Porvenir', 'El Porvenir', '', 15.8333300, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64348, 'El Porvenir', 'El Porvenir', 'El Porvenir,Porvenir', 15.7500000, -86.9333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64349, 'El Porvenir', 'El Porvenir', '', 14.5833300, -87.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64350, 'El Porvenir', 'El Porvenir', '', 13.7616700, -87.3458300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64351, 'El Plan', 'El Plan', '', 15.2833300, -87.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64352, 'El Pino', 'El Pino', '', 15.7000000, -86.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64353, 'El Perico', 'El Perico', '', 15.0833300, -88.1000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64354, 'El Pedernal', 'El Pedernal', '', 14.7000000, -87.1166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64355, 'El Paraíso', 'El Paraiso', 'El Paraiso,El Paraíso', 13.8666700, -86.5500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64356, 'El Olivar', 'El Olivar', '', 15.0833300, -87.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64357, 'El Ocotón', 'El Ocoton', 'El Ocoton,El Ocotón,Ocoton,Ocotona,Ocotón', 15.0333300, -88.8833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64358, 'El Ocote', 'El Ocote', '', 15.4166700, -86.5666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64359, 'El Obraje', 'El Obraje', 'El Obraje,Obraje', 14.0000000, -86.4333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64360, 'El Obraje', 'El Obraje', '', 13.1541700, -87.1308300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64361, 'El Níspero', 'El Nispero', 'El Nispero,El Níspero,Nispero', 14.7666700, -88.3333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64362, 'El Negrito', 'El Negrito', 'El Negrito,Negrito', 15.3166700, -87.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64363, 'El Mochito', 'El Mochito', 'El Mochito,El Nochito,Mochito', 14.8666700, -88.0833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64364, 'El Milagro', 'El Milagro', '', 15.4000000, -87.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64365, 'El Marañón', 'El Maranon', 'El Maranon,El Marañón,Maranon,Marañón', 15.4000000, -88.0500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64366, 'El Lolo', 'El Lolo', '', 14.1166700, -87.2666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64367, 'El Llano', 'El Llano', '', 15.1500000, -87.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64368, 'El Juncal', 'El Juncal', 'El Juncal,Juncal', 15.4500000, -86.4333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64369, 'Elíxir', 'Elixir', '', 15.4833300, -86.3000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64370, 'El Guayabito', 'El Guayabito', '', 14.8333300, -86.0333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64371, 'El Guapinol', 'El Guapinol', '', 13.7666700, -87.4666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64372, 'El Guantillo', 'El Guantillo', 'El Guantillo,Guantillo', 14.6000000, -87.3000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64373, 'El Guante', 'El Guante', 'El Guante,Guante', 14.5500000, -87.1000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64374, 'El Escaño de Tepale', 'El Escano de Tepale', 'El Escano,El Escano de Tepale,El Escaño de Tepale,Escano de Tepale,Escano de Tepales', 14.7500000, -87.0666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64375, 'El Escanito', 'El Escanito', 'El Escanito,Escanito', 14.6666700, -87.1000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64376, 'El Cubolero', 'El Cubolero', 'El Cubolero,El Cubulero', 13.4666700, -87.6666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64377, 'El Corpus', 'El Corpus', '', 14.7000000, -88.9166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64378, 'Corpus', 'Corpus', 'Corpus,El Corpus', 13.2888900, -87.0347200, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64379, 'El Corozal', 'El Corozal', '', 15.0666700, -88.6166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64380, 'El Ciruelo', 'El Ciruelo', 'Ciruelo,El Ciruelo', 15.3000000, -88.5000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64381, 'El Chimbo', 'El Chimbo', 'Chimbo,El Chimbo', 14.1333300, -87.1166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64382, 'El Chichicaste', 'El Chichicaste', 'Chichicaste,El Chichicaste,El Chichiquiste', 14.0666700, -86.3000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64383, 'El Benque', 'El Benque', '', 14.0333300, -86.4666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64384, 'El Bálsamo', 'El Balsamo', 'Balsamo,Bálsamo,El Balsamo,El Bálsamo', 15.0666700, -87.4666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64385, 'El Agua Dulcita', 'El Agua Dulcita', 'Agua Dulcita,El Agua Dulcita', 14.7000000, -87.7500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64386, 'El Achiotal', 'El Achiotal', 'Achiotal,El Achiotal,El Achotal', 14.0833300, -88.7500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64387, 'Duyure', 'Duyure', 'Duyure', 13.6333300, -86.8166700, 'HN', '2012-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64388, 'Dulce Nombre de Culmí', 'Dulce Nombre de Culmi', 'Culmi,Culmí,Ducle Nombre,Dulce Nombre,Dulce Nombre Culmi,Dulce Nombre Culmí,Dulce Nombre de Culmi,Dulce Nombre de Culmí,El Dulce Nombre', 15.1000000, -85.5333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64389, 'Dulce Nombre', 'Dulce Nombre', '', 14.8500000, -88.8333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64390, 'Dolores', 'Dolores', 'Dolores', 14.8666700, -88.8333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64391, 'Danlí', 'Danli', 'Danli,Danlí', 14.0333300, -86.5833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64392, 'Cuyamel', 'Cuyamel', 'Cuaymel,Cuyamel', 15.6666700, -88.2000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64393, 'Cuyalí', 'Cuyali', '', 13.8833300, -86.5500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64394, 'Cusuna', 'Cusuna', 'Casuna,Cusuma,Cusuna', 15.8500000, -85.2333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64395, 'Cucuyagua', 'Cucuyagua', 'Cucuyagua', 14.6500000, -88.8666700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64396, 'Coyoles Central', 'Coyoles Central', '', 15.4000000, -86.6666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64397, 'Correderos', 'Correderos', 'Corredero,Correderos,San Miguel Correderos', 15.4166700, -88.4500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64398, 'Corquín', 'Corquin', 'Corguin,Corquin,Corquín', 14.5666700, -88.8666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64399, 'Corozal', 'Corozal', '', 15.8000000, -86.7166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64400, 'Corocito', 'Corocito', 'Corocilo,Corocito', 15.7500000, -85.7833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64401, 'Copán', 'Copan', 'Copan,Copán,Kopan,RUY,Копан', 14.8333300, -89.1500000, 'HN', '2013-12-15', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64402, 'Concordia', 'Concordia', 'Concordia', 14.6166700, -86.6500000, 'HN', '2013-04-04', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64403, 'Concepción del Sur', 'Concepcion del Sur', 'Concepcion,Concepcion Sur,Concepcion del Sur,Concepción Sur,Concepción del Sur', 14.8000000, -88.1666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64404, 'Concepción de la Barranca', 'Concepcion de la Barranca', 'Concepcion Barrancas,Concepcion de la Barranca,Concepción Barrancas,Concepción de la Barranca', 15.1666700, -88.7166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64405, 'Concepción de Guasistagua', 'Concepcion de Guasistagua', 'Concepcion de Guasistagua,Concepción de Guasistagua,Guasistagua,Guyasistagua', 14.6000000, -87.6500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64406, 'Comayagua', 'Comayagua', 'Comayagua,XPL', 14.4513900, -87.6375000, 'HN', '2013-10-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64407, 'Cololaca', 'Cololaca', '', 14.3000000, -88.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64408, 'Cofradía', 'Cofradia', 'Cofradia,Cofradía', 15.4000000, -88.1500000, 'HN', '2016-03-10', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64409, 'Cofradía', 'Cofradia', '', 14.2166700, -87.1833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64410, 'Chotepe', 'Chotepe', '', 15.4166700, -87.9833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64411, 'Ciudad Choluteca', 'Ciudad Choluteca', 'Chollolteca,Choluteca,Ciudad Choluteca', 13.3002800, -87.1908300, 'HN', '2012-01-16', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64412, 'Choloma', 'Choloma', '', 15.6144400, -87.9530200, 'HN', '2007-02-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64413, 'Chivana', 'Chivana', '', 15.7500000, -87.9833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64414, 'Chalmeca', 'Chalmeca', '', 15.1000000, -88.6833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64415, 'Cerro Grande', 'Cerro Grande', '', 13.8166700, -87.2500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64416, 'Cerro Blanco', 'Cerro Blanco', '', 14.6666700, -87.7833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64417, 'Ceguaca', 'Ceguaca', 'Ceguaca', 14.8000000, -88.2000000, 'HN', '2014-04-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64418, 'Cedros', 'Cedros', 'Cedros,Cerros', 14.6000000, -87.1166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64419, 'Casa Quemada', 'Casa Quemada', '', 15.2666700, -88.5500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64420, 'Casa Quemada', 'Casa Quemada', '', 15.1166700, -88.0833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64421, 'Carbajales', 'Carbajales', '', 15.5166700, -86.3500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64422, 'Cane', 'Cane', 'Cane', 14.2833300, -87.6666700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64423, 'Cañaveral', 'Canaveral', 'Canaveral,Canaverales,Cañaveral,Cañaverales', 14.9833300, -88.0166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64424, 'Campamento', 'Campamento', 'Campamento', 14.5500000, -86.6500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64425, 'Camasca', 'Camasca', 'Camasca,Villa de Camasca', 14.0000000, -88.3833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64426, 'Camalote', 'Camalote', '', 15.3333300, -88.3333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64427, 'Callejones', 'Callejones', 'Callejones,Collejones', 15.1666700, -88.6500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64428, 'Buenos Aires', 'Buenos Aires', '', 15.0333300, -88.9666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64429, 'Brus Laguna', 'Brus Laguna', 'BHG,Brewers,Brewers Lagoon,Brus Laguna', 15.7500000, -84.4833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64430, 'Bonito Oriental', 'Bonito Oriental', '', 15.7476500, -85.7355900, 'HN', '2011-11-08', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64431, 'Berlín', 'Berlin', '', 14.8333300, -88.5000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64432, 'Belén Gualcho', 'Belen Gualcho', 'Belen,Belen Gualcho,Belén Gualcho,Gualcho', 14.4833300, -88.8000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64433, 'Bejuco', 'Bejuco', '', 15.1333300, -87.9333300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64434, 'Barra Patuca', 'Barra Patuca', 'Barra Patuca,Barra del Patuca,Butucamaya,Butukamaya,Patuca', 15.8000000, -84.2833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64435, 'Baracoa', 'Baracoa', '', 15.7666700, -87.8500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64436, 'Bálsamo Oriental', 'Balsamo Oriental', 'Balsamo,Balsamo Oriental,Bálsamo Oriental', 15.4833300, -86.3333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64437, 'Baja Mar', 'Baja Mar', '', 15.8833300, -87.8500000, 'HN', '2006-01-27', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64438, 'Azacualpa', 'Azacualpa', '', 15.3433300, -88.5513900, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64439, 'Azacualpa', 'Azacualpa', 'Azacualpa', 14.7166700, -88.1000000, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64440, 'Ayapa', 'Ayapa', '', 15.1117400, -87.1755700, 'HN', '2015-08-03', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64441, 'Auka', 'Auka', 'Auca,Auka', 14.9408700, -83.8322900, 'HN', '2017-02-02', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64442, 'Auas', 'Auas', 'Ahuas,Ahuás,Auas,Awas,Butukawas', 15.4833300, -84.3333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64443, 'Atima', 'Atima', 'Atima', 14.9333300, -88.4833300, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64444, 'Atenas de San Cristóbal', 'Atenas de San Cristobal', 'Atenas de San Cristobal,Atenas de San Cristóbal,Kilometro 17,Kilómetro 17', 15.6833300, -87.3166700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64445, 'Armenta', 'Armenta', '', 15.5000000, -88.0500000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64446, 'Armenia', 'Armenia', '', 15.4666700, -86.3666700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64447, 'Arizona', 'Arizona', 'Arizona', 15.6333300, -87.3166700, 'HN', '2012-05-06', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64448, 'Arimís', 'Arimis', '', 14.7833300, -86.0000000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64449, 'Arenal', 'Arenal', 'Arenal,El Arenal', 15.3500000, -86.8333300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64450, 'Araulí', 'Arauli', 'Arauli,Araulí,Aurali', 13.9500000, -86.5500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64451, 'Aramecina', 'Aramecina', 'Aramecina', 13.7422200, -87.7102800, 'HN', '2012-08-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64452, 'Arada', 'Arada', 'Arada,La Arada', 14.8500000, -88.3000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64453, 'Antigua Ocotepeque', 'Antigua Ocotepeque', 'Antigua Ocotepeque,Vieja Ocotepeque', 14.4000000, -89.2000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64454, 'Amapala', 'Amapala', 'Amapala', 13.2922200, -87.6538900, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64455, 'La Alianza', 'La Alianza', 'Alianza,La Alianza', 13.5122200, -87.7244400, 'HN', '2013-05-05', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64456, 'Ajuterique', 'Ajuterique', 'Ajuterique', 14.3833300, -87.7000000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64457, 'Aguas del Padre', 'Aguas del Padre', '', 14.5666700, -87.8833300, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64458, 'Agualote', 'Agualote', '', 15.3352800, -88.5530600, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64459, 'Agua Fría', 'Agua Fria', '', 13.4688900, -87.5511100, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64460, 'Agua Caliente', 'Agua Caliente', '', 14.8833300, -88.8166700, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64461, 'Agua Blanca Sur', 'Agua Blanca Sur', 'Agua Blanca,Agua Blanca Sur,Agua Blanca del Sur', 15.2500000, -87.8833300, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64462, 'Agua Azul Rancho', 'Agua Azul Rancho', 'Agua Azul,Agua Azul Rancho,Granja', 14.9000000, -87.9500000, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64463, 'Agua Azul', 'Agua Azul', 'Agua Azul,Agua Azul Sierra,Aserradero', 14.9166700, -87.9666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64464, 'Agalteca', 'Agalteca', 'Agalteca,Ingenio Agalteca', 14.4500000, -87.2666700, 'HN', '2012-01-18', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64465, 'Texíguat', 'Texiguat', '', 13.6497200, -87.0225000, 'HN', '2006-01-17', 99);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64989, 'Garešnica', 'Garesnica', 'Gareshnica,Gareshnicja,Gareshnitsa,Garesnica,Garesnicza,Garešnica,gareshunitsu~a,garshnytsa,jia lei shen ni cha,Гарешница,Гарешниця,گارشنیتسا,گارێشنیتسا,ガレシュニツァ,加雷什尼察', 45.5744400, 16.9413900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64990, 'Garčin', 'Garcin', 'Garcin,Garčin', 45.1827800, 18.1830600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64991, 'Galovac', 'Galovac', 'Galovac', 44.0713900, 15.3933300, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64992, 'Galižana', 'Galizana', 'Galezan,Galežan,Galizana,Galižana,Gallesano', 44.9316700, 13.8686100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64993, 'Gala', 'Gala', '', 43.7150000, 16.7269400, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64994, 'Fužine', 'Fuzine', 'Fusine,Fuzine,Fužine', 45.3052800, 14.7155600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64995, 'Funtana', 'Funtana', 'Fontane,Funtana,Funtane', 45.1747200, 13.6050000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64996, 'Sveti Filip i Jakov', 'Sveti Filip i Jakov', 'Filipjakov,Santi Filippo e Giacomo,Santo Filippo-Giacomo,Sv. Filipi i Jakov,Sveti Filip Jakov,Sveti Filip i Jakov,Sveti Filip-Jakov', 43.9647200, 15.4300000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64997, 'Feričanci', 'Fericanci', 'Fericanci,Ferichancze,Feričanci', 45.5288900, 17.9758300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64998, 'Ferdinandovac', 'Ferdinandovac', 'Ferdinandorf,Ferdinandovac', 46.0500000, 17.2000000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(64999, 'Fažana', 'Fazana', 'Fasana,Fasana d''Istria,Fasana d’Istria,Fazana,Fažana', 44.9275000, 13.8036100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65000, 'Ervenik', 'Ervenik', 'Ervenik', 44.0994400, 15.9452800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65001, 'Ernestinovo', 'Ernestinovo', 'Ernestinovo', 45.4519400, 18.6591700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65002, 'Erdut', 'Erdut', 'Erdod,Erdut,Erdőd', 45.5263900, 19.0602800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65003, 'Dvor', 'Dvor', 'Comuna Dvor,Dvor,Dvor na Uni,Opshtina Dvor,Stepinac Grad,dovu~oru,Двор,Општина Двор,ドヴォル', 45.0730600, 16.3708300, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65004, 'Ðurmanec', 'Durmanec', 'Durmanec,Gjurmanec,Ðurmanec', 46.1963900, 15.8408300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65005, 'Đurđevac', 'GJurgevac', 'Djurdjevac,Djurdjevec,Durdevac,Gjurgjevac,Gyurgyevecz,Sanct-Georgen,Sankt-Georgen,Szentgyorgy,Szentgyörgy,Ðurđevac', 46.0411100, 17.0697200, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65006, 'Ðurđenovac', 'Durdenovac', '', 45.5433300, 18.0458300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65007, 'Dugo Selo', 'Dugo Selo', 'Dugo Selo,Dugo-Selo,du ge cun,dwgw slw,Дуго Село,Дуго-Село,دوگو سلو,دوگۆ سێلۆ,杜戈村', 45.8061100, 16.2444400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65008, 'Dugopolje', 'Dugopolje', 'Dugopolje', 43.5805600, 16.6027800, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65009, 'Dugi Rat', 'Dugi Rat', 'Dugi Rat', 43.4461100, 16.6397200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65010, 'Duga Resa', 'Duga Resa', 'Duga Resa,Duga Rosa,Duga-Resa,du jia lei sa,dwga rsa,Дуга Реса,Дуга-Реса,دوگا رسا,دوگا ڕێسا,杜加雷薩', 45.4286100, 15.4883300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65011, 'Duće', 'Duce', 'Duce,Duće', 43.4427800, 16.6683300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65012, 'Dubrovnik', 'Dubrovnik', 'Communitas Ragusina,DBV,Dubrava,Dubrounik,Dubrovacka Republika,Dubrovačka Republika,Dubrovnik,Dubrovnikas,Dubrovnique,Dubrovník,Dubrownik,Dùbrōvnik,Laus,Pearl of the Adriatic,Ragusa,Repubblica di Ragusa,Republic of Ragusa,Respublica Ragusina,do~uburovuniku,du bu luo fu ni ke,dwbrwbnyq,la perla del Adriatico,la perla del Adriático,Дубровник,Дуброўнік,דוברובניק,ドゥブロヴニク,杜布羅夫尼克', 42.6480700, 18.0921600, 'HR', '2016-05-10', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65013, 'Dubravica', 'Dubravica', 'Dabravica,Dubravica', 45.9500000, 15.7333300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65014, 'Dubrava', 'Dubrava', '', 45.8377700, 16.5375100, 'HR', '2012-04-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65015, 'Hrvatska Dubica', 'Hrvatska Dubica', 'Dubica,Hrvatska Dubica', 45.1911100, 16.8002800, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65016, 'Drnje', 'Drnje', 'Drnje', 46.2069400, 16.9169400, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65017, 'Drniš', 'Drnis', 'Dernis,Dernisium,Drnis,Drnish,Drniš,de er ni shen,drnysh,Дрниш,Дрніш,درنیش,德爾尼什', 43.8625000, 16.1555600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65018, 'Novo Virje', 'Novo Virje', 'Drenovica,Novo Virje', 46.0913900, 17.1516700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65019, 'Drenovci', 'Drenovci', '', 44.9205600, 18.9122200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65020, 'Drenova', 'Drenova', 'Drenova,Drenovo', 45.3500000, 14.4302800, 'HR', '2013-05-05', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65021, 'Drenje', 'Drenje', 'Drenje,Drenye', 45.3811100, 18.2819400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65022, 'Dražice', 'Drazice', '', 45.3908300, 14.4702800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65023, 'Draž', 'Draz', 'Draz,Draž', 45.8422200, 18.7886100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65024, 'Draganići', 'Draganici', 'Draganic,Draganici,Draganić,Draganići', 45.6000000, 15.6000000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65025, 'Dragalić', 'Dragalic', 'Dragalci,Dragalic,Dragalić', 45.2441700, 17.2886100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65026, 'Zemunik Donji', 'Zemunik Donji', 'Donji Zemunik,Zemonico,Zemonico Inferiore,Zemunik,Zemunik Donji,Zemuniki', 44.1066700, 15.3805600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65027, 'Donji Vidovec', 'Donji Vidovec', 'Donji Vidovec', 46.3291700, 16.7866700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65028, 'Donji Seget', 'Donji Seget', 'Donji Seget,Seget Donji', 43.5166700, 16.2333300, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65029, 'Donji Proložac', 'Donji Prolozac', 'Donji Prolozac,Donji Proložac,Prolozac Donji,Proložac Donji', 43.4697200, 17.1563900, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65030, 'Donji Miholjac', 'Donji Miholjac', 'Alsomiholjac,Alsomiholjacz,Alsómiholjác,Alsómiholjácz,Donja Miholjac,Donji Miholjac,Miholjacz,Unter-Miholtz', 45.7608300, 18.1672200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65031, 'Donji Lapac', 'Donji Lapac', 'Donji Lapac,Donji Lopac', 44.5530600, 15.9619400, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65032, 'Donji Kraljevec', 'Donji Kraljevec', 'Donji Kraljevec,Donji Kraljevoc', 46.3661100, 16.6527800, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65033, 'Donji Andrijevci', 'Donji Andrijevci', 'Andrijevci,Donji Andrijevci', 45.1883300, 18.2997200, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65034, 'Donje Ladanje', 'Donje Ladanje', 'Donje Ladanje,Ladanje Dolnje', 46.3000000, 16.1666700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65035, 'Donja Zdenčina', 'Donja Zdencina', 'Donja Zdencina,Donja Zdenčina,Zdencina,Zdenčina', 45.6666700, 15.7666700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65036, 'Donja Voća', 'Donja Voca', 'Donja Voca,Donja Voća', 46.3008300, 16.1050000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65037, 'Donja Stubica', 'Donja Stubica', 'Don''ja-Stubica,Dona Stubica,Donja Stubica,Donja Stubicja,Donja-Stubica,Stubica,Stubica-dolnji,Sztubicza,dnya stwbytsa,xia si tu bi cha,Донья-Стубица,Доня Стубиця,Доня-Стубица,Доња Стубица,دنیا ستوبیتسا,دۆنیا ستوبیتسا,下斯图比察', 45.9833300, 15.9666700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65038, 'Donja Pušća', 'Donja Pusca', 'Donja Pusca,Donja Pušća,Pusca,Pusca Donja,Pušća,Pušća Donja', 45.9166700, 15.7777800, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65039, 'Donja Motičina', 'Donja Moticina', 'Donja Moticina,Donja Motičina,Madocsa,Matucsina,Moticina', 45.4947200, 18.0241700, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65040, 'Donja Lomnica', 'Donja Lomnica', '', 45.7119400, 16.0269400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65041, 'Donja Dubrava', 'Donja Dubrava', 'Alsodomboru,Alsódomboru,Donja Dubrava,Donji Dombori', 46.3147200, 16.8119400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65042, 'Brela', 'Brela', 'Brela,Brela Donja,Donja Brela', 43.3688900, 16.9341700, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65043, 'Donja Bistra', 'Donja Bistra', 'Bistra,Bistra Donja,Donja Bistra', 45.9077800, 15.8544400, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65044, 'Domašinec', 'Domasinec', 'Domasinec,Domašinec', 46.4325000, 16.6000000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65045, 'Dobrinj', 'Dobrinj', 'Dobrigno,Dobrinj', 45.1266700, 14.6033300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65046, 'Dežanovac', 'Dezanovac', 'Desanovacz,Dezanovac,Dežanovac,Donji Dezanovac,Donji Dežanovac,Donji Drezanovac,Donji Drežanovac', 45.5705600, 17.0866700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65047, 'Desinić', 'Desinic', 'Comuna Desinic,Comuna Desinić,Desinic,Desinich,Desinić,Десинич,Десинић', 46.1486100, 15.6686100, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65048, 'Delnice', 'Delnice', 'Delnice,Delnicza,dai er ni cai,dlnytsh,Делнице,Делніце,دلنیتسه,دێلنیتسێ,代爾尼采', 45.4008300, 14.7997200, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65049, 'Ðelekovec', 'Delekovec', '', 46.2486100, 16.8666700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65050, 'Dekanovec', 'Dekanovec', 'Dekanovec', 46.4486100, 16.5847200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65051, 'Davor', 'Davor', 'Davor', 45.1152800, 17.5163900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65052, 'Daruvar', 'Daruvar', 'Aquae Balisae,Daruvar,Daruvár,da lu wa er,darwvar,darwwar,Дарувар,דארובאר,دارووار,داروڤار,達魯瓦爾', 45.5905600, 17.2250000, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65053, 'Darda', 'Darda', 'Darda,dardh,دارده', 45.6280600, 18.6997200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65054, 'Dalj', 'Dalj', 'Dal,Dalj,Dalja,Dallia,Dallya,Dalya,Dállya,Dálya,Teutoburgium,da li,Даљ,達利', 45.4900000, 18.9847200, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65055, 'Đakovo', 'GJakovo', 'Dakovo,Deakovar,Deakovár,Diaco,Diakovar,Diakovár,Djakovar,Djakovo,Djakovár,Djakowar,Dzakovas,Dzhakovo,Dzhjakovo,Džakovas,gqwbw,gu ke wo,jakobo,jakovu~o,jakww,Ðakovo,Đakovo,Ђаково,Джаково,Джяково,גקובו,جاکوو,داکۆڤۆ,ジャコヴォ,賈科沃,자코보', 45.3083300, 18.4105600, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65056, 'Crnac', 'Crnac', 'Chernacz,Crnac,Csernac,Czernacz', 45.6961100, 17.9372200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65057, 'Crikvenica', 'Crikvenica', 'Cirkvenica,Cirquenizza,Crikvenica,Crikvenicja,Crkvenica,Czirkvenicza,ci li ke wei ni cha,tsrykwnytsa,Цриквеница,Цриквениця,تسریکونیتسا,تسریکڤێنیتسا,茨里克韋尼察', 45.1772200, 14.6927800, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65058, 'Cres', 'Cres', 'Cerzo,Cherso,Crepsa,Cres,Cresa,Cresi saar,Kres,Vostrau Crehs,ci lei si dao,krys,tsresi,tsuresu dao,zrs,Čerzo,Κρες,Востраў Црэс,Црес,צרס,كريس,ცრესი,ツレス島,茨雷斯島', 44.9609200, 14.4124600, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65059, 'Civljane', 'Civljane', 'Civljane', 43.9500000, 16.4000000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65060, 'Cista Provo', 'Cista Provo', 'Cista Provo,Provo', 43.5033300, 16.9477800, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65061, 'Čibača', 'Cibaca', 'Cibaca,Čibača', 42.6288900, 18.1711100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65062, 'Cetingrad', 'Cetingrad', 'Cetin,Cetingrad,Comuna Cetingrad,Цетинград', 45.1597200, 15.7394400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65063, 'Cestica', 'Cestica', 'Cestica', 46.3716700, 16.1252800, 'HR', '2016-05-08', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65064, 'Cerovlje', 'Cerovlje', 'Ceronglie,Cerovlje,Cerreto Istriano', 45.2780600, 14.0122200, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65065, 'Cernik', 'Cernik', 'Cernigo,Cernik,Cernik Primorski', 45.3436100, 14.5022200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65066, 'Cernik', 'Cernik', 'Cernik', 45.2886100, 17.3819400, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65067, 'Cerna', 'Cerna', 'Cerna,Czerna', 45.1819400, 18.6894400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65068, 'Cerić', 'Ceric', 'Ceric,Cerić', 45.3113900, 18.8561100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65069, 'Čepin', 'Cepin', 'Cepin,Csapa,Csepen,Csepin,Csepén,Tschepin,Čepin', 45.5236100, 18.5633300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65070, 'Čeminac', 'Ceminac', 'Ceminac,Čeminac', 45.6863900, 18.6675000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65071, 'Čazma', 'Cazma', 'Cazma,Chasma,Chazma,Csazma,Csázma,cha zi ma,chazma,chazuma,Čazma,Чазма,چازما,チャズマ,察茲馬', 45.7481800, 16.6139000, 'HR', '2012-04-15', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65072, 'Cavtat', 'Cavtat', 'Cavtat,Epidaurus,Ragusa Vecchia,Ragusavecchia,tsu~avutatto,Цавтат,ツァヴタット', 42.5811100, 18.2180600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65073, 'Čavle', 'Cavle', 'Cavle,Čavle', 45.3519400, 14.4838900, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65074, 'Čakovec', 'Cakovec', 'Aquama,Cakovec,Cakovecas,Chakovec,Csakathurn,Csaktornya,Csáktornya,Gorad Chakavec,cha ke wei ci,chakobecheu,chakovu~etsu,chakwts,chakwwts,tshakwfytsh,Čakovec,Čakovecas,Горад Чакавец,Чаковец,تشاكوفيتش,چاکوتس,چاکووتس,چاکۆڤێتس,ჩაკოვეცი,チャコヴェツ,查科韋茨,차코베츠', 46.3844400, 16.4338900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65075, 'Čaglin', 'Caglin', 'Caglin,Chaglin,Comuna Caglin,Comuna Čaglin,Csegleny,Cseglény,Čaglin,Чаглин', 45.3497200, 17.9897200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65076, 'Čađavica', 'Cadavica', 'Cadavica,Cadjavica,Chagyavecz,Csagavica,Čadjavica,Čađavica', 45.7441700, 17.8547200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65077, 'Čačinci', 'Cacinci', 'Cacinci,Chachincze,Csacsince,Čačinci', 45.6038900, 17.8702800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65078, 'Buzet', 'Buzet', 'Buzet,Pinguente,Piquentum,bu ze te,buzeto,bwzt,Бузет,Բուզետ,بوزت,بوزێت,ブゼト,布澤特', 45.4094400, 13.9666700, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65079, 'Bukovlje', 'Bukovlje', 'Bukovlje,Bukovlje Podvinjsko,Podvinjsko Bukovlje', 45.1852800, 18.0700000, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65080, 'Buje', 'Buje', 'Bue,Buie,Buie d''Istria,Buie d’Istria,Buje,Bullae,Buíe,bu ye,bui~e,bwyh,Буе,Бує,Бује,بویه,بویێ,ブイェ,布耶', 45.4100000, 13.6619400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65081, 'Budrovci', 'Budrovci', 'Budrovce,Budrovci,Budrovcze', 45.2711100, 18.4486100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65082, 'Budinšćina', 'Budinscina', 'Budinscina,Budinšćina', 46.1289400, 16.2059500, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65083, 'Budaševo', 'Budasevo', 'Budasevo,Budaševo,Veliko Budasevo,Veliko Budaševo', 45.4747200, 16.4366700, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65084, 'Brtonigla', 'Brtonigla', 'Brtonigla,Crni Vrh,Verteneglio,Črni Vrh', 45.3813900, 13.6294400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65085, 'Bršadin', 'Brsadin', 'Brsadin,Bršadin', 45.3627800, 18.9111100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65086, 'Brodski Varoš', 'Brodski Varos', 'Brodski Varos,Brodski Varoš,Ovar,Varos,Varos Brodski,Varoš,Varoš Brodski,Óvár', 45.1811100, 17.9786100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65087, 'Brodski Stupnik', 'Brodski Stupnik', 'Brodski Stupnik,Stupnik,Stupnik Brodski', 45.1677800, 17.8036100, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65088, 'Brod Moravice', 'Brod Moravice', 'Brod Moravice,Brod-Moravice,Comuna Brod Moravice,Брод Моравице,Брод-Моравице', 45.4652800, 14.9744400, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65089, 'Brnaze', 'Brnaze', 'Brnaze', 43.6800000, 16.6497200, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65090, 'Brinje', 'Brinje', 'Brinje', 45.0025000, 15.1338900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65091, 'Bribir', 'Bribir', '', 45.1611100, 14.7647200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65092, 'Brezovica', 'Brezovica', 'Brezovica', 45.7291900, 15.9106900, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65093, 'Brezovac', 'Brezovac', '', 45.8675000, 16.8408300, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65094, 'Breznica', 'Breznica', 'Breznica,Brežnica', 46.0711100, 16.2711100, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65095, 'Brestovac', 'Brestovac', 'Brestovac,Brestovac Pozaski,Brestovac Pozeski,Brestovac Požeški,Comuna Brestovac,Pozeski Brestovac,Požeški Brestovac,Szilberek,Брестовац', 45.3305600, 17.5969400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65096, 'Koprivnički Bregi', 'Koprivnicki Bregi', 'Bregi,Bregi Koprivnicki,Bregi Koprivnički,Koprivnicki Bregi,Koprivnički Bregi', 46.1386100, 16.9058300, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65097, 'Bregana', 'Bregana', 'Bregana', 45.8401300, 15.6879200, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65098, 'Brdovec', 'Brdovec', 'Brdovec', 45.8666600, 15.7710200, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65099, 'Brckovljani', 'Brckovljani', 'Brckovljani', 45.8333300, 16.3000000, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65100, 'Bošnjaci', 'Bosnjaci', 'Bosnjaci,Bošnjaci', 45.0502800, 18.7555600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65101, 'Bosiljevo', 'Bosiljevo', 'Bosilevo,Bosiljevo,Bosiljevo Cazmansko,Bosiljevo Čazmansko,Comuna Bosiljevo,Босиљево', 45.4013900, 15.2883300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65102, 'Borovo', 'Borovo', 'Boro,Borovo,Boró', 45.3763900, 18.9669400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65103, 'Bol', 'Bol', 'Bol,Comuna Bol,Vallum Brattiae,Бол', 43.2619400, 16.6550000, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65104, 'Bogdanovci', 'Bogdanovci', 'Bogdanovci', 45.3408300, 18.9308300, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65105, 'Bobota', 'Bobota', 'Bobota', 45.4211100, 18.8538900, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65106, 'Blato', 'Blato', 'Blato,Blatta', 42.9408300, 16.7916700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65107, 'Blato', 'Blato', 'Blata,Blatina,Blato', 42.7625000, 17.4822200, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65108, 'Bjelovar', 'Bjelovar', 'B''elovar,Belavar,Bellovar,Bellovarium,Belovar,Belovár,Belowar,Bjelovar,Bjelovaras,Bélavár,bellobaleu,belovari,bie luo wa er,byerovu~aru,bylwar,bylwfar,byylwwar,Беловар,Бьеловар,Бјеловар,Բելովար,ביילובאר,بيلوفار,بیئلووار,بیلوار,بیێلۆڤار,ბელოვარი,ビェロヴァル,别洛瓦尔,벨로바르', 45.8986100, 16.8488900, 'HR', '2012-01-19', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65109, 'Bizovac', 'Bizovac', 'Bizovac', 45.5927800, 18.4588900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65110, 'Bistrinci', 'Bistrinci', 'Bistrince,Bistrinci,Bisztrincze', 45.6916700, 18.3986100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65111, 'Biskupija', 'Biskupija', 'Biskupija', 44.0113900, 16.2372200, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65112, 'Biograd na Moru', 'Biograd na Moru', 'Biograd,Biograd na Moru,Biograd-na-Moru,Blandona,Zaravecchia,bi ao ge lei na mo lu,bywgrad na mrw,bywgrad na mwrw,Биоград на Мору,Биоград-на-Мору,Біоград-на-Мору,Բիոգրադ նա Մորու,بیوگراد نا مرو,بیوگراد نا مورو,بیۆگراد نا مۆرو,ビオグラード・ナ・モル,比奧格勒納莫魯', 43.9433300, 15.4519400, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65113, 'Bilje', 'Bilje', 'Belje,Bilje', 45.6069400, 18.7438900, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65114, 'Bilice', 'Bilice', 'Bilice', 43.7886900, 15.8747300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65115, 'Bijelo Brdo', 'Bijelo Brdo', 'Bielo Brdo,Bijelo Brdo', 45.5172200, 18.8708300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65116, 'Bibinje', 'Bibinje', 'Bibigne,Bibinje', 44.0728800, 15.2839600, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65117, 'Beretinec', 'Beretinec', 'Beretinec,Bertinec', 46.2500000, 16.3000000, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65118, 'Berek', 'Berek', 'Berek', 45.7383300, 16.8302800, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65119, 'Benkovac', 'Benkovac', 'Bencovazzo,Benkovac,ben ke wa ci,benkovu~atsu,bnkwwats,Бенковац,Բենկովաց,بنکوواتس,بنکۆڤاتس,ベンコヴァツ,本科瓦茨', 44.0344400, 15.6127800, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65120, 'Belišće', 'Belisce', 'Belisce,Belishche,Belishhe,Belistye,Belišće,Beliščė,bei li shen qie,blyshchh,Белишче,Белишће,Беліще,Բելիշցե,بلیشچه,بێلیشچێ,貝利什切', 45.6802800, 18.4058300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65121, 'Beli Manastir', 'Beli Manastir', 'Beli Manastir,Beli-Manastir,Monostor,Pel-Monostor,Pelmonostor,Pélmonostor,bei li ma na si di er,bly manastyr,Бели Манастир,Бели-Манастир,Белі Манастір,Բելի Մանաստիր,بلی ماناستیر,بێلی ماناستیر,貝利馬納斯蒂爾', 45.7700000, 18.6036100, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65122, 'Belica', 'Belica', 'Belica', 46.4041700, 16.5183300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65123, 'Bednja', 'Bednja', 'Bedna,Bednja,Bednjz,Comuna Bednja,Бедня,Бедња', 46.2305600, 15.9827800, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65124, 'Bedenica', 'Bedenica', 'Bedenica', 46.0333300, 16.2427800, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65125, 'Bedekovčina', 'Bedekovcina', 'Bedekovcina,Bedekovčina,Donja Bedekovcina,Donja Bedekovčina', 46.0411100, 15.9963900, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65126, 'Bebrina', 'Bebrina', 'Bebrina', 45.0983300, 17.8341700, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65127, 'Batrina', 'Batrina', 'Batrina', 45.1894400, 17.6663900, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65128, 'Baška Voda', 'Baska Voda', 'Bashka-Voda,Baska Voda,Baška Voda,Bestonio,Башка-Вода', 43.3569400, 16.9502800, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65129, 'Baška', 'Baska', 'Baska,Baska Primorje,Baskanova,Baška,Baška Primorje,Baškanova,Bescanuova', 44.9702800, 14.7533300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65130, 'Barilović', 'Barilovic', 'Barilovic,Barilović,Comuna Barilovic,Comuna Barilović,Бариловић', 45.3833300, 15.5500000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65131, 'Barban', 'Barban', 'Barban,Barbana,Barbana d''Istria,Barbana d’Istria,Comuna Barban,Ruzici,Ružići,Барбан', 45.0644400, 14.0136100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65132, 'Banjol', 'Banjol', 'Banjol', 44.7500000, 14.7833300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65133, 'Bale', 'Bale', 'Bal,Bale,Valle,Valle d''Istria,Valle d’Istria', 45.0405600, 13.7836100, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65134, 'Bakar', 'Bakar', 'Bakar,Bakovac,Buccari,ba ka er,bakar,Бакар,Բակար,באקאר,باکار,巴卡爾', 45.3086100, 14.5302800, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65135, 'Babino Polje', 'Babino Polje', 'Babina Polje,Babino,Babino Polje,Pian di Babino', 42.7333300, 17.5619400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65136, 'Babina Greda', 'Babina Greda', 'Babina Greda', 45.1172200, 18.5369400, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65137, 'Antunovac', 'Antunovac', 'Antunovac,Antunovac Tenjski,Antunowatz,Tenjski Antunovac', 45.4908300, 18.6750000, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65138, 'Andrijaševci', 'Andrijasevci', 'Andriaschevce,Andriassewcze,Andrijasevci,Andrijaševci', 45.2247200, 18.7380600, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65139, 'Jankomir', 'Jankomir', 'Jankomir', 45.7916700, 15.9000000, 'HR', '2013-05-05', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65140, 'Zagreb- Stenjevec', 'Zagreb- Stenjevec', 'Stenjevec', 45.8084600, 15.8824500, 'HR', '2015-10-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65141, 'Bestovje', 'Bestovje', 'Bestovje', 45.8083300, 15.8166700, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65142, 'Zagreb- Novi Zagreb', 'Zagreb- Novi Zagreb', 'Novi Zagreb', 45.7833300, 15.9833300, 'HR', '2015-12-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65143, 'Brodarica', 'Brodarica', 'Brodarica,Lusa', 43.6800000, 15.9197200, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65144, 'Zagorska Sela', 'Zagorska Sela', 'Zagorska Sela', 46.0969400, 15.6350000, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65145, 'Buzdohanj', 'Buzdohanj', '', 45.3452800, 14.4883300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65146, 'Otrić-Seoci', 'Otric-Seoci', 'Otric-Seoci,Otrici,Otrić-Seoci,Otrići,Seoci', 43.1586100, 17.4508300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65147, 'Netretić', 'Netretic', 'Comuna Netretic,Comuna Netretić,Netretic,Netretić,Нетретић', 45.5088900, 15.4133300, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65148, 'Donji Kukuruzari', 'Donji Kukuruzari', 'Donji Kukuruzari', 45.2663900, 16.4833300, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65149, 'Lipovljani', 'Lipovljani', 'Lipovljane,Lipovljani', 45.3966700, 16.8897200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65150, 'Sukošan', 'Sukosan', 'Sukosan,Sukošan', 44.0466700, 15.3155600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65151, 'Bibinje', 'Bibinje', 'Bibinje', 44.0716700, 15.2877800, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65152, 'Kukljica', 'Kukljica', 'Kukljica', 44.0347200, 15.2455600, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65153, 'Zlatar', 'Zlatar', '', 46.0855600, 16.0755600, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65154, 'Preko', 'Preko', 'Oltre,Preko', 44.0811100, 15.1875000, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65155, 'Stari Grad', 'Stari Grad', 'Stari Grad', 46.1366700, 16.8052800, 'HR', '2013-08-07', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65156, 'Koprivnički Ivanec', 'Koprivnicki Ivanec', 'Ivanec,Koprivnicki Ivanec,Koprivnički Ivanec', 46.2027800, 16.8166700, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65157, 'Farkaševac', 'Farkasevac', '', 45.8794400, 16.6408300, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65158, 'Nin', 'Nin', 'Aenana,Nin,Nona,nin,ning,nyn,nyn  krwasy,Нин,Нін,نین,نین، کرواسی,ニン,寧', 44.2413900, 15.1783300, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65159, 'Privlaka', 'Privlaka', 'Privlaka', 44.2633300, 15.1197200, 'HR', '2016-12-30', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65160, 'Stari Grad', 'Stari Grad', 'Stari Grad,Стари Град', 44.4300000, 15.0622200, 'HR', '2012-01-19', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65161, 'Popovača', 'Popovaca', '', 44.6391700, 15.1791700, 'HR', '2006-01-17', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65162, 'Kampor', 'Kampor', '', 44.7750000, 14.7186100, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65163, 'Vidovci', 'Vidovci', 'Vidovci', 45.3325000, 17.7147200, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65164, 'Borovo Selo', 'Borovo Selo', 'Borovo,Borovo Selo', 45.4052800, 18.9758300, 'HR', '2017-01-03', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65165, 'Drenovci', 'Drenovci', 'Drenovci', 44.9182600, 18.9088400, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65166, 'Podgora', 'Podgora', '', 42.8486100, 17.8363900, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65167, 'Brinje', 'Brinje', '', 45.0000000, 15.1308300, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65168, 'Kamen', 'Kamen', '', 43.5141700, 16.5147200, 'HR', '2017-01-02', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65169, 'Zmijavci', 'Zmijavci', 'Zmijavci', 43.4108300, 17.2055600, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65170, 'Greda', 'Greda', '', 43.6152800, 16.6936100, 'HR', '2006-01-17', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65171, 'Grabovci', 'Grabovci', 'Grabovci,Грабовци', 43.4927800, 17.2011100, 'HR', '2013-08-13', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65172, 'Grubine', 'Grubine', '', 43.4298600, 17.1629200, 'HR', '2017-01-01', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65173, 'Vlaka', 'Vlaka', '', 42.9991700, 17.5241700, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65174, 'Korenica', 'Korenica', '', 45.2247200, 18.1655600, 'HR', '2016-12-21', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65175, 'Brijest', 'Brijest', 'Brijest', 45.5205600, 18.6719400, 'HR', '2016-12-24', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65176, 'Karlovac', 'Karlovac', 'Carelostadium,Carlostadium,Carlstadt,Carolostadium,Dubovacz,Karlovac,Karlovacas,Karlovec,Karlovecz,Karlstadt,Karolyvaros,Károlyváros,Suburbium,ka er luo wa ci,kaleullobacheu,karlwats,karlwfatsh,karlwwats,karurovu~atsu,Карловац,كارلوفاتش,کارلواتس,کارلوواتس,کارلۆڤاتس,კარლოვაცი,カルロヴァツ,卡爾洛瓦茨,카를로바츠', 45.4916700, 15.5500000, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65177, 'Zagreb - Centar', 'Zagreb - Centar', 'Donji grad', 45.8131300, 15.9775300, 'HR', '2016-10-14', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65178, 'Stubičke Toplice', 'Stubicke Toplice', '', 45.9758500, 15.9323800, 'HR', '2016-01-16', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65179, 'Koprivnički Ivanec', 'Koprivnicki Ivanec', '', 46.1993800, 16.8172700, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65180, 'Novo Virje', 'Novo Virje', '', 46.0985900, 17.1523800, 'HR', '2016-06-06', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65181, 'Viškovo', 'Viskovo', '', 45.3757200, 14.3840000, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65182, 'Donji Stupnik', 'Donji Stupnik', '', 45.7397100, 15.8597500, 'HR', '2016-12-27', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65183, 'Hrašćica', 'Hrascica', '', 46.3249400, 16.2942700, 'HR', '2016-12-25', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65184, 'Mihotići', 'Mihotici', '', 45.3612500, 14.3055300, 'HR', '2016-12-26', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65185, 'Valbandon', 'Valbandon', '', 44.9187900, 13.8134400, 'HR', '2016-12-22', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65186, 'Konjšćina', 'Konjscina', 'Konjscina,Konjšćina', 46.0521000, 16.1726400, 'HR', '2016-12-23', 56);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65187, 'Verrettes', 'Verrettes', 'Les Verettes,Les Verrettes,Veret,Verrettes,Vèrèt', 19.0505000, -72.4658500, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65188, 'Trou du Nord', 'Trou du Nord', 'Le Trou,Trou,Trou di No,Trou di Nò,Trou du Nord', 19.6166800, -72.0244200, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65189, 'Torbeck', 'Torbeck', 'Tobek,Torbeck,Tòbèk', 18.1633800, -73.8094900, 'HT', '2017-02-04', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65190, 'Tiburon', 'Tiburon', 'Tiburon', 18.3258900, -74.3959800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65191, 'Thomonde', 'Thomonde', 'Thomonde,Tomond', 19.0173000, -71.9623500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65192, 'Thomazeau', 'Thomazeau', 'Thomazeau,Tomazo', 18.6529700, -72.0939100, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65193, 'Thomassique', 'Thomassique', 'Thomassique,Tomasik', 19.0820900, -71.8385500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65194, 'Thiotte', 'Thiotte', 'Cai-Tiot,Caï-Tiot,Thiote,Thiotte,Tiote,Tyot,Tyòt', 18.2438400, -71.8415700, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65195, 'Saint-Raphaël', 'Saint-Raphael', 'Saint-Raphael,Saint-Raphaël,Sen Rafayel,Sen Rafayèl', 19.4387700, -72.1991000, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65196, 'Saint-Marc', 'Saint-Marc', 'Saint-Marc,Sen-Mark,Сен-Марк', 19.1081900, -72.6937900, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65197, 'Saint-Louis du Sud', 'Saint-Louis du Sud', 'Saint Louis,Saint-Louis du Sud,Sen Lwi di Sid', 18.2624100, -73.5460300, 'HT', '2017-02-04', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65198, 'Saint-Louis du Nord', 'Saint-Louis du Nord', 'Saint Louis,Saint-Louis du Nord,Sen Lwi di No,Sen Lwi di Nò', 19.9339700, -72.7213800, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65199, 'Roche-à-Bateau', 'Roche-a-Bateau', 'Roche a Bateaux,Roche-a-Bateau,Roche-à-Bateau,Wochabato,Wòchabato', 18.1818200, -74.0034500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65200, 'Ranquitte', 'Ranquitte', 'Rankit,Ranquite,Ranquitte', 19.4132700, -72.0807700, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65201, 'Quartier Morin', 'Quartier Morin', 'Katye Moren,Qartier-Morin,Quartier Morin,Ville de Quartier Morin', 19.6969600, -72.1571200, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65202, 'Port-Margot', 'Port-Margot', 'Po Mago,Port Margot,Port-Margot,Pò Mago', 19.7518000, -72.4300600, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65203, 'Port-de-Paix', 'Port-de-Paix', 'PAX,Podepe,Podpe,Por-de-Pe,Port Paix,Port-de-Paix,Porto-da-Paz,Pòdepè,Pòdpè,he ping gang,poleudeupe,poleudeupei,porudope,Пор-де-Пе,پورت دے پئے,ポールドペ,和平港,포르드페,포르드페이', 19.9389000, -72.8325700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65204, 'Port-au-Prince', 'Port-au-Prince', 'Gorad Port-o-Prehns,PAP,Port au Prince,Port o Prens,Port o Prensas,Port-au-Prince,Port-o-Prens,Port-o-Prins,Porto Principe,Porto Príncipe,Portoprensa,Portoprinco,Portus Principis,Potoprens,Puerto Principe,Puerto Príncipe,Pòtoprens,Ville de Port-au-Prince,bwrt aw brans,poleutopeulaengseu,porata-o-prainsa,port-o-pirins,porta-a-prinsa,porta-au-prinsa,porta-o-prinsa,porutopuransu,pwrtw prns,pwrtwprns,tai zi gang,Πορτ-ο-Πρενς,Горад Порт-о-Прэнс,Порт о Пренс,Порт-о-Пренс,Պորտ-օ-Պրենս,פורט או פרינס,פורט-או-פרנס,بورت أو برانس,پورتو پرنس,پورتوپرنس,پورٹ او پرنس,पोर्ट-ऑ-प्रिंस,पोर्ट-औ-प्रिन्स,পোর্ট-অ-প্রিন্স,ਪੋਰਤ-ਓ-ਪ੍ਰੈਂਸ,போர்ட்-ஓ-பிரின்ஸ்,പോർട്ട്-ഔ-പ്രിൻസ്,ปอร์โตแปรงซ์,པོ་རོ་ཊི་ཨའུ་པི་རིན་སི།,პორტ-ო-პრენსი,ፖርቶፕሪንስ,ポルトープランス,太子港,포르토프랭스', 18.5391700, -72.3350000, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65205, 'Port-à-Piment', 'Port-a-Piment', 'Port Piment,Port-a-Piment,Port-à-Piment', 18.2496300, -74.0971000, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65206, 'Plaisance', 'Plaisance', 'Plaisance,Plezans', 19.5979500, -72.4699400, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65207, 'Plaine du Nord', 'Plaine du Nord', 'Plaine du Nord,Plen di No,Plèn di Nò', 19.6770700, -72.2696900, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65208, 'Pilate', 'Pilate', 'Pilat,Pilate', 19.6674500, -72.5522900, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65209, 'Pignon', 'Pignon', 'Dignon,Pignon,Piyon', 19.3359400, -72.1166200, 'HT', '2016-10-24', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65210, 'Phaëton', 'Phaeton', 'Phaeton,Phaéton,Phaëton', 19.6752500, -71.8969100, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65211, 'Petit Trou de Nippes', 'Petit Trou de Nippes', 'Petit Trou', 18.5253500, -73.5081500, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65212, 'Tigwav', 'Tigwav', 'Petit Goave,Petit Goâve,Petit-Goave,Petit-Goâve,Tigwav,Ville de Petit Goave,Ville de Petit Goâve', 18.4311700, -72.8652100, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65213, 'Petite Rivière de Nippes', 'Petite Riviere de Nippes', 'Ville de Petite Riviere,Ville de Petite Rivière', 18.4761100, -73.2349500, 'HT', '2011-01-10', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65214, 'Petite Anse', 'Petite Anse', 'Petite Anse', 19.6301100, -73.1549900, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65215, 'Pétionville', 'Petionville', 'Petionville,Petyon-Vil,Pétionville,Ville de Petion-Ville,Ville de Pétion-Ville', 18.5125000, -72.2852800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65216, 'Perches', 'Perches', 'Pech,Perches,Pèch', 19.5220100, -71.9232300, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65217, 'Ouanaminthe', 'Ouanaminthe', 'Juana Mendez,Ouanaminthe,Quanamenthe,Wanament', 19.5493400, -71.7247500, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65218, 'Moron', 'Moron', 'Bourg de Moron,Monwon,Moron,Ville de Moron', 18.5603900, -74.2577700, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65219, 'Montòrganize', 'Montorganize', 'Lassalle,Mont Organise,Mont Organisé,Mont-Organise,Mont-Organisé,Montorganize,Montòrganize', 19.4081500, -71.7813200, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65220, 'Môle Saint-Nicolas', 'Mole Saint-Nicolas', 'Le Mole,Le Mole Saint Nicolas,Le Môle,Le Môle Saint Nicolas,Mole Saint-Nicolas,Mole Taint-Nicolas,Môle Saint-Nicolas', 19.8070000, -73.3760500, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65221, 'Mirebalais', 'Mirebalais', 'Bourg Saint Louis,Mibale,Mibalè,Mirebalais', 18.8345500, -72.1048000, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65222, 'Miragoâne', 'Miragoane', '', 18.4423200, -73.0875800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65223, 'Milot', 'Milot', 'Milo,Milot', 19.6083700, -72.2131900, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65224, 'Marmelade', 'Marmelade', 'Mamelad,Marmeiade,Marmelade', 19.5173600, -72.3613300, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65225, 'Marigot', 'Marigot', 'Marigo,Marigot', 18.2316700, -72.3228900, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65226, 'Mayisad', 'Mayisad', 'Maissade,Mayisad,Maïssade', 19.1760700, -72.1395800, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65227, 'Limonade', 'Limonade', 'Limonad,Limonade', 19.6701400, -72.1243000, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65228, 'Lenbe', 'Lenbe', 'Le Limbe,Lenbe,Limbe,Limbé,Ville de Limbe,Ville de Limbé,Лимбе', 19.7060300, -72.4033600, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65229, 'Les Irois', 'Les Irois', 'Irois,Les Irois', 18.4049000, -74.4528000, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65230, 'Les Anglais', 'Les Anglais', 'Anglais,Les Anglais,Ville des Anglais', 18.3054000, -74.2196800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65231, 'Léogâne', 'Leogane', 'Leogan,Leogane,Leyogan,Leyogàn,Léogâne,Ville de Leogane,Ville de Léogane,Yaguana,lai ao gan,reogan,Леоган,レオガン,萊奧甘', 18.5111000, -72.6334300, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65232, 'Borgne', 'Borgne', 'Borgne,La Borgne,Le Borgne,Le Rorgne,Oboy,Obòy,Ville du Borgne', 19.8450700, -72.5234900, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65233, 'Lascahobas', 'Lascahobas', 'Las Cahobes,Las Caobas,Lascahobas,Laskawobas,Ville de Lascahobas', 18.8304700, -71.9356300, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65234, 'Kenscoff', 'Kenscoff', 'Kenscoff,Kenskof,Kenskoff,Kenskòf', 18.4477300, -72.2839800, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65235, 'Jérémie', 'Jeremie', 'JEE,Jeremi,Jeremias,Jeremie,Jérémie,Zheremi,jelemi,jeremi,jyrymy,re lei mi,zrmy,Жереми,Жеремі,זרמי,جیریمی,ジェレミー,熱雷米,제레미', 18.6500000, -74.1166700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65236, 'Jean-Rabel', 'Jean-Rabel', 'Jan Rabel,Jan Rabèl,Jean-Rabel,Ville de Jean Rabel', 19.8537900, -73.1913100, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65237, 'Jacmel', 'Jacmel', 'JAK,Jacmel,Jakmel,Jakmèl,Yaquimo,Yáquimo,Zhakmel'',Zhakmele,jakeumel,jakumeru,jkml,ya ke mei lei,zʼqml,Жакмеле,Жакмель,זאקמל,جکمل,ジャクメル,雅克梅勒,자크멜', 18.2342700, -72.5353900, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65238, 'Hinche', 'Hinche', 'Ehnsh,Ench,Ensh,Hincha,Hinche,aengsyu,an shen,anshu,Енш,Энш,اینشے,アンシュ,安什,앵슈', 19.1500000, -72.0166700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65239, 'Gros Morne', 'Gros Morne', 'Gromon,Gromòn,Gros Morne', 19.6708000, -72.6780800, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65240, 'Gressier', 'Gressier', 'Gressier', 18.5409100, -72.5267900, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65241, 'Grangwav', 'Grangwav', 'Grand Goave,Grand Goâve,Grand-Goave,Grand-Goâve,Grande Goave,Grangwav', 18.4259000, -72.7699500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65242, 'Grande Saline', 'Grande Saline', 'Grand Saline,Grande Saline,Ville de Grande Saline', 19.2651300, -72.7689700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65243, 'Grande Rivière du Nord', 'Grande Riviere du Nord', 'Grand Riviere,Grande Riviere,Grande Riviere du Nord,Grande Rivière du Nord,Grann Rivye di No,Grann Rivyè di Nò,Sainte Rose,Ville de Grande Riviere du Nord,Ville de Grande Rivière du Nord', 19.5774400, -72.1687200, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65244, 'Gonayiv', 'Gonayiv', 'Gonaiv,Gonaives,Gonayiv,Gonaïves,Les Gonaives,Les Gonaïves,Ville des Gonaives,Ville des Gonaïves,Гонаив', 19.4474900, -72.6890300, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65245, 'Fort Liberté', 'Fort Liberte', 'Folibete,Fort Liberte,Fort Liberté,Fort-Dauphin,Fòlibète,Ville de Fort Liberte,Ville de Fort Liberté', 19.6627300, -71.8379800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65246, 'Fonds Verrettes', 'Fonds Verrettes', 'Fon Veret,Fon Vèrèt,Fond Verrettes,Fonds Verettes,Fonds Verrettes,La Mission', 18.3956600, -71.8563400, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65247, 'Fond Parisien', 'Fond Parisien', '', 18.5054700, -71.9812200, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65248, 'Fond des Blancs', 'Fond des Blancs', 'Fond des Blancs', 18.2778200, -73.1273300, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65249, 'Fond Bassin Bleu', 'Fond Bassin Bleu', 'Fond Bassin Bleu', 19.7944500, -72.7994900, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65250, 'Ferrier', 'Ferrier', 'Ferie,Ferié,Ferrier,Ferye,Fèrye', 19.6154900, -71.7779200, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65251, 'Ennery', 'Ennery', 'Ennery,Ennri', 19.4834200, -72.4853700, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65252, 'Dondon', 'Dondon', 'Dondon', 19.5273400, -72.2433700, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65253, 'Dessalines', 'Dessalines', 'Desalin,Dessalines,Marchand', 19.2617700, -72.5161100, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65254, 'Désarmes', 'Desarmes', 'Desarmes,Désarmes', 18.9934500, -72.3905800, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65255, 'Dérac', 'Derac', 'Derac,Dérac,Lagnon', 19.6547600, -71.8145100, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65256, 'Delmas 73', 'Delmas 73', '', 18.5447200, -72.3027800, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65257, 'Dame-Marie', 'Dame-Marie', 'Dame-Marie,Ville de Dame Marie', 18.5610700, -74.4216700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65258, 'Croix-des-Bouquets', 'Croix-des-Bouquets', 'Croix des Bouquets,Croix-des-Bouquets', 18.5767700, -72.2262500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65259, 'Kotdefè', 'Kotdefe', 'Cote de Fer,Cotes de Fer,Cotes-de-Fer,Côtes de Fer,Côtes-de-Fer,Kotdefe,Kotdefè', 18.1887200, -73.0028700, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65260, 'Koto', 'Koto', 'Coteau,Coteaux,Koto,Les Coteaux,Les Côteaux', 18.2060100, -74.0401300, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65261, 'Cornillon', 'Cornillon', 'Cornillon,Grands Bois,Koniyon,Kòniyon', 18.6754600, -71.9527100, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65262, 'Corail', 'Corail', 'Corail,Koray', 18.5676600, -73.8894200, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65263, 'Chardonnière', 'Chardonniere', 'Chardonniere,Chardonnieres,Chardonnière,Chardonnières,Ville de Chardonniere,Ville de Chardonnière', 18.2748400, -74.1661300, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65264, 'Chantal', 'Chantal', 'Chantal', 18.2016900, -73.8895700, 'HT', '2017-02-04', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65265, 'Chambellan', 'Chambellan', 'Chambellan,Chanbelan,Chanbèlan', 18.5503700, -74.3131700, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65266, 'Cerca la Source', 'Cerca la Source', 'Cerca la Source,La Source,Seka Lasous,Sèka Lasous,Ville de Cerca la Source', 19.1669600, -71.7901500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65267, 'Cayes-Jacmel', 'Cayes-Jacmel', 'Cayes Jacmel,Cayes de Jacmel,Cayes-Jacmel,Kay Jakmel,Kay Jakmèl', 18.2311000, -72.3954500, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65268, 'Les Cayes', 'Les Cayes', 'Aux Cayes,CYA,Cayes,Le Kajus,Le-Ke,Les Cayes,Los Cayos,Okay,Ville des Cayes,lai kai,leukaye,rekai,Ле-Ке,لے سائیس,レカイ,萊凱,르카예', 18.1933100, -73.7460100, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65269, 'Cavaillon', 'Cavaillon', 'Cauaillon,Cavaillon,Cavailon,Kavayon', 18.2998700, -73.6545500, 'HT', '2017-02-04', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65270, 'Carrefour', 'Carrefour', '', 18.5411400, -72.3992200, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65271, 'Carice', 'Carice', 'Carice,Karis', 19.3779500, -71.8303000, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65272, 'Caracol', 'Caracol', 'Caracol,Karakol,Karakòl', 19.6927400, -72.0173300, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65273, 'Okap', 'Okap', 'CAP,Cabo Haitiano,Cap Haitien,Cap-Francais,Cap-Français,Cap-Haitien,Cap-Haïtien,Cape Haitien,Cape Haytien,Guarico,Guárico,Haitia Kabo,Kap Ayisyen,Kap-Ait''en,Kap-Ait''ene,Kap-Aitien,Le Cap,Okap,Ville du Cap-Haitien,hai de jiao,kap-hayytyn,kapaishan,kapeuaisiaeng,Καπ-Αϊτιέν,Кап-Аитьен,Кап-Аитьене,Кап-Аїтьєн,کاپ-هائیتین,カパイシャン,海地角,카프아이시앵', 19.7593800, -72.1981500, 'HT', '2016-10-12', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65274, 'Cabaret', 'Cabaret', 'Cabaret,Duvalierville,Kabare,Kabarè,Prince', 18.7358200, -72.4192900, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65275, 'Bombardopolis', 'Bombardopolis', 'Bombardopolis,Bonbadopolis,Ville de Bombardopolis', 19.6914200, -73.3376900, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65276, 'Belle-Anse', 'Belle-Anse', 'Belans,Belle-Anse,Saltrou', 18.2376800, -72.0663800, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65277, 'Baradères', 'Baraderes', 'Baradaires,Barade,Baraderes,Baradè,Baradères', 18.4825500, -73.6388400, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65278, 'Baie de Henne', 'Baie de Henne', 'Baie de Haine,Baie de Henne,Be de En,Be de Èn,Henne,Henne Bay', 19.6630700, -73.2094300, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65279, 'Bahon', 'Bahon', 'Bahon,Bawon,Bohon', 19.4695900, -72.1146600, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65280, 'Arcahaie', 'Arcahaie', '', 19.8166700, -72.9166700, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65281, 'Aquin', 'Aquin', 'Aken,Aquin', 18.2797400, -73.3943300, 'HT', '2017-04-07', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65282, 'Anse Rouge', 'Anse Rouge', 'Anse Rouge,Answouj,Ville de l''Anse Rouge,Ville de l’Anse Rouge', 19.6338200, -73.0553000, 'HT', '2017-03-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65283, 'Anse-à-Veau', 'Anse-a-Veau', 'Ville de Anse a Veau,Ville de Anse à Veau', 18.5011000, -73.3449000, 'HT', '2011-01-10', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65284, 'Anse-à-Pitre', 'Anse-a-Pitre', 'Anse Pitres,Anse-a-Pitre,Anse-a-Pitres,Anse-à-Pitre,Anse-à-Pitres,Anses a Pitre,Anses à Pitre,Anses-a-Pitres,Anses-a-Pîtres', 18.0500000, -71.7500000, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65285, 'Anse à Galets', 'Anse a Galets', 'Ansagale,Ansagalè,Anse Galets,Anse a Galet,Anse a Galets,Anse à Galet,Anse à Galets', 18.8344900, -72.8664400, 'HT', '2017-01-05', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65286, 'Acul du Nord', 'Acul du Nord', 'Acul du Nord,Akil di No,Akil di Nò', 19.6807500, -72.3197800, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65287, 'Les Abricots', 'Les Abricots', 'Abricot,Abricots,Abriko,Les Abricots,Ville de Apricots', 18.6490100, -74.3078600, 'HT', '2017-05-08', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65288, 'Ti Port-de-Paix', 'Ti Port-de-Paix', '', 19.9333300, -72.8333300, 'HT', '2016-01-30', 96);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65289, 'Záhony', 'Zahony', 'Zahony,Záhony', 48.4090600, 22.1761400, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65290, 'Zagyvarékas', 'Zagyvarekas', 'Zagyvarekas,Zagyvarékas', 47.2666700, 20.1333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65291, 'Vésztő', 'Veszto', 'Veszto,Vésztő', 46.9166700, 21.2666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65292, 'Verpelét', 'Verpelet', '', 47.8500000, 20.2333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65293, 'Vásárosnamény', 'Vasarosnameny', 'Vasarosnameny,Vásárosnamény', 48.1254200, 22.3132500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65294, 'Vámospércs', 'Vamospercs', 'Vamospercs,Vámospércs', 47.5333300, 21.9000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65295, 'Vaja', 'Vaja', 'Vaja', 48.0057400, 22.1676100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65296, 'Újszász', 'Ujszasz', 'Ujszasz,Újszász', 47.3000000, 20.0833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65297, 'Újkígyós', 'Ujkigyos', 'Ujkigyos,Újkígyós', 46.5833300, 21.0333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65298, 'Újfehértó', 'Ujfeherto', 'Uj Fejerto,Ujfeherto,Új Fejertó,Újfehértó', 47.8000000, 21.6833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65299, 'Tyukod', 'Tyukod', 'Tyukod', 47.8537800, 22.5633000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65300, 'Tuzsér', 'Tuzser', 'Tuzser,Tuzsér', 48.3440700, 22.1176200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65301, 'Túrkeve', 'Turkeve', 'Turkeve,Túrkeve', 47.1000000, 20.7500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65302, 'Tunyogmatolcs', 'Tunyogmatolcs', 'Matolcs,Tunyog,Tunyogmatolcs', 47.9666700, 22.4666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65303, 'Tótkomlós', 'Totkomlos', 'Kistanyadulo,Kistanyadůlő,Nagykopancs,Nagykopáncs,Totkmolos,Totkomlos,Tótkmolós,Tótkomlós', 46.4166700, 20.7333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65304, 'Tószeg', 'Toszeg', 'Toszeg,Tószeg', 47.1000000, 20.1500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65305, 'Törökszentmiklós', 'Torokszentmiklos', 'Toroksentmiklosh,Torokszenimiklos,Torokszentmiklos,Törökszenimiklós,Törökszentmiklós,Тороксентмиклош', 47.1833300, 20.4166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65306, 'Tornyospálca', 'Tornyospalca', 'Tornyospalca,Tornyospálca', 48.2666700, 22.1833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65307, 'Tömörkény', 'Tomorkeny', 'Tomorkeny,Tömörkény', 46.6171600, 20.0435700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65308, 'Tolcsva', 'Tolcsva', 'Tolcsva', 48.2833300, 21.4500000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65309, 'Tokaj', 'Tokaj', 'Tokaj,Токай', 48.1166700, 21.4166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65310, 'Tiszavasvári', 'Tiszavasvari', 'Tiszavasvari,Tiszavasvári', 47.9666700, 21.3500000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65311, 'Tiszaújváros', 'Tiszaujvaros', 'Leninvaros,Leninváros,Tiszaszederken,Tiszaszederkeny,Tiszaszederkény,Tiszaujvaros,Tiszaújváros', 47.9333300, 21.0833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65312, 'Tiszaszentimre', 'Tiszaszentimre', 'Tiszaszentimre', 47.4833300, 20.7333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65313, 'Tiszasüly', 'Tiszasuly', '', 47.3833300, 20.4000000, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65314, 'Tiszaroff', 'Tiszaroff', 'Tiszaroff', 47.4000000, 20.4500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65315, 'Tiszapüspöki', 'Tiszapuspoki', 'Tiszapuspoki,Tiszapüspöki', 47.2166700, 20.3166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65316, 'Tiszanána', 'Tiszanana', '', 47.5666700, 20.5333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65317, 'Tiszanagyfalu', 'Tiszanagyfalu', 'Tiszanagyfalu', 48.1000000, 21.4833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65318, 'Tiszalúc', 'Tiszaluc', 'Tiszaluc,Tiszalucz,Tiszalúc', 48.0377400, 21.0726100, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65319, 'Tiszalök', 'Tiszalok', 'Tiszalok,Tiszalök', 48.0166700, 21.3833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65320, 'Tiszakeszi', 'Tiszakeszi', 'Tiszakeszi', 47.7833300, 21.0000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65321, 'Tiszakécske', 'Tiszakecske', 'O-hecske,Okecie,Okecske,Okeske,Tiszakecske,Tiszakécske,Ujkecske,Ó-hecske,Ókeske,Ókécske,Újkécske', 46.9326100, 20.1034900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65322, 'Tiszakarád', 'Tiszakarad', 'Tiszakarad,Tiszakarád', 48.2000000, 21.7166700, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65323, 'Tiszafüred', 'Tiszafured', 'Tiszafiired,Tiszafured,Tiszafüred,Tiszaszollos,Tiszaszolos,Tiszaszőllős,Tiszaszőlős', 47.6166700, 20.7666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65324, 'Tiszaföldvár', 'Tiszafoldvar', 'Tiszafoldvar,Tiszaföldvár', 46.9833300, 20.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65325, 'Tiszaeszlár', 'Tiszaeszlar', 'Tiszaeszlar,Tiszaeszlár', 48.0500000, 21.4666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65326, 'Tiszadob', 'Tiszadob', 'Tiszadob', 48.0166700, 21.1666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65327, 'Tiszadada', 'Tiszadada', 'Tiszadada', 48.0333300, 21.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65328, 'Tiszacsege', 'Tiszacsege', 'Tiszacsege', 47.7000000, 21.0000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65329, 'Tiszabura', 'Tiszabura', 'Tiszabura', 47.4500000, 20.4666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65330, 'Tiszabő', 'Tiszabo', 'Tiszabo,Tiszabő', 47.3000000, 20.4833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65331, 'Tiszabezdéd', 'Tiszabezded', 'Tiszabezded,Tiszabezdéd', 48.3666700, 22.1500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65332, 'Tiszabercel', 'Tiszabercel', 'Tiszabercel', 48.1500000, 21.6500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65333, 'Téglás', 'Teglas', 'Teglas,Téglás', 47.7166700, 21.6833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65334, 'Tarpa', 'Tarpa', 'Tarpa', 48.1048000, 22.5374400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65335, 'Tarnaörs', 'Tarnaoers', '', 47.5949900, 20.0525400, 'HU', '2010-04-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65336, 'Tarnalelesz', 'Tarnalelesz', '', 48.0500000, 20.1833300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65337, 'Tarcal', 'Tarcal', 'Tarcal', 48.1333300, 21.3500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65338, 'Tállya', 'Tallya', 'Tallya,Tállya', 48.2333300, 21.2333300, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65339, 'Taktaszada', 'Taktaszada', 'Taktaszada', 48.1166700, 21.1833300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65340, 'Taktaharkány', 'Taktaharkany', 'Taktaharkany,Taktaharkány', 48.0833300, 21.1333300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65341, 'Szolnok', 'Szolnok', 'Gorad Sol''nak,Sol''nok,Solnoca,Solnok,Solnokas,Szolnok,shwlnwk,slnwk,solnokeu,sorunoku,suo er nuo ke,swlnwq,Горад Сольнак,Солнок,Сольнок,סולנוק,سلنوک,شولنوک,სოლნოკი,ソルノク,索尔诺克,솔노크', 47.1833300, 20.2000000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65342, 'Szirmabesenyő', 'Szirmabesenyo', 'Szirmabesenyo,Szirmabesenyő', 48.1500000, 20.8000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65343, 'Szilvásvárad', 'Szilvasvarad', '', 48.1000000, 20.4000000, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65344, 'Szikszó', 'Szikszo', 'Szikszo,Szikszó', 48.2000000, 20.9333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65345, 'Szihalom', 'Szihalom', '', 47.7666700, 20.4833300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65346, 'Szerencs', 'Szerencs', 'Ond,Szerencs', 48.1599300, 21.2097000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65347, 'Szentistván', 'Szentistvan', 'Szentistvan,Szentistván', 47.7666700, 20.6666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65348, 'Szentes', 'Szentes', 'Szentes', 46.6583400, 20.2608000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65349, 'Szentes', 'Szentes', 'Szentes', 46.6562700, 20.2720100, 'HU', '2012-12-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65350, 'Szendrő', 'Szendro', 'Szendro,Szendrő', 48.4000000, 20.7333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65351, 'Székkutas', 'Szekkutas', 'Vasarhelykutas,Vásárhelykutas', 46.5000000, 20.5333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65352, 'Szegvár', 'Szegvar', 'Szegvar,Szegvár', 46.5874000, 20.2240800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65353, 'Szeghalom', 'Szeghalom', 'Szeghalom', 47.0333300, 21.1666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65354, 'Szeged', 'Szeged', 'Kiskundorozsma,QZD,Seged,Segedin,Seghedin,Szegedin,Szeghed,Tape,Tápé,skdyn,Сегед,سکدین', 46.2530000, 20.1482400, 'HU', '2016-12-08', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65355, 'Szatymaz', 'Szatymaz', 'Szatymaz', 46.3430600, 20.0402000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65356, 'Szarvas', 'Szarvas', 'Sarvas,Sarvash,Sarvaš,Szarvas,sarwash,Сарваш,صارواش', 46.8666700, 20.5500000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65357, 'Szamosszeg', 'Szamosszeg', 'Szamosszeg', 48.0456100, 22.3658200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65358, 'Szakoly', 'Szakoly', 'Szakoly', 47.7666700, 21.9166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65359, 'Szajol', 'Szajol', 'Szajol', 47.1833300, 20.3000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65360, 'Szabadkígyós', 'Szabadkigyos', 'Okigyos,Szabadkigyos,Szabadkígyós,Ókigyós', 46.6166700, 21.1000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65361, 'Sirok', 'Sirok', 'Sirok', 47.9333300, 20.2000000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65362, 'Sátoraljaújhely', 'Satoraljaujhely', 'Karolyfalva,Károlyfalva,Neustadt am Zeltberg,Nove Mesto Pod Siatrom,Nove Mesto pod Siatrom,Nové Mesto Pod Šiatrom,Nové Mesto pod Šiatrom,Rudabanyacska,Rudabányácska,Satoraijaujhely,Satoraljaujhelj,Satoraljaujhely,Shatoral''jaujkhej,Shatoralaujkhel,Szephalom,Széphalom,Sátoraljaújhely,Ujhely,sha tuo lao er yao wu yi hai yi,shatwrayaywyhy,Újhely,Šatoraljaujhelj,ʼyhl,Шаторальяуйхей,Шатораљаујхељ,איהל,איהעל,שאטוראליאויהיי,شاتورایائویهی,沙托勞爾堯烏伊海伊', 48.3949200, 21.6587100, 'HU', '2017-01-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65363, 'Sárrétudvari', 'Sarretudvari', 'Sarretudvari,Sárrétudvari', 47.2333300, 21.2000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65364, 'Sárospatak', 'Sarospatak', 'Brodroghalasz,Brodroghalász,Sarospatak,Sárospatak,Vegardo,Végardó', 48.3245000, 21.5738300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65365, 'Sarkad', 'Sarkad', 'Sarkad', 46.7500000, 21.3833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65366, 'Sáránd', 'Sarand', 'Sarand,Sáránd', 47.4000000, 21.6333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65367, 'Sándorfalva', 'Sandorfalva', 'Sandorfalva,Sándorfalva', 46.3608700, 20.0988900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65368, 'Sály', 'Saly', 'Saly,Sály', 47.9500000, 20.6666700, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65369, 'Sajóvámos', 'Sajovamos', 'Sajovamos,Sajóvámos', 48.1817100, 20.8314900, 'HU', '2014-10-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65370, 'Sajószöged', 'Sajoszoged', 'Sajoszoged,Sajószöged', 47.9500000, 21.0000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65371, 'Sajószentpéter', 'Sajoszentpeter', 'Sajoszentpeter,Sajószentpéter', 48.2166700, 20.7166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65372, 'Sajóörös', 'Sajooeroes', 'S.oeroes,S.örös', 47.9500000, 21.0333300, 'HU', '2006-08-27', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65373, 'Sajólád', 'Sajolad', 'Sajolad,Sajólád', 48.0500000, 20.9000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65374, 'Sajókaza', 'Sajokaza', 'Sajokaza,Sajókaza', 48.2833300, 20.5833300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65375, 'Sajóbábony', 'Sajobabony', 'Sajobabony,Sajóbábony', 48.1666700, 20.7333300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65376, 'Rudabánya', 'Rudabanya', 'Rudabanya,Rudabánya', 48.3833300, 20.6333300, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65377, 'Röszke', 'Roszke', 'Roske,Roszke,Röske,Röszke', 46.1879600, 20.0337200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65378, 'Ricse', 'Ricse', 'Ricse', 48.3256500, 21.9706900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65379, 'Recsk', 'Recsk', '', 47.9333300, 20.1166700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65380, 'Rákócziújfalu', 'Rakocziujfalu', 'Rakocziujfalu,Rákócziújfalu', 47.0666700, 20.2666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65381, 'Rákóczifalva', 'Rakoczifalva', 'Rakoczifalva,Rákóczifalva', 47.0833300, 20.2333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65382, 'Rakamaz', 'Rakamaz', 'Rakamaz', 48.1237200, 21.4642900, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65383, 'Putnok', 'Putnok', 'Putnok', 48.3000000, 20.4333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65384, 'Pusztaföldvár', 'Pusztafoldvar', 'Pusztafoldvar,Pusztaföldvár', 46.5333300, 20.8000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65385, 'Püspökladány', 'Puspokladany', 'Puspokladany,Püspökladány', 47.3166700, 21.1166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65386, 'Prügy', 'Prugy', 'Prugy,Prügy', 48.0833300, 21.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65387, 'Poroszló', 'Poroszlo', 'Poroszlo,Poroszló', 47.6500000, 20.6666700, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65388, 'Porcsalma', 'Porcsalma', 'Porcsalma', 47.8833300, 22.5666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65389, 'Polgár', 'Polgar', 'Polgar,Polgár', 47.8666700, 21.1166700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65390, 'Pocsaj', 'Pocsaj', 'Pocsaj', 47.2833300, 21.8166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65391, 'Petneháza', 'Petnehaza', 'Petnehaza,Petneháza', 48.0608400, 22.0748500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65392, 'Pétervására', 'Petervasara', 'Petervasara,Pétervására', 48.0166700, 20.1000000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65393, 'Pátroha', 'Patroha', 'Patroha,Pátroha', 48.1666700, 22.0000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65394, 'Parád', 'Parad', 'Parad,Paradohuta,Parád,Parádóhuta', 47.9232300, 20.0297200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65395, 'Ózd', 'Ozd', 'Bolyok,Center,Hodoscsepany,Hodoscsépány,Ozd,Sajovarkony,Sajóvárkony,Susa,Szentsimon,Uraj,azd,ou zi de,Ózd,Озд,אוזד,ازد,歐茲德', 48.2166700, 20.3000000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65396, 'Ostoros', 'Ostoros', '', 47.8666700, 20.4333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65397, 'Orosháza', 'Oroshaza', 'Oroshaza,Oroshazi,Oroshkhaza,Orosháza,Orosházi,Орошхаза', 46.5666700, 20.6666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65398, 'Ópusztaszer', 'Opusztaszer', 'Opusztaszer,Sovenyhaza,Sövényháza,Ópusztaszer', 46.4859200, 20.0872200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65399, 'Ópályi', 'Opalyi', 'Opalyi,Ópályi', 47.9977100, 22.3261700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65400, 'Ónod', 'Onod', 'Onod,Ónod', 48.0000000, 20.9166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65401, 'Onga', 'Onga', 'Onga', 48.1166700, 20.9166700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65402, 'Olaszliszka', 'Olaszliszka', 'Olaszliszka', 48.2500000, 21.4333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65403, 'Ököritófülpös', 'Okoritofulpos', 'Fulpos,Fülpös,Okoritofulpos,Szatmarokorito,Szatmárököritó,Ököritófülpös', 47.9186200, 22.5081000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65404, 'Okány', 'Okany', 'Okany,Okány', 46.9000000, 21.3500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65405, 'Ófehértó', 'Ofeherto', '', 47.9333300, 22.0500000, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65406, 'Öcsöd', 'Ocsod', 'Ocsod,Öcsöd', 46.9000000, 20.4000000, 'HU', '2013-04-04', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65407, 'Nyírvasvári', 'Nyirvasvari', 'Nyirvasvari,Nyírvasvári', 47.8166700, 22.1868300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65408, 'Nyírtelek', 'Nyirtelek', 'Kiralytelekpuszta,Királytelekpuszta,Nyirtelek,Nyírtelek', 48.0166700, 21.6333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65409, 'Nyírtass', 'Nyirtass', 'Nyirtass,Nyírtass', 48.1166700, 22.0333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65410, 'Nyírpazony', 'Nyirpazony', 'Nyirpazony,Nyírpazony', 47.9833300, 21.8000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65411, 'Nyírmihálydi', 'Nyirmihalydi', 'Nyirmihalydi,Nyírmihálydi', 47.7397600, 21.9644500, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65412, 'Nyírmeggyes', 'Nyirmeggyes', 'Nyirmeggyes,Nyírmeggyes', 47.9166700, 22.2666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65413, 'Nyírmártonfalva', 'Nyirmartonfalva', 'Nyirmartonfalva,Nyírmártonfalva', 47.5833300, 21.9000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65414, 'Nyírmada', 'Nyirmada', 'Nyirmada,Nyírmada', 48.0666700, 22.2000000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65415, 'Nyírlugos', 'Nyirlugos', 'Nairlugos,Nyirlugos,Nyírlugos', 47.6931500, 22.0447600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65416, 'Nyírkarász', 'Nyirkarasz', 'Nyirkarasz,Nyírkarász', 48.0947700, 22.1046300, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65417, 'Nyírgyulaj', 'Nyirgyulaj', 'Nyirgyulaj,Nyírgyulaj', 47.8862200, 22.0978100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65418, 'Nyíregyháza', 'Nyiregyhaza', 'Gorad N''irehdz''khaza,N''ired''gaza,N''ired''khaza,Nired''khaza,Niredkhaza,Nireghaza,Njiredhaz,Njireghaza,Njiregkhaza,Njiređhaza,Nyirszollos,Nyirszolos,Nyredhaza,Nyírszőllős,Nyírszőlős,Níreďháza,ni lai ji ha zuo,nilejihajeo,niredhaza,nirejihaza,nyrghhaza,nyrghza,Њиређхаза,Њиреѓхаза,Горад Ньірэдзьхаза,Ниредхаза,Ниредьхаза,Ньиредьхаза,Ньїредьгаза,נירגהאזה,נירעדהאז,نيرغهازا,نیرادہازا,نیرگهزا,ნირედჰაზა,ニーレジハーザ,尼賴吉哈佐,니레지하저', 47.9553900, 21.7167100, 'HU', '2016-12-08', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65419, 'Nyírcsaholy', 'Nyircsaholy', 'Nyircsaholy,Nyírcsaholy', 47.9038300, 22.3363000, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65420, 'Nyírbogdány', 'Nyirbogdany', 'Nyirbogdany,Nyírbogdány', 48.0572300, 21.8824200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65421, 'Nyírbogát', 'Nyirbogat', 'Nyirbogat,Nyirbognt,Nyírbogát', 47.8034000, 22.0656100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65422, 'Nyírbéltek', 'Nyirbeltek', 'Nyirbeltek,Nyirbetek,Nyírbetek,Nyírbéltek', 47.7000000, 22.1333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65423, 'Nyírbátor', 'Nyirbator', 'Nyirbator,Nyírbátor', 47.8333300, 22.1333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65424, 'Nyíradony', 'Nyiradony', 'Nyiradony,Nyíradony', 47.6974600, 21.9187800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65425, 'Nyíracsád', 'Nyiracsad', 'Nyiracsad,Nyíracsád', 47.6033000, 21.9720800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65426, 'Nyírábrány', 'Nyirabrany', 'Nyirabrany,Nyírábrány', 47.5531100, 22.0240100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65427, 'Nyékládháza', 'Nyekladhaza', 'Ladhaza,Ládháza,Malom,Mezonyek,Mezőnyék,Nyekladhaza,Nyékládháza', 47.9833300, 20.8333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65428, 'Napkor', 'Napkor', 'Napkor', 47.9379700, 21.8676300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65429, 'Nagyszénás', 'Nagyszenas', 'Nagyszenas,Nagyszénás', 46.6833300, 20.6666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65430, 'Nagyrábé', 'Nagyrabe', 'Nagyrabe,Nagyrábé', 47.2000000, 21.3333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65431, 'Nagykálló', 'Nagykallo', 'Kiskallo,Kiskálló', 47.8749100, 21.8408200, 'HU', '2008-03-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65432, 'Nagyhalász', 'Nagyhalasz', 'Nagyhalasz,Nagyhalász', 48.1326600, 21.7610400, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65433, 'Nagyecsed', 'Nagyecsed', 'Nagyecsed', 47.8654700, 22.3915900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65434, 'Nagydobos', 'Nagydobos', 'Nagydobos', 48.0575900, 22.3042300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65435, 'Nagycserkesz', 'Nagycserkesz', 'Nagycserkesz', 47.9666700, 21.5333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65436, 'Nádudvar', 'Nadudvar', 'Nadudvar,Nádudvar', 47.4166700, 21.1666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65437, 'Múcsony', 'Mucsony', 'Mucsony,Múcsony', 48.2666700, 20.6833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65438, 'Monostorpályi', 'Monostorpalyi', 'Monostorpalyi,Monostorpályi', 47.4000000, 21.7833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65439, 'Monok', 'Monok', 'Monok,Morok', 48.2110200, 21.1505200, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65440, 'Miskolc', 'Miskolc', 'MCQ,Mishkol''c,Mishkolc,Miskolc,Miskolca,Miskolcas,Miskolcz,Miskole,Miskovec,Miszkolc,Miškolc,Miškolca,Miškolcas,Miškovec,mi shen ke er ci,mishukorutsu,misyukolcheu,mskwls,myshkwlts,mysqwlz,Мишколц,Мишкольц,Мішкольц,מישקולץ,مسکولس,ميشكولتس,میشکولتس,მიშკოლცი,ミシュコルツ,米什科尔茨,미슈콜츠', 48.1000000, 20.7833300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65441, 'Mindszent', 'Mindszent', 'Mindszent', 46.5236200, 20.1903800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65442, 'Mikepércs', 'Mikepercs', 'Mikepercs,Mikepércs', 47.4500000, 21.6333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65443, 'Mezőzombor', 'Mezozombor', 'Mezozombor,Mezőzombor', 48.1500000, 21.2666700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65444, 'Mezőtúr', 'Mezotur', 'Mezoetur,Mezotur,Mezötúr,Mezőtúr', 47.0000000, 20.6333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65445, 'Mezőkövesd', 'Mezokovesd', 'Mezokovesd,Mezőkövesd', 47.8166700, 20.5833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65446, 'Mezőkovácsháza', 'Mezokovacshaza', 'Mezokovacshaza,Mezőkovácsháza,Reformatuskovacshaza,Reformatustovacshaza,Reformátuskovácsháza,Reformátustovácsháza', 46.4000000, 20.9166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65447, 'Mezőkeresztes', 'Mezokeresztes', 'Keresztespuspoki,Keresztespüspöki,Mezokeresztes,Mezőkeresztes', 47.8333300, 20.7000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65448, 'Mezőhegyes', 'Mezohegyes', 'Mezohegyes,Mezőhegyes', 46.3166700, 20.8166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65449, 'Mezőcsát', 'Mezocsat', 'Mezocsat,Mezőcsát', 47.8166700, 20.9166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65450, 'Mezőberény', 'Mezobereny', 'Mezobereny,Mezőberény', 46.8166700, 21.0333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65451, 'Mérk', 'Merk', 'Merk,Mérk', 47.7882400, 22.3803800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65452, 'Méhkerék', 'Mehkerek', 'Mehkerek,Méhkerék', 46.7833300, 21.4500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65453, 'Megyaszó', 'Megyaszo', 'Megyaszo,Megyaszó', 48.1833300, 21.0500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65454, 'Medgyesegyháza', 'Medgyesegyhaza', '', 46.5000000, 21.0333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65455, 'Mátraderecske', 'Matraderecske', '', 47.9500000, 20.0833300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65456, 'Mátészalka', 'Mateszalka', 'Mateszalka,Mátészalka', 47.9552800, 22.3234800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65457, 'Maroslele', 'Maroslele', 'Maroslele,Maroslelle,Puspoklele,Püspöklele', 46.2666700, 20.3500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65458, 'Máriapócs', 'Mariapocs', 'Mariapocs,Máriapócs', 47.8830300, 22.0250100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65459, 'Mándok', 'Mandok', 'Mandok,Mándok', 48.3214900, 22.1910700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65460, 'Mályi', 'Malyi', 'Malyi,Mályi', 48.0166700, 20.8333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65461, 'Makó', 'Mako', 'Macau,Macău,Mako,Makov,Makovo,Makó,makw,mao ke,meoko,Мако,מאקו,מאקעווע,ماکو,毛科,머코', 46.2166700, 20.4833300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65462, 'Maklár', 'Maklar', 'Maklar,Maklartalya,Maklár,Maklártálya', 47.8000000, 20.4166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65463, 'Magyarbánhegyes', 'Magyarbanhegyes', 'Magyarbanhegyes,Magyarbánhegyes', 46.4500000, 20.9666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65464, 'Mád', 'Mad', 'Mad,Mád', 48.1944200, 21.2820800, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65465, 'Lőkösháza', 'Lokoshaza', 'Lokoshaza,Lőkösháza', 46.4333300, 21.2333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65466, 'Levelek', 'Levelek', 'Levelek', 47.9628200, 21.9853700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65467, 'Létavértes', 'Letavertes', 'Letavertes,Létavértes,Nagyleta,Nagyléta,Vertes,Vértes', 47.3833300, 21.9000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65468, 'Kunszentmárton', 'Kunszentmarton', 'Kunszentmarton,Kunszentmárton,Szeleveny,Szelevény', 46.8391600, 20.2887900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65469, 'Kunmadaras', 'Kunmadaras', 'Kunmadaras', 47.4333300, 20.8000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65470, 'Kunhegyes', 'Kunhegyes', 'Kunhegyes', 47.3666700, 20.6333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65471, 'Kunágota', 'Kunagota', 'Kunagota,Kunágota', 46.4333300, 21.0500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65472, 'Kótaj', 'Kotaj', 'Keresztut,Keresztút,Kotaj,Kótaj', 48.0500000, 21.7166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65473, 'Köröstarcsa', 'Korostarcsa', 'Korostarcsa,Köröstarcsa', 46.8833300, 21.0333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65474, 'Körösladány', 'Korosladany', 'Korosladany,Körösladány', 46.9666700, 21.0833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65475, 'Konyár', 'Konyar', 'Konyar,Konyár', 47.3166700, 21.6666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65476, 'Kondoros', 'Kondoros', 'Kondoros', 46.7666700, 20.8000000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65477, 'Kompolt', 'Kompolt', 'Komoplt,Kompolt', 47.7333300, 20.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65478, 'Komádi', 'Komadi', 'Komadi,Komaiti,Komádi,Komāiti', 47.0000000, 21.5000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65479, 'Kocsord', 'Kocsord', 'Kocsord', 47.9391200, 22.3833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65480, 'Kiszombor', 'Kiszombor', 'Kiszombor,Zombor', 46.1833300, 20.4333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65481, 'Kisvárda', 'Kisvarda', 'Kisvarda,Kisvárda', 48.2166700, 22.0833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65482, 'Kisújszállás', 'Kisujszallas', 'Kisujszallas,Kisújszállás', 47.2166700, 20.7666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65483, 'Kisléta', 'Kisleta', 'Kisleta,Kisléta', 47.8424400, 22.0039300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65484, 'Kisköre', 'Kiskore', 'Kiskore,Kisköre', 47.5000000, 20.5000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65485, 'Kevermes', 'Kevermes', 'Kevermes', 46.4166700, 21.1833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65486, 'Kétegyháza', 'Ketegyhaza', 'Ketegyhaza,Kétegyháza', 46.5333300, 21.1833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65487, 'Kerecsend', 'Kerecsend', '', 47.8000000, 20.3500000, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65488, 'Kengyel', 'Kengyel', 'Kengyel,Pusztakengyel', 47.0833300, 20.3333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65489, 'Kenderes', 'Kenderes', 'Kenderes', 47.2500000, 20.6833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65490, 'Kemecse', 'Kemecse', 'Kemecse', 48.0753200, 21.8062500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65491, 'Kék', 'Kek', 'Kek,Kék', 48.1166700, 21.8833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65492, 'Kazincbarcika', 'Kazincbarcika', 'Kazincbarcika,Sajokazinc,Sajókazinc,kao jin ci bao er qi kao,kazyntbartyka,Казинцбарцика,کازینتبارتیکا,考津茨包爾齊考', 48.2500000, 20.6333300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65493, 'Kaszaper', 'Kaszaper', 'Kaszaper', 46.4666700, 20.8333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65494, 'Karcsa', 'Karcsa', 'Karcsa', 48.3113000, 21.8053700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65495, 'Karcag', 'Karcag', 'Karcag,Karcage,Карцаге', 47.3166700, 20.9333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65496, 'Karácsond', 'Karacsond', '', 47.7296200, 20.0307600, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65497, 'Kántorjánosi', 'Kantorjanosi', 'Kantorjanosi,Kántorjánosi', 47.9333300, 22.1500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65498, 'Kálmánháza', 'Kalmanhaza', 'Kalmanhaza,Kálmánháza', 47.8833300, 21.5833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65499, 'Kállósemjén', 'Kallosemjen', 'Kallosemjen,Kállósemjén', 47.8608100, 21.9392900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65500, 'Kál', 'Kal', '', 47.7333300, 20.2666700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65501, 'Kaba', 'Kaba', 'Kaba', 47.3500000, 21.2833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65502, 'Jászszentandrás', 'Jaszszentandras', 'Jaszszentandras,Jászszentandrás', 47.5833300, 20.1833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65503, 'Jászladány', 'Jaszladany', 'Jaszladany,Jászladány', 47.3666700, 20.1666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65504, 'Jászkisér', 'Jaszkiser', 'Jaszkiser,Jászkisér', 47.4500000, 20.2166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65505, 'Jászkarajenő', 'Jaszkarajeno', 'Jaszkarajeno,Jászkarajenő', 47.0500000, 20.0666700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65506, 'Jászjákóhalma', 'Jaszjakohalma', 'Jaszjakohalma,Jászjákóhalma', 47.5203800, 19.9908600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65507, 'Jászdózsa', 'Jaszdozsa', 'Jaszdozsa,Jászdózsa', 47.5661000, 20.0153400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65508, 'Jászapáti', 'Jaszapati', 'Jaszapati,Jászapáti', 47.5166700, 20.1500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65509, 'Jászalsószentgyörgy', 'Jaszalsoszentgyorgy', 'Jaszalsoszentgyorgy,Jászalsószentgyörgy', 47.3666700, 20.1000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65510, 'Járdánháza', 'Jardanhaza', 'Jardanhaza,Járdánháza', 48.1500000, 20.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65511, 'Jánoshida', 'Janoshida', 'Janoshida,Jánoshida', 47.3833300, 20.0666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65512, 'Izsófalva', 'Izsofalva', 'Disznoshorvat,Disznóshorvát,Izsofalva,Izsófalva', 48.3000000, 20.6666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65513, 'Ibrány', 'Ibrany', 'Ibrany,Ibrány', 48.1232900, 21.7095300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65514, 'Hosszúpályi', 'Hosszupalyi', 'Hosszupaly,Hosszúpály', 47.3930300, 21.7328000, 'HU', '2010-04-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65515, 'Hortobágy', 'Hortobagy', '', 47.5827800, 21.1510800, 'HU', '2010-02-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65516, 'Hódmezővásárhely', 'Hodmezovasarhely', 'Chontmezovasarchei,Godmezevashargej,Hodmezevasarhelj,Hodmezevašarhelj,Khodmez''ovasharkhej,Khodmezevasharkhej,Khodmezevasharkhel,Khodmezjovasharkhej,Vasrelj,Vašrelj,hdmzwasharhy,hod me sex wa char he,hodeumejoebasyaleuhei,hodmezevasharhei,hodomezevu~asharuhei,huo de mei ze wa,Χοντμεζοβάσαρχεϊ,Годмезевашаргей,Ходмезевашархей,Ходмезевашархељ,Ходмезьовашархей,Ходмезёвашархей,هدمزواشارهی,ہودمیزواسرہیلی,โฮดเมเซอวาชาร์เฮ,ჰოდმეზევაშარჰეი,ホードメゼーヴァーシャールヘイ,霍德梅澤瓦,호드메죄바샤르헤이', 46.4166700, 20.3333300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65517, 'Hodász', 'Hodasz', 'Hodasz,Hodász', 47.9183400, 22.2015300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65518, 'Heves', 'Heves', 'Heves', 47.6000000, 20.2833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65519, 'Hernádnémeti', 'Hernadnemeti', 'Hernadnemeti,Hernádnémeti', 48.0666700, 20.9833300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65520, 'Hejőbába', 'Hejobaba', 'Hejobaba,Hejőbába', 47.9000000, 20.9500000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65521, 'Harsány', 'Harsany', 'Harsany,Harsány', 47.9666700, 20.7500000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65522, 'Halmaj', 'Halmaj', 'Halmaj', 48.2500000, 21.0000000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65523, 'Hajdúszovát', 'Hajduszovat', 'Hajduszovat,Hajdúszovát', 47.3833300, 21.4833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65524, 'Hajdúszoboszló', 'Hajduszoboszlo', 'Hajduszoboszlo,Hajdúszoboszló,Khajdusoboslo,Хайдусобосло', 47.4500000, 21.4000000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65525, 'Hajdúsámson', 'Hajdusamson', 'Hajdusamson,Hajdúsámson', 47.6000000, 21.7666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65526, 'Hajdúnánás', 'Hajdunanas', 'Hajdunanas,Hajdúnánás', 47.8500000, 21.4333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65527, 'Hajdúhadház', 'Hajduhadhaz', 'Hajduhadhaz,Hajdúhadház', 47.6833300, 21.6666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65528, 'Hajdúdorog', 'Hajdudorog', 'Hajdudorog,Hajdúdorog', 47.8166700, 21.5000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65529, 'Hajdúböszörmény', 'Hajduboszormeny', 'Hajduboszormeny,Hajdúböszörmény', 47.6666700, 21.5166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65530, 'Hajdúbagos', 'Hajdubagos', '', 47.3929500, 21.6655100, 'HU', '2010-04-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65531, 'Gyulaháza', 'Gyulahaza', 'Gyulahaza,Gyulaháza', 48.1333300, 22.1166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65532, 'Gyula', 'Gyula', 'D''jula,GJula,Gyula,Gyulavari,Gyulavári,dwla,jiu luo,julleo,Đula,Ђула,Дьюла,دولا,久洛,줄러', 46.6500000, 21.2833300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65533, 'Gyomaendrőd', 'Gyomaendrod', 'Endrod,Endrőd,Gyoma,Gyomaendrod,Gyomaendrőd', 46.9333300, 20.8333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65534, 'Görbeháza', 'Gorbehaza', 'Gorbehaza,Gorbehazapuszta,Görbeháza,Görbeházapuszta', 47.8333300, 21.2333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65535, 'Gönc', 'Gonc', 'Gonc,Gönc', 48.4666700, 21.2833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65536, 'Gesztely', 'Gesztely', 'Gesztely', 48.1000000, 20.9666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65537, 'Gégény', 'Gegeny', 'Gegeny,Gégény', 48.1500000, 21.9500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65538, 'Gádoros', 'Gadoros', 'Gadoros,Gádoros', 46.6666700, 20.6000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65539, 'Füzesgyarmat', 'Fuzesgyarmat', 'Fuzesgyarmat,Füzesgyarmat', 47.1000000, 21.2166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65540, 'Füzesabony', 'Fuzesabony', 'Fuzesabony,Füzesabony', 47.7500000, 20.4166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65541, 'Földes', 'Foldes', 'Foldes,Földes', 47.3000000, 21.3666700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65542, 'Földeák', 'Foldeak', 'Foldeak,Földeák', 46.3166700, 20.5000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65543, 'Fényeslitke', 'Fenyeslitke', 'Fenyeslitke,Fényeslitke', 48.2713300, 22.1000900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65544, 'Felsőzsolca', 'Felsozsolca', 'Felsozsolca,Felsőzsolca', 48.1000000, 20.8666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65545, 'Felsőtárkány', 'Felsotarkany', 'Felsotarkany,Felsőtárkány', 47.9666700, 20.4166700, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65546, 'Fehérgyarmat', 'Fehergyarmat', 'Fehergyarmat,Fehérgyarmat', 47.9833300, 22.5166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65547, 'Fegyvernek', 'Fegyvernek', 'Fegyvernek', 47.2666700, 20.5333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65548, 'Farkaslyuk', 'Farkaslyuk', 'Farkaslyuk Banyatelep,Farkaslyuk Bányatelep,Farkaslyuki Banyatelep,Farkaslyuki Bányatelep', 48.1833300, 20.3166700, 'HU', '2007-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65549, 'Fábiánsebestyén', 'Fabiansebestyen', 'Fabiansebestyen,Fábiánsebestyén', 46.6833300, 20.4666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65550, 'Erdőtelek', 'Erdotelek', '', 47.6833300, 20.3166700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65551, 'Encsencs', 'Encsencs', 'Encsencs', 47.7333300, 22.1166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65552, 'Encs', 'Encs', 'Abaujdevecser,Abaújdevecser,Ehnch,Ench,Encs,Fugod,Fügöd,Gibart,Gibárt,en qi,Енч,Энч,恩奇', 48.3333300, 21.1333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65553, 'Emőd', 'Emod', 'Emod,Emőd', 47.9333300, 20.8166700, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65554, 'Elek', 'Elek', 'Elek', 46.5333300, 21.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65555, 'Egyek', 'Egyek', '', 47.6333300, 20.9000000, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65556, 'Egerszalók', 'Egerszalok', 'Egerszalok,Egerszalók', 47.8666700, 20.3333300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65557, 'Eger', 'Eger', 'Agria,Eger,Egera,Egeris,Egra,Egri,Ehger,Erlau,Eğri,Gorad Ehger,Jager,Jegra,Jáger,Szarvasko,Szarvaskő,agr,ai ge er,aygyr,egeleu,egeri,egeru,Јегра,Горад Эгер,Егер,Еґер,Эгер,אגר,ערלוי,اگر,ایگیر,ეგერი,エゲル,埃格爾,에게르', 47.9026500, 20.3732900, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65558, 'Edelény', 'Edeleny', 'Balajt,Edeleny,Edelény,Ladbesenyo,Ládbesenyő', 48.3000000, 20.7333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65559, 'Ebes', 'Ebes', 'Ebes', 47.4666700, 21.5000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65560, 'Domoszló', 'Domoszlo', '', 47.8333300, 20.1166700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65561, 'Dombrád', 'Dombrad', 'Dombrad,Dombrád', 48.2333300, 21.9333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65562, 'Dombegyház', 'Dombegyhaz', 'Dombegyhaz,Dombegyház', 46.3333300, 21.1333300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65563, 'Domaszék', 'Domaszek', 'Domaszek,Domaszék', 46.2491700, 20.0111100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65564, 'Döge', 'Doge', 'Doge,Döge', 48.2624600, 22.0633900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65565, 'Doboz', 'Doboz', 'Doboz', 46.7333300, 21.2500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65566, 'Dévaványa', 'Devavanya', 'Devavanya,Dévaványa', 47.0333300, 20.9666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65567, 'Deszk', 'Deszk', 'Deska,Deszk,Deszka', 46.2180200, 20.2432200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65568, 'Derecske', 'Derecske', 'Derecske', 47.3500000, 21.5666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65569, 'Demecser', 'Demecser', 'Demecser', 48.1164800, 21.9262400, 'HU', '2013-01-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65570, 'Debrecen', 'Debrecen', 'DEB,Debrecen,Debrecena,Debrecenas,Debrecin,Debrecinum,Debreczyn,Debrecín,Debretin,Debrețin,Ntempretsen,dbrsn,dbrtsn,dbrzn,de bu lei sen,debeulechen,debretseni,deburetsu~en,dybrysyn,Ντέμπρετσεν,Дебрецен,Дебрецин,Դեբրեցեն,דברצן,دبرتسن,دبرسن,دیبریسین,დებრეცენი,デブレツェン,德布勒森,데브레첸', 47.5333300, 21.6333300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65571, 'Csorvás', 'Csorvas', 'Csorvas,Csorvás', 46.6333300, 20.8333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65572, 'Csongrád', 'Csongrad', 'Csongrad,Csongrád', 46.7133200, 20.1424100, 'HU', '2015-07-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65573, 'Csökmő', 'Csokmo', 'Csokmo,Csökmő', 47.0333300, 21.3000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65574, 'Cserkeszőlő', 'Cserkeszolo', 'Cserkeszollo,Cserkeszolo,Cserkeszőllő,Cserkeszőlő', 46.8632000, 20.1870100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65575, 'Csenger', 'Csenger', 'Csenger', 47.8358200, 22.6809600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65576, 'Csanytelek', 'Csanytelek', 'Csanytelek', 46.5950100, 20.1234200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65577, 'Csanádpalota', 'Csanadpalota', 'Csanadpalota,Csanádpalota', 46.2500000, 20.7333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65578, 'Csanádapáca', 'Csanadapaca', 'Csanadapaca,Csanádapáca', 46.5500000, 20.8833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65579, 'Cigánd', 'Cigand', 'Cigand,Cigánd', 48.2556100, 21.8919500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65580, 'Cibakháza', 'Cibakhaza', 'Cibakhaza,Cibakháza', 46.9597600, 20.1975300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65581, 'Buj', 'Buj', 'Buj', 48.1000000, 21.6500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65582, 'Bucsa', 'Bucsa', 'Bucsa', 47.2000000, 21.0000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65583, 'Borsodnádasd', 'Borsodnadasd', 'Borsodnadasd,Borsodnádasd', 48.1166700, 20.2500000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65584, 'Boldva', 'Boldva', 'Boldva', 48.2166700, 20.8000000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65585, 'Bököny', 'Bokony', 'Bokony,Bököny', 47.7333300, 21.7500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65586, 'Bogács', 'Bogacs', 'Bogacs,Bogács', 47.9000000, 20.5333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65587, 'Bőcs', 'Bocs', 'Bocs,Bőcs', 48.0500000, 20.9666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65588, 'Biharnagybajom', 'Biharnagybajom', 'Biharnagybajom', 47.2166700, 21.2333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65589, 'Biharkeresztes', 'Biharkeresztes', 'Biharkeresztes', 47.1333300, 21.7166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65590, 'Besenyszög', 'Besenyszog', 'Besenyszog,Besenyszög', 47.3000000, 20.2666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65591, 'Besenyőtelek', 'Besenyotelek', '', 47.7000000, 20.4333300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65592, 'Berettyóújfalu', 'Berettyoujfalu', 'Berettyoujfalu,Berettyóújfalu', 47.2166700, 21.5500000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65593, 'Bélapátfalva', 'Belapatfalva', 'Belapatfalva,Bélapátfalva', 48.0500000, 20.3666700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65594, 'Békésszentandrás', 'Bekesszentandras', 'Bekesszentadras,Bekesszentandras,Békésszentadrás,Békésszentandrás', 46.8666700, 20.4833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65595, 'Békéssámson', 'Bekessamson', 'Bekessamson,Békéssámson', 46.4166700, 20.6333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65596, 'Békéscsaba', 'Bekescsaba', 'Bekescab,Bekescaba,Bekescsaba,Bekeshchaba,Bekesska Caba,Bekeščab,Bekeščaba,Bichisciaba,Bichișciaba,Békešská Čaba,Békéscsaba,Gerla,Mezomegyer,Mezőmegyer,Nagymajor,bei kai shen qiao bao,bekeshuchaba,bekesyucheobeo,bykyschaba,bykyshchaba,Бекешчаба,בקשצאבה,بیکیسچابا,بیکیشچابا,ბეკეშჩაბა,ベーケーシュチャバ,貝凱什喬包,베케슈처버', 46.6833300, 21.1000000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65597, 'Békés', 'Bekes', 'Bekes,Bekes megye,Bekesh,Békés,Békés megye,Comitatul Bekes,Comitatul Békés,Бекеш', 46.7666700, 21.1333300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65598, 'Bekecs', 'Bekecs', 'Bekecs', 48.1500000, 21.1833300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65599, 'Battonya', 'Battonya', 'Battonya', 46.2833300, 21.0166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65600, 'Báránd', 'Barand', 'Barand,Báránd', 47.3000000, 21.2333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65601, 'Balmazújváros', 'Balmazujvaros', 'Balmazujvaros,Balmazújváros', 47.6166700, 21.3500000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65602, 'Balkány', 'Balkany', '', 47.7706600, 21.8631400, 'HU', '2008-03-26', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65603, 'Balástya', 'Balastya', 'Balastya,Balástya,Felsokozpont,Felsőközpont', 46.4227700, 20.0081600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65604, 'Baktalórántháza', 'Baktaloranthaza', 'Baktaloranthaza,Baktalórántháza', 48.0000000, 22.0833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65605, 'Baks', 'Baks', 'Baks,Baksi-major,Baksiret,Baksirét', 46.5429700, 20.1021300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65606, 'Bagamér', 'Bagamer', 'Bagamer,Bagamér', 47.4488200, 21.9890000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65607, 'Aszaló', 'Aszalo', 'Aszalo,Aszaló', 48.2166700, 20.9666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65608, 'Arnót', 'Arnot', '', 48.1305800, 20.8583200, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65609, 'Arló', 'Arlo', 'Arlo,Arló', 48.1833300, 20.2666700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65610, 'Aranyosapáti', 'Aranyosapati', 'Aranyosapati,Aranyosapáti,Kopocsapati,Kopócsapáti,Revaranyos,Révaranyos', 48.2059500, 22.2591600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65611, 'Apátfalva', 'Apatfalva', '', 46.1666700, 20.5833300, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65612, 'Apagy', 'Apagy', 'Apagy', 47.9643100, 21.9353900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65613, 'Andornaktálya', 'Andornaktalya', '', 47.8500000, 20.4166700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65614, 'Anarcs', 'Anarcs', 'Anarcs', 48.1764200, 22.1116700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65615, 'Alsózsolca', 'Alsozsolca', '', 48.0698200, 20.8804600, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65616, 'Alattyán', 'Alattyan', 'Alattyan,Alattyán', 47.4270500, 20.0421900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65617, 'Ajak', 'Ajak', 'Ajak', 48.1766400, 22.0627300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65618, 'Abony', 'Abony', 'Abony', 47.1899000, 20.0047600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65619, 'Abaújszántó', 'Abaujszanto', 'Abaujsanto,Abaujszanto,Abaújszántó,Gorad Abaujsanta,ao bao wu yi sang tuo,Абауйсанто,Горад Абаўйсанта,اباوج‌س‌زانتا,奥包乌伊桑托', 48.2833300, 21.2000000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65620, 'Abasár', 'Abasar', 'Abasar,Abasár,Palosvorosmart,Pálosvörösmart', 47.7970500, 20.0032400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65621, 'Abádszalók', 'Abadszalok', 'Abadszalok,Abádszalók', 47.4666700, 20.6000000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65622, 'Zsombó', 'Zsombo', 'Zsombo,Zsombó', 46.3256600, 19.9746400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65623, 'Zsámbok', 'Zsambok', 'Zsambok,Zsámbok', 47.5438100, 19.6104800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65624, 'Zsámbék', 'Zsambek', 'Zsambek,Zsámbék', 47.5481400, 18.7201100, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65625, 'Zomba', 'Zomba', 'Zomba', 46.4108400, 18.5657700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65626, 'Zirc', 'Zirc', '', 47.2636200, 17.8737300, 'HU', '2007-06-13', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65627, 'Zánka', 'Zanka', 'Zanka,Zánka', 46.8714600, 17.6847300, 'HU', '2012-03-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65628, 'Zámoly', 'Zamoly', 'Zamoly,Zámoly', 47.3166700, 18.4081000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65629, 'Zamárdi', 'Zamardi', 'Balatonzamardi,Balatonzamárdi,Zamardi,Zamárdi', 46.8848800, 17.9536600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65630, 'Zalaszentgrót', 'Zalaszentgrot', 'Csaford,Csáford,Tekenye,Zalakoppany,Zalakoppány,Zalaszentgrot,Zalaszentgrót,Zalaudvarnok', 46.9447400, 17.0792500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65631, 'Zalalövő', 'Zalalovo', 'Zalalovo,Zalalövő', 46.8480200, 16.5875000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65632, 'Zalakomár', 'Zalakomar', 'Zalakomar,Zalakomár', 46.5379500, 17.1809400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65633, 'Zalaegerszeg', 'Zalaegerszeg', 'Jegersek,Zalaederseg,Zalaegerseg,Zalaegersegas,Zalaegerszeg,Zalaegerszegium,Zalaehgerseg,jeolleoegeleusegeu,zalaegersegi,zalaygrsg,zalaygyrshyg,zaraegerusegu,zuo luo ai ge sai ge,Залаегерсег,Залаеґерсеґ,Залаэгерсег,זאלאגרסג,زالائگرسگ,زالائگیرشیگ,ზალაეგერსეგი,ザラエゲルセグ,佐洛埃格塞格,절러에게르세그', 46.8400000, 16.8438900, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65634, 'Zákányszék', 'Zakanyszek', 'Szegi Tanya,Zakanyszek,Zákányszék', 46.2745300, 19.8897500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65635, 'Zagyvaszántó', 'Zagyvaszanto', '', 47.7770300, 19.6709200, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65636, 'Vonyarcvashegy', 'Vonyarcvashegy', 'Vonyarcvashegy', 46.7574200, 17.3117200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65637, 'Visegrád', 'Visegrad', 'Gorad Vishehgrad,Visegrad,Visegradas,Visegrád,Vishegrad,Vişegrad,Višegrad,Višegradas,Vysehrad,Vyšehrad,Wyszehrad,bisyegeuladeu,vishegradi,vu~ishegurado,waysgrad,wei xie ge la de,wysgrd,Вишеград,Горад Вішэград,וישגרד,وایسگراد,ვიშეგრადი,ヴィシェグラード,維謝格拉德,비셰그라드', 47.7852600, 18.9709000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65638, 'Villány', 'Villany', 'Villany,Villány', 45.8688900, 18.4538900, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65639, 'Veszprém', 'Veszprem', 'Comitatul Veszprem,Comitatul Veszprém,Gyulafiratot,Gyulafirátót,Kadarta,Kádárta,Vesprem,Vespremas,Vesprim,Vesprimia,Vesprém,Vesprėmas,Vessprem,Vessprém,Veszprem,Veszprem megye,Veszprim,Veszprém,Veszprém megye,Wesprim,ZFP,beseupeulem,vu~esupuremu,wei si pu lei mu,wei si pu lei mu zhou,wshprym,wsprm,wsprym,Веспрем,וספרם,وسپریم,وشپریم,ვესპრემი,ヴェスプレーム,維斯普雷姆,維斯普雷姆州,베스프렘', 47.0932700, 17.9114900, 'HU', '2015-11-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65640, 'Vértesszőlős', 'Vertesszolos', 'Vertesszollos,Vertesszolos,Vértesszőllős,Vértesszőlős', 47.6210600, 18.3813000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65641, 'Verőce', 'Veroce', 'Nogradveroce,Nógrádverőce', 47.8246800, 19.0348400, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65642, 'Veresegyház', 'Veresegyhaz', 'Veresegyhaz,Veresegyház', 47.6459000, 19.2953600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65643, 'Vép', 'Vep', 'Weltendorf,Wettendorf', 47.2304100, 16.7224800, 'HU', '2008-07-03', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65644, 'Velence', 'Velence', 'Velence', 47.2385500, 18.6548400, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65645, 'Vecsés', 'Vecses', 'Vecses,Vecsés', 47.4070500, 19.2864800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65646, 'Vasvár', 'Vasvar', 'Eisenburg,Kismakfa,Kismákfa,Nagymakfa,Nagymákfa', 47.0492800, 16.7995400, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65647, 'Vaskút', 'Vaskut', 'Vaskut,Vaskút', 46.1078200, 18.9851400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65648, 'Várpalota', 'Varpalota', 'Varpalota,Várpalota', 47.1993600, 18.1395400, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65649, 'Városföld', 'Varosfoeld', '', 46.8167400, 19.7566800, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65650, 'Vámosgyörk', 'Vamosgyork', 'Vamosgyork,Vámosgyörk', 47.6842900, 19.9292400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65651, 'Valkó', 'Valko', 'Valko,Valkó', 47.5639100, 19.5126700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65652, 'Vál', 'Val', 'Val,Vál', 47.3626400, 18.6793100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65653, 'Vajszló', 'Vajszlo', 'Vajszlo,Vajszló', 45.8595700, 17.9840600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65654, 'Vácszentlászló', 'Vacszentlaszlo', 'Vacszentlaszlo,Vácszentlászló', 47.5740000, 19.5377100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65655, 'Vác', 'Vac', 'Vac,Vacas,Vacov,Vacz,Vác,Vácz,Waitzen,fak,vu~achi,wa ci,wats,Вац,فاك,واتس,ヴァーチ,瓦茨', 47.7759100, 19.1361200, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65656, 'Üröm', 'Urom', 'Urom,Üröm', 47.5967400, 19.0158300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65657, 'Úrkút', 'Urkut', 'Urkut,Úrkút', 47.0850500, 17.6439300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65658, 'Úri', 'Uri', 'Uri,Úri', 47.4142900, 19.5276200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65659, 'Üllő', 'Ullo', 'Ullo,Üllő', 47.3877100, 19.3553300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65660, 'Üllés', 'Ulles', 'Arpad,Ulles,Árpád,Üllés', 46.3361100, 19.8445400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65661, 'Újszilvás', 'Ujszilvas', 'Uj-major,Ujszilvas,Új-major,Újszilvás', 47.2747700, 19.9247700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65662, 'Újhartyán', 'Ujhartyan', 'Ujhartyan,Újhartyán', 47.2198100, 19.3863800, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65663, 'Türje', 'Turje', 'Turje,Türje', 46.9836600, 17.1074200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65664, 'Tura', 'Tura', 'Tura', 47.6092400, 19.6027900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65665, 'Törtel', 'Tortel', 'Tortel,Törtel', 47.1220900, 19.9371400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65666, 'Törökbálint', 'Toeroekbalint', 'Grossturwall,Großturwall,Toeroek-balint,Török-bálint', 47.4293100, 18.9135600, 'HU', '2010-05-25', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65667, 'Tompa', 'Tompa', 'Tompa', 46.2060500, 19.5391000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65668, 'Töltéstava', 'Toltestava', 'Toltestava,Töltéstava', 47.6260900, 17.7337600, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65669, 'Tolna', 'Tolna', 'Tolma,Tolna', 46.4267700, 18.7824800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65670, 'Tököl', 'Toekoel', '', 47.3217800, 18.9624900, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65671, 'Tokod', 'Tokod', 'Tokod', 47.7227700, 18.6588900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65672, 'Tóalmás', 'Toalmas', 'Toalmas,Tóalmás', 47.5078200, 19.6665700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65673, 'Tihany', 'Tihany', 'Tihany,Tikhan'',di hao ni,Тихань,טיהאן,蒂豪尼', 46.9136900, 17.8891800, 'HU', '2012-12-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65674, 'Tét', 'Tet', 'Tet,Tét', 47.5192200, 17.5080200, 'HU', '2014-10-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65675, 'Tengelic', 'Tengelic', 'Tengelic', 46.5287800, 18.7111700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65676, 'Telki', 'Telki', 'Telki', 47.5479100, 18.8281600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65677, 'Tázlár', 'Tazlar', 'Pronayfalva,Prónayfalva,Tazlar,Tázlár', 46.5482400, 19.5143600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65678, 'Tatabánya', 'Tatabanya', 'Tataban''ja,Tatabana,Tatabania,Tatabanj,Tatabanja,Tatabanya,Tatabánya,tao tao ba ni ao,tatabanya,teoteobanyeo,Татабанья,Татабаня,Татабања,טאטאבניה,تاتابانیا,ტატაბანია,タタバーニャ,陶陶巴尼奧,터터바녀', 47.5849400, 18.3932500, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65679, 'Tata', 'Tata', 'Agostyan,Tata,Tatatovaros,Tatatóváros,tao tao,tata,teoteo,tth,Ágostyán,Тата,טטה,تاتا,タタ,陶陶,터터', 47.6528900, 18.3183800, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65680, 'Tát', 'Tat', 'Tat,Tát', 47.7414800, 18.6481300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65681, 'Taszár', 'Taszar', 'TZR,Tasar,Taszar,Taszár,Tazar,Тасар', 46.3746700, 17.9059400, 'HU', '2017-07-26', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65682, 'Tass', 'Tass', 'Tass', 47.0209500, 19.0298800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65683, 'Tárnok', 'Tarnok', 'Tarnok,Tárnok', 47.3732700, 18.8457900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65684, 'Tarján', 'Tarjan', 'Tarjan,Tarján', 47.6104200, 18.5107000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65685, 'Tardos', 'Tardos', 'Tardosbanya,Tardosbánya', 47.6619200, 18.4441600, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65686, 'Tar', 'Tar', 'Tar', 47.9537100, 19.7461000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65687, 'Tapolca', 'Tapolca', 'Tapolca,Tapolcza,Tapolezai', 46.8815200, 17.4411700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65688, 'Táplánszentkereszt', 'Taplanszentkereszt', '', 47.1949600, 16.6961300, 'HU', '2008-07-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65689, 'Tápiószőlős', 'Tapioszolos', 'Halesz,Tapiohalesz,Tapioszollos,Tapioszolos,Tápióhalesz,Tápiószőllős,Tápiószőlős', 47.3024800, 19.8513300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65690, 'Tápiószentmárton', 'Tapioszentmarton', 'Tapioszentmarton,Tápiószentmárton', 47.3399000, 19.7464800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65691, 'Tápiószele', 'Tapioszele', 'Tapioszele,Tápiószele', 47.3360900, 19.8772400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65692, 'Tápiószecső', 'Tapioszecso', 'Tapioszecso,Tápiószecső', 47.4500000, 19.6092300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65693, 'Sülysáp', 'Suelysap', 'Suelysap,Sülysáp,Tapiosap,Tapiosuely,Tápiósáp,Tápiósüly', 47.4520600, 19.5336900, 'HU', '2012-04-29', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65694, 'Tápióság', 'Tapiosag', 'Tapiosag,Tápióság', 47.4020000, 19.6304700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65695, 'Tápiógyörgye', 'Tapiogyorgye', 'Tapiogyorgye,Tápiógyörgye', 47.3350500, 19.9527600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65696, 'Tápióbicske', 'Tapiobicske', 'Tapiobicske,Tápióbicske', 47.3609600, 19.6860900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65697, 'Tamási', 'Tamasi', 'Pari,Pári,Tamasi,Tamási', 46.6333300, 18.2833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65698, 'Taksony', 'Taksony', 'Taksony', 47.3296800, 19.0669500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65699, 'Tahitótfalu', 'Tahitotfalu', '', 47.7500000, 19.1000000, 'HU', '2006-10-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65700, 'Táborfalva', 'Taborfalva', 'Lotertabor,Lőtértábor,Taborfalva,Táborfalva', 47.0994200, 19.4783700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65701, 'Tab', 'Tab', 'Tab', 46.7313500, 18.0320100, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65702, 'Szurdokpüspöki', 'Szurdokpuspoki', '', 47.8592300, 19.6921800, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65703, 'Szomód', 'Szomod', 'Szomod,Szomód', 47.6849200, 18.3406100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65704, 'Szombathely', 'Szombathely', 'Gorad Sombatkhej,Gyongyosherman,Gyöngyöshermán,Hereny,Herény,Kamon,Kámon,Olad,Perint,Sabaria,Sambotel,Savaria,Sombatgej,Sombathejus,Sombathel,Sombathelj,Sombathėjus,Sombatkhej,Sombatkhel,Sombotel,Steinamanger,Szentkiraly,Szentkirály,Szombatehly,Szombathely,Szombatnely,ZBX,Zanat,smbathy,som bxt he,sombeoteuhei,sonbatohei,song bo te hai yi,swmbthy,Горад Сомбатхей,Сомбатгей,Сомбатхей,Сомбатхељ,סומבטהי,سمباتهی,شامباتہیلی,โซมบอตเฮ,სომბატჰეი,ソンバトヘイ,松博特海伊,솜버트헤이', 47.2308800, 16.6215500, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65705, 'Sződliget', 'Szodliget', 'Szodliget,Sződliget', 47.7325900, 19.1474900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65706, 'Sződ', 'Szod', 'Szod,Sződ', 47.7243900, 19.1704600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65707, 'Szob', 'Szob', 'Szob', 47.8192100, 18.8702000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65708, 'Szigetvár', 'Szigetvar', 'Siget,Sigethum,Sigetvar,Szigetvar,Szigetvár,Zigetvar,sygtwar,syktwar,xi gai te bao,Сигет,Сигетвар,سيكتوار,سیگتوار,錫蓋特堡', 46.0486500, 17.8055400, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65709, 'Szigetújfalu', 'Szigetujfalu', 'Szigetujfalu,Szigetújfalu', 47.2341700, 18.9274600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65710, 'Szigetszentmiklós', 'Szigetszentmiklos', 'Sigetsentmiklosh,Szigentmiklos,Szigetsentmiklos,Szigetszentmiklos,Szigetszentmiklós,Сигетсентмиклош', 47.3438200, 19.0433500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65711, 'Szigethalom', 'Szigethalom', 'Horthyliget,Szigethalom,Szilagyitelep,Szilágyitelep', 47.3222800, 19.0026200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65712, 'Szigetcsép', 'Szigetcsep', 'Szigetcsep,Szigetcsép', 47.2649200, 18.9704800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65713, 'Szentmártonkáta', 'Szentmartonkata', 'Szentmartonkata,Szentmártonkáta', 47.4541900, 19.7014300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65714, 'Szentlőrinckáta', 'Szentlorinckata', 'Szentlorinckata,Szentlőrinckáta', 47.5194700, 19.7528600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65715, 'Szentlőrinc', 'Szentlorinc', 'Szentlorinc,Szentlőrinc', 46.0401600, 17.9871900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65716, 'Szentkirályszabadja', 'Szentkiralyszabadja', 'Szentkiralyszabadja,Szentkirályszabadja', 47.0576000, 17.9705200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65717, 'Szentkirály', 'Szentkiraly', 'Laszlofalva,Lászlófalva,Nep Iskola,Nép Iskola,Szentkiraly,Szentkirály', 46.9189200, 19.9184600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65718, 'Szentgotthárd', 'Szentgotthard', 'Farkasfa,Jakabhaza,Jakabháza,Mariaujfalu,Máriaújfalu,Rabafuzes,Rabakethely,Rabakisfalud,Rabatotfalu,Rábafüzes,Rábakethely,Rábakisfalud,Rábatótfalu,Sankt Gotthard,Talapatka,Zsida', 46.9526100, 16.2735800, 'HU', '2008-11-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65719, 'Szentgálpuszta', 'Szentgalpuszta', 'Szentgal,Szentgalpuszta,Szentgál,Szentgálpuszta', 46.3747900, 18.6260100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65720, 'Szentendre', 'Szentendre', 'Senandrija,Sentandreja,Sentendre,Svaety Ondrej,Svätý Ondrej,Szentendre,sentendore,sheng an de lie,sntndrh,Сентандреја,Сентендре,סנטאנדרה,سنتندره,センテンドレ,圣安德烈', 47.6694300, 19.0756100, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65721, 'Szekszárd', 'Szekszard', 'Gorad Seksard,Seksar,Seksard,Seksardas,Szekszard,Szekszárd,sai ke sa de,segsaleudeu,sekusarudo,shykshard,sksard,Горад Сексард,Сексард,סקסארד,سکسارد,شیکشارد,セクサールド,塞克薩德,섹사르드', 46.3501400, 18.7090500, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65722, 'Székesfehérvár', 'Szekesfehervar', 'Alba Regalis,Alba Regia,Albareale,Gorad Sekeshfekhervar,Sekesfehervar,Sekesfehervara,Sekesfehervaras,Sekeshfegervar,Sekeshfekhervar,Sekešfehervar,Stolicny Belehrad,Stoličný Belehrad,Stolni Beograd,Stolni Biograd,Stuhlweissenburg,Stuhlweißenburg,Szekesfehervar,Székesfehérvár,Sēkešfehērvāra,Sėkešfehėrvaras,sai ke shen bai bao,sekeshufeheruvu~aru,sekesyupeheleubaleu,sekhesfe her war,sykshfhrwar,sykshfhyrfar,Горад Секешфехервар,Секешфегервар,Секешфехервар,Столни Београд,סקשפהרוואר,سيكشفهيرفار,سیکشفهروار,شیکیسفیہیروار,เซเคซเฟเฮร์วาร์,სეკეშფეჰერვარი,セーケシュフェヘールヴァール,塞克什白堡,세케슈페헤르바르', 47.1899500, 18.4103400, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65723, 'Szedres', 'Szedres', 'Szedres', 46.4755100, 18.6830500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65724, 'Szécsény', 'Szecseny', 'Szecheny,Szecseny,Széchény,Szécsény,schan,سچان', 48.0805700, 19.5201900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65725, 'Százhalombatta', 'Szazhalombatta', 'Szazhalombatta,Százhalombatta', 47.3257900, 18.9214100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65726, 'Szászvár', 'Szaszvar', 'Mazaszaszvar,Mázaszászvár,Szaszvar,Szászvár', 46.2767300, 18.3756600, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65727, 'Szárliget', 'Szarliget', 'Ujszar,Újszár', 47.5158100, 18.4948000, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65728, 'Szany', 'Szany', 'Szany', 47.4642300, 17.3040200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65729, 'Szank', 'Szank', 'Szank', 46.5571300, 19.6610300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65730, 'Szalkszentmárton', 'Szalkszentmarton', 'Szalkszentmarton,Szalkszentmárton', 46.9756500, 19.0117800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65731, 'Szada', 'Szada', '', 47.6333300, 19.3166700, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65732, 'Szabadszállás', 'Szabadszallas', 'Szabadszallas,Szabadszállás', 46.8757500, 19.2232400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65733, 'Szabadbattyán', 'Szabadbattyan', 'Szabadbattyan,Szabadbattyán', 47.1190200, 18.3682300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65734, 'Süttő', 'Sutto', 'Sutto,Süttő', 47.7588700, 18.4487300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65735, 'Sümeg', 'Sumeg', 'Shjumeg,Шюмег', 46.9770300, 17.2820900, 'HU', '2010-07-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65736, 'Sükösd', 'Sukosd', 'Sukosd,Sükösd', 46.2818100, 18.9952400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65737, 'Sóskút', 'Soskut', 'Soskut,Sóskút', 47.4066500, 18.8224700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65738, 'Sopron', 'Sopron', 'OEdenburg,Scarabantia,Scarbantia,Shopron,Sopron,Sopronas,Sopronium,shopuron,shprn,shwbrwn,soparona,swprwn,syopeulon,xiao pu lang,Ödenburg,Šopron,Šopronas,Σόπρον,Шопрон,שאפראן,שופרון,سوپرون,شوبرون,شپرن,सोपरोन,შოპრონი,ショプロン,肖普朗,쇼프론', 47.6850100, 16.5904900, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65739, 'Soponya', 'Soponya', 'Nagylang,Nagyláng,Soponya', 47.0148500, 18.4534300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65740, 'Somoskőújfalu', 'Somoskoujfalu', '', 48.1637400, 19.8230300, 'HU', '2007-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65741, 'Somogyvár', 'Somogyvar', 'Somogyvar,Somogyvár', 46.5814000, 17.6628900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65742, 'Solymár', 'Solymar', 'Solymar,Solymár', 47.5924600, 18.9321200, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65743, 'Soltvadkert', 'Soltvadkert', 'Soltvadkert', 46.5788900, 19.3938900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65744, 'Solt', 'Solt', 'Solt', 46.8006700, 18.9999300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65745, 'Siófok', 'Siofok', 'Balatonkiliti,Balatonujhely,Balatonújhely,Shiofok,Siofok,Siofokas,Siófok,shiofoku,shywfk,siopokeu,sywpwq,xi ou fu ke,Šiofok,Šiofokas,Шиофок,Шіофок,שיופוק,شیوفک,シオーフォク,希歐福克,시오포크', 46.9041300, 18.0580000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65746, 'Simontornya', 'Simontornya', 'Simontornya', 46.7546200, 18.5549000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65747, 'Siklós', 'Siklos', 'Mariagyud,Máriagyůd,Shiklosh,Siklos,Siklós,shyklwsh,sqlws,xi ke luo shen,Šikloš,Шиклош,سقلوس,شیکلوش,希克洛什', 45.8549900, 18.2975200, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65748, 'Seregélyes', 'Seregelyes', 'Seregelyes,Seregélyes', 47.1105000, 18.5650000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65749, 'Sellye', 'Sellye', 'Sellye', 45.8724700, 17.8471100, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65750, 'Segesd', 'Segesd', 'Alsosegesd,Alsósegesd,Felsosegesd,Felsősegesd,Segesd', 46.3414200, 17.3513200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65751, 'Sásd', 'Sasd', 'Sasd,Sásd', 46.2552000, 18.1077600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65752, 'Sárvár', 'Sarvar', 'Savar', 47.2539500, 16.9352500, 'HU', '2008-07-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65753, 'Sárszentmihály', 'Sarszentmihaly', 'Sarszentmihaly,Sárszentmihály', 47.1532100, 18.3387900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65754, 'Sárosd', 'Sarosd', 'Sarosd,Sárosd', 47.0427300, 18.6435700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65755, 'Sármellék', 'Sarmellek', 'Egenfold,SOB,Sarmellek,Sármellék,Égenföld', 46.7122100, 17.1686500, 'HU', '2013-03-30', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65756, 'Sárkeresztúr', 'Sarkeresztur', 'Sarkeresztur,Sárkeresztúr', 47.0054000, 18.5439100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65757, 'Sárisáp', 'Sarisap', 'Sarisap,Sárisáp', 47.6770000, 18.6793300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65758, 'Sárbogárd', 'Sarbogard', 'Pusztaegres,Sarszentmiklos,Sárszentmiklós', 46.8869200, 18.6204100, 'HU', '2007-04-26', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65759, 'Salgótarján', 'Salgotarjan', 'Baglyasalja,Salgotarjan,Salgotarjanas,Shal''gotar''jan,Shalgo Tar''yan,Shalgotarjan,Zagyvapalfalva,Zagyvapálfalva,salgwtaryyn,shalgwtaryan,shao er ge tao er yang,sharugotaruyan,syeolgoteolyan,Šalgotarjan,Šalgotarjanas,Шалготарян,Шалготарјан,Шальготарьян,Шалґотарян,שאלגוטאריאן,سالگوتاریئن,شالگوتاریان,შალგოტარიანი,シャルゴータルヤーン,紹爾戈陶爾揚,셜고터랸', 48.0987200, 19.8030300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65760, 'Ruzsa', 'Ruzsa', 'Ruzsa', 46.2880600, 19.7471400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65761, 'Rózsaszentmárton', 'Rozsaszentmarton', '', 47.7820000, 19.7421000, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65762, 'Romhány', 'Romhany', '', 47.9261800, 19.2572300, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65763, 'Rimóc', 'Rimoc', '', 48.0369500, 19.5301000, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65764, 'Révfülöp', 'Revfueloep', 'Revfjulep,Ревфюлеп', 46.8257300, 17.6196700, 'HU', '2010-06-23', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65765, 'Rétság', 'Retsag', '', 47.9281600, 19.1372000, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65766, 'Répcelak', 'Repcelak', 'Repcelak,Répcelak', 47.4210500, 17.0179500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65767, 'Rajka', 'Rajka', 'Rajka', 47.9964300, 17.1982100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65768, 'Ráckeve', 'Rackeve', 'Rackeve,Ráckeve', 47.1609500, 18.9447800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65769, 'Ráckeresztúr', 'Rackeresztur', 'Rackeresztur,Ráckeresztúr', 47.2736000, 18.8334300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65770, 'Rácalmás', 'Racalmas', 'Racalmas,Raczalmas,Rácalmás,Ráczalmas', 47.0226300, 18.9405600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65771, 'Rábapatona', 'Rabapatona', 'Rabapatona,Rábapatona', 47.6322400, 17.4800400, 'HU', '2013-04-04', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65772, 'Pusztavám', 'Pusztavam', 'Pusztavam,Pusztavám', 47.4294800, 18.2264800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65773, 'Pusztaszer', 'Pusztaszer', 'Pusztaszer', 46.5508300, 19.9882300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65774, 'Pusztaszabolcs', 'Pusztaszabolcs', 'Pusztaszabolcs', 47.1371800, 18.7670400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65775, 'Pomáz', 'Pomaz', 'Pomaz,Pomáz', 47.6422700, 19.0278400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65776, 'Polgárdi', 'Polgardi', 'Polgardi,Polgárdi', 47.0609900, 18.3020000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65777, 'Pincehely', 'Pincehely', 'Pincehely', 46.6809500, 18.4393500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65778, 'Pilisvörösvár', 'Pilisvorosvar', '', 47.6138600, 18.9089300, 'HU', '2008-03-16', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65779, 'Pilisszentkereszt', 'Pilisszentkereszt', 'Pilisszenkereszt,Pilisszentkereszt', 47.6914300, 18.9050300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65780, 'Pilisszentiván', 'Pilisszentivan', '', 47.6096400, 18.8994000, 'HU', '2008-03-16', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65781, 'Pilisszántó', 'Pilisszanto', 'Pilisszanto,Pilisszántó', 47.6690900, 18.8876200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65782, 'Pilismarót', 'Pilismarot', 'Pilismarot,Pilismarót', 47.7846400, 18.8753900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65783, 'Piliscsév', 'Piliscsev', 'Csev,Csév,Piliscsev,Piliscsév', 47.6792400, 18.8187200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65784, 'Piliscsaba', 'Piliscsaba', 'Klotildliget,Klotildtelep,Piliscsaba,Pilisliget', 47.6341700, 18.8288600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65785, 'Pilisborosjenő', 'Pilisborosjeno', '', 47.6074400, 18.9932200, 'HU', '2008-03-16', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65786, 'Pilis', 'Pilis', 'Pilis', 47.2890400, 19.5484800, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65787, 'Petőfibánya', 'Petofibanya', 'Petofi Banyatelep,Petofibanya,Petőfi Bányatelep,Petőfibánya', 47.7794300, 19.7055000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65788, 'Pétfürdő', 'Petfuerdo', '', 47.1666700, 18.1166700, 'HU', '2007-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65789, 'Péteri', 'Peteri', 'Peteri,Péteri', 47.3910400, 19.4098100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65790, 'Perkáta', 'Perkata', 'Nagy-Perkata,Nagy-Perkáta,Perkata,Perkáta', 47.0470100, 18.7873400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65791, 'Perbál', 'Perbal', 'Perbal,Perbál', 47.5895700, 18.7609900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65792, 'Pér', 'Per', 'Per,Pér', 47.6115300, 17.8063200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65793, 'Pellérd', 'Pellerd', 'Pellerd,Pellérd', 46.0343800, 18.1540300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65794, 'Pécsvárad', 'Pecsvarad', '', 46.1603300, 18.4232100, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65795, 'Pécs', 'Pecs', 'Cinquechiese,Fuenfkirchen,Funfkirchen,Fünfkirchen,Gorad Pech,Hird,Magyarurugy,Magyarürügy,Malom,Meced Sabolc,Mecek Sabolc,Mecsekalja,Mecsekszabolcs,Málom,Nadapipad,Nadarpad,Nagyarpad,Nagyárpád,PEV,Paetkostolie,Patacs,Pec,Peca,Pecas,Pech,Pechuj,Pecs,Pecuh,Pecuj,Pecuy-,Pecz,Pets,Peçuy-,Peč,Pečuh,Pečuj,Päťkostolie,Pécs,Pēča,Pėčas,Quinque Ecclesiae,Racvaros,Rácváros,Somogy,Sopianae,Vasas,bytsh,pch,peca,pechi,pei qi,pych,pz,Πετς,Горад Печ,Печ,Печуј,פעטש,פץ,بيتش,پچ,پیچ,पेच,პეჩი,ペーチ,佩奇,페치', 46.0833300, 18.2333300, 'HU', '2017-01-15', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65796, 'Pécel', 'Pecel', 'Pecel,Pécel', 47.4896200, 19.3416200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65797, 'Pázmánd', 'Pazmand', 'Pazmand,Pázmánd', 47.2875500, 18.6535600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65798, 'Páty', 'Paty', 'Paty,Páty', 47.5170900, 18.8285100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65799, 'Pásztó', 'Paszto', 'Hasznos,Paszto,Pásztó', 47.9201900, 19.6982900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65800, 'Parádsasvár', 'Paradsasvar', 'Paradsasvar,Paradshashvar,Ureghuta,Uveghuta,Üreghuta,Üveghuta,Парадшашвар', 47.9126000, 19.9770900, 'HU', '2009-03-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65801, 'Pápa', 'Papa', 'Borsosgyor,Borsosgyőr,Kettornyulak,Kéttornyúlak,Papa,Papy,Pápa,Tapolcafo,Tapolcafő,pa bo,papa,papeo,Папа,Папы,פאפא,پاپا,帕波,파퍼', 47.3300400, 17.4674000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65802, 'Pannonhalma', 'Pannonhalma', 'Gyorszentmarton,Győrszentmárton,Martinsberg,Pannonhalma,Panonsky vrch,Panónsky vrch,Rabsky Svaety Martin,Rábsky Svätý Martin,Sankt Martinsberg', 47.5494600, 17.7553500, 'HU', '2015-11-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65803, 'Pánd', 'Pand', 'Pand,Pánd', 47.3533300, 19.6357100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65804, 'Palotás', 'Palotas', '', 47.7952800, 19.5961800, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65805, 'Pálmonostora', 'Palmonostora', 'Palmonostora,Pálmonostora', 46.6241700, 19.9515600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65806, 'Paks', 'Paks', 'Dunakomlod,Dunakömlőd,Paks', 46.6264800, 18.8596200, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65807, 'Pákozd', 'Pakozd', 'Pakozd,Pákozd', 47.2136900, 18.5330600, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65808, 'Pacsa', 'Pacsa', 'Pacsa,Pacsatuttos,Pacsatüttös', 46.7198100, 17.0140100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65809, 'Ozora', 'Ozora', 'Ozora,Ozors', 46.7513300, 18.4001000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65810, 'Öttevény', 'Otteveny', '', 47.7194600, 17.4847400, 'HU', '2010-07-15', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65811, 'Ősi', 'Osi', 'Osi,Ősi', 47.1472200, 18.1883300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65812, 'Oroszlány', 'Oroszlany', 'Oroslane,Oroszlany,Oroszlány,Орослане', 47.4867100, 18.3122500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65813, 'Örkény', 'Orkeny', 'Orkeny,Örkény', 47.1299100, 19.4332400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65814, 'Orgovány', 'Orgovany', 'Orgovany,Orgovány', 46.7508700, 19.4725900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65815, 'Őrbottyán', 'Orbottyan', 'Orbottyan,Orszentmiklos,Vacbottyan,Vácbottyán,Őrbottyán,Őrszentmiklós', 47.6871100, 19.2823900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65816, 'Őcsény', 'Ocseny', 'Ocseny,Őcsény', 46.3137000, 18.7574900, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65817, 'Ócsa', 'Ocsa', 'Ocsa,Osca,Ócsa', 47.2998600, 19.2305700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65818, 'Nyúl', 'Nyul', 'Nyul,Nyúl', 47.5904700, 17.6890400, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65819, 'Nyergesújfalu', 'Nyergesujfalu', 'Sattelneudorf', 47.7602700, 18.5569400, 'HU', '2008-11-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65820, 'Nyárlőrinc', 'Nyarlorinc', 'Nyarlorinc,Nyárlőrinc', 46.8601700, 19.8783600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65821, 'Nyáregyháza', 'Nyaregyhaza', 'Nyaregyhaza,Nyáregyháza', 47.2617500, 19.5014600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65822, 'Neszmély', 'Neszmely', 'Almasneszmely,Almásneszmély,Neszmely,Neszmély', 47.7358500, 18.3596600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65823, 'Németkér', 'Nemetker', 'Nemetker,Németkér', 46.7163700, 18.7631100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65824, 'Nemesvámos', 'Nemesvamos', 'Nemesvamos,Nemesvámos', 47.0551400, 17.8747700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65825, 'Nemesnádudvar', 'Nemesnadudvar', 'Nemesnadudvar,Nemesnádudvar', 46.3405100, 19.0511500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65826, 'Naszály', 'Naszaly', 'Naszaly,Naszály', 47.7032900, 18.2575100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65827, 'dunaújváros', 'dunaujvaros', '', 46.9673700, 18.9328800, 'HU', '2008-03-09', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65828, 'Nagytarcsa', 'Nagytarcsa', 'Nagytarcsa', 47.5312800, 19.2834300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65829, 'Nagyréde', 'Nagyrede', '', 47.7654300, 19.8481900, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65830, 'Nagyoroszi', 'Nagyoroszi', 'Nagyoroszi', 48.0050300, 19.0905000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65831, 'Nagymaros', 'Nagymaros', 'Nagymaros', 47.7928000, 18.9598400, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65832, 'Nagymányok', 'Nagymanyok', '', 46.2791100, 18.4548900, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65833, 'Nagykovácsi', 'Nagykovacsi', 'Nagykovacsi,Nagykovacsi Part,Nagykovácsi,Nagykovácsi Part', 47.6500000, 19.0166700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65834, 'Nagykőrös', 'Nagykoros', 'Nagykoros,Nagykőrös', 47.0341900, 19.7785700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65835, 'Nagykáta', 'Nagykata', 'Nagykata,Nagykáta', 47.4151400, 19.7441000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65836, 'Nagykanizsa', 'Nagykanizsa', 'Bagola,Bagolasanc,Bagolasánc,Bajcsa,Gross Kanischa,Grosz Kanischa,Kanije,Korpavar,Korpavár,Miklosfa,Miklósfa,Nad''kanizha,Nadkaniza,Nadkanizha,Nadkaniža,Nagykanizsa,Somogyszentmiklos,Somogyszentmiklós,Velika Kaniza,Velika Kanizha,Velika Kaniža,Velika Kanjiza,Velika Kanjiža,nadkanyzha,nadkanyzsa,najikanija,nao ji kao ni rao,neojikeonijeo,qnyzhh,Велика Канижа,Надканижа,Надьканижа,Надьканіжа,قنیژه,نادکانیزسا,نادکانیژا,ნადკანიჟა,ナジカニジャ,瑙吉考尼饒,너지커니저', 46.4534700, 16.9910400, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65837, 'Nagyigmánd', 'Nagyigmand', 'Nagyigmand,Nagyigmánd', 47.6409300, 18.0813000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65838, 'Nagydorog', 'Nagydorog', 'Nagydorog', 46.6274900, 18.6556500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65839, 'Nagycenk', 'Nagycenk', 'Cienjka,Cienka,Cinka,Gross-Zinkendorf,Grosszinkendorf,Groß-Zinkendorf,Großzinkendorf,Nad''cenk,Nagycenk,Надьценк', 47.6043500, 16.6973200, 'HU', '2012-10-29', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65840, 'Nagybaracska', 'Nagybaracska', 'Nagybaracska', 46.0424800, 18.9059000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65841, 'Nagybajom', 'Nagybajom', 'Nagybajom', 46.3923200, 17.5114700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65842, 'Nagyatád', 'Nagyatad', 'Bodvica,Henesz,Henész,Kivadar,Kivadár', 46.2296100, 17.3578800, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65843, 'Murakeresztúr', 'Murakeresztur', 'Murakeresztur,Murakeresztúr', 46.3642200, 16.8817700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65844, 'Mosonmagyaróvár', 'Mosonmagyarovar', 'Ad Flexum,Altenburg,Magyarovar,Magyaróvár,Moshonmad''jarovar,Moshonmadjarovar,Moson,Mosonmagarovar,Mosonmagyarovar,Mosonmagyaróvár,Mošonmađarovar,mo xiong ma zha er gu bao,moshonmajarovu~aru,mosyonmeojeolobaleu,mshwnmagrwwr,Мошонмадьяровар,Мошонмадяровар,Мошонмађаровар,مشونماگروور,モションマジャローヴァール,莫雄馬扎爾古堡,모숀머저로바르', 47.8678900, 17.2699400, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65845, 'Mórahalom', 'Morahalom', 'Alsokozpont,Alsóközpont,Morahalom,Mórahalom', 46.2180600, 19.8851000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65846, 'Mór', 'Mor', 'Mor,Mór', 47.3778700, 18.2035300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65847, 'Monor', 'Monor', 'Monor', 47.3513300, 19.4473300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65848, 'Mohács', 'Mohacs', 'Gorad Mokhach,Mohac,Mohacs,Mohacz,Mohaç,Mohač,Mohács,Moháč,Mokhach,mo ha qi,mohachi,mwhach,Горад Мохач,Мохач,מוהאץ,موهاچ,موہاچ,モハーチ,莫哈奇,모하치', 45.9930600, 18.6830600, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65849, 'Mogyoród', 'Mogyorod', 'Mogyorod,Mogyoród', 47.5974800, 19.2407000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65850, 'Mocsa', 'Mocsa', 'Mocsa', 47.6699900, 18.1850500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65851, 'Mihályi', 'Mihalyi', 'Kisfalud,Mihalyi,Mihályi', 47.5138400, 17.0950700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65852, 'Mezőszilas', 'Mezoszilas', 'Mezoszilas,Mezőszilas,Szilas-Balhas,Szilas-Balhás', 46.8110900, 18.4778900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65853, 'Mezőfalva', 'Mezofalva', 'Hercegfalva,Mezofalva,Mezőfalva', 46.9318400, 18.7717700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65854, 'Mende', 'Mende', 'Mende', 47.4313300, 19.4562800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65855, 'Mélykút', 'Melykut', 'Melykut,Mélykút', 46.2150900, 19.3810200, 'HU', '2013-04-04', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65856, 'Mecseknádasd', 'Mecseknadasd', 'Nados,Nadoš,Puspoknadasd,Püspöknádasd,mai qie ke na dao shen de,迈切克纳道什德', 46.2246800, 18.4707600, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65857, 'Mátraverebély', 'Matraverebely', 'Matraverebely,Mátraverebély', 47.9742100, 19.7804900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65858, 'Mátraterenye', 'Matraterenye', 'Homokterenye,Matraterenye,Mátraterenye,Nadujfalu,Nádújfalu', 48.0326700, 19.9476200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65859, 'Mátranovák', 'Matranovak', 'Matranovak,Matraterenye,Mátranovák,Mátraterenye', 48.0380900, 19.9825700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65860, 'Martonvásár', 'Martonvasar', 'Martonvasar,Martonvásár', 47.3160100, 18.7904500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65861, 'Marcali', 'Marcali', 'Marcali', 46.5849800, 17.4119600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65862, 'Mány', 'Many', 'Many,Mány', 47.5335200, 18.6562700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65863, 'Mágocs', 'Magocs', 'Magocs,Mágocs', 46.3499800, 18.2324000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65864, 'Maglód', 'Maglod', 'Maglod,Maglód', 47.4425800, 19.3643800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65865, 'Madocsa', 'Madocsa', 'Madocsa', 46.6879000, 18.9579100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65866, 'Madaras', 'Madaras', 'Madaras', 46.0587000, 19.2612100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65867, 'Lovasberény', 'Lovasbereny', 'Lovasbereny,Lovasberény', 47.3099700, 18.5517700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65868, 'Lőrinci', 'Lorinci', 'Lorinci,Lőrinci', 47.7329500, 19.6786700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65869, 'Litér', 'Liter', 'Liter,Litér', 47.1010400, 18.0045400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65870, 'Letenye', 'Letenye', 'Letenye', 46.4330100, 16.7258300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65871, 'Lepsény', 'Lepseny', 'Lapseny,Lepseny,Lepsény', 46.9903600, 18.2435700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65872, 'Lenti', 'Lenti', 'Barhely,Barszentmihalyfa,Bárhely,Bárszentmihályfa,Kerkaszentmihaly,Kerkaszentmihály,Lenti,Lentikapolna,Lentikápolna,Lentiszombathely,Mahomfa,Mumor,Máhomfa', 46.6240300, 16.5386300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65873, 'Lengyeltóti', 'Lengyeltoti', 'Lengyeltoti,Lengyeltóti', 46.6701300, 17.6439800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65874, 'Lébény', 'Lebeny', '', 47.7357400, 17.3907600, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65875, 'Leányfalu', 'Leanyfalu', 'Leanyfalu,Leányfalu', 47.7177800, 19.0858500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65876, 'Lánycsók', 'Lanycsok', '', 46.0054300, 18.6252600, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65877, 'Lakitelek', 'Lakitelek', 'Lakitelek', 46.8760100, 19.9950400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65878, 'Lajosmizse', 'Lajosmizse', 'Lajosmizse', 47.0213300, 19.5617100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65879, 'Lajoskomárom', 'Lajoskomarom', 'Lajoskomarom,Lajoskomárom', 46.8420100, 18.3376300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65880, 'Lábod', 'Labod', 'Labod,Lábod,Rinyahosszufalu,Rinyahosszúfalu', 46.2053500, 17.4541900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65881, 'Lábatlan', 'Labatlan', 'Labatlan,Lábatlan,Piszke', 47.7473500, 18.4962300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65882, 'Kunszentmiklós', 'Kunszentmiklos', 'Kunszentmiklos,Kunszentmiklós', 47.0269900, 19.1257500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65883, 'Kunfehértó', 'Kunfeherto', 'Kunfeherto,Kunfehértó', 46.3609100, 19.4145400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65884, 'Kozármisleny', 'Kozarmisleny', 'Kozarmisleny,Kozármisleny', 46.0296700, 18.2921000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65885, 'Kőszeg', 'Koszeg', 'Ginsium,Guns,Güns,Keseg,Kiseg,Kjoseg,Koeszeg,Koszeg,Köszeg,Kőszeg,ke sai ge,kwsg,Кесег,Кёсег,کوسگ,克塞格', 47.3892200, 16.5410000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65886, 'Kosd', 'Kosd', 'Kosd', 47.8079100, 19.1782100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65887, 'Környe', 'Kornye', 'Kornye,Környe', 47.5466800, 18.3208100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65888, 'Körmend', 'Kormend', '', 47.0109600, 16.6059600, 'HU', '2008-07-22', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65889, 'Kóny', 'Kony', 'Kony,Kóny', 47.6305300, 17.3571700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65890, 'Komló', 'Komlo', '', 46.1927800, 18.2649400, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65891, 'Komárom', 'Komarom', 'Gorad Komaram,Komarom,Komaromujvaros,Komoran,Komorn,Komárom,Komáromújváros,Szony,Szőny,Ujszony,Ujvaros,ke ma luo mu,kmrm,komalom,komaromu,Újváros,Горад Комарам,Комаром,کمرم,コマーロム,科馬羅姆,코마롬', 47.7431800, 18.1191300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65892, 'Kóka', 'Koka', 'Koka,Kóka', 47.4855200, 19.5787600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65893, 'Kocsér', 'Kocser', 'Kocser,Kocsér', 47.0016500, 19.9206700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65894, 'Kocs', 'Kocs', 'Kocs', 47.6075000, 18.2151700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65895, 'Kistelek', 'Kistelek', 'Kistelek', 46.4725000, 19.9797200, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65896, 'Kisszállás', 'Kisszallas', 'Kisszalla,Kisszallas,Kisszállá,Kisszállás', 46.2800900, 19.4895400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65897, 'Kisláng', 'Kislang', 'Kislang,Kisláng', 46.9574400, 18.3881300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65898, 'Kiskunmajsa', 'Kiskunmajsa', 'Kiskunmajsa', 46.4902800, 19.7400000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65899, 'Kiskunlacháza', 'Kiskunlachaza', 'Kiskunlachaza,Kiskunlacháza', 47.1883900, 19.0093000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65900, 'Kiskunhalas', 'Kiskunhalas', 'Kishkunkhalash,Kiskunhalas,Kiskunhalos,Кишкунхалаш', 46.4340200, 19.4847900, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65901, 'Kiskunfélegyháza', 'Kiskunfelegyhaza', 'Kiskunfelegyhaza,Kiskunfélegyháza', 46.7121300, 19.8445800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65902, 'Kiskőrös', 'Kiskoros', 'Kiskoros,Kiskőrös', 46.6213900, 19.2852800, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65903, 'Kisbér', 'Kisber', 'Aszar,Ete,Hanta,Hánta,Kisber,Kisbér,Ászár', 47.5028900, 18.0366500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65904, 'Kincsesbánya', 'Kincsesbanya', 'Kincses', 47.2644400, 18.2779000, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65905, 'Kimle', 'Kimle', 'Horvatkimle,Horvátkimle,Hrvatska Kemlja,Kimle,Magyarkimle', 47.8172600, 17.3664200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65906, 'Kéthely', 'Kethely', 'Kethely,Kéthely', 46.6460500, 17.3936200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65907, 'Kesztölc', 'Kesztolc', 'Kesztolc,Kesztölc', 47.7126600, 18.8017700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65908, 'Keszthely', 'Keszthely', 'Kestel,Kesthelj,Kestkhej,Kestkhel,Keszthely,Keszthelyi,kai si te hai yi,krsthy,Кестхей,Кестхељ,کرستهی,凱斯特海伊', 46.7681200, 17.2431700, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65909, 'Kistarcsa', 'Kistarcsa', 'Kerepestarcsa', 47.5475700, 19.2624700, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65910, 'Kerekegyháza', 'Kerekegyhaza', 'Kerekegyhaza,Kerekegyháza', 46.9372200, 19.4780600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65911, 'Kelebia', 'Kelebia', 'Kelebia', 46.1968000, 19.6165900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65912, 'Kecskemét', 'Kecskemet', 'Heteny,Hetenyegyhaza,Hetény,Hetényegyháza,Kechkemet,Keckemet,Keckemetas,Kecskemet,Kecskemét,Kečkemet,Kečkemėtas,kai qi kai mei te,kchkmyt,kchkymt,kechikemeteu,kechikemeto,khechkhe met,qz''qmt,Кечкемет,קצ''קמט,کچکمیت,کچکیمت,เคชเคเมต,ケチケメート,凯奇凯梅特,케치케메트', 46.9061800, 19.6912800, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65913, 'Kecskéd', 'Kecsked', 'Kecsked,Kecskéd', 47.5229800, 18.3093900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65914, 'Kecel', 'Kecel', 'Kecel', 46.5252800, 19.2519400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65915, 'Kazár', 'Kazar', 'Kazar,Kazár', 48.0495200, 19.8614300, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65916, 'Katymár', 'Katymar', 'Katymar,Katymár', 46.0339800, 19.2093500, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65917, 'Kartal', 'Kartal', 'Kartal', 47.6713300, 19.5420000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65918, 'Karancslapujtő', 'Karancslapujto', 'Bocsarlapujto,Bocsárlapujtő,Karancslapujto,Karancslapujtő', 48.1500000, 19.7333300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65919, 'Karancskeszi', 'Karancskeszi', 'Karancskeszi', 48.1635300, 19.6968600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65920, 'Karád', 'Karad', 'Karad,Karád', 46.6907600, 17.8413600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65921, 'Kapuvár', 'Kapuvar', 'Capuvar,Kapuvar,Kapuvár', 47.5922400, 17.0288600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65922, 'Kaposvár', 'Kaposvar', 'Kaposfured,Kaposfüred,Kaposhvar,Kaposszentjakab,Kaposvar,Kaposvaras,Kaposvár,Kapošvar,Kapošvaras,Toponar,Toponár,Torocske,Töröcske,kao bo shen bao,kaposhuvu~aru,kapshwar,kapwswar,keoposyubaleu,Капошвар,קאפושוואר,کاپشوار,کاپوسوار,კაპოშვარი,カポシュヴァール,考波什堡,커포슈바르', 46.3666700, 17.8000000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65923, 'Kaposmérő', 'Kaposmero', 'Kaposmero,Kaposmérő', 46.3616700, 17.7040000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65924, 'Kápolnásnyék', 'Kapolnasnyek', 'Kapolnasnyek,Kápolnásnyék', 47.2400400, 18.6756400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65925, 'Káloz', 'Kaloz', 'Kaloz,Káloz', 46.9546400, 18.4825900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65926, 'Kalocsa', 'Kalocsa', 'Kaloca,Kalocha,Kalocsa,Kaloča,Koloca,Koloča,kalwcha,kao luo qiao,karocha,keollocheo,Калоча,کالوچا,カロチャ,考洛喬,컬로처', 46.5263900, 18.9858300, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65927, 'Kakucs', 'Kakucs', 'Kakucs', 47.2420000, 19.3646700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65928, 'Kadarkút', 'Kadarkut', 'Kadarkut,Kadarkút', 46.2362300, 17.6201400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65929, 'Jobbágyi', 'Jobbagyi', 'Jobbagyi,Jobbágyi', 47.8323800, 19.6776200, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65930, 'Jászszentlászló', 'Jaszszentlaszlo', 'Jaszszentlaszlo,Jaszszentlazlo,Jászszentlászló,Jászszentlázló', 46.5668500, 19.7606500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65931, 'Jászberény', 'Jaszbereny', 'Jaszbereny,Jászberény', 47.5000000, 19.9166700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65932, 'Jászárokszállás', 'Jaszarokszallas', 'Jaszarokszallas,Jászárokszállás', 47.6423800, 19.9803800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65933, 'Jánossomorja', 'Janossomorja', 'Janossomorja,Jánossomorja,Mosonszentjanos,Mosonszentjános,Mosonszentpeter,Mosonszentpéter,Pusztasomorja,Sankt-Johann,Szent-Janos,Szent-János', 47.7862100, 17.1360300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65934, 'Jánosháza', 'Janoshaza', 'Janoshaza,Jánosháza', 47.1193700, 17.1650300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65935, 'Jánoshalma', 'Janoshalma', 'Janoshalma,Jánoshalma', 46.2986100, 19.3258300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65936, 'Fülöpjakab', 'Fueloepjakab', 'Fulopjakabszallas,Fülopjakabszállás', 46.7422100, 19.7213200, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65937, 'Ják', 'Jak', 'Jak,Ják,Sankt Georgen', 47.1424900, 16.5814800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65938, 'Izsák', 'Izsak', 'Izsak,Izsák', 46.8045400, 19.3517200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65939, 'Iváncsa', 'Ivancsa', 'Ivancsa,Iváncsa', 47.1567000, 18.8203000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65940, 'Isaszeg', 'Isaszeg', 'Isaszeg', 47.5301100, 19.4020500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65941, 'Iregszemcse', 'Iregszemcse', 'Iregszemcse', 46.6928600, 18.1858100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65942, 'Inárcs', 'Inarcs', 'Inarcs,Inárcs', 47.2620000, 19.3270000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65943, 'Iklad', 'Iklad', 'Iklad', 47.6653300, 19.4361000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65944, 'Hosszúhetény', 'Hosszuheteny', 'Hosszuheteny,Hosszúhetény,Kisujbanya,Kisújbánya', 46.1641400, 18.3507700, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65945, 'Hort', 'Hort', '', 47.6908100, 19.7893000, 'HU', '2007-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65946, 'Hőgyész', 'Hogyesz', '', 46.4969700, 18.4184100, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65947, 'Hidas', 'Hidas', '', 46.2568000, 18.4954000, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65948, 'Hévízgyörk', 'Hevizgyoerk', '', 47.6333300, 19.5166700, 'HU', '2010-04-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65949, 'Hévíz', 'Heviz', 'Heuwies,Heviz,Heviz Szent Andras,Héviz Szent András,Hévíz,Kheviz,Хевиз', 46.7903100, 17.1840800, 'HU', '2014-08-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65950, 'Hernád', 'Hernad', 'Alsohernad,Alsóhernád,Hernad,Hernád', 47.1623800, 19.4329500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65951, 'Herend', 'Herend', 'Herend', 47.1333300, 17.7500000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65952, 'Heréd', 'Hered', '', 47.7063800, 19.6331400, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65953, 'Hercegszántó', 'Hercegszanto', 'Hercegszanto,Hercegszántó', 45.9500000, 18.9391700, 'HU', '2012-02-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65954, 'Helvécia', 'Helvecia', 'Helvecia,Helvécia', 46.8366100, 19.6225100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65955, 'Hatvan', 'Hatvan', 'Hatvan,Khatvan,htwn,Хатван,حطون', 47.6666700, 19.6833300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65956, 'Harta', 'Harta', 'Harta', 46.6984600, 19.0305300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65957, 'Harkány', 'Harkany', 'Harkany,Harkány', 45.8500200, 18.2366800, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65958, 'Halásztelek', 'Halasztelek', 'Halasztelek,Halásztelek,Hermina-major', 47.3617300, 18.9811900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65959, 'Halászi', 'Halaszi', 'Halaszi,Halászi', 47.8893000, 17.3261500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65960, 'Hajós', 'Hajos', 'Hajos,Hajós', 46.3986100, 19.1205600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65961, 'Hajmáskér', 'Hajmasker', '', 47.1451300, 18.0196400, 'HU', '2007-06-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65962, 'Győrújbarát', 'Gyorujbarat', 'Gyorujbarat,Győrújbarát,Kisbarat,Kisbarát,Nagybarat,Nagybarát', 47.6064300, 17.6487500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65963, 'Győrszemere', 'Gyorszemere', 'Gyorszemere,Győrszemere', 47.5525600, 17.5635600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65964, 'Győr', 'Gyor', 'Arrabona,D''er,D''jor,D''or,Deras,Djor,Dėras,GJer,Gera,Gjer,Gjur,Gorad Dz''jor,Gyirmot,Gyirmót,Gyor,Gyorszentivan,Győr,Győrszentiván,Iaurinum,Jura,Menfocsanak,Ménfőcsanak,Pinnyed,Pinnyéd,Raab,cexr,diori,dywr,gywr,jeru,jie er,joeleu,Đer,Ģēra,Ђер,Ѓер,Горад Дзьёр,Дьер,Дьйор,Дьор,Дьёр,Дьӧр,גיור,دیؤر,گیور,เจอร์,დიორი,ジェール,杰尔,죄르', 47.6833300, 17.6351200, 'HU', '2015-11-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65965, 'Gyönk', 'Gyonk', '', 46.5560300, 18.4769400, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65966, 'Gyöngyöstarján', 'Gyongyostarjan', '', 47.8136900, 19.8672400, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65967, 'Gyöngyössolymos', 'Gyongyossolymos', '', 47.8172400, 19.9361900, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65968, 'Gyöngyöspata', 'Gyongyospata', '', 47.8150500, 19.7892500, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65969, 'Gyöngyöshalász', 'Gyongyoshalasz', 'Gyongyoshalasz,Gyöngyöshalász', 47.7416100, 19.9287600, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65970, 'Gyöngyös', 'Gyongyos', 'D''end''esh,D''jond''josh,D''ond''osh,Dyoendyoes,Dyöndyöş,GJenges,GJungus,Gyongyos,Gyöngyös,dyndys,jnjwsh,joenjoesi,zhen zhu shi,Đenđeš,Đunđuš,Ђенђеш,Дьондьош,Дьёндьёш,Дьєндьєш,דינדיש,جنجوش,珍珠市,죈죄시', 47.7825700, 19.9280000, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65971, 'Gyömrő', 'Gyomro', 'Gyomro,Gyömrő', 47.4273300, 19.4013300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65972, 'Gyenesdiás', 'Gyenesdias', 'Gyenesdias,Gyenesdiás', 46.7705800, 17.2866000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65973, 'Gyál', 'Gyal', 'Gyal,Gyál', 47.3844900, 19.2214000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65974, 'Gomba', 'Gomba', 'Gomba', 47.3709500, 19.5305700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65975, 'Gödöllő', 'Godollo', 'G''od''ol''o,Gedele,Gedelle,Gjodjolljo,Godollo,Godolo,Goedoello,Gödöllő,Gödölö,gdlw,ge de lei,gedere,goedoelloe,Геделе,Гьодьольо,Гёдёллё,Ґеделле,گدلو,ゲデレー,格德勒,괴될뢰', 47.5965700, 19.3551500, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65976, 'Göd', 'God', 'Alsogod,Alsógöd,Felsogod,Felsőgöd,God,Göd', 47.6832400, 19.1341700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65977, 'Gencsapáti', 'Gencsapati', '', 47.2849600, 16.5957500, 'HU', '2008-07-03', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65978, 'Gárdony', 'Gardony', '', 47.2094200, 18.6360700, 'HU', '2012-01-30', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65979, 'Gara', 'Gara', 'Gara,Gora', 46.0319400, 19.0427800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65980, 'Galgamácsa', 'Galgamacsa', 'Galgamacsa,Galgamácsa', 47.6956200, 19.3872400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65981, 'Galgahévíz', 'Galgaheviz', '', 47.6166700, 19.5666700, 'HU', '2010-04-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65982, 'Fülöpszállás', 'Fulopszallas', 'Fulopszallas,Fülöpszállás', 46.8207500, 19.2374800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65983, 'Fót', 'Fot', 'Fot,Fót', 47.6177000, 19.1887000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65984, 'Forrópuszta', 'Forropuszta', 'Forro,Forropuszta,Forró,Forrópuszta', 47.4550400, 19.6600100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65985, 'Forráskút', 'Forraskut', 'Forraskut,Forráskút', 46.3652800, 19.9097300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65986, 'Fonyód', 'Fonyod', 'Fonyod,Fonyód', 46.7555200, 17.5794500, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65987, 'Fertőszentmiklós', 'Fertoszentmiklos', 'Miklos,Mikloš,St. Niklau', 47.5899600, 16.8751700, 'HU', '2012-10-29', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65988, 'Fertőrákos', 'Fertorakos', 'Fertorakos,Fertőrákos,Kroisbach', 47.7201700, 16.6504000, 'HU', '2011-11-13', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65989, 'Fertőd', 'Fertod', 'Eszterhaza,Eszterháza,Fertod,Fertőd,Hercesko,Herceško,Suttor,Süttör', 47.6217300, 16.8708800, 'HU', '2012-10-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65990, 'Felsőszentiván', 'Felsoszentivan', 'Felsoszentivan,Felsőszentiván', 46.1971300, 19.1868600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65991, 'Felsőpakony', 'Felsopakony', 'Felsopakony,Felsőpakony', 47.3432900, 19.2369800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65992, 'Fehérvárcsurgó', 'Fehervarcsurgo', 'Fehervarcscurgo,Fehervarscsurgo,Fehérvárcscurgó,Fehérvárscsurgó', 47.2934900, 18.2646000, 'HU', '2008-03-09', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65993, 'Farmos', 'Farmos', 'Farmos', 47.3606700, 19.8461900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65994, 'Farád', 'Farad', 'Farad,Farád', 47.6063300, 17.2002400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65995, 'Fadd', 'Fadd', 'Fadd', 46.4647600, 18.8192500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65996, 'Etyek', 'Etyek', 'Etyek', 47.4479400, 18.7532800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65997, 'Esztergom', 'Esztergom', 'Ehstergom,Estergom,Estergon,Esztergom,Gran,Ostrihom,Ostrogon,Ostrzyhom,Ostřihom,Pilisszentlelek,Pilisszentlélek,Strigoni,Strigonie,Strigonio,Strigoniu,Strigonium,ai si tai er ge mu,astrgm,eseuteleugom,esuterugomu,Естергом,Естерґом,Эстергом,אסטרגום,استرگم,エステルゴム,埃斯泰尔戈姆,에스테르곰', 47.7928000, 18.7414800, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65998, 'Erzsébetváros', 'Erzsebetvaros', '7e arrondissement de Budapest,Budapest VII. keruelet,Budapest VII. kerület,Budimpeshta VII okrug,Elisabethstadt,Quan VII,Quận VII,VII. Budapester Bezirk,yi li sha bai cheng,Будимпешта VII округ,伊丽莎白城', 47.5020700, 19.0721800, 'HU', '2017-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(65999, 'Érsekvadkert', 'Ersekvadkert', 'Ersekvadkert,Érsekvadkert', 47.9961900, 19.2023100, 'HU', '2016-03-10', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66000, 'Érsekcsanád', 'Ersekcsanad', 'Ersekcsanad,Érsekcsanád', 46.2535200, 18.9845700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66001, 'Erdőkertes', 'Erdokertes', 'Erdokertes,Erdovaros,Erdőkertes,Erdőváros', 47.6726100, 19.3078600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66002, 'Érd', 'Erd', 'Andzabeg,Ehrd,Erd,Hamzsabeg,Hamzsabég,ai er de,ayrd,eleudeu,erdi,erudo,Érd,Ерд,Эрд,ארד,ایرد,ერდი,エールド,埃爾德,에르드', 47.3948900, 18.9136100, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66003, 'Ercsi', 'Ercsi', 'Ercs,Ercsi', 47.2519400, 18.8962300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66004, 'Enying', 'Enying', 'Enying', 46.9304600, 18.2420200, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66005, 'Előszállás', 'Eloszallas', 'Eloszallas,Előszállás', 46.8309400, 18.8348100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66006, 'Ecser', 'Ecser', 'Ecer,Ecera,Eceras,Echer,Ecser,Ehcher,Esceri,Esçeri,Eçer,Ečer,Ečera,Ečeras,achr,ai qie er,atshr,ecar,echeleu,echeri,echeru,eksara,xeth chex,Ечер,Эчер,Էչեր,אצר,أتشر,اچر,एक्सर,ఏచర్,เอทเชอ,ეჩერი,エチェル,埃切尔,에체르', 47.4438900, 19.3245000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66007, 'Ecséd', 'Ecsed', 'Ecsed,Ecséd', 47.7326700, 19.7669600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66008, 'Dusnok', 'Dusnok', 'Dusnok', 46.3908500, 18.9629600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66009, 'Dunavecse', 'Dunavecse', 'Dunavecse', 46.9140700, 18.9743300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66010, 'Dunavarsány', 'Dunavarsany', 'Dunakisvarsany,Dunakisvarsány,Dunavarsany,Dunavarsány', 47.2785900, 19.0661700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66011, 'Dunaújváros', 'Dunaujvaros', 'Duna Pentele,Dunapentele,Dunauivarosas,Dunauivarošas,Dunaujvaros,Dunaujvarosh,Dunaujvaroš,Dunaújváros,Pentela,Stalinvaros,Sztalinvaros,Sztálinváros,do~unauivu~aroshu,dunauivaroshi,duneou-ibalosi,duo nao xin cheng,dwnawywarws,dwnayywrwsh,Дунауйварош,Дунаујварош,دوناؤئواروس,دونائیوروش,დუნაუივაროში,ドゥナウーイヴァーロシュ,多瑙新城,두너우이바로시', 46.9647900, 18.9397400, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66012, 'Dunaszentgyörgy', 'Dunaszentgyorgy', 'Dunaszentgyorgy,Dunaszentgyörgy', 46.5285200, 18.8177100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66013, 'Dunaszekcső', 'Dunaszekcso', 'Dunaszekcso,Dunaszekcső,Dunaszeksco,Dunaszekscö,Sekcoey,Sekçöy,skchwy,سکچوی', 46.0866300, 18.7586500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66014, 'Dunapataj', 'Dunapataj', 'Dunapataj', 46.6440000, 18.9963200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66015, 'Dunakeszi', 'Dunakeszi', 'Dunakeszi', 47.6364100, 19.1386400, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66016, 'Dunaharaszti', 'Dunaharaszti', 'Dunaharaszti', 47.3545000, 19.0982200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66017, 'Dunaföldvár', 'Dunafoldvar', 'Dunafoldvar,Dunaföldvár', 46.8079900, 18.9263800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66018, 'Dunabogdány', 'Dunabogdany', 'Dunabogdany,Dunabogdány', 47.7905200, 19.0412500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66019, 'Dunaalmás', 'Dunaalmas', 'Dunaalmas,Dunaalmás', 47.7286800, 18.3223500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66020, 'Dorog', 'Dorog', 'Dorog', 47.7209500, 18.7364100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66021, 'Dömsöd', 'Domsod', 'Domsod,Dömsöd', 47.0900500, 19.0110600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66022, 'Domony', 'Domony', 'Domony', 47.6555200, 19.4322900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66023, 'Dombóvár', 'Dombovar', 'Dombovar,Dombóvár', 46.3765700, 18.1369600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66024, 'Döbrököz', 'Dobrokoz', 'Dobrokoz,Döbrököz', 46.4217800, 18.2395300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66025, 'Diósjenő', 'Diosjeno', 'Diosjeno,Diósjenő', 47.9396800, 19.0431700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66026, 'Diósd', 'Diosd', 'Diosd,Diósd', 47.4095000, 18.9489800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66027, 'Devecser', 'Devecser', 'Devecser', 47.1031600, 17.4380200, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66028, 'Délegyháza', 'Delegyhaza', 'Delegyhaza,Délegyháza', 47.2413500, 19.0901900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66029, 'Dég', 'Deg', 'Deg,Dég', 46.8680700, 18.4504200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66030, 'Decs', 'Decs', 'Decs', 46.2842800, 18.7600000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66031, 'Dávod', 'Davod', 'Davod,Dávod', 45.9950000, 18.9172200, 'HU', '2012-02-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66032, 'Dány', 'Dany', 'Dany,Dány', 47.5200000, 19.5440000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66033, 'Dánszentmiklós', 'Danszentmiklos', 'Danszentmiklos,Dánszentmiklós', 47.2148600, 19.5469500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66034, 'Dabas', 'Dabas', 'Dabas,Gyon,Gyón,Sari,Sári', 47.1859400, 19.3109100, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66035, 'Csurgó', 'Csurgo', 'Csurgo,Csurgó', 46.2531400, 17.1006000, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66036, 'Csorna', 'Csorna', 'Csorna', 47.6115500, 17.2501200, 'HU', '2014-10-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66037, 'Csopak', 'Csopak', 'Chopak,Чопак', 46.9770900, 17.9181900, 'HU', '2010-10-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66038, 'Csömör', 'Csomor', 'Csomor,Csömör', 47.5500000, 19.2333300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66039, 'Csolnok', 'Csolnok', 'Csolnok', 47.6911600, 18.7161100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66040, 'Csobánka', 'Csobanka', '', 47.6463700, 18.9618900, 'HU', '2008-03-16', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66041, 'Csetény', 'Cseteny', 'Cseteny,Csetény', 47.3180600, 17.9920800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66042, 'Cserszegtomaj', 'Cserszegtomaj', 'Cserszegtomaj', 46.8016500, 17.2209600, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66043, 'Csepreg', 'Csepreg', 'Caprieg,Cepreg,Ceprieg,Csepreg,Tschapring,Čaprieg,Čepreg,Čeprieg', 47.4009800, 16.7088100, 'HU', '2012-11-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66044, 'Csengőd', 'Csengod', 'Csengod,Csengőd', 46.7154300, 19.2680200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66045, 'Csengele', 'Csengele', 'Csengele', 46.5423400, 19.8635800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66046, 'Csemő', 'Csemo', 'Csemo,Csemő', 47.1179900, 19.6909200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66047, 'Csávoly', 'Csavoly', 'Csavoly,Csávoly,Kiscsavoly Baja', 46.1891700, 19.1466700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66048, 'Császártöltés', 'Csaszartoltes', 'Csaszartoltes,Császártöltés', 46.4219400, 19.1836100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66049, 'Császár', 'Csaszar', 'Csaszar,Császár', 47.4980000, 18.1427200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66050, 'Csány', 'Csany', '', 47.6482900, 19.8297200, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66051, 'Csákvár', 'Csakvar', 'Csakyar,Csákyár', 47.3918400, 18.4650100, 'HU', '2007-04-27', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66052, 'Csabrendek', 'Csabrendek', 'Csabrendek', 47.0135600, 17.2910800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66053, 'Celldömölk', 'Celldomolk', 'Celldoemoelk,Celldomolk,Celldömölk,Czelldomolk,Czelldömölk,Izsakfa,Izsákfa,Kiscell', 47.2571300, 17.1502700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66054, 'Ceglédbercel', 'Cegledbercel', 'Cegledbercel,Ceglédbercel', 47.2237000, 19.6682800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66055, 'Cegléd', 'Cegled', 'Cegled,Cegledas,Cegléd,Ceglėdas,Czegled,cai ge lai de,chegeulledeu,sghlyd,sglyd,tsegledi,tsu~eguredo,Цеглед,Цеґлед,سغليد,سگلید,ცეგლედი,ツェグレード,采格莱德,체글레드', 47.1726600, 19.7995200, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66056, 'Cece', 'Cece', '', 46.7705600, 18.6282600, 'HU', '2007-04-26', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66057, 'Bükkösd', 'Buekkoesd', 'Buekkoesd,Bükkösd,Gorica', 46.1075100, 17.9882000, 'HU', '2011-08-25', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66058, 'Bük', 'Buk', 'Buk,Bük,Wichs', 47.3848600, 16.7506500, 'HU', '2012-11-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66059, 'Buják', 'Bujak', 'Bujak,Buják', 47.8835200, 19.5438100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66060, 'Bugyi', 'Bugyi', 'Bugyi', 47.2274800, 19.1466400, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66061, 'Bugac', 'Bugac', 'Bugac,Bugacmonostor', 46.6870400, 19.6807400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66062, 'Budapest', 'Budapest', 'BUD,Boedapes,Boedapest,Boudapes,Boudapeste,Boudapès,Budaipeist,Budapescht,Budapeshha,Budapesht,Budapesht osh,Budapest,Budapesta,Budapestas,Budapeste,Budapesti,Budapestinum,Budapesto,Budapeszt,Budapeŝto,Budapeşt,Budapeşte,Budapešt,Budapešta,Budapeštas,Budapešť,Budapèst,Budapésht,Budimpeshta,Budimpesta,Budimpešta,Bùdapest,Bùdapeszt,Búdaipeist,Búdapest,Gorad Budapesht,bu da pei si,budapaisata,budapeseuteu,budapesrr,budapest,budapesta,budapesuto,bwdabst,bwdabyst,bwdapst,bwdpst,putapest,Βουδαπέστη,Будапешт,Будапешт ош,Будапеща,Будимпешта,Горад Будапешт,Բուդապեշտ,בודאפעשט,בודפשט,بودابست,بودابيست,بوداپست,بوداپێست,بوډاپسټ,बुडापेस्ट,बुदापेस्त,বুদাপেস্ট,ਬੁਦਾਪੈਸਤ,બુડાપેસ્ટ,ବୁଦାପେଷ୍ଟ,புடாபெஸ்ட்,ಬುಡಾಪೆಸ್ಟ್,ബുഡാപെസ്റ്റ്,บูดาเปสต์,བུ་ད་ཕེ་སིད།,ဗူးဒပက်မြို့,ბუდაპეშტი,ቡዳፔስት,ブダペスト,布达佩斯,부다페스트', 47.4980100, 19.0399100, 'HU', '2017-06-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66063, 'Budaörs', 'Budaors', '', 47.4618100, 18.9584500, 'HU', '2008-03-16', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66064, 'Budakeszi', 'Budakeszi', 'Budakeszi', 47.5108300, 18.9271700, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66065, 'Budakalász', 'Budakalasz', 'Budakalasz,Budakalász', 47.6166700, 19.0500000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66066, 'Aszód', 'Aszod', '', 47.6517400, 19.4785000, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66067, 'Bősárkány', 'Bosarkany', 'Bosarkany,Bősárkány', 47.6882100, 17.2500000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66068, 'Bordány', 'Bordany', 'Bordany,Bordány,Kistemplomtanya', 46.3184300, 19.9230600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66069, 'Bonyhád', 'Bonyhad', 'Bonyhad,Bonyhád', 46.2992100, 18.5302400, 'HU', '2011-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66070, 'Bőny', 'Bony', 'Bony,Bonyretalap,Bőny,Bőnyrétalap', 47.6500000, 17.8697700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66071, 'Bóly', 'Boly', 'Boly,Bóly,Nemetboly,Németbóly', 45.9672200, 18.5183300, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66072, 'Boldog', 'Boldog', 'Boldog', 47.6028500, 19.6883900, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66073, 'Bölcske', 'Bolcske', 'Bolcske,Bölcske', 46.7410200, 18.9673600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66074, 'Bokod', 'Bokod', 'Bokod', 47.4918600, 18.2474300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66075, 'Böhönye', 'Bohonye', 'Bohonye,Böhönye', 46.4134500, 17.3803700, 'HU', '2012-08-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66076, 'Bogyiszló', 'Bogyiszlo', 'Bogyiszlo,Bogyiszló', 46.3863800, 18.8296200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66077, 'Bodajk', 'Bodajk', 'Bodajk', 47.3235200, 18.2331200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66078, 'Bicske', 'Bicske', 'Bicske', 47.4841900, 18.6440400, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66079, 'Biatorbágy', 'Biatorbagy', 'Biatorbagy,Biatorbágy', 47.4706000, 18.8189200, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66080, 'Berzence', 'Berzence', 'Berzence,بره‌زنچه', 46.2090700, 17.1481000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66081, 'Berhida', 'Berhida', 'Berhida,Peremarton', 47.1113100, 18.1294800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66082, 'Beremend', 'Beremend', 'Beremend', 45.7910800, 18.4326300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66083, 'Bercel', 'Bercel', 'Bercel', 47.8705700, 19.4071500, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66084, 'Beled', 'Beled', 'Beled,Vica', 47.4659400, 17.0929400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66085, 'Becsehely', 'Becsehely', 'Becsehely,Bekcsenypolya,Bekcsénypolya,Pola', 46.4475500, 16.7771000, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66086, 'Bátya', 'Batya', 'Batya,Bátya', 46.4880000, 18.9541900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66087, 'Bátonyterenye', 'Batonyterenye', 'Batonyterenye,Bátonyterenye,Kisterenye,Nagybatony,Nagybátony,Szupatak,Szúpatak', 47.9696200, 19.8407600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66088, 'Bátaszék', 'Bataszek', 'Bataszek,Bátaszék', 46.1937300, 18.7230700, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66089, 'Báta', 'Bata', 'Bata,Báta', 46.1286400, 18.7702700, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66090, 'Barcs', 'Barcs', 'Barcs,Dravaszentes,Drávaszentes,Somogy Tarnocza,Somogytarnoca,Somogytarnóca,barchh,بارچه', 45.9600000, 17.4586100, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66091, 'Baracska', 'Baracska', 'Baracska', 47.2822500, 18.7585300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66092, 'Baracs', 'Baracs', 'Baracs', 46.8820200, 18.9065800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66093, 'Ballószög', 'Balloszog', 'Balloszog,Ballószög', 46.8621600, 19.5709200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66094, 'Balatonszárszó', 'Balatonszarszo', 'Balatonszarszo,Balatonszárszó', 46.8294600, 17.8242600, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66095, 'Balatonszabadi', 'Balatonszabadi', 'Balatonszabadi,Siomaros,Siómaros', 46.8939700, 18.1373700, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66096, 'Balatonlelle', 'Balatonlelle', 'Balatonlelle,Boglarlelle,Boglárlelle', 46.7831800, 17.6949800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66097, 'Balatonkenese', 'Balatonkenese', 'Balatonkenese', 47.0401900, 18.1067100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66098, 'Balatonfüred', 'Balatonfured', 'Balatonfired,Balatonfiuredas,Balatonfjured,Balatonfured,Balatonfüred,ba la dun fei lai de,balatnfwrd,Балатонфиред,Балатонфюред,بالاتنفورد,巴拉頓菲賴德', 46.9618800, 17.8718700, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66099, 'Balatonföldvár', 'Balatonfoldvar', 'Balaton Foldvar Furdotelep,Balaton Földvár Fürdőtelep,Balatonfeldvar,Balatonfoldvar,Balatonföldvár,ba la dun cheng bao,Балатонфелдвар,巴拉頓城堡', 46.8525500, 17.8812300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66100, 'Balatonfenyves', 'Balatonfenyves', 'Balatonfenyves', 46.7154200, 17.4922300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66101, 'Balatonboglár', 'Balatonboglar', 'Balatonboglar,Balatonboglár,Szolloskislak,Szoloskislak,Szőllőskislak,Szőlőskislak', 46.7752500, 17.6441500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66102, 'Balatonberény', 'Balatonbereny', 'Balatonbereni,Balatonbereny,Balatonberény,Балатонберени', 46.7070100, 17.3201300, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66103, 'Balatonalmádi', 'Balatonalmadi', 'Balatonalmadi,Balatonalmádi,Vorosbereny,Vörösberény', 47.0352600, 18.0207600, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66104, 'Balassagyarmat', 'Balassagyarmat', 'Balassagyarmat,Ipolyszog,Ipolyszög', 48.0729600, 19.2961400, 'HU', '2014-11-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66105, 'Bakonyszentlászló', 'Bakonyszentlaszlo', 'Bakonyszentlaszlo,Bakonyszentlászló', 47.3890100, 17.8032100, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66106, 'Bakonycsernye', 'Bakonycsernye', 'Bakonycsernye', 47.3239500, 18.0750900, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66107, 'Bajna', 'Bajna', 'Bajna', 47.6540000, 18.5972000, 'HU', '2012-02-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66108, 'Baja', 'Baja', 'Baja,Bajja,Baya,baia,bao yao,baya,bayh,beoyeo,Байя,Бая,Баја,באיה,بایا,بایه,ბაია,バヤ,包姚,버여', 46.1749600, 18.9563900, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66109, 'Baj', 'Baj', 'Baj', 47.6459300, 18.3641000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66110, 'Bag', 'Bag', '', 47.6333300, 19.4833300, 'HU', '2006-01-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66111, 'Badacsonytomaj', 'Badacsonytomaj', 'Badacsonytomaj', 46.8071100, 17.5138500, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66112, 'Bácsbokod', 'Bacsbokod', 'Bacsbokod,Bácsbokod', 46.1250000, 19.1562100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66113, 'Bácsalmás', 'Bacsalmas', 'Bacsahna,Bacsalmas,Bácsahná,Bácsalmás', 46.1264800, 19.3326000, 'HU', '2017-04-05', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66114, 'Bábolna', 'Babolna', 'Babolna,Babolnapuszta,Bábolna,Bábolnapuszta', 47.6436100, 17.9779800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66115, 'Babócsa', 'Babocsa', 'Babocsa,Babócsa,bwbwfchh,بوبوفچه', 46.0415500, 17.3433200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66116, 'Ásványráró', 'Asvanyraro', '', 47.8273300, 17.4941800, 'HU', '2010-04-07', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66117, 'Ásotthalom', 'Asotthalom', 'Asotthalom,Ásotthalom', 46.1987500, 19.7833400, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66118, 'Apostag', 'Apostag', 'Apostag', 46.8820800, 18.9621000, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66119, 'Apc', 'Apc', 'Apc', 47.7941900, 19.6942900, 'HU', '2014-04-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66120, 'Alsónémedi', 'Alsonemedi', 'Alsonemedi,Alsónémedi', 47.3152400, 19.1584300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66121, 'Almásfüzitő', 'Almasfuzito', 'Kiskolonia,Kiskolónia', 47.7275200, 18.2615300, 'HU', '2012-02-23', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66122, 'Albertirsa', 'Albertirsa', 'Alberti,Albertirsa,Irsa', 47.2431500, 19.6168600, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66123, 'Alap', 'Alap', 'Alap', 46.7991500, 18.6893800, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66124, 'Akasztó', 'Akaszto', 'Akaszto,Akasztó', 46.6916700, 19.2042300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66125, 'Ajka', 'Ajka', 'Aika,Ajka,Ajkarendek,Ayka,Bakonygyepes,Csekut,Csékút,Padrag,Padragkut,Padragkút,Tosok,Tosokberend,Tósok,Tósokberénd,aika,ao yi kao,ayka,eoikeo,Айка,Ајка,آیکا,アイカ,奧伊考,어이커', 47.1019600, 17.5589200, 'HU', '2015-06-17', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66126, 'Ágfalva', 'Agfalva', 'Agendorf,Agfalva,Ogendorf,Ágfalva', 47.6899100, 16.5165800, 'HU', '2012-10-28', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66127, 'Ágasegyháza', 'Agasegyhaza', 'Agasegyhaza,Ágasegyháza', 46.8402500, 19.4520800, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66128, 'Adony', 'Adony', 'Adony', 47.1194000, 18.8649300, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66129, 'Ádánd', 'Adand', 'Adand,Ádánd', 46.8593100, 18.1644200, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66130, 'Adács', 'Adacs', '', 47.6921000, 19.9769600, 'HU', '2011-04-19', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66131, 'Acsa', 'Acsa', 'Acsa', 47.7942500, 19.3879500, 'HU', '2007-02-11', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66132, 'Ács', 'Acs', 'Acs,Ecs,Ács', 47.7123100, 18.0113100, 'HU', '2012-01-18', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66133, 'Abda', 'Abda', 'Abda', 47.6946400, 17.5448900, 'HU', '2012-05-06', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66134, 'Aba', 'Aba', 'Aba,Аба', 47.0290700, 18.5217200, 'HU', '2016-10-22', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66135, 'Tiszaalpár', 'Tiszaalpar', 'Tiszaalpar,Tiszaalpár', 46.8127900, 19.9984100, 'HU', '2012-01-20', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66136, 'Budapest XII. kerület', 'Budapest XII. keruelet', '', 47.4919200, 19.0149300, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66137, 'Budapest XI. kerület', 'Budapest XI. keruelet', '', 47.4760300, 19.0360500, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66138, 'Budapest VIII. kerület', 'Budapest VIII. keruelet', '', 47.4891900, 19.0701200, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66139, 'Budapest VI. kerület', 'Budapest VI. keruelet', 'Terezvaros,Terézváros,Theresienstadt,VI. Budapester Bezirk', 47.5036900, 19.0658300, 'HU', '2016-10-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66140, 'Budapest XIII. kerület', 'Budapest XIII. keruelet', '', 47.5297800, 19.0806800, 'HU', '2016-10-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66141, 'Budapest IV. kerület', 'Budapest IV. keruelet', '', 47.5618200, 19.0890900, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66142, 'Budapest XV. kerület', 'Budapest XV. keruelet', '', 47.5626300, 19.1168100, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66143, 'Budapest XVI. kerület', 'Budapest XVI. keruelet', '', 47.5148200, 19.1702800, 'HU', '2016-10-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66144, 'Budapest X. kerület', 'Budapest X. keruelet', '', 47.4791000, 19.1583500, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66145, 'Budapest XIX. kerület', 'Budapest XIX. keruelet', '', 47.4529300, 19.1494300, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66146, 'Budapest XVIII. kerület', 'Budapest XVIII. keruelet', '', 47.4441700, 19.1759500, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66147, 'Budapest XXIII. kerület', 'Budapest XXIII. keruelet', '', 47.3978800, 19.1149200, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66148, 'Budapest XXII. kerület', 'Budapest XXII. keruelet', '', 47.4269800, 19.0401600, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66149, 'Budapest XXI. kerület', 'Budapest XXI. keruelet', '', 47.4304700, 19.0709800, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66150, 'Budapest XX. kerület', 'Budapest XX. keruelet', '', 47.4367400, 19.1009300, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66151, 'Budapest XVII. kerület', 'Budapest XVII. keruelet', '', 47.4799700, 19.2538800, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66152, 'Budapest III. kerület', 'Budapest III. keruelet', '', 47.5415700, 19.0450100, 'HU', '2016-10-14', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66153, 'Budapest II. kerület', 'Budapest II. keruelet', '', 47.5198400, 19.0221800, 'HU', '2016-02-24', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66154, 'Budapest I. kerület', 'Budapest I. keruelet', '', 47.4970500, 19.0396100, 'HU', '2010-04-01', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66155, 'Algyő', 'Algyo', '', 46.3347200, 20.2084900, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66156, 'Szelevény', 'Szeleveny', '', 46.8025900, 20.2028300, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66157, 'Kismaros', 'Kismaros', '', 47.8374200, 19.0046300, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66158, 'Héhalom', 'Hehalom', '', 47.7801700, 19.5851900, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66159, 'Mosonszentmiklós', 'Mosonszentmiklos', '', 47.7277800, 17.4278400, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66160, 'Kerepes', 'Kerepes', 'Kerepestarcsa', 47.5600800, 19.2828900, 'HU', '2010-04-02', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66161, 'Tiszaszőlős', 'Tiszaszolos', '', 47.5570700, 20.7194900, 'HU', '2012-11-26', 101);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66162, 'Ujung Gading', 'Ujung Gading', 'Oedjoenggading,Udjunggading,Ujung Gading', 0.2729300, 99.5576200, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66163, 'Ujungbatu', 'Ujungbatu', 'Oedjoengbatoe,Udjungbatu,Ujungbatu', 1.0423900, 99.9346100, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66164, 'Tualangcut', 'Tualangcut', 'Toealang-Tjoet,Toealang-Tjot,Tualancut,Tualang Cut,Tualangcut,Tualangtjut', 4.4018000, 98.0722000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66165, 'Tongging', 'Tongging', 'Tongging,Tonging,Тонгинг', 2.8985000, 98.5231000, 'ID', '2015-03-31', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66166, 'Tomok Bolon', 'Tomok Bolon', 'Tomok,Tomok Bolon', 2.6521000, 98.8608000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66167, 'Tiku', 'Tiku', 'Tikoe,Tiku', -0.3958000, 99.9230700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66168, 'Teluk Nibung', 'Teluk Nibung', 'Teloekniboeng,Teluk Nibung', 3.0010000, 99.8164000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66169, 'Teluk Dalam', 'Teluk Dalam', 'Teloekdalam,Teloekdalem,Telok Dalam,Telokdalem,Teluk Dalam,Telukdalam,Telukdalem', 0.5729000, 97.8034000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66170, 'Tebingtinggi', 'Tebingtinggi', 'Tebingtinggi', 3.3285000, 99.1625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66171, 'Tarutung', 'Tarutung', 'Taroeloeng,Taroetoeng,Tarutung', 2.0146700, 98.9654800, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66172, 'Tanjungtiram', 'Tanjungtiram', 'Tandjoengtiram,Tandjungtiram,Tanjungtiram', 4.0613000, 98.3699000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66173, 'Tanjungbalai', 'Tanjungbalai', 'Tandjoengbalai,Tandjungbalai,Tanjungbalai', 2.9666700, 99.8000000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66174, 'Tangse', 'Tangse', 'Keude Tangse,Tangse,Tangsee', 5.0136000, 95.9153000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66175, 'Talu', 'Talu', 'Taloe,Talu', 0.2300600, 99.9812300, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66176, 'Takengon', 'Takengon', 'TXE,Takengeun,Takengon,Takingeun,Takingon', 4.6212000, 96.8467000, 'ID', '2016-06-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66177, 'Susoh', 'Susoh', 'Soesoh,Suso,Susoh,Susu', 3.7239400, 96.8215900, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66178, 'Sunggal', 'Sunggal', 'Sungal,Sunggal', 3.5765000, 98.6151000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66179, 'Sei Rampah', 'Sei Rampah', 'Rampah,Sei Rampah,Soengairampah,Sungairampah,Sungairampah 2', 3.4845000, 99.1366000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66180, 'Stabat', 'Stabat', 'Stabat,Stabatbaru', 3.7333500, 98.4502500, 'ID', '2015-01-27', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66181, 'Sondi', 'Sondi', 'Sondi', 2.9735000, 98.8617000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66182, 'Sipirok', 'Sipirok', 'Sipirok,Sipohue', 1.6024800, 99.2737700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66183, 'Sipiongot', 'Sipiongot', 'Sipiongot', 1.8350100, 99.6626600, 'ID', '2013-10-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66184, 'Sipagimbar', 'Sipagimbar', 'Sipagimbar', 1.8307200, 99.3718500, 'ID', '2013-10-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66185, 'Singkil', 'Singkil', 'Nieuw Singkel,Nieuw Singkil,Pasar Singkil,Singkel,Singkil,Singkilbaru,Sinkel,Сингкил', 2.2874000, 97.7884000, 'ID', '2015-03-31', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66186, 'Sinabang', 'Sinabang', 'Sinabang', 2.4803000, 96.3801000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66187, 'Simpang Empat', 'Simpang Empat', 'Simpang Ampek,Simpang Empat,Simpang IV,Simpangampat', 0.0970300, 99.8233900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66188, 'Sigli', 'Sigli', 'Sigli', 5.3848000, 95.9609000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66189, 'Sidikalang', 'Sidikalang', 'Sidikalang', 2.7489900, 98.3127000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66190, 'Sibuhuan', 'Sibuhuan', 'Siboehoean,Sibubuhan,Sibuhuan', 1.0538700, 99.7301800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66191, 'Siborong-Borong', 'Siborong-Borong', 'DTB,Siborangbarang,Siborong-Borong', 2.2125100, 98.9729100, 'ID', '2015-12-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66192, 'Sibolga', 'Sibolga', 'FLZ,Kota Sibolga,Sibolga,Сиболга', 1.7401600, 98.7811700, 'ID', '2014-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66193, 'Sibigo', 'Sibigo', 'Sibigio,Sibigo', 2.8385000, 95.9131000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66194, 'Siabu', 'Siabu', 'Siaboe,Siabu', 1.0155200, 99.4945200, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66195, 'Seulimeum', 'Seulimeum', 'Selimeum,Seulimeum,Seulimeun', 5.3618000, 95.5765000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66196, 'Serawai', 'Serawai', 'Peukan Seruway,Serawai,Seroewai,Seruwai', 4.3542000, 98.1868000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66197, 'Saribudolok', 'Saribudolok', 'Saribudolok,Seriboedolok,Seribudolok', 2.9392000, 98.6107000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66198, 'Salak', 'Salak', 'Salak', 2.5566000, 98.3235000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66199, 'Sabang', 'Sabang', 'Gorad Sabang,Kota Sabang,Kuta Sabang,Kutha Sabang,Sabang,Sabangas,Sabong,saban,sabang,sabangh,sha huang,Горад Сабанг,Сабанг,سابانغ,سابانگ، انڈونیشیا,サバン,沙璜,사방', 5.8896900, 95.3164400, 'ID', '2012-03-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66200, 'Rikitgaib', 'Rikitgaib', 'Rikip Gaib,Rikitgaib,Ringkitgaib', 4.1447000, 97.0572000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66201, 'Reuleuet', 'Reuleuet', '', 5.2166700, 96.2833300, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66202, 'Rantauprapat', 'Rantauprapat', 'Rantauprapat', 2.1000000, 99.8333300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66203, 'Parapat', 'Parapat', 'Parapat,Prapat,SIW', 2.6630000, 98.9349000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66204, 'Pintupadang', 'Pintupadang', 'Pintoepadang,Pintu Padang,Pintupadang', 1.2402000, 99.3450000, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66205, 'Peureulak', 'Peureulak', 'Keude Peureula,Keudepeureulak,Perlak,Peureula,Peureulak,Porolak,Pörölak', 4.8098000, 97.8902000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66206, 'Percut', 'Percut', 'Percut,Pertjoet,Pertjut', 3.6253000, 98.8640000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66207, 'Perbaungan', 'Perbaungan', 'Baoengan,Baoengar,Baungan,Perbaungan', 3.5679000, 98.9560000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66208, 'Penaron', 'Penaron', 'Peharon,Penaron,Peunaron', 4.6407000, 97.6842000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66209, 'Pematangsiantar', 'Pematangsiantar', 'Pematangsiantar,Pematangsieantar', 2.9595000, 99.0687000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66210, 'Pematang Raya', 'Pematang Raya', 'Pematang Raya,Pematangraja,Pematangraya,Permatangraya', 2.9658000, 98.8473000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66211, 'Parmonangan', 'Parmonangan', 'Parmonangan', 2.1046000, 98.7637000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66212, 'Parlilitan', 'Parlilitan', 'Palilitan,Parlilitan', 2.3240000, 98.4571000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66213, 'Panyambungan', 'Panyambungan', 'Panjaboengan,Panjabungan,Panyabungan,Panyambungan', 0.8651000, 99.5528000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66214, 'Pangururan', 'Pangururan', 'Pangoeroeran,Panguruan,Pangururan', 2.6081000, 98.6961000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66215, 'Pangkalan Brandan', 'Pangkalan Brandan', 'Pangkalan Brandan,Pangkalanberandan', 4.0238000, 98.2782000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66216, 'Pakkat', 'Pakkat', 'Pakkat', 2.1524000, 98.4745000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66217, 'Padangtiji', 'Padangtiji', 'Padadangtidji,Padang Tiji,Padangtidji,Padangtiji,Padangtijie', 5.3742000, 95.8445000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66218, 'Padangsidempuan', 'Padangsidempuan', 'Padangsidempuan,Padangsidimpoean,Padangsidimpuan', 1.3795200, 99.2714600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66219, 'Natal', 'Natal', 'Natal', 0.5632000, 99.1099000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66220, 'Nainggolan', 'Nainggolan', 'Nainggalan,Nainggolan', 2.4361000, 98.8852000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66221, 'Muara Soma', 'Muara Soma', 'Moearasoma,Muara Soma', 0.6884200, 99.3619400, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66222, 'Muara Sipongi', 'Muara Sipongi', 'Moearasipongi,Muara Sipongi', 0.5692600, 100.0126600, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66223, 'Sikabaluan', 'Sikabaluan', 'Moearasikabaloean,Muarasikabaluan,Sikabaluan', -1.1196100, 98.9921700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66224, 'Muara Siberut', 'Muara Siberut', 'Moearasiberoet,Moearasioetort,Muara Siberut,Muarasiberut,Siberut', -1.5978700, 99.2109700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66225, 'Muara', 'Muara', 'Moeara,Muara', 2.3372200, 98.9053900, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66226, 'Montasik', 'Montasik', '', 5.5026600, 95.4230600, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66227, 'Mogang', 'Mogang', 'Mogang', 2.4697000, 98.8043000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66228, 'Meureubo', 'Meureubo', 'Meureubo', 4.1400000, 96.1623000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66229, 'Meulaboh', 'Meulaboh', 'MEQ,Melabokha,Meulaboh,Molabo,Mölabo,Мелабоха', 4.1440200, 96.1266400, 'ID', '2014-08-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66230, 'Medan', 'Medan', 'Gorad Medan,Kota Medan,Kuta Medan,Kuta Mèdan,Kutha Medan,MES,Medan,Medana,Medanas,Medano,Mentan,mdan,me dan,medan,metan,mian lan,mydan,Μεντάν,Горад Медан,Медан,مدان,ميدان,میدان ، انڈونیشیا,மேடான்,เมดาน,メダン,棉蘭,메단', 3.5833300, 98.6666700, 'ID', '2015-06-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66231, 'Lubuk Pakam', 'Lubuk Pakam', 'Loeboekpakam,Lubuk Pakam,Lubukpakam 1', 3.5592000, 98.8733000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66232, 'Lintongnihuta', 'Lintongnihuta', 'Lintongnihoeta,Lintongnihuta', 2.2760000, 98.8660000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66233, 'Limapuluh', 'Limapuluh', 'Limapoeloeh,Limapuluh', 3.1689000, 99.4175000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66234, 'Lhoong', 'Lhoong', 'Lhong,Lhoong,Loong', 5.2666700, 95.2500000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66235, 'Lhokseumawe', 'Lhokseumawe', 'Kota Lhokseumawe,LSW,Lho''seumawe,Lhokseumawe,Lhoksumawe,Lho’seumawe,Lokseumave,Локсеумаве', 5.1801000, 97.1507000, 'ID', '2017-07-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66236, 'Lhoknga', 'Lhoknga', 'Lho''gna,Lho''nga,Lhoknga,Lho’gna,Lho’nga', 5.4769100, 95.2453800, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66237, 'Lhokkruet', 'Lhokkruet', 'Krut,Lho''kroeet,Lho''kroeët,Lho''kruet,Lhokkroeet,Lhokkroeët,Lhokkruet,Lhokruet', 4.8797000, 95.4010000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66238, 'Laweueng', 'Laweueng', 'Laweueng,Laweung', 5.5151000, 95.8465000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66239, 'Langsa', 'Langsa', 'Langsa,Langsar', 4.4683000, 97.9683000, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66240, 'Langgapayung', 'Langgapayung', 'Langgapajoeng,Langgapajung,Langgapayung', 1.7269300, 99.9628500, 'ID', '2013-10-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66241, 'Lampuyang', 'Lampuyang', 'Lampujang,Lampuyang', 5.6701000, 95.1345000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66242, 'Lamno', 'Lamno', 'Lamno,Lamo', 5.0902000, 95.3727000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66243, 'Labuhan Deli', 'Labuhan Deli', 'Deli,Laboean Deli,Laboehan,Laboehandeli,Labuan Deli,Labuhan,Labuhan Deli,Laukaban', 3.7278000, 98.6738000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66244, 'Kuala Bhee', 'Kuala Bhee', 'Koeala Bhee,Koeala Bheë,Koealabae,Koealabee,Koealabeë,Kuala Bhee,Kualabee,Kualabhee', 4.3855000, 96.0471000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66245, 'Kruengraya', 'Kruengraya', 'Kroeengraja,Kroeëngraja,Kruengraja,Kruengraya,Malhayati Port', 5.5895000, 95.5145000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66246, 'Krueng Luak', 'Krueng Luak', 'Kroeengloeak,Kroeëngloeak,Krueng Luak,Krueng Luas,Kruengluah', 2.8583000, 97.7578000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66247, 'Kisaran', 'Kisaran', 'Kisaran,Kisaran Baru', 2.9845000, 99.6158000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66248, 'Kabanjahe', 'Kabanjahe', 'Kabandjahe,Kabanjahe', 3.1001000, 98.4908000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66249, 'Isak', 'Isak', 'Isak,Isaq', 4.4599000, 96.8822000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66250, 'Kotanopan', 'Kotanopan', 'Hoetanopan,Hutanopan,Kotanopan', 0.6675800, 99.7090800, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66251, 'Gunung Tua', 'Gunung Tua', 'Goenoengtoea,Gunongtua,Gunung Tua,Gunungtua', 1.5127400, 99.6262800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66252, 'Gunungsitoli', 'Gunungsitoli', 'GNS,Goenoengsitoli,Goenoensitoli,Gunongsitoli,Gunungsitoli,Omositoli', 1.2888000, 97.6143000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66253, 'Gosong Telaga', 'Gosong Telaga', 'Gosong Telaga,Gosongtelaga Utara', 2.2786000, 97.9268000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66254, 'Dolok Sanggul', 'Dolok Sanggul', 'Dolok Sanggul,Doloksanggoel,Sangaul', 2.2588000, 98.7501000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66255, 'Deli Tua', 'Deli Tua', 'Deli Tua,Delitoea', 3.5078000, 98.6839000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66256, 'Celala', 'Celala', 'Celala,Tjelala', 4.5955000, 96.6920000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66257, 'Calang', 'Calang', 'Calang,Calong,Chalang,Tjalang,Tyalang', 4.6306000, 95.5754000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66258, 'Blangpidie', 'Blangpidie', 'Belangpidie,Belangpidië,Blangpidi,Blangpidie', 3.7395600, 96.8360800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66259, 'Blangkejeren', 'Blangkejeren', 'Blangkedjeren,Blangkejeren', 3.9971000, 97.3384000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66260, 'Bireun', 'Bireun', 'Bireuen,Bireun,Biroen,Biröen', 5.2030000, 96.7009000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66261, 'Binjai', 'Binjai', 'Bindjai,Bindjei,Binjai,Kota Binjai,min li,民禮', 3.6001000, 98.4854000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66262, 'Binanga', 'Binanga', 'Binanga', 1.4100600, 99.7760200, 'ID', '2013-10-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66263, 'Berastagi', 'Berastagi', 'Berastagi,Берастаги', 3.1946800, 98.5088900, 'ID', '2015-03-31', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66264, 'Belawan', 'Belawan', 'Belawan', 3.7755000, 98.6832000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66265, 'Bayeuen', 'Bayeuen', 'Bajenen,Bajeuen,Bayan,Bayang,Bayeuen,Bayoen,Bayuen,Bayöen', 4.5902000, 97.9087000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66266, 'Batangtoru', 'Batangtoru', 'Batangtoroe,Batangtoru', 1.4825300, 99.0656900, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66267, 'Barus', 'Barus', 'Baroes,Barus', 2.0106000, 98.3982000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66268, 'Bandar', 'Bandar', '', 2.0500000, 99.7500000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66269, 'Banda Aceh', 'Banda Aceh', 'BTJ,Baiturahman,Banda Aceh,Banda Aceha,Banda Acehas,Banda Acheh,Banda Achekh,Banda Achem,Banda Achém,Banda Atjeh,Banda Ačeha,Banda Ačehas,Banda-Achekh,Banta Atsech,Koetaradja,Kota Banda Aceh,Kota Banda Acéh,Kuta Banda Aceh,Kuta Banda Acèh,Kuta Raja,Kutaradja,Kutha Banda Aceh,Kutha Banda Acèh,ban da ya qi,ban dar xa ceah,banda ash,banda atshyh,bandaache,Μπάντα Άτσεχ,Банда Ачех,Банда-Ачех,باندا آتشيه,باندا آسه,بندا آچے,บันดาร์อาเจะห์,バンダ・アチェ,班達亞齊,반다아체', 5.5416700, 95.3333300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66270, 'Balige', 'Balige', 'Balige', 2.3328000, 99.0657000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66271, 'Bakungan', 'Bakungan', 'Bakoengan,Bakongan,Bakungan,Keude Bakongan', 2.9239700, 97.4831100, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66272, 'Asan Kumbang', 'Asan Kumbang', 'Asan Kumbang', 5.3042400, 96.0274400, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66273, 'Ambarita', 'Ambarita', 'Ambarita', 2.6814000, 98.8311000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66274, 'Air Bangis', 'Air Bangis', 'Aibangis,Air Bangis,Ajerbangis,Ayerbangis', 0.2018000, 99.3798500, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66275, 'Terangun', 'Terangun', 'Terangon,Terangun', 4.0772000, 97.0666000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66276, 'Kenyaran', 'Kenyaran', 'Kenyarah,Kenyaran', 4.1544000, 97.1951000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66277, 'Pining', 'Pining', 'Pedeng,Penaeng,Pining', 4.1064000, 97.5886000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66278, 'Yosowilangun', 'Yosowilangun', 'Jasawilangoen,Josowilangoen,Josowilangun,Yosowilangun', -8.2391000, 113.3136000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66279, 'Yogyakarta', 'Yogyakarta', 'DI Yogyakarta,DIY,Daerah Istimewa Yogyakarta,Djogjakarta,Djokja,Djokjakarta,Dzhodzhakarta,Dzhok''jakarta,Dzhokjakarta,Dzogdzakarta,Dzogjakarta,Džogjakarta,Gionkiakarta,JOG,Jogjakarta,Jogjakarto,Jogyakarta,Jokjakarta,Jokyakarta,Kota Yogyakarta,Kuta Yogyakarta,Kutha Ngayogyakarta,Special Region of Yogyakarta,Yogyakarta,jogujakaruta shi,ri re,yog-yakaleuta,yogyakarta,ywgyakarta,ywjyakrta,yxk ya kar ta,Γιογκιακάρτα,Џогџакарта,Джоджакарта,Джокьякарта,Джокякарта,يوجياكرتا,یوگیاکارتا,योग्यकर्ता,योग्यकार्ता,ยอกยาการ์ตา,ჯოკიაკარტა,ジョグジャカルタ市,日惹,욕야카르타', -7.8013900, 110.3647200, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66280, 'Praiyawang', 'Praiyawang', 'Jawang,Praiyawang,Yawang', -9.9354700, 120.6699700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66281, 'Wureh', 'Wureh', 'Woereh,Woeri,Wureh,Wuri', -8.3060000, 123.0421000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66282, 'Wulung', 'Wulung', 'Wulung', -7.1932000, 111.3973000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66283, 'Wuluhan', 'Wuluhan', 'Woeloehan,Wuluhan', -8.3376000, 113.5503000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66284, 'Sumberwudi', 'Sumberwudi', 'Sumberwudi,Wudi', -7.0002000, 112.3656000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66285, 'Wotu', 'Wotu', 'Wotoe,Wotu', -2.5906000, 120.8040000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66286, 'Wori', 'Wori', 'Wori', 1.5971400, 124.8524600, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66287, 'Wonosobo', 'Wonosobo', 'Wanasaba,Wonosabo,Wonosobo', -7.3588900, 109.9030600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66288, 'Wonosari', 'Wonosari', 'Wanasari,Wonasari,Wonosan,Wonosari', -7.9655600, 110.6036100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66289, 'Wonorejo', 'Wonorejo', 'Wonoredjo,Wonorejo', -2.4937000, 120.8126000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66290, 'Wonopringgo', 'Wonopringgo', 'Wanapringga,Wonopringgo', -6.9833300, 109.6166700, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66291, 'Wonogiri', 'Wonogiri', 'Wanagiri,Wonogiri', -7.8144400, 110.9205600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66292, 'Wongsorejo', 'Wongsorejo', 'Wangsaredja,Wangsoredjo,Wongsoredjo', -7.9908000, 114.4009000, 'ID', '2011-02-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66293, 'Wolowiro', 'Wolowiro', 'Wolowiro', -8.7803000, 122.0136000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66294, 'Wolowaru', 'Wolowaru', 'Wolowaroe,Wolowaru', -8.7835000, 121.8860000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66295, 'Wolosoko', 'Wolosoko', 'Wolosoko,Wolotopo', -8.8531000, 121.7107000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66296, 'Wolo', 'Wolo', 'Wolo', -8.4045000, 122.8539000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66297, 'Wlingi', 'Wlingi', 'Wilingi,Wlingi', -8.0776000, 112.3311000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66298, 'Witihama', 'Witihama', 'Witihama', -8.2996000, 123.2627000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66299, 'Wiradesa', 'Wiradesa', 'Wiradesa,Wirodeso', -6.8922000, 109.6190000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66300, 'Windusakti Hilir', 'Windusakti Hilir', 'Windusakti,Windusakti Hilir', -7.1554000, 108.7231000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66301, 'Winduasri', 'Winduasri', 'Windoeasri,Winduasri', -7.1385000, 108.7327000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66302, 'Weru', 'Weru', 'Weru', -6.7110000, 108.5037000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66303, 'Werinama', 'Werinama', 'Werinama', -3.5029000, 130.1105000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66304, 'Werasari', 'Werasari', 'Werasari', -7.0358000, 108.2346000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66305, 'Wera', 'Wera', 'Wera', -8.3400000, 120.7200000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66306, 'Weleri', 'Weleri', 'Weleri', -6.9713000, 110.0666000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66307, 'Welahan', 'Welahan', '', -6.8000000, 110.7166700, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66308, 'Wekmurak', 'Wekmurak', 'Wekmoerak,Wekmurak', -9.5622000, 124.7199000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66309, 'Wedi', 'Wedi', 'Wed,Wedi', -7.7430600, 110.5794400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66310, 'Wedarijaksa', 'Wedarijaksa', 'Wedaridjekso,Wedarijaksa,Wedarijekso', -6.6815500, 111.0716100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66311, 'Weda', 'Weda', 'Weda', 0.3295200, 127.8738900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66312, 'Waworada', 'Waworada', 'Waworada,Waworadax', -8.6995000, 118.7991000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66313, 'Watulimo', 'Watulimo', 'Watoelimo,Watulimo', -8.2211000, 111.7155000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66314, 'Watuapi', 'Watuapi', 'Watoeapi,Watuapi', -8.6122000, 121.4203000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66315, 'Wates', 'Wates', 'Wates', -7.8572200, 110.1569400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66316, 'Watansoppeng', 'Watansoppeng', 'Watan Sopeng,Watansopeng,Watansoppeng', -4.3522000, 119.8841000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66317, 'Watampone', 'Watampone', 'Bone,Boni,Watampone', -4.5386000, 120.3279000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66318, 'Warungpeuteuy', 'Warungpeuteuy', 'Waroengpeuteuj,Warungpeuteuj,Warungpeuteuy', -7.3771000, 108.0475000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66319, 'Warudoyong', 'Warudoyong', 'Waroedojong,Warudojong,Warudoyong', -7.1258000, 108.2206000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66320, 'Waru', 'Waru', 'Waroe,Waru', -6.9421000, 113.5499000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66321, 'Waren', 'Waren', 'Waren', -2.2645000, 136.3342000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66322, 'Wardo', 'Wardo', 'Wardo,Wardok', -1.0623000, 135.8416000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66323, 'Muaratiga', 'Muaratiga', 'Maratiga,Muaratiga,Waratiga', -7.6105000, 108.5850000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66324, 'Wanurian', 'Wanurian', 'Wanurian', -1.2463000, 131.5665000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66325, 'Wangon', 'Wangon', 'Wangon', -7.5161100, 109.0538900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66326, 'Wanci', 'Wanci', 'Wanchi,Wanci,Wandji,Wangi,Wanji,Wantiji,Wantji', -5.3271000, 123.5388000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66327, 'Wanasalam', 'Wanasalam', 'Wanasalam', -6.8031000, 105.9108000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66328, 'Wanareja', 'Wanareja', 'Wanaredja,Wanareja', -7.3332000, 108.6876000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66329, 'Wanaraja', 'Wanaraja', 'Wanaradja,Wanaraja', -7.1749000, 107.9808000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66330, 'Wamena', 'Wamena', 'WMX,Wamena', -4.0951200, 138.9449200, 'ID', '2016-01-23', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66331, 'Wajak', 'Wajak', 'Wadjak,Wadjok,Wajak', -8.1020000, 112.7312000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66332, 'Waiwerang', 'Waiwerang', 'Waewerang,Waiwerang', -8.3884000, 123.1648000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66333, 'Weetobula', 'Weetobula', 'Waitaboela,Waitaboela 1,Waitabula,Waitjaboelo,Weeteboela,Weetebula,Weetobula,Weëteboela', -9.4413000, 119.2323000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66334, 'Waisai', 'Waisai', 'Waigeo,Waisai', -0.2379000, 130.5072000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66335, 'Waigete', 'Waigete', 'Waigete,Wairgete', -8.6127000, 122.4198000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66336, 'Waipukang', 'Waipukang', 'Waipoekang,Waipukang', -8.3207000, 123.4638000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66337, 'Waioti', 'Waioti', 'Waioteng,Waioti,Wairotang', -8.6308000, 122.2413000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66338, 'Waingapu', 'Waingapu', 'WGP,Waingapoe,Waingapu', -9.6567000, 120.2641000, 'ID', '2013-12-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66339, 'Waimangura', 'Waimangura', 'Waimangoear,Waimangoera,Waimangura', -9.5098000, 119.2377000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66340, 'Wailebe', 'Wailebe', 'Wailebe,Wailebi', -8.3695000, 123.0005000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66341, 'Waikabubak', 'Waikabubak', 'Waikaboebak,Waikabubak,Waikatoebak', -9.6475000, 119.3889000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66342, 'Waigama', 'Waigama', 'Waigam,Waigama,Walgama', -1.8364000, 129.8316000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66343, 'Waibalun', 'Waibalun', 'Waibaloeng,Waibalon,Waibalong,Waibalun,Wailbaloeng', -8.3453000, 122.9542000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66344, 'Waibakul', 'Waibakul', 'Waibakoel,Waibakul', -9.6355600, 119.4133300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66345, 'Wahai', 'Wahai', 'WBA,Wahaai,Wahai', -2.7952900, 129.5382000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66346, 'Utan', 'Utan', 'Oetan,Utan', -8.4129000, 117.1332000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66347, 'Uta', 'Uta', 'Aoeta,Auta,Oeta,Uta', -4.5536000, 136.0339000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66348, 'Urung', 'Urung', 'Urung', 0.7841600, 103.4831200, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66349, 'Ungaran', 'Ungaran', 'Oengaran,Ungaran,Unggaran', -7.1397200, 110.4050000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66350, 'Umbulsari', 'Umbulsari', 'Oemboelsari,Umbulsari', -8.2595000, 113.4445000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66351, 'Ketapang', 'Ketapang', 'Ketapang,Umbulan Ketapang,Umbulanketibung', -4.7133500, 104.7995400, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66352, 'Uluwolo', 'Uluwolo', 'Oeloe Wolo,Uluwolo', -8.5753000, 121.2908000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66353, 'Kolaka', 'Kolaka', 'Kolaka,Oeloekolaka,Ulukolaka', -4.0597000, 121.6055600, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66354, 'Ulu', 'Ulu', 'Hoeloe,Hulu,Oeloe,Ulu,Ulu Siau', 2.7036300, 125.3937500, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66355, 'Ujungpangkah', 'Ujungpangkah', 'Udjungpangkah,Ujungpangkah', -6.9170000, 112.5551000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66356, 'Makassar', 'Makassar', 'Djumpandang,Kota Makassar,Macassar,Makasar,Makasaras,Makassar,Makasser,UPG,Udjung Pandang,Ujungpandang,makasaleu,makasar,makassaru,Макассар,ماکاسار,マカッサル,마카사르', -5.1486100, 119.4319400, 'ID', '2017-06-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66357, 'Ujungbarang Satu', 'Ujungbarang Satu', 'Oedjoengbarang,Udjungbarang,Ujungbarang,Ujungbarang Satu', -7.2200000, 108.7845000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66358, 'Ujoh Bilang', 'Ujoh Bilang', 'Ujoh Bilang,Ujohbilang', 0.5500000, 115.2500000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66359, 'Ubud', 'Ubud', 'Oeboed,Ubud,abwd,ubuda,ubudo,ywbwd,Убуд,ابود,یوبود,उबुद,ウブド', -8.5098000, 115.2654000, 'ID', '2014-08-26', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66360, 'Tuwiri Wetan', 'Tuwiri Wetan', 'Toewiri-wetan,Toewiri-wètan,Tuwiri Wetan', -6.8736000, 111.9768000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66361, 'Turus', 'Turus', 'Turus', -6.4085000, 106.0556000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66362, 'Turen', 'Turen', 'Toeren,Turen', -8.1729500, 112.6861000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66363, 'Tunjungan', 'Tunjungan', 'Toendjoengan,Tundjungan,Tunjungan', -6.9210000, 111.3698000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66364, 'Tumpang', 'Tumpang', 'Toempang,Tumpang', -8.0061000, 112.7639000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66365, 'Tulungagung', 'Tulungagung', 'Toeloengagoeng,Toeloengoeng,Tulungagung', -8.0657000, 111.9025000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66366, 'Tulangan Utara', 'Tulangan Utara', 'Toelangan,Tulangan,Tulangan Utara', -7.4737000, 112.6505000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66367, 'Tugu', 'Tugu', 'Toegoe,Toegoe 1,Tugu', -8.0265000, 111.6358000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66368, 'Tuban', 'Tuban', 'Toeban,Tuban,Тубан', -6.8976000, 112.0649000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66369, 'Tual', 'Tual', 'Toeal,Tual', -5.6193000, 132.7886000, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66370, 'Trucuk', 'Trucuk', 'Trucuk,Trutjuk', -7.7183300, 110.6588900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66371, 'Terong', 'Terong', 'Terong,Trong', -8.3911000, 123.1404000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66372, 'Trenggalek', 'Trenggalek', 'Trengalek,Trenggalek', -8.0764000, 111.7064100, 'ID', '2013-03-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66373, 'Trembulrejo', 'Trembulrejo', 'Tremboelredja,Tremboelredjo,Trembul,Trembulredjo,Trembulrejo', -7.0199000, 111.3070000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66374, 'Tarebung', 'Tarebung', 'Tarebung,Treboeng,Trebung,Triboeng,Tribung', -7.0963000, 114.2781000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66375, 'Terawas', 'Terawas', 'Terawas,Trawas', -3.0526000, 102.8149000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66376, 'Trangkil', 'Trangkil', 'Trangkil', -6.6632000, 111.0746000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66377, 'Toyapakeh', 'Toyapakeh', 'Tojapakeh,Toyapake,Toyapakeh,Toyopakeh', -8.6820000, 115.4880000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66378, 'Tongutisungi', 'Tongutisungi', 'Tongoete,Tongoete-soengi,Tongute-sungi,Tongutisungi', 1.4930500, 127.5514900, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66379, 'Tangga', 'Tangga', 'Tangga,Tongga', -8.6560000, 118.6937000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66380, 'Tondano', 'Tondano', 'Tondano', 1.3054000, 124.9126100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66381, 'Tomohon', 'Tomohon', 'Tomohon', 1.3167800, 124.8037900, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66382, 'Tombatu', 'Tombatu', 'Tombatoe,Tombatu', 1.0416800, 124.6836200, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66383, 'Tolitoli', 'Tolitoli', 'Baru,Kampoengbaroe,Kampungbaru,Tolitoli', 1.0392000, 120.8169000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66384, 'Tokojaeng', 'Tokojaeng', 'Tokodjain,Tokojaeng,Tokojain', -8.2580000, 123.5469000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66385, 'Toho', 'Toho', 'Toho', 0.4179500, 109.2200100, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66386, 'Toblong', 'Toblong', 'Toblong', -7.5609000, 107.9192000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66387, 'Tobelo', 'Tobelo', '', 1.7283700, 128.0094800, 'ID', '2007-12-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66388, 'Titiakar', 'Titiakar', 'Naka,Titiakar,Titinaka', 2.0319300, 101.5801400, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66389, 'Tiom', 'Tiom', 'TMY,Tiom', -3.9236100, 138.4547200, 'ID', '2016-01-23', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66390, 'Tinabogan', 'Tinabogan', 'Tinabogan,Tinabogang', 0.7823000, 120.5264000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66391, 'Timbang Satu', 'Timbang Satu', 'Timbang,Timbang Satu', -7.2076000, 108.6730000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66392, 'Tilamuta', 'Tilamuta', 'Boalemo,Tilamoeta,Tilamuta', 0.5273000, 122.3463000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66393, 'Tigi', 'Tigi', 'Tigi', -3.9666700, 136.2666700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66394, 'Tigaherang', 'Tigaherang', 'Tigaherang', -7.1296000, 108.4452000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66395, 'Tideng Pale', 'Tideng Pale', 'Tidangpala,Tideng Pale,Tidengpale,Tidung Pala,Tindangpala', 3.6081500, 116.9066800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66396, 'Teta Satu', 'Teta Satu', 'Teta,Teta 1,Teta Satu', -8.5685000, 118.8028000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66397, 'Ternate', 'Ternate', 'Kota Ternate,Ternate,teleunate seom,terunate dao,Тернате,テルナテ島,테르나테 섬', 0.7906500, 127.3842400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66398, 'Terbanggi Besar', 'Terbanggi Besar', 'Terbanggi Besar,Terbanggi-besar', -4.8789800, 105.2181800, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66399, 'Tepas', 'Tepas', 'Tepa,Tepas', -8.7166700, 116.9166700, 'ID', '2014-09-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66400, 'Tepal', 'Tepal', 'Tepal', -8.6261000, 117.1787000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66401, 'Tentena', 'Tentena', 'Tentana,Tentena,Tenteno', -1.7562000, 120.6480000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66402, 'Tenjolahang Timur', 'Tenjolahang Timur', 'Tendjolhang,Tenjolahang,Tenjolahang Timur', -6.3557000, 105.8561000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66403, 'Tenga', 'Tenga', 'Tenga', 1.1614600, 124.4392900, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66404, 'Tempeh Tengah', 'Tempeh Tengah', 'Tempeh Tengah,Tempeh-tengah', -8.2055000, 113.1758000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66405, 'Teminabuan', 'Teminabuan', 'Kampoeng Taminaboean,TXM,Taminaboean,Teminaboean,Teminabuan', -1.4416000, 132.0142800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66406, 'Tembongraja', 'Tembongraja', 'Tembongradja,Tembongraja', -7.1499000, 108.7600000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66407, 'Tembong', 'Tembong', 'Tembong', -7.0039000, 108.5132000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66408, 'Tembilahan', 'Tembilahan', 'Tambilaha,Tambilahan,Tembilahan', -0.3227000, 103.1603000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66409, 'Temanggung', 'Temanggung', 'Temanggoeng,Temanggung,Temangoeng,Temangung', -7.3191700, 110.1927800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66410, 'Teluksantong', 'Teluksantong', 'Santong,Teloeksantong,Teluksantong', -8.7218000, 117.8884000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66411, 'Telukpakedai', 'Telukpakedai', 'Teloekpahedai,Telukpahedai,Telukpakedai', -0.2649300, 109.1206900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66412, 'Telukdalam', 'Telukdalam', 'Telukdalam', 0.5327500, 103.2664500, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66413, 'Tlogorejo', 'Tlogorejo', 'Telagaredja,Telagaredjo,Telagredja,Telogoredjo,Tlogoredjo,Tlogorejo', -6.7097000, 111.0167000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66414, 'Tekung', 'Tekung', 'Tekong,Tekung', -8.1736000, 113.2796000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66415, 'Tehoru', 'Tehoru', 'Taharoe,Tehoroe,Tehoru,Tihoro', -3.4432000, 129.5434000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66416, 'Tegalpanjang', 'Tegalpanjang', 'Tegalpandjang,Tegalpandjang Satu,Tegalpanjang', -7.2730000, 107.1404000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66417, 'Tegallega', 'Tegallega', 'Tegallega,Tegallega Satu', -7.0463000, 107.2224000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66418, 'Tegalbuleud', 'Tegalbuleud', 'Tegalbuleud', -7.4259000, 106.7451000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66419, 'Tegalalang', 'Tegalalang', 'Banjar Tegallalang,Tegalalang,Tegallalang', -8.4366000, 115.2792000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66420, 'Tegal', 'Tegal', 'Kota Tegal,Kutha Tegal,Tegal,tgal,tygal  wsty jawa,tyghal,zhi ge,Тегал,تيغال,تگال,تیگال، وسطی جاوا,ტეგალი,直葛', -6.8694000, 109.1402000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66421, 'Tegal', 'Tegal', 'Tegal', -6.4046000, 105.8972000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66422, 'Tebing Tinggi', 'Tebing Tinggi', 'Tebing Tinggi,Tebingtinggi', -3.5842000, 103.0772000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66423, 'Tayu', 'Tayu', 'Tajoe,Tajoe-wetan,Taju,Tayu', -6.5397000, 111.0518000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66424, 'Tayan', 'Tayan', 'Tajan,Tayan', -0.0336500, 110.1018400, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66425, 'Tawun', 'Tawun', 'Tawoen,Tawun', -6.9148000, 111.7378000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66426, 'Tatelu', 'Tatelu', 'Talelu,Tateloe,Tatelu', 1.5307000, 124.9476500, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66427, 'Tasikmalaya', 'Tasikmalaya', 'Kota Tasikmalaya,TSY,Tasikmalaja,Tasikmalaya,Tasikmalaya kutha', -7.3274000, 108.2207000, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66428, 'Tarub', 'Tarub', '', -6.9333300, 109.1666700, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66429, 'Tarogong', 'Tarogong', 'Tarogong,Trogong', -7.1902000, 107.8874000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66430, 'Tarempa', 'Tarempa', 'Tarampah,Tarempa,Tarempah,Terampa,Terampah', 3.2158300, 106.2172200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66431, 'Taramana', 'Taramana', 'Taramana', -8.1675000, 124.8507000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66432, 'Tarakan', 'Tarakan', 'Kota Tarakan,Kutha Tarakan,TRK,Tarakan,ta la ka en,tarakan,tarakan  shmaly kalymantan,Таракан,تاراكان,تاراکان,تاراکان، شمالی کالیمانتان,塔拉卡恩', 3.3133200, 117.5915200, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66433, 'Taraju', 'Taraju', 'Taradjoe,Taradju,Taraju', -7.4580000, 107.9812000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66434, 'Tapalang', 'Tapalang', 'Tapalang,Taparang,Tappalang', -2.8637000, 118.8672000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66435, 'Tanjung Selor', 'Tanjung Selor', 'Tandjoeng Seilor,Tandjoengseloe,Tandjoengselor,Tandjungselor,Tanjongselor,Tanjung Selor,Tanjungselor', 2.8375000, 117.3652800, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66436, 'Tanjungsakti', 'Tanjungsakti', 'Tandjoengsakti,Tandjungsakti,Tanjungsakti', -4.1676200, 103.0687000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66437, 'Tanjungraja', 'Tanjungraja', 'Tandjoengradja,Tandjungradja,Tanjungraja', -3.3372500, 104.7745200, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66438, 'Tanjungpinang', 'Tanjungpinang', 'Tandjoengpinang,Tandjungpinang,Tanjungpinang', 0.9166700, 104.4583300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66439, 'Tanjungpati', 'Tanjungpati', 'Tandjungpati,Tanjungpati', -0.1604600, 100.6799700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66440, 'Tanjung Pandan', 'Tanjung Pandan', 'Pandan,TJQ,Tandjoengpandan,Tandjong-pandan,Tandjungpandan,Tanjong Pandan,Tanjung Pandan,Tanjungpandan', -2.7335300, 107.6347700, 'ID', '2013-09-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66441, 'Tanjung Lubuk', 'Tanjung Lubuk', 'Tandjoengloeboek,Tandjunglubuk,Tanjung Lubuk,Tanjunglubuk', -3.5267800, 104.7585800, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66442, 'Tanjungluar', 'Tanjungluar', 'Tandjoengloear,Tandjungluar,Tanjungluar', -8.7752000, 116.5177000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66443, 'Tanjungkerta', 'Tanjungkerta', 'Tandjoengkerta,Tandjungkerta,Tanjungkerta', -7.0702000, 108.6767000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66444, 'Bandar Lampung', 'Bandar Lampung', 'Bandar Lampung,Bandar-Lampung,Bandarlampung,Kota Bandar Lampung,TKG,Tanjungkarang,Tanjungkarang-Telukbetung,Telukbetung,ban da nan bang,bandaleulampung,bandaruranpun,bndr lampwng,Бандар-Лампунг,بندر لامپونگ,バンダールランプン,班達楠榜,반다르람풍', -5.4291700, 105.2611100, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66445, 'Tanjunggadang', 'Tanjunggadang', 'Tandjoeng Gadang,Tandjunggadang,Tanjunggadang', -0.7783000, 101.1982000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66446, 'Tanjunggadang', 'Tanjunggadang', 'Tandjunggadang,Tanjunggadang', -0.3012600, 100.7384100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66447, 'Tanjungbumi', 'Tanjungbumi', 'Tandjoengboemi,Tandjungbumi,Tanjungbumi', -6.8912000, 113.0799000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66448, 'Tanjungbatu', 'Tanjungbatu', 'Tandjoengbatoe,Tandjungbatu,Tanjungbatu', -3.0002000, 116.2227000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66449, 'Tanjungbatu', 'Tanjungbatu', 'Tandjungbatu,Tanjungbatu', 0.6593600, 103.4619500, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66450, 'Tanjungampalu', 'Tanjungampalu', 'Tandjungampalu,Tanjungampalu', -0.6221000, 100.8250700, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66451, 'Tanjungagung', 'Tanjungagung', 'Tandjoengagoeag,Tandjoengagoeng,Tandjungagung,Tanjungagung', -3.9372800, 103.8046500, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66452, 'Tanjung', 'Tanjung', 'Tandjoeng,Tandjung,Tanjung', -8.3560000, 116.1565000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66453, 'Tanjung', 'Tanjung', 'Tandjoeng,Tandjung,Tanjung', 4.0152700, 108.3434500, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66454, 'Tanjung', 'Tanjung', 'Tandjoeng,Tandjung,Tanjong,Tanjung', -2.1709000, 115.4077000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66455, 'Taniwel', 'Taniwel', 'Taniwel,Taniwele', -2.8524500, 128.4772000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66456, 'Tanglad', 'Tanglad', 'Tanglad', -8.7737000, 115.5831000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66457, 'Tongkiling', 'Tongkiling', 'Tangkiling,Tongkiling', -2.1357000, 113.8755000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66458, 'Tanggulangin', 'Tanggulangin', 'Tanggoelangin,Tangoelangin', -7.4995800, 112.6999200, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66459, 'Tanggul', 'Tanggul', 'Tanggoel,Tanggul', -8.1645000, 113.4525000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66460, 'Tanggeung', 'Tanggeung', 'Tanggeung', -7.2677000, 107.1236000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66461, 'Tangerang', 'Tangerang', 'Gorad Tangerang,Kota Tangerang,Kutha Tangerang,Tangarang,Tangerang,Tangerangas,tan ge lang,tang-elang,tangeran,tangrang,Горад Тангеранг,Тангеранг,تانگرانگ,ტანგერანგი,タンゲラン,坦格朗,탕에랑', -6.1780600, 106.6300000, 'ID', '2013-11-28', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66462, 'Tanahwangko', 'Tanahwangko', 'Rano wangko,Ranò wangko,Tanahwangko,Tanawangko', 1.3936800, 124.6822700, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66463, 'Tana Paser', 'Tana Paser', 'Tana Paser,Tanahgrogot', -1.9051000, 116.1913000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66464, 'Tamiang Layang', 'Tamiang Layang', 'Tamiang Layang,Tamianglajang,Tamianglayang', -2.1236000, 115.1958000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66465, 'Tamalabang', 'Tamalabang', 'Tamalabang,Tamelabang', -8.3527000, 124.2572000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66466, 'Tamberu', 'Tamberu', 'Tamberoe,Tamberoe-barat,Tamberoe-timoer,Tamberu,Temberoe,Tĕmbĕroe', -6.8981000, 113.4843000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66467, 'Tembayangan Barat', 'Tembayangan Barat', 'Tambajangan,Tambayangan,Tembayangan Barat', -6.8827000, 115.4189000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66468, 'Tambaksari', 'Tambaksari', 'Tambaksari', -7.2489000, 108.5350000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66469, 'Krajan Tambakrejo', 'Krajan Tambakrejo', 'Krajan Tambakrejo,Tambakredja,Tambakredjo,Tambakrejo', -8.4028000, 112.7145000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66470, 'Tamako', 'Tamako', 'Tamako', 3.4458900, 125.5269600, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66471, 'Talun', 'Talun', 'Taloen,Talun', -8.0906000, 112.2850000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66472, 'Teluk Kuantan', 'Teluk Kuantan', 'Taloek,Taluk,Talukkuantan,Teluk Kuantan,Telukkuantan', -0.5283000, 101.5810000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66473, 'Talok', 'Talok', 'Metaraman 2,Metaraman Dua,Talok', -8.1866900, 112.7011100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66474, 'Taliwang', 'Taliwang', 'Talavang,Taliwang', -8.7449000, 116.8532000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66475, 'Talise', 'Talise', 'Talise,Talisei,Talisej,Talisèj', 1.8334400, 125.0694900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66476, 'Tolbuk Laok', 'Tolbuk Laok', 'Talbuk,Tolbuk Laok', -6.9265000, 112.8385000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66477, 'Talawi', 'Talawi', 'Talawi', -0.5974500, 100.7397900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66478, 'Talang Ubi', 'Talang Ubi', 'Talang Ubi,Talangubi', -3.2656000, 103.8253000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66479, 'Talangbetutu', 'Talangbetutu', 'Talangbetoetoe,Talangbetutu', -2.8817000, 104.6939000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66480, 'Takokak', 'Takokak', 'Takokak,Takokak 1', -7.0513000, 107.0036000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66481, 'Takalar', 'Takalar', 'Takalar', -5.4258000, 119.4384000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66482, 'Tajinan', 'Tajinan', 'Tadjinan,Tajinan', -8.0497000, 112.6824000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66483, 'Tais', 'Tais', 'Tais', -4.0754300, 102.5773900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66484, 'Tagolu', 'Tagolu', 'Tagoloe,Tagolu,Togoloe,Togolu', -1.4393000, 120.7731000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66485, 'Taccipi', 'Taccipi', 'Taccipi,Tacipi,Taljipi,Tatjip,Tatjipi', -4.5066000, 120.1842000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66486, 'Tabing', 'Tabing', 'Tabing', -0.8720300, 100.3427900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66487, 'Tabanan', 'Tabanan', 'Tabanan', -8.5413000, 115.1252200, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66488, 'Suwaru', 'Suwaru', 'Suwaru', -8.2122000, 112.6086000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66489, 'Banjar Susut Kaja', 'Banjar Susut Kaja', 'Banjar Susut Kaja,Susut', -8.4368000, 115.3301000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66490, 'Susupu', 'Susupu', 'Soesoepoe,Susupu', 1.1512500, 127.4324300, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66491, 'Lasusua', 'Lasusua', 'Lasoeasoea,Lasusua,Soesoea,Susua', -3.5105000, 120.8844000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66492, 'Surulangun Rawas', 'Surulangun Rawas', 'Soeroelangoen,Surulangun,Surulangun Rawas', -2.6227000, 102.7634000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66493, 'Suruhwadang', 'Suruhwadang', 'Soeroehwadang,Suruhwadang', -8.1985000, 112.1049000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66494, 'Suruhan Lor', 'Suruhan Lor', 'Soeroehan-Lor,Suruhan,Suruhan Lor', -8.1546000, 111.7887000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66495, 'Surian', 'Surian', 'Soerian,Surian', -1.2558700, 100.8812900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66496, 'Kubangkepuh', 'Kubangkepuh', 'Kubangkepuh,Surataja,Surataya', -5.8994000, 106.0284000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66497, 'Surakarta', 'Surakarta', 'Gorad Surakarta,Kota Surakarta,Kutha Surakarta,SOC,Soerakarta,Solo,Sourakarta,Surakarta,Surakarte,sulakaleuta,suo luo,suo luo shi,surakarta,surakaruta,swrakarta,Σουρακάρτα,Горад Суракарта,Суракарта,Суракарте,سوراكارتا,سوراکارتا,सुरकर्ता,სურაკარტა,スラカルタ,梭罗市,索罗,수라카르타', -7.5561100, 110.8316700, 'ID', '2013-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66498, 'Surade', 'Surade', 'Surade', -7.3420000, 106.5616000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66499, 'Surabaya', 'Surabaya', 'Gorad Surabaja,Kota Surabaya,Kutha Surabaya,SUB,Soerabaja,Soerabaya,Sourabaya,Sourampagia,Surabaia,Surabaja,Surabajo,Surabaya,si shui,sulabaya,sura ba ya,surabaia,surabaya,swrabaya,swrbyh,Σουραμπάγια,Горад Сурабая,Сурабайа,Сурабая,Сурабаја,סורביה,سورابايا,سورابایا,สุราบายา,სურაბაია,スラバヤ,泗水,수라바야', -7.2491700, 112.7508300, 'ID', '2014-01-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66500, 'Surabaya', 'Surabaya', 'Soerabaja,Surabaja,Surabaya,Surabaya Ilir,Сурабайа', -4.6712200, 105.7257100, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66501, 'Suban Jeriji', 'Suban Jeriji', 'Soebandjeridii,Soebandjeridji,Suban Jeriji,Subandjeridji,Subanjeruji,Supandjeridji,Supanjeriji,Talang Djeridji', -3.7463700, 103.9640500, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66502, 'Sungsang', 'Sungsang', 'Soengsang,Sungsang,Sunsang', -2.3629000, 104.9038000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66503, 'Sungguminasa', 'Sungguminasa', 'Soenggoeminasa,Sungguhminasa,Sungguminasa', -5.1971000, 119.4510000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66504, 'Sungaikakap', 'Sungaikakap', 'Soengaikakap,Sungaikakap,Sungeikakop', -0.0519300, 109.2074100, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66505, 'Sungaisalak', 'Sungaisalak', 'Soengaisalak,Sungaisalak', -0.4381000, 103.0075000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66506, 'Sungairotan', 'Sungairotan', 'Soengairotan,Sungairotan', -3.1024500, 104.2780200, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66507, 'Sungairaya', 'Sungairaya', 'Soengai Raja,Sungairaja,Sungairaya', -2.8566000, 115.2474000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66508, 'Sungai Raya', 'Sungai Raya', 'Soengai Raya,Soengairaja,Sungai Raya,Sungairaja,Sungairaya', 0.7000000, 108.9000000, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66509, 'Sungai Pinyuh', 'Sungai Pinyuh', 'Penjoe,Soengaipenjoe,Soengaipinjoe,Sungai Pinyuh,Sungaipenju,Sungaipenyu', 0.2832000, 109.0785900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66510, 'Sungai Penuh', 'Sungai Penuh', 'Soengaipenoeh,Sungai Penuh,Sungeipenu', -2.0561000, 101.3913000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66511, 'Sungailimau', 'Sungailimau', 'Soengailimau,Soengeilimau,Sungailimau', -0.5163800, 100.0617100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66512, 'Sungailiat', 'Sungailiat', 'Soengailiat,Soengei Liat,Sungailiat', -1.8544200, 106.1221500, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66513, 'Sungaikupang', 'Sungaikupang', 'Kupang,Soengaikoepang,Sungaikupang', -3.0438000, 115.9918000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66514, 'Sungaigerong', 'Sungaigerong', 'Soengaigerong,Sungaigerong,Sungaigerung,Sungei Gerong', -2.9817000, 104.8483000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66515, 'Sungaiduri', 'Sungaiduri', 'Soengaidoeri,Sungaiduri', 0.5664000, 108.9289100, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66516, 'Sungaibengkal', 'Sungaibengkal', 'Soengaibengkal,Sungaibengkal,Sungaibengkali', -1.5360000, 102.7211000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66517, 'Sungaibali', 'Sungaibali', 'Soengaibali,Sungaibali', -3.4027000, 116.4044000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66518, 'Semurup', 'Semurup', 'Semurup,Sumurup', -1.9917000, 101.3690000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66519, 'Sumurbatu', 'Sumurbatu', 'Sumurbatu', -6.7874000, 105.8505000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66520, 'Sumuragung', 'Sumuragung', 'Soemoeragoeng,Sumuragung', -7.2196000, 113.7836000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66521, 'Sumpur Kudus', 'Sumpur Kudus', 'Sumpur,Sumpur Kudus', -0.4418000, 100.9088000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66522, 'Sumenep', 'Sumenep', 'SUP,Soemanep,Soemenap,Soemenep,Sumenep', -7.0166700, 113.8666700, 'ID', '2017-04-27', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66523, 'Sumedang Utara', 'Sumedang Utara', '', -6.8500000, 107.9166700, 'ID', '2017-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66524, 'Sumedang', 'Sumedang', 'Soemadang,Soemedang,Sumedang', -6.8586100, 107.9163900, 'ID', '2017-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66525, 'Sumberrojokrajan', 'Sumberrojokrajan', 'Sumberredjo,Sumberredjo 2,Sumberrejo,Sumberrojokrajan', -8.2441000, 112.6227000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66526, 'Sumberpucung', 'Sumberpucung', 'Soemberpoetjoeng,Sumberputjung', -8.1585600, 112.4829200, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66527, 'Krajansumbermujur', 'Krajansumbermujur', 'Krajansumbermujur,Sumbermudjur,Sumbermujur', -8.1375000, 113.0219000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66528, 'Sumbermanjing Wetan', 'Sumbermanjing Wetan', 'Soembermandjing,Sumbermandjing,Sumbermandjing-wetan,Sumbermanjing Wetan', -8.2807000, 112.6896000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66529, 'Sumbermanjing Kulon', 'Sumbermanjing Kulon', 'Soembermandjing,Soembermandjing 1,Sumbermandjing,Sumbermandjing-kulon,Sumbermanjing Kulon', -8.3013000, 112.4948000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66530, 'Sumberkalong', 'Sumberkalong', 'Sumberkalong', -8.0846000, 113.7914000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66531, 'Sumberjati', 'Sumberjati', 'Soemberdjati,Sumberdjati,Sumberjati', -8.1873000, 113.8799000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66532, 'Sumberjambe', 'Sumberjambe', 'Soemberdjambe,Sumberdjambe,Sumberjambe', -8.0699000, 113.9002000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66533, 'Sumberbaru', 'Sumberbaru', 'Soemberbaroe,Sumberbaru', -8.1177000, 113.3887000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66534, 'Sumberanyar', 'Sumberanyar', 'Soemberanjar,Sumberanjar,Sumberanyar', -7.7824000, 114.2997000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66535, 'Sumber', 'Sumber', 'Soember,Soember 1,Sumber', -6.7978000, 111.2572000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66536, 'Sumber', 'Sumber', 'Soember,Sumber', -6.7602800, 108.4830600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66537, 'Sumbawa Besar', 'Sumbawa Besar', 'SWQ,Soembawa,Soembawa-besar,Sumbawa,Sumbawa Besar', -8.4931700, 117.4202400, 'ID', '2014-01-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66538, 'Sulitair', 'Sulitair', 'Soelitair,Sulitair', -0.6125800, 100.6478800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66539, 'Sulang Tengah', 'Sulang Tengah', 'Soelang,Sulang,Sulang Tengah', -6.8065000, 111.3806000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66540, 'Sukowono', 'Sukowono', 'Soekawana,Soekowono,Sukowono', -8.0576000, 113.8342000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66541, 'Sukoharjo', 'Sukoharjo', 'Soeka ardja,Soekoardjo,Sukoardjo,Sukohardjo,Sukoharjo', -7.6725000, 110.8380600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66542, 'Sukawening', 'Sukawening', 'Sukawening', -7.1568000, 108.0065000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66543, 'Sukasari', 'Sukasari', 'Sukasari', -7.0757000, 107.8947000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66544, 'Sukasada', 'Sukasada', 'Soekasade,Sukasada,Sukasade,Sukasadel', -8.1395000, 115.1031000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66545, 'Sokaraja', 'Sokaraja', 'Soekaradja,Sokaraja,Sukaradja,Sukaraja', -7.4580600, 109.2880600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66546, 'Sukaraja', 'Sukaraja', 'Soekaradja,Sukaradja,Sukaraja', -7.4519000, 108.1944000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66547, 'Cibatu', 'Cibatu', 'Cibatu,Soekaradja,Sukaradja,Sukaraja', -7.3102000, 108.0533000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66548, 'Sukaraja', 'Sukaraja', 'Sokaradja,Sukaradja,Sukaraja', -6.5360000, 106.3124000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66549, 'Sukanagara', 'Sukanagara', 'Soekanagara,Soekanegara,Soekanĕgara,Sukanagara,Sukanegara', -7.0980000, 107.1309000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66550, 'Sukadana', 'Sukadana', 'Soekadana,Sukadana', -5.0644600, 105.5486900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66551, 'Sukadana', 'Sukadana', 'Soekadana,Sukadana,Udjungdatu', -1.2500000, 109.9500000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66552, 'Sukabumi', 'Sukabumi', 'Kota Sukabumi,Kutha Sukabumi,Soekaboemi,Sukabumi,su jia wu mei,swkabwmy,Сукабуми,Сукабумі,سوکابومی,სუკაბუმი,蘇加武眉', -6.9180600, 106.9266700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66553, 'Sudimoro', 'Sudimoro', 'Soedimoro,Sudimoro', -8.2197000, 111.3751000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66554, 'Subang', 'Subang', 'Soebang,Subang', -7.1277000, 108.5283000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66555, 'Subang', 'Subang', 'Soebang,Subang', -6.5700000, 107.7566700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66556, 'Subaim', 'Subaim', 'Sabaim,Soebai,Soebaim,Subaim,Wasile', 1.1203400, 128.1330100, 'ID', '2016-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66557, 'Stagen', 'Stagen', 'Setagin,Stagen', -3.3049000, 116.1779000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66558, 'Srono', 'Srono', 'Srono', -8.4000300, 114.2666100, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66559, 'Srandakan', 'Srandakan', '', -7.9386100, 110.2505600, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66560, 'Sragen', 'Sragen', 'Spagen,Sragen,Sregen', -7.4263900, 111.0222200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66561, 'Sowa', 'Sowa', 'Sowa', -8.3750900, 118.6900900, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66562, 'Sorong', 'Sorong', 'Kota Sorong,SOQ,Sorong,Соронг', -0.8795600, 131.2610400, 'ID', '2013-04-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66563, 'Insrom', 'Insrom', 'Insirom,Insrom', -1.1447300, 136.0313400, 'ID', '2017-02-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66564, 'Sorendiweri', 'Sorendiweri', 'Sarendiweri,Sorendeweri,Sorendiweri', -0.7338900, 135.7361100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66565, 'Soreang', 'Soreang', 'Sereang,Soreang', -7.0330600, 107.5183300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66566, 'Sondo', 'Sondo', 'Sondo', -8.7455000, 118.6650000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66567, 'Sonder', 'Sonder', 'Sonder', 1.2547400, 124.7794500, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66568, 'Somba', 'Somba', 'Somba', -3.3772000, 118.8475000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66569, 'Solok', 'Solok', 'Solok', -0.8006000, 100.6571000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66570, 'Sokobanah', 'Sokobanah', 'Sokabana,Sokabanah-daja,Sokobana,Sokobanah', -6.8900000, 113.4347000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66571, 'Soko', 'Soko', '', -7.4831500, 112.4270400, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66572, 'Sofifi', 'Sofifi', 'Sofifi', 0.7372900, 127.5588000, 'ID', '2016-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66573, 'Soe', 'Soe', 'Soe,Su,Сое', -9.8607100, 124.2839500, 'ID', '2010-01-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66574, 'Sodong Hilir', 'Sodong Hilir', 'Sodong,Sodong Hilir', -7.4894000, 108.0514000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66575, 'Sluke', 'Sluke', 'Bloeke,Sloeke,Sluke', -6.6325200, 111.4994600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66576, 'Selorok', 'Selorok', 'Selorok,Slorok', -8.1438000, 112.5259000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66577, 'Sleman', 'Sleman', 'Sleman,Suleman', -7.7155600, 110.3555600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66578, 'Slawi', 'Slawi', 'Selawi,Slawi,Slawj', -6.9816000, 109.1407000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66579, 'Slahung', 'Slahung', 'Slahung,Slaoeng,Slaung', -8.0349000, 111.4139000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66580, 'Siwa', 'Siwa', 'Siwa', -3.6999000, 120.4156000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66581, 'Situbondo', 'Situbondo', 'Sitoebanda,Sitoebondo,Situbando,Situbondo', -7.7062300, 114.0097600, 'ID', '2007-12-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66582, 'Sitiarjo', 'Sitiarjo', 'Sitiardjo,Sitiarjo', -8.3793000, 112.6811000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66583, 'Sintang', 'Sintang', 'SQG,Sintang', 0.0666700, 111.5000000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66584, 'Sinjai', 'Sinjai', 'Sindjai,Sinjai,Sinjay', -5.1241000, 120.2530000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66585, 'Singosari', 'Singosari', 'Singasari,Singosari,Сингосари', -7.8924000, 112.6658000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66586, 'Singojuruh', 'Singojuruh', 'Singodjoeroeh,Singodjuruh,Soekasari', -8.3166700, 114.2333300, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66587, 'Singkawang', 'Singkawang', 'Sekawang,Singkawang', 0.9092500, 108.9846300, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66588, 'Singkarak', 'Singkarak', 'Singkarah,Singkarak', -0.6908900, 100.6033500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66589, 'Sengkang', 'Sengkang', 'Sengkang,Singkang', -4.1279000, 120.0297000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66590, 'Singaraja', 'Singaraja', 'Boeleleng,Boelèlèng,Singaradja,Singaradzha,Singaraja,shigaraja,Сингараджа,シガラジャ', -8.1120000, 115.0881800, 'ID', '2010-01-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66591, 'Singaparna', 'Singaparna', 'Singaparna', -7.3515000, 108.1110000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66592, 'Singajaya', 'Singajaya', 'Singadjaja,Singajaya', -7.4886000, 107.9116000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66593, 'Sindangjaya', 'Sindangjaya', 'Sindangdjaja,Sindangjaya', -7.4815000, 108.6616000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66594, 'Sindangheula', 'Sindangheula', 'Sindangheula', -7.0879000, 108.8106000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66595, 'Sindangbarang', 'Sindangbarang', 'Sindangbarang', -7.4516000, 107.1353000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66596, 'Sindanghayu', 'Sindanghayu', 'Sindangajoe,Sindangaju,Sindangayu,Sindanghayu', -7.4716000, 108.6356000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66597, 'Simu', 'Simu', 'Simoe,Simu', -8.6686000, 117.6898000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66598, 'Simpur', 'Simpur', 'Simpur', -2.8281000, 115.2666000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66599, 'Simpangempat', 'Simpangempat', 'Simpangampat,Simpangempat', -3.2785000, 115.0293000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66600, 'Simpang', 'Simpang', 'Simpang,Simpang Satu', -7.3682000, 107.2166000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66601, 'Simpang', 'Simpang', 'Simpang', -7.3418000, 106.4576000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66602, 'Simpang', 'Simpang', 'Simpang', -7.1406000, 107.0033000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66603, 'Simpang', 'Simpang', 'Simpang', -4.4486700, 104.1922000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66604, 'Simpang', 'Simpang', 'Simpang', -1.2642400, 104.0970100, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66605, 'Silo', 'Silo', 'Sempolan,Sila,Silo', -8.2166700, 113.8536400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66606, 'Sila', 'Sila', 'Sila', -8.5025000, 118.6200000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66607, 'Sikka', 'Sikka', 'Sika,Sika Besar,Sikka', -8.7494000, 122.1961000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66608, 'Sijunjung', 'Sijunjung', 'Sidjoendioeng,Sidjoendjoeng,Sidjoengdjoeng,Sidjundjung,Sijunjung', -0.7005000, 100.9774000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66609, 'Sidoarjo', 'Sidoarjo', 'Sidaardja,Sidoardio,Sidoardja,Sidoardjo,Sidoarjo,Sidohardjo', -7.4478000, 112.7183000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66610, 'Sidareja', 'Sidareja', 'Sidaredja,Sidareja', -7.4846000, 108.7923000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66611, 'Siak Sri Indrapura', 'Siak Sri Indrapura', 'Siah Seri Inderapura,Siak Sri Inderapura,Siak Sri Indrapoera,Siak Sri Indrapura', 0.7931700, 102.0511000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66612, 'Sewon', 'Sewon', '', -7.8763900, 110.3588900, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66613, 'Seteluk', 'Seteluk', 'Setelai,Seteloek,Setelok,Seteluk', -8.6254900, 116.8667400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66614, 'Sesayap', 'Sesayap', 'Sesajap,Sesajap-lama,Sesayap,Sesayap Lama', 3.5852500, 117.0076500, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66615, 'Serui', 'Serui', 'Seroei,Serui,ZRI', -1.8802000, 136.2426000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66616, 'Serpong', 'Serpong', '', -6.3169400, 106.6641700, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66617, 'Seredang', 'Seredang', 'Serdang,Seredang', -6.8043000, 106.2653000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66618, 'Serasan', 'Serasan', '', 2.5111100, 109.0311100, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66619, 'Serang', 'Serang', 'Serang', -8.3077000, 112.2402000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66620, 'Serang', 'Serang', 'Kabupaten Serang,Serang', -6.1152800, 106.1541700, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66621, 'Sepit', 'Sepit', 'Sepit', -8.7418000, 116.4607000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66622, 'Sepatan', 'Sepatan', 'Sepaitan,Sepatan', -6.1188900, 106.5750000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66623, 'Sepanjang', 'Sepanjang', 'Sepandjang,Sepanjang,Sepanjang Kidul', -8.3014000, 114.0513000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66624, 'Sepang', 'Sepang', 'Sepang', -8.3089000, 114.9171000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66625, 'Sentul', 'Sentul', 'Sentoel,Sentul,Sentuli', -7.5591000, 108.7376000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66626, 'Sentul', 'Sentul', 'Sentoel,Sentul,Setol', -6.8815400, 112.4303400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66627, 'Senori', 'Senori', 'Djatisari,Senori', -7.0157000, 111.7244000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66628, 'Senori', 'Senori', 'Senor,Senori', -6.8709000, 111.9589000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66629, 'Sengeti', 'Sengeti', 'Sengeti,Sengiti,Singeti', -1.4772000, 103.5076500, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66630, 'Sangatta', 'Sangatta', 'Sangatta,Sengata', 0.5049000, 117.5279000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66631, 'Senduro', 'Senduro', 'Sendoera,Sendoero,Senduro', -8.0936000, 113.0891000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66632, 'Semuda', 'Semuda', 'Samoeda,Samuda,Sanuda,Semoeda,Semuda', -2.8617000, 112.9732000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66633, 'Sempol', 'Sempol', 'Sempo,Sempol', -8.0075000, 114.1489000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66634, 'Semongkat', 'Semongkat', 'Semongkat', -8.5721000, 117.3193000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66635, 'Semiring', 'Semiring', 'Semering,Semiring', -7.6300000, 114.0222000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66636, 'Semilat', 'Semilat', 'Semilat', -2.3077000, 112.2118000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66637, 'Semboro Lor', 'Semboro Lor', 'Semboro,Semboro Lor', -8.1901000, 113.4445000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66638, 'Sembalunlawang', 'Sembalunlawang', 'Sambaloen Lawang,Sembaloen,Sembaloenlawang,Sembalunlawang', -8.3635000, 116.5339000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66639, 'Sembalunbumbung', 'Sembalunbumbung', 'Sembaloenboemboeng,Sembalunbumbung', -8.3852000, 116.5447000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66640, 'Sembakung', 'Sembakung', 'Sembakoeng,Sembaroen', 3.8166700, 117.2500000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66641, 'Semarang', 'Semarang', 'Gorad Semarang,Kota Semarang,Kutha Semarang,SRG,Samarang,Semaran''nk,Semarang,Semarangas,cemaran,san bao long,san ma leng,se ma rang,semarangi,seumalang,smarang,sumaran,symarang,symaranj,Σεμαράνγκ,Горад Семаранг,Семаранг,سمارانگ,سيمارانج,سیمارانگ,செமாராங்,เซมารัง,სემარანგი,スマラン,三孖冷,三宝垄,三寶瓏,스마랑', -6.9930600, 110.4208300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66642, 'Semanggi', 'Semanggi', 'Samanggi,Semanggi', -7.0591000, 111.4281000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66643, 'Semamung', 'Semamung', 'Semamaeng,Semamung', -8.6515000, 117.4288000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66644, 'Selorejo', 'Selorejo', 'Seloredjo,Selorejo', -8.1392000, 112.4257000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66645, 'Selopuro', 'Selopuro', 'Selopuro', -8.1449000, 112.3086000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66646, 'Selong', 'Selong', 'Balli,Selong', -8.6503000, 116.5318000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66647, 'Selokambang', 'Selokambang', 'Selokambang', -8.1428000, 113.1662000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66648, 'Selogiri', 'Selogiri', '', -7.7833300, 110.8666700, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66649, 'Selebung', 'Selebung', 'Seleboeng,Selebung', -8.7651000, 116.4820000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66650, 'Selat Panjang', 'Selat Panjang', 'Selat Panjang,Selatpandjang,Selatpanjang,Setat Pandjang', 0.9940800, 102.7081700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66651, 'Cidolog', 'Cidolog', 'Cidolog,Selamandjah,Selamanjah', -7.3167000, 106.8395000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66652, 'Salakuray', 'Salakuray', 'Salakuray,Selakoeraj,Selakuraj,Selakuray', -7.2564000, 107.8643000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66653, 'Selasari', 'Selasari', 'Selakambang,Selakembang,Selasari', -7.6203000, 108.5205000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66654, 'Selajambe', 'Selajambe', 'Seladjambe,Selajambe', -7.1181000, 108.4625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66655, 'Selacai', 'Selacai', 'Selacai,Selatjai', -7.2156000, 108.3829000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66656, 'Selaawi', 'Selaawi', 'Selaawi', -7.3194700, 107.4784600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66657, 'Sekupang', 'Sekupang', 'Sekoepang,Sekupang', 1.1272300, 103.9267200, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66658, 'Sekongkang Bawah', 'Sekongkang Bawah', 'Sekongkang Bawah', -8.9659000, 116.7491700, 'ID', '2014-09-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66659, 'Sekayu', 'Sekayu', 'Sekaja,Sekajoe,Sekaju,Sekayu', -2.8819000, 103.8344000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66660, 'Sekernan', 'Sekernan', 'Sekarnan,Sekernan', -1.5234200, 103.5675200, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66661, 'Sekapuk', 'Sekapuk', 'Sekapoek,Sekapuk', -6.9542000, 112.5055000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66662, 'Sekampung', 'Sekampung', 'Sekampung', -5.1332600, 105.4359500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66663, 'Sekadau', 'Sekadau', 'Sekadau', 0.0166700, 110.9000000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66664, 'Segong', 'Segong', 'Segong,Sègong', -7.0875000, 108.6476000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66665, 'Seget', 'Seget', 'Kampoeng Seget,Seget', -1.4117900, 130.9747800, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66666, 'Sedinginan', 'Sedinginan', 'Sedinginan,Sidinginan', 1.5538100, 101.0152000, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66667, 'Sidayu', 'Sidayu', 'Sedaju,Sedayu,Sidajd,Sidajoe,Sidaju,Sidayu', -6.9993000, 112.5636000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66668, 'Sedanau', 'Sedanau', 'Sedanau', 3.7937700, 108.0292900, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66669, 'Sedan', 'Sedan', 'Saden,Sedan', -6.7668000, 111.5744000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66670, 'Sebulu', 'Sebulu', 'Seboekoe,Seboeloe,Sebulu', -0.2739300, 116.9983500, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66671, 'Sebuku', 'Sebuku', 'Sebuku,Siboekoe,Sibuku', 4.0023200, 117.0345600, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66672, 'Sawangan', 'Sawangan', '', -6.4027800, 106.7744400, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66673, 'Sawang', 'Sawang', 'Sawang', 0.7368000, 103.3563500, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66674, 'Saukorem', 'Saukorem', 'Saoekorem,Saokorem,Saukorem', -0.5650000, 133.1527000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66675, 'Satui', 'Satui', 'Satoei,Satoel,Satui', -3.7818000, 115.4575000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66676, 'Sarongan', 'Sarongan', 'Sarongan,Sarungan', -8.5416000, 113.9604000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66677, 'Saruaso', 'Saruaso', 'Saruaso', -0.4831000, 100.6376500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66678, 'Sarolangun', 'Sarolangun', 'Sarolangoen,Sarolangun', -2.3121000, 102.7271000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66679, 'Sarmi', 'Sarmi', 'Sarmi,Sarmo,ZRM', -1.8530200, 138.7509300, 'ID', '2015-04-26', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66680, 'Sarilamak', 'Sarilamak', 'Sarilamak', -0.1503000, 100.6640000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66681, 'Sarangmeduro', 'Sarangmeduro', 'Sarang,Sarangdjawa,Sarangmeduro,Savang', -6.7366000, 111.6698000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66682, 'Sepulu', 'Sepulu', 'Sapoeloe,Sapolo,Sapulu,Sepoeloe,Sepulu,Sĕpoeloe', -6.8976000, 112.9593000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66683, 'Sapeken', 'Sapeken', 'Sapekan,Sapeken,Sepekan', -7.0046800, 115.7061900, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66684, 'Sape', 'Sape', 'Sape,Sapeh', -8.5666700, 118.9833300, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66685, 'Sapat', 'Sapat', 'Sapat,Sapatloear,Sepat', -0.3235000, 103.3101000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66686, 'Saparua', 'Saparua', 'Saparoea,Saparua', -3.5730000, 128.6524200, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66687, 'Saonek', 'Saonek', 'Saonek', -0.4379000, 130.7559000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66688, 'Santosa', 'Santosa', 'Santosa', -7.2537000, 107.6388000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66689, 'Sausapor', 'Sausapor', 'Sansapor,Sausapor', -0.4998500, 132.0858800, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66690, 'Sangojar', 'Sangojar', 'Sangodjar,Sangojar', -7.1667000, 108.0306000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66691, 'Sangkulirang', 'Sangkulirang', 'Benoa Baroe,Benoa Baru,Benua Baru,Sangkoelirang,Sangkulirang', 0.9770000, 117.9803000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66692, 'Sanggau', 'Sanggau', 'Sanggau', 0.1333300, 110.6000000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66693, 'Kore', 'Kore', 'Kore,Sanggar', -8.3759900, 118.2987600, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66694, 'Sangasangadalam', 'Sangasangadalam', 'Sanga 2,Sangasanga,Sangasangadalam,Sangsanga-dalam', -0.6624000, 117.2365000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66695, 'Sanana', 'Sanana', 'SQN,Sanana', -2.0585300, 125.9778600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66696, 'Sampungu', 'Sampungu', 'Sampoengoe,Sampungu', -8.2655000, 118.5442000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66697, 'Sampit', 'Sampit', 'SMQ,Sampit,Tanah Hevea', -2.5315000, 112.9496000, 'ID', '2013-12-15', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66698, 'Sampang', 'Sampang', 'Sampang', -7.5633300, 109.1966700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66699, 'Sampang', 'Sampang', 'Sampand,Sampang', -7.1872000, 113.2394000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66700, 'Sampalan', 'Sampalan', 'Sampalan', -8.6736000, 115.5586000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66701, 'Samboja', 'Samboja', 'Samboaja,Sambodja,Samboja,Sembodja,Sembodjalama,Semboja,Soengaiseloeang', -1.0333300, 117.0333300, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66702, 'Sumberbaba', 'Sumberbaba', 'Samberbaba,Sumberbaba', -1.8188000, 136.7576000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66703, 'Sambas', 'Sambas', 'Sambas', 1.3333300, 109.2500000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66704, 'Samarinda', 'Samarinda', 'Batoeng Panggol,Gorad Samarynda,Kota Samarinda,Kuta Samarinda,Kutha Samarinda,SRI,Samarinda,camarinta,sa ma rin da,samalinda,samarinda,samarynda,sha ma lin da,Горад Самарында,Самаринда,ساماريندا,ساماریندا,سامارینڈا,சமாரிண்டா,ซามารินดา,サマリンダ,沙馬林達,사마린다', -0.4916700, 117.1458300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66705, 'Tanjungsamalantakan', 'Tanjungsamalantakan', 'Samalantakan,Semalantakan,Tanjungsamalantakan', -2.5818000, 116.4099000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66706, 'Salopa', 'Salopa', 'Salopa', -7.5162000, 108.2722000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66707, 'Salinbatu', 'Salinbatu', 'Salim Batu,Salimbatoe,Salimbatu,Salinbatoe,Salinbatu', 2.9405100, 117.3434300, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66708, 'Salem', 'Salem', 'Salem', -7.1825000, 108.8059000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66709, 'Sale', 'Sale', 'Sale', -6.8619000, 111.6043000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66710, 'Salawu', 'Salawu', 'Salawoe,Salawu', -7.3755000, 108.0325000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66711, 'Salatiga', 'Salatiga', '', -7.3319400, 110.4927800, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66712, 'Salakan', 'Salakan', 'Salakan', -1.3085000, 123.2909000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66713, 'Sakra', 'Sakra', 'Sakra', -8.6831000, 116.4620000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66714, 'Saketi', 'Saketi', 'Saketi,Seketi', -6.4010000, 105.9920000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66715, 'Sai', 'Sai', 'Sai,Sai-bo-oe,Saibaoe,Saibou', -8.3155000, 118.6591000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66716, 'Sagaranten', 'Sagaranten', 'Sagaranten,Saguranten', -7.2184000, 106.8851000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66717, 'Sadewata', 'Sadewata', 'Sadewata', -7.1202000, 108.3322000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66718, 'Sadang', 'Sadang', 'Sadang', -6.8764000, 111.6625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66719, 'Sadananya', 'Sadananya', 'Sadanaja,Sadananja,Sadananya', -7.2741000, 108.3149000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66720, 'Sadahayu', 'Sadahayu', 'Sadahajoe,Sadahaju,Sadahayu', -7.2153000, 108.7205000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66721, 'Sadabumi', 'Sadabumi', 'Sadaboemi,Sadabumi', -7.2137000, 108.7505000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66722, 'Sebewe', 'Sebewe', 'Sabewe,Sebewe', -8.4788000, 117.4788000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66723, 'Sabang Barat', 'Sabang Barat', 'Kampoeng Sabang Barat,Sabang Barat', 3.0072200, 107.7536100, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66724, 'Ruteng', 'Ruteng', 'RTG,Roeteng,Roeting,Ruteng', -8.6113900, 120.4644400, 'ID', '2017-04-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66725, 'Ruser', 'Ruser', 'Puser,Ruser', -8.2042000, 112.0232000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66726, 'Rumbia', 'Rumbia', 'Roembia,Rumbia', -4.6276700, 122.0047200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66727, 'Rubaru', 'Rubaru', 'Poeberoe,Roebaroe,Roeberoe,Rubaru', -6.9581000, 113.7530000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66728, 'Rokan', 'Rokan', 'Rokan', 0.5698000, 100.4075000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66729, 'Robatal', 'Robatal', 'Djlegoeng,Robatal', -7.0009000, 113.2800000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66730, 'Riung', 'Riung', 'Rioeng,Riung', -8.4213000, 121.0256000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66731, 'Riangbao', 'Riangbao', 'Riangbao,Riangeba', -8.3014000, 123.4519000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66732, 'Reo', 'Reo', 'Reo', -8.3098000, 120.4893000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66733, 'Rengat', 'Rengat', 'RGT,Rengat', -0.3754600, 102.5481000, 'ID', '2014-04-26', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66734, 'Rengasdengklok', 'Rengasdengklok', 'Rengasdengklok', -6.1591700, 107.2980600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66735, 'Rembes', 'Rembes', 'Rembes', -6.9035000, 112.1358000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66736, 'Rembangan', 'Rembangan', 'Rembang,Rembangan', -6.7036000, 111.3416000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66737, 'Rego', 'Rego', 'Rego', -8.4266000, 120.2565000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66738, 'Rawalo', 'Rawalo', 'Rawalo', -7.5369400, 109.1791700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66739, 'Ratahan', 'Ratahan', 'Rantahan,Ratahan', 1.0549000, 124.8012000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66740, 'Rasiei', 'Rasiei', 'Rasi,Rasiei,Rasjei,Rasl,Rassiei', -2.8170000, 134.5292000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66741, 'Rosong Timur', 'Rosong Timur', 'Rasang,Rosong,Rosong Timur', -7.0651000, 114.3455000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66742, 'Rarang Selatan', 'Rarang Selatan', 'Rarang,Rarang Selatan', -8.6387000, 116.3937000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66743, 'Rappang', 'Rappang', 'Rapang,Rappang', -3.8445000, 119.8173000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66744, 'Rantepao', 'Rantepao', 'Rantepao', -2.9701000, 119.8978000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66745, 'Rantaupulut', 'Rantaupulut', 'Rantaupoeloet,Rantaupulut', -2.0093000, 112.1956000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66746, 'Rantaupangiang', 'Rantaupangiang', 'Rantaupandjang,Rantaupangiang,Rantaupanjang', -2.4962000, 102.2505000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66747, 'Rantaupanjang', 'Rantaupanjang', 'Rantaupandjang,Rantaupanjang', -1.8446000, 102.3081000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66748, 'Rantau', 'Rantau', 'Rantau', -2.9334000, 115.1621000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66749, 'Ransiki', 'Ransiki', 'RSK,Ranasiki,Ransiki', -1.5083000, 134.1708000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66750, 'Rangkasbitung', 'Rangkasbitung', 'Rangkas Betung,Rangkasbitoeng,Rangkasbitung,Rangkasibitoeng', -6.3591000, 106.2494000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66751, 'Randudongkal', 'Randudongkal', 'Randoedonggal,Randoedongkal,Randudongkal,Randudongkol', -7.0981000, 109.3243000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66752, 'Randuagung', 'Randuagung', 'Randoeagoeng,Randuagung', -8.0720000, 113.3032000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66753, 'Randegan', 'Randegan', 'Randegan', -7.3522000, 108.5712000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66754, 'Rancah', 'Rancah', 'Rancah,Rancha,Ranijah,Rantjah', -7.1969000, 108.5041000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66755, 'Ranai', 'Ranai', 'NTX,Ranai', 3.9384000, 108.3840100, 'ID', '2017-01-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66756, 'Rambipuji', 'Rambipuji', 'Rambipoedji,Rambipudji,Rambipuji', -8.2090000, 113.6092000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66757, 'Ramban Wetan', 'Ramban Wetan', 'Ramban,Ramban Wetan', -7.7783000, 114.0262000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66758, 'Rajapolah', 'Rajapolah', 'Radjapolah,Radjapoloh,Rajapolah', -7.2210000, 108.1896000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66759, 'Rejamulya', 'Rejamulya', 'Radjamoelja,Radjamulia,Rajamulia,Rejamulya', -7.4789000, 108.7414000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66760, 'Rajadesa', 'Rajadesa', 'Radjadesa,Rajadesa', -7.1836000, 108.4341000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66761, 'Rainis', 'Rainis', 'Kampoeng Rainis,Painis,Paniki,Raimis,Rainis,Rainis Paniki', 4.2328200, 126.8612900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66762, 'Raha', 'Raha', 'Raba,Raha', -4.8380000, 122.7209000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66763, 'Rabig', 'Rabig', 'Rabig', -6.8148200, 106.4041700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66764, 'Raba', 'Raba', 'Raba', -8.4613000, 118.7470000, 'ID', '2014-01-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66765, 'Putussibau', 'Putussibau', 'PSU,Poetoessibau,Putusibau,Putussibau', 0.8333300, 112.9333300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66766, 'Puspahiang', 'Puspahiang', 'Poespahiang,Puspahiang', -7.4190000, 108.0497000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66767, 'Purworejo', 'Purworejo', 'Poerwaredja,Poerworedjo,Purworedjo,Purworejo', -7.7113900, 110.0102800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66768, 'Purworejo', 'Purworejo', 'Poerwaredja 1,Poerworedjo,Poewocedjo,Purworedjo,Purworejo', -6.7872000, 111.9224000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66769, 'Purwokerto', 'Purwokerto', 'Kota Purwokerto,Poerwakerta,Poerwokerto,Purwakerta,Purwokerto', -7.4213900, 109.2344400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66770, 'Purwoharjo', 'Purwoharjo', 'Purwohardjo,Purwoharjo', -8.5010000, 114.2220000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66771, 'Purwodadi', 'Purwodadi', 'Poerwadadi,Poerwodadi,Purwadadi,Purwodadi,Purwodadi Grobogan', -7.0868000, 110.9158000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66772, 'Purwakarta', 'Purwakarta', 'Kota Purwakarta,Poerwakarta,Purwakarta', -6.5569400, 107.4433300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66773, 'Puruk Cahu', 'Puruk Cahu', 'Poeroektjahoe,Poeroektjanoe,Poeroektjaoe,Puruk Cahu,Purukcahu,Puruktjahu,Puruktjau,Puruktyau', -0.5833300, 114.5833300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66774, 'Purbalingga', 'Purbalingga', 'Poerbalingga,Poerbolinggo,Purbalingga,Purbolinggo,Purbolingo', -7.3880600, 109.3638900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66775, 'Purabaya', 'Purabaya', 'Poerabaja,Purabaja,Purabaya', -7.1001000, 106.8803000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66776, 'Pundong', 'Pundong', 'Poendoeng,Poendong,Pundong,Pundung', -7.9522200, 110.3486100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66777, 'Puncakwangi', 'Puncakwangi', 'Puncaklawang,Puncakwangi,Puntjaklawang', -7.4722000, 107.4113000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66778, 'Pule', 'Pule', 'Poele,Poele 1,Pule', -8.1238000, 111.5614000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66779, 'Pulaupinang', 'Pulaupinang', 'Pulaupinang', -3.8910600, 103.5202300, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66780, 'Pulaukijang', 'Pulaukijang', 'Poelaukidjang,Pulaukidjang,Pulaukijang', -0.6868000, 103.1841000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66781, 'Pulauberingin', 'Pulauberingin', 'Poelauberingin,Poelaubringin,Pulauberingin', -4.4998200, 103.6366200, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66782, 'Pulang Pisau', 'Pulang Pisau', 'Poelangpisau,Pulang Pisau,Pulangpisau', -2.7671000, 114.2406000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66783, 'Pujiharjo', 'Pujiharjo', 'Poedjihardjo,Pudjihardjo,Pujiharjo', -8.3676000, 112.8828000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66784, 'Puger', 'Puger', 'Poeger,Poeger-koelon,Puger,Puger-kulon', -8.3702000, 113.4752000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66785, 'Probolinggo', 'Probolinggo', 'Kota Probolinggo,Prabalingga,Probalingga,Probalinggo,Probolinggo', -7.7543000, 113.2159000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66786, 'Pringsewu', 'Pringsewu', 'Pringsewu', -5.3582200, 104.9744100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66787, 'Prigen', 'Prigen', '', -7.6833300, 112.6166700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66788, 'Pretana', 'Pretana', 'Parewatana,Pretana', -9.6161000, 119.6441000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66789, 'Praya', 'Praya', 'LOP,Praja,Praya,Прая', -8.7053600, 116.2703600, 'ID', '2014-08-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66790, 'Candi Prambanan', 'Candi Prambanan', 'Candi Prambanan,Prambanan', -7.7500000, 110.4941700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66791, 'Pota', 'Pota', 'Pota,Potah', -8.3414000, 120.7607000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66792, 'Poso', 'Poso', 'PSJ,Poso,Posso,Посо', -1.3959000, 120.7524000, 'ID', '2017-06-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66793, 'Popnam', 'Popnam', 'Pobnam,Popnam', -9.6248000, 124.5315000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66794, 'Pontianak', 'Pontianak', 'Kota Pontianak,Kuta Pontianak,Kutha Pontianak,PNK,Pontianak,Pontianakas,Pontijanak,bwntyanak,kun dian,pn ti xa nak,pontianag,pontianakku,pwntyanak,pwnٹyank  anڈwnyshya,Понтианак,פונטיאנק,بونتياناك,پونتیاناک,پونٹیاناک,پونٹیانک، انڈونیشیا,ปนตีอานัก,ポンティアナック,坤甸,폰티아낙', -0.0319400, 109.3250000, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66795, 'Ponorogo', 'Ponorogo', 'Panaraga,Ponogoro,Ponorogo', -7.8685000, 111.4620000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66796, 'Pahonjean', 'Pahonjean', 'Pahonjean,Pondjean,Ponjean', -7.3248000, 108.7381000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66797, 'Pondokdalem', 'Pondokdalem', 'Pondokdalem', -8.1470000, 113.4298000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66798, 'Poncokusumo', 'Poncokusumo', 'Poncokusumo,Pontjokesoemo,Pontjokoesoemo,Pontjokusumo', -8.0522000, 112.8099000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66799, 'Polewali', 'Polewali', 'Polewali', -3.4324000, 119.3435000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66800, 'Poigar', 'Poigar', 'Piogar,Poigar', 1.0208200, 124.3089400, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66801, 'Pohgajih', 'Pohgajih', 'Pohgadjih,Pohgajih', -8.1546000, 112.4201000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66802, 'Pohbango', 'Pohbango', 'Pohbango', -6.6425000, 111.0625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66803, 'Pogalankrajan', 'Pogalankrajan', 'Pogalan,Pogalankrajan', -8.0542000, 111.7380000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66804, 'Plumbon', 'Plumbon', 'Pelumbon,Ploembon,Plumbon', -6.7050000, 108.4727800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66805, 'Plampang', 'Plampang', 'Palampang,Plampang', -8.7974000, 117.7791000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66806, 'Piru', 'Piru', 'Piroe,Piru', -3.0618000, 128.1945000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66807, 'Pinrang', 'Pinrang', 'Pinrang', -3.7861100, 119.6522200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66808, 'Pineleng', 'Pineleng', 'Pineleng', 1.4242200, 124.8386500, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66809, 'Pinara', 'Pinara', 'Pinara', -7.0866000, 108.5139000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66810, 'Pimpi', 'Pimpi', 'Pimpi', 0.8825000, 123.5502000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66811, 'Peuara', 'Peuara', 'Peuara', -8.2444000, 123.7505000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66812, 'Petung', 'Petung', 'Gerengredjo,Petoeng,Petung', -8.2068000, 113.5822000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66813, 'Patimuan', 'Patimuan', 'Patimoean,Patimuan,Petimuan', -7.5982500, 108.7551100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66814, 'Petarukan', 'Petarukan', 'Petaroekan,Petarukan', -6.8833300, 109.4333300, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66815, 'Petakbehandang', 'Petakbehandang', 'Patakbehandang,Petakbahandang,Petakbehandang', -2.0775000, 113.4364000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66816, 'Perdana', 'Perdana', 'Perdana', -6.5280000, 105.8403000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66817, 'Peranap', 'Peranap', 'Peranap,Perenap', -0.5449000, 101.9837000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66818, 'Prabumulih', 'Prabumulih', 'Peraboemoelih,Perabumulih,Praboemoelih,Prabumuli,Prabumulih', -3.4344700, 104.2305600, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66819, 'Peninjawan', 'Peninjawan', 'Penindjawan,Peninjawan', -3.8694500, 104.3823300, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66820, 'Pangaron', 'Pangaron', 'Pangaron,Pengaron', -3.3101000, 115.1961000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66821, 'Pengandonan', 'Pengandonan', 'Pengandonan', -4.0542100, 103.8766800, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66822, 'Penebel', 'Penebel', 'Panebel,Penebel,Penebel Kaja', -8.4205000, 115.1454000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66823, 'Pendolo', 'Pendolo', 'Pendolo,Pindblo,Pindolo', -2.0746000, 120.6851000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66824, 'Penanggal', 'Penanggal', 'Penanggal', -8.1423000, 113.0428000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66825, 'Pembuanghulu', 'Pembuanghulu', 'Pemboeang,Pemboeangoeloe,Pembuang,Pembuanghulu', -2.5094000, 112.1515000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66826, 'Pemangkat', 'Pemangkat', 'Pamangka,Pamangkat,Pemangkat', 1.1666700, 108.9666700, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66827, 'Pemalang', 'Pemalang', 'Pemalang', -6.9000000, 109.3666700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66828, 'Pelau', 'Pelau', 'Kampong Pelauw,Pelau,Pelauw', -3.5204000, 128.4681000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66829, 'Pelaihari', 'Pelaihari', 'Palaihari,Pelaihari,Pleihari', -3.7987000, 114.7788000, 'ID', '2015-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66830, 'Pelabuhanratu', 'Pelabuhanratu', 'Palaboehan,Palaboehanratoe,Palabuanratu,Palabuhan,Palabuhanratu,Palakoehanratoe,Pelabuanratu,Pelabuhanratu,Plabuhanratu', -6.9875000, 106.5513900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66831, 'Pelabuhan Dagang', 'Pelabuhan Dagang', 'Palaboehandagang,Pelaboehandagang,Pelabuhan Dagang,Talaboehandagang', -1.1463000, 103.0849400, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66832, 'Pekanbaru', 'Pekanbaru', 'Kota Pekanbaru,Kutha Pekanbaru,PKU,Pakanbahru,Pakanbaroe,Pakanbaru,Pekanbaroe,Pekanbaru,bei gan ba lu,pekanbalu,pkanbarw,pukanbaru,pykanbarw,Пеканбару,پکانبارو,پیکانبارو,プカンバル,北干巴魯,페칸바루', 0.5166700, 101.4416700, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66833, 'Pekalongan', 'Pekalongan', 'Kota Pekalongan,Pekalongan', -6.8886000, 109.6753000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66834, 'Pedamaran', 'Pedamaran', 'Pedamaran,Pedamarananam', -3.4884000, 104.8376000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66835, 'Pecatu', 'Pecatu', 'Pecatu,Petjatoe,Petjatu', -8.8323000, 115.1247000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66836, 'Pecangaan', 'Pecangaan', 'Pecangaan,Pecangakan,Petjangaan,Petjangakan,Petjangkan', -6.6978000, 110.7107000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66837, 'Payunga', 'Payunga', 'Pajoenga,Pajunga,Payunga', 0.5632000, 122.9519000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66838, 'Payakumbuh', 'Payakumbuh', 'Kota Payakumbuh,Paja Kombo,PajaKumbuh,Pajakoemboeh,Payakumbuh,Rayakumbuh', -0.2159000, 100.6334000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66839, 'Pemenang', 'Pemenang', 'Pawenang,Pemenang', -8.4040100, 116.1025500, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66840, 'Pauh', 'Pauh', 'Paoeh,Pau,Pauh', -2.1386000, 102.8186000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66841, 'Pototano', 'Pototano', 'Patotano,Poto Tano,Pototano', -8.4126000, 117.4811000, 'ID', '2016-10-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66842, 'Patia Kidul', 'Patia Kidul', 'Patia,Patia Kidul', -6.4860800, 105.8593100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66843, 'Pati', 'Pati', 'Pati,Пати', -6.7559000, 111.0380000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66844, 'Patemon', 'Patemon', 'Patemon', -8.1517000, 113.4536000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66845, 'Patawang', 'Patawang', 'Lapatawang,Patawang,Petawang', -9.8107000, 120.6225000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66846, 'Petaunan', 'Petaunan', 'Pataunan,Petaunan', -8.0037000, 113.9765000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66847, 'Pasuruan', 'Pasuruan', 'Kota Pasuruan,Pasoeroean,Pasuruan', -7.6453000, 112.9075000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66848, 'Pasongsongan', 'Pasongsongan', 'Pasongsongan', -6.8890000, 113.6570000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66849, 'Passo', 'Passo', 'Paso,Passo', -3.6301100, 128.2523700, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66850, 'Pasir Pengaraian', 'Pasir Pengaraian', 'Pasir Pangaraian,Pasir Pengaraian,Pasirpengarajan,Pasirpengarayan', 0.8645900, 100.2954700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66851, 'Pasirpanjang', 'Pasirpanjang', 'Pasirpandjang,Pasirpanjang', -7.3042000, 106.5267000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66852, 'Pasirnangka', 'Pasirnangka', '', -6.8295900, 106.0951400, 'ID', '2011-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66853, 'Pasirnangka', 'Pasirnangka', 'Pasirnangka', -6.7886000, 105.6289000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66854, 'Pasirmadang', 'Pasirmadang', 'Pasirmadang', -6.5983000, 106.4782000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66855, 'Pasirian', 'Pasirian', 'Pasirian', -8.2137000, 113.1146000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66856, 'Pasirgadung Satu', 'Pasirgadung Satu', 'Pasirgadoeng,Pasirgadung,Pasirgadung Satu', -6.4919000, 105.9002000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66857, 'Pasirawi', 'Pasirawi', 'Pasirawi', -7.0966000, 106.9521000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66858, 'Pasean', 'Pasean', 'Pasean,Pasian', -6.8932000, 113.5805000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66859, 'Passi', 'Passi', 'Pasi,Passi', 0.7655000, 124.2982000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66860, 'Paseh', 'Paseh', 'Paseh', -7.1026000, 107.7641000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66861, 'Pasauran', 'Pasauran', 'Pasaoeran,Pasauran', -6.2306000, 105.8325000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66862, 'Pasar Wajo', 'Pasar Wajo', 'Pasar Wajo,Pasarwadjo,Pasarwajo', -5.4957000, 122.8447000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66863, 'Pasarkuok', 'Pasarkuok', 'Pasarkuok', -1.4414000, 100.6220000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66864, 'Pasarkemis', 'Pasarkemis', 'Pasarkemis', -6.1702800, 106.5302800, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66865, 'Pasarbaru', 'Pasarbaru', 'Pasar Baharoe,Pasarbaroe,Pasarbaru', -1.3051000, 100.5099500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66866, 'Pasarbanggi', 'Pasarbanggi', 'Pasarbanggi,Pasarbangi,Paser Banggi', -6.6987000, 111.3940000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66867, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan', -7.2642000, 107.9118000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66868, 'Pesanggaran', 'Pesanggaran', 'Pasanggaran,Pesanggaran', -8.5703000, 114.0997000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66869, 'Parungrasa', 'Parungrasa', 'Parungrasa', -6.7318000, 105.9243000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66870, 'Parungponteng', 'Parungponteng', 'Paroengponteng,Parungponteng', -7.4948000, 108.1520000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66871, 'Parung', 'Parung', 'Paroeng,Parung', -6.4213900, 106.7330600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66872, 'Parumasan', 'Parumasan', 'Paroemasan 1,Parumasan', -7.5228000, 108.0474000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66873, 'Parit Malintang', 'Parit Malintang', 'Parit Malintang,Paritmalintang', -0.6204600, 100.2788500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66874, 'Paringin', 'Paringin', 'Paringin', -2.3357000, 115.4749000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66875, 'Parigi', 'Parigi', 'Parigi', -7.7015000, 108.4960000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66876, 'Parigi', 'Parigi', 'Parigi,Peoigi', -0.8156000, 120.1768000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66877, 'Pariaman', 'Pariaman', 'Kota Pariaman,Pariaman', -0.6189800, 100.1199700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66878, 'Parepare', 'Parepare', 'Parepare', -4.0135000, 119.6255000, 'ID', '2013-05-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66879, 'Pare', 'Pare', 'Pare', -7.7679000, 112.1980000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66880, 'Parakanbeusi', 'Parakanbeusi', 'Parakanbeusi', -6.5940000, 106.1911000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66881, 'Papilawe', 'Papilawe', 'Papelawe,Papilawe', -8.3153000, 123.1609000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66882, 'Papayan', 'Papayan', 'Papajan,Papayan', -7.4649000, 108.2023000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66883, 'Panyingkiran', 'Panyingkiran', 'Panjingkiran,Panyingkiran', -7.1911000, 108.0193000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66884, 'Panyindangan', 'Panyindangan', 'Panjindangan,Panyindangan', -7.5742500, 107.7589300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66885, 'Panyindangan', 'Panyindangan', 'Panjindangan,Panyindangan', -7.3964000, 107.0945000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66886, 'Panulisan', 'Panulisan', 'Panoelisan,Panulisan', -7.3079000, 108.5794000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66887, 'Panti', 'Panti', 'Panti', -8.1677000, 113.6259000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66888, 'Panti', 'Panti', 'Panti', 0.3623000, 100.0552000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66889, 'Pantaihambawang', 'Pantaihambawang', 'Pantaihambawang', -2.6465900, 115.3308700, 'ID', '2015-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66890, 'Pantai', 'Pantai', 'Pantai', -3.1313000, 116.1353000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66891, 'Panolan', 'Panolan', 'Panolan', -7.2246000, 111.5334000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66892, 'Panji', 'Panji', 'Pandji,Pandji-lor,Panji,Panji-lor', -7.7252800, 114.0995400, 'ID', '2010-05-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66893, 'Panjerrejo', 'Panjerrejo', 'Pandjerredjo,Panjerejo,Panjerrejo', -8.1382000, 112.0177000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66894, 'Panjang', 'Panjang', 'Oemboelan Pandjang,Oosthaven,Pandjang,Panjang,Panjung,Umbulan Pandjang', -5.4759000, 105.3198200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66895, 'Panjalu', 'Panjalu', 'Pandjaloe,Pandjalu,Panjalu,Penjalu', -7.1313000, 108.2661000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66896, 'Pangkalpinang', 'Pangkalpinang', 'Merawang,PGK,Pangkalpinang,Pankal Pinang', -2.1291400, 106.1137700, 'ID', '2013-05-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66897, 'Pangkalan Kasai', 'Pangkalan Kasai', 'Pangkalan Kasai,Pangkalankasai', -0.5892000, 102.3900000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66898, 'Pangkalanbuun', 'Pangkalanbuun', 'PKN,Pangkalanboeoen,Pangkalanbun,Pangkalanbuun,Soekaboemi,Sukabumi', -2.6832000, 111.6259000, 'ID', '2013-04-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66899, 'Pangkalanbunut', 'Pangkalanbunut', 'Boenoet,Bunut,Pangkalanboenoet,Pangkalanbunut', 0.2981000, 102.1461000, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66900, 'Pangkalan Balai', 'Pangkalan Balai', 'Pangkalan Balai,Pangkalanbalai,Pangkalanbelai', -2.8812000, 104.3943000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66901, 'Pangkalan', 'Pangkalan', 'Pangkalan', -6.6276000, 111.4904000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66902, 'Pangkajene', 'Pangkajene', 'Pangkadjene,Pangkajene', -4.8372000, 119.5472000, 'ID', '2013-12-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66903, 'Krajan Pangkah Kulon', 'Krajan Pangkah Kulon', 'Krajan Pangkah Kulon,Pangka,Pangka-kulon,Pangkah-koelon,Pangkah-kulon', -6.9158000, 112.5541000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66904, 'Panggungrejo', 'Panggungrejo', 'Panggoengredjo,Panggungredjo,Panggungrejo', -8.2512000, 112.2787000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66905, 'Panggul', 'Panggul', 'Panggoel,Panggul', -8.2492000, 111.4554000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66906, 'Pangauban', 'Pangauban', 'Pangaoeban,Pangauban', -7.2634000, 107.7785000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66907, 'Pangasinan', 'Pangasinan', 'Pangasinan', -7.4066000, 108.5292000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66908, 'Pangarengan', 'Pangarengan', 'Pangarengan', -5.9571400, 106.0726600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66909, 'Pandeglang', 'Pandeglang', 'Pandegelang,Pandeglang', -6.3084000, 106.1067000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66910, 'Pandan', 'Pandan', 'Pandan', -6.7335000, 111.4507000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66911, 'Pandaan', 'Pandaan', 'Pandaan,Pandakara,Pandaän,Paodakan', -7.6526800, 112.6875000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66912, 'Pandak', 'Pandak', '', -7.9130600, 110.2936100, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66913, 'Pancur', 'Pancur', 'Pancur,Pantjur', -6.7215000, 111.4684000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66914, 'Panawangan', 'Panawangan', 'Panawangan', -7.1180000, 108.3816000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66915, 'Panarukan', 'Panarukan', 'Panaroekan', -7.7018100, 113.9184400, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66916, 'Panaragan', 'Panaragan', 'Panaragan,Panarangan', -4.4778400, 105.0814200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66917, 'Penanggapan', 'Penanggapan', 'Pananggapan,Penanggapan', -7.0633000, 108.7875000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66918, 'Penajam', 'Penajam', 'Panajam,Penadjam,Penajam', -1.2491900, 116.7696800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66919, 'Panacaran', 'Panacaran', 'Panacaran,Panatjaran', -6.6606000, 105.9240000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66920, 'Pamulang', 'Pamulang', '', -6.3427800, 106.7383300, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66921, 'Pompanua', 'Pompanua', 'Pampamua,Pampanoea,Pampanua,Pompanoea,Pompanua', -4.2254000, 120.1484000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66922, 'Pamoyanan', 'Pamoyanan', 'Pamojanan,Pamoyanan', -7.3066000, 107.1798000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66923, 'Pamoyanan', 'Pamoyanan', 'Pamojanan,Pamoyanan', -7.1252000, 108.1538000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66924, 'Pamotan', 'Pamotan', 'Pamotan', -6.7609000, 111.4898000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66925, 'Pameungpeuk', 'Pameungpeuk', 'Pameungpeak,Pameungpeuk,Pamong Pok,Pamoungpeuk', -7.6413000, 107.7332000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66926, 'Pameungpeuk', 'Pameungpeuk', 'Pameungpeuk', -7.3798000, 106.8148000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66927, 'Pameungpeuk', 'Pameungpeuk', '', -7.0183300, 107.6038900, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66928, 'Pamekasan', 'Pamekasan', 'Pamekasan,Ramekasan', -7.1568000, 113.4746000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66929, 'Pamarican', 'Pamarican', 'Pamarican,Pamaritjan', -7.4576000, 108.5240000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66930, 'Pamanukan', 'Pamanukan', 'Pamanoekan,Pamanukan', -6.2841700, 107.8105600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66931, 'Cinyumput', 'Cinyumput', 'Cinyumput,Pamalajan,Pamalayan', -7.3837400, 107.5096200, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66932, 'Pamakayo', 'Pamakayo', 'Pamakajoe,Pamakaju,Pamakayo,Pamakayu', -8.4368000, 122.9830000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66933, 'Palumbungan', 'Palumbungan', 'Paloemboengan,Palumbungan', -7.6329000, 108.4156000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66934, 'Palu', 'Palu', 'Kabupaten Poso,Kota Palu,PLW,Pal,Paloe,Palu,Пал', -0.9083300, 119.8708300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66935, 'Palopo', 'Palopo', 'LLO,Palopo,Paloppo,Wara', -2.9925000, 120.1969400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66936, 'Palla', 'Palla', 'Palla', -9.5266000, 119.3552000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66937, 'Palimanan', 'Palimanan', 'Palimanan', -6.7069400, 108.4241700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66938, 'Palembaian', 'Palembaian', 'Palembaian,Palembajan,Palembayan', -0.1833300, 100.2333300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66939, 'Palembang', 'Palembang', 'Gorad Palembang,Kota Palembang,Kutha Palembang,PLM,Palembang,Palembangas,Palempan''nk,Palimbao,Palimbão,Palèmbang,balymbanj,ju gang,pa lem bang,palembanga,pallembang,palmbang,palymbang,parenban,Παλεμπάνγκ,Горад Палембанг,Палембанг,باليمبانج,پالمبانگ,پالم‌بانگ,پالیمبانگ,पालेंबांग,ปาเล็มบัง,パレンバン,巨港,팔렘방', -2.9167300, 104.7458000, 'ID', '2015-06-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66940, 'Pelem Satu', 'Pelem Satu', 'Palem,Pelem,Pelem 1,Pelem Satu', -8.0437000, 111.4583000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66941, 'Palattae', 'Palattae', 'Palatae,Palattae', -4.9711000, 120.1127000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66942, 'Palangkaraya', 'Palangkaraya', 'Kota Palangka Raya,PKY,Pahandoet,Pahandut,Palangka Raya,Palangkaraja,Palangkaraya,Plangkaraja,pa lang ka la ya,帕朗卡拉亚', -2.2083300, 113.9166700, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66943, 'Palang Utara', 'Palang Utara', 'Palang,Palang Utara,Talang', -6.9025000, 112.1400000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66944, 'Palakka', 'Palakka', 'Palaka,Palakka', -4.5313000, 120.2892000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66945, 'Pakuan Agung', 'Pakuan Agung', 'Pakoeanagoeng,Pakuan Agung', -4.6648100, 104.9629300, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66946, 'Kuaro', 'Kuaro', 'Kuaro,Pakoetkowaro,Pakotkoearo,Pakotkuaro', -1.8198000, 116.0797000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66947, 'Pakong', 'Pakong', 'Pakong', -7.0311000, 113.5496000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66948, 'Pakisaji', 'Pakisaji', 'Pakisadji,Pakisadji l,Pakisaji', -8.0665000, 112.5981000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66949, 'Pakis', 'Pakis', 'Pakis', -6.5600000, 105.9613000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66950, 'Pakenjeng', 'Pakenjeng', 'Pakendjeng,Pakenjeng', -7.4118100, 107.6904900, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66951, 'Pakembangan', 'Pakembangan', 'Pakembangan', -7.0224000, 108.5268000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66952, 'Pakel', 'Pakel', 'Pakel', -8.1543000, 111.8264000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66953, 'Paitoko', 'Paitoko', 'Paitoko,Peitoko', -8.3633000, 124.8944000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66954, 'Painan', 'Painan', 'Painan,Parnau', -1.3517200, 100.5738300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66955, 'Pai', 'Pai', 'Pai', -8.4316000, 119.0255000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66956, 'Pagerageung', 'Pagerageung', 'Pagerageung', -7.1124000, 108.1668000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66957, 'Pagelaran', 'Pagelaran', 'Pagelaran,Pagelran', -8.1975000, 112.6203000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66958, 'Pagelaran', 'Pagelaran', 'Pagelaran', -6.8155000, 106.0401100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66959, 'Pagelaran', 'Pagelaran', 'Pagelaran', -6.4330000, 105.8572000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66960, 'Pagatan', 'Pagatan', 'Pagatan,Pegatan', -3.6075000, 115.9381000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66961, 'Pagatan', 'Pagatan', 'Pagatan,Pegatan', -3.1701000, 113.2881000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66962, 'Pagat', 'Pagat', 'Pagat', -2.6243000, 115.4338000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66963, 'Pagar Alam', 'Pagar Alam', 'PXA,Pagar Alam,Pageralam', -4.0250600, 103.2469400, 'ID', '2016-06-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66964, 'Pagak', 'Pagak', 'Pagak', -8.2258000, 112.5276000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66965, 'Paga', 'Paga', 'Paga', -8.7766000, 122.0455000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66966, 'Pademawu', 'Pademawu', 'Pademaboe,Pademabu,Pademawu', -7.1862000, 113.5257100, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66967, 'Padarincang', 'Padarincang', 'Padanintjan,Padarincang,Padarintjan,Padarintjang', -6.2140000, 105.9512000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66968, 'Padangulaktanding', 'Padangulaktanding', 'Padangoelaktanding,Padangulaktanding', -3.3749000, 102.7996000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66969, 'Padangtikar', 'Padangtikar', 'Padangtikar', -0.6913000, 109.2632700, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66970, 'Padangguci', 'Padangguci', 'Padanggoetji,Padangguci,Padanggutji,Padanggutyi', -4.5889100, 103.1442500, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66971, 'Padangcermin', 'Padangcermin', 'Padangcermin,Padangtjermin', -5.6007500, 105.1387000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66972, 'Padangbatung', 'Padangbatung', 'Padangbatoeng,Padangbatung', -2.8380000, 115.2912000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66973, 'Padangan', 'Padangan', 'Padangan', -7.1536000, 111.6146000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66974, 'Padangbai', 'Padangbai', 'Padang,Padangbai,Padangbaj,Падангбай', -8.5317000, 115.5072000, 'ID', '2016-10-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66975, 'Padang', 'Padang', 'Gorad Padang,Kota Padang,Kuta Padang,Kutha Padang,PDG,Padang,Padangas,Padango,ba dong,badangh,pa dang,padan,padang,padanga,padng  andwnzy,Горад Паданг,Паданг,بادانغ,پادانگ,پادنگ، اندونزی,پاڈانگ,पादांग,ปาดัง,パダン,巴東,파당', -0.9492400, 100.3542700, 'ID', '2012-02-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66976, 'Padaherang', 'Padaherang', 'Padaberang,Padabérang,Padaherang', -7.5499000, 108.6956000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66977, 'Padabeunghar', 'Padabeunghar', 'Padabeunghar', -7.0147000, 106.8047000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66978, 'Pacitan', 'Pacitan', 'Pachitan,Pacitan,Patjitan', -8.1938900, 111.1033300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66979, 'Paciran', 'Paciran', 'Pachiran,Patjiran', -6.8766600, 112.3760600, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66980, 'Pacar', 'Pacar', 'Paca,Pacar,Patja', -8.4824000, 120.2011000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66981, 'Pabuaran', 'Pabuaran', 'Paboewaran,Pabuaran,Pabuwaran 3', -6.2043000, 106.0711000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66982, 'Oransbari', 'Oransbari', 'Oransbari', -1.3442000, 134.2587000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66983, 'Ondong Siau', 'Ondong Siau', 'Ondong,Ondong Siau', 2.7473000, 125.3611000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66984, 'Olejet', 'Olejet', 'Olecet,Olejet,Oletjet', -6.9924000, 108.5693000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66985, 'Oetuke', 'Oetuke', 'Oetoeke,Oetuke,Oëtoeke', -9.9909000, 124.5543000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66986, 'Nunhala', 'Nunhala', 'Nunhala,Oehala', -9.6218000, 124.4923000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66987, 'Obano', 'Obano', 'OBD,Obano', -3.9259000, 136.2259000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66988, 'Nyapar', 'Nyapar', 'Ngapar,Njapar,Nyapar', -6.9055000, 113.8317000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66989, 'Nyalindung', 'Nyalindung', 'Njalindoeng,Njalindung,Nyalindung', -7.0426000, 106.9442000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66990, 'Numba', 'Numba', 'Noemba,Numba', -8.8067000, 121.5265000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66991, 'Nuhawala', 'Nuhawala', 'Noehawaila,Noehawala,Nuhawala', -8.3747000, 124.2389000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66992, 'Ntonggu', 'Ntonggu', 'Ntonggoe,Ntonggu', -8.5302000, 118.7610000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66993, 'Ntoke', 'Ntoke', 'Ntoke', -8.4083000, 118.9066000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66994, 'Noenoni', 'Noenoni', 'Noenoni,Noilnoni', -9.7297000, 124.3737000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66995, 'Nogosari', 'Nogosari', 'Nogosari', -8.1882000, 113.2936000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66996, 'Noemuti', 'Noemuti', 'Noemoeti,Noemuti,Noëmoeti', -9.5680000, 124.4950000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66997, 'Noeltoko', 'Noeltoko', 'Noeltoko,Noiltoko,Nuitoko', -9.5373000, 124.3596000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66998, 'Nobo', 'Nobo', 'Nobo', -8.4851000, 122.7896000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(66999, 'Nita', 'Nita', 'Nita', -8.6782000, 122.1706000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67000, 'Nipah Panjang', 'Nipah Panjang', 'Nipah Panjang,Nipahpandiang,Nipahpanjang', -1.0751800, 104.1943800, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67001, 'Nikiniki', 'Nikiniki', 'Nikiniki', -9.8136100, 124.4764900, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67002, 'Ngunut', 'Ngunut', 'Ngoenoet', -8.1058000, 112.0159100, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67003, 'Ngrejo', 'Ngrejo', 'Ngredjo,Ngrejo', -8.1014000, 112.5036000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67004, 'Ngrayun', 'Ngrayun', 'Ngrajoen,Ngrajun,Ngrayun', -8.0723000, 111.4489000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67005, 'Ngoro', 'Ngoro', 'Ngara', -7.6838600, 112.2580400, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67006, 'Nglongsor', 'Nglongsor', 'Nglongsor', -8.0471000, 111.6623000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67007, 'Ngliron', 'Ngliron', 'Ngliron', -7.1056000, 111.4261000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67008, 'Nglengkir', 'Nglengkir', 'Nglengkir', -6.9199000, 111.5112000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67009, 'Nginokrajan', 'Nginokrajan', 'Ngina,Ngino,Nginokrajan', -6.9936000, 112.0647000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67010, 'Nggalak', 'Nggalak', 'Nggalak', -8.3539000, 120.3173000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67011, 'Ngebruk', 'Ngebruk', 'Ngebroek,Ngebruk', -8.1504000, 112.5165000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67012, 'Ngawi', 'Ngawi', 'Ngawi', -7.4038000, 111.4461000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67013, 'Ngawen', 'Ngawen', 'Ngawen', -7.0032000, 111.3129000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67014, 'Ngantru', 'Ngantru', 'Ngantroe,Ngantru', -8.0101000, 111.9254000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67015, 'Nganjuk', 'Nganjuk', 'Ngandjoek,Ngandjuk,Nganjuk', -7.6051000, 111.9035000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67016, 'Ngandang', 'Ngandang', 'Ngandang', -6.8160000, 111.5559000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67017, 'Ngamplang', 'Ngamplang', 'Ngamplang', -7.2543000, 107.8999000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67018, 'Ngabang', 'Ngabang', 'Ngabang', 0.3833300, 109.9500000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67019, 'Sirnagalih', 'Sirnagalih', 'Nengtet,Sirnagalih', -6.2888000, 105.9973000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67020, 'Nele', 'Nele', 'Nela,Nele', -8.6767000, 122.2144000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67021, 'Neglasari', 'Neglasari', 'Neglasari', -7.5147000, 107.8086000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67022, 'Negararatu', 'Negararatu', 'Negararatoe,Negararatu', -4.6560300, 104.7357600, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67023, 'Negara', 'Negara', '', -8.3569400, 114.6169400, 'ID', '2014-06-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67024, 'Nefoneut', 'Nefoneut', 'Nefoneoel,Nefoneoet,Nefoneut,Nefoneöet', -9.7114000, 123.7971000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67025, 'Nebe', 'Nebe', 'Nebe', -8.4741000, 122.5615000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67026, 'Detukeli', 'Detukeli', 'Detukeli,Nd Keli,Ndetokeli', -8.6318000, 121.8195000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67027, 'Ndano', 'Ndano', 'Ndano', -8.4960000, 118.5407000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67028, 'Natar', 'Natar', 'Natar', -5.3089700, 105.1925100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67029, 'Narmada', 'Narmada', 'Narmada', -8.5912000, 116.2020000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67030, 'Naringgul', 'Naringgul', 'Naringgul', -7.3344000, 107.3282000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67031, 'Napu', 'Napu', 'Napoe,Napu', -9.3962700, 119.9263700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67032, 'Nangtang', 'Nangtang', 'Nangtang', -7.3482000, 107.9870000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67033, 'Nangkaruka', 'Nangkaruka', 'Nangkaroeka,Nangkaruka', -7.4331000, 107.6462000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67034, 'Nangela', 'Nangela', 'Nangela,Nanggela', -7.2060000, 108.5359000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67035, 'Nangaroro', 'Nangaroro', 'Nangaroro', -8.7872000, 121.3923000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67036, 'Nangaraba', 'Nangaraba', 'Nangaraba', -8.3154000, 118.7681000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67037, 'Nangah Pinoh', 'Nangah Pinoh', 'NPO,Nanga Pinoh,Nangah Pinoh,Nangapinoh,Sintang', -0.3333300, 111.7333300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67038, 'Kolo', 'Kolo', 'Kolo,Nae,Nanganae', -8.3722000, 118.7193000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67039, 'Nangalimang', 'Nangalimang', 'Nangalima,Nangalimang', -8.6469000, 122.2058000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67040, 'Nangalili', 'Nangalili', 'Nangalele,Nangalili', -8.7765000, 120.1310000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67041, 'Nangahale', 'Nangahale', 'Nangahale', -8.5590000, 122.5065000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67042, 'Nanga Bulik', 'Nanga Bulik', 'Nanga Bulik,Nangaboelik,Nangabulik', -2.1624000, 111.4885000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67043, 'Namrole', 'Namrole', 'NRE,Nam'' Role,Namrole,Nam’ Role', -3.8454800, 126.7261900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67044, 'Namlea', 'Namlea', 'Nam'' Lea,Namlea,Nam’ Léa', -3.2619400, 127.0929200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67045, 'Nagrak', 'Nagrak', 'Nagrak', -6.8954000, 106.4651000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67046, 'Nabire', 'Nabire', 'NBX,Nabarie,Nabire', -3.3598900, 135.5007400, 'ID', '2013-05-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67047, 'Muruy', 'Muruy', 'Muruj,Muruy', -6.3663000, 105.8999000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67048, 'Muraloka', 'Muraloka', 'Moera,Mura,Muraloka', -8.7721300, 116.8793200, 'ID', '2014-09-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67049, 'Muer', 'Muer', 'Moer,Muer,Mur', -8.7490000, 117.7305000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67050, 'Muntok', 'Muntok', 'Mentok,Muntok', -2.0671900, 105.1622800, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67051, 'Muntilan', 'Muntilan', 'Moentilan,Muntilan', -7.5811100, 110.2927800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67052, 'Munjungan', 'Munjungan', 'Moedjoengan,Moendjoengan,Mudjungan,Mujungan,Mundjungan,Munjungan', -8.3031000, 111.5786000, 'ID', '2012-05-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67053, 'Munjul', 'Munjul', 'Moendjoel,Mundjul,Munjul', -6.6105000, 105.8989000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67054, 'Mungkin', 'Mungkin', 'Moengkin,Mungkin', -8.7510600, 117.1270500, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67055, 'Munduk', 'Munduk', 'Moendoek,Munduk,Мундук', -8.2686600, 115.0794700, 'ID', '2010-03-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67056, 'Muncar', 'Muncar', 'Moentjar,Muncar,Muntjar', -8.4333300, 114.3333300, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67057, 'Muncang', 'Muncang', 'Moentjang,Muncang,Muntjang', -6.5443000, 106.2911000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67058, 'Mulia', 'Mulia', 'LII,Mulia', -3.7147200, 137.9852800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67059, 'Mulankera', 'Mulankera', 'Moelan,Moelang,Mulan,Mulang,Mulankera', -8.5162000, 123.4854000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67060, 'Mukusaki', 'Mukusaki', 'Moekoe Saki,Mukusaki', -8.5653300, 121.6167100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67061, 'Mukomuko', 'Mukomuko', 'Moekomoeko,Moko Moko,Mukomuko', -2.5689000, 101.1118000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67062, 'Mujur', 'Mujur', 'Moedjoer,Mudjur,Mujur', -8.7617000, 116.3548000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67063, 'Muarauya', 'Muarauya', 'Moearaoeja,Muarauja,Muarauya', -1.8875000, 115.5950000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67064, 'Muara Teweh', 'Muara Teweh', 'Moearatewe,Moearateweh,Muara Teweh,Muaratawe,Muaratewa,Muaratewe,Muarateweh', -0.9500000, 114.8833300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67065, 'Muara Tembesi', 'Muara Tembesi', 'Moearatembesi,Muara Tembesi,Muaratemusi,Muarotembesi', -1.7109000, 103.1182000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67066, 'Muara Tebo', 'Muara Tebo', 'Moearatebo,Muara Tebo,Muarotebo', -1.4760000, 102.4435000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67067, 'Muarasiau', 'Muarasiau', 'Moearasian,Moearasiau,Moearaslau,Muarasiau', -2.2730000, 102.0998000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67068, 'Muara Sabak', 'Muara Sabak', 'Moearasabak,Moenrasabak,Muara Sabak,Muarasabak', -1.1361200, 103.8498700, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67069, 'Muararupit', 'Muararupit', 'Moeararoepit,Muararupit,Muarorupit', -2.7236000, 102.9108000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67070, 'Muarapinang', 'Muarapinang', 'Moearapinang-baroe,Muarapinang,Muarapinang-baru', -3.8503000, 103.0533000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67071, 'Muaralimun', 'Muaralimun', 'Muaralimun', -2.3967000, 102.6389000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67072, 'Muaralembu', 'Muaralembu', 'Muaralembu', -0.3808000, 101.3395000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67073, 'Muaralakitan', 'Muaralakitan', 'Moearalakitan,Muaralakitan', -2.8594000, 103.3039000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67074, 'Muaralabuh', 'Muaralabuh', 'Moearalaboeh,Muaralabuh,Muarolabu', -1.4621000, 101.0230000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67075, 'Muarakuang', 'Muarakuang', 'Moearakoeang,Muarakuang', -3.6664800, 104.5671700, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67076, 'Muarakomam', 'Muarakomam', 'Muarakomam,Muarakoman', -1.6785000, 115.8129000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67077, 'Muara Enim', 'Muara Enim', 'Moearaenim,Muara Enim,Muaraenim,Muarunim', -3.6486000, 103.7710000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67078, 'Muara Dua', 'Muara Dua', 'Moearadoe,Moearadoea,Muara Dua,Muaraduwa', -4.5317800, 104.0739700, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67079, 'Muaracikadu', 'Muaracikadu', 'Moearatjikadoe,Muaracikadu,Muaratjikadu', -7.4217000, 107.1546000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67080, 'Muara Bungo', 'Muara Bungo', 'Moearaboengo,Muara Bungo,Muarabungo', -1.4901800, 102.1149000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67081, 'Muara Bulian', 'Muara Bulian', 'Moearaboelian,Muara Bulian', -1.7132700, 103.2590200, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67082, 'Binuangeun', 'Binuangeun', 'Binoeangeun,Binuangeun,Moearabinoeangeun,Moearbinoeangeun,Muarabinuangeun', -6.8374900, 105.8850800, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67083, 'Muara Beliti', 'Muara Beliti', 'Moearaboliti,Muara Beliti,Muarabeliti,Muarabliti,Muarabuliti,Muarobliti', -3.2486000, 103.0335000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67084, 'Muarabadak', 'Muarabadak', 'Koealabadak,Moearabadak,Muarabadak', -0.3508500, 117.4352300, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67085, 'Muaro', 'Muaro', 'Moeara,Muara,Muaro', -0.6638700, 100.9581800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67086, 'Mrayun', 'Mrayun', 'Mrajun,Mrayun', -6.8762000, 111.5877000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67087, 'Mranggen', 'Mranggen', 'Mranggen', -7.0268000, 110.5158000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67088, 'Moro', 'Moro', 'Mora,Moro,Penju,Penyu', 0.7541700, 103.7083300, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67089, 'Montongsekar', 'Montongsekar', 'Mantong,Montang,Montangsekar,Montong,Montongsekar', -6.9489000, 111.8809000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67090, 'Munse', 'Munse', 'Monse,Munse', -4.0967000, 123.2519000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67091, 'Mondokan', 'Mondokan', 'Mondokan', -6.8852000, 112.0253000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67092, 'Molobulahe', 'Molobulahe', 'Moelomboelahe,Molobulahe,Molomboelahe,Molombulahe', 0.6326000, 122.5748000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67093, 'Molibagu', 'Molibagu', 'Malibagu,Molibagoe,Molibagu,Molobagoe', 0.3862000, 123.9824000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67094, 'Mojosari', 'Mojosari', 'Madjasari,Modjosari,Mojosari', -7.5194000, 112.5597000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67095, 'Mojokerto', 'Mojokerto', 'Kota Mojokerto,Madjakerta,Modjokerto,Mojokerto', -7.4664000, 112.4338000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67096, 'Mojoagung', 'Mojoagung', 'Madja agoeng,Madjaagung,Modjoagoeng,Modjoagung,Mojoangung', -7.5666700, 112.3500000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67097, 'Mlonggo', 'Mlonggo', '', -6.5333300, 110.7000000, 'ID', '2013-11-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67098, 'Metro', 'Metro', 'Kota Metro,Metra,Metro,Метро', -5.1130600, 105.3066700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67099, 'Mertoyudan', 'Mertoyudan', 'Mertajoedan,Mertojoedan,Mertojudan,Mertoyudan', -7.5200000, 110.2263900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67100, 'Mersam', 'Mersam', 'Mersam', -1.6982300, 102.9976000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67101, 'Margoyoso', 'Margoyoso', 'Margoyoso,Mergadjasa,Mergojoso,Mergoloso,Mergoyoso', -6.5930000, 111.0652000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67102, 'Margotuhu Kidul', 'Margotuhu Kidul', 'Margotuhu Kidul,Matgotuhu Kidul,Mergatoehoe Kidoel,Mergotuhukidul', -6.5781000, 111.0606000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67103, 'Merakurak', 'Merakurak', 'Merakurak', -6.8783000, 111.9863000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67104, 'Mensalong', 'Mensalong', 'Mensaloeng,Mensalong,Mensalung', 3.7588300, 116.7453200, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67105, 'Menjalin', 'Menjalin', 'Mendjalin,Menjalin', 0.4693500, 109.3382800, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67106, 'Mengkalip', 'Mengkalip', 'Mengkalip,Mengkatip', -2.1488000, 114.8819000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67107, 'Menggala', 'Menggala', 'Menggala', -4.4713100, 105.2521400, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67108, 'Menganti', 'Menganti', 'Meganti,Menganti', -7.5491700, 109.1563900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67109, 'Menes', 'Menes', 'Menes', -6.3755300, 105.9187200, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67110, 'Mendenrejo', 'Mendenrejo', 'Mendenredjo,Mendenrejo', -7.2383000, 111.4450000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67111, 'Mempawah', 'Mempawah', 'Mampawa,Mampawah,Mempawah', 0.3710200, 108.9701300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67112, 'Meluwung', 'Meluwung', 'Meloewoeng,Meluwung', -7.3936000, 108.7012000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67113, 'Meliau', 'Meliau', 'Meliau', -0.1253300, 110.2896200, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67114, 'Melati', 'Melati', 'Melati,Mlati', -7.7333300, 110.3666700, 'ID', '2012-10-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67115, 'Melahayu', 'Melahayu', 'Melahajoe,Melahaju,Melahayu', -7.0260000, 108.8269000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67116, 'Mega', 'Mega', 'Kampoeng Mega,Mega,Nega', -0.6639200, 131.9048700, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67117, 'Borong', 'Borong', 'Borong,Kampoeng Mborong,Mborong,Nboro', -8.8125000, 120.6097200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67118, 'Mayong', 'Mayong', 'Majong,Mayong', -8.2443000, 114.9625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67119, 'Mayang', 'Mayang', 'Majang,Mayang', -8.1762000, 113.7958000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67120, 'Mauponggo', 'Mauponggo', 'Maoeponggo,Mauponggo', -8.8892000, 121.2112000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67121, 'Maunura', 'Maunura', 'Manoeran,Maoenoera,Maunura', -8.8819000, 121.3640000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67122, 'Maundai', 'Maundai', 'Maoe Ndai,Maundai', -8.8993000, 121.2901000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67123, 'Maumere', 'Maumere', 'MOF,Maoemere,Maomere,Maumere,Mauniere', -8.6199000, 122.2111000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67124, 'Matur', 'Matur', 'Matoer,Matur', -0.2787700, 100.2880200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67125, 'Mataram', 'Mataram', 'AMI,Kota Mataram,Kutha Mataram,Mataram,Mataram-Lombok,Mataramas,ma ta lan,matalam,mataram,mataramu,Матарам,ماتارام,ماٹارام,მატარამი,マタラム,馬塔蘭,마타람', -8.5833300, 116.1166700, 'ID', '2014-07-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67126, 'Masmambang', 'Masmambang', 'Masmambang', -4.1641800, 102.7004500, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67127, 'Masbagik', 'Masbagik', 'Masbagik', -8.6220000, 116.4773000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67128, 'Masat', 'Masat', 'Masat', -4.3805700, 102.9543700, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67129, 'Masamba', 'Masamba', 'Masamba,Masambe', -2.5537000, 120.3279000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67130, 'Maronge', 'Maronge', 'Maroenge,Maroengi,Maronge,Marunge', -8.6715000, 117.7070000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67131, 'Martapura', 'Martapura', 'Martapoera,Martapura', -4.3188500, 104.3471500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67132, 'Martapura', 'Martapura', 'Martapoera,Martapura', -3.4109000, 114.8642000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67133, 'Maros', 'Maros', 'Maroesoe,Maros', -5.0060000, 119.5727000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67134, 'Maroko', 'Maroko', 'Maroko', -7.6350000, 107.8919000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67135, 'Buakayu', 'Buakayu', 'Boeakajoe,Buakayu,Maroang,Maroangin,Maroanging', -3.1995000, 119.7232000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67136, 'Marisa', 'Marisa', 'Marisa', 0.4655000, 121.9386000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67137, 'Marenteh', 'Marenteh', 'Marenteh,Marinteh', -8.5472000, 117.0181000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67138, 'Maria', 'Maria', 'Maria,Maria 1', -8.5238800, 118.8429400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67139, 'Margasari', 'Margasari', 'Margasari', -7.2214000, 108.1916000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67140, 'Margasari', 'Margasari', 'Margasari,Margosari', -7.1000000, 109.0166700, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67141, 'Pahing Margamukti', 'Pahing Margamukti', 'Margamoekti,Margamukti,Pahing Margamukti', -7.0130000, 108.6883000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67142, 'Margahayukencana', 'Margahayukencana', 'Margahajoe,Margahaju,Margahayu,Margahayukencana', -6.9708300, 107.5675000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67143, 'Margaharja', 'Margaharja', 'Margahardja,Margaharja', -7.2593000, 108.4503000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67144, 'Cimarelang', 'Cimarelang', 'Cimarelang,Mareleng', -7.2638000, 106.5400000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67145, 'Marabahan', 'Marabahan', 'Marabahan,Martabahan', -3.0136000, 114.7687000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67146, 'Maparah', 'Maparah', 'Maparah', -7.1176000, 108.2943000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67147, 'Manuakalada', 'Manuakalada', 'Manoeakalada,Manoekalada,Manuakalada', -9.4013000, 119.5450000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67148, 'Manonjaya', 'Manonjaya', 'Manondjaja,Manonjaya', -7.3509000, 108.3087000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67149, 'Manokwari', 'Manokwari', 'Kabupaten Manokwari,Kutha Manokwari,MKW,Manokvari,Manokvaris,Manokwari,Menoekwari,man nuo wa li,manokuwari,manokwali,manwkwary,Маноквари,مانوكواري,مانوکواری,მანოკვარი,マノクワリ,曼諾瓦里,마노콰리', -0.8629100, 134.0640200, 'ID', '2015-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67150, 'Manna', 'Manna', 'Mana,Manna', -4.4651000, 102.9038600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67151, 'Manismata', 'Manismata', '', -2.4666700, 111.0333300, 'ID', '2013-10-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67152, 'Maninjau', 'Maninjau', 'Manindjau,Maninjau,Maninyau', -0.3005900, 100.2267100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67153, 'Maniis', 'Maniis', 'Maniis,Maniis Satu', -7.0387000, 108.3144000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67154, 'Mangunjaya', 'Mangunjaya', 'Mangoendjaja,Mangoendjaja 2,Mangoendjajan,Mangundjaja,Mangundjaja 2,Mangunjaya', -7.4881000, 108.6982000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67155, 'Mangkutana', 'Mangkutana', 'Mangkoetana,Mangkutana,Moengkotna', -2.4894000, 120.8120000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67156, 'Manggar', 'Manggar', 'Manggar', -2.8833300, 108.2666700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67157, 'Mangarang', 'Mangarang', 'Kampoeng Mangarang,Mangarang,Mengarang', 3.8128400, 126.7513500, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67158, 'Mangaran', 'Mangaran', 'Mangaran', -7.6668000, 114.0406000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67159, 'Manganitu', 'Manganitu', 'Manganitoe,Manganitu', 3.5762200, 125.5184900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67160, 'Mandor', 'Mandor', 'Mandor', 0.3224300, 109.3379500, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67161, 'Manding', 'Manding', 'Manding,Manding-laoet,Manding-laut,Mundinglaut', -6.9530000, 113.8717000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67162, 'Mander', 'Mander', 'Mander', -6.8593000, 111.8028000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67163, 'Mandalawangi', 'Mandalawangi', 'Mandalawangi', -6.3102000, 105.9886000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67164, 'Mandalasari', 'Mandalasari', 'Mandalasari', -7.4067000, 107.9888000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67165, 'Mendaha', 'Mendaha', 'Mandahara,Mendaha,Mendahara', -1.0163000, 103.5933100, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67166, 'Khairiahmandah', 'Khairiahmandah', 'Khairiahmandah,Mandah', 0.0210700, 103.4975700, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67167, 'Manalu', 'Manalu', 'Manaloe,Manalu,Menaloe', 3.5122500, 125.6230200, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67168, 'Manado', 'Manado', 'Kota Manado,Kutha Manado,MDC,Manadas,Manado,Menado,ma na do,manado,manadw,wan ya lao,Манадо,مانادو,مناڈو,मानदो,มานาโด,マナド,万鸦老,萬鴉老,마나도', 1.4821800, 124.8489200, 'ID', '2014-07-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67169, 'Mamuju', 'Mamuju', 'Gorad Mamudzhu,MJU,Mamoedjoe,Mamudju,Mamudzhu,Mamudzu,Mamudžu,Mamuju,ma mu zhu,mamuju,mamwjw,Горад Мамуджу,Мамуджу,ماموجو,馬穆朱,마무주', -2.6805600, 118.8861100, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67170, 'Mambi', 'Mambi', 'Mambi,Mambie,Mambië', -2.9505000, 119.1747000, 'ID', '2012-02-28', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67171, 'Banjar Mambalkajanan', 'Banjar Mambalkajanan', 'Banjar Mambalkajanan,Mambal,Mambat', -8.5506000, 115.2234000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67172, 'Mamasa', 'Mamasa', 'Mamasa', -2.9420000, 119.3776000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67173, 'Malingping', 'Malingping', 'Malimpang,Malingping', -6.7783800, 106.0176700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67174, 'Malili', 'Malili', 'Malili', -2.6351000, 121.0948000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67175, 'Malangnengah', 'Malangnengah', 'Malangnengah', -6.5290000, 106.3597000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67176, 'Malangbong', 'Malangbong', 'Malangbong,Malanghong,Malongbong', -7.0603000, 108.0876000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67177, 'Malang', 'Malang', 'Kabupaten Malang,Kota Malang,Kutha Malang,MLG,Maland,Malang,ma lang,malangh,malangi,mallang,malng,maran,Маланг,مالانغ,مالنگ,მალანგი,マラン,瑪琅,말랑', -7.9797000, 112.6304000, 'ID', '2013-05-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67178, 'Makbon', 'Makbon', 'Makbon,Makebon', -0.7475300, 131.5387500, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67179, 'Makale', 'Makale', 'Makaie,Makale', -3.1019000, 119.8539000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67180, 'Majingklak', 'Majingklak', 'Madjingklak,Majingklak', -7.3051000, 108.6757000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67181, 'Kampungmasjid', 'Kampungmasjid', 'Kampungmasjid,Madjeuw,Majeuw', -6.4267000, 105.9708000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67182, 'Majene', 'Majene', 'Madjene,Majene', -3.5403000, 118.9707000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67183, 'Majenang', 'Majenang', 'Madjenang,Majenang', -7.2975000, 108.7642000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67184, 'Majalengka', 'Majalengka', 'Madjalengka,Majalengka', -6.8361100, 108.2277800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67185, 'Maja', 'Maja', 'Madja,Maja', -6.6559000, 106.3636000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67186, 'Maikawada', 'Maikawada', 'Maikawada', -8.2816000, 124.7128000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67187, 'Maguan', 'Maguan', 'Magoean,Maguan', -8.0712000, 112.5370000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67188, 'Magetan', 'Magetan', 'Magetan', -7.6566700, 111.3313900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67189, 'Magepanda', 'Magepanda', 'Mage Pandan,Magepanda,Magé Pandan', -8.5487000, 122.0486000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67190, 'Magelang', 'Magelang', 'Kota Magelang,Kutha Magelang,Magelang,ma ge lang,magelangi,maglang,Магеланг,ماگلانگ,მაგელანგი,馬格朗', -7.4705600, 110.2177800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67191, 'Mafa', 'Mafa', 'Boli,Mafa', 0.0572700, 127.8814000, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67192, 'Maesan', 'Maesan', 'Maesan', -8.0233000, 113.7779000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67193, 'Maduran', 'Maduran', 'Maduran', -7.0042000, 112.2807000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67194, 'Madiun', 'Madiun', 'Kota Madiun,Madioen,Madiun', -7.6298000, 111.5239000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67195, 'Maba', 'Maba', 'Maba', 0.7007000, 128.2919700, 'ID', '2016-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67196, 'Luwuk', 'Luwuk', 'LUW,Loewoek,Luwuk', -0.9516000, 122.7875000, 'ID', '2016-02-27', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67197, 'Luragung', 'Luragung', 'Loerah goen-landeuh,Loerah goeng-landeuh,Loerahagoeng-landeuh,Loerangoen-landeuh,Luragung,Lurahagung-landeuh,Lurahgung,Lurahgung-Landeuh', -7.0172000, 108.6381000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67198, 'Lunyuk Ode', 'Lunyuk Ode', 'Loenjoek Odeh,Lunjuk-odeh,Lunyuk Ode,Lunyuk-odeh', -8.9709000, 117.2160000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67199, 'Lumajang', 'Lumajang', 'Kabupaten Lumajang,Loemadjang,Lumadjang,Lumajang', -8.1335000, 113.2248000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67200, 'Lubuk Sikaping', 'Lubuk Sikaping', 'Loeboeksikaping,Lubok Sikapang,Lubuk Sikaping', 0.1441100, 100.1657000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67201, 'Lubuklinggau', 'Lubuklinggau', 'Kota Lubuklinggau,Loeboeklinggau,Lubuklinggao,Lubuklinggau', -3.2945000, 102.8614000, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67202, 'Lubukjambi', 'Lubukjambi', 'Labuk Jambi,Loeboekdjambi,Loeboekjambi,Lubok Jambi,Lubukdjambi,Lubukjambi', -0.6517000, 101.4681000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67203, 'Lubukgadang', 'Lubukgadang', 'Loeboekgadang,Lubukgadang', -1.5251000, 101.2734000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67204, 'Lubuk Basung', 'Lubuk Basung', 'Loeboekbasoeng,Loeboekoasoeng,Lubuk Basung,Lubukbasung', -0.3254500, 100.0646200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67205, 'Lubukbergalung', 'Lubukbergalung', 'Lubukbargalung,Lubukbergalung', -0.9607600, 100.4001100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67206, 'Lubukalung', 'Lubukalung', 'Loeboekaloeng,Lubukalung', -0.6832100, 100.3185600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67207, 'Lopokloka', 'Lopokloka', 'Lopok,Lopokloka', -8.6080000, 117.5475000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67208, 'Lontar', 'Lontar', 'Lonta,Lontar,Lontar Alangalang', -5.9699300, 106.3053100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67209, 'Long Pujungan', 'Long Pujungan', 'Long Pujungan,Longpoedjoegan,Longpudjungan,Longpujungan,Poedjoengan,Pudjungan', 2.5876900, 115.7947800, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67210, 'Longnawang', 'Longnawang', 'Longnawan,Longnawang,Nawan', 1.7893100, 114.9013000, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67211, 'Longkali', 'Longkali', 'Longkali', -1.5218000, 116.3205000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67212, 'Longikis', 'Longikis', 'Longikis', -1.5834000, 116.2061000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67213, 'Labuan Lombok', 'Labuan Lombok', '', -8.5000000, 116.6666700, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67214, 'Lolak', 'Lolak', 'Lolak', 0.8755000, 124.0098000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67215, 'Lojejerkrajan', 'Lojejerkrajan', 'Lodjedjer,Lojejer,Lojejerkrajan', -8.3653000, 113.4956000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67216, 'Lodoyo', 'Lodoyo', 'Lodojo,Lodoyo', -8.1613000, 112.2173000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67217, 'Lodan Wetan', 'Lodan Wetan', 'Lodan,Lodan Wetan', -6.7854000, 111.6086000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67218, 'Loakulu', 'Loakulu', 'Loakoeloe,Loakulu', -0.5148900, 117.0156700, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67219, 'Loa Janan', 'Loa Janan', 'Loa Djanan,Loa Janan', -0.5829500, 117.0950300, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67220, 'Liwa', 'Liwa', 'Liwa', -5.0355400, 104.0759500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67221, 'Lirung', 'Lirung', 'Kampoeng Liroeng,Liroeng,Lirung,Urung', 3.9448100, 126.6726500, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67222, 'Limboto', 'Limboto', 'Limboto,Limbotto', 0.6270000, 122.9778000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67223, 'Likupang', 'Likupang', 'Likoepang,Likupang', 1.6722000, 125.0610400, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67224, 'Lewobelen', 'Lewobelen', 'Lewobela,Lewobelen,Lewotolo', -8.2731000, 123.3937000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67225, 'Lewotobi', 'Lewotobi', 'Lewotobi,Lobetobi', -8.5760000, 122.8360000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67226, 'Lewotolok', 'Lewotolok', 'Lewotelo,Lewotolok', -8.2647000, 123.4691000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67227, 'Lewoeleng', 'Lewoeleng', 'Lewaling,Lewoeleng,Lewolein', -8.3359000, 123.6264000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67228, 'Lewoleba', 'Lewoleba', 'LWE,Lewoleba', -8.3723000, 123.4180000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67229, 'Lewolaga', 'Lewolaga', 'Lewolaga', -8.4196000, 122.8094000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67230, 'Lewohala', 'Lewohala', 'Lewohala', -8.2834000, 122.9540000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67231, 'Lewo', 'Lewo', 'Lewo,Lewo 2', -7.0676000, 108.0546000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67232, 'Leuwipicung', 'Leuwipicung', 'Leuwipicung,Leuwipitjoeng,Leuwipitjung', -7.7160000, 108.0766000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67233, 'Leuwihalang', 'Leuwihalang', 'Leuwihalang', -7.6989000, 108.2851000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67234, 'Leuwidamar', 'Leuwidamar', 'Leuwidamar,Lowidamar,Löwidamar', -6.5125000, 106.1934000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67235, 'Letung', 'Letung', 'Leteng,Letong,Letung', 2.9886100, 105.7069400, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67236, 'Leran', 'Leran', 'Leran', -6.6436000, 111.4712000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67237, 'Lengkong', 'Lengkong', 'Lengkong', -7.1315000, 106.6926000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67238, 'Lenangguar', 'Lenangguar', 'Desa Lenangguar,Lenanggoear,Lenangguar', -8.7356000, 117.3653000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67239, 'Lemito', 'Lemito', 'Leinito,Lemito', 0.5424000, 121.5713000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67240, 'Lembongan Kawan', 'Lembongan Kawan', 'Lembongan,Lembongan Kawan', -8.6902000, 115.4397000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67241, 'Lembar', 'Lembar', 'Lembar', -8.7264000, 116.0744000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67242, 'Lembang', 'Lembang', 'Lembang,Lembang 1,Lembange,Лембанге', -6.8116700, 107.6175000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67243, 'Lemahputih', 'Lemahputih', 'Lemahpoetih,Lemahputih', -7.0099000, 108.1698000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67244, 'Lelogama', 'Lelogama', 'Lelogama', -9.7114000, 123.9540000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67245, 'Leles', 'Leles', 'Leles', -7.3705000, 106.9824000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67246, 'Leles', 'Leles', 'Leles', -7.1099000, 107.8986000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67247, 'Lela', 'Lela', 'Lela', -8.7289000, 122.1726000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67248, 'Leksula', 'Leksula', 'Lek Soela,Leksoela,Leksula,Lék Soela', -3.7731000, 126.5380000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67249, 'Lekong', 'Lekong', 'Lekong,Mapin Lekong', -8.5346000, 116.9657000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67250, 'Lekebai', 'Lekebai', 'Lekebai', -8.7120000, 122.0762000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67251, 'Ledokombo', 'Ledokombo', 'Ledokamba 1,Ledokombo', -8.1346000, 113.8752000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67252, 'Lebakwangi', 'Lebakwangi', 'Lebakwangi', -7.0173000, 108.6016000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67253, 'Lebaksiu', 'Lebaksiu', 'Lebaksioe,Lebaksiu', -7.0496000, 109.1441000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67254, 'Lebakkeusik', 'Lebakkeusik', 'Lebakkeusik', -6.6008000, 105.9517000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67255, 'Lebak', 'Lebak', 'Lebak', -6.8865000, 113.7855000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67256, 'Lawonda', 'Lawonda', 'Lawonda', -9.5252000, 119.5923000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67257, 'Lohayong', 'Lohayong', 'Lawajong,Lawayong,Lewahadjong,Lewohajong,Lohayong', -8.4345000, 123.0688000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67258, 'Lawang', 'Lawang', 'Lawang', -7.8353000, 112.6947000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67259, 'Latuna', 'Latuna', 'Latoena,Latuna', -8.3923400, 124.0558300, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67260, 'Lasem', 'Lasem', 'Binangun,Lasem', -6.6922000, 111.4527000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67261, 'Lasehao', 'Lasehao', 'Lasahaoe,Lasahau,Lasehao,Laseheo', -5.0068000, 122.4943000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67262, 'Larompong', 'Larompong', 'Larompong', -3.5150000, 120.3704000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67263, 'Laren', 'Laren', 'Laren', -6.9776000, 112.2957000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67264, 'Larantuka', 'Larantuka', 'LKA,Larantaka,Larantoeka,Larantuka', -8.3468000, 122.9771000, 'ID', '2013-12-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67265, 'Lampihung', 'Lampihung', 'Lampihoeng,Lampihoeng-kanan,Lampihung,Lapihoeng-kanan,Lapihung-kanan', -2.3809000, 115.5277000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67266, 'Langgur', 'Langgur', 'LUV,Langgoer,Langgur', -5.6668900, 132.7376200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67267, 'Langnga', 'Langnga', 'Langa,Langga,Langnga', -3.8459000, 119.5222000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67268, 'Langensari', 'Langensari', 'Langensari', -6.4222000, 105.9425000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67269, 'Langara', 'Langara', 'Langara,Langgara,Langgarabugis', -4.0248000, 122.9906000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67270, 'Lamongan', 'Lamongan', '', -7.1166700, 112.4166700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67271, 'Lamalera', 'Lamalera', 'Hada Kewa,Lamalera,Lamalerap,Lamararap', -8.5748000, 123.4239000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67272, 'Lamakera Satu', 'Lamakera Satu', 'Lamakera,Lamakera Satu', -8.4358000, 123.1646000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67273, 'Laiwui', 'Laiwui', 'Laiwoei,Laiwui', -1.3517700, 127.6692900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67274, 'Lais', 'Lais', 'Lais', -3.5294000, 102.0497000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67275, 'Laikit, Laikit II (Dimembe)', 'Laikit, Laikit II (Dimembe)', 'Deikit,Laikit 1,Laikit Dimembe,Laikit Matungkas', 1.4883300, 124.9744400, 'ID', '2008-01-28', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67276, 'Lahat', 'Lahat', 'Lahat,PXA', -3.7851400, 103.5427900, 'ID', '2016-06-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67277, 'Labuhansumbawa', 'Labuhansumbawa', 'Laboe Soembawa,Laboehan Soembawa,Labu Sumbawa,Labuhansumbawa', -8.4726000, 117.4014000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67278, 'Labuhanmapin', 'Labuhanmapin', 'Laboe Mapin,Laboean Mapin,Laboehan Mapin,Labu Mapin,Labuhanmapin,Mapin', -8.5193000, 116.9398000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67279, 'Labuhanlalar', 'Labuhanlalar', 'Laboe Lalar,Laboean Lalar,Laboehan Lalar,Labu Lalar,Labuhanlalar', -8.8146000, 116.8157000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67280, 'Labuhankananga', 'Labuhankananga', 'Kananga,Lab Kananga,Laboe Kananga,Laboehan Kananga,Labu Kananga,Labuhankananga', -8.1391000, 117.7714000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67281, 'Labuhanjambu', 'Labuhanjambu', 'Djamboe,Djambu,Djamoe,Jambu,Laboe Djamboe,Laboehan Djamoe,Labu Djambu,Labu Jambu,Labuhanjambu', -8.6962000, 118.0205000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67282, 'Labuhanmaringgai', 'Labuhanmaringgai', 'Laboehanmarbiggai,Laboehanmaringgai,Labuhanmaringgai,Labuhanmeringgai,Maringgai', -5.3507400, 105.8099300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67283, 'Labuan Bajo', 'Labuan Bajo', 'Badjo,LBJ,Laboean Bajo,Laboehanbadjo,Labuan Bajo,Labuanbadzho,Labuanbajo,Labuhanbadjo,Labuhanbajo,Лабуанбаджо', -8.4964000, 119.8877000, 'ID', '2016-02-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67284, 'Labuan', 'Labuan', 'Laboean,Laboehan,Labuan,Labuhan', -6.3784000, 105.8300000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67285, 'Labuhanaji', 'Labuhanaji', 'Laboean Hadji,Laboehadji,Laboehan Hadji,Labuanhaji,Labuhadji,Labuhaji,Labuhanaji', -8.2188900, 117.4861100, 'ID', '2014-11-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67286, 'Labuha', 'Labuha', 'LAH,Laboeha,Labuha', -0.6254600, 127.4780800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67287, 'Labala', 'Labala', 'Labala', -8.5147000, 123.4912000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67288, 'Komi', 'Komi', 'Kjomi,Komi,Kyomi', -9.4299000, 119.3029000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67289, 'Kwantisore', 'Kwantisore', 'Kwantisore,Kwatisore', -3.2651000, 134.9065000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67290, 'Kutoarjo', 'Kutoarjo', 'Koeta''ardja,Koeta’ardja,Koetoardjo,Kutoardjo,Kutoarjo', -7.7169400, 109.9127800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67291, 'Kutaagung', 'Kutaagung', 'Koetaagoeng,Koetaägoeng,Kutaagung', -7.1806000, 108.5729000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67292, 'Kute', 'Kute', 'Koeta,Kuta,Kute', -8.8920000, 116.2776000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67293, 'Kuta', 'Kuta', 'Koeta,Kuta,ku ta,kuta,Кута,कूटा,クタ,庫塔', -8.7233200, 115.1723400, 'ID', '2015-10-15', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67294, 'Pangkalan Kerinci', 'Pangkalan Kerinci', 'Kerinci,Koerintji,Kurinci,Kurintji,Pangkalan Kerinci', 0.3961100, 101.8572200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67295, 'Kuningan', 'Kuningan', 'Koeningan,Kuningan', -6.9758300, 108.4830600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67296, 'Kumurkek', 'Kumurkek', 'Kumurkek', -1.2566700, 132.4997200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67297, 'Kumpai', 'Kumpai', 'Kumpai', -6.4765000, 106.0134000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67298, 'Kumai', 'Kumai', 'Koemai,Kumai', -2.7398000, 111.7255800, 'ID', '2015-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67299, 'Kuma', 'Kuma', 'Koema,Kuma', 3.5746700, 125.5774600, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67300, 'Kudus', 'Kudus', 'Koedoes,Kudus', -6.8048000, 110.8405000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67301, 'Kubu', 'Kubu', 'Koeboe,Kubu', -8.2524000, 115.5666000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67302, 'Kubu', 'Kubu', 'Koeboe,Kubu', -0.4857600, 109.3551300, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67303, 'Kwandang', 'Kwandang', 'Koeandang,Kuandang,Kwandang,Moloo', 0.8348000, 122.9150000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67304, 'Kuala Tungkal', 'Kuala Tungkal', 'Koealatoengkal,Kuala Tungkal,Kualatungkal', -0.8162300, 103.4611100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67305, 'Kualakapuas', 'Kualakapuas', 'Koealakapoeas,Kualakapuas', -3.0091300, 114.3875900, 'ID', '2010-12-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67306, 'Krui', 'Krui', 'Kroe,Kroei,Krue,Krui', -5.1825100, 103.9374600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67307, 'Kroya', 'Kroya', 'Kroja,Kroya', -7.6330600, 109.2461100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67308, 'Krian', 'Krian', 'Kerian,Krian,Krijan', -7.4104000, 112.5792000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67309, 'Kresek', 'Kresek', 'Keresek,Kresek', -6.1313900, 106.3797200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67310, 'Kraksaan', 'Kraksaan', 'Kraksahan,Kraksan', -7.7584500, 113.3962400, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67311, 'Kragan', 'Kragan', 'Kragan', -6.6897000, 111.6125000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67312, 'Kotawaringin', 'Kotawaringin', 'Katawaringin,Kotawaringin', -2.4729000, 111.4731000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67313, 'Kotatengah', 'Kotatengah', 'Kotatengah', 1.0873800, 100.5545800, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67314, 'Kota Pinang', 'Kota Pinang', 'Kota Pinang,Kotapinang,Kotapinang-baroe,Kotapinang-baru', 1.8907600, 100.0921100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67315, 'Daik Lingga', 'Daik Lingga', 'Daik,Daik Lingga,Katadaik,Kotadaik,Lingga', -0.2145100, 104.6182400, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67316, 'Kotabunan', 'Kotabunan', 'Kotaboen,Kotaboena,Kotaboenan,Kotabuna,Kotabunan', 0.8121700, 124.6554600, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67317, 'Kotabumi', 'Kotabumi', 'Kotaboemi,Kotabumi', -4.8250500, 104.8817000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67318, 'Kotabesi', 'Kotabesi', 'Kotabesi', -2.3715000, 113.0025000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67319, 'Kotabaru Hilir', 'Kotabaru Hilir', 'KBU,Kotabaroe,Kotabaru Hilir', -3.2426700, 116.2251400, 'ID', '2014-03-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67320, 'Kotabaru', 'Kotabaru', 'Kotabaroe,Kotabaru,Kote Bahru', -1.1015500, 101.7603100, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67321, 'Kotaagung', 'Kotaagung', 'Kota Agung,Kotaagoeng,Kotaagung,Kotaägoeng,Koto Agoeng,Kotŏ Agoeng', -5.4941500, 104.6220100, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67322, 'Kotaagung', 'Kotaagung', 'Kotaagoeng,Kotaagung', -4.0685300, 103.4316400, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67323, 'Korem', 'Korem', 'Korem,Korim', -0.9000400, 136.0408200, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67324, 'Korido', 'Korido', 'Awaki,Korido,Korrido', -0.8747000, 135.6344000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67325, 'Kopang Satu', 'Kopang Satu', 'Kopang,Kopang Satu', -8.6335000, 116.3517000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67326, 'Konga', 'Konga', 'Konga', -8.4510000, 122.7756000, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67327, 'Kompa Satu', 'Kompa Satu', 'Kompa,Kompa Satu', -6.5822200, 106.5061100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67328, 'Komodo', 'Komodo', 'Komodo,Komodo sala,Pulau Komodo,ke mo duo dao,Комодо,科莫多島', -8.5895000, 119.4913000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67329, 'Kolonodale', 'Kolonodale', 'Kolonedale,Kolonodale', -1.9825000, 121.3364000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67330, 'Kokas', 'Kokas', 'Kaukas,Kokas', -2.7030600, 132.4380600, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67331, 'Kokar', 'Kokar', 'Kokar', -8.1629000, 124.4473000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67332, 'Koba', 'Koba', 'Koba', -2.4931300, 106.4081000, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67333, 'Klungkung', 'Klungkung', 'Kloengkoeng', -8.5333300, 115.4000000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67334, 'Kelua', 'Kelua', 'Kelua,Kloea,Klua', -2.2048000, 115.3993000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67335, 'Klepu Krajan', 'Klepu Krajan', 'Klepu,Klepu Krajan', -8.2627000, 112.7330000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67336, 'Klaten', 'Klaten', 'Kabupaten Klaten,Klaten,Klathen', -7.7058300, 110.6063900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67337, 'Klangenan', 'Klangenan', 'Klangenan', -6.7094400, 108.4400000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67338, 'Klampis', 'Klampis', 'Klampis,Klampis-barat', -6.8938000, 112.9041000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67339, 'Kiruru', 'Kiruru', 'Kikoeroe,Kiroeroe,Kiruri,Kiruru', -3.9389000, 134.9696000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67340, 'Kimaam', 'Kimaam', 'Kimaam,Kinaam,Kinaäm', -7.9850700, 138.8468900, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67341, 'Kikilai', 'Kikilai', 'Kikilai', -8.2646000, 124.5228000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67342, 'Kijang', 'Kijang', 'Goenoengkidjang,Gunungkidjang,Gunungkijang,Kijang', 0.9000000, 104.6333300, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67343, 'Kidal', 'Kidal', 'Kidal', -8.0224000, 112.7085000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67344, 'Kiarajangkung', 'Kiarajangkung', 'Kiaradjangkoeng,Kiaradjangkung,Kiarajangkung', -7.2002000, 108.1288000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67345, 'Ketupat', 'Ketupat', 'Katoepat,Katupat,Ketoepat,Ketupat', -7.1458000, 114.4972000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67346, 'Ketowan', 'Ketowan', 'Ketoan,Ketowan', -7.7829000, 114.1314000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67347, 'Ketahun', 'Ketahun', 'Ketahun,Ketaoen,Ketaun', -3.3897000, 101.8352000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67348, 'Ketapang', 'Ketapang', 'Kelapang,Ketapang,Ketapang Daya,Ketapang-daja', -6.8958000, 113.2806000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67349, 'Ketapang', 'Ketapang', 'Ketapang', -1.8386200, 109.9772800, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67350, 'Ketanggungan', 'Ketanggungan', 'Ketanggoengan,Ketanggungan', -6.9383000, 108.8910000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67351, 'Kesugihan', 'Kesugihan', 'Kasugihan,Kesoegian,Kesoegihan,Kesugihan', -7.6175000, 109.1213900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67352, 'Kesamben', 'Kesamben', 'Kesamben', -8.1462000, 112.3658000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67353, 'Kertosono', 'Kertosono', 'Pelem,Pĕlĕm', -7.5833300, 112.1000000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67354, 'Kertosari', 'Kertosari', 'Kertosari', -7.7543000, 114.2024000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67355, 'Kertabumi', 'Kertabumi', 'Kertaboemi,Kertabumi', -7.3347000, 108.4384000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67356, 'Kerek', 'Kerek', 'Kerek', -6.8951000, 111.8866000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67357, 'Kerang', 'Kerang', 'Kerang', -2.2333000, 116.0718000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67358, 'Kepoh', 'Kepoh', 'Kepo,Kepo 2,Kepoh,Kĕpo 2', -2.9445400, 106.5574300, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67359, 'Kepi', 'Kepi', 'Kepi', -6.5246100, 139.3222400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67360, 'Kepanjen', 'Kepanjen', 'Kepandjen,Kepanjen', -8.1303000, 112.5727000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67361, 'Kendari', 'Kendari', 'KDI,Kendari,Kendaris,Kota Kendari,Kutha Kendhari,ken da li,ken da ri,kendari,keundali,kndary,kndry  andwnzy,Кендари,کنداری,کندری، اندونزی,เก็นดารี,ケンダリ,肯達里,큰다리', -3.9778000, 122.5150700, 'ID', '2013-04-27', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67362, 'Kendal', 'Kendal', 'Kendal', -6.9213000, 110.2022000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67363, 'Kencong', 'Kencong', 'Kentjong,Ketjong', -8.2833300, 113.3666700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67364, 'Kenali', 'Kenali', 'Kenali', -4.9915700, 104.1929000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67365, 'Kemiri', 'Kemiri', 'Kemiri', -8.2267000, 111.9113000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67366, 'Kembang', 'Kembang', 'Kembang', -8.0105000, 113.9634000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67367, 'Kema', 'Kema', 'Kema,Kema 1,Kema Satu', 1.3657400, 125.0748400, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67368, 'Kalapagenep', 'Kalapagenep', 'Kalapagenep,Kelapagenep,Klapagenep', -7.8073000, 108.2926000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67369, 'Dalamdesa Kalapadua', 'Dalamdesa Kalapadua', 'Dalamdesa Kalapadua,Kelapadoea Satu,Kelapadua', -7.0037000, 108.2267000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67370, 'Kelapa', 'Kelapa', 'Kelapa', -1.8775700, 105.6766100, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67371, 'Kefamenanu', 'Kefamenanu', 'Kefamenanu,Kefannanoe,Kefannanu,Kefannau', -9.4466700, 124.4780600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67372, 'Kedungwuni', 'Kedungwuni', 'Kedoengwoeni,Kedungwuni', -6.9703800, 109.6479400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67373, 'Kedungwuluh', 'Kedungwuluh', 'Kedoengwoeloeh,Kedungwuluh,Kedungwulul', -7.5360000, 108.6873000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67374, 'Kedungwaru', 'Kedungwaru', '', -8.0666700, 111.9166700, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67375, 'Kedungtuban', 'Kedungtuban', 'Kedoengtoeban,Kedoengtóeban,Kedungtuban', -7.1640000, 111.4940000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67376, 'Kedungreja', 'Kedungreja', 'Kedoengredja,Kedungredja,Kedungreja', -7.5047200, 108.7798100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67377, 'Kedungpeluk', 'Kedungpeluk', 'Kedungpeluk', -7.4824000, 112.7546000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67378, 'Kedunglo', 'Kedunglo', 'Kedunglo', -7.7863000, 114.2203000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67379, 'Kedung', 'Kedung', 'Kedung,Kedungsari', -6.5990000, 111.0439000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67380, 'Kediri', 'Kediri', 'Kediri', -8.6343000, 116.1515000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67381, 'Kediri', 'Kediri', 'Kediri,Kota Kediri,Kutha Kedhiri,jian yi li,kdyry,kydyry  mshrqy jawa,Кедири,كديري,کیدیری، مشرقی جاوا,კედირი,諫義里', -7.8166700, 112.0166700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67382, 'Kedewan', 'Kedewan', 'Kadewan,Kedewan', -7.0360000, 111.6385000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67383, 'Kedaton', 'Kedaton', 'Kedaton', -5.3835400, 105.2596000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67384, 'Kebumen', 'Kebumen', 'Keboemen,Kebumen', -7.6686100, 109.6536100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67385, 'Kebonarun', 'Kebonarun', 'Kebonarum,Kebonarun', -7.7002800, 110.5630600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67386, 'Kebomas', 'Kebomas', '', -7.1666700, 112.6333000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67387, 'Kebasen', 'Kebasen', 'Kabasen,Kebasen', -7.5333300, 109.1997200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67388, 'Padangtepung', 'Padangtepung', 'Keban,Padangtepong,Padangtepung', -3.7538000, 102.7945000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67389, 'Kayuaru', 'Kayuaru', 'Kajoewa,Kajoewaroe,Kajuwaru,Kayuaru,Kayuwaru', -6.9132000, 115.5580000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67390, 'Kayu Agung', 'Kayu Agung', 'Kajoeagoeng,Kajuagung,Kayu Agung,Kayuagung', -3.3920000, 104.8306000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67391, 'Marica', 'Marica', 'Kajan,Kajian,Kayan,Kayian,Marica', -8.3488400, 123.9662800, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67392, 'Kawunglarang', 'Kawunglarang', 'Kawoenglarang,Kawunglarang', -7.1649000, 108.4832000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67393, 'Kawangu', 'Kawangu', 'Kawangoe,Kawangu', -9.6728000, 120.3409000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67394, 'Kawangkoan', 'Kawangkoan', 'Kawangkoaan,Kawangkoan', 1.2052500, 124.7821800, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67395, 'Kawalu', 'Kawalu', 'Kawaloe,Kawalu', -7.3817000, 108.2082000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67396, 'Kawali', 'Kawali', 'Kawah,Kawali,Kwali', -7.1854000, 108.3704000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67397, 'Babakantengah', 'Babakantengah', 'Babakantengah,Katoembiri,Katumbiri', -6.6421000, 105.6979000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67398, 'Katabu', 'Katabu', 'Kahoboe,Kataboe', -4.9333000, 122.5167000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67399, 'Kasui', 'Kasui', 'Kasoei,Kasui', -4.7157200, 104.4498000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67400, 'Kasonawejo', 'Kasonawejo', 'Kasonaweja,Kasonawejo', -2.2818000, 138.0348000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67401, 'Kasiguncu', 'Kasiguncu', 'Kasigoentjoe,Kasiguncu,Kasiguntju', -1.4211400, 120.6554000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67402, 'Kasiyan', 'Kasiyan', 'Kasian,Kasiyan', -8.3146000, 113.4690000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67403, 'Kasarangan', 'Kasarangan', 'Kasarangan', -2.6263600, 115.2973900, 'ID', '2015-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67404, 'Karumbu', 'Karumbu', 'Karoemboe,Karumbu', -8.6949000, 118.8304000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67405, 'Karawang', 'Karawang', 'Karawang,Krawang', -6.3033300, 107.3055600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67406, 'Karangturi', 'Karangturi', 'Karangturi', -8.2776000, 111.5811000, 'ID', '2012-05-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67407, 'Karangsono', 'Karangsono', 'Karangsana,Karangsono', -8.2270000, 113.5204000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67408, 'Karangsembung', 'Karangsembung', 'Karangsemboeng,Karangsembung', -6.8487000, 108.6422000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67409, 'Karangsari', 'Karangsari', 'Karangsari', -7.0993000, 107.9342000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67410, 'Karangrejo', 'Karangrejo', 'Karangredjo,Karangrejo', -8.0030000, 111.9092000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67411, 'Karangpawitan', 'Karangpawitan', 'Karangpawitan', -7.2061000, 107.9456000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67412, 'Karangnunggal', 'Karangnunggal', 'Karangnoenggal,Karangnunggal', -7.6278000, 108.1341000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67413, 'Karangintan', 'Karangintan', 'Karangintan', -3.4116000, 115.0134000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67414, 'Karanggeneng', 'Karanggeneng', 'Karanggeneng', -6.9897000, 112.3738000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67415, 'Karangdowo', 'Karangdowo', '', -6.7377000, 111.0434000, 'ID', '2011-11-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67416, 'Karangdowo', 'Karangdowo', 'Karangdow,Karangdowo', -6.7912000, 111.8951000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67417, 'Karangbolong', 'Karangbolong', 'Karangbolong', -6.6288000, 105.6501000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67418, 'Karangbenda', 'Karangbenda', 'Karangbenda', -7.6917000, 108.5108000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67419, 'Karangasem', 'Karangasem', 'Amlapura,Denpasar,Karangasem Amlapura,Денпасар', -8.4500000, 115.6166700, 'ID', '2010-01-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67420, 'Karangasem', 'Karangasem', 'Karangasem', -6.7560000, 111.5823000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67421, 'Karangarjo', 'Karangarjo', 'Karangardjo,Karangarjo,Karangharjo Kidul', -8.3125000, 114.0483000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67422, 'Karanganyar', 'Karanganyar', 'Karanganjar,Karanganyar', -7.5983300, 110.9444400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67423, 'Karanganyar', 'Karanganyar', 'Karanganjar,Karanganyar', -6.7072000, 111.0834000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67424, 'Karanganom', 'Karanganom', 'Karanganom', -7.6488900, 110.6250000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67425, 'Karangan', 'Karangan', 'Karangan', -8.0876000, 111.6592000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67426, 'Karangan', 'Karangan', 'Karangan', 0.5598600, 109.3756600, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67427, 'Karangampel', 'Karangampel', 'Karangampel', -6.4622200, 108.4519400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67428, 'Kapuan', 'Kapuan', 'Kapoean,Kapuan', -7.1894000, 111.5567000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67429, 'Kapongan', 'Kapongan', 'Kapongan', -7.6907000, 114.0619000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67430, 'Kapinango', 'Kapinango', 'Kapinango', -6.4127000, 105.8625000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67431, 'Kapan', 'Kapan', 'Kapan', -9.7348000, 124.2739000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67432, 'Kepahiang', 'Kepahiang', 'Kapahiang,Kepahiang', -3.6455000, 102.5712000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67433, 'Kandangan', 'Kandangan', 'Kandangan,Kendangan', -2.7837000, 115.2772000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67434, 'Kandang Timur', 'Kandang Timur', 'Kandang,Kandang Timur', -6.8041600, 106.0059800, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67435, 'Malaju', 'Malaju', 'Kampoeng Maladjoe,Kampung Maladju,Kampung Malaju,Malaju', -8.3104000, 118.3940000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67436, 'Kelarik', 'Kelarik', 'Kampong Air Nali,Kampung Air Nali,Kelarik', 4.0083300, 107.9986100, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67437, 'Hampang', 'Hampang', 'Hampang,Kampang', -2.9180000, 115.8373000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67438, 'Kampak', 'Kampak', 'Kampak', -8.1748000, 111.6613000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67439, 'Kameri', 'Kameri', 'Kameri,Kamiri,Kamirt', -0.9821000, 134.8046000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67440, 'Kambu', 'Kambu', 'Kamboe,Kambu', -8.3861000, 118.3212000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67441, 'Kambang', 'Kambang', 'Kambang', -1.6904000, 100.7209000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67442, 'Kamal', 'Kamal', 'Kama,Kamal,Kamal'',Камаль', -7.1677800, 112.7191700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67443, 'Cikaludan', 'Cikaludan', 'Cikaludan,Kaludan', -6.7077000, 105.8906000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67444, 'Cibaregbeg', 'Cibaregbeg', 'Cibaregbeg,Kalong,Tjibaregbeg', -7.6791600, 107.8029500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67445, 'Kalitengah', 'Kalitengah', 'Kalitengah', -6.9954000, 112.4004000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67446, 'Kalitelo', 'Kalitelo', 'Kalitelo', -8.2572000, 112.4341000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67447, 'Kalipuro', 'Kalipuro', 'Kalipuro', -8.1687000, 114.3591000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67448, 'Kalipucang', 'Kalipucang', 'Kalipoetjang,Kalipucang,Kalipuchang,Kaliputjang,Kaliputjung', -7.6433000, 108.7526000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67449, 'Kalipang', 'Kalipang', 'Kalipang', -6.7241000, 111.6536000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67450, 'Kaliori', 'Kaliori', 'Kaliori', -6.7019000, 111.2475000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67451, 'Kalikasa', 'Kalikasa', 'Kalikasa,Kalikassa', -8.4338000, 123.4678000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67452, 'Kalijeruk', 'Kalijeruk', 'Kalidjeruk,Kalijeruk', -8.0653000, 113.3390000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67453, 'Kalidawir', 'Kalidawir', 'Kalidawir', -8.1808000, 111.9723000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67454, 'Kalibunder', 'Kalibunder', 'Kalibunder', -7.2627000, 106.7222000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67455, 'Kalibaru', 'Kalibaru', 'Kalibaroe,Kalibaru,Kalibaru-wetan,Kaliboroe', -8.2897000, 113.9859000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67456, 'Kalianget', 'Kalianget', 'Kalianget', -7.0537000, 113.9424400, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67457, 'Kalianda', 'Kalianda', 'Kalanda,Kalianda,Kaliandak', -5.7380500, 105.5916000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67458, 'Kiraman', 'Kiraman', 'Kalatani,Kilabani,Kiraman', -8.4004400, 124.7505900, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67459, 'Kalangbret', 'Kalangbret', 'Kalangbret', -8.0527000, 111.8653000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67460, 'Kalabahi', 'Kalabahi', 'Kalabahi,Kalabaki,Kalaoahi,Kalooahi', -8.2151000, 124.5458000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67461, 'Kajen', 'Kajen', 'Kadjen,Kajen', -7.0324000, 109.5773000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67462, 'Kairatu', 'Kairatu', 'Kairatoe,Kairatu', -3.3516700, 128.3685300, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67463, 'Kaimana', 'Kaimana', 'KNG,Kaimana', -3.6635000, 133.7649000, 'ID', '2017-02-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67464, 'Kahale', 'Kahale', 'Kahale', -9.6962000, 119.1047000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67465, 'Kaduranca', 'Kaduranca', 'Kaduranca,Kadurantja', -6.3610000, 105.9299000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67466, 'Kadupandak', 'Kadupandak', 'Kadoepandak,Kadupandak', -7.2611000, 107.0472000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67467, 'Kadupandak', 'Kadupandak', 'Kadupandak', -6.5061000, 105.9690000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67468, 'Kadumula', 'Kadumula', 'Kadumula', -6.5162000, 105.9661000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67469, 'Kadujajar', 'Kadujajar', 'Kadoedjadjar,Kadudjadjar,Kadujajar', -6.7482600, 106.0261600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67470, 'Cililitan', 'Cililitan', 'Cililitan,Kadoehaoek,Kaduhauk', -6.5063800, 105.9780200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67471, 'Kadugedong', 'Kadugedong', 'Kadugedong', -6.3639000, 106.1000000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67472, 'Kadugede', 'Kadugede', 'Kadoegede,Kadugede', -7.0043000, 108.4543000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67473, 'Kaduengang', 'Kaduengang', 'Kaduengang', -6.2598000, 106.0742000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67474, 'Kadubitung', 'Kadubitung', 'Kadubitung', -6.5370000, 106.3531000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67475, 'Kadubeureum', 'Kadubeureum', 'Kadubeureum', -6.3595000, 105.9416000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67476, 'Kademangan', 'Kademangan', 'Kademangan', -8.1467400, 112.1442900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67477, 'Kabir', 'Kabir', 'Kabir', -8.2545000, 124.2145000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67478, 'Kabare', 'Kabare', 'Kabare,Kabarei,Kabarel', -0.0149000, 130.8322000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67479, 'Juwana', 'Juwana', 'Djoeana,Djoewana,Djoewono,Djuana,Djuwana,Djuwono,Joana,Juana,Juwana', -6.7150000, 111.1514000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67480, 'Dungkek', 'Dungkek', 'Djoerangan,Djurangan,Doengkek,Doengket,Dungkek,Jurangan', -6.9779000, 114.0948000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67481, 'Jungkat Selatan', 'Jungkat Selatan', 'Djoengkat,Djungkat,Jungkat,Jungkat Selatan', -7.1385000, 114.5259000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67482, 'Jorong', 'Jorong', 'Djorong,Jorong', -3.9860000, 114.9518000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67483, 'Jombang', 'Jombang', 'Djombang,Jombang,Kabupaten Jombang', -7.5459500, 112.2330700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67484, 'Jojogan', 'Jojogan', 'Djodjogan,Jojogan,Singgahan', -6.9709000, 111.7881000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67485, 'Jogonalan', 'Jogonalan', 'Djogonalan,Jogonalan', -7.7036100, 110.5361100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67486, 'Jiput', 'Jiput', 'Djiput,Jiput', -6.3442000, 105.9014000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67487, 'Jimbaran', 'Jimbaran', 'Djimbaran,Dzhimbaran,Джимбаран', -8.7909300, 115.1600600, 'ID', '2010-06-24', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67488, 'Cijalarang', 'Cijalarang', 'Cijalarang,Djialang,Djralang,Jialang', -6.6644000, 105.6704000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67489, 'Jeruklegi', 'Jeruklegi', 'Djeroeklegi,Djeruklegi,Djeruklegi-wetan,Jeruklegi', -7.6244400, 109.0191700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67490, 'Jepon', 'Jepon', 'Djepon,Jepon', -6.9726000, 111.4795000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67491, 'Jepara', 'Jepara', 'Djapara,Djepara,Japara,Jepara,Yapara,jybara,جيبارا', -6.5924000, 110.6710000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67492, 'Jepara', 'Jepara', 'Djepara,Jepara', -5.1694800, 105.7044100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67493, 'Jenggawah', 'Jenggawah', 'Djanggawah,Djenggawah,Djenggawak,Jenggawah', -8.2661000, 113.6479000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67494, 'Jeneponto', 'Jeneponto', 'Bontongsunggu,Bontosunggu,Djeneponto,Jeneponto', -5.6765000, 119.7484000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67495, 'Jember', 'Jember', 'Djember,JBB,Jember', -8.1721100, 113.6995300, 'ID', '2014-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67496, 'Jelbuk', 'Jelbuk', 'Djelboek,Djelbuk,Djelebuk,Jelbuk', -8.0839000, 113.7592000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67497, 'Jelat', 'Jelat', 'Djelat,Jelat', -7.2839000, 108.3853000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67498, 'Jekulo', 'Jekulo', 'Djekoela,Djekoelo,Djekolo,Djekulo,Jekulo,Tenggeles', -6.8057000, 110.9262000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67499, 'Jebus', 'Jebus', 'Djeboes,Djebus,Jebus', -1.7430200, 105.4552700, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67500, 'Jatiwangi', 'Jatiwangi', 'Djatiwangi,Jatiwangi', -6.7336100, 108.2627800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67501, 'Jatiroto', 'Jatiroto', 'Djatirata,Djatiroto,Jatiroto', -8.1218000, 113.3637000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67502, 'Jatiroto', 'Jatiroto', 'Djatiroto,Jatiroto', -7.8833300, 111.1166700, 'ID', '2013-11-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67503, 'Jatirogo', 'Jatirogo', 'Djatiraga,Djatirogo,Jatiraga,Jatirogo,Wotsaga,Wotsoga,Wotsogo', -6.8858000, 111.6592000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67504, 'Jatipamor', 'Jatipamor', 'Djatipamor,Jatipamor', -7.0028000, 108.3290000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67505, 'Jatinagara', 'Jatinagara', 'Djatinegara,Jatinagara,Jatinegara', -7.1735000, 108.4028000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67506, 'Jatilawang', 'Jatilawang', 'Djatilawang,Djatitawang,Jatilawang', -7.5344400, 109.1197200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67507, 'Jatibarang', 'Jatibarang', 'Djatibarang,Jatibarang', -6.4747200, 108.3152800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67508, 'Jaten', 'Jaten', 'Djaten,Jaten', -7.5772200, 110.8975000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67509, 'Jatake', 'Jatake', 'Djatake,Jatake', -6.8727000, 106.2564000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67510, 'Jarurejo', 'Jarurejo', 'Djaroredja,Djaroredjo,Jarorejo,Jarurejo', -6.9000000, 111.8852000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67511, 'Jarangan', 'Jarangan', 'Djarangan,Jarangan', -8.1078000, 112.4463000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67512, 'Japah', 'Japah', 'Djapah,Djapoh,Japah,Japoh', -6.9423000, 111.2903000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67513, 'Japerejo', 'Japerejo', 'Djape,Djaperedjo,Japerejo', -6.7495000, 111.4495000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67514, 'Jangkat', 'Jangkat', 'Djangkat,Jangkat', -2.5072000, 102.0540000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67515, 'Janaka', 'Janaka', 'Djanaka,Janaka', -6.3167100, 105.8813700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67516, 'Jampang Tengah', 'Jampang Tengah', 'Bodjonglopang,Diampang-tengah,Djampang-rengah,Djampang-tengah,Djampangtengah,Jampang Tengah', -7.0568000, 106.8014000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67517, 'Jampang Kulon', 'Jampang Kulon', 'Djampang-koelon,Djampang-kulon,Jampang Kulon,Jampang-kulon,Tjitjoeroeg,Tjitjurug', -7.2579000, 106.6256000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67518, 'Jambula', 'Jambula', 'Djamboela,Djambula,Jambula,Jambulang', 0.7577600, 127.3182800, 'ID', '2016-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67519, 'Jambi City', 'Jambi City', 'DJB,Djambi,Dzhambi,Jambi,Jambi City,Sriindrapura,Telanaipura,jamby,Джамби,جامبي', -1.6000000, 103.6166700, 'ID', '2014-05-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67520, 'Jalatrang', 'Jalatrang', 'Djalatrang,Jalatrang', -7.2373000, 108.3483000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67521, 'Jalang', 'Jalang', 'Djalang,Djaling,Jalang,Jaling', -4.0383000, 120.3216000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67522, 'Jakenan', 'Jakenan', 'Djakenan,Jakenan', -6.7620000, 111.1643000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67523, 'Jaken', 'Jaken', 'Djaken,Jaken,Srikaton', -6.7803000, 111.2429000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67524, 'Jakarta', 'Jakarta', 'Batavia,Cakarta,D''akarta,Daerah Khusus Ibukota Jakarta,Djakarta,Djogkarta,Dki Jakarta,Dzakarta,Dzhakarta,Dzhakartae,Dżakarta,Džakarta,Gakarto,Giacarta,Gorad Dzhakarta,Iacarta,Iacárta,JKT,Jacarta,Jakarta,Jogkarta,Nga-ka-that Su-tu Thit-khi,Ngâ-kâ-tha̍t Sú-tû Thi̍t-khî,Tzakarta,Xacarta,Xhakarta,Yajgyadaz,Yakarta,Zhakarta,cakarta,g''qrth,jakaleuta,jakarata,jakarta,jakartta,jakaruta,jkarta,ya jia da,Ĝakarto,Τζακάρτα,Џакарта,Горад Джакарта,Джакартæ,Джакарта,Дьакарта,Жакарта,Ջակարտա,ג''קרטה,דזשאקארטא,جاكارتا,جاکارتا,جکارتا,جکارتہ,जकार्ता,জাকার্তা,ਜਕਾਰਤਾ,જાકાર્તા,ଜାକର୍ତା,ஜகார்த்தா,జకార్తా,ಜಕಾರ್ತ,ജക്കാർത്ത,จาการ์ตา,ཊ་ཁར་ཏ།,ဂျကာတာမြို့,ჯაკარტა,ጃካርታ,ចាការតា,ジャカルタ,雅加达,자카르타', -6.2146200, 106.8451300, 'ID', '2012-08-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67525, 'Jajawai', 'Jajawai', 'Djadjawa,Djadjawaj,Jajawai,Jajaway', -7.5682000, 108.4781000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67526, 'Jailolo', 'Jailolo', 'Djaibolo,Djailolo,Jailolo', 1.0650400, 127.4678600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67527, 'Jager', 'Jager', 'Djager,Jager', -7.1770000, 107.9446000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67528, 'Jabungsisir', 'Jabungsisir', 'Diabung,Djaboeng,Djaboengsisir,Djabung,Jabung,Jabungsisir', -7.7316000, 113.4693000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67529, 'Jabung', 'Jabung', 'Djaboeng,Djabung,Jabung', -5.4631400, 105.6675200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67530, 'Isimu', 'Isimu', 'Isimoe,Isimu', 0.6446000, 122.8614000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67531, 'Ipuh', 'Ipuh', 'Ipoeh,Ipu,Ipuh', -3.0067000, 101.4836000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67532, 'Indramayu', 'Indramayu', 'Indramajoe,Indramaju,Indramayu', -6.3263900, 108.3200000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67533, 'Indrajaya Satu', 'Indrajaya Satu', 'Indradjaja,Indrajaya,Indrajaya Satu', -7.1751000, 108.7750000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67534, 'Indralaya', 'Indralaya', 'Inderalaja,Inderalaya,Indralaja,Indralaya', -3.2524900, 104.6755500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67535, 'Inanwatan', 'Inanwatan', 'INX,Inamwatan,Inanwatan,Inawatan,Kampoeng Bira', -2.1270500, 132.1652700, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67536, 'Alung', 'Alung', 'Alung,Iloeng,Ilung', -2.5161000, 115.4275000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67537, 'Ili', 'Ili', 'Ili', -8.6748000, 122.2660000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67538, 'Hinga', 'Hinga', 'Hinga,Hingga', -8.3085000, 123.2288000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67539, 'Hila', 'Hila', 'Hila', -3.5868900, 128.0879800, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67540, 'Haurkuning', 'Haurkuning', 'Haoerkoening,Haurkuning', -7.0187000, 108.4310000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67541, 'Gajrug', 'Gajrug', 'Gajrug,Haoergadjoeg,Haurgadjrug,Haurgajrug', -6.5271000, 106.3798000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67542, 'Haruyan', 'Haruyan', 'Haroejan,Harujan,Haruyan', -2.6916900, 115.3499200, 'ID', '2015-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67543, 'Haruai', 'Haruai', 'Haruai,Harui', -2.0154000, 115.5072000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67544, 'Hanjuang', 'Hanjuang', 'Handjuang,Hanjuang', -7.4648000, 107.5953000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67545, 'Hanjuang', 'Hanjuang', 'Handjuang,Hanjuang', -6.5791000, 106.2762000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67546, 'Hadakewa', 'Hadakewa', 'Hadakewa,Pasar Hadakewa', -8.3698000, 123.5473000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67547, 'Guyangan', 'Guyangan', 'Gujangan,Guyangan', -6.6598000, 111.0989000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67548, 'Guranteng', 'Guranteng', 'Goeranteng,Guranteng', -7.0991000, 108.1931000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67549, 'Gunungwungkal', 'Gunungwungkal', 'Goenoengwoengkal,Gunungwungkal', -6.5662000, 110.9891000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67550, 'Gunungwaru Satu', 'Gunungwaru Satu', 'Goenoengwaroe,Gunungwaru,Gunungwaru Satu', -7.2410000, 107.0498000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67551, 'Gunung Sugih', 'Gunung Sugih', 'Goenoengsoegih,Gunongsugi,Gunung Sugih,Gunungsugih', -4.9753000, 105.2139600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67552, 'Gunungsari', 'Gunungsari', 'Goenoengsari,Gunungsari', -6.1628000, 106.0611000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67553, 'Gunungmenang', 'Gunungmenang', 'Goenoengmenang,Gunungmenang', -3.1799000, 104.0334700, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67554, 'Gunungmegang Dalam', 'Gunungmegang Dalam', 'Goenoengmegang-dalem,Gunungmegang,Gunungmegang Dalam,Gunungmegang-dalem,Ooenoengmegangdalem', -3.4496800, 103.8699000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67555, 'Gunungkendeng', 'Gunungkendeng', 'Goenoengkendeng,Gunungkendeng', -6.6706000, 106.0547000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67556, 'Gunungkencana', 'Gunungkencana', 'Goenoengkantjana,Goenoengkenchana,Goenoengkentjana,Goenoengketjana,Gunungkencana,Gunungkentjana', -6.5721000, 106.0742000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67557, 'Desa Kaler Gunungcupu', 'Desa Kaler Gunungcupu', 'Desa Kaler Gunungcupu,Goenoengtjoepoe,Gunungcupu,Gunungtjupu', -7.2948000, 108.2298000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67558, 'Gunungbitung', 'Gunungbitung', 'Gunungbitung', -7.3150000, 107.0919000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67559, 'Gunungbatubesar', 'Gunungbatubesar', 'Goengengbatoe-besar,Goenoeng Batoe Besar,Gunong Batu Befar,Gunong Batu Besar,Gunungbatubesar', -2.6211000, 116.2931000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67560, 'Gunem', 'Gunem', 'Gunem', -6.8070000, 111.4656000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67561, 'Gemuruh', 'Gemuruh', 'Gemuruh,Gumuruh', -6.4393000, 106.0889000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67562, 'Gumuk Tengah', 'Gumuk Tengah', 'Goemoek,Gumuk,Gumuk Tengah', -7.6392000, 114.0047000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67563, 'Gulukguluk', 'Gulukguluk', 'Goeloekgoeloek,Gulukguluk', -7.0546000, 113.6754000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67564, 'Gubugklakah Barat', 'Gubugklakah Barat', 'Gubugklakah Barat,Gubukklakah', -8.0232000, 112.8336000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67565, 'Grogol', 'Grogol', '', -7.6011100, 110.8186100, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67566, 'Gresik', 'Gresik', 'Geresik,Gersik,Gresik,Grise,Grisee,Grissee', -7.1538900, 112.6561100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67567, 'Grawan', 'Grawan', 'Grawan', -6.7672000, 111.2909000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67568, 'Gorontalo', 'Gorontalo', 'Gorontalo,Горонтало', 0.5375000, 123.0625000, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67569, 'Gonggong', 'Gonggong', 'Gonggong', -6.3875000, 105.8976000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67570, 'Gondanglegi Wetan', 'Gondanglegi Wetan', 'Gondanglegi Wetan,Gondanglegi-wetan', -8.1796600, 112.6407600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67571, 'Gongdanglegi Kulon', 'Gongdanglegi Kulon', 'Gondanglegi,Gondangtegi,Gongdanglegi Kulon', -8.1752900, 112.6359400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67572, 'Gondang', 'Gondang', 'Gondang', -8.0734000, 111.8472000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67573, 'Gombong', 'Gombong', 'Gombong', -7.6072200, 109.5141700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67574, 'Gombong', 'Gombong', 'Gombong', -7.1914000, 108.1361000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67575, 'Golokan', 'Golokan', 'Golokan', -6.9784000, 112.5392000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67576, 'Godo', 'Godo', 'Godo', -8.5611400, 118.6664700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67577, 'Godean', 'Godean', 'Godean,Godejan', -7.7697200, 110.2938900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67578, 'Glonggong', 'Glonggong', 'Glonggong', -6.7535000, 111.1234000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67579, 'Glondong', 'Glondong', 'Glondong', -6.7924000, 111.8916000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67580, 'Gisiliba', 'Gisiliba', 'Gisi,Gisiliba', -8.8312600, 121.0524300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67581, 'Cigebrok', 'Cigebrok', 'Cigebrok,Girilaja,Girilaya', -6.5654000, 106.3716000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67582, 'Gilimanuk', 'Gilimanuk', 'Gilimanoek,Gilimanuk', -8.1716000, 114.4344000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67583, 'Gianyar', 'Gianyar', 'Gianjar,Gianyar', -8.5435000, 115.3272000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67584, 'Geser', 'Geser', 'Geser,Gisser', -3.8732000, 130.9254000, 'ID', '2013-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67585, 'Gerung', 'Gerung', 'Geroeng,Gerung,Groeng', -8.6830000, 116.1253000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67586, 'Gersikputih Tengah', 'Gersikputih Tengah', 'Gersekpoetih,Gersekputih,Gersikpoetih,Gersikputih,Gersikputih Tengah', -7.0353000, 113.9564000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67587, 'Karangsari', 'Karangsari', 'Gerdoeg,Gerdug,Karangsari', -6.4361000, 105.9725000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67588, 'Genteng', 'Genteng', 'Genteng-kulon', -8.3666700, 114.1500000, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67589, 'Genteng Wetan', 'Genteng Wetan', 'Genteng,Genteng Wetan', -7.3671000, 108.8657000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67590, 'Glumbang', 'Glumbang', 'Geloembang,Gelumbang,Gloembang,Glumbang', -3.2394900, 104.4372500, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67591, 'Gedong Tataan', 'Gedong Tataan', 'Gedong Tataan,Gedongtataan', -5.3827000, 105.0955000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67592, 'Gedog Wetan', 'Gedog Wetan', 'Gedog Wetan,Gedokwetan', -8.1996500, 112.6952300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67593, 'Gedangan', 'Gedangan', '', -7.3908300, 112.7266700, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67594, 'Gebog', 'Gebog', 'Gebog', -6.7350000, 110.8444000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67595, 'Gayam', 'Gayam', 'Gajam,Gayam,Grajam', -7.1636000, 114.3310000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67596, 'Garut', 'Garut', 'Garoet,Garut', -7.2024000, 107.8878000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67597, 'Garisul', 'Garisul', 'Garisul', -6.5055000, 106.4959000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67598, 'Gardu', 'Gardu', 'Gardoe Dua,Gardu', -7.0762000, 108.3845000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67599, 'Garawangi', 'Garawangi', 'Garangwangi,Garawangi', -6.9987000, 108.5389000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67600, 'Garahan', 'Garahan', 'Garaan,Garahan,Garaän', -8.2117000, 113.8924000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67601, 'Garajati', 'Garajati', 'Garadjati,Garajati', -7.0498000, 108.6381000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67602, 'Gapura', 'Gapura', 'Gapoera,Gapura', -6.9966700, 113.9557500, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67603, 'Gangseyan', 'Gangseyan', 'Gangsejan,Gangseyan', -6.9427000, 112.9460000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67604, 'Gandusari', 'Gandusari', 'Gandusari', -8.1296000, 111.7044000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67605, 'Gandusari', 'Gandusari', 'Gandoesari,Gandusari', -8.0457000, 112.3030000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67606, 'Gandrungmangu', 'Gandrungmangu', 'Gandroengmangoe,Gandrungmangu,Gandrungmangun', -7.5203600, 108.8535100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67607, 'Ganding', 'Ganding', 'Ganding', -7.0387000, 113.6887000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67608, 'Gampengrejo', 'Gampengrejo', 'Gampeng,Gampengredja,Gampengredjo', -7.7666700, 112.0166700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67609, 'Gampang', 'Gampang', 'Gampang', -6.9560000, 112.2986000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67610, 'Gambirono', 'Gambirono', 'Gambirana,Gambirono', -8.1990000, 113.5189000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67611, 'Gambiran Satu', 'Gambiran Satu', 'Gambiran,Gambiran Satu', -8.3939000, 114.1464000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67612, 'Galunggalung', 'Galunggalung', 'Galunggalung,Pambauang', -3.4890000, 118.8960000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67613, 'Kalumpang', 'Kalumpang', 'Galoempang,Galumpang,Goloempang,Kalumpang', -2.4781000, 119.4859000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67614, 'Galis', 'Galis', 'Galis', -7.1562400, 113.5537300, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67615, 'Galesong', 'Galesong', 'Galesong', -5.3166000, 119.3661000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67616, 'Gadog', 'Gadog', 'Gadog', -7.7937000, 108.4381000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67617, 'Gadang', 'Gadang', 'Gadang', -8.0123000, 112.6283000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67618, 'Fakfak', 'Fakfak', 'FKQ,Fakfak', -2.9248100, 132.2981300, 'ID', '2014-11-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67619, 'Essang', 'Essang', 'Esang,Essang,Kampoeng Essang', 4.4550100, 126.7385900, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67620, 'Enrekang', 'Enrekang', 'Enrekang', -3.5650800, 119.7702500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67621, 'Enok', 'Enok', 'Enok', -0.5149000, 103.1985000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67622, 'Enemawira', 'Enemawira', 'Enemawira', 3.6565000, 125.5612000, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67623, 'Ende', 'Ende', 'ENE,Ende,Endeh,Kota Ende', -8.8432000, 121.6623000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67624, 'Enarotali', 'Enarotali', 'EWI,Enaratoli,Enaretali,Enarotali,Pania,Paniai', -3.9303200, 136.3765100, 'ID', '2013-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67625, 'Elopada', 'Elopada', 'Ellopada,Elopada', -9.5686000, 119.3172000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67626, 'Duri', 'Duri', 'Duri', 1.2760700, 101.1945700, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67627, 'Durenan', 'Durenan', 'Doerenan,Durenan', -8.1203000, 111.7986000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67628, 'Dumoga', 'Dumoga', 'Doemoega-besar,Doemoga,Dumoga,Dumoga Besar', 0.6096000, 124.0826000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67629, 'Dumai', 'Dumai', 'DUM,Doemai,Dumai,Dumaj,Kota Dumai,Думай', 1.6671100, 101.4431600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67630, 'Dulolong', 'Dulolong', 'Doelolong,Dulolong', -8.2547000, 124.4476000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67631, 'Dukuhturi', 'Dukuhturi', '', -6.9000000, 109.0833300, 'ID', '2013-11-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67632, 'Dukuhtengah', 'Dukuhtengah', 'Doekoehtengah,Dukuhtengah', -7.5173900, 108.8009000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67633, 'Dukuhseti', 'Dukuhseti', 'Doekoehseti,Dukuhseti', -6.4705000, 111.0358000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67634, 'Dukuhbadag', 'Dukuhbadag', 'Doekoehbadag,Dukuhbadag', -7.0256000, 108.7564000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67635, 'Kotadukuh', 'Kotadukuh', 'Doekoeh,Dukuh,Kotadukuh', -6.5973000, 105.9036000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67636, 'Driyorejo', 'Driyorejo', 'Driaredja,Drijoredjo,Drioredja,Drioredjo,Driorejo,Driyorejo', -7.3659000, 112.6219000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67637, 'Dresi Kulon', 'Dresi Kulon', 'Dresi,Dresi Kulon', -6.7111000, 111.2689000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67638, 'Drajat', 'Drajat', 'Dradjat,Drajat', -6.8828000, 112.3880000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67639, 'Soro', 'Soro', 'Dorosoro,Soro', -8.5573000, 118.2381000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67640, 'Kesi', 'Kesi', 'Doro Kessi,Kesi,Santigi', -8.5338000, 118.1922000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67641, 'Kempo', 'Kempo', 'Dorokempo,Kempo', -8.5428600, 118.2482100, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67642, 'Taloko', 'Taloko', 'Doro Taloko,Dorokaloko,Taloko', -8.4012000, 118.3165000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67643, 'Dopang', 'Dopang', 'Dopang', -6.8266000, 111.1348000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67644, 'Donomulyo', 'Donomulyo', 'Danamoeljo,Donomoeljo,Donomulio,Donomuljo,Donomulyo', -8.2867000, 112.4270000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67645, 'Dongko', 'Dongko', 'Dongko', -8.1882000, 111.5746000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67646, 'Donggala', 'Donggala', 'Dongala,Donggala', -0.6723000, 119.7402000, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67647, 'Dompu', 'Dompu', 'Dompo,Dompoe,Dompu', -8.5365000, 118.4634000, 'ID', '2016-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67648, 'Domasan', 'Domasan', 'Domasan', -8.1447000, 111.9760000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67649, 'Dofa', 'Dofa', 'Dofa', -1.7952000, 125.3649000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67650, 'Dobo', 'Dobo', 'DOB,Dobo', -5.7609200, 134.2340500, 'ID', '2013-12-15', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67651, 'Diwek', 'Diwek', '', -7.5789700, 112.2310900, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67652, 'Deudeul', 'Deudeul', 'Deudeul', -7.4310000, 108.0273000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67653, 'Depok', 'Depok', '', -7.7625000, 110.4316700, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67654, 'Depok', 'Depok', 'Depok,Depok kutha,Depokas,Kota Depok,Kota Dépok', -6.4000000, 106.8186100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67655, 'Denpasar', 'Denpasar', 'DPS,Dempasar,Dempassar,Denpasar,Denpasar Bali,Denpasaras,Gorad Dehnpasar,Kota Denpasar,Kutha Denpasar,Ntenpasar,dan pa sha,denapasara,denpasaleu,denpasaru,dnpasar,Ντενπασάρ,Горад Дэнпасар,Денпасар,דנפסאר,دنپاسار,ڈنپاسار,ڈنپسار,देनपसार,દેનપસાર,ဒန်ပါဆာမြို့,დენპასარი,デンパサール,丹帕沙,덴파사르', -8.6500000, 115.2166700, 'ID', '2016-03-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67656, 'Demak', 'Demak', 'Demak,Demark,Демак', -6.8909000, 110.6396000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67657, 'Delanggu', 'Delanggu', 'Delanggoe,Delanggu,Delangu', -7.6166700, 110.6833300, 'ID', '2013-10-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67658, 'Dayeuhluhur', 'Dayeuhluhur', 'Dajeon-loehoer,Dajeuh-loehoer,Dajeuh-luhur,Dayeuhluhur', -7.2594000, 108.6108000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67659, 'Dayeuhluhur', 'Dayeuhluhur', 'Dajeuh-Loehoer,Dajeuhluhur,Dayeuhluhur', -7.1752000, 108.3854000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67660, 'Datar', 'Datar', 'Datar', -7.2078000, 108.6321000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67661, 'Dasun', 'Dasun', 'Dasoen,Dasun', -6.6782000, 111.4454000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67662, 'Dasuk', 'Dasuk', 'Dasok,Dasuk', -6.9015000, 113.8139000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67663, 'Daruba', 'Daruba', 'Daruba', 2.0500000, 128.2958300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67664, 'Darma', 'Darma', 'Darma', -7.0045000, 108.4035000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67665, 'Danurejo', 'Danurejo', 'Danuredjo,Danurejo', -8.2415000, 113.0721000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67666, 'Dangiang', 'Dangiang', 'Dangiang', -7.4586000, 107.8762000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67667, 'Dampit', 'Dampit', 'Dampit', -8.2116200, 112.7493400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67668, 'Dalududalu', 'Dalududalu', 'Daloedaloe,Daludalu,Dalududalu', 1.0814200, 100.2447500, 'ID', '2013-10-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67669, 'Dadapan', 'Dadapan', 'Dadapan', -8.3222000, 114.1946000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67670, 'Dabra', 'Dabra', 'DRH,Dabra', -3.2453000, 138.5878000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67671, 'Curup', 'Curup', 'Churup,Curup,Tjoeroep,Tjurup', -3.4703000, 102.5207000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67672, 'Curugkembar Satu', 'Curugkembar Satu', 'Curugkembar,Curugkembar Satu,Tjoeroegkembar 1,Tjurugkembar', -7.2141000, 106.9363000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67673, 'Curug', 'Curug', 'Curug,Tjoeroeg,Tjurug', -6.2658300, 106.5563900, 'ID', '2013-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67674, 'Curahtakir', 'Curahtakir', 'Curahtakir,Tjurahtakir', -8.3586000, 113.7522000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67675, 'Curahnongko', 'Curahnongko', 'Curahnongko,Tjoerahnangka,Tjurahnongko', -8.4007000, 113.7346000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67676, 'Cungkal', 'Cungkal', 'Cungkal,Tjoengkal,Tjungkal', -8.2074000, 112.4866000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67677, 'Cumedak', 'Cumedak', 'Cumedak,Cumedak Satu,Tjumedak', -8.1004000, 113.8928000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67678, 'Desa', 'Desa', 'Cukangkawung,Desa,Desa Cukangkawung,Tjoekangkawoeng,Tjukangkawung', -7.4748000, 108.0168000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67679, 'Coo', 'Coo', 'Coo,Tjoo,Tjoö', -6.5563000, 106.2901000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67680, 'Comal', 'Comal', 'Chiomal,Chomal,Comal,Tjomal', -6.9053000, 109.5347000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67681, 'Colomadu', 'Colomadu', 'Colomadu,Tjolomadu', -7.5333300, 110.7500000, 'ID', '2013-10-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67682, 'Ciwaru', 'Ciwaru', 'Ciwaru,Tjiwaroe,Tjiwaru', -7.0777000, 108.6278000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67683, 'Ciwalen', 'Ciwalen', 'Ciwalen,Tjiwalen', -7.2795000, 108.6079000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67684, 'Ciusul', 'Ciusul', 'Ciusul,Tjiusul', -6.7386000, 106.3452000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67685, 'Ciudian', 'Ciudian', 'Ciudian,Tjioedian,Tjiudian', -7.4596000, 107.9011000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67686, 'Citundun', 'Citundun', 'Citundun,Tjitoendoen,Tjitundun', -7.1108000, 108.6206000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67687, 'Citeureup', 'Citeureup', 'Citeureup,Tjiteureup', -6.6483000, 106.0751000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67688, 'Citeureup', 'Citeureup', 'Chiteureup,Citeureup,Tjiteurep,Tjiteureup', -6.5338000, 105.7099000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67689, 'Citeureup', 'Citeureup', 'Citeurep,Citeureup,Tjiteureup', -6.4855600, 106.8819400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67690, 'Citanglar', 'Citanglar', 'Citanglar,Tjitanglar', -7.3179000, 106.5844000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67691, 'Citampian', 'Citampian', 'Citampian,Tjitampian', -7.1599000, 106.7645000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67692, 'Cisuru', 'Cisuru', 'Cisuru,Tjiseru,Tjisoeroe Satu,Tjisuru', -7.3982000, 108.7368000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67693, 'Cisompet', 'Cisompet', 'Cisompet,Tjisoinpet,Tjisompet', -7.5517900, 107.8103000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67694, 'Cisolok', 'Cisolok', 'Chisolok,Cisolok,Tjisolok', -6.9482000, 106.4498000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67695, 'Cisewu', 'Cisewu', 'Cisewu,Tjisewoe,Tjisewu', -7.3758000, 107.4975000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67696, 'Ciseureuheun', 'Ciseureuheun', 'Ciseureuheum,Ciseureuheun,Tjiseureuheum', -6.5995000, 105.7152000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67697, 'Ciseukeut Timur', 'Ciseukeut Timur', 'Ciseukeut,Ciseukeut Timur,Tjiseukeut', -6.5232000, 105.7548000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67698, 'Cisayong', 'Cisayong', 'Cisayong,Tjisajong', -7.2575000, 108.1494700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67699, 'Cisarua', 'Cisarua', 'Cisarua,Tjisarua', -6.6527000, 106.4710000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67700, 'Cisandaan', 'Cisandaan', 'Cisandaan,Tjisandaan', -7.3958000, 107.7202000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67701, 'Cisalak', 'Cisalak', 'Cisalak,Tjisalak', -7.3086000, 108.8649000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67702, 'Cisaga', 'Cisaga', 'Cisaga,Tjisaga,Tjisaga Satu', -7.3461000, 108.5163000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67703, 'Cirukem', 'Cirukem', 'Cirukem,Tjiroekem,Tjirukem', -7.0235000, 108.5106000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67704, 'Ciruas', 'Ciruas', 'Ciruas,Tjiroeas,Tjiruas', -6.1250000, 106.2327800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67705, 'Ciroyom', 'Ciroyom', 'Ciroyom,Tjirojom', -7.4916000, 107.9704000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67706, 'Cirompang', 'Cirompang', 'Cirompang,Tjirompang', -6.6682000, 106.3181000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67707, 'Cirinten', 'Cirinten', 'Cirinten,Tjirinten', -6.6324000, 106.1572000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67708, 'Cireuma', 'Cireuma', 'Cireuma,Tjireuma', -7.8134000, 108.3674000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67709, 'Cirebon', 'Cirebon', 'CBN,Cheribon,Chirebon,Cirebon,Cirebon kutha,Kota Cirebon,Kutha Cirebon,Tjerebon,Tjeribon,Tjirebon,chileubon,chireboni,chirubon,jing li wen,syrybwn,Чиребон,سيريبون,سیریبون,ჩირებონი,チルボン,井裡汶,치르본', -6.7063000, 108.5570000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67710, 'Ciracap', 'Ciracap', 'Chirachap,Ciracap,Tjiratjap', -7.3312000, 106.5215000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67711, 'Ciputat', 'Ciputat', 'Ciputat,Tjipoetat,Tjipoetat 2,Tjiputat,Tjiputat 2', -6.2375000, 106.6955600, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67712, 'Cipondok', 'Cipondok', 'Cipondok,Tjipondok', -7.0817000, 108.7579000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67713, 'Ciomas', 'Ciomas', 'Ciomas,Cipomas,Tjiomas,Tjipomas', -7.1527000, 108.2879000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67714, 'Cipinang', 'Cipinang', 'Cipinang,Cipining,Tjipining', -6.6075000, 105.8640000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67715, 'Cipicung', 'Cipicung', 'Cipicung,Tjipitjoeng 2,Tjipitjung', -7.5566000, 108.0322000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67716, 'Cipicung Timur', 'Cipicung Timur', 'Cipicung,Cipicung Timur,Tjipitjoeng,Tjipitjung', -6.6750000, 106.1737000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67717, 'Cipeundeuy', 'Cipeundeuy', 'Cipeundeuy,Tjipeundeuj', -6.7003000, 106.1134000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67718, 'Cipeundeuy', 'Cipeundeuy', 'Cipeundeuy,Tjipeundeuj', -6.6569400, 106.5011100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67719, 'Cipedes', 'Cipedes', 'Cipedes,Tjipedes', -7.0585000, 108.5295000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67720, 'Cipatujah', 'Cipatujah', 'Chipatujah,Cipatujah,Tjipatoedja,Tjipatudja,Tjipatudjah', -7.7330000, 108.0204000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67721, 'Cipatat', 'Cipatat', 'Cipata,Cipatat,Tjipata', -6.6223000, 106.4955000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67722, 'Cipasung', 'Cipasung', 'Cipasung,Tjipasoeng,Tjipasung', -7.0505000, 108.1877000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67723, 'Cipari', 'Cipari', 'Cipari,Tjipari', -7.4391000, 108.7635000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67724, 'Ciparay', 'Ciparay', 'Ciparay,Tjiparaj', -7.4249000, 108.4742000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67725, 'Ciporang', 'Ciporang', 'Ciparang,Ciporang,Tjiparang,Tjiporang', -7.0101000, 108.5682000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67726, 'Cipanas', 'Cipanas', 'Cipanas,Tjipanas', -6.5495000, 106.3985000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67727, 'Cipaku', 'Cipaku', 'Cipaku,Tjipakoe,Tjipaku', -7.2218000, 108.3325000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67728, 'Cipaas', 'Cipaas', 'Cipaas,Tjipaas', -6.7033000, 105.9045000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67729, 'Ciomas', 'Ciomas', 'Chiomas,Ciomas,Tjiomas', -6.2173000, 106.0440000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67730, 'Cinta', 'Cinta', 'Cinta,Tjinta', -7.1564000, 108.0558000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67731, 'Cimuncang', 'Cimuncang', 'Cimuncang,Tjimuntjang', -7.0548000, 108.2803000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67732, 'Cimoyan', 'Cimoyan', 'Cimoyan,Tjimojan', -6.4707000, 105.8875000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67733, 'Cimerak', 'Cimerak', 'Cimerak,Tjimerak', -7.7507000, 108.4399000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67734, 'Cimaragas', 'Cimaragas', 'Cimaragas,Tjimaragas', -7.3720000, 108.4629000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67735, 'Cimara', 'Cimara', 'Cimara,Tjimara', -7.0856000, 108.7124000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67736, 'Cimanuk', 'Cimanuk', 'Cimanuk,Tjimanuk', -6.3440000, 106.0289000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67737, 'Cimanggu', 'Cimanggu', 'Cimanggu,Tjimanggoe,Tjimanggu', -7.3524000, 108.8402000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67738, 'Cimanggu', 'Cimanggu', 'Cimanggu,Tjimanggoe,Tjimanggu', -7.3148000, 107.1089000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67739, 'Cimandiri', 'Cimandiri', 'Cimandiri,Tjimandiri', -6.8566000, 106.1713000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67740, 'Cimaja', 'Cimaja', 'Cimaja,Tjimadja', -6.9549000, 106.4851000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67741, 'Cimahi', 'Cimahi', 'Chimahi,Cimahi,Cimahi kutha,Kota Cimahi,Tjimahi,Tjimaki', -6.8722200, 107.5425000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67742, 'Cilopadang', 'Cilopadang', 'Cilopadang,Tjilopadang', -7.3044000, 108.7898000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67743, 'Cilentung', 'Cilentung', 'Cilentung,Cilontung,Tjilontung', -6.3274000, 105.9563000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67744, 'Cileunyi', 'Cileunyi', 'Cileunyi,Tjileunji,Tjileunji 2', -6.9388900, 107.7527800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67745, 'Cileungsir', 'Cileungsir', 'Cileungsi,Cileungsir,Tjileungsir', -6.3947200, 106.9591700, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67746, 'Cileuksa', 'Cileuksa', 'Cileuksa,Tjileuksa', -6.6032000, 106.4448000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67747, 'Cilegong', 'Cilegong', 'Cilegong,Cilegongastai,Tjilegong,Tjilegongastai', -6.5485000, 105.9988000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67748, 'Cilebak', 'Cilebak', 'Cilebak,Tjilebak', -7.1364000, 108.5835000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67749, 'Cilawu', 'Cilawu', 'Cilawu,Tjilawoe,Tjilawu', -7.2779000, 107.9203000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67750, 'Cilandak', 'Cilandak', 'Cilandak,Tjilandak', -6.9987000, 106.7177500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67751, 'Cilampuyang', 'Cilampuyang', 'Cilampuyang,Tjilampoejang,Tjilampujang', -7.0131000, 108.0795000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67752, 'Ciladaeun', 'Ciladaeun', 'Ciladaeun,Ciladaheun,Tjiladaheun', -6.6233000, 106.4048000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67753, 'Cilacap', 'Cilacap', 'CXP,Chilachap,Cilacap,Tjilatjap', -7.7263900, 109.0094400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67754, 'Cikuya', 'Cikuya', 'Cikuya,Tjikoeja,Tjikuja', -7.6288000, 108.3752000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67755, 'Cikoneng', 'Cikoneng', 'Cikoneng,Tjikoneng,Tjikoneng 1', -7.3118000, 108.2710000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67756, 'Kampungdesa', 'Kampungdesa', 'Cikondang,Kampungdesa,Tjikondang', -7.5718700, 107.8600100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67757, 'Cikijing', 'Cikijing', 'Cikijing,Tjikidjing', -7.7221000, 108.3604000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67758, 'Cikijing', 'Cikijing', 'Cikijing,Tjikidjing,Tjiladjing', -7.0163000, 108.3665000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67759, 'Cikeusikdesa', 'Cikeusikdesa', 'Cikeusik,Cikeusikdesa,Tjikeusik', -6.7540000, 105.9539000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67760, 'Cikeusik', 'Cikeusik', 'Cikeusik,Tjikeusik', -6.7282000, 105.8720000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67761, 'Cikembulan', 'Cikembulan', 'Cikembulan,Tjikemboelan,Tjikembulan', -7.0841000, 107.9132000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67762, 'Cikelet', 'Cikelet', 'Cikelet,Tjikelet,Tjikolet', -7.6117000, 107.6771000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67763, 'Cikayas', 'Cikayas', 'Cikayas,Tjikajas', -6.5924400, 105.8802800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67764, 'Cikawung', 'Cikawung', 'Cikawung,Tjikawung', -7.5981000, 108.0169000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67765, 'Cikawung', 'Cikawung', 'Cikaung,Cikawung,Tjikaung', -6.7535000, 106.1689000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67766, 'Cikatomas', 'Cikatomas', 'Chikatomas,Cikatomas,Tjikalomas,Tjikatomas', -7.6209000, 108.2583000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67767, 'Cikate', 'Cikate', 'Cikate,Tjikate', -6.7289000, 106.2163000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67768, 'Cikaso', 'Cikaso', 'Cikaso,Tjikaso', -7.4996000, 108.5824000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67769, 'Cikaras', 'Cikaras', 'Cikaras,Tjikaras', -6.7831000, 106.1481000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67770, 'Cikarang', 'Cikarang', 'Cikarang,Tjikarang', -7.4263000, 107.4533000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67771, 'Cikarang', 'Cikarang', 'Cikarang,Tjikarang', -6.7165000, 105.9201000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67772, 'Cikarang', 'Cikarang', 'Chikarang,Cikarang,Tjikarang', -6.2611100, 107.1527800, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67773, 'Cikandang', 'Cikandang', 'Cikandang,Cikanjang,Tjikadjang,Tjikandjang', -6.9966000, 108.6335000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67774, 'Cikandang', 'Cikandang', 'Cikandang,Tjikandang', -7.3689000, 107.7560000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67775, 'Cikamurang', 'Cikamurang', 'Cikamurang,Tjikamoerang,Tjikamurang', -7.4848000, 107.2429000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67776, 'Cikampek', 'Cikampek', 'Chikampek,Cikampek,Tjikampek', -6.4197200, 107.4558300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67777, 'Cikalong', 'Cikalong', 'Chikalong,Cikalong,Tjikalong', -7.7623000, 108.1727000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67778, 'Cikalong', 'Cikalong', 'Cikalong,Tjikalong,Tjikolang Dua', -7.6487000, 108.5662000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67779, 'Cikalong', 'Cikalong', 'Cikalong,Tjikalong', -7.4599000, 108.0518000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67780, 'Cikajang', 'Cikajang', 'Chikajang,Cikajang,Tjikadjang', -7.3578000, 107.8086000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67781, 'Cikadu', 'Cikadu', 'Cikadu,Tjikadu', -6.7454000, 105.7007000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67782, 'Cikadongdong', 'Cikadongdong', 'Cikadongdong,Tjikadongdong,Tjikadongdong 1', -7.5501000, 108.1275000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67783, 'Cijulang', 'Cijulang', 'CJN,Chijulang,Cidjulang,Cijulang,Tjidjoelang,Tjidjulang', -7.7273000, 108.4733000, 'ID', '2016-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67784, 'Cijulang', 'Cijulang', 'Chijulang,Cijulang,Tjidjoelang,Tjidjulang', -7.2616000, 108.1972000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67785, 'Cijeungjing', 'Cijeungjing', 'Cijeungjing,Tjidjeundjing,Tjidjeungdjing', -7.3323000, 108.4145000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67786, 'Cijengkol', 'Cijengkol', 'Cijengkol,Tjidjengkol', -6.9099000, 106.3566000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67787, 'Cihuni Kaler', 'Cihuni Kaler', 'Cihuni,Cihuni Kaler,Tjihuni', -7.1661000, 107.9915000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67788, 'Cihonje', 'Cihonje', 'Cihonje,Tjihondje,Tjihondje 1', -7.1916000, 108.1873000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67789, 'Cihideung', 'Cihideung', 'Cihideung,Tjihideung', -7.3051000, 107.9259000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67790, 'Ciherang', 'Ciherang', 'Ciherang,Tjiherang', -6.3740000, 105.9491000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67791, 'Ciherang', 'Ciherang', 'Ciherang,Tjiherang', -6.1829000, 106.0599000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67792, 'Cihaurbeuti', 'Cihaurbeuti', 'Cihaurbeuti,Tjihaoerbeuti,Tjihaurbeuti', -7.2234000, 108.2011000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67793, 'Ciguha Tengah', 'Ciguha Tengah', 'Ciguha,Ciguha Tengah,Tjiguha', -7.1110000, 107.0554000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67794, 'Cigintung', 'Cigintung', 'Cigintung,Tjigintoeng Satu,Tjigintung', -7.2335000, 108.6976000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67795, 'Cigemlong', 'Cigemlong', 'Cigemblong,Cigemlong,Tjigemblong', -6.7227000, 106.1576000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67796, 'Cigaru', 'Cigaru', 'Cigaru,Tjigaru', -7.0988000, 106.5953000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67797, 'Cigalontang', 'Cigalontang', 'Cigalontang,Tjigalontang,Tjigalontjang', -7.3224000, 108.0052000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67798, 'Cigagade', 'Cigagade', 'Cigagad,Cigagade,Tjigagad,Tjigagade 1', -7.0428000, 107.9564000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67799, 'Cigadog Hilir', 'Cigadog Hilir', 'Cigadog,Cigadog Hilir,Tjigadog', -7.2139000, 108.0021000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67800, 'Cigaber', 'Cigaber', 'Cigaber,Tjigaber', -6.7999700, 106.1098300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67801, 'Ciemas', 'Ciemas', 'Ciemas,Tjiemas', -7.2333000, 106.5198000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67802, 'Cidima', 'Cidima', 'Cidima,Tjidima', -6.5930000, 106.0399000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67803, 'Cidadap', 'Cidadap', 'Cidadap,Tjidadap', -7.7721000, 108.1407000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67804, 'Cidadap', 'Cidadap', 'Cidadap,Djidadap,Tjidadap,Tjidadup,Warungsimpang', -7.0167000, 106.5661000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67805, 'Cicurug', 'Cicurug', 'Cicurug,Tjitjoeroeg,Tjitjurug', -6.7813900, 106.7825000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67806, 'Cicatang Satu', 'Cicatang Satu', 'Cicatang,Cicatang Satu,Citjatung,Tjitjatang', -6.8643300, 106.1069100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67807, 'Cicarucub', 'Cicarucub', 'Cicarucub,Cicarucup,Tjitjarutjup', -6.8227000, 106.3567000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67808, 'Cicapar', 'Cicapar', 'Cicapar,Tjitjapar', -7.5129000, 108.6485000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67809, 'Cilebang Satu', 'Cilebang Satu', 'Cicalebang,Cilebang Satu,Tjitjalebang', -6.6590200, 106.2896800, 'ID', '2013-06-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67810, 'Ciburial', 'Ciburial', 'Ciburial,Tjiburial', -6.7239000, 105.6665000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67811, 'Ciburang', 'Ciburang', 'Ciburang,Tjiboerang 2,Tjiburang', -7.3002000, 106.9973000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67812, 'Cibuntu', 'Cibuntu', 'Cibuntu,Tjiboentoe,Tjibuntu', -7.7474000, 108.2865000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67813, 'Cibungurgardu', 'Cibungurgardu', 'Cibungur,Cibungurgardu,Tjibungur', -6.4675000, 105.8147000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67814, 'Cibunar', 'Cibunar', 'Cibunar,Tjiboenar,Tjibunar', -7.2365000, 107.8877000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67815, 'Cibuluh', 'Cibuluh', 'Cibuluh,Tjibuluh', -7.3633000, 107.4567000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67816, 'Cibulan', 'Cibulan', 'Cibulan,Tjiboelan,Tjibulan', -7.0297000, 108.1922000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67817, 'Cibitung', 'Cibitung', 'Cibitung,Tjibitung', -7.1190000, 107.1309000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67818, 'Cibitungmasjid', 'Cibitungmasjid', 'Cibitung,Cibitungmasjid,Tjibitoeng,Tjibitung', -6.6161000, 105.8889000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67819, 'Cibinong Satu', 'Cibinong Satu', 'Cibinong,Cibinong Satu,Tjibinong,Tjibinong Satu,Tjibluong', -7.3228000, 107.1275000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67820, 'Cibinong', 'Cibinong', 'Chibinong,Chibinung,Cibinong,Sibinonge,Tjibinong,Сибинонге', -6.4816700, 106.8541700, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67821, 'Cibingbin', 'Cibingbin', 'Cibingbin,Tjibingbin', -7.0611000, 108.7619000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67822, 'Cibeuti', 'Cibeuti', 'Cibeuti,Tjibeuti', -7.3862000, 108.1889000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67823, 'Cibeurih', 'Cibeurih', 'Cibeurih,Tjibeurih', -6.5480000, 106.3288000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67824, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum', -7.3552000, 108.2693000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67825, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum', -7.0218000, 108.3031000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67826, 'Cibeureum Kidul', 'Cibeureum Kidul', 'Cibeureum,Cibeureum Kidul,Tjibeureum', -7.0504000, 108.7246000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67827, 'Cibenda', 'Cibenda', 'Bojong Chibenda,Cibenda,Tjibenda', -7.6806000, 108.5511000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67828, 'Cibeber', 'Cibeber', 'Cibeber,Tjibeber', -7.7086000, 108.1964000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67829, 'Cibatu', 'Cibatu', 'Cibatu,Tjibatoe,Tjibatu', -7.6327000, 108.2008000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67830, 'Cibaregbeg Dua', 'Cibaregbeg Dua', 'Cibaregbeg,Cibaregbeg Dua,Tjibaregbeg', -7.1600000, 106.8789000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67831, 'Cibanten', 'Cibanten', 'Cibanten,Tjibanten', -7.6941000, 108.4029000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67832, 'Cibalong', 'Cibalong', 'Cibalong,Paroeng,Parung,Tjibalong', -7.5148000, 108.1812000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67833, 'Cibaliung', 'Cibaliung', 'Cibaliung,Tjibalioeng,Tjibaliung', -6.7050000, 105.7160000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67834, 'Ciawitali', 'Ciawitali', 'Ciawitali,Tjiawitali', -7.4488000, 108.6550000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67835, 'Ciaro', 'Ciaro', 'Ciaro,Tjiaro', -7.0384000, 107.9201000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67836, 'Ciapus', 'Ciapus', 'Ciapus,Tjiapus', -6.7461000, 106.0869000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67837, 'Cianjur', 'Cianjur', 'Chiandzhur,Chianjur,Cianjur,Kabupaten Cianjur,Kabupaten de Cianjur,Kabupatèn Cianjur,Kabupatén Cianjur,Tjandjoer,Tjiandjoer,Tjiandjur,chianjuri,ciyancur,zhan yu,Чианджур,சியாஞ்சூர்,ჩიანჯური,展玉', -6.8222200, 107.1394400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67838, 'Ciamis', 'Ciamis', 'Chiamis,Ciamis,Tjiamis', -7.3257000, 108.3534000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67839, 'Cermee', 'Cermee', 'Cerme,Cermee,Tjerme', -7.7772000, 114.0487000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67840, 'Cerenti', 'Cerenti', 'Cerenti,Tjerenti,Tjerinti', -0.5086000, 101.8689000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67841, 'Cepu', 'Cepu', 'CPF,Cepu,Chepu,Panolan,Tjepoe,Tjepu', -7.1475000, 111.5906000, 'ID', '2013-05-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67842, 'Ceper', 'Ceper', 'Ceper,Tjeper,Tjepper', -7.6741700, 110.6788900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67843, 'Cempaka', 'Cempaka', 'Cempaka,Cempoko,Tiempaka,Tjempaka,Tjempako', -3.7323500, 104.6675900, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67844, 'Caruban', 'Caruban', 'Caruban,Charuban,Tjaroeban,Tjaruban', -7.5447000, 111.6566000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67845, 'Carita', 'Carita', 'Carita,Tjarita', -6.3178000, 105.8382000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67846, 'Caringin', 'Caringin', 'Caringin,Tjaringin', -7.4546000, 107.5139000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67847, 'Caringin', 'Caringin', 'Caringin,Tjaringin', -6.9178000, 106.4004000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67848, 'Caringin', 'Caringin', 'Caringin,Caringin 2,Tjaringin', -6.7061100, 106.8213900, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67849, 'Caringin Lor', 'Caringin Lor', 'Caringin,Caringin Lor,Tjaringin', -6.3503000, 105.8272000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67850, 'Capar', 'Capar', 'Capar,Tjapar', -7.1192000, 108.7338000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67851, 'Cantilan', 'Cantilan', 'Cantilan,Tjantilan', -7.1045700, 108.4385100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67852, 'Cangkuang', 'Cangkuang', 'Cangkuang,Tjangkoeang,Tjangkuang', -7.1031000, 107.9120000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67853, 'Candipuro', 'Candipuro', 'Candipuro,Tjandipuro', -8.1884000, 113.0763000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67854, 'Campurdarat', 'Campurdarat', 'Campurdarat,Champurdarat,Tjampoerdarat,Tjampurdarat', -8.1652000, 111.8535000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67855, 'Campor', 'Campor', 'Campor,Tjampor', -6.9729000, 112.8851000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67856, 'Ciampea', 'Ciampea', 'Campea,Ciampea,Tjampea,Tjampea 1', -6.5547200, 106.7008300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67857, 'Campaka', 'Campaka', 'Campaka,Tjampaka', -7.0336000, 107.1323000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67858, 'Camming', 'Camming', 'Caming,Camming,Tjaming', -4.8118000, 120.0771000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67859, 'Calingcing Satu', 'Calingcing Satu', 'Calincing Satu,Calingcing,Calingcing Satu,Tjalingtjing,Tjalingtjing Satu', -7.2136000, 108.1552000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67860, 'Cakke', 'Cakke', 'Cakka,Cakke', -3.4101000, 119.7985000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67861, 'Buriwutung', 'Buriwutung', 'Boeroewoetoen,Buriwutung,Buruwutun', -8.1832000, 123.8088000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67862, 'Buraga', 'Buraga', 'Boeraga,Buraga', -8.4205000, 124.4871000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67863, 'Buol', 'Buol', 'Boeol,Buol,Bwool', 1.1584000, 121.4361000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67864, 'Buntok', 'Buntok', 'Boentok,Buntok', -1.7213900, 114.8397000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67865, 'Buniseuri', 'Buniseuri', 'Beuniseuri,Boeniseuri Satu,Buniseuri', -7.2425000, 108.3778000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67866, 'Bunigeulis', 'Bunigeulis', 'Boenigeulis,Bunigeulis', -7.0594000, 108.4337000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67867, 'Bungku', 'Bungku', 'Boengkoe,Bungku,Sakita,Tombuko', -2.5471000, 121.9720000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67868, 'Bungkal', 'Bungkal', 'Boengkal,Bungkal', -8.0079000, 111.4541000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67869, 'Bungbulang', 'Bungbulang', 'Boengboelang,Bungbulang', -7.4568000, 107.5991000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67870, 'Bunga Mas', 'Bunga Mas', 'Boengamas,Boengomas,Bunga Mas,Bungamas,Bungomas', -3.7011000, 103.3686000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67871, 'Bunder', 'Bunder', 'Bunder', -7.1867000, 113.5296700, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67872, 'Bulumanis Kidul', 'Bulumanis Kidul', 'Bulumanis,Bulumanis Kidul', -6.6128000, 111.0689000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67873, 'Bulukumba', 'Bulukumba', 'Boeloekoemba,Bulukamba,Bulukumba', -5.5500000, 120.1833300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67874, 'Bulu', 'Bulu', 'Boeloe,Boeloedjawa,Boeloedjowo,Bolloejowo,Bulu,Buludjowo,Bulujowo', -6.7706000, 111.7190000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67875, 'Bulu', 'Bulu', 'Boeloe,Bulu', -6.8587000, 111.4056000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67876, 'Bulakan', 'Bulakan', 'Bulakan', -6.6454000, 106.0329000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67877, 'Bulakamba', 'Bulakamba', 'Boelakamba,Bulakamba', -6.8748000, 108.9559000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67878, 'Bula', 'Bula', 'Boela,Bula', -3.1112000, 130.4954000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67879, 'Bukittinggi', 'Bukittinggi', 'Bukittinggi,Bukittingi,Fort de Kock,Fort de Rock,Kota Bukittinggi,Kutha Bukittinggi,bukitingi,wu ji ding yi,Букиттинги,ブキティンギ,武吉丁宜', -0.3090700, 100.3705500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67880, 'Bukitkemuning', 'Bukitkemuning', 'Bukitkemuning,Bukitkuning', -4.8596200, 104.5737300, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67881, 'Karangbugis', 'Karangbugis', 'Boegis,Bugis,Karangbugis', -8.4966000, 117.4219000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67882, 'Banjar Bugbug', 'Banjar Bugbug', 'Banjar Bugbug,Boegboeg,Bugbug', -8.4889000, 115.5935000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67883, 'Buduran', 'Buduran', 'Buduran', -7.4281000, 112.7234000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67884, 'Buaran', 'Buaran', 'Boearan,Boearan 1,Buaran', -7.0500000, 109.5500000, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67885, 'Bualu', 'Bualu', 'Boealoe,Bualu', -8.7960000, 115.2172000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67886, 'Brondong', 'Brondong', 'Berondong,Brondong', -6.8770000, 112.2915000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67887, 'Brebes', 'Brebes', 'Brebes', -6.8691000, 109.0378000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67888, 'Berbek', 'Berbek', 'Berbek,Brebek', -7.3463900, 112.7636100, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67889, 'Brakas', 'Brakas', 'Brakas', -7.1521000, 114.6143000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67890, 'Boyolangu', 'Boyolangu', 'Bojolangoe,Bojolangu,Boyolangu', -8.1181000, 111.8935000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67891, 'Boyolali', 'Boyolali', 'Bajalali,Bajalili,Bojolali,Boyolali', -7.5330600, 110.5958300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67892, 'Bosnik', 'Bosnik', 'Bosnek,Bosnik,Soriari', -1.1572000, 136.2283000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67893, 'Boroko', 'Boroko', 'Boroko', 0.9083000, 123.2679000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67894, 'Bontang', 'Bontang', 'BXT,Bontang,Kota Bontang', 0.1324000, 117.4854000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67895, 'Bunobogu', 'Bunobogu', 'Bonobogoe,Bonobogu,Bunobogu', 1.0407000, 121.6126000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67896, 'Bonjol', 'Bonjol', 'Bondjol,Bonjol', -0.0178500, 100.2274800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67897, 'Bonebone', 'Bonebone', 'Bone,Bone 2,Bonebae,Bonebone', -2.6005000, 120.5195000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67898, 'Bondowoso', 'Bondowoso', 'Bandawasa,Bandowoso,Bondawasa,Bondowoso', -7.9134600, 113.8214500, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67899, 'Bondokodi', 'Bondokodi', 'Bondokodi', -9.5943000, 118.9934000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67900, 'Bonang', 'Bonang', 'Boenang,Bonang', -6.6619000, 111.4666000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67901, 'Boleng', 'Boleng', 'Boleng,Boling', -8.3831000, 123.2954000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67902, 'Bolang', 'Bolang', 'Bolang', -6.7658000, 105.9928000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67903, 'Bolaang', 'Bolaang', 'BJG,Bolaang,Bolaang Mongondow,Bolaangmongondou,Bolang,Botaang', 0.9411000, 124.1556000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67904, 'Bolangitang', 'Bolangitang', 'Bolaangitam,Bolaangitang,Bolangitang,Bolaängitang', 0.9068000, 123.3067000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67905, 'Bola', 'Bola', 'Bola', -8.7419000, 122.2958000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67906, 'Bokong Timur', 'Bokong Timur', 'Bokong,Bokong Timur', -9.9727000, 124.0611000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67907, 'Bikondini', 'Bikondini', 'BUI,Bikondini,Bokondini', -3.6583600, 138.5746800, 'ID', '2013-12-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67908, 'Bokat', 'Bokat', 'Bokat', 1.0871000, 121.5050000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67909, 'Bojongmanik Girang', 'Bojongmanik Girang', 'Bodjongmanik,Bojongmanik,Bojongmanik Girang', -6.5843000, 106.1662000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67910, 'Bojongjengkol', 'Bojongjengkol', 'Bodjongdjenkol,Bojongjengkol,Bojongjenkol', -7.0929000, 106.7655000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67911, 'Bojonghaur', 'Bojonghaur', 'Bodjonghaoer,Bodjonghaur,Bojonghaur', -7.1274000, 106.7421000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67912, 'Bojonggenteng', 'Bojonggenteng', 'Bodjonggenteng,Bojonggenteng', -7.2883000, 106.6218000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67913, 'Ciawi', 'Ciawi', 'Bodjonggambir,Bojonggambir,Ciawi', -7.5117000, 107.9767000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67914, 'Bojong', 'Bojong', 'Bodjong,Bojong', -7.5963800, 107.7354500, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67915, 'Bojong', 'Bojong', 'Bodjong,Bojong', -7.5471300, 108.4944200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67916, 'Bojong', 'Bojong', 'Bodjong,Bodjong 2,Bojong', -7.3467000, 108.4316000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67917, 'Bojong', 'Bojong', 'Bodjong,Bojong', -6.1618000, 106.0899000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67918, 'Bojonegoro', 'Bojonegoro', 'Bodjanegara,Bodjonegoro,Bojonegoro', -7.1502000, 111.8817000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67919, 'Bojonegara', 'Bojonegara', 'Bodjanegara,Bodjonegara,Bojanegara,Bojonegara', -5.9700000, 106.0955000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67920, 'Bogorejo', 'Bogorejo', 'Bagaredja,Bogoredjo,Bogorejo', -6.9404000, 111.5186000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67921, 'Bogor', 'Bogor', 'Bogor,Buitenzorg,Kota Bogor,Kutha Bogor,bogoleu,bogori,bogoru,bwgwr,bwkwr,mao wu,Богор,بوكور,بوگور,ბოგორი,ボゴール,茂物,보고르', -6.5944400, 106.7891700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67922, 'Bobong', 'Bobong', 'Bobong', -1.9462500, 124.3839400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67923, 'Boawae', 'Boawae', 'Boawae,Boawai', -8.7639000, 121.1694000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67924, 'Boafeo', 'Boafeo', 'Boafeo', -8.6903000, 121.6260000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67925, 'Baluburlimbangan', 'Baluburlimbangan', 'Baloeboerjanbangan,Baloeboerlimbangan,Baluburlimbangan,Bloeboerlimbangan,Bluburlimbangan', -7.0357000, 107.9829000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67926, 'Blora', 'Blora', 'Blora', -6.9698000, 111.4186000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67927, 'Blitar', 'Blitar', 'Belitar,Blitar,Kota Blitar', -8.0983000, 112.1681000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67928, 'Baranusa', 'Baranusa', 'Baranusa,Blangmerang', -8.3622000, 124.0888000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67929, 'Bitung', 'Bitung', 'Bitoeng,Bitung,Kota Bitung', 1.4569700, 125.1895000, 'ID', '2015-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67930, 'Bitung', 'Bitung', 'Bitoeng,Bitsun,Bitung', 1.2074600, 124.5958000, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67931, 'Birayang', 'Birayang', 'Birajang,Birayang', -2.5328000, 115.4549000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67932, 'Binuang', 'Binuang', 'Binoeang,Binuang', -3.0707000, 115.1638000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67933, 'Bintuni', 'Bintuni', 'Bintuni,NTI,Steekool,Steenkool,Timbuni', -2.1084000, 133.5370000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67934, 'Bintuhan', 'Bintuhan', 'Bintoehan,Bintuan,Bintuhan', -4.7937100, 103.3483600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67935, 'Bingintelok', 'Bingintelok', 'Binginteloek,Bingintelok,Binginteluk', -2.6232000, 103.1173000, 'ID', '2013-02-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67936, 'Binangun', 'Binangun', 'Binangoen,Binangun', -8.2343000, 112.3360000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67937, 'Bima', 'Bima', 'BMU,Bim,Bima,Бим', -8.4600600, 118.7266700, 'ID', '2014-01-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67938, 'Bilungala', 'Bilungala', 'Biloengala,Biloengala-timoer,Bilongola,Bilungala', 0.3815000, 123.2135000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67939, 'Biha', 'Biha', 'Biha', -5.3296000, 104.0295000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67940, 'Biak', 'Biak', 'BIK,Biak,Biak-Stad', -1.1767000, 136.0820000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67941, 'Betaf', 'Betaf', 'Betaf', -2.1142200, 139.2528200, 'ID', '2017-01-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67942, 'Besuki Satu', 'Besuki Satu', 'Besoeki,Besuki,Besuki Satu', -8.2088000, 111.7755000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67943, 'Besuki', 'Besuki', 'Besoeki', -7.7337900, 113.6978500, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67944, 'Beo', 'Beo', 'Beo,Kampoeng Beo', 4.2286700, 126.7987200, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67945, 'Benteng', 'Benteng', 'Benteng,Salajar', -6.1184000, 120.4605000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67946, 'Bengkulu', 'Bengkulu', 'BKS,Bangkahulu,Bengkoeloe,Bengkulu,Benkoelen,Benkulen,Benkulu,Kota Bengkulu,Kutha Bengkulu,beungkullu,bngkwlw,bngkwlw  andwnzy,bnjkwlw,ming gu lu shi,Бенгкулу,Бенкулу,بنجكولو,بنگکولو,بنگکولو، اندونزی,明古魯市,븡쿨루', -3.8004400, 102.2655400, 'ID', '2010-08-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67947, 'Bengkayang', 'Bengkayang', 'Bengkajang,Bengkayang,Benkajang,Benkayan', 0.8319400, 109.4358900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67948, 'Bengkalis', 'Bengkalis', 'Bengkalis,SEQ', 1.4666700, 102.1333300, 'ID', '2017-03-23', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67949, 'Belopa', 'Belopa', 'Belopa', -3.3849000, 120.3676000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67950, 'Belimbing', 'Belimbing', 'Belimbing', -2.9823000, 115.3502000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67951, 'Blambangan Umpu', 'Blambangan Umpu', 'Belambanganumpu,Blambangan,Blambangan Umpu,Blambanganumpu,Blambangumpu', -4.5026300, 104.5192600, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67952, 'Mentarang', 'Mentarang', 'Belalau,Mentarang', 3.6062600, 116.1678600, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67953, 'Belakangpadang', 'Belakangpadang', 'Belakangpadang,Belakangpandang', 1.1496400, 103.8916400, 'ID', '2015-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67954, 'Bekasi', 'Bekasi', 'Bekasi,Bekasis,Gorad Bekasi,Kota Bekasi,Kutha Bekasi,beukasi,bkasy,bukashi,bykasy,wu jia si,Бекаси,Горад Бекасі,בקאסי,بيكاسي,بکاسی,ბეკასი,ᎠᎴᏂ,ブカシ,勿加泗,브카시', -6.2349000, 106.9896000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67955, 'Bejubang Dua', 'Bejubang Dua', 'Badjoebang,Badjubang,Bedjoebang,Bedjubang,Bejubang,Bejubang 2,Bejubang Dua', -1.7923000, 103.3167000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67956, 'Bebandem', 'Bebandem', 'Bebandem', -8.4403000, 115.5602000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67957, 'Bayunglincir', 'Bayunglincir', 'Bajoenglentjir,Bajoenglintiir,Bajunglentjir,Bajunglintjir,Bayunglencir,Bayunglinchir,Bayunglincir', -2.0549000, 103.6834000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67958, 'Bayongbong', 'Bayongbong', 'Bajongbong,Bayongbong,Bayungbung', -7.2716000, 107.8197000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67959, 'Bayan', 'Bayan', 'Bajan,Bayan', -8.2689000, 116.4255000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67960, 'Bayah', 'Bayah', 'Bajah,Bayah', -6.9277000, 106.2547000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67961, 'Batusangkar', 'Batusangkar', 'Batusangkar,Fort Van Der Capellen', -0.4606000, 100.6107000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67962, 'Baturotok', 'Baturotok', 'Batoe Rottok,Batoerotok,Baturotok', -8.6651000, 117.1460000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67963, 'Baturaja', 'Baturaja', 'Batoeradja,Batoerradja,Batu Radia,Baturadja,Baturaja', -4.1289100, 104.1669500, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67964, 'Baturaden', 'Baturaden', 'Baturaden,Baturraden', -7.3000000, 109.2166700, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67965, 'Batuputih', 'Batuputih', 'Batoepoetih,Batuputih', -6.9161000, 113.9177000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67966, 'Batu Panjang', 'Batu Panjang', 'Batoepandjang,Batu Panjang,Batupandjang', 1.7120600, 101.5142700, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67967, 'Batumandi', 'Batumandi', 'Batoemandi,Batumandi', -2.4218000, 115.4409000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67968, 'Batumadeg Kaja', 'Batumadeg Kaja', 'Batoemadeg,Batumadeg,Batumadeg Kaja,Batumandeg Kaja', -8.7465000, 115.5069000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67969, 'Batulicin', 'Batulicin', 'Batoelitjin,Batulichin,Batulicin,Batulijin,Batulitjin', -3.4202200, 116.0061100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67970, 'Batulawang', 'Batulawang', 'Batoelawang,Batulawang', -7.3672000, 107.1502000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67971, 'Batudulang', 'Batudulang', 'Batoedoelang,Batudulang', -8.5873000, 117.2809000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67972, 'Batubantar', 'Batubantar', 'Batoebantar,Batubantar', -6.3501000, 106.0444000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67973, 'Batu', 'Batu', 'Batoe,Batu,Batyj,Kota Batu,Sisir,Батый', -7.8700000, 112.5283300, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67974, 'Batibati', 'Batibati', 'Batibati', -3.6184000, 114.7166000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67975, 'Batangan', 'Batangan', 'Batangan,Batoesari,Batusari', -6.7094000, 111.2295000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67976, 'Batauga', 'Batauga', 'Batanga,Bataoega,Batauga', -5.5882000, 122.5964000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67977, 'Batang', 'Batang', 'Batang', -6.4846000, 110.7083000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67978, 'Baso', 'Baso', 'Baso', -0.2806700, 100.4536200, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67979, 'Baserah', 'Baserah', 'Baserah,Baseroh', -0.4462000, 101.7436000, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67980, 'Barusatu', 'Barusatu', 'Barus,Barusatu', -6.3207000, 105.9460000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67981, 'Barru', 'Barru', 'Barroe,Barru', -4.4120000, 119.6180000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67982, 'Bareng', 'Bareng', 'Bareng,Baringwala', -8.1731000, 123.7744000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67983, 'Bari', 'Bari', 'Bari,Berit', -8.3518000, 120.1822000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67984, 'Barengkok Hilir', 'Barengkok Hilir', 'Barengkok,Barengkok Hilir', -6.7663000, 105.9234000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67985, 'Baratan', 'Baratan', 'Baratan', -8.1348000, 113.7304000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67986, 'Barapas', 'Barapas', 'Barapas,Barapasi,Barapassi,Kamar Sano', -2.1990000, 137.0013000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67987, 'Barabai', 'Barabai', '', -2.5833300, 115.3833300, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67988, 'Bapoh', 'Bapoh', 'Bapoh', -6.7098000, 111.0558000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67989, 'Banyuwangi', 'Banyuwangi', 'Banjoewangi,Banjuwangi,Banyuwangi', -8.2325000, 114.3575500, 'ID', '2011-09-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67990, 'Banyuresmi', 'Banyuresmi', 'Banjoeresmi,Banjuresmi,Banyuresmi', -7.1605000, 107.9517000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67991, 'Banyumas', 'Banyumas', 'Banjoemas,Banjumas,Banyumas', -7.5141700, 109.2941700, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67992, 'Banyuates', 'Banyuates', 'Banjoeates,Banjuates,Banyuates', -6.8967000, 113.1554000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67993, 'Bantur', 'Bantur', 'Bantoer,Bantur', -8.3140000, 112.5807000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67994, 'Bantul', 'Bantul', 'Bantoel,Bantul', -7.8880600, 110.3288900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67995, 'Bantarpanjang', 'Bantarpanjang', 'Bantarpandjang,Bantarpanjang', -7.0061000, 108.7663000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67996, 'Bantardawa', 'Bantardawa', 'Bantardawa', -7.4381000, 108.6123000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67997, 'Bantar', 'Bantar', 'Bantar', -7.3231000, 108.1897000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67998, 'Bantaeng', 'Bantaeng', 'Bantaeng,Bonthain', -5.5475000, 119.9509000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(67999, 'Bantal', 'Bantal', 'Banta,Bantal', -7.7907000, 114.2308000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68000, 'Banjarwaru', 'Banjarwaru', 'Badjarwaroe,Bandjarwaru,Banjarwaru', -7.7778000, 108.3815000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68001, 'Banjarwangi', 'Banjarwangi', 'Bandjarwang,Bandjarwangi,Banjarwangi', -7.4398000, 107.9026000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68002, 'Banjarsari', 'Banjarsari', 'Bandjarsari,Banjar,Banjarsari', -7.4819000, 108.5998000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68003, 'Banjarejo', 'Banjarejo', 'Bandjarredja,Bandjarredjo,Banjarejo,Banjarrejo', -7.0344000, 111.3441000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68004, 'Banjarnegara', 'Banjarnegara', 'Bandjarnegal,Bandjarnegara,Bandjoenagara,Banjarnegara,Bondjonegoro', -7.3961100, 109.6961100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68005, 'Banjarmasin', 'Banjarmasin', 'BDJ,Bandgermasin,Bandjarmasin,Bandjermasin,Bandjermassin,Banjarmasin,Banjermasin,Banyermasin', -3.3198700, 114.5907500, 'ID', '2014-08-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68006, 'Banjarangsana', 'Banjarangsana', 'Bandjarangsana,Banjarangsana', -7.1339000, 108.2407000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68007, 'Banjaran', 'Banjaran', 'Bandjaran,Banjaran', -7.1905000, 108.7977000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68008, 'Banjaran', 'Banjaran', 'Bandjaran,Banjaran', -7.0452800, 107.5877800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68009, 'Banjar', 'Banjar', 'Bandjar,Banjar', -8.1900000, 114.9675000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68010, 'Banjar', 'Banjar', 'Bandar,Bandjar,Banjar', -7.3688000, 108.5329000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68011, 'Banjar', 'Banjar', 'Bandjar,Banjar', -7.1955000, 107.4313000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68012, 'Bangli', 'Bangli', 'Bangli', -8.4542000, 115.3545000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68013, 'Bangko', 'Bangko', 'Bangko', -2.0796000, 102.2573000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68014, 'Bangkinang', 'Bangkinang', 'Bangkinang', 0.3383300, 101.0236100, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68015, 'Bangkalan', 'Bangkalan', 'Bangkalan,Pangkalan', -7.0455000, 112.7351000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68016, 'Bangilan', 'Bangilan', 'Bangilan', -6.9700000, 111.7141000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68017, 'Bangil', 'Bangil', '', -7.5993900, 112.8186000, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68018, 'Banggai', 'Banggai', 'Banggai,Luwuk', -1.5887000, 123.4992000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68019, 'Bangelan', 'Bangelan', 'Bangelan', -8.1019000, 112.4981000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68020, 'Bandung', 'Bandung', 'Bandoeng,Bandung,Бандунг', -8.1676000, 111.7844000, 'ID', '2012-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68021, 'Bandung', 'Bandung', 'BDO,Bandoeng,Banduna,Bandung,Bandungas,Bandungo,Bantoun''nk,Gorad Bandung,Kota Bandung,Kuta Bandung,Kutha Bandhung,ban dung,bandon,bandung,bandungi,bandwng,bandwnj,bndwng,pantun,wan long,Μπαντούνγκ,Бандунг,Бандуң,Горад Бандунг,Բանդունգ,באנדונג,باندونج,باندونگ,بندونگ,بنڈونگ,பண்டுங்,บันดุง,ဘန်ဒေါင်းမြို့,ბანდუნგი,バンドン,万隆,萬隆,반둥', -6.9222200, 107.6069400, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68022, 'Banding Agung', 'Banding Agung', 'Banding Agung,Bandingagung,Dasarbandingagung,Pasarbandingagoeng,Pasarbandingagung', -4.8094700, 103.9244300, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68023, 'Elat', 'Elat', 'Banda Elat,Bandan Elat,Elat,Ellat', -5.6578000, 132.9709000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68024, 'Bancar', 'Bancar', 'Bancar,Banchar,Bantjar,Bantjariedok,Bantjariëdok,Bantjarledok,Bantjarlĕdok', -6.7827000, 111.7808000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68025, 'Bambanglipuro', 'Bambanglipuro', '', -7.9500000, 110.2833300, 'ID', '2013-10-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68026, 'Bama', 'Bama', 'Bama', -8.3761000, 122.8808000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68027, 'Balung', 'Balung', 'Baloeng,Baloeng-lor,Balung,Balung-lor', -8.2727000, 113.5388000, 'ID', '2012-02-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68028, 'Balung', 'Balung', 'Baloeng', -7.7333300, 113.9166700, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68029, 'Baluk', 'Baluk', 'Baloek,Baluk', -8.7426000, 122.3044000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68030, 'Balong', 'Balong', 'Balong', -6.8381000, 111.1714000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68031, 'Balokang', 'Balokang', 'Balokang', -7.3665000, 108.4852000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68032, 'Balikpapan', 'Balikpapan', 'BPN,Balikpapan,Balikpapanas,Kota Balikpapan,Kutha Balikpapan,ba li ba ban,ba lik pa pan,balligpapan,balyk‌papan,barikupapan,Баликпапан,بالیک‌پاپان,บาลิก์ปาปัน,ဘာလစ်ပါပန်မြို့,ბალიკპაპანი,バリクパパン,巴厘巴板,발릭파판', -1.2675300, 116.8288700, 'ID', '2010-01-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68033, 'Balegede', 'Balegede', 'Balegede', -7.2639000, 107.3569000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68034, 'Balearjo', 'Balearjo', 'Baleardjo,Balearjo', -8.1956000, 112.5748000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68035, 'Balauring', 'Balauring', 'Balaoerin,Balaoerjn,Balaurin,Balauring,Baloerin,Balurin', -8.2336000, 123.7060000, 'ID', '2012-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68036, 'Balapulang', 'Balapulang', 'Balapoelang,Balapulang', -7.0500000, 109.0833300, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68037, 'Balaipungut', 'Balaipungut', 'Balaipoengoet,Balaipungut', 1.0594900, 101.2905400, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68038, 'Balaiberkuak', 'Balaiberkuak', 'Balaiberkoewak,Balaiberkuak,Balaiberkuwak', -0.5260900, 110.3663700, 'ID', '2014-04-30', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68039, 'Bagorejo', 'Bagorejo', 'Bagorejo,Bakuredjo,Bakurejo', -8.3960000, 114.3045000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68040, 'Bakung', 'Bakung', 'Bakoeng Satu,Bakung', -7.3524000, 108.6761000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68041, 'Baki', 'Baki', '', -7.6127800, 110.7838900, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68042, 'Bakalan', 'Bakalan', 'Bakalan,Bakalan Satu,Bangelan', -8.1096000, 112.6596000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68043, 'Bajo', 'Bajo', 'Badjo,Bajo', -3.3788000, 120.3102000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68044, 'Bajawa', 'Bajawa', 'BJW,Badjava,Badjawa,Bajawa', -8.7848000, 120.9744000, 'ID', '2013-05-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68045, 'Bagansiapiapi', 'Bagansiapiapi', 'Bagansiapiapi,Bangan-siapiapi', 2.1566800, 100.8076300, 'ID', '2014-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68046, 'Baekrajan', 'Baekrajan', 'Bae,Baekrajan,Beh,Tjendono,Бэ', -6.7674000, 110.8541000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68047, 'Badur', 'Badur', 'Badur', -6.3805000, 105.8474000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68048, 'Bade', 'Bade', 'Bade,Badi,Badie', -7.1666700, 139.5833300, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68049, 'Labuhanbadas', 'Labuhanbadas', 'Badas,Labuhanbadas', -8.4637000, 117.3681000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68050, 'Babo', 'Babo', 'BXB,Babo,Kampoeng Babo', -2.5383000, 133.4199000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68051, 'Babirik', 'Babirik', 'Babirik', -2.5409000, 115.1588000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68052, 'Babat', 'Babat', 'Babad,Babat,Бабат', -7.1128200, 112.1635400, 'ID', '2010-01-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68053, 'Babat', 'Babat', 'Babat', -2.7381000, 103.6401000, 'ID', '2013-04-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68054, 'Babana', 'Babana', 'Babana', -2.0779000, 119.1986000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68055, 'Babakanloa', 'Babakanloa', 'Babakanloa', -7.1609000, 107.9968000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68056, 'Babakan', 'Babakan', 'Babakan', -7.2820000, 107.2224000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68057, 'Ayamaru', 'Ayamaru', 'Ajamaroe,Ajamaru,Ayamaru', -1.2744800, 132.1933400, 'ID', '2017-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68058, 'Awipari Tengah', 'Awipari Tengah', 'Awipari,Awipari Tengah', -7.3511000, 108.2719000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68059, 'Awiluar', 'Awiluar', 'Awiloear Dua,Awiluar', -7.1554000, 108.3377000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68060, 'Aitinyo', 'Aitinyo', 'Aitinjo,Aitinyo,Atinjoe,Atinju,Atinyu', -1.3119000, 132.3447000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68061, 'Atap', 'Atap', 'Atap', 3.8571400, 117.0465400, 'ID', '2013-09-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68062, 'Atambua', 'Atambua', 'ABU,Atamboea,Atamboewa,Atambua,Атамбуа', -9.1061100, 124.8925000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68063, 'Astanajapura', 'Astanajapura', 'Astanadjapura,Astanajapura', -6.8017000, 108.6311000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68064, 'Asera', 'Asera', 'Asera', -3.4746000, 122.0669000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68065, 'Asembagus', 'Asembagus', 'Asembagoes,Asembagus', -7.7507000, 114.2101000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68066, 'Arosbaya', 'Arosbaya', 'Aroebaja-barat,Arosbaja,Arosbaja-Darat,Arosbaja-barat,Arosbaya', -6.9442000, 112.8390000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68067, 'Armopa', 'Armopa', 'Armopa', -2.3409000, 139.6335000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68068, 'Arjawinangun', 'Arjawinangun', 'Ardjawinangoen,Ardjawinangoen-Koelan,Ardjawinangun,Arjawinangun', -6.6452800, 108.4102800, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68069, 'Arjasa', 'Arjasa', 'Ardjasa,Arjasa', -6.8596000, 115.2852000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68070, 'Argamakmur', 'Argamakmur', 'Argamakmur,Argamamur', -3.4232000, 102.1891000, 'ID', '2013-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68071, 'Ansus', 'Ansus', 'Ansas,Ansoes,Ansus', -1.7256000, 135.8115000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68072, 'Ankola', 'Ankola', 'Angkola,Ankola', -7.3071000, 107.1272000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68073, 'Anggana', 'Anggana', 'Anggana', -0.5705000, 117.2844000, 'ID', '2013-11-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68074, 'Andoolo', 'Andoolo', 'Andoolo', -4.3273000, 122.2522000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68075, 'Amuntai', 'Amuntai', 'Amoentai', -2.4177300, 115.2494100, 'ID', '2007-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68076, 'Ampana', 'Ampana', 'Ampana', -0.8692000, 121.5747000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68077, 'Ambuten', 'Ambuten', 'Amboenten,Amboenten-timoer,Ambunten,Ambuntentimur,Ambuten', -6.8885000, 113.7392000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68078, 'Ambon', 'Ambon', 'AMQ,Amboina,Ambon,Ambon City,Ambonas,Amboyna,Ambun,Gorad Ambon,Kota Ambon,Kutha Ambon,ambn,ambon,ambwn,ambwn  malwkw,an wen,anbon,Амбон,Горад Амбон,آمبن,آمبون,أمبون,امبون، مالوکو,アンボン,安汶,암본', -3.6958300, 128.1833300, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68079, 'Banjar Ambengan', 'Banjar Ambengan', 'Ambengan,Banjar Ambengan', -8.1689000, 115.1193000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68080, 'Ambarawa', 'Ambarawa', 'Ambarava,Ambarawa', -7.2633300, 110.3975000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68081, 'Amahai', 'Amahai', 'AHI,Amahai,Amahei,Masohi', -3.3398400, 128.9197500, 'ID', '2013-05-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68082, 'Aluhaluh', 'Aluhaluh', 'Alualu,Aluhaluh', -3.4991000, 114.5443000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68083, 'Alasbuluh', 'Alasbuluh', 'Alasboeloeh,Alasbuluh', -8.0097000, 114.4068000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68084, 'Alahanpanjang', 'Alahanpanjang', 'Alahanpandgan,Alahanpandjang,Alahanpanjang', -1.0749100, 100.7935400, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68085, 'Alabio', 'Alabio', 'Alabio', -2.4542000, 115.2445000, 'ID', '2013-12-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68086, 'Banjar Yehsatang', 'Banjar Yehsatang', 'Airsatang,Banjar Yehsatang', -8.3932000, 114.8028000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68087, 'Airmolek', 'Airmolek', 'Aermolek,Airmolek', -0.3700100, 102.2922100, 'ID', '2013-07-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68088, 'Airmadidi', 'Airmadidi', 'Airmadidi,Airmodidi,Ajer Madidi,Ajermadidih,Ajĕrmadidih,Ayermadidi,Koemelemboeai,Koemĕlĕmboeai', 1.4280400, 124.9777400, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68089, 'Aimere', 'Aimere', 'Aemere,Aimere,Wai Sai', -8.8431000, 120.8579000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68090, 'Agats', 'Agats', 'Agats,Agatz', -5.5450500, 138.1352200, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68091, 'Airbuaya', 'Airbuaya', 'Aerboeaja,Aerbuaja,Aerbuaya,Airbuaya,Wa Oebo,Wa Oebó,Waoebo,Waoebó', -3.1030000, 126.4207000, 'ID', '2014-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68092, 'Aenganyar', 'Aenganyar', 'Aenganjar,Aenganyar,Tandjoeng,Tandjung', -7.1905000, 113.8969000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68093, 'Adiwerna', 'Adiwerna', 'Adiwerna,Adiwerno', -6.9375000, 109.1325000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68094, 'Adipala', 'Adipala', 'Adipala,Adipolo', -7.6597200, 109.1500000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68095, 'Cipatujah Selatan', 'Cipatujah Selatan', 'Cipatujah,Cipatujah Selatan', -7.7433000, 108.0173000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68096, 'Lewolere', 'Lewolere', 'Lewaleri,Lewolere', -8.3480000, 122.9598000, 'ID', '2012-12-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68097, 'Atawutung', 'Atawutung', 'Atawatu,Atawutung', -8.2432600, 123.4947800, 'ID', '2012-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68098, 'Leramatang', 'Leramatang', 'Leramatang,Waienga,Waihinga', -8.3647000, 123.5718000, 'ID', '2012-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68099, 'Riangderi', 'Riangderi', 'Deri,Riangderi', -8.3628000, 123.3026000, 'ID', '2012-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68100, 'Lupak', 'Lupak', 'Lupak', -3.3823000, 114.2680000, 'ID', '2013-12-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68101, 'Tabunganen', 'Tabunganen', 'Tabunganen,Tambunanim', -3.4103000, 114.4829000, 'ID', '2013-12-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68102, 'Belawang', 'Belawang', 'Belawan,Belawang', -3.0715000, 114.6604000, 'ID', '2013-12-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68103, 'Totok', 'Totok', 'Totok,Totoka', -9.4828000, 119.3060000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68104, 'Belanting', 'Belanting', 'Belanting', -8.3053000, 116.6275000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68105, 'Penyaring Bawah', 'Penyaring Bawah', 'Penyaring Bawah,Penyaringan', -8.4701000, 117.4663000, 'ID', '2013-01-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68106, 'Obelobel', 'Obelobel', 'Labuhanburung,Obelobel', -8.2654000, 116.5491000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68107, 'Tulehu', 'Tulehu', 'Toelehoe,Tulehu', -3.5880300, 128.3272800, 'ID', '2014-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68108, 'Kowo', 'Kowo', 'Koroah,Kowo', -8.5352000, 119.0061000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68109, 'Segorotambak', 'Segorotambak', 'Segorotambak', -7.3666700, 112.8075000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68110, 'Tambakoso', 'Tambakoso', 'Tambakoso', -7.3460000, 112.8039000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68111, 'Medokanayu', 'Medokanayu', 'Medokanaju,Medokanayu', -7.3256000, 112.7988000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68112, 'Wonorejo', 'Wonorejo', 'Wonoredjo,Wonorejo', -7.3113800, 112.7968100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68113, 'Pocokan Satu', 'Pocokan Satu', 'Pocogan,Pocokan Satu', -6.9738000, 112.8045000, 'ID', '2012-09-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68114, 'Lancang', 'Lancang', 'Lancang', -6.9525000, 112.8281000, 'ID', '2012-09-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68115, 'Ngembo', 'Ngembo', 'Ngembo,Ngembuh', -6.9087000, 112.5022000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68116, 'Saseel', 'Saseel', 'Saseel,Seseel,Sesiil', -7.0912000, 115.7656000, 'ID', '2012-11-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68117, 'Meral', 'Meral', 'Mera,Meral,Pameral,Pemeral', 0.9948700, 103.3936500, 'ID', '2015-08-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68118, 'Ploso', 'Ploso', 'Ploso,Plosobegem', -7.2522200, 112.7633300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68119, 'Gununganyar', 'Gununganyar', 'Gununganjar,Gununganyar', -7.3409000, 112.7821000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68120, 'Panjangjiwo', 'Panjangjiwo', 'Pandjangdjiwo,Panjangjiwo', -7.3129000, 112.7641000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68121, 'Semampir', 'Semampir', 'Medokansemampir,Semampir', -7.3082000, 112.7802000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68122, 'Wadungasri', 'Wadungasri', 'Wadungasri,Wadungsari', -7.3451000, 112.7683000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68123, 'Wedoro', 'Wedoro', 'Wedoro', -7.3511100, 112.7513900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68124, 'Dares', 'Dares', 'Dares', -7.3690000, 112.7624000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68125, 'Semampirbarat', 'Semampirbarat', 'Semampir,Semampirbarat', -7.3722200, 112.7727800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68126, 'Banjarkemuning', 'Banjarkemuning', 'Bandjarkemuningtambak,Banjarkemuning,Gesikgebang', -7.3867000, 112.8085000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68127, 'Tambaksumur', 'Tambaksumur', 'Tambaksumur', -7.3485000, 112.7729000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68128, 'Buncitan', 'Buncitan', 'Buncitan,Buntjitan', -7.3961000, 112.7813000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68129, 'Dukuhgisikcemandi', 'Dukuhgisikcemandi', 'Dukuhgisikcemandi,Gisiktjemandi', -7.3899000, 112.8066000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68130, 'Betun', 'Betun', 'Betun', -9.5672200, 124.9075000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68131, 'Nilulat', 'Nilulat', 'Nilujat,Nilulat', -9.5005000, 124.3294000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68132, 'Nunpo', 'Nunpo', 'Nunpo', -9.4853000, 124.3561000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68133, 'Basan', 'Basan', 'Basan', -9.4809000, 124.3737000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68134, 'Naisano Dua', 'Naisano Dua', 'Naisano 2,Naisano Dua,Nusa Dua,Нуса Дуа', -9.5980600, 123.7702800, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68135, 'Sasi', 'Sasi', 'Sasi', -9.4991700, 124.4927800, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68136, 'Cikotok', 'Cikotok', 'Cikotok', -6.8612000, 106.3067000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68137, 'Bangunrejo', 'Bangunrejo', 'Bangunrejo', -5.1403000, 105.0372000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68138, 'Punggur', 'Punggur', 'Punggur', -5.0414600, 105.2773400, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68139, 'Pekalongan', 'Pekalongan', 'Pekalongan', -5.0827700, 105.3588500, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68140, 'Batanghari', 'Batanghari', 'Batanghari', -5.1409500, 105.3752000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68141, 'Girsereng', 'Girsereng', 'Girsereng', -7.0066000, 114.0279000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68142, 'Sokarame', 'Sokarame', 'Sokarame,Sokarammepasisar', -7.0840000, 114.2856000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68143, 'Kropoh', 'Kropoh', 'Kropoh,Kropon', -7.1322000, 114.5521000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68144, 'Taman', 'Taman', 'Taman', -7.0748000, 114.0421000, 'ID', '2012-10-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68145, 'Glugur Krajan', 'Glugur Krajan', 'Glugur Krajan,Tandjunglugur', -7.6476000, 114.0461000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68146, 'Krajan Gebangan', 'Krajan Gebangan', 'Gebangan-wetan,Krajan,Krajan Gebangan', -7.6752000, 114.0644000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68147, 'Krajan Panji Kidul', 'Krajan Panji Kidul', 'Krajan,Krajan Panji Kidul,Pandji-kidul', -7.7094000, 114.0416000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68148, 'Bercak', 'Bercak', 'Bercak,Bertjak', -7.7761000, 114.0615000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68149, 'Kedungdowo', 'Kedungdowo', 'Kedungdowo', -7.7515000, 114.1492000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68150, 'Selasaan', 'Selasaan', 'Selasaan,Sletreng', -7.7031000, 114.0998000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68151, 'Pariyaan', 'Pariyaan', 'Parejaan,Pariyaan', -7.7733000, 114.1749000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68152, 'Mojosari', 'Mojosari', 'Modjosari,Mojosari', -7.7631000, 114.1946000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68153, 'Awar-awar', 'Awar-awar', 'Awar-awar,Awararawar', -7.7602000, 114.2248000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68154, 'Langgen', 'Langgen', 'Langgen,Selanggen', -5.9832200, 106.3056100, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68155, 'Padalarang', 'Padalarang', '', -6.8377800, 107.4727800, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68156, 'Ciranjang-hilir', 'Ciranjang-hilir', 'Ciranjang-hilir,Tjirandjang-hilir', -6.8200000, 107.2572200, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68157, 'Ngamprah', 'Ngamprah', 'Ngamprah', -6.8036100, 107.2752800, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68158, 'Gunung Kendil', 'Gunung Kendil', 'Gunung Kendil,Gunung Kendit', -7.3316700, 110.4041700, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68159, 'Pepe', 'Pepe', 'Pepe', -7.4024000, 112.7692000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68160, 'Sawohan', 'Sawohan', 'Sawahan,Sawohan', -7.4272000, 112.7701000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68161, 'Damarsi', 'Damarsi', 'Damarsi', -7.4177000, 112.7598000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68162, 'Dukuh Tengah', 'Dukuh Tengah', 'Dukuh Tengah', -7.4160000, 112.7538000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68163, 'Pandansari', 'Pandansari', 'Pandansari', -8.0074000, 112.5617000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68164, 'Balesari', 'Balesari', 'Balesari,Bateisari', -8.0329000, 112.5234000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68165, 'Wadung', 'Wadung', 'Wadung', -8.0454000, 112.5923000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68166, 'Tambaksari', 'Tambaksari', 'Tambaksari,Tambaksari 3,Tambaksari Tiga', -8.0545000, 112.5899000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68167, 'Gading', 'Gading', 'Gading', -8.1025000, 112.6352000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68168, 'Glanggang', 'Glanggang', 'Glanggang', -8.0820000, 112.5991000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68169, 'Wonokerso', 'Wonokerso', 'Wonokenso,Wonokerso', -8.0765000, 112.6113000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68170, 'Golek', 'Golek', 'Golek', -8.0639000, 112.6122000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68171, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.0176000, 112.6191000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68172, 'Gedangan', 'Gedangan', 'Gedangan,Gendowangi', -8.0112000, 112.5849000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68173, 'Permanu', 'Permanu', 'Permanu', -8.0637000, 112.5785000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68174, 'Kranggan', 'Kranggan', 'Kranggan', -8.0803000, 112.5692000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68175, 'Mboto', 'Mboto', 'Boto,Mboto', -8.0908000, 112.5687000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68176, 'Ngasem', 'Ngasem', 'Ngasem', -8.0955000, 112.5588000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68177, 'Kesamben', 'Kesamben', 'Kasembon,Kesamben', -8.0637000, 112.5669000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68178, 'Tumpangrejo', 'Tumpangrejo', 'Tumpangredjo,Tumpangrejo', -8.0665000, 112.5151000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68179, 'Kasembon', 'Kasembon', 'Kasembon', -8.0878000, 112.6704000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68180, 'Krebet', 'Krebet', 'Krebet', -8.0944000, 112.6377000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68181, 'Tangkilsari', 'Tangkilsari', 'Tangkilsari,Tangkilsari 1,Tangkilsari Satu', -8.0601000, 112.6529000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68182, 'Tutut', 'Tutut', 'Totut,Tutut', -8.0390000, 112.6429000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68183, 'Kalisari', 'Kalisari', 'Kalisari', -8.0234000, 112.6483000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68184, 'Sumbersuko', 'Sumbersuko', 'Sumbersuko,Sumbersuko 2,Sumbersuko Dua', -8.0438000, 112.6675000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68185, 'Plaosan', 'Plaosan', 'Plaosan', -8.0916000, 112.5176000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68186, 'Palaan', 'Palaan', 'Palaan,Palahan', -8.1049000, 112.5478000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68187, 'Blobo', 'Blobo', 'Blobo', -8.1153000, 112.5970000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68188, 'Boro Utara', 'Boro Utara', 'Boro Utara,Sukarabardjo,Sukarabarjo', -8.1019000, 112.6086000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68189, 'Plandi', 'Plandi', '', -8.1101000, 112.5144000, 'ID', '2009-06-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68190, 'Tamiajeng', 'Tamiajeng', 'Pandanadjung,Pandanajung,Tamiajeng', -8.0074000, 112.7196000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68191, 'Kambingan', 'Kambingan', 'Kambingan,Kambingan 1,Kambingan Satu', -8.0120000, 112.7103000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68192, 'Bokor', 'Bokor', 'Bokor', -8.0047000, 112.7415000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68193, 'Glagahdowo', 'Glagahdowo', 'Glagahdowo,Pulungdowo', -8.0180000, 112.7355000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68194, 'Ngingit', 'Ngingit', 'Ngingit,Ngringit', -8.0293000, 112.7167000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68195, 'Keden', 'Keden', 'Kapugeran,Keden', -8.0347000, 112.7419000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68196, 'Pajaran', 'Pajaran', 'Padjaran,Pajaran', -8.0351000, 112.7174000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68197, 'Rambaan', 'Rambaan', 'Rambaan,Rambakan', -8.0463000, 112.6787000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68198, 'Ngebruk', 'Ngebruk', 'Ngebruk', -8.0467000, 112.7367000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68199, 'Argomulyo', 'Argomulyo', 'Argomulyo,Gunungronggo', -8.0498000, 112.7054000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68200, 'Kasri', 'Kasri', 'Kasri', -8.1091000, 112.6774000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68201, 'Pringu', 'Pringu', 'Pringo,Pringu', -8.0951000, 112.6843000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68202, 'Kidangbang', 'Kidangbang', 'Kidangbang,Kioangbang', -8.0954000, 112.7048000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68203, 'Sukoanyar', 'Sukoanyar', 'Sukoanjar,Sukoanyar', -8.0979000, 112.7161000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68204, 'Bureng', 'Bureng', 'Bureng', -8.1195000, 112.6168000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68205, 'Ngadilangkung', 'Ngadilangkung', 'Ngadilangkung,Ngodilangkung', -8.1058000, 112.5757000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68206, 'Ngantru', 'Ngantru', 'Ngantru', -8.1178000, 112.5677000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68207, 'Putukrejo', 'Putukrejo', 'Putukredjo,Putukrejo', -8.1261200, 112.6326300, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68208, 'Talangagung', 'Talangagung', 'Talangagung', -8.1254000, 112.5540000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68209, 'Jatikerto', 'Jatikerto', 'Djatikerto,Jatikerto', -8.1369000, 112.5381000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68210, 'Penarukan', 'Penarukan', 'Penarukan', -8.1354000, 112.5791000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68211, 'Ketawang', 'Ketawang', 'Ketawang', -8.1411100, 112.6435500, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68212, 'Urek-urek', 'Urek-urek', '', -8.1415100, 112.6640900, 'ID', '2002-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68213, 'Ganjaran', 'Ganjaran', 'Gandjaran,Ganjaran', -8.1413000, 112.6148000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68214, 'Senggreng', 'Senggreng', 'Senggreng', -8.1623000, 112.5160000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68215, 'Panggungrejo', 'Panggungrejo', 'Panggungredjo,Panggungrejo', -8.1464000, 112.5610000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68216, 'Mangunrejo', 'Mangunrejo', 'Mangunredjo,Mangunrejo', -8.1552000, 112.5562000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68217, 'Tegalsari', 'Tegalsari', 'Tegalsari', -8.1647200, 112.5763900, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68218, 'Panggungrejo', 'Panggungrejo', 'Panggungredjo,Panggungrejo', -8.1455000, 112.6009000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68219, 'Karangsuko', 'Karangsuko', 'Karangsuko', -8.1666000, 112.5992000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68220, 'Pagedangan', 'Pagedangan', 'Pagedangan,Pagedangan 1,Pagedangan Satu', -8.1592700, 112.7152900, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68221, 'Jambangan', 'Jambangan', 'Djambangah,Jambangah,Jambangan', -8.1622500, 112.7382100, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68222, 'Jeru', 'Jeru', 'Djeru,Jeru', -8.1615100, 112.6755000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68223, 'Sanankerto', 'Sanankerto', 'Sanankerto', -8.1505100, 112.7459400, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68224, 'Sananrejo', 'Sananrejo', 'Sananrejo,Sanatedjo,Sanatejo', -8.1489800, 112.7175800, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68225, 'Tumpukrenteng', 'Tumpukrenteng', 'Tumpukrenteng', -8.1305000, 112.6945000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68226, 'Sudimoro', 'Sudimoro', 'Sudimoro,Sudimoro 1,Sudimoro Satu', -8.1237000, 112.6731000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68227, 'Kedok', 'Kedok', 'Kedok', -8.1489100, 112.6948500, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68228, 'Talang Suko', 'Talang Suko', '', -8.1407500, 112.6868300, 'ID', '2002-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68229, 'Codo', 'Codo', 'Codo,Tjodo', -8.1286000, 112.7222000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68230, 'Blayu', 'Blayu', 'Blaju 1,Blayu,Blayu Satu', -8.1119000, 112.7347000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68231, 'Tanggung', 'Tanggung', 'Tanggung', -8.1711100, 112.6774800, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68232, 'Putat Kidul', 'Putat Kidul', 'Putat Kidul', -8.1743300, 112.6445300, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68233, 'Sawahan', 'Sawahan', 'Sawahan', -8.2124500, 112.6670400, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68234, 'Kemulan', 'Kemulan', 'Kemulan,Kemutan 1,Kemutan Satu', -8.2222600, 112.6571100, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68235, 'Sepanjang', 'Sepanjang', 'Sepandjang,Sepanjang', -8.1703600, 112.6627500, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68236, 'Kademangan', 'Kademangan', 'Kademangan', -8.2144000, 112.5989000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68237, 'Rejoyoso', 'Rejoyoso', 'Redjojoso,Rejoyoso', -8.2169000, 112.5781000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68238, 'Brongkal', 'Brongkal', 'Brongkal', -8.1806000, 112.5938000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68239, 'Kanigorokrajan', 'Kanigorokrajan', 'Kanigoro,Kanigorokrajan', -8.1854000, 112.5788000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68240, 'Sedayu', 'Sedayu', 'Sedaju,Sedayu', -8.1795000, 112.6875000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68241, 'Pojok', 'Pojok', 'Podjok 1,Pojok,Pojok Satu', -8.1773500, 112.7207200, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68242, 'Undaan', 'Undaan', 'Undaan,Undaan 1,Undaan Satu', -8.1955700, 112.6778200, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68243, 'Rembun', 'Rembun', 'Rembun,Rembun 1,Rembun Satu', -8.1936800, 112.7118700, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68244, 'Pamotan', 'Pamotan', 'Pamotan', -8.1996000, 112.7348700, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68245, 'Majang Tengah', 'Majang Tengah', 'Madjangtengah 1,Majang Tengah,Majangtengah Satu', -8.1970600, 112.7205700, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68246, 'Tawangrejeni', 'Tawangrejeni', 'Tawangredjeni 1,Tawangrejeni,Tawangrejeni Satu', -8.2226000, 112.6876000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68247, 'Kali', 'Kali', 'Kali', 1.1627000, 121.4278000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68248, 'Lamadong', 'Lamadong', 'Lamadong', 1.1175000, 121.4142000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68249, 'Kauditan', 'Kauditan', 'Kauditan', 1.3913200, 125.0343600, 'ID', '2014-03-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68250, 'Ogotua', 'Ogotua', 'Ogotua', 0.9596000, 120.2642000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68251, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', 0.6496000, 122.6152000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68252, 'Tompasobaru', 'Tompasobaru', 'Tompasobaru,Tomposo,Topmposo', 0.9202000, 124.4689000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68253, 'Tobadak', 'Tobadak', 'Tabodak,Tobadak', -2.0894400, 119.3472200, 'ID', '2016-10-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68254, 'Rantepang', 'Rantepang', 'Rantepang', -2.9252000, 119.9413000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68255, 'Rindingallo', 'Rindingallo', 'Rindingallo', -2.8979000, 119.8138000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68256, 'Sukamaju', 'Sukamaju', 'Sukamaju', -2.6098000, 120.4664000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68257, 'Lamasi', 'Lamasi', 'Lamasi', -2.8166000, 120.1763000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68258, 'Walenrang', 'Walenrang', 'Walenrang', -2.8417000, 120.1222000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68259, 'Malunda', 'Malunda', 'Malunda', -3.0130000, 118.8559000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68260, 'Lampa', 'Lampa', 'Lampa', -3.6634000, 119.5334000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68261, 'Majennang', 'Majennang', 'Majennang', -3.9728000, 119.6091000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68262, 'Uluale', 'Uluale', 'Uluale', -3.9072000, 119.7441000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68263, 'Amparita', 'Amparita', 'Amparita', -3.9937000, 119.8122000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68264, 'Sidenreng', 'Sidenreng', 'Sidenreng', -3.9275300, 119.7993000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68265, 'Baranti', 'Baranti', 'Baranti', -3.8398000, 119.7838000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68266, 'Teppo', 'Teppo', 'Teppo', -3.7065000, 119.6700000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68267, 'Baraka', 'Baraka', 'Baraka', -3.4079000, 119.8559000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68268, 'Getengan', 'Getengan', 'Getengan', -3.1813000, 119.8839000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68269, 'Gopaan', 'Gopaan', 'Gopaan,Gopohan', -7.0014000, 112.5106000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68270, 'Sembungan Kidul', 'Sembungan Kidul', 'Sembungan Kidul', -7.0064000, 112.5079000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68271, 'Kalimati', 'Kalimati', 'Kalimat,Kalimati', -7.0086000, 112.4997000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68272, 'Raci Kulon', 'Raci Kulon', 'Raci Kulan,Raci Kulon,Ratji-kulan', -7.0005000, 112.5425000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68273, 'Randuboto', 'Randuboto', 'Randuboto', -7.0034000, 112.5812000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68274, 'Beringinjaya', 'Beringinjaya', 'Beringinjaya', -3.0072000, 120.2057000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68275, 'Beuma', 'Beuma', 'Beuma', -3.2115000, 120.0527000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68276, 'Padangsappa', 'Padangsappa', 'Padangsappa', -3.2347000, 120.3005000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68277, 'Lempokasi', 'Lempokasi', 'Lempokasi', -3.4557000, 120.3661000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68278, 'Unaaha', 'Unaaha', 'Unaaha', -3.8539000, 122.0420000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68279, 'Tancung', 'Tancung', 'Tancung', -4.0525000, 120.0288000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68280, 'Maroanging', 'Maroanging', 'Maroanging', -4.1961000, 120.0984000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68281, 'Kotabaru', 'Kotabaru', 'Kotabaru', -4.2137000, 120.0096000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68282, 'Matango', 'Matango', 'Matango', -4.6619000, 120.0140000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68283, 'Apala', 'Apala', 'Apala', -4.6125000, 120.3136000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68284, 'Kadai', 'Kadai', 'Kadai', -4.8083000, 120.3423000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68285, 'Bulubulu', 'Bulubulu', 'Bulubulu', -4.9127000, 120.2817000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68286, 'Bilalang', 'Bilalang', 'Bilalang', 0.7729200, 124.3010300, 'ID', '2014-03-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68287, 'Modayag', 'Modayag', 'Modajag,Modayag', 0.7105000, 124.3838000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68288, 'Batuputih', 'Batuputih', 'Batuputih', -2.9582000, 120.1810000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68289, 'Kalanganyartambak', 'Kalanganyartambak', 'Kalanganyartambak', -7.3995000, 112.7938000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68290, 'Sedatigede', 'Sedatigede', 'Sedatigede', -7.3768000, 112.7623000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68291, 'Sedatiagung', 'Sedatiagung', 'Sedatiagung', -7.3819400, 112.7580600, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68292, 'Gubengairlangga', 'Gubengairlangga', 'Gubengairlangga', -7.2729000, 112.7573000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68293, 'Gununganyartambak Tengah', 'Gununganyartambak Tengah', 'Gununganyartambak Tengah', -7.3375300, 112.8019400, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68294, 'Kedungasem', 'Kedungasem', 'Kedungasem', -7.3216000, 112.7787000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68295, 'Jagirsidosermo', 'Jagirsidosermo', 'Jagirsidosermo', -7.3067800, 112.7545300, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68296, 'Labansari', 'Labansari', 'Labansari', -7.2596900, 112.7913100, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68297, 'Brongkalan', 'Brongkalan', 'Brongkalan', -7.2575000, 112.7674000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68298, 'Cikupa', 'Cikupa', '', -6.2363900, 106.5083300, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68299, 'Tenggilis Lama', 'Tenggilis Lama', 'Tenggilis Lama', -7.3166000, 112.7628000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68300, 'Teluknaga', 'Teluknaga', 'Teluknaga', -6.0988900, 106.6380600, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68301, 'Wonosari', 'Wonosari', '', -7.9655600, 110.6036100, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68302, 'Gamping Lor', 'Gamping Lor', '', -7.7955600, 110.3263900, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68303, 'Kasihan', 'Kasihan', '', -7.8269400, 110.3291700, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68304, 'Ngemplak', 'Ngemplak', '', -7.5497200, 110.7163900, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68305, 'Kartasura', 'Kartasura', '', -7.5519400, 110.7377800, 'ID', '2006-01-27', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68306, 'Gatak', 'Gatak', '', -7.5908300, 110.7044400, 'ID', '2006-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68307, 'Wahang Dua', 'Wahang Dua', 'Wahang,Wahang 2,Wahang Dua', -10.0950000, 120.0280000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68308, 'Olafulihaa', 'Olafulihaa', 'Oelafoelihaa,Olafulihaa,Ulafulihaa', -10.6310000, 123.2347000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68309, 'Tuatuka', 'Tuatuka', 'Toetoeka,Tuatuka,Tutuka', -10.1551000, 123.8360000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68310, 'Tuamese', 'Tuamese', 'Tuamesa,Tuamese', -10.2455000, 123.8749000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68311, 'Seda', 'Seda', 'Seda,Sedah', -10.7694000, 123.2157000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68312, 'Seba', 'Seba', 'Heba,Meba,Seba', -10.4933000, 121.8393000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68313, 'Pukdale', 'Pukdale', 'Bick Dale,Poekdale,Pukdale', -10.1201000, 123.8319000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68314, 'Pitai', 'Pitai', 'Pitai,Pitoi', -10.0108000, 123.6442000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68315, 'Pariti', 'Pariti', 'Pariti', -10.0148000, 123.7448000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68316, 'Praingkareha', 'Praingkareha', 'Paraingkareha,Praingkareha', -10.0129000, 120.0453000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68317, 'Sepedale', 'Sepedale', 'Oetefoe-ketjil,Oetefu-kecil,Oetefu-ketjil,Oëtefoe-ketjil,Sepedale', -10.2892000, 123.3950000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68318, 'Uitiuhtuan', 'Uitiuhtuan', 'Oetefoe-besar,Oetefu-besar,Oëtefoe-besar,Uitiuhtuan', -10.2834000, 123.3177000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68319, 'Oesao', 'Oesao', 'Oesao,Oesaoe,Oesau,Oisau,Usau', -10.1201000, 123.8115000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68320, 'Oesapa', 'Oesapa', 'Oesapa,Oesapa-besar', -10.1485000, 123.6470000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68321, 'Oelamasi', 'Oelamasi', 'Oelamasi,Oelmasi,Oemasi', -10.0642000, 123.8787000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68322, 'Oekabiti', 'Oekabiti', 'Oekabit,Oekabiti', -10.2152000, 123.8253000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68323, 'Oebelo', 'Oebelo', 'Oebelo,Oibelo', -10.1098000, 123.7534000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68324, 'Nemberala', 'Nemberala', 'Nemberala,Nembrala', -10.8861000, 122.8257000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68325, 'Namosain', 'Namosain', 'Namosain,Namsain', -10.1733000, 123.5585000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68326, 'Mbueaian', 'Mbueaian', 'Mboe Eain,Mbueaian,Mbueain', -10.8070000, 122.8295000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68327, 'Maulafa', 'Maulafa', 'Maoelafa,Maulafa', -10.1861000, 123.6227000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68328, 'Manulai', 'Manulai', 'Manoelairoti,Manulai,Manulairoti', -10.2327000, 123.5660000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68329, 'Lailunggi', 'Lailunggi', 'Lailoenggi,Lailunggi', -10.1716000, 120.1174000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68330, 'Kupang', 'Kupang', 'Gorad Kupang,KOE,Koepang,Kota Kupang,Kupang,Kupangas,Kupange,Kupango,Kupanq,Kutha Kupang,gu bang,kupan,kupang,kwpang,Горад Купанг,Купанг,Купанге,کوپانگ,クパン,古邦,쿠팡', -10.1708300, 123.6069400, 'ID', '2016-04-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68331, 'Kolbano', 'Kolbano', 'Kalbano,Kolbano', -10.0347300, 124.5220900, 'ID', '2012-12-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68332, 'Kelapalima', 'Kelapalima', 'Kelapalima,Klapalima', -10.1499000, 123.6194000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68333, 'Keoen Satu', 'Keoen Satu', 'Keoen,Keoen Satu,Keun', -10.6125000, 123.2944000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68334, 'Kananggar', 'Kananggar', 'Kanangar,Kananggar', -10.0432000, 120.3622000, 'ID', '2013-01-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68335, 'Kakaek', 'Kakaek', 'Kakae,Kakaek,Kakoe', -10.7322000, 123.2581000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68336, 'Oekiu', 'Oekiu', 'Haoetimoen,Hautimun,Oekiu', -10.0687000, 124.3022000, 'ID', '2012-10-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68337, 'Feapopi', 'Feapopi', 'Feapopi', -10.6777000, 123.1116000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68338, 'Eahun', 'Eahun', 'Eahun', -10.6146000, 123.3852000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68339, 'Camplong', 'Camplong', 'Camplong,Champlong,Saneplom,Tjampiong,Tjamplong', -10.0376000, 123.9234000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68340, 'Baun', 'Baun', 'Baoen,Baoep,Baun,Buraen', -10.2939300, 123.7251300, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68341, 'Baumata', 'Baumata', 'Baoemata,Baumata,Bomata', -10.1983000, 123.6886000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68342, 'Batuidu', 'Batuidu', 'Batoeidoe,Batuidu', -10.6235000, 123.4053000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68343, 'Baing', 'Baing', 'Bai,Baing', -10.2209000, 120.5592000, 'ID', '2012-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68344, 'Babau', 'Babau', 'Babaoe,Babau', -10.1054000, 123.7863000, 'ID', '2012-09-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68345, 'Ba', 'Ba', 'Ba,Baah,Bolauw', -10.4771000, 121.9882000, 'ID', '2012-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68346, 'Baa', 'Baa', 'Baa', -10.7263000, 123.0492000, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68347, 'Waris', 'Waris', 'WAR,Waris', -3.1166700, 140.8833300, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68348, 'Ubrub', 'Ubrub', 'UBR,Ubrub', -3.7131000, 140.8795000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68349, 'Tanah Merah', 'Tanah Merah', 'TMH,Tanah Merah,Tanahmerah,Tanamerah', -6.0975600, 140.3064900, 'ID', '2016-01-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68350, 'Sentani', 'Sentani', 'DJJ,Koejaboe,Kojaboeti,Kojabuti,Sentani', -2.5691000, 140.5127000, 'ID', '2013-11-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68351, 'Sengge', 'Sengge', 'Sengge,Senggi', -3.4475000, 140.7751000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68352, 'Jayapura', 'Jayapura', 'DJJ,Djajapoera,Djajapura,Dzajapura,Dzhajapura,Džajapura,Hollandia,Jaya Pura,Jayapura,Kota Jayapura,Kotabaru,Noordwijk,Port Numbay,Port-Numbaj,Sukarnapura,Sukarnopura,ca ya pu ra,cha ya pu la,japapwra,jayapula,jayapura,Џајапура,Джаяпура,Порт-Нумбай,جاپاپورا,จายาปุระ,ジャヤプラ,查雅普拉,자야푸라', -2.5337100, 140.7181300, 'ID', '2017-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68353, 'Genyem', 'Genyem', 'Gengen,Genjem,Genyem,Goenjem', -2.5791000, 140.1495000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68354, 'Depapre', 'Depapre', 'Depapre', -2.4869000, 140.3711000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68355, 'Demta', 'Demta', 'Demta', -2.3589000, 140.1473000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68356, 'Arso', 'Arso', 'ARJ,Arso,Arzo', -2.9028000, 140.7657000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68357, 'Abepura', 'Abepura', 'Abepura', -2.5964000, 140.6324000, 'ID', '2013-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68358, 'Mungkid', 'Mungkid', 'Mungkid', -7.5925000, 110.2188900, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68359, 'Tipar', 'Tipar', 'Tipar', -7.5052800, 109.1480600, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68360, 'Garbi', 'Garbi', 'Garbi', -7.5022200, 109.2147200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68361, 'Papringan', 'Papringan', 'Papringan', -7.5038900, 109.2483300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68362, 'Tugu', 'Tugu', 'Tugu', -7.5147200, 109.1377800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68363, 'Pesawahan', 'Pesawahan', 'Pesawahan', -7.5241700, 109.1677800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68364, 'Gambarsari', 'Gambarsari', 'Gambarsari', -7.5313900, 109.2013900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68365, 'Gambarjati', 'Gambarjati', 'Gambarjati', -7.5369400, 109.1288900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68366, 'Margasana', 'Margasana', 'Margasana', -7.5383300, 109.1383300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68367, 'Binangun', 'Binangun', 'Binangun', -7.5375000, 109.2469400, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68368, 'Karanglewas', 'Karanglewas', 'Karanglewas', -7.5536100, 109.1388900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68369, 'Losari', 'Losari', 'Losari', -7.5577800, 109.1547200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68370, 'Brak', 'Brak', 'Brak', -7.5591700, 109.2200000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68371, 'Karangtengah', 'Karangtengah', 'Karangtengah', -7.5655600, 109.1894400, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68372, 'Brani', 'Brani', 'Brani', -7.5588900, 109.1777800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68373, 'Sampang Selatan', 'Sampang Selatan', 'Sampang Selatan', -7.5669400, 109.2002800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68374, 'Gambolempuk', 'Gambolempuk', 'Gambolempuk', -7.5677800, 109.2322200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68375, 'Karangjati', 'Karangjati', 'Karangjati', -7.5813900, 109.2233300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68376, 'Sidasari', 'Sidasari', 'Sidasari', -7.5772200, 109.2016700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68377, 'Glempang Tengah', 'Glempang Tengah', 'Glempang Tengah', -7.5797200, 109.1661100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68378, 'Lancar', 'Lancar', 'Lancar', -7.5941700, 109.1469400, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68379, 'Penisihan', 'Penisihan', 'Penisihan', -7.5869400, 109.1588900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68380, 'Gununglaban', 'Gununglaban', 'Gununglaban', -7.5894400, 109.2311100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68381, 'Rawaseser', 'Rawaseser', 'Rawaseser', -7.6008300, 109.2475000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68382, 'Tinggarmalang', 'Tinggarmalang', 'Tinggarmalang', -7.5975000, 109.1988900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68383, 'Bulupayung', 'Bulupayung', 'Bulupayung', -7.5966700, 109.1391700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68384, 'Karangrena', 'Karangrena', 'Karangrena', -7.6069400, 109.1286100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68385, 'Ketanggung', 'Ketanggung', 'Ketanggung', -7.6022200, 109.1994400, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68386, 'Bayeman', 'Bayeman', 'Bayeman', -7.6016700, 109.2197200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68387, 'Mernek', 'Mernek', 'Mernek', -7.6127800, 109.1797200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68388, 'Krikil', 'Krikil', 'Krikil', -7.6247200, 109.1466700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68389, 'Klapagada', 'Klapagada', 'Klapagada', -7.6233300, 109.1486100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68390, 'Kaliterus', 'Kaliterus', 'Kaliterus', -7.6238900, 109.1977800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68391, 'Rejanegara', 'Rejanegara', 'Rejanegara', -7.6852800, 109.0383300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68392, 'Karangbadar Kidul', 'Karangbadar Kidul', 'Karangbadar Kidul', -7.7055600, 109.0308300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68393, 'Sangkalputung', 'Sangkalputung', 'Sangkalputung', -7.5061100, 109.0625000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68394, 'Gerduren', 'Gerduren', 'Gerduren', -7.5133300, 109.0927800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68395, 'Sudikampir', 'Sudikampir', 'Sudikampir', -7.5127800, 109.0272200, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68396, 'Klapagading', 'Klapagading', 'Klapagading', -7.5186100, 109.0694400, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68397, 'Tinggarwangi', 'Tinggarwangi', 'Tinggarwangi', -7.5238900, 109.1227800, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68398, 'Rawaheng', 'Rawaheng', 'Rawaheng', -7.5411100, 109.0466700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68399, 'Bantar Tengah', 'Bantar Tengah', 'Bantar Tengah', -7.5452800, 109.0891700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68400, 'Tengah', 'Tengah', 'Tengah', -7.5552800, 109.1130600, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68401, 'Pekuncen', 'Pekuncen', 'Pekuncen', -7.5597200, 109.1186100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68402, 'Kaliduren', 'Kaliduren', 'Kaliduren', -7.5602800, 109.0980600, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68403, 'Prapagan', 'Prapagan', 'Prapagan', -7.5663900, 109.0033300, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68404, 'Jambuandap', 'Jambuandap', 'Jambuandap', -7.5672200, 109.0275000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68405, 'Keleng', 'Keleng', 'Keleng', -7.5950000, 109.1116700, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68406, 'Watuagung', 'Watuagung', 'Watuagung', -7.5944400, 109.1150000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68407, 'Mandala', 'Mandala', 'Mandala', -7.5980600, 109.0561100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68408, 'Dawuhan', 'Dawuhan', 'Dawuhan', -7.6041700, 109.0825000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68409, 'Bantarsari Kulon', 'Bantarsari Kulon', 'Bantarsari Kulon', -7.6019400, 109.0913900, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68410, 'Sawoan', 'Sawoan', 'Sawoan', -7.6186100, 109.0675000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68411, 'Madusari', 'Madusari', 'Madusari', -7.6230600, 109.0786100, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68412, 'Ploso', 'Ploso', 'Ploso', -8.0827800, 111.0597200, 'ID', '2013-02-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68413, 'Krajan', 'Krajan', 'Krajan', -8.1186100, 111.0300000, 'ID', '2013-02-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68414, 'Jambuluwuk', 'Jambuluwuk', 'Jambuluwuk', -7.3135000, 108.8702000, 'ID', '2012-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68415, 'Cibeber', 'Cibeber', 'Cibeber', -6.9986100, 107.0791700, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68416, 'Gunungkalong', 'Gunungkalong', 'Gunungkalong', -6.9961100, 106.7983300, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68417, 'Bojonggaling', 'Bojonggaling', 'Bojonggaling', -6.9966700, 106.6408300, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68418, 'Sindangsari', 'Sindangsari', 'Sindangsari', -6.9930600, 106.6747200, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68419, 'Kadaka', 'Kadaka', 'Kadaka', -6.5190000, 106.4998000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68420, 'Sidoger Lebak', 'Sidoger Lebak', 'Sidoger Lebak', -6.5927800, 106.5130600, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68421, 'Gili Air', 'Gili Air', 'Gili Air,Gili Ehjr,gili air,Гили Эйр', -8.3578300, 116.0824000, 'ID', '2013-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68422, 'Senggigi', 'Senggigi', 'Sengigi,Сенгиги', -8.4919000, 116.0424000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68423, 'Lueng Putu', 'Lueng Putu', 'Lengputu,Lueng Putu', 5.2571000, 96.0565000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68424, 'Kuala Tuha', 'Kuala Tuha', 'Kuala Tuha,Kuala-tua', 4.0592700, 96.2445200, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68425, 'Kebayakan', 'Kebayakan', 'Kabayakan,Kebayakan', 4.6408000, 96.8538000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68426, 'Simpang Tiga Redelong', 'Simpang Tiga Redelong', 'Simpang Tiga Redelong', 4.7220000, 96.8743000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68427, 'Pandan', 'Pandan', 'Pandan', 1.6838000, 98.8220000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68428, 'Tangantangancut', 'Tangantangancut', 'Tangan2 Cut,Tangantangancut,Tangantangantjut', 3.6876000, 96.8896000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68429, 'Jambi Baru', 'Jambi Baru', 'Jambi Baru,Jambi-baru', 2.7787000, 97.8887000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68430, 'Drien Rampak', 'Drien Rampak', 'Drien Rampak', 4.3105000, 95.9580000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68431, 'Angkup', 'Angkup', 'Angkup', 4.6216000, 96.7228000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68432, 'Aek Kanopan', 'Aek Kanopan', 'Aek Kanopan', 2.5704000, 99.6534000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68433, 'Onolimbu', 'Onolimbu', 'Onolimbu', 0.9945900, 97.4974600, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68434, 'Jembul Kulon', 'Jembul Kulon', 'Jembul Kulon', -6.5469000, 110.9983000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68435, 'Bancak Wetan', 'Bancak Wetan', 'Bancak Wetan', -6.5564000, 110.9862000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68436, 'Cabak Satu', 'Cabak Satu', 'Cabak Satu', -6.6254000, 110.9935000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68437, 'Lahar', 'Lahar', 'Lahar', -6.6450000, 110.9935000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68438, 'Randangan', 'Randangan', 'Randangan', -6.7084000, 110.9897000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68439, 'Kaburon', 'Kaburon', 'Kaburon', -6.2875000, 106.1267000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68440, 'Karangtanjung', 'Karangtanjung', 'Karangtanjung', -6.2886000, 106.1283000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68441, 'Pekijing', 'Pekijing', 'Pekijing', -6.1234000, 106.1033000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68442, 'Babakankasilun', 'Babakankasilun', 'Babakankasilun', -6.4984000, 106.2254000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68443, 'Talagasari', 'Talagasari', 'Talagasari', -6.4954000, 106.2003000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68444, 'Pakuncen', 'Pakuncen', 'Pakuncen', -5.9543000, 106.0711000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68445, 'Curug', 'Curug', 'Curug', -5.9813000, 106.0193000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68446, 'Torsobih', 'Torsobih', 'Torsobih', -7.0004000, 113.0553000, 'ID', '2012-09-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68447, 'Bunisakit', 'Bunisakit', 'Bunisakit', -7.2487000, 107.8217000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68448, 'Bringin', 'Bringin', 'Bringin', -7.0055000, 111.9035000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68449, 'Waleran', 'Waleran', 'Waleran', -7.0011000, 111.9646000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68450, 'Gesikan', 'Gesikan', 'Gesikan', -6.9994000, 111.9872000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68451, 'Karangwungu', 'Karangwungu', 'Karangwungu', -7.0003000, 112.3612000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68452, 'Krajan Dermawuharjo', 'Krajan Dermawuharjo', 'Krajan Dermawuharjo', -7.0062000, 112.0295000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68453, 'Dempel', 'Dempel', 'Dempel', -7.0013000, 112.1122000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68454, 'Tlogosari', 'Tlogosari', 'Tlogosari', -7.9993000, 113.9353000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68455, 'Pabyongan', 'Pabyongan', 'Pabyongan', -7.9928000, 111.8086000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68456, 'Barat', 'Barat', 'Barat', -7.0496000, 113.4945000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68457, 'Morsoksok', 'Morsoksok', 'Morsoksok', -7.2078400, 113.4978800, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68458, 'Utara', 'Utara', 'Utara', -7.1988600, 113.4965800, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68459, 'Utara', 'Utara', 'Utara', -7.1683400, 113.4986900, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68460, 'Ombul', 'Ombul', 'Ombul', -7.1507400, 113.4975700, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68461, 'Talok', 'Talok', 'Talok', -7.1255000, 111.7469000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68462, 'Gemiring', 'Gemiring', 'Gemiring', -6.7531000, 111.0155000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68463, 'Baran', 'Baran', 'Baran', -6.7540000, 111.0522000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68464, 'Geritan', 'Geritan', 'Geritan', -6.7522000, 111.0604000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68465, 'Ngangguk', 'Ngangguk', 'Ngangguk', -6.7547000, 111.0823000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68466, 'Tlogocilik', 'Tlogocilik', 'Tlogocilik', -6.7565000, 111.1048000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68467, 'Kijingan', 'Kijingan', 'Kijingan', -6.7528000, 111.1162000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68468, 'Krajan Gajahmati', 'Krajan Gajahmati', 'Krajan Gajahmati', -6.7618000, 111.0460000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68469, 'Guyangan', 'Guyangan', 'Guyangan', -6.8643000, 111.1202000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68470, 'Ngapus', 'Ngapus', 'Ngapus', -6.9426000, 111.2446000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68471, 'Bahoi', 'Bahoi', 'Bahoi', 2.3619100, 125.3733500, 'ID', '2014-05-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68472, 'Tutuyan', 'Tutuyan', 'Tutuyan', 0.7654000, 124.6144000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68473, 'Lolayan', 'Lolayan', 'Lolayan', 0.6460000, 124.3074000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68474, 'Poigar', 'Poigar', 'Poigar', 0.9957000, 124.2827000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68475, 'Tanggung', 'Tanggung', 'Tanggung', -8.1318000, 111.8892000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68476, 'Glodokan', 'Glodokan', 'Glodokan', -8.1272000, 111.9105000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68477, 'Wates', 'Wates', 'Wates', -8.1326000, 111.9541000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68478, 'Pandansari', 'Pandansari', 'Pandansari', -8.1266000, 111.9826000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68479, 'Sumberingin Kulon', 'Sumberingin Kulon', 'Sumberingin Kulon', -8.1272000, 111.9898000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68480, 'Selorejo', 'Selorejo', 'Selorejo', -8.1382000, 111.9945000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68481, 'Balesono', 'Balesono', 'Balesono', -8.1393000, 111.9862000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68482, 'Mirigambar', 'Mirigambar', 'Mirigambar', -8.1340000, 111.9807000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68483, 'Sambidoplang', 'Sambidoplang', 'Sambidoplang', -8.1377000, 111.9665000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68484, 'Pojok', 'Pojok', 'Pojok', -8.1415000, 111.8928000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68485, 'Sambirejo', 'Sambirejo', 'Sambirejo', -8.1453000, 111.9501000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68486, 'Brandil', 'Brandil', 'Brandil', -8.1454000, 111.9562000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68487, 'Tunggangri', 'Tunggangri', 'Tunggangri', -8.1491000, 111.9656000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68488, 'Salakan Lor', 'Salakan Lor', 'Salakan Lor', -8.1570000, 111.9935000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68489, 'Pelem', 'Pelem', 'Pelem', -8.1581000, 111.8818000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68490, 'Pagersari', 'Pagersari', 'Pagersari', -8.1626000, 111.9239000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68491, 'Jabon', 'Jabon', 'Jabon', -8.1645000, 111.9651000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68492, 'Ngejring', 'Ngejring', 'Ngejring', -8.1724000, 111.9545000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68493, 'Karangsonojabon', 'Karangsonojabon', 'Karangsonojabon', -8.1689000, 111.9561000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68494, 'Jatirejo', 'Jatirejo', 'Jatirejo', -8.1822000, 111.8801000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68495, 'Ngrejo', 'Ngrejo', 'Ngrejo', -8.1770000, 111.9427000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68496, 'Karangtalun Lor', 'Karangtalun Lor', 'Karangtalun Lor', -8.1798000, 111.9694000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68497, 'Nganggrek', 'Nganggrek', 'Nganggrek', -8.1811000, 111.9829000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68498, 'Tumpakjoho', 'Tumpakjoho', 'Tumpakjoho', -8.1864000, 111.9139000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68499, 'Kedungdowo', 'Kedungdowo', 'Kedungdowo', -8.2030000, 111.9751000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68500, 'Manding', 'Manding', 'Manding', -8.2136000, 111.9825000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68501, 'Tekik Wetan', 'Tekik Wetan', 'Tekik Wetan', -8.2254000, 111.9572000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68502, 'Tekikbanyuurip', 'Tekikbanyuurip', 'Tekikbanyuurip', -8.2219000, 111.9507000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68503, 'Darungan', 'Darungan', 'Darungan', -8.2222000, 111.9375000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68504, 'Tanggunggunung', 'Tanggunggunung', 'Tanggunggunung', -8.2185000, 111.8757000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68505, 'Krajan', 'Krajan', 'Krajan', -8.2267000, 111.8842000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68506, 'Kaligentong', 'Kaligentong', 'Kaligentong', -8.2282000, 111.9899000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68507, 'Jengglungharjo', 'Jengglungharjo', 'Jengglungharjo', -8.2410000, 111.8956000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68508, 'Padangan', 'Padangan', 'Padangan', -8.1288000, 112.0284000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68509, 'Tenggur', 'Tenggur', 'Tenggur', -8.1322000, 112.0456000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68510, 'Banjarsari Kidul', 'Banjarsari Kidul', 'Banjarsari Kidul', -8.1348000, 112.0568000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68511, 'Tegalrejo', 'Tegalrejo', 'Tegalrejo', -8.1325000, 112.0663000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68512, 'Pakisrejo', 'Pakisrejo', 'Pakisrejo', -8.1290000, 112.0781000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68513, 'Blimbing', 'Blimbing', 'Blimbing', -8.1284000, 112.0853000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68514, 'Tugu', 'Tugu', 'Tugu', -8.1406000, 112.0309000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68515, 'Bendorubuh', 'Bendorubuh', 'Bendorubuh', -8.1377000, 112.0026000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68516, 'Samir', 'Samir', 'Samir', -8.1470000, 112.0013000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68517, 'Jatidowo', 'Jatidowo', 'Jatidowo', -8.1490000, 112.0486000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68518, 'Sumberagung', 'Sumberagung', 'Sumberagung', -8.1446000, 112.1066000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68519, 'Purwodadi', 'Purwodadi', 'Purwodadi', -8.1560000, 112.0780000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68520, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.1574000, 112.0490000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68521, 'Tenggong', 'Tenggong', 'Tenggong', -8.1567000, 112.0263000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68522, 'Karangsono', 'Karangsono', 'Karangsono', -8.1537000, 112.0059000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68523, 'Ngluweng Dua', 'Ngluweng Dua', 'Ngluweng Dua', -8.1682000, 112.0008000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68524, 'Sumberjo', 'Sumberjo', 'Sumberjo', -8.1783000, 112.1067000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68525, 'Demuk', 'Demuk', 'Demuk', -8.1903000, 112.0035000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68526, 'Maron', 'Maron', 'Maron', -8.1972000, 112.0554000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68527, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.2002000, 112.0693000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68528, 'Panggungduwet', 'Panggungduwet', 'Panggungduwet', -8.2042000, 112.0321000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68529, 'Panggunguni', 'Panggunguni', 'Panggunguni', -8.2027000, 112.0024000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68530, 'Pakisaji', 'Pakisaji', 'Pakisaji', -8.2155000, 112.0564000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68531, 'Bendosari', 'Bendosari', 'Bendosari', -8.2150000, 112.1081000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68532, 'Sumberbendo', 'Sumberbendo', 'Sumberbendo', -8.2303000, 112.0118000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68533, 'Lorejo', 'Lorejo', 'Lorejo', -8.2336000, 112.1191000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68534, 'Kedungbanteng', 'Kedungbanteng', 'Kedungbanteng', -8.2381000, 112.0926000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68535, 'Ngrejo', 'Ngrejo', 'Ngrejo', -8.2385000, 112.0810000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68536, 'Miribanteng', 'Miribanteng', 'Miribanteng', -8.2358000, 112.0273000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68537, 'Kromengan', 'Kromengan', 'Kromengan', -8.1296000, 112.4911000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68538, 'Jatirejo', 'Jatirejo', 'Jatirejo', -8.1273000, 112.4889000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68539, 'Ngreco', 'Ngreco', 'Ngreco', -8.1408000, 112.4491000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68540, 'Sumberejo', 'Sumberejo', 'Sumberejo', -8.1348000, 112.4365000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68541, 'Sukoanyar', 'Sukoanyar', 'Sukoanyar', -8.1393000, 112.3927000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68542, 'Sembung', 'Sembung', 'Sembung', -8.1410000, 112.3826000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68543, 'Krajan', 'Krajan', 'Krajan', -8.1336000, 112.3765000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68544, 'Krajan', 'Krajan', 'Krajan', -8.1583000, 112.4915000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68545, 'Bandung', 'Bandung', 'Bandung', -8.1586000, 112.4618000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68546, 'Barisan', 'Barisan', 'Barisan', -8.1841000, 112.4251000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68547, 'Kopral', 'Kopral', 'Kopral', -8.1819000, 112.4548000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68548, 'Dadapan', 'Dadapan', 'Dadapan', -8.2059000, 112.4943000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68549, 'Krajan', 'Krajan', 'Krajan', -8.2070000, 112.4651000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68550, 'Sumbertimo', 'Sumbertimo', 'Sumbertimo', -8.2165000, 112.4043000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68551, 'Sukomulyo', 'Sukomulyo', 'Sukomulyo', -8.2228000, 112.3799000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68552, 'Krajan Dua Putukrejo', 'Krajan Dua Putukrejo', 'Krajan Dua Putukrejo', -8.2392000, 112.4590000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68553, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.2353000, 112.4337000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68554, 'Selorejo', 'Selorejo', 'Selorejo', -8.1392000, 112.4257000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68555, 'Kalipare', 'Kalipare', 'Kalipare', -8.2066000, 112.4663000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68556, 'Wonosari', 'Wonosari', 'Wonosari', -8.0056000, 112.3532000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68557, 'Ringinrejo', 'Ringinrejo', 'Ringinrejo', -8.0195000, 112.2540000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68558, 'Slumbung', 'Slumbung', 'Slumbung', -8.0121200, 112.3450100, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68559, 'Purwosari', 'Purwosari', 'Purwosari', -8.0353000, 112.3225000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68560, 'Baos', 'Baos', 'Baos', -8.0433000, 112.3236000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68561, 'Sukosewu Satu', 'Sukosewu Satu', 'Sukosewu Satu', -8.0428000, 112.2958000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68562, 'Sumberagung Satu', 'Sumberagung Satu', 'Sumberagung Satu', -8.0464000, 112.2772000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68563, 'Tambakan', 'Tambakan', 'Tambakan', -8.0566000, 112.2980000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68564, 'Sendung', 'Sendung', 'Sendung', -8.0551000, 112.3382000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68565, 'Kotes', 'Kotes', 'Kotes', -8.0563700, 112.2848200, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68566, 'Sanan', 'Sanan', 'Sanan', -8.0675000, 112.2832000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68567, 'Jajar', 'Jajar', 'Jajar', -8.0727000, 112.2956000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68568, 'Tembalang', 'Tembalang', 'Tembalang', -8.0701000, 112.3350000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68569, 'Plumbangan', 'Plumbangan', 'Plumbangan', -8.0766000, 112.3404000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68570, 'Gogolatar', 'Gogolatar', 'Gogolatar', -8.0785000, 112.3042000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68571, 'Kamulan', 'Kamulan', 'Kamulan', -8.0811000, 112.2912000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68572, 'Sonogunting', 'Sonogunting', 'Sonogunting', -8.0839000, 112.2605000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68573, 'Gogosuket', 'Gogosuket', 'Gogosuket', -8.0896000, 112.2944000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68574, 'Pandean', 'Pandean', 'Pandean', -8.0930800, 112.3279500, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68575, 'Suru', 'Suru', 'Suru', -8.0933000, 112.3519000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68576, 'Klemunan', 'Klemunan', 'Klemunan', -8.0984000, 112.3341000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68577, 'Tulungrejo', 'Tulungrejo', 'Tulungrejo', -8.1116000, 112.3492000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68578, 'Tegalrejo', 'Tegalrejo', 'Tegalrejo', -8.1125000, 112.3213000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68579, 'Sragi', 'Sragi', 'Sragi', -8.1134000, 112.2983000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68580, 'Wonorejo Dua', 'Wonorejo Dua', 'Wonorejo Dua', -8.1136000, 112.2869000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68581, 'Tumpang', 'Tumpang', 'Tumpang', -8.1227000, 112.2541000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68582, 'Jeblog Satu', 'Jeblog Satu', 'Jeblog Satu', -8.1186000, 112.2625000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68583, 'Bendosewu', 'Bendosewu', 'Bendosewu', -8.1198000, 112.2726000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68584, 'Duren', 'Duren', 'Duren', -8.1213000, 112.2828000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68585, 'Bukur', 'Bukur', 'Bukur', -8.1214000, 112.3362000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68586, 'Talun', 'Talun', 'Talun', -8.0906000, 112.2850000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68587, 'Gandusari', 'Gandusari', 'Gandusari', -8.0457000, 112.3030000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68588, 'Doko', 'Doko', 'Doko', -8.0816000, 112.3729000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68589, 'Beru', 'Beru', 'Beru', -8.0870000, 112.3190000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68590, 'Balerejo', 'Balerejo', 'Balerejo', -8.0301000, 112.3765000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68591, 'Sumberingin', 'Sumberingin', 'Sumberingin', -8.0428000, 112.4650000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68592, 'Ampelgading', 'Ampelgading', 'Ampelgading', -8.0467000, 112.4457000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68593, 'Kalimanis', 'Kalimanis', 'Kalimanis', -8.0450000, 112.4374000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68594, 'Resapombo', 'Resapombo', 'Resapombo', -8.0445000, 112.4188000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68595, 'Tempursari Wetan', 'Tempursari Wetan', 'Tempursari Wetan', -8.0522000, 112.4885000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68596, 'Bumirejo', 'Bumirejo', 'Bumirejo', -8.0593000, 112.4281000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68597, 'Sidorejo', 'Sidorejo', 'Sidorejo', -8.0743000, 112.3798000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68598, 'Kemiri Gede', 'Kemiri Gede', 'Kemiri Gede', -8.0763000, 112.4100000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68599, 'Ringinrejo', 'Ringinrejo', 'Ringinrejo', -8.0832000, 112.3873000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68600, 'Jambuwerkrajan', 'Jambuwerkrajan', 'Jambuwerkrajan', -8.0934000, 112.4630000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68601, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.0926000, 112.4492000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68602, 'Cungkup', 'Cungkup', 'Cungkup', -8.0935000, 112.4260000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68603, 'Tepas', 'Tepas', 'Tepas', -8.0977000, 112.3945000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68604, 'Tapakrejo', 'Tapakrejo', 'Tapakrejo', -8.1094000, 112.4017000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68605, 'Krandil', 'Krandil', 'Krandil', -8.1129000, 112.4929000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68606, 'Kertorejo', 'Kertorejo', 'Kertorejo', -8.1085000, 112.4717000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68607, 'Kepel', 'Kepel', 'Kepel', -8.1157000, 112.4289000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68608, 'Pakel', 'Pakel', 'Pakel', -8.1090000, 112.4112000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68609, 'Wonosari', 'Wonosari', 'Wonosari', -8.0283000, 112.4938000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68610, 'Tanjung Timur', 'Tanjung Timur', 'Tanjung Timur', -7.1870000, 111.4987000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68611, 'Pulo', 'Pulo', 'Pulo', -7.1895000, 111.4989000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68612, 'Peting', 'Peting', 'Peting', -7.1805000, 111.4600000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68613, 'Gayam', 'Gayam', 'Gayam', -7.2195000, 111.4557000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68614, 'Mojorembun', 'Mojorembun', 'Mojorembun', -7.2269000, 111.4706000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68615, 'Gondel', 'Gondel', 'Gondel', -7.2293000, 111.4947000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68616, 'Menden', 'Menden', 'Menden', -7.2467000, 111.4548000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68617, 'Temulus', 'Temulus', 'Temulus', -7.2185000, 111.4221000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68618, 'Sumberrejo', 'Sumberrejo', 'Sumberrejo', -7.2000000, 111.4347000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68619, 'Pilang', 'Pilang', 'Pilang', -7.2008000, 111.3926000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68620, 'Kadengan', 'Kadengan', 'Kadengan', -7.1840000, 111.3876000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68621, 'Ploso Wetan', 'Ploso Wetan', 'Ploso Wetan', -7.1893000, 111.4109000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68622, 'Randublatung', 'Randublatung', 'Randublatung', -7.2036000, 111.3864000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68623, 'Ngraho', 'Ngraho', 'Ngraho', -7.1707000, 111.4972000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68624, 'Karangboyo', 'Karangboyo', 'Karangboyo', -7.1291000, 111.6003000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68625, 'Ngroto', 'Ngroto', 'Ngroto', -7.1257000, 111.6054000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68626, 'Caper', 'Caper', 'Caper', -7.1354000, 111.6124000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68627, 'Ngelo', 'Ngelo', 'Ngelo', -7.1354000, 111.6053000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68628, 'Demakan', 'Demakan', 'Demakan', -7.1475000, 111.6047000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68629, 'Kuncen', 'Kuncen', 'Kuncen', -7.1572000, 111.6215000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68630, 'Tambakkromo', 'Tambakkromo', 'Tambakkromo', -7.1571000, 111.5702000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68631, 'Mulyorejo', 'Mulyorejo', 'Mulyorejo', -7.1587000, 111.5646000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68632, 'Mernung', 'Mernung', 'Mernung', -7.1544000, 111.5476000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68633, 'Seren', 'Seren', 'Seren', -7.1571000, 111.5378000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68634, 'Kentongan', 'Kentongan', 'Kentongan', -7.1655000, 111.5605000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68635, 'Nguken', 'Nguken', 'Nguken', -7.1609000, 111.5954000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68636, 'Pengkok', 'Pengkok', 'Pengkok', -7.1667000, 111.6099000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68637, 'Mersodo', 'Mersodo', 'Mersodo', -7.1788000, 111.5889000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68638, 'Nglanjuk', 'Nglanjuk', 'Nglanjuk', -7.1664000, 111.5849000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68639, 'Balangpule', 'Balangpule', 'Balangpule', -7.1724000, 111.5010000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68640, 'Blimbing', 'Blimbing', 'Blimbing', -7.1845000, 111.6005000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68641, 'Gempol', 'Gempol', 'Gempol', -7.1827000, 111.6137000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68642, 'Sonorejo', 'Sonorejo', 'Sonorejo', -7.1814000, 111.6234000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68643, 'Ngeper', 'Ngeper', 'Ngeper', -7.1919000, 111.6006000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68644, 'Prangi', 'Prangi', 'Prangi', -7.1874000, 111.5835000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68645, 'Sumberpitu', 'Sumberpitu', 'Sumberpitu', -7.1849000, 111.5817000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68646, 'Tebon', 'Tebon', 'Tebon', -7.1883000, 111.5668000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68647, 'Sugihwaras', 'Sugihwaras', 'Sugihwaras', -7.1863000, 111.5437000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68648, 'Kemantren', 'Kemantren', 'Kemantren', -7.2095000, 111.5187000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68649, 'Jetis', 'Jetis', 'Jetis', -7.2144000, 111.5179000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68650, 'Klagen', 'Klagen', 'Klagen', -7.2125000, 111.5293000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68651, 'Ketawang', 'Ketawang', 'Ketawang', -7.2122000, 111.5630000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68652, 'Purwa', 'Purwa', 'Purwa', -7.2228000, 111.5441000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68653, 'Ketuwan', 'Ketuwan', 'Ketuwan', -7.2325000, 111.5099000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68654, 'Tapelan', 'Tapelan', 'Tapelan', -7.2283000, 111.5335000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68655, 'Klempun', 'Klempun', 'Klempun', -7.2292000, 111.5837000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68656, 'Pengkol', 'Pengkol', 'Pengkol', -7.2352000, 111.5932000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68657, 'Pandan', 'Pandan', 'Pandan', -7.2394000, 111.5640000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68658, 'Ngori', 'Ngori', 'Ngori', -7.2368000, 111.5459000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68659, 'Mojorejo', 'Mojorejo', 'Mojorejo', -7.2405000, 111.5210000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68660, 'Batokan', 'Batokan', 'Batokan', -7.1433000, 111.6129000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68661, 'Sekaran', 'Sekaran', 'Sekaran', -7.1271000, 111.6519000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68662, 'Suroh', 'Suroh', 'Suroh', -7.1335000, 111.6602000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68663, 'Kliteh', 'Kliteh', 'Kliteh', -7.1272000, 111.7028000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68664, 'Celangap', 'Celangap', 'Celangap', -7.1373000, 111.7260000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68665, 'Cengungklung', 'Cengungklung', 'Cengungklung', -7.1388000, 111.7137000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68666, 'Telumbung', 'Telumbung', 'Telumbung', -7.1375000, 111.7081000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68667, 'Semanding', 'Semanding', 'Semanding', -7.1441000, 111.6856000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68668, 'Besah', 'Besah', 'Besah', -7.1358000, 111.6394000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68669, 'Kacangan Lor', 'Kacangan Lor', 'Kacangan Lor', -7.1470000, 111.6679000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68670, 'Kembangan', 'Kembangan', 'Kembangan', -7.1476000, 111.6902000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68671, 'Katur', 'Katur', 'Katur', -7.1586000, 111.7191000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68672, 'Banjarjo', 'Banjarjo', 'Banjarjo', -7.1585000, 111.6272000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68673, 'Ketawang', 'Ketawang', 'Ketawang', -7.1657000, 111.6260000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68674, 'Tembeling', 'Tembeling', 'Tembeling', -7.1640000, 111.6507000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68675, 'Dukuh Lor', 'Dukuh Lor', 'Dukuh Lor', -7.1629000, 111.6601000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68676, 'Bulu', 'Bulu', 'Bulu', -7.1659000, 111.6751000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68677, 'Ringintunggal', 'Ringintunggal', 'Ringintunggal', -7.1703000, 111.7124000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68678, 'Gayam', 'Gayam', 'Gayam', -7.1764000, 111.7137000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68679, 'Beged', 'Beged', 'Beged', -7.1746000, 111.6690000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68680, 'Bonorejo', 'Bonorejo', 'Bonorejo', -7.1827000, 111.6792000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68681, 'Dawung', 'Dawung', 'Dawung', -7.2006000, 111.6928000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68682, 'Gapluk', 'Gapluk', 'Gapluk', -7.2048000, 111.6619000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68683, 'Donan', 'Donan', 'Donan', -7.2066000, 111.6374000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68684, 'Tinumpuk', 'Tinumpuk', 'Tinumpuk', -7.2118000, 111.6857000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68685, 'Tlatah', 'Tlatah', 'Tlatah', -7.2122000, 111.7011000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68686, 'Ngrejeng', 'Ngrejeng', 'Ngrejeng', -7.2174000, 111.7076000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68687, 'Pelem', 'Pelem', 'Pelem', -7.2407000, 111.7065000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68688, 'Mojosawit', 'Mojosawit', 'Mojosawit', -7.2477000, 111.7131000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68689, 'Purwosari', 'Purwosari', 'Purwosari', -7.1723000, 111.6590000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68690, 'Wonocolo', 'Wonocolo', 'Wonocolo', -7.0507000, 111.6703000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68691, 'Ngrowo', 'Ngrowo', 'Ngrowo', -7.0774000, 111.6269000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68692, 'Tambakmerak', 'Tambakmerak', 'Tambakmerak', -7.1155000, 111.6638000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68693, 'Sendang', 'Sendang', 'Sendang', -7.0067000, 111.7308000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68694, 'Wanglu Kulon', 'Wanglu Kulon', 'Wanglu Kulon', -7.0197000, 111.7314000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68695, 'Wanglu Wetan', 'Wanglu Wetan', 'Wanglu Wetan', -7.0241000, 111.7332000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68696, 'Leran', 'Leran', 'Leran', -7.0225000, 111.7185000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68697, 'Medalem', 'Medalem', 'Medalem', -7.0023000, 111.7140000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68698, 'Sarang', 'Sarang', 'Sarang', -7.0313000, 111.7010000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68699, 'Banaran', 'Banaran', 'Banaran', -7.0393000, 111.7384000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68700, 'Wonosari', 'Wonosari', 'Wonosari', -7.0722000, 111.7116000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68701, 'Banyuurip', 'Banyuurip', 'Banyuurip', -7.0629000, 111.6975000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68702, 'Kawengan', 'Kawengan', 'Kawengan', -7.0711000, 111.6806000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68703, 'Ledok', 'Ledok', 'Ledok', -7.0990000, 111.7371000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68704, 'Gotak', 'Gotak', 'Gotak', -7.1095000, 111.7419000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68705, 'Sudah', 'Sudah', 'Sudah', -7.1198000, 111.7225000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68706, 'Ngujung', 'Ngujung', 'Ngujung', -7.1238000, 111.7090000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68707, 'Karuk', 'Karuk', 'Karuk', -7.1106000, 111.7268000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68708, 'Malo', 'Malo', 'Malo', -7.1071000, 111.7317000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68709, 'Blajo', 'Blajo', 'Blajo', -7.0434000, 112.3933000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68710, 'Kemendung', 'Kemendung', 'Kemendung', -7.0460000, 112.3782000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68711, 'Kemlagigede', 'Kemlagigede', 'Kemlagigede', -7.0612000, 112.3910000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68712, 'Bambang', 'Bambang', 'Bambang', -7.0595000, 112.3969000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68713, 'Baru', 'Baru', 'Baru', -7.0525000, 112.3901000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68714, 'Gowa', 'Gowa', 'Gowa', -7.0487000, 112.4050000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68715, 'Waru', 'Waru', 'Waru', -7.0468000, 112.4048000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68716, 'Gambuhan Kidul', 'Gambuhan Kidul', 'Gambuhan Kidul', -7.0392000, 112.3985000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68717, 'Canditunggal', 'Canditunggal', 'Canditunggal', -7.0013000, 112.4199000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68718, 'Depek', 'Depek', 'Depek', -7.0072000, 112.4286000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68719, 'Palangan', 'Palangan', 'Palangan', -7.0049000, 112.4451000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68720, 'Lembung Lor', 'Lembung Lor', 'Lembung Lor', -7.0150000, 112.4252000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68721, 'Mayong Tengah', 'Mayong Tengah', 'Mayong Tengah', -7.0146000, 112.4366000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68722, 'Wedeng', 'Wedeng', 'Wedeng', -7.0462000, 112.4224000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68723, 'Mlawe', 'Mlawe', 'Mlawe', -7.0510000, 112.4232000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68724, 'Karang Kulon', 'Karang Kulon', 'Karang Kulon', -7.0507000, 112.4243000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68725, 'Luntas', 'Luntas', 'Luntas', -7.0612000, 112.4340000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68726, 'Blawi', 'Blawi', 'Blawi', -7.0502000, 112.4574000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68727, 'Ladan', 'Ladan', 'Ladan', -7.0641000, 112.4413000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68728, 'Ngujung', 'Ngujung', 'Ngujung', -7.0638000, 112.4186000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68729, 'Jrebeng', 'Jrebeng', 'Jrebeng', -7.0051000, 112.4662000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68730, 'Baron', 'Baron', 'Baron', -7.0129000, 112.4533000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68731, 'Banjaranyar', 'Banjaranyar', 'Banjaranyar', -7.0121000, 112.4618000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68732, 'Watangan', 'Watangan', 'Watangan', -7.0150000, 112.4842000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68733, 'Sambopinggir', 'Sambopinggir', 'Sambopinggir', -7.0225000, 112.4793000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68734, 'Windu', 'Windu', 'Windu', -7.0259000, 112.4879000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68735, 'Magok', 'Magok', 'Magok', -7.0387000, 112.4630000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68736, 'Prioso Barat', 'Prioso Barat', 'Prioso Barat', -7.0494000, 112.4885000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68737, 'Kebon', 'Kebon', 'Kebon', -7.0400000, 112.4717000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68738, 'Calan', 'Calan', 'Calan', -7.0483000, 112.4646000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68739, 'Baturono', 'Baturono', 'Baturono', -7.0464000, 112.4762000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68740, 'Pompongan', 'Pompongan', 'Pompongan', -7.0622000, 112.4708000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68741, 'Duni', 'Duni', 'Duni', -7.0701000, 112.4678000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68742, 'Turi', 'Turi', 'Turi', -7.0795000, 112.3820000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68743, 'Getung', 'Getung', 'Getung', -7.0784000, 112.3904000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68744, 'Pagerwojo', 'Pagerwojo', 'Pagerwojo', -7.1196000, 112.4021000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68745, 'Made', 'Made', 'Made', -7.1174000, 112.3915000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68746, 'Tanjung', 'Tanjung', 'Tanjung', -7.1146000, 112.3866000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68747, 'Bilo', 'Bilo', 'Bilo', -7.1114000, 112.3782000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68748, 'Ngaglik Timur', 'Ngaglik Timur', 'Ngaglik Timur', -7.1183000, 112.4126000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68749, 'Tumenggungan', 'Tumenggungan', 'Tumenggungan', -7.1147000, 112.4145000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68750, 'Krian', 'Krian', 'Krian', -7.1163000, 112.4194000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68751, 'Kendaruan', 'Kendaruan', 'Kendaruan', -7.1185000, 112.4220000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68752, 'Jetis', 'Jetis', 'Jetis', -7.1204000, 112.4199000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68753, 'Deket Kulon', 'Deket Kulon', 'Deket Kulon', -7.1184000, 112.4395000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68754, 'Keset', 'Keset', 'Keset', -7.1061000, 112.4276000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68755, 'Glugu', 'Glugu', 'Glugu', -7.0883000, 112.4259000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68756, 'Balun', 'Balun', 'Balun', -7.0877000, 112.4073000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68757, 'Mlanggeng', 'Mlanggeng', 'Mlanggeng', -7.0748000, 112.4303000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68758, 'Rawaglagah', 'Rawaglagah', 'Rawaglagah', -7.0775000, 112.4453000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68759, 'Keputran', 'Keputran', 'Keputran', -7.0912000, 112.4470000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68760, 'Sugihwaras', 'Sugihwaras', 'Sugihwaras', -7.1024000, 112.4443000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68761, 'Gajah', 'Gajah', 'Gajah', -7.1125000, 112.4534000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68762, 'Bendungan', 'Bendungan', 'Bendungan', -7.1177000, 112.4981000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68763, 'Nginjen', 'Nginjen', 'Nginjen', -7.1187000, 112.4742000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68764, 'Semambung', 'Semambung', 'Semambung', -7.0972000, 112.4590000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68765, 'Kebon Tengah', 'Kebon Tengah', 'Kebon Tengah', -7.0937000, 112.4667000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68766, 'Dagangan', 'Dagangan', 'Dagangan', -7.0913000, 112.4604000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68767, 'Sampangan', 'Sampangan', 'Sampangan', -7.0720000, 112.4587000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68768, 'Bucu Lor', 'Bucu Lor', 'Bucu Lor', -7.0728000, 112.4799000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68769, 'Bucu Kidul', 'Bucu Kidul', 'Bucu Kidul', -7.0764000, 112.4789000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68770, 'Sudangan', 'Sudangan', 'Sudangan', -7.0832000, 112.4955000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68771, 'Mendogo Lor', 'Mendogo Lor', 'Mendogo Lor', -7.0879000, 112.4924000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68772, 'Plosobuden', 'Plosobuden', 'Plosobuden', -7.0990000, 112.4956000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68773, 'Began', 'Began', 'Began', -7.0963000, 112.4813000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68774, 'Mungli', 'Mungli', 'Mungli', -7.0130000, 112.3859000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68775, 'Lukrejo', 'Lukrejo', 'Lukrejo', -7.0194000, 112.3939000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68776, 'Deket Wetan', 'Deket Wetan', 'Deket Wetan', -7.1184000, 112.4439000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68777, 'Niwen', 'Niwen', 'Niwen', -8.0003000, 112.5955000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68778, 'Kenongo', 'Kenongo', 'Kenongo', -8.0089000, 112.5393000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68779, 'Ardirejo', 'Ardirejo', 'Ardirejo', -8.1245000, 112.5734000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68780, 'Bendo', 'Bendo', 'Bendo', -8.0723000, 112.5926000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68781, 'Sukonolo Krajan', 'Sukonolo Krajan', 'Sukonolo Krajan', -8.1031000, 112.6167000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68782, 'Wagir', 'Wagir', 'Wagir', -8.0132000, 112.5942000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68783, 'Kepuh', 'Kepuh', 'Kepuh', -8.0060000, 112.6188000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68784, 'Pakisaji', 'Pakisaji', 'Pakisaji', -8.0665000, 112.5981000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68785, 'Ngajum', 'Ngajum', 'Ngajum', -8.0955000, 112.5410000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68786, 'Bumiayu', 'Bumiayu', 'Bumiayu', -8.0151000, 112.6347000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68787, 'Sekarsari', 'Sekarsari', 'Sekarsari', -8.0366000, 112.6542000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68788, 'Gunungsari', 'Gunungsari', 'Gunungsari', -8.0456000, 112.6936000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68789, 'Watudakon', 'Watudakon', 'Watudakon', -8.0453000, 112.6276000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68790, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.0636000, 112.6429000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68791, 'Sidoaji', 'Sidoaji', 'Sidoaji', -8.0874000, 112.6326000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68792, 'Krapyak Kidul', 'Krapyak Kidul', 'Krapyak Kidul', -8.0940000, 112.6468000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68793, 'Napel', 'Napel', 'Napel', -8.1088000, 112.7100000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68794, 'Tajinan', 'Tajinan', 'Tajinan', -8.0497000, 112.6824000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68795, 'Wajak', 'Wajak', 'Wajak', -8.1020000, 112.7312000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68796, 'Jambekumbu', 'Jambekumbu', 'Jambekumbu', -8.1006000, 113.0674000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68797, 'Pasrukrajan Satu', 'Pasrukrajan Satu', 'Pasrukrajan Satu', -8.1192000, 113.0582000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68798, 'Wonorejo', 'Wonorejo', 'Wonorejo', -8.0691000, 113.0708000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68799, 'Burno', 'Burno', 'Burno', -8.0853000, 113.0723000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68800, 'Krajanjambearum', 'Krajanjambearum', 'Krajanjambearum', -8.1170000, 113.0794000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68801, 'Kandangan', 'Kandangan', 'Kandangan', -8.0667000, 113.0902000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68802, 'Bedayutalang', 'Bedayutalang', 'Bedayutalang', -8.0698000, 113.1151000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68803, 'Bedayu', 'Bedayu', 'Bedayu', -8.0710000, 113.1016000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68804, 'Gasri', 'Gasri', 'Gasri', -8.1164000, 113.1123000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68805, 'Senduro', 'Senduro', 'Senduro', -8.0936000, 113.0891000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68806, 'Wringinsari', 'Wringinsari', 'Wringinsari', -8.1247000, 113.2019000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68807, 'Pakel', 'Pakel', 'Pakel', -8.0643000, 113.1281000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68808, 'Wonoayu', 'Wonoayu', 'Wonoayu', -8.0766000, 113.1340000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68809, 'Krajan', 'Krajan', 'Krajan', -8.1193000, 113.1287000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68810, 'Pule', 'Pule', 'Pule', -8.0482000, 113.1404000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68811, 'Sidomakmur', 'Sidomakmur', 'Sidomakmur', -8.0560000, 113.1448000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68812, 'Tanjung', 'Tanjung', 'Tanjung', -8.0980000, 113.1562000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68813, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.0363000, 113.1575000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68814, 'Krajan', 'Krajan', 'Krajan', -8.0775000, 113.1627000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68815, 'Krajan', 'Krajan', 'Krajan', -8.1224000, 113.1672000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68816, 'Sidorejo', 'Sidorejo', 'Sidorejo', -8.0104000, 113.1803000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68817, 'Sekartanjung', 'Sekartanjung', 'Sekartanjung', -8.0298000, 113.1777000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68818, 'Karangrejo', 'Karangrejo', 'Karangrejo', -8.0450000, 113.1761000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68819, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.0976000, 113.1867000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68820, 'Antrukan', 'Antrukan', 'Antrukan', -8.0080000, 113.1976000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68821, 'Darungan', 'Darungan', 'Darungan', -8.0419000, 113.2034000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68822, 'Krajan', 'Krajan', 'Krajan', -8.0723000, 113.2012000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68823, 'Krajan', 'Krajan', 'Krajan', -8.0779000, 113.1940000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68824, 'Krajan', 'Krajan', 'Krajan', -8.1155000, 113.2023000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68825, 'Makam', 'Makam', 'Makam', -8.0033000, 113.2154000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68826, 'Taman', 'Taman', 'Taman', -8.0196000, 113.2173000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68827, 'Krajan', 'Krajan', 'Krajan', -8.0295000, 113.2117000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68828, 'Umpak', 'Umpak', 'Umpak', -8.0776000, 113.2104000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68829, 'Krajan', 'Krajan', 'Krajan', -8.1020000, 113.2220000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68830, 'Sidodadi', 'Sidodadi', 'Sidodadi', -8.1063000, 113.2194000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68831, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.1069000, 113.2114000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68832, 'Darungan Lor', 'Darungan Lor', 'Darungan Lor', -8.0438000, 113.2345000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68833, 'Srunikrajan', 'Srunikrajan', 'Srunikrajan', -8.0030000, 113.2353000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68834, 'Krajan', 'Krajan', 'Krajan', -8.0291000, 113.2330000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68835, 'Krajan', 'Krajan', 'Krajan', -8.0504000, 113.2364000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68836, 'Krajan', 'Krajan', 'Krajan', -8.0775000, 113.2380000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68837, 'Krajan Wetan', 'Krajan Wetan', 'Krajan Wetan', -8.0885000, 113.2423000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68838, 'Sekarputih', 'Sekarputih', 'Sekarputih', -8.1205000, 113.2408000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68839, 'Krajan Baru', 'Krajan Baru', 'Krajan Baru', -8.0879000, 113.2481000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68840, 'Kajaran', 'Kajaran', 'Kajaran', -8.0854000, 113.1909000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68841, 'Sukodono', 'Sukodono', 'Sukodono', -8.1046000, 113.2322000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68842, 'Rogotrunan', 'Rogotrunan', 'Rogotrunan', -8.1191000, 113.2283000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68843, 'Jalinan', 'Jalinan', 'Jalinan,Pendjalinan', -8.2542000, 113.8191000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68844, 'Karangharjo', 'Karangharjo', 'Karangharjo', -8.2536000, 113.8363000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68845, 'Sukmoilang', 'Sukmoilang', 'Sukmoilang', -8.2631000, 113.8575000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68846, 'Baban Tengah', 'Baban Tengah', 'Baban Tengah', -8.3357000, 113.8510000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68847, 'Sedati', 'Sedati', 'Sedati', -7.3952000, 112.7675000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68848, 'Pasembon', 'Pasembon', 'Pasembon', -8.5081000, 114.1571000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68849, 'Selorejo', 'Selorejo', 'Selorejo', -8.5238000, 114.1890000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68850, 'Kedungrejo', 'Kedungrejo', 'Kedungrejo', -8.5141000, 114.1726000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68851, 'Krajan', 'Krajan', 'Krajan', -8.5333000, 114.1558000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68852, 'Curahjati', 'Curahjati', 'Curahjati', -8.5460000, 114.2419000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68853, 'Sumberkepoh', 'Sumberkepoh', 'Sumberkepoh', -8.5191000, 114.3192000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68854, 'Sumberluhur', 'Sumberluhur', 'Sumberluhur', -8.5131000, 114.2822000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68855, 'Jatimulyo', 'Jatimulyo', 'Jatimulyo', -8.5136000, 114.2571000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68856, 'Persen', 'Persen', 'Persen', -8.5311000, 114.3245000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68857, 'Kendalrejo', 'Kendalrejo', 'Kendalrejo', -8.5507000, 114.3199000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68858, 'Tegalsari', 'Tegalsari', 'Tegalsari', -8.5464000, 114.2872000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68859, 'Sumberasri', 'Sumberasri', 'Sumberasri', -8.5455000, 114.2668000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68860, 'Krajan Tengah', 'Krajan Tengah', 'Krajan Tengah', -8.3035000, 114.0325000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68861, 'Purwojoyo', 'Purwojoyo', 'Purwojoyo', -8.3320000, 114.0979000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68862, 'Karangharjo Kidul', 'Karangharjo Kidul', 'Karangharjo Kidul', -8.3125000, 114.0483000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68863, 'Krajan', 'Krajan', 'Krajan', -8.2529000, 114.2063000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68864, 'Tambakbayan', 'Tambakbayan', 'Tambakbayan', -8.2656000, 114.2356000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68865, 'Wiyayu Barat', 'Wiyayu Barat', 'Wiyayu Barat', -8.2889000, 114.2229000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68866, 'Krajan', 'Krajan', 'Krajan', -8.2916000, 114.2416000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68867, 'Cantuk Kidul', 'Cantuk Kidul', 'Cantuk Kidul', -8.2983000, 114.2275000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68868, 'Rukem', 'Rukem', 'Rukem', -8.2959000, 114.2110000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68869, 'Kopen', 'Kopen', 'Kopen', -8.3085000, 114.1738000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68870, 'Krajan', 'Krajan', 'Krajan', -8.3044000, 114.2099000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68871, 'Pasinan Barat', 'Pasinan Barat', 'Pasinan Barat', -8.3147000, 114.2374000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68872, 'Krajan', 'Krajan', 'Krajan', -8.3149000, 114.2301000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68873, 'Krajan', 'Krajan', 'Krajan', -8.3125000, 114.1998000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68874, 'Krajan', 'Krajan', 'Krajan', -8.3379000, 114.2442000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68875, 'Melikkrajan', 'Melikkrajan', 'Melikkrajan', -8.3482000, 114.2281000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68876, 'Payaman', 'Payaman', 'Payaman', -8.3561000, 114.2497000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68877, 'Semalang', 'Semalang', 'Semalang', -8.3660000, 114.2207000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68878, 'Krajan', 'Krajan', 'Krajan', -8.3652000, 114.1627000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68879, 'Kopen', 'Kopen', 'Kopen', -8.3621000, 114.1487000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68880, 'Krajan', 'Krajan', 'Krajan', -8.3646000, 114.1345000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68881, 'Sempu', 'Sempu', 'Sempu', -8.3184000, 114.1520000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68882, 'Plalangan', 'Plalangan', 'Plalangan', -8.0051000, 114.1626000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68883, 'Peneng', 'Peneng', 'Peneng', -8.3795000, 115.1942000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68884, 'Tua', 'Tua', 'Tua', -8.4114000, 115.1806000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68885, 'Empalan', 'Empalan', 'Empalan', -8.3952000, 115.1512000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68886, 'Luwus', 'Luwus', 'Luwus', -8.3984000, 115.1956000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68887, 'Banjar Buahan', 'Banjar Buahan', 'Buahan', -8.3948000, 115.2367000, 'ID', '2014-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68888, 'Badung', 'Badung', 'Badung', -8.4355000, 115.2437000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68889, 'Pergan', 'Pergan', 'Pergan', -8.4266000, 115.1948000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68890, 'Pohgending Kangin', 'Pohgending Kangin', 'Pohgending Kangin', -8.4316000, 115.1455000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68891, 'Pohgending Kawan', 'Pohgending Kawan', 'Pohgending Kawan', -8.4359000, 115.1426000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68892, 'Payangan Tengah', 'Payangan Tengah', 'Payangan Tengah', -8.4361000, 115.1673000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68893, 'Petiga', 'Petiga', 'Petiga', -8.4358000, 115.1772000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68894, 'Penatahan Kaja', 'Penatahan Kaja', 'Penatahan Kaja', -8.4360000, 115.1257000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68895, 'Bayad', 'Bayad', 'Bayad', -8.4472000, 115.2415000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68896, 'Pemijian', 'Pemijian', 'Pemijian', -8.4499000, 115.2193000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68897, 'Bunutan', 'Bunutan', 'Bunutan', -8.4649000, 115.2480000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68898, 'Tembau', 'Tembau', 'Tembau', -8.4692000, 115.1683000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68899, 'Wanasari Baleran', 'Wanasari Baleran', 'Wanasari Baleran', -8.4849000, 115.1348000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68900, 'Kuwumkumambal', 'Kuwumkumambal', 'Kuwumkumambal', -8.4879000, 115.1696000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68901, 'Kekeran', 'Kekeran', 'Kekeran', -8.4906000, 115.1777000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68902, 'Brahmana', 'Brahmana', 'Brahmana', -8.4867000, 115.2101000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68903, 'Pegongan', 'Pegongan', 'Pegongan', -8.4855000, 115.2265000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68904, 'Basa', 'Basa', 'Basa', -8.4741000, 115.1685000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68905, 'Tunjuk Selatan', 'Tunjuk Selatan', 'Tunjuk Selatan', -8.4755000, 115.1518000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68906, 'Banjar Tengah', 'Banjar Tengah', 'Banjar Tengah,Tengah', -8.4985000, 115.1942000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68907, 'Pengembunan', 'Pengembunan', 'Pengembunan', -8.4954000, 115.1542000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68908, 'Buahan Tengah', 'Buahan Tengah', 'Buahan Tengah', -8.4947000, 115.1497000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68909, 'Beaung Tengah', 'Beaung Tengah', 'Beaung Tengah', -8.4215000, 115.1610000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68910, 'Petang', 'Petang', 'Petang', -8.3963000, 115.2187000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68911, 'Sukorejo', 'Sukorejo', 'Sukorejo', -7.9603000, 114.0015000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68912, 'Tangkup', 'Tangkup', 'Tangkup', -7.9330000, 114.3718000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68913, 'Keli', 'Keli', 'Keli', -8.3899000, 118.7992000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68914, 'Lela', 'Lela', 'Lela', -8.4405000, 118.7512000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68915, 'Penaraga', 'Penaraga', 'Penaraga', -8.4657000, 118.7575000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68916, 'Pisang', 'Pisang', 'Pisang', -8.4700000, 118.7574000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68917, 'Rontu', 'Rontu', 'Rontu', -8.4797000, 118.7539000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68918, 'Kumbe', 'Kumbe', 'Kumbe', -8.4847000, 118.7701000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68919, 'Kendo Satu', 'Kendo Satu', 'Kendo Satu', -8.4685000, 118.7800000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68920, 'Penanae', 'Penanae', 'Penanae', -8.4604000, 118.7638000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68921, 'Dodu Dua', 'Dodu Dua', 'Dodu Dua', -8.4892000, 118.7962000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68922, 'Nungga', 'Nungga', 'Nungga', -8.4829000, 118.7930000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68923, 'Ntobo', 'Ntobo', 'Ntobo', -8.4498000, 118.7794000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68924, 'Rato', 'Rato', 'Rato', -8.4744000, 118.7649000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68925, 'Amahusu', 'Amahusu', 'Amahani,Amahoesoe,Amahusu', -3.7252500, 128.1471000, 'ID', '2014-01-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68926, 'Watulumbung', 'Watulumbung', 'Watulumbung', -7.0052000, 111.5120000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68927, 'Suruhan', 'Suruhan', 'Suruhan', -7.0046000, 111.5157000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68928, 'Tirtoyudo', 'Tirtoyudo', 'Tirtoyudo', -8.2446000, 112.8160000, 'ID', '2012-01-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68929, 'Banjar Wangsian', 'Banjar Wangsian', 'Banjar Wangsian', -8.4949700, 115.4234200, 'ID', '2012-04-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68930, 'Tuliskriyo', 'Tuliskriyo', 'Tuliskriyo', -8.1341000, 112.1519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68931, 'Klampok', 'Klampok', 'Klampok', -8.1299000, 112.1617000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68932, 'Minggirsari Dua', 'Minggirsari Dua', 'Minggirsari Dua', -8.1420000, 112.1697000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68933, 'Karangsono', 'Karangsono', 'Karangsono', -8.1402000, 112.2061400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68934, 'Jegu', 'Jegu', 'Jegu', -8.1512000, 112.2349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68935, 'Satrejan', 'Satrejan', 'Satrejan', -8.1429000, 112.2206000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68936, 'Serut', 'Serut', 'Serut', -8.1435000, 112.1932000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68937, 'Plosorejo', 'Plosorejo', 'Plosorejo', -8.1570000, 112.1708000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68938, 'Tenggong', 'Tenggong', 'Tenggong', -8.1539000, 112.1326000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68939, 'Dawuhan', 'Dawuhan', 'Dawuhan', -8.1680000, 112.1312000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68940, 'Sumberjati', 'Sumberjati', 'Sumberjati', -8.1653000, 112.1462000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68941, 'Darungan Satu', 'Darungan Satu', 'Darungan Satu', -8.1598000, 112.1765000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68942, 'Kembangarum', 'Kembangarum', 'Kembangarum', -8.1593000, 112.2168000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68943, 'Wonorejo', 'Wonorejo', 'Wonorejo', -8.1702100, 112.2182400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68944, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.1717000, 112.2310000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68945, 'Jinglong', 'Jinglong', 'Jinglong', -8.1657600, 112.2307600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68946, 'Bacem', 'Bacem', 'Bacem', -8.1946000, 112.2320700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68947, 'Klampok', 'Klampok', 'Klampok', -8.1819800, 112.1947800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68948, 'Kedungbunder', 'Kedungbunder', 'Kedungbunder', -8.1775000, 112.2083000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68949, 'Sutojayan', 'Sutojayan', 'Sutojayan', -8.1784900, 112.2162200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68950, 'Sumberrejo', 'Sumberrejo', 'Sumberrejo', -8.1802000, 112.2379000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68951, 'Wonotirto', 'Wonotirto', 'Wonotirto', -8.2245000, 112.1540000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68952, 'Pasiraman', 'Pasiraman', 'Pasiraman', -8.2437000, 112.1287000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68953, 'Sumberboto Satu', 'Sumberboto Satu', 'Sumberboto Satu', -8.2279000, 112.1474000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68954, 'Becirto', 'Becirto', 'Becirto', -8.2264800, 112.2418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68955, 'Kanigoro', 'Kanigoro', 'Kanigoro', -8.1300300, 112.2189600, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68956, 'Tumpang Satu', 'Tumpang Satu', 'Tumpang Satu', -8.0063500, 112.7608500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68957, 'Pandansari', 'Pandansari', 'Pandansari', -8.0699000, 112.8044000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68958, 'Karanganyar', 'Karanganyar', 'Karanganyar', -8.0658000, 112.7568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68959, 'Nongkosewu', 'Nongkosewu', 'Nongkosewu', -8.0461000, 112.7640000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68960, 'Wates', 'Wates', 'Wates', -8.0413000, 112.7677000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68961, 'Krajan', 'Krajan', 'Krajan', -8.0130000, 112.7696000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68962, 'Belung Satu', 'Belung Satu', 'Belung Satu', -8.0338000, 112.7692000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68963, 'Wonorejo', 'Wonorejo', 'Wonorejo', -8.0453000, 112.7812000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68964, 'Simpanganduwet', 'Simpanganduwet', 'Simpanganduwet', -8.0321000, 112.7975000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68965, 'Kedampul', 'Kedampul', 'Kedampul', -8.0097000, 112.8132000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68966, 'Krajan', 'Krajan', 'Krajan', -8.0189000, 112.8190000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68967, 'Gaplek', 'Gaplek', 'Gaplek', -8.1294000, 113.6275000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68968, 'Krajan', 'Krajan', 'Krajan', -8.1298000, 113.7416000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68969, 'Plalangan', 'Plalangan', 'Plalangan', -8.1359000, 113.7104000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68970, 'Jumerto', 'Jumerto', 'Jumerto', -8.1379000, 113.6881000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68971, 'Serut', 'Serut', 'Serut', -8.1523000, 113.6379000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68972, 'Sukorambi', 'Sukorambi', 'Sukorambi', -8.1571000, 113.6652000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68973, 'Krajan', 'Krajan', 'Krajan', -8.1531000, 113.6673000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68974, 'Kebonwaru Satu', 'Kebonwaru Satu', 'Kebonwaru Satu', -8.1532000, 113.6721000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68975, 'Puring Kulon', 'Puring Kulon', 'Puring Kulon', -8.1491900, 113.6902700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68976, 'Patrang', 'Patrang', 'Patrang', -8.1446000, 113.7196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68977, 'Tegalgede Kulon', 'Tegalgede Kulon', 'Tegalgede Kulon', -8.1545400, 113.7224900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68978, 'Krajan', 'Krajan', 'Krajan', -8.1585600, 113.7054800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68979, 'Dukuhmencek Lor', 'Dukuhmencek Lor', 'Dukuhmencek Lor', -8.1690000, 113.6489000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68980, 'Kaliwates', 'Kaliwates', 'Kaliwates', -8.1821000, 113.6712000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68981, 'Kepatihan', 'Kepatihan', 'Kepatihan', -8.1746000, 113.7025000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68982, 'Sumberketangi', 'Sumberketangi', 'Sumberketangi', -8.1868000, 113.7381000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68983, 'Kloncing', 'Kloncing', 'Kloncing', -8.1848000, 113.7270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68984, 'Telengsari', 'Telengsari', 'Telengsari', -8.1814000, 113.6917000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68985, 'Sumberdangdang', 'Sumberdangdang', 'Sumberdangdang', -8.1839000, 113.7036000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68986, 'Sumbersari Wetan', 'Sumbersari Wetan', 'Sumbersari Wetan', -8.1739900, 113.7182600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68987, 'Krajan', 'Krajan', 'Krajan', -8.1857000, 113.6648000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68988, 'Jubung', 'Jubung', 'Jubung', -8.1968000, 113.6374000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68989, 'Mangli', 'Mangli', 'Mangli', -8.1910000, 113.6516000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68990, 'Langsepan', 'Langsepan', 'Langsepan', -8.2078700, 113.7253700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68991, 'Muktisari', 'Muktisari', 'Muktisari', -8.2066000, 113.6966000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68992, 'Ajung', 'Ajung', 'Ajung', -8.2059000, 113.6560000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68993, 'Krasak', 'Krasak', 'Krasak', -8.2207000, 113.6558000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68994, 'Klompangan', 'Klompangan', 'Klompangan', -8.2340000, 113.6538000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68995, 'Renes', 'Renes', 'Renes', -8.2306000, 113.7017000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68996, 'Durenan', 'Durenan', 'Durenan', -8.2441000, 113.6536000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68997, 'Bedadung', 'Bedadung', 'Bedadung', -8.1326000, 113.7596000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68998, 'Ajung', 'Ajung', 'Ajung', -8.1335000, 113.8207000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(68999, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.1396000, 113.8330000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69000, 'Tlogowetan', 'Tlogowetan', 'Tlogowetan', -8.1465000, 113.7550000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69001, 'Karangsadang', 'Karangsadang', 'Karangsadang', -8.1432000, 113.7801000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69002, 'Gambiran Wetan', 'Gambiran Wetan', 'Gambiran Wetan', -8.1552900, 113.8085900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69003, 'Suren', 'Suren', 'Suren', -8.1661000, 113.8551000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69004, 'Sumberpinang Satu', 'Sumberpinang Satu', 'Sumberpinang Satu', -8.1732000, 113.8181000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69005, 'Pakusari', 'Pakusari', 'Pakusari', -8.1798000, 113.7766000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69006, 'Sumberkejayan', 'Sumberkejayan', 'Sumberkejayan', -8.1768700, 113.8336900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69007, 'Klayu Wetan', 'Klayu Wetan', 'Klayu Wetan', -8.1844000, 113.8014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69008, 'Kertosari', 'Kertosari', 'Kertosari', -8.1862000, 113.7619000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69009, 'Sidomukti', 'Sidomukti', 'Sidomukti', -8.2051000, 113.8279000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69010, 'Seputih', 'Seputih', 'Seputih', -8.2019000, 113.7841000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69011, 'Karangkedawung', 'Karangkedawung', 'Karangkedawung', -8.2142000, 113.7720000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69012, 'Sumberagung', 'Sumberagung', 'Sumberagung', -8.2409000, 113.7559400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69013, 'Mayang', 'Mayang', 'Mayang', -8.1762000, 113.7958000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69014, 'Sumberpinang', 'Sumberpinang', 'Sumberpinang', -8.1560000, 113.7672000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69015, 'Mulyorejo', 'Mulyorejo', 'Mulyorejo', -7.2628700, 112.7839200, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69016, 'Pacarkeling', 'Pacarkeling', 'Pacarkeling', -7.2580000, 112.7581000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69017, 'Gununganyar', 'Gununganyar', 'Gununganyar', -7.3409000, 112.7821000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69018, 'Prapen', 'Prapen', 'Prapen', -7.3145300, 112.7566700, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69019, 'Semarapura', 'Semarapura', 'Semarapura', -8.5346000, 115.4022000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69020, 'Dawan', 'Dawan', 'Dawan', -8.5408000, 115.4425000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69021, 'Semarapura', 'Semarapura', 'Semarapura', -8.5346000, 115.4022000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69022, 'Krajan', 'Krajan', 'Krajan', -8.3804600, 114.1110500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69023, 'Balokan', 'Balokan', 'Balokan', -8.3889800, 114.1198400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69024, 'Blokagung', 'Blokagung', 'Blokagung', -8.4398900, 114.1043100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69025, 'Barurejo', 'Barurejo', 'Barurejo', -8.4815000, 114.1142000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69026, 'Kluncing', 'Kluncing', 'Kluncing', -8.1896600, 114.2304900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69027, 'Krajan', 'Krajan', 'Krajan', -8.1973800, 114.2288700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69028, 'Plataran', 'Plataran', 'Plataran', -8.2204700, 114.1976500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69029, 'Songgon', 'Songgon', 'Songgon', -8.2351000, 114.2043800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69030, 'Songgon Krajan', 'Songgon Krajan', 'Songgon Krajan', -8.2373200, 114.2063200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69031, 'Sragikrajan', 'Sragikrajan', 'Sragikrajan', -8.2393800, 114.1700500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69032, 'Sumberagung', 'Sumberagung', 'Sumberagung', -8.2174600, 114.1726200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69033, 'Sumberarumkrajan', 'Sumberarumkrajan', 'Sumberarumkrajan', -8.2130400, 114.1563600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69034, 'Tirtopuro', 'Tirtopuro', 'Tirtopuro', -8.1805000, 114.3570000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69035, 'Krajanputuk', 'Krajanputuk', 'Krajanputuk', -8.1890000, 114.3365000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69036, 'Krajan', 'Krajan', 'Krajan', -8.1671000, 114.3325000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69037, 'Detik Satu', 'Detik Satu', 'Detik Satu', -8.1993000, 114.3233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69038, 'Krajan', 'Krajan', 'Krajan', -8.1959000, 114.2985000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69039, 'Krajan', 'Krajan', 'Krajan', -8.1928000, 114.2666000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69040, 'Krajan', 'Krajan', 'Krajan', -8.1735700, 114.2825400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69041, 'Krajan', 'Krajan', 'Krajan', -8.2067000, 114.2577000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69042, 'Krajan', 'Krajan', 'Krajan', -8.2057000, 114.2698000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69043, 'Krajan', 'Krajan', 'Krajan', -8.2152000, 114.2791000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69044, 'Krajan', 'Krajan', 'Krajan', -8.2234000, 114.2806000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69045, 'Krajan', 'Krajan', 'Krajan', -8.2221000, 114.3038000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69046, 'Krajan', 'Krajan', 'Krajan', -8.2184000, 114.3106000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69047, 'Olehsari', 'Olehsari', 'Olehsari', -8.2158000, 114.3193000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69048, 'Krajan', 'Krajan', 'Krajan', -8.2158000, 114.3223000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69049, 'Krajan', 'Krajan', 'Krajan', -8.2047000, 114.3205000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69050, 'Krajan', 'Krajan', 'Krajan', -8.2094000, 114.2980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69051, 'Krajan', 'Krajan', 'Krajan', -8.2296000, 114.3320000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69052, 'Gaplak', 'Gaplak', 'Gaplak', -8.2190000, 114.3469000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69053, 'Krajan', 'Krajan', 'Krajan', -8.2131000, 114.3407000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69054, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.2072000, 114.3563000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69055, 'Krajan', 'Krajan', 'Krajan', -8.1996000, 114.3582000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69056, 'Wirodayan', 'Wirodayan', 'Wirodayan', -8.2133000, 114.3701000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69057, 'Krajan', 'Krajan', 'Krajan', -8.2192000, 114.3710000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69058, 'Krajan Selatan', 'Krajan Selatan', 'Krajan Selatan', -8.2227000, 114.3703000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69059, 'Krajan', 'Krajan', 'Krajan', -8.2261000, 114.3745000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69060, 'Cungking', 'Cungking', 'Cungking', -8.2170000, 114.3543000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69061, 'Krajan', 'Krajan', 'Krajan', -8.2321000, 114.3614000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69062, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.2314000, 114.3591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69063, 'Krajan', 'Krajan', 'Krajan', -8.2432000, 114.3554000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69064, 'Kepuh Wetan', 'Kepuh Wetan', 'Kepuh Wetan', -8.2489000, 114.3569000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69065, 'Kertosari', 'Kertosari', 'Kertosari', -8.2396000, 114.3240000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69066, 'Krajan', 'Krajan', 'Krajan', -8.2039000, 114.3730000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69067, 'Banyuwangi', 'Banyuwangi', 'BWX,Banyuwangi', -8.2215000, 114.3646000, 'ID', '2014-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69068, 'Seririt', 'Seririt', 'Seririt,Серирит', -8.1928000, 114.9388000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69069, 'Dajanrurung', 'Dajanrurung', 'Dajanrurung', -8.2015000, 114.8899000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69070, 'Umbanyar', 'Umbanyar', 'Umbanyar', -8.1947000, 114.9181000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69071, 'Purwa', 'Purwa', 'Purwa', -8.1874000, 114.9293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69072, 'Tamansari', 'Tamansari', 'Tamansari', -8.1963000, 114.9445000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69073, 'Tangguwisia', 'Tangguwisia', 'Tangguwisia', -8.1976000, 114.9466000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69074, 'Kelodan', 'Kelodan', 'Kelodan', -8.2030000, 114.9535000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69075, 'Banjar Dawan', 'Banjar Dawan', 'Banjar Dawan', -8.2002000, 114.9591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69076, 'Ambian', 'Ambian', 'Ambian', -8.1999000, 114.9687000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69077, 'Tampekan', 'Tampekan', 'Tampekan', -8.2021000, 114.9734000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69078, 'Pegayaman', 'Pegayaman', 'Pegayaman', -8.1835500, 114.9869200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69079, 'Pangkungparuk', 'Pangkungparuk', 'Pangkungparuk', -8.2150000, 114.8869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69080, 'Yatnyaketi', 'Yatnyaketi', 'Yatnyaketi', -8.2371000, 114.9300000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69081, 'Kajanan', 'Kajanan', 'Kajanan', -8.2201000, 114.9407000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69082, 'Lebahseri', 'Lebahseri', 'Lebahseri', -8.2499000, 114.9306000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69083, 'Baleagung', 'Baleagung', 'Baleagung', -8.2492000, 114.9310000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69084, 'Kertanadi', 'Kertanadi', 'Kertanadi', -8.2340000, 114.9503000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69085, 'Bestala', 'Bestala', 'Bestala', -8.2460000, 114.9778000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69086, 'Banjarsari', 'Banjarsari', 'Banjarsari', -8.2449000, 114.9866000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69087, 'Dajanpura', 'Dajanpura', 'Dajanpura', -8.2177000, 114.9963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69088, 'Seririt', 'Seririt', 'Seririt', -8.1928000, 114.9388000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69089, 'Banjar Trunyan', 'Banjar Trunyan', 'Banjar Trunyan', -8.2524000, 115.4255000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69090, 'Banjar Kedisan', 'Banjar Kedisan', 'Banjar Kedisan', -8.2799000, 115.3809000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69091, 'Banjar Buahan', 'Banjar Buahan', 'Banjar Buahan', -8.2870000, 115.3900000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69092, 'Banjar Suter', 'Banjar Suter', 'Banjar Suter', -8.3073000, 115.3953000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69093, 'Banjar Bias', 'Banjar Bias', 'Banjar Bias', -8.3168700, 115.3961800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69094, 'Sengkerang Tiga', 'Sengkerang Tiga', 'Sengkerang Tiga', -8.7679000, 116.3735000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69095, 'Rangah', 'Rangah', 'Rangah', -8.7819000, 116.3511000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69096, 'Tamanbumigora', 'Tamanbumigora', 'Tamanbumigora', -8.7751000, 116.3070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69097, 'Ketara', 'Ketara', 'Ketara', -8.7890000, 116.2805000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69098, 'Pengembur Dua', 'Pengembur Dua', 'Pengembur Dua', -8.8073000, 116.2626000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69099, 'Tanakawu Dua', 'Tanakawu Dua', 'Tanakawu Dua', -8.7741000, 116.2678000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69100, 'Teruwai', 'Teruwai', 'Teruwai', -8.8124000, 116.3375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69101, 'Pagutan', 'Pagutan', 'Pagutan', -8.6275000, 116.2840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69102, 'Barabali', 'Barabali', 'Barabali', -8.6259000, 116.3091000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69103, 'Bodak', 'Bodak', 'Bodak', -8.6538000, 116.3102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69104, 'Montongbelok', 'Montongbelok', 'Montongbelok', -8.6312000, 116.3293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69105, 'Montonggamang', 'Montonggamang', 'Montonggamang', -8.6343000, 116.3714000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69106, 'Darmaji', 'Darmaji', 'Darmaji', -8.6719000, 116.3364000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69107, 'Barejulat', 'Barejulat', 'Barejulat', -8.6590000, 116.2519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69108, 'Semayan', 'Semayan', 'Semayan', -8.7191000, 116.2840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69109, 'Bagiktinggang', 'Bagiktinggang', 'Bagiktinggang', -8.7482000, 116.3038000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69110, 'Majan', 'Majan', 'Majan', -8.7300000, 116.3119000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69111, 'Beraim', 'Beraim', 'Beraim', -8.7068000, 116.3396000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69112, 'Praya', 'Praya', 'Praya', -8.7053600, 116.2703600, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69113, 'Kopang Satu', 'Kopang Satu', 'Kopang Satu', -8.6335000, 116.3517000, 'ID', '2010-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69114, 'Meringkik', 'Meringkik', 'Meringkik', -8.8165000, 116.5307000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69115, 'Sukamulia', 'Sukamulia', 'Sukamulia', -8.6286000, 116.5125000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69116, 'Gubuk Timuk', 'Gubuk Timuk', 'Gubuk Timuk', -8.6330000, 116.5035000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69117, 'Bongkemalik', 'Bongkemalik', 'Bongkemalik', -8.6306000, 116.5275000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69118, 'Muhajirin', 'Muhajirin', 'Muhajirin', -8.6455000, 116.5205000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69119, 'Peresak Barat', 'Peresak Barat', 'Peresak Barat', -8.6577000, 116.5519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69120, 'Denggen Daya', 'Denggen Daya', 'Denggen Daya', -8.6659000, 116.5103000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69121, 'Timba Timuk', 'Timba Timuk', 'Timba Timuk', -8.6648000, 116.5571000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69122, 'Bebae', 'Bebae', 'Bebae', -8.6898000, 116.5506000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69123, 'Gereneng', 'Gereneng', 'Gereneng', -8.6874000, 116.5118000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69124, 'Paoqpampang', 'Paoqpampang', 'Paoqpampang', -8.6966000, 116.5697000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69125, 'Lepak', 'Lepak', 'Lepak', -8.7048000, 116.5005000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69126, 'Timukpeken', 'Timukpeken', 'Timukpeken', -8.7217000, 116.5264000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69127, 'Mandikbatu', 'Mandikbatu', 'Mandikbatu', -8.7200000, 116.5050000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69128, 'Gubuk Daya', 'Gubuk Daya', 'Gubuk Daya', -8.5246000, 116.5734000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69129, 'Batubasong Lauk', 'Batubasong Lauk', 'Batubasong Lauk', -8.5276000, 116.5833000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69130, 'Montonggedeng', 'Montonggedeng', 'Montonggedeng', -8.5388000, 116.5917000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69131, 'Selaparang Timur', 'Selaparang Timur', 'Selaparang Timur', -8.5480000, 116.6012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69132, 'Dasanlian Lauk', 'Dasanlian Lauk', 'Dasanlian Lauk', -8.5514000, 116.5189000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69133, 'Kembangkerang Lauk Timur', 'Kembangkerang Lauk Timur', 'Kembangkerang Lauk Timur', -8.5583000, 116.5378000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69134, 'Jorong Lauk', 'Jorong Lauk', 'Jorong Lauk', -8.5666000, 116.5751000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69135, 'Aikmel', 'Aikmel', 'Aikmel', -8.5678000, 116.5305000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69136, 'Bagikkedok Lauk', 'Bagikkedok Lauk', 'Bagikkedok Lauk', -8.5720000, 116.6058000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69137, 'Gubuk Daya', 'Gubuk Daya', 'Gubuk Daya', -8.5693000, 116.6242000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69138, 'Karangranjong', 'Karangranjong', 'Karangranjong', -8.5817000, 116.5120000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69139, 'Gelumpang', 'Gelumpang', 'Gelumpang', -8.5964000, 116.5246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69140, 'Anjani Barat', 'Anjani Barat', 'Anjani Barat', -8.6038000, 116.5056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69141, 'Gubuk Leuk', 'Gubuk Leuk', 'Gubuk Leuk', -8.6182000, 116.6078000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69142, 'Tumbukebon', 'Tumbukebon', 'Tumbukebon', -8.4450000, 115.6243000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69143, 'Banjar Geriana Kangin', 'Banjar Geriana Kangin', 'Banjar Geriana Kangin', -8.4335000, 115.5012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69144, 'Banjar Wates Tengah', 'Banjar Wates Tengah', 'Banjar Wates Tengah', -8.4484000, 115.5011000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69145, 'Banjar Jungutan', 'Banjar Jungutan', 'Banjar Jungutan', -8.4335000, 115.5367000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69146, 'Banjar Tengah', 'Banjar Tengah', 'Banjar Tengah', -8.4458000, 115.5373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69147, 'Banjar Tengah', 'Banjar Tengah', 'Banjar Tengah', -8.4749000, 115.5375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69148, 'Banjar Kawan', 'Banjar Kawan', 'Banjar Kawan', -8.4889000, 115.5241000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69149, 'Banjar Kelodan', 'Banjar Kelodan', 'Banjar Kelodan', -8.4691000, 115.5491000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69150, 'Banjar Bau Kawan', 'Banjar Bau Kawan', 'Banjar Bau Kawan', -8.3803000, 115.5843000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69151, 'Banjar Ababi', 'Banjar Ababi', 'Banjar Ababi', -8.4056000, 115.5853000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69152, 'Banjar Budakeling', 'Banjar Budakeling', 'Banjar Budakeling', -8.4278000, 115.5718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69153, 'Banjar Beji', 'Banjar Beji', 'Banjar Beji', -8.4588000, 115.5813000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69154, 'Banjar Pegeringsingan', 'Banjar Pegeringsingan', 'Banjar Pegeringsingan', -8.4758000, 115.5671000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69155, 'Tistagede', 'Tistagede', 'Tistagede', -8.3792000, 115.6090000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69156, 'Abang', 'Abang', 'Abang', -8.3866000, 115.6013000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69157, 'Tiyingtali Kelod', 'Tiyingtali Kelod', 'Tiyingtali Kelod', -8.4103000, 115.6143000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69158, 'Banjar Danginsema', 'Banjar Danginsema', 'Banjar Danginsema', -8.4513000, 115.6162000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69159, 'Subagan', 'Subagan', 'Subagan', -8.4503000, 115.6065000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69160, 'Banjar Timbrah', 'Banjar Timbrah', 'Banjar Timbrah', -8.4774000, 115.5970000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69161, 'Alanga', 'Alanga', 'Alanga', -9.5386000, 119.7530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69162, 'Lokuuy', 'Lokuuy', 'Lokuuy', -9.5663000, 119.8145000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69163, 'Pahomba', 'Pahomba', 'Pahomba', -9.6239000, 119.7998000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69164, 'Lengkoajang', 'Lengkoajang', 'Lengkoajang', -8.5074000, 120.6790000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69165, 'Buti', 'Buti', 'Buti', -8.5015000, 120.7052000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69166, 'Ntaram', 'Ntaram', 'Ntaram', -8.5281000, 120.6937000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69167, 'Mombok', 'Mombok', 'Mombok', -8.5271000, 120.7293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69168, 'Watunggong', 'Watunggong', 'Watunggong', -8.5418000, 120.6733000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69169, 'Rantang', 'Rantang', 'Rantang', -8.5485000, 120.7419000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69170, 'Ngkolong', 'Ngkolong', 'Ngkolong', -8.5513000, 120.7163000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69171, 'Ngkodal', 'Ngkodal', 'Ngkodal', -8.5648000, 120.7180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69172, 'Ngkiong', 'Ngkiong', 'Ngkiong', -8.5675000, 120.6568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69173, 'Jawa', 'Jawa', 'Jawa', -8.5620000, 120.6371000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69174, 'Biting', 'Biting', 'Biting', -8.5966000, 120.6341000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69175, 'Pamakoe', 'Pamakoe', 'Pamakoe,Pomakoe', -8.7592000, 121.2501000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69176, 'Lena', 'Lena', 'Lena', -8.7613000, 121.3010000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69177, 'Bhokadoke', 'Bhokadoke', 'Bhokadoke', -8.8020000, 121.3118000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69178, 'Lokatadho', 'Lokatadho', 'Lokatadho', -8.8143000, 121.2744000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69179, 'Wolowada', 'Wolowada', 'Wolowada', -8.8555000, 121.2755000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69180, 'Pau', 'Pau', 'Pau', -8.8555000, 121.2993000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69181, 'Mbeku', 'Mbeku', 'Mbeku', -8.8667000, 121.2864000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69182, 'Boanio', 'Boanio', 'Boanio', -8.6373000, 121.3234000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69183, 'Doma', 'Doma', 'Doma', -8.6846000, 121.3278000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69184, 'Jawatiwa', 'Jawatiwa', 'Jawatiwa', -8.7073000, 121.2809000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69185, 'Aegela', 'Aegela', 'Aegela', -8.7323000, 121.3372000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69186, 'Tibakisa', 'Tibakisa', 'Tibakisa', -8.7393000, 121.3054000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69187, 'Pauhambar', 'Pauhambar', 'Pauhambar', -0.6553600, 100.2127900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69188, 'Lubukalung', 'Lubukalung', 'Lubukalung', -0.6862400, 100.2861300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69189, 'Sungaisarik', 'Sungaisarik', 'Sungaisarik', -0.5735800, 100.2246400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69190, 'Kampungladang', 'Kampungladang', 'Kampungladang', -0.5419200, 100.1704300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69191, 'Kotatua', 'Kotatua', 'Kotatua', -0.3451400, 100.3624100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69192, 'Guguk', 'Guguk', 'Guguk', -0.1389000, 100.5526000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69193, 'Salimpaung', 'Salimpaung', 'Salimpaung', -0.3523000, 100.5488400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69194, 'Sungayang', 'Sungayang', 'Sungayang', -0.4075600, 100.5971800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69195, 'Simabur', 'Simabur', 'Simabur', -0.4644800, 100.5281700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69196, 'Rambatan', 'Rambatan', 'Rambatan', -0.4921400, 100.5454400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69197, 'Gunung Talang', 'Gunung Talang', 'Gunung Talang', -0.9056600, 100.6270900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69198, 'Kumanis', 'Kumanis', 'Kumanis', -0.5497000, 100.8310000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69199, 'Tanjungampalu', 'Tanjungampalu', 'Tanjungampalu', -0.6386500, 100.8281000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69200, 'Kototujuh', 'Kototujuh', 'Kototujuh', -0.6361000, 100.8890000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69201, 'Sirukam', 'Sirukam', 'Sirukam', -0.8871100, 100.7595000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69202, 'Painan', 'Painan', 'Painan', -1.3517200, 100.5738300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69203, 'Tanjung Mas', 'Tanjung Mas', 'Tanjung Mas', -0.4970000, 100.7730000, 'ID', '2013-07-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69204, 'Nusa Dua', 'Nusa Dua', 'Nusa Dua,Нуса Дуа', -8.8004700, 115.2334100, 'ID', '2017-02-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69205, 'Legian', 'Legian', 'Legian,Легиан', -8.7041500, 115.1702800, 'ID', '2017-02-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69206, 'Boto', 'Boto', 'Boto', -7.0042000, 111.3893000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69207, 'Badong', 'Badong', 'Badong', -7.0044000, 111.4072000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69208, 'Nglego', 'Nglego', 'Nglego', -7.0013000, 111.4459000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69209, 'Nlorong', 'Nlorong', 'Nlorong', -7.0009000, 111.4625000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69210, 'Palon', 'Palon', 'Palon', -7.0063000, 111.4860000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69211, 'Klampok', 'Klampok', 'Klampok', -7.0006000, 111.4969000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69212, 'Ngampon', 'Ngampon', 'Ngampon', -7.0105000, 111.4292000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69213, 'Jepang Satu', 'Jepang Satu', 'Jepang Satu', -7.0142000, 111.4215000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69214, 'Ngablak', 'Ngablak', 'Ngablak', -7.0186000, 111.3868000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69215, 'Jomblang', 'Jomblang', 'Jomblang', -7.0184000, 111.4400000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69216, 'Klopoduwur', 'Klopoduwur', 'Klopoduwur', -7.0273000, 111.4090000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69217, 'Gumiring', 'Gumiring', 'Gumiring', -7.0357000, 111.3814000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69218, 'Jatiklampok', 'Jatiklampok', 'Jatiklampok', -7.0907000, 111.3964000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69219, 'Botoh', 'Botoh', 'Botoh', -7.0916000, 111.4717000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69220, 'Temanjang', 'Temanjang', 'Temanjang', -7.0931000, 111.3929000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69221, 'Galuk', 'Galuk', 'Galuk', -7.1097000, 111.4871000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69222, 'Banjar Meliling Kawan', 'Banjar Meliling Kawan', 'Banjar Meliling Kawan', -8.5092000, 115.0822000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69223, 'Kromot', 'Kromot', 'Kromot', -8.0430000, 113.3029000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69224, 'Sumbergebang', 'Sumbergebang', 'Sumbergebang', -8.0710000, 113.3245000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69225, 'Krajan', 'Krajan', 'Krajan', -8.0581000, 113.3651000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69226, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.0737000, 113.3341000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69227, 'Krajan', 'Krajan', 'Krajan', -8.0936000, 113.3697000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69228, 'Curahklapa', 'Curahklapa', 'Curahklapa', -8.0975000, 113.3194000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69229, 'Pondoktelo', 'Pondoktelo', 'Pondoktelo', -8.1054000, 113.2827000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69230, 'Banjar Delodrurung', 'Banjar Delodrurung', 'Banjar Delodrurung,Delodrurung', -8.5003000, 115.0188000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69231, 'Bajera', 'Bajera', 'Bajera', -8.5038000, 115.0258000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69232, 'Banjar Baleagung', 'Banjar Baleagung', 'Banjar Baleagung', -8.5066000, 115.0353000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69233, 'Banjar Bantasbaleagung', 'Banjar Bantasbaleagung', 'Banjar Bantasbaleagung', -8.5042000, 115.0689000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69234, 'Banjar Batuaji Kaja', 'Banjar Batuaji Kaja', 'Banjar Batuaji Kaja', -8.5132000, 115.1099000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69235, 'Banjar Sembunggede', 'Banjar Sembunggede', 'Banjar Sembunggede', -8.5090000, 115.0877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69236, 'Banjar Gablogan', 'Banjar Gablogan', 'Banjar Gablogan', -8.5107000, 115.0286000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69237, 'Banjar Mambanggede', 'Banjar Mambanggede', 'Banjar Mambanggede', -8.5246000, 115.0631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69238, 'Banjar Mandung', 'Banjar Mandung', 'Banjar Mandung', -8.5179000, 115.0919000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69239, 'Banjar Jambe Baleran', 'Banjar Jambe Baleran', 'Banjar Jambe Baleran', -8.5324000, 115.1246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69240, 'Banjar Tegalmengkeb Kaja', 'Banjar Tegalmengkeb Kaja', 'Banjar Tegalmengkeb Kaja', -8.5328000, 115.0338000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69241, 'Banjar Kebon', 'Banjar Kebon', 'Banjar Kebon', -8.5403000, 115.0526000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69242, 'Banjar Baturiti Kaja', 'Banjar Baturiti Kaja', 'Banjar Baturiti Kaja', -8.5408000, 115.0833000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69243, 'Banjar Penyalin', 'Banjar Penyalin', 'Banjar Penyalin', -8.5332000, 115.1085000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69244, 'Banjar Tegal Belodan', 'Banjar Tegal Belodan', 'Banjar Tegal Belodan', -8.5408000, 115.1191000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69245, 'Banjar Pangkungkarung Kangin', 'Banjar Pangkungkarung Kangin', 'Banjar Pangkungkarung Kangin', -8.5437000, 115.1036000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69246, 'Banjar Pekandelan', 'Banjar Pekandelan', 'Banjar Pekandelan', -8.5477000, 115.0798000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69247, 'Banjar Dauhpangkung', 'Banjar Dauhpangkung', 'Banjar Dauhpangkung', -8.5453000, 115.0752000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69248, 'Banjar Belumbang Tengah', 'Banjar Belumbang Tengah', 'Banjar Belumbang Tengah', -8.5488000, 115.0629000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69249, 'Banjar Beraban Kangin', 'Banjar Beraban Kangin', 'Banjar Beraban Kangin', -8.5569000, 115.0421000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69250, 'Banjar Tonja', 'Banjar Tonja', 'Banjar Tonja', -8.5518000, 115.1043000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69251, 'Banjar Bongangede', 'Banjar Bongangede', 'Banjar Bongangede', -8.5576000, 115.1196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69252, 'Banjar Tibubiyu Kaja', 'Banjar Tibubiyu Kaja', 'Banjar Tibubiyu Kaja', -8.5588000, 115.0498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69253, 'Banjar Dukuh', 'Banjar Dukuh', 'Banjar Dukuh', -8.5733000, 115.0623000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69254, 'Banjar Pejaten', 'Banjar Pejaten', 'Banjar Pejaten', -8.5759000, 115.1069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69255, 'Banjar Sengguan', 'Banjar Sengguan', 'Banjar Sengguan', -8.5802000, 115.1112000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69256, 'Banjar Bengkelgede', 'Banjar Bengkelgede', 'Banjar Bengkelgede', -8.5882000, 115.0943000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69257, 'Banjar Pangkungtibah Selatan', 'Banjar Pangkungtibah Selatan', 'Banjar Pangkungtibah Selatan', -8.5943000, 115.0906000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69258, 'Banjar Dauhrurung', 'Banjar Dauhrurung', 'Banjar Dauhrurung', -8.5954000, 115.0960000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69259, 'Banjar Delodsema', 'Banjar Delodsema', 'Banjar Delodsema,Delodsema', -8.5979000, 115.1233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69260, 'Banjar Batanbuah', 'Banjar Batanbuah', 'Banjar Batanbuah', -8.6026000, 115.1053000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69261, 'Banjar Batanyuh Kaja', 'Banjar Batanyuh Kaja', 'Banjar Batanyuh Kaja', -8.5080000, 115.1678000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69262, 'Banjar Sayanbaleran', 'Banjar Sayanbaleran', 'Banjar Sayanbaleran', -8.5060000, 115.1804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69263, 'Banjar Badung Tengah', 'Banjar Badung Tengah', 'Banjar Badung Tengah', -8.5067000, 115.1994000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69264, 'Banjar Teguan', 'Banjar Teguan', 'Banjar Teguan', -8.5067000, 115.2298000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69265, 'Banjar Tengahbelayu', 'Banjar Tengahbelayu', 'Banjar Tengahbelayu', -8.5140000, 115.1673000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69266, 'Banjar Subamiabaleagung', 'Banjar Subamiabaleagung', 'Banjar Subamiabaleagung', -8.5142000, 115.1271000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69267, 'Banjar Kertasari', 'Banjar Kertasari', 'Banjar Kertasari,Kerthasari', -8.6239000, 115.2095000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69268, 'Banjar Keraman', 'Banjar Keraman', 'Banjar Keraman', -8.5289000, 115.2114000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69269, 'Banjar Cemenggon', 'Banjar Cemenggon', 'Banjar Cemenggon', -8.5391000, 115.1995000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69270, 'Banjar Paangkelod', 'Banjar Paangkelod', 'Banjar Paangkelod', -8.6240000, 115.2414000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69271, 'Banjar Abiantuwung', 'Banjar Abiantuwung', 'Banjar Abiantuwung', -8.5575500, 115.1488600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69272, 'Banjar Jumbayah', 'Banjar Jumbayah', 'Banjar Jumbayah', -8.5651000, 115.1645000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69273, 'Banjar Sedang', 'Banjar Sedang', 'Banjar Sedang', -8.5707000, 115.2389000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69274, 'Banjar Desa', 'Banjar Desa', 'Banjar Desa', -8.5825000, 115.2404000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69275, 'Banjar Parekan', 'Banjar Parekan', 'Banjar Parekan', -8.5763000, 115.2164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69276, 'Banjar Pekenjelodan', 'Banjar Pekenjelodan', 'Banjar Pekenjelodan', -8.5752000, 115.1777000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69277, 'Banjar Danginpangkung', 'Banjar Danginpangkung', 'Banjar Danginpangkung', -8.5754000, 115.1645000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69278, 'Banjar Mundeh', 'Banjar Mundeh', 'Banjar Mundeh', -8.5803000, 115.1392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69279, 'Banjar Laing', 'Banjar Laing', 'Banjar Laing', -8.5793000, 115.1334000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69280, 'Banjar Dauh Peken', 'Banjar Dauh Peken', 'Banjar Dauh Peken', -8.5909000, 115.1427000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69281, 'Banjar Bucu', 'Banjar Bucu', 'Banjar Bucu', -8.5863400, 115.2046800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69282, 'Banjar Jabejero', 'Banjar Jabejero', 'Banjar Jabejero', -8.5988000, 115.2401000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69283, 'Banjar Lalangpasek', 'Banjar Lalangpasek', 'Banjar Lalangpasek', -8.5985000, 115.1455000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69284, 'Banjar Karangsuling', 'Banjar Karangsuling', 'Banjar Karangsuling', -8.5998000, 115.1952000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69285, 'Banjar Kayangan', 'Banjar Kayangan', 'Banjar Kayangan,Kayangan', -8.6227000, 115.2295000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69286, 'Banjar Gunungpande', 'Banjar Gunungpande', 'Banjar Gunungpande', -8.6160000, 115.1448000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69287, 'Banjar Kerobokan', 'Banjar Kerobokan', 'Banjar Kerobokan', -8.6185000, 115.1276000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69288, 'Banjar Kembangsari', 'Banjar Kembangsari', 'Banjar Kembangsari', -8.5096000, 115.2110000, 'ID', '2010-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69289, 'Banjar Tebongkang', 'Banjar Tebongkang', 'Banjar Tebongkang', -8.5290000, 115.2436700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69290, 'Banjar Serangan', 'Banjar Serangan', 'Banjar Serangan', -8.5432000, 115.1708000, 'ID', '2010-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69291, 'Banjar Jagasatru', 'Banjar Jagasatru', 'Banjar Jagasatru', -8.5611000, 115.1391000, 'ID', '2010-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69292, 'Karanglo', 'Karanglo', 'Karanglo', -8.3847000, 114.2778000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69293, 'Sumbersewu', 'Sumbersewu', 'Sumbersewu', -8.4016000, 114.3270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69294, 'Kumendung Satu', 'Kumendung Satu', 'Kumendung Satu', -8.3833000, 114.3327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69295, 'Rejoagung Satu', 'Rejoagung Satu', 'Rejoagung Satu', -8.3781000, 114.3102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69296, 'Curahpacul Satu', 'Curahpacul Satu', 'Curahpacul Satu', -8.4572000, 114.2901000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69297, 'Kedungwringin Satu', 'Kedungwringin Satu', 'Kedungwringin Satu', -8.4537000, 114.3345000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69298, 'Wringinputih', 'Wringinputih', 'Wringinputih', -8.4765000, 114.3343000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69299, 'Sumberberas', 'Sumberberas', 'Sumberberas', -8.4759000, 114.3186000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69300, 'Kedungsumur', 'Kedungsumur', 'Kedungsumur', -8.4982000, 114.3195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69301, 'Wringinanom Satu', 'Wringinanom Satu', 'Wringinanom Satu', -8.4889000, 114.2880000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69302, 'Siderejo', 'Siderejo', 'Siderejo', -8.4910000, 114.2577000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69303, 'Rumping', 'Rumping', 'Rumping', -8.4714000, 114.2751000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69304, 'Kedungrejo', 'Kedungrejo', 'Kedungrejo', -8.4399000, 114.3205000, 'ID', '2010-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69305, 'Denuma', 'Denuma', 'Denuma', -8.4155000, 115.1223000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69306, 'Riang Tengah', 'Riang Tengah', 'Riang Tengah', -8.4932000, 115.1238000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69307, 'Megati Kelod', 'Megati Kelod', 'Megati Kelod', -8.4978000, 115.0562000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69308, 'Angkahgede', 'Angkahgede', 'Angkahgede', -8.4635000, 115.0159000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69309, 'Laleng', 'Laleng', 'Laleng', -8.4483000, 115.0467000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69310, 'Wanagiri', 'Wanagiri', 'Wanagiri', -8.4100000, 115.0556000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69311, 'Dalangdesa', 'Dalangdesa', 'Dalangdesa', -8.4401000, 115.0807000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69312, 'Apityeh', 'Apityeh', 'Apityeh', -8.4525000, 115.0714000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69313, 'Carik', 'Carik', 'Carik', -8.4834000, 115.0769000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69314, 'Delodpeken', 'Delodpeken', 'Delodpeken', -8.4923000, 115.0907000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69315, 'Wongaya Kaja', 'Wongaya Kaja', 'Wongaya Kaja', -8.3904000, 115.1112000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69316, 'Rejasa Kaja', 'Rejasa Kaja', 'Rejasa Kaja', -8.4609000, 115.1173000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69317, 'Kesiutkawan Kaja', 'Kesiutkawan Kaja', 'Kesiutkawan Kaja', -8.4801000, 115.1088000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69318, 'Selemadeg Kelod', 'Selemadeg Kelod', 'Selemadeg Kelod', -8.4960000, 115.0410000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69319, 'Cungapmimbo', 'Cungapmimbo', 'Cungapmimbo', -7.7794000, 114.2878000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69320, 'Jorowaru Daya', 'Jorowaru Daya', 'Jorowaru Daya', -8.7872000, 116.4814000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69321, 'Pemongkong', 'Pemongkong', 'Pemongkong', -8.8447000, 116.4820000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69322, 'Ganti Dua', 'Ganti Dua', 'Ganti Dua', -8.7692000, 116.3953000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69323, 'Batugulung', 'Batugulung', 'Batugulung', -8.7956000, 116.3916000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69324, 'Sagikmateng', 'Sagikmateng', 'Sagikmateng', -8.8279000, 116.4079000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69325, 'Penimbung Barat', 'Penimbung Barat', 'Penimbung Barat', -8.5475000, 116.1352000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69326, 'Mambalan', 'Mambalan', 'Mambalan', -8.5495000, 116.1281000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69327, 'Dasangeria Selatan', 'Dasangeria Selatan', 'Dasangeria Selatan', -8.5561000, 116.1480000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69328, 'Dumandesa', 'Dumandesa', 'Dumandesa', -8.5643000, 116.1492000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69329, 'Kekeri', 'Kekeri', 'Kekeri', -8.5570000, 116.1278000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69330, 'Sayang Lauq', 'Sayang Lauq', 'Sayang Lauq', -8.5694000, 116.1325000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69331, 'Selagalas', 'Selagalas', 'Selagalas', -8.5811000, 116.1436000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69332, 'Sindu', 'Sindu', 'Sindu', -8.5832000, 116.1351000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69333, 'Karangkecicang', 'Karangkecicang', 'Karangkecicang', -8.5954700, 116.1312800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69334, 'Karangparwa', 'Karangparwa', 'Karangparwa', -8.6034000, 116.1271000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69335, 'Babakan Barat', 'Babakan Barat', 'Babakan Barat', -8.6021800, 116.1371000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69336, 'Jejelok', 'Jejelok', 'Jejelok', -8.6120500, 116.1656700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69337, 'Tanaktepong', 'Tanaktepong', 'Tanaktepong', -8.5957000, 116.2112000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69338, 'Batukuta', 'Batukuta', 'Batukuta', -8.6026900, 116.1996600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69339, 'Selat', 'Selat', 'Selat', -8.5816000, 116.2101000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69340, 'Lingsar', 'Lingsar', 'Lingsar', -8.5729000, 116.1824000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69341, 'Tanakbeak Daye', 'Tanakbeak Daye', 'Tanakbeak Daye', -8.6068000, 116.2028000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69342, 'Sintung Timur', 'Sintung Timur', 'Sintung Timur', -8.6098800, 116.2222200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69343, 'Sesaot Lauq', 'Sesaot Lauq', 'Sesaot Lauq', -8.5408000, 116.2448000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69344, 'Bengkel Utara', 'Bengkel Utara', 'Bengkel Utara', -8.6159000, 116.1482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69345, 'Karangsubagan', 'Karangsubagan', 'Karangsubagan', -8.4067000, 116.1019000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69346, 'Redakodi', 'Redakodi', 'Redakodi', -9.4542000, 119.2271000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69347, 'Maredakamau', 'Maredakamau', 'Maredakamau', -9.4350000, 119.1866000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69348, 'Tambolaka', 'Tambolaka', 'TMC,Tambolaka', -9.4283000, 119.2380000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69349, 'Radamata', 'Radamata', 'Radamata', -9.4258000, 119.2446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69350, 'Nangapanda', 'Nangapanda', 'Nangapanda', -8.7928000, 121.4691000, 'ID', '2010-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69351, 'Wakaseko', 'Wakaseko', 'Wakaseko', -8.6376000, 121.4704000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69352, 'Kamubheka', 'Kamubheka', 'Kamubheka', -8.6632000, 121.4888000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69353, 'Oja', 'Oja', 'Oja', -8.6920000, 121.4325000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69354, 'Puukau', 'Puukau', 'Puukau', -8.7249000, 121.4293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69355, 'Kuekobo', 'Kuekobo', 'Kuekobo', -8.7158000, 121.3926000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69356, 'Arwea', 'Arwea', 'Arwea', -8.7378000, 121.4867000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69357, 'Lando', 'Lando', 'Lando', -8.4967000, 120.0790000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69358, 'Pau', 'Pau', 'Pau', -8.4402000, 120.1931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69359, 'Sasa', 'Sasa', 'Sasa', -8.4388000, 120.1809000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69360, 'Kembo', 'Kembo', 'Kembo', -8.3971000, 120.8808000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69361, 'Mbarungkeli', 'Mbarungkeli', 'Mbarungkeli', -8.4052000, 120.9965000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69362, 'Wate', 'Wate', 'Wate', -8.4988000, 120.9599000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69363, 'Kombandaru', 'Kombandaru', 'Kombandaru', -8.7869000, 121.6033000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69364, 'Puubheto', 'Puubheto', 'Puubheto', -8.7918000, 121.5904000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69365, 'Maunggora', 'Maunggora', 'Maunggora', -8.8043000, 121.5146000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69366, 'Baraiwena', 'Baraiwena', 'Baraiwena', -8.8204000, 121.6041000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69367, 'Mbomba', 'Mbomba', 'Mbomba', -8.8283000, 121.6201000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69368, 'Puutura', 'Puutura', 'Puutura', -8.8644000, 121.5214000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69369, 'Roa', 'Roa', 'Roa', -8.7568000, 121.7183000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69370, 'Kengga', 'Kengga', 'Kengga', -8.7596000, 121.7138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69371, 'Aefeo', 'Aefeo', 'Aefeo', -8.7633000, 121.6739000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69372, 'Saga', 'Saga', 'Saga', -8.7694000, 121.7349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69373, 'Detumbawa', 'Detumbawa', 'Detumbawa', -8.7860000, 121.6722000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69374, 'Puuperi', 'Puuperi', 'Puuperi', -8.7945000, 121.6482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69375, 'Nuasepu', 'Nuasepu', 'Nuasepu', -8.7955000, 121.6347000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69376, 'Puutuga', 'Puutuga', 'Puutuga', -8.8026000, 121.7230000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69377, 'Aemura', 'Aemura', 'Aemura', -8.8087000, 121.6685000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69378, 'Lokoboko', 'Lokoboko', 'Lokoboko', -8.8195000, 121.6804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69379, 'Nuakota', 'Nuakota', 'Nuakota', -8.8294000, 121.6974000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69380, 'Ndona', 'Ndona', 'Ndona', -8.8338000, 121.6862000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69381, 'Wolowona', 'Wolowona', 'Wolowona', -8.8322000, 121.6765000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69382, 'Wolonio', 'Wolonio', 'Wolonio', -8.8265000, 121.6428000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69383, 'Onewitu', 'Onewitu', 'Onewitu', -8.8397000, 121.6449000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69384, 'Onekore', 'Onekore', 'Onekore', -8.8366000, 121.6518000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69385, 'Mautapaga Bawah', 'Mautapaga Bawah', 'Mautapaga Bawah', -8.8450000, 121.6718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69386, 'Potulando', 'Potulando', 'Potulando', -8.8469000, 121.6521000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69387, 'Mbongawani', 'Mbongawani', 'Mbongawani', -8.8467000, 121.6447000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69388, 'Rukunlima Bawah', 'Rukunlima Bawah', 'Rukunlima Bawah', -8.8512000, 121.6439000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69389, 'Paupanda Bawah', 'Paupanda Bawah', 'Paupanda Bawah', -8.8559000, 121.6432000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69390, 'Tetandara', 'Tetandara', 'Tetandara', -8.8526000, 121.6580000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69391, 'Ngalupolo', 'Ngalupolo', 'Ngalupolo', -8.8716000, 121.7352000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69392, 'Detuwane', 'Detuwane', 'Detuwane', -8.5137000, 121.7930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69393, 'Jalasenga', 'Jalasenga', 'Jalasenga', -8.5302000, 121.8051000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69394, 'Maurole', 'Maurole', 'Maurole', -8.5110000, 121.8023000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69395, 'Nggesa', 'Nggesa', 'Nggesa', -8.6028000, 121.8186000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69396, 'Kanganara', 'Kanganara', 'Kanganara', -8.6237000, 121.8411000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69397, 'Nuamuri', 'Nuamuri', 'Nuamuri', -8.5871000, 121.8612000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69398, 'Lendangtampel Daya', 'Lendangtampel Daya', 'Lendangtampel Daya', -8.6128000, 116.2875000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69399, 'Kembangkerang Satu', 'Kembangkerang Satu', 'Kembangkerang Satu', -8.5972000, 116.2981000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69400, 'Mantang', 'Mantang', 'Mantang', -8.6155000, 116.3137000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69401, 'Selebung Satu', 'Selebung Satu', 'Selebung Satu', -8.6024000, 116.3230000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69402, 'Pediti', 'Pediti', 'Pediti', -8.5878000, 116.3298000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69403, 'Lilin Satu', 'Lilin Satu', 'Lilin Satu', -8.6193000, 116.3645000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69404, 'Lendangara Satu', 'Lendangara Satu', 'Lendangara Satu', -8.6090000, 116.3722000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69405, 'Peseng', 'Peseng', 'Peseng', -8.5800000, 116.3740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69406, 'Purut', 'Purut', 'Purut', -8.2337000, 113.1087000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69407, 'Krajanpagowan', 'Krajanpagowan', 'Krajanpagowan', -8.1297000, 113.1213000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69408, 'Krajankertosari', 'Krajankertosari', 'Krajankertosari', -8.1365000, 113.0772000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69409, 'Tambahrejo Krajan', 'Tambahrejo Krajan', 'Tambahrejo Krajan', -8.1487000, 113.0674000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69410, 'Kloposawit Krajan', 'Kloposawit Krajan', 'Kloposawit Krajan', -8.1532000, 113.0820000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69411, 'Besuk Selatan', 'Besuk Selatan', 'Besuk Selatan', -8.1539000, 113.1148000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69412, 'Sumberrejo', 'Sumberrejo', 'Sumberrejo', -8.1868000, 113.0718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69413, 'Krajanjugosari', 'Krajanjugosari', 'Krajanjugosari', -8.2219000, 113.0597000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69414, 'Sumberkardi', 'Sumberkardi', 'Sumberkardi', -8.2287000, 113.1027000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69415, 'Jambesari', 'Jambesari', 'Jambesari', -8.0161000, 113.3840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69416, 'Gelang', 'Gelang', 'Gelang', -8.0900000, 113.4075000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69417, 'Karangbayat', 'Karangbayat', 'Karangbayat', -8.1040000, 113.4200000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69418, 'Pringgowirawan', 'Pringgowirawan', 'Pringgowirawan', -8.1233000, 113.4129000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69419, 'Boreng', 'Boreng', 'Boreng', -8.1288000, 113.2601000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69420, 'Blukon', 'Blukon', 'Blukon', -8.1378000, 113.2702000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69421, 'Sukosari', 'Sukosari', 'Sukosari', -8.1277000, 113.3290000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69422, 'Krajan Kidul Rojopolo', 'Krajan Kidul Rojopolo', 'Krajan Kidul,Krajan Kidul Rojopolo', -8.1356000, 113.3257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69423, 'Krajan Dua Dawuan Wetan', 'Krajan Dua Dawuan Wetan', 'Krajan Dua,Krajan Dua Dawuan Wetan', -8.1495000, 113.2778000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69424, 'Denok', 'Denok', 'Denok', -8.1497000, 113.2597000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69425, 'Pandansari', 'Pandansari', 'Pandansari', -8.1503000, 113.2509000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69426, 'Krajan Wonokerto', 'Krajan Wonokerto', 'Krajan,Krajan Wonokerto', -8.1603000, 113.2595000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69427, 'Krajan Tekung', 'Krajan Tekung', 'Krajan,Krajan Tekung', -8.1762000, 113.2838000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69428, 'Tegalsari', 'Tegalsari', 'Tegalsari', -8.1863000, 113.2865000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69429, 'Darunban', 'Darunban', 'Darunban', -8.1934000, 113.2618000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69430, 'Pondokrejo', 'Pondokrejo', 'Pondokrejo', -8.2072000, 113.3097000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69431, 'Rowokangkung', 'Rowokangkung', 'Rowokangkung', -8.1945000, 113.3297000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69432, 'Krajan Rowokangkung', 'Krajan Rowokangkung', 'Krajan,Krajan Rowokangkung', -8.1942000, 113.3338000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69433, 'Tulusmulyo', 'Tulusmulyo', 'Tulusmulyo', -8.2211000, 113.2577000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69434, 'Gogosan', 'Gogosan', 'Gogosan', -8.2270000, 113.2518000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69435, 'Karangsari', 'Karangsari', 'Karangsari', -8.2272000, 113.2620000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69436, 'Darungan', 'Darungan', 'Darungan', -8.2490000, 113.2559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69437, 'Krajan Krai', 'Krajan Krai', 'Krajan,Krajan Krai', -8.2397000, 113.2745000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69438, 'Jombang', 'Jombang', 'Jombang', -8.2329000, 113.3026000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69439, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.2461000, 113.3138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69440, 'Krajan Dua Padomasan', 'Krajan Dua Padomasan', 'Krajan Dua,Krajan Dua Padomasan', -8.2306000, 113.3192000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69441, 'Sebaren', 'Sebaren', 'Sebaren', -8.2371000, 113.3493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69442, 'Slateng Dua', 'Slateng Dua', 'Slateng Dua', -8.1119500, 113.8916900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69443, 'Sumberkenanga', 'Sumberkenanga', 'Sumberkenanga', -8.0028000, 113.8914000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69444, 'Sukowono', 'Sukowono', 'Sukowono', -8.0105000, 113.9158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69445, 'Pringgodani', 'Pringgodani', 'Pringgodani', -8.0311000, 113.8981000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69446, 'Jambearum', 'Jambearum', 'Jambearum', -8.0493000, 113.9239000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69447, 'Rowosari', 'Rowosari', 'Rowosari', -8.0740000, 113.9270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69448, 'Karangsumber', 'Karangsumber', 'Karangsumber', -8.0843000, 113.8758000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69449, 'Gunungmalang Satu', 'Gunungmalang Satu', 'Gunungmalang Satu', -8.0966000, 113.9015000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69450, 'Banjar Pasekan', 'Banjar Pasekan', 'Banjar Pasekan', -8.6329000, 115.2840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69451, 'Banjar Kertajiwa', 'Banjar Kertajiwa', 'Banjar Kertajiwa', -8.6402000, 115.2618000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69452, 'Banjar Batanpoh', 'Banjar Batanpoh', 'Banjar Batanpoh', -8.6761000, 115.2579000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69453, 'Banjar Taman', 'Banjar Taman', 'Banjar Taman', -8.6818000, 115.2564000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69454, 'Banjar Medura', 'Banjar Medura', 'Banjar Medura', -8.6926000, 115.2533000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69455, 'Banjar Cempaga', 'Banjar Cempaga', 'Banjar Cempaga', -8.2217000, 115.0103000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69456, 'Banjar Tamansari', 'Banjar Tamansari', 'Banjar Tamansari', -8.2456000, 115.0017000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69457, 'Banjar Bunutpanggang', 'Banjar Bunutpanggang', 'Banjar Bunutpanggang', -8.1655600, 115.0194300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69458, 'Banjar Dauhpura', 'Banjar Dauhpura', 'Banjar Dauhpura', -8.2019000, 115.0232000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69459, 'Banjar Pedawa', 'Banjar Pedawa', 'Banjar Pedawa', -8.2367000, 115.0258000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69460, 'Banjar Banyualit', 'Banjar Banyualit', 'Banjar Banyualit', -8.1584000, 115.0386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69461, 'Banjar Kayuputih', 'Banjar Kayuputih', 'Banjar Kayuputih', -8.1833000, 115.0418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69462, 'Banjar Dauhmargi', 'Banjar Dauhmargi', 'Banjar Dauhmargi', -8.1367000, 115.0653000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69463, 'Banjar Dharmasemedi', 'Banjar Dharmasemedi', 'Banjar Dharmasemedi', -8.1462000, 115.0596000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69464, 'Banjar Anyar', 'Banjar Anyar', 'Banjar Anyar', -8.1510000, 115.0552000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69465, 'Banjar Tegallinggah', 'Banjar Tegallinggah', 'Banjar Tegallinggah', -8.1560000, 115.0710000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69466, 'Banjar Galiran', 'Banjar Galiran', 'Banjar Galiran', -8.1295000, 115.0738000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69467, 'Banjar Selat', 'Banjar Selat', 'Banjar Selat', -8.1757000, 115.0662000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69468, 'Banjar Tegalsari', 'Banjar Tegalsari', 'Banjar Tegalsari', -8.1256000, 115.0926000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69469, 'Banjar Liligundi', 'Banjar Liligundi', 'Banjar Liligundi', -8.1276000, 115.0984300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69470, 'Banjar Sambangan', 'Banjar Sambangan', 'Banjar Sambangan', -8.1461000, 115.0968000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69471, 'Banjar Dauhpura', 'Banjar Dauhpura', 'Banjar Dauhpura', -8.1485000, 115.0862000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69472, 'Banjar Beratan', 'Banjar Beratan', 'Banjar Beratan', -8.1321000, 115.0993000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69473, 'Banjar Pondok', 'Banjar Pondok', 'Banjar Pondok', -8.1400000, 115.1246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69474, 'Banjar Padangbulia', 'Banjar Padangbulia', 'Banjar Padangbulia', -8.1584000, 115.1246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69475, 'Meraran', 'Meraran', 'Meraran', -8.6882000, 116.8493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69476, 'Seteluk Tengah', 'Seteluk Tengah', 'Seteluk Tengah', -8.6263000, 116.8641000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69477, 'Seteluk Atas', 'Seteluk Atas', 'Seteluk Atas', -8.6282000, 116.8695000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69478, 'Rempe', 'Rempe', 'Rempe', -8.6472000, 116.8663000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69479, 'Airsuning', 'Airsuning', 'Airsuning', -8.6508000, 116.8547000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69480, 'Bugis', 'Bugis', 'Bugis', -8.7422000, 116.8420000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69481, 'Motong', 'Motong', 'Motong', -8.7433000, 116.8532000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69482, 'Dalam', 'Dalam', 'Dalam', -8.7417000, 116.8486000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69483, 'Sampir', 'Sampir', 'Sampir', -8.7420000, 116.8564000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69484, 'Juranalas', 'Juranalas', 'Juranalas', -8.5229600, 116.9972800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69485, 'Mapinkebak', 'Mapinkebak', 'Mapinkebak', -8.5496000, 116.9417000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69486, 'Mapinrea', 'Mapinrea', 'Mapinrea', -8.5596000, 116.9463000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69487, 'Luar', 'Luar', 'Luar', -8.5190000, 116.9933000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69488, 'Dalam', 'Dalam', 'Dalam', -8.5155000, 116.9953000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69489, 'Baru', 'Baru', 'Baru', -8.5229000, 116.9928000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69490, 'Kalimango', 'Kalimango', 'Kalimango', -8.5221200, 116.9954000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69491, 'Batutering', 'Batutering', 'Batutering', -8.6664000, 117.4795000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69492, 'Sebasang', 'Sebasang', 'Sebasang', -8.6502000, 117.4461000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69493, 'Mronjo', 'Mronjo', 'Mronjo', -8.1282000, 112.2817000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69494, 'Siraman', 'Siraman', 'Siraman', -8.1430000, 112.3361000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69495, 'Jabung', 'Jabung', 'Jabung', -8.1343000, 112.2646000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69496, 'Mandesan', 'Mandesan', 'Mandesan', -8.1476000, 112.2935000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69497, 'Kaulon', 'Kaulon', 'Kaulon', -8.1605000, 112.2811000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69498, 'Ngembul', 'Ngembul', 'Ngembul', -8.1739000, 112.3320000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69499, 'Umbuldamar', 'Umbuldamar', 'Umbuldamar', -8.1796000, 112.3563000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69500, 'Ngadri', 'Ngadri', 'Ngadri', -8.1812000, 112.3622000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69501, 'Rampalombo', 'Rampalombo', 'Rampalombo', -8.1985000, 112.2651000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69502, 'Rejoso', 'Rejoso', 'Rejoso', -8.1971000, 112.3357000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69503, 'Sambigede', 'Sambigede', 'Sambigede', -8.2051000, 112.3427000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69504, 'Panggungasri', 'Panggungasri', 'Panggungasri', -8.2099000, 112.2963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69505, 'Birowo', 'Birowo', 'Birowo', -8.2226000, 112.3661000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69506, 'Salamrejo', 'Salamrejo', 'Salamrejo', -8.2254000, 112.3147000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69507, 'Panggungwinong', 'Panggungwinong', 'Panggungwinong', -8.2394000, 112.2878000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69508, 'Sumberarum', 'Sumberarum', 'Sumberarum', -8.2490000, 112.3393000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69509, 'Balong Wetan', 'Balong Wetan', 'Balong Wetan', -7.0006000, 111.2610000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69510, 'Pecaren', 'Pecaren', 'Pecaren', -7.0070000, 111.3002000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69511, 'Pruntusan', 'Pruntusan', 'Pruntusan', -7.0044000, 111.3467000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69512, 'Sembungin', 'Sembungin', 'Sembongin,Sembungin', -7.0002100, 111.3681600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69513, 'Balongrejo', 'Balongrejo', 'Balongrejo', -7.0094000, 111.3712000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69514, 'Gondang', 'Gondang', 'Gondang', -7.0109000, 111.3189000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69515, 'Punggursugih', 'Punggursugih', 'Punggursugih', -7.0135000, 111.3107000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69516, 'Ketanggi', 'Ketanggi', 'Ketanggi', -7.0156000, 111.3162000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69517, 'Karangtalun', 'Karangtalun', 'Karangtalun', -7.0202000, 111.3514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69518, 'Mojo Wetan', 'Mojo Wetan', 'Mojo Wetan', -7.0308000, 111.3679000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69519, 'Talok', 'Talok', 'Talok', -7.0293000, 111.3048000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69520, 'Jetak', 'Jetak', 'Jetak', -7.0320000, 111.2638000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69521, 'Jepang', 'Jepang', 'Jepang', -7.0240000, 111.2572000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69522, 'Karangtengah', 'Karangtengah', 'Karangtengah', -7.0398000, 111.3171000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69523, 'Gapuk', 'Gapuk', 'Gapuk', -7.0328000, 111.3335000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69524, 'Sendanggayam', 'Sendanggayam', 'Sendanggayam', -7.0415000, 111.3452000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69525, 'Bacem', 'Bacem', 'Bacem', -7.0468000, 111.3559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69526, 'Sambirejo', 'Sambirejo', 'Sambirejo', -7.0455000, 111.3391000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69527, 'Gesik', 'Gesik', 'Gesik', -7.0464000, 111.3336000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69528, 'Muraharjo', 'Muraharjo', 'Muraharjo', -7.0456000, 111.2657000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69529, 'Jagong', 'Jagong', 'Jagong', -7.0481000, 111.2534000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69530, 'Plumbon', 'Plumbon', 'Plumbon', -7.0534000, 111.2919000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69531, 'Kendayakan', 'Kendayakan', 'Kendayakan', -7.0530000, 111.3096000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69532, 'Pipes', 'Pipes', 'Pipes', -7.0646000, 111.2848000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69533, 'Jatiarum', 'Jatiarum', 'Jatiarum', -8.2440000, 113.2217000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69534, 'Purwosari', 'Purwosari', 'Purwosari', -8.1293000, 113.1483000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69535, 'Perjuangan', 'Perjuangan', 'Perjuangan', -8.1379000, 113.1822000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69536, 'Laban', 'Laban', 'Laban', -8.1418000, 113.2037000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69537, 'Kadipaten', 'Kadipaten', 'Kadipaten', -8.1357000, 113.2158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69538, 'Gedongsari', 'Gedongsari', 'Gedongsari', -8.1488000, 113.1990000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69539, 'Pandanwangi', 'Pandanwangi', 'Pandanwangi', -8.1508000, 113.2484000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69540, 'Sarirejo Satu', 'Sarirejo Satu', 'Sarirejo Satu', -8.1565000, 113.1991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69541, 'Grati Satu', 'Grati Satu', 'Grati Satu', -8.1531000, 113.2176000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69542, 'Suko Dua', 'Suko Dua', 'Suko Dua', -8.1680000, 113.1871000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69543, 'Besukan', 'Besukan', 'Besukan', -8.1696000, 113.2377000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69544, 'Krajan Satu', 'Krajan Satu', 'Krajan Satu', -8.1812000, 113.1486000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69545, 'Bedok Dua', 'Bedok Dua', 'Bedok Dua', -8.1874000, 113.1793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69546, 'Sumberbendo', 'Sumberbendo', 'Sumberbendo', -8.1871000, 113.2154000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69547, 'Besukrejo', 'Besukrejo', 'Besukrejo', -8.1858000, 113.2393000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69548, 'Recobanteng', 'Recobanteng', 'Recobanteng', -8.1986200, 113.2169600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69549, 'Dompyong', 'Dompyong', 'Dompyong', -8.2165000, 113.1426000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69550, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.2109800, 113.1702000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69551, 'Krajan Tengah', 'Krajan Tengah', 'Krajan Tengah', -8.2142000, 113.1954000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69552, 'Kebonan', 'Kebonan', 'Kebonan', -8.2162000, 113.2283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69553, 'Mujur Satu', 'Mujur Satu', 'Mujur Satu', -8.2191300, 113.1629900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69554, 'Mentosari', 'Mentosari', 'Mentosari', -8.2202000, 113.2121000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69555, 'Ketangi', 'Ketangi', 'Ketangi', -8.2233000, 113.2211000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69556, 'Sukolilo', 'Sukolilo', 'Sukolilo', -8.2236000, 113.2362000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69557, 'Kebonan', 'Kebonan', 'Kebonan', -8.2261000, 113.1323000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69558, 'Pandean', 'Pandean', 'Pandean', -8.2297000, 113.2158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69559, 'Cengkok', 'Cengkok', 'Cengkok', -8.2405000, 113.1968000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69560, 'Krajan Dua', 'Krajan Dua', 'Krajan Dua', -8.2440000, 113.1445000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69561, 'Karangtengah', 'Karangtengah', 'Karangtengah', -8.2438000, 113.1789000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69562, 'Kramat', 'Kramat', 'Kramat', -8.1311000, 113.4499000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69563, 'Rowotengah', 'Rowotengah', 'Rowotengah', -8.1577000, 113.3884000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69564, 'Klatakan', 'Klatakan', 'Klatakan', -8.1886000, 113.4889000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69565, 'Tanggul Wetan', 'Tanggul Wetan', 'Tanggul Wetan', -8.1716000, 113.4709000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69566, 'Darungan', 'Darungan', 'Darungan', -8.1576000, 113.4903000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69567, 'Tanggul Kulon', 'Tanggul Kulon', 'Tanggul Kulon', -8.1647000, 113.4484000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69568, 'Rowotengu', 'Rowotengu', 'Rowotengu', -8.1695000, 113.4259000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69569, 'Sukoreno', 'Sukoreno', 'Sukoreno', -8.2477000, 113.4003000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69570, 'Ngampelrejo', 'Ngampelrejo', 'Ngampelrejo', -8.2193000, 113.3766000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69571, 'Wringinagung', 'Wringinagung', 'Wringinagung', -8.2076000, 113.3915000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69572, 'Rejoagung', 'Rejoagung', 'Rejoagung', -8.2017000, 113.4171000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69573, 'Semboropasar', 'Semboropasar', 'Semboropasar', -8.2105400, 113.4450800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69574, 'Gadingrejo', 'Gadingrejo', 'Gadingrejo', -8.2355000, 113.4346000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69575, 'Paleran', 'Paleran', 'Paleran', -8.2244000, 113.4950000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69576, 'Sidomekar', 'Sidomekar', 'Sidomekar', -8.2111000, 113.4610000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69577, 'Banjar Ponggang', 'Banjar Ponggang', 'Banjar Ponggang', -8.3893000, 115.2605000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69578, 'Banjar Taro Kelod', 'Banjar Taro Kelod', 'Banjar Taro Kelod', -8.3849000, 115.2794000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69579, 'Banjar Tiga', 'Banjar Tiga', 'Banjar Tiga', -8.3825000, 115.3535000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69580, 'Banjar Dujung Kaja', 'Banjar Dujung Kaja', 'Banjar Dujung Kaja', -8.4008000, 115.2886000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69581, 'Banjar Bukian', 'Banjar Bukian', 'Banjar Bukian', -8.4068700, 115.2651200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69582, 'Banjar Manukayaanyar', 'Banjar Manukayaanyar', 'Banjar Manukayaanyar', -8.4083000, 115.3124000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69583, 'Sulahan', 'Sulahan', 'Sulahan', -8.4210000, 115.3479000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69584, 'Banjar Kubu', 'Banjar Kubu', 'Banjar Kubu', -8.4282000, 115.3629000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69585, 'Banjar Brahmanabukit', 'Banjar Brahmanabukit', 'Banjar Brahmanabukit', -8.4399000, 115.3561000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69586, 'Banjar Triwangsakelusa', 'Banjar Triwangsakelusa', 'Banjar Triwangsakelusa', -8.4406000, 115.2582000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69587, 'Banjar Petak', 'Banjar Petak', 'Banjar Petak', -8.4448000, 115.3195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69588, 'Banjar Triwangsakeliki', 'Banjar Triwangsakeliki', 'Banjar Triwangsakeliki', -8.4520000, 115.2620000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69589, 'Banjar Sandinggianyar', 'Banjar Sandinggianyar', 'Banjar Sandinggianyar', -8.4629000, 115.2992000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69590, 'Banjar Mulung', 'Banjar Mulung', 'Banjar Mulung', -8.4786000, 115.3107000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69591, 'Banjar Pesalakan', 'Banjar Pesalakan', 'Banjar Pesalakan', -8.4812000, 115.3025000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69592, 'Banjar Abuan', 'Banjar Abuan', 'Banjar Abuan', -8.4625000, 115.3350000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69593, 'Banjar Bebalang', 'Banjar Bebalang', 'Banjar Bebalang', -8.4718000, 115.3530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69594, 'Banjar Apuan Kaja', 'Banjar Apuan Kaja', 'Banjar Apuan Kaja', -8.4766000, 115.3296000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69595, 'Banjar Madangan Kaja', 'Banjar Madangan Kaja', 'Banjar Madangan Kaja', -8.4750000, 115.3238000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69596, 'Sulahan', 'Sulahan', '', -8.4210000, 115.3479000, 'ID', '2010-08-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69597, 'Jeding', 'Jeding', 'Jeding', -7.9171000, 114.1447000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69598, 'Karangkebon Timur', 'Karangkebon Timur', 'Karangkebon Timur', -8.6269100, 116.1375200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69599, 'Karang Kuripan', 'Karang Kuripan', 'Karang Kuripan', -8.6347000, 116.1540000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69600, 'Pendaleman', 'Pendaleman', 'Pendaleman', -8.6844000, 116.2404000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69601, 'Batutulis', 'Batutulis', 'Batutulis', -8.6911000, 116.2139000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69602, 'Blong Daye', 'Blong Daye', 'Blong Daye', -8.6931000, 116.2257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69603, 'Ampanlolat', 'Ampanlolat', 'Ampanlolat', -8.7198000, 116.1983000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69604, 'Ranggagata', 'Ranggagata', 'Ranggagata', -8.7224000, 116.1847000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69605, 'Karangdalam', 'Karangdalam', 'Karangdalam', -8.7384000, 116.2431000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69606, 'Bangekdewa', 'Bangekdewa', 'Bangekdewa', -8.7476000, 116.1921000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69607, 'Karang Daye', 'Karang Daye', 'Karang Daye', -8.7448000, 116.2413000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69608, 'Permas', 'Permas', 'Permas', -8.7376000, 116.2078000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69609, 'Tetebatu', 'Tetebatu', 'Tetebatu', -8.5535000, 116.4198000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69610, 'Perian Selatan', 'Perian Selatan', 'Perian Selatan', -8.5641000, 116.3930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69611, 'Gubukjero Timuk', 'Gubukjero Timuk', 'Gubukjero Timuk', -8.5605000, 116.4792000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69612, 'Keroak', 'Keroak', 'Keroak', -8.5705000, 116.4980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69613, 'Sepolong Timur', 'Sepolong Timur', 'Sepolong Timur', -8.5850000, 116.4539000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69614, 'Kampungmasjid', 'Kampungmasjid', 'Kampungmasjid', -8.5984000, 116.4498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69615, 'Rempungtimur Utara', 'Rempungtimur Utara', 'Rempungtimur Utara', -8.6118000, 116.4991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69616, 'Danger Utara', 'Danger Utara', 'Danger Utara', -8.6121000, 116.4594000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69617, 'Timba Lauk', 'Timba Lauk', 'Timba Lauk', -8.6210000, 116.4446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69618, 'Dayanpeken', 'Dayanpeken', 'Dayanpeken', -8.5920000, 116.4209000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69619, 'Dalamdesa Selatan', 'Dalamdesa Selatan', 'Dalamdesa Selatan', -8.5938000, 116.4115000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69620, 'Mujur', 'Mujur', 'Mujur', -8.6036000, 116.4012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69621, 'Kelungkung', 'Kelungkung', 'Kelungkung', -8.5518000, 117.3368000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69622, 'Ngeru', 'Ngeru', 'Ngeru', -8.5171000, 117.5158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69623, 'Jorok Dalam', 'Jorok Dalam', 'Jorok Dalam', -8.4112000, 117.1353000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69624, 'Orong', 'Orong', 'Orong', -8.4130000, 117.1296000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69625, 'Satowebrang', 'Satowebrang', 'Satowebrang', -8.4160000, 117.1266000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69626, 'Motong Barat', 'Motong Barat', 'Motong Barat', -8.4152000, 117.1311000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69627, 'Tengah Satu', 'Tengah Satu', 'Tengah Satu', -8.4183000, 117.1308000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69628, 'Rhee Beru', 'Rhee Beru', 'Rhee Beru', -8.4182000, 117.2360000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69629, 'Sebedo', 'Sebedo', 'Sebedo', -8.4287000, 117.1631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69630, 'Seseng', 'Seseng', 'Seseng', -8.4675000, 117.2304000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69631, 'Tolotangga', 'Tolotangga', 'Tolotangga', -8.7642000, 118.6353000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69632, 'Lantebaru', 'Lantebaru', 'Lantebaru', -8.6321000, 118.7736000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69633, 'Doro Oo', 'Doro Oo', 'Doro Oo', -8.6864000, 118.7631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69634, 'Rupe', 'Rupe', 'Rupe', -8.6953000, 118.8384000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69635, 'Kalodu', 'Kalodu', 'Kalodu', -8.6589000, 118.8384000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69636, 'Lampe Satu', 'Lampe Satu', 'Lampe Satu', -8.5118000, 118.8012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69637, 'Ta’a', 'Ta''a', 'Ta''a,Ta’a', -8.5184000, 118.8411000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69638, 'Sigih', 'Sigih', 'Sigih', -8.5373000, 118.8502000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69639, 'Raba', 'Raba', 'Raba', -8.5608000, 118.8633000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69640, 'Oinao', 'Oinao', 'Oinao', -8.5773000, 118.8274000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69641, 'Kuta', 'Kuta', 'Kuta', -8.5858000, 118.7811000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69642, 'Lambitu', 'Lambitu', 'Lambitu', -8.5969000, 118.7725000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69643, 'Kenari', 'Kenari', 'Kenari', -8.6184000, 119.8403000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69644, 'Dalong', 'Dalong', 'Dalong', -8.5649000, 119.9362000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69645, 'Merombok', 'Merombok', 'Merombok', -8.5404000, 119.8968000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69646, 'Melo', 'Melo', 'Melo', -8.5977000, 119.9613000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69647, 'Ngarangiakambera', 'Ngarangiakambera', 'Ngarangiakambera', -9.6710000, 120.0049000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69648, 'Karipidita', 'Karipidita', 'Karipidita', -9.7138000, 120.0297000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69649, 'Borik', 'Borik', 'Borik', -8.8435000, 120.2497000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69650, 'Waepau', 'Waepau', 'Waepau', -8.8058000, 120.2258000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69651, 'Kaca', 'Kaca', 'Kaca', -8.7511000, 120.2272000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69652, 'Tungguwaneng', 'Tungguwaneng', 'Tungguwaneng', -8.4465000, 121.1364000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69653, 'Nanganumba', 'Nanganumba', 'Nanganumba', -8.4699000, 121.2227000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69654, 'Wololele A', 'Wololele A', 'Wololele A', -8.7567000, 121.9151000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69655, 'Aemalu', 'Aemalu', 'Aemalu', -8.7657000, 121.9442000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69656, 'Wololele B', 'Wololele B', 'Wololele B', -8.7624000, 121.8929000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69657, 'Jitapanda', 'Jitapanda', 'Jitapanda', -8.7765000, 121.9569000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69658, 'Liabeke', 'Liabeke', 'Liabeke', -8.7764000, 121.9269000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69659, 'Baolokan', 'Baolokan', 'Baolokan', -8.7755000, 121.8887000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69660, 'Wonda', 'Wonda', 'Wonda', -8.7910000, 121.9370000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69661, 'Aeteke', 'Aeteke', 'Aeteke', -8.8000000, 121.9778000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69662, 'Maubasa', 'Maubasa', 'Maubasa', -8.8263000, 121.9328000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69663, 'Aipetu', 'Aipetu', 'Aipetu', -8.7953000, 121.9765000, 'ID', '2010-08-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69664, 'Boujawa', 'Boujawa', 'Boujawa', -8.7336000, 121.6329000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69665, 'Mbani', 'Mbani', 'Mbani', -8.6852000, 121.6551000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69666, 'Wolofeo', 'Wolofeo', 'Wolofeo', -8.7250000, 121.6808000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69667, 'Tendaleo', 'Tendaleo', 'Tendaleo', -8.6477000, 121.7005000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69668, 'Wolomage', 'Wolomage', 'Wolomage', -8.7031000, 121.7359000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69669, 'Nuajena', 'Nuajena', 'Nuajena', -8.7298000, 121.7468000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69670, 'Wolomoni', 'Wolomoni', 'Wolomoni', -8.7433000, 121.7445000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69671, 'Rerawere', 'Rerawere', 'Rerawere', -8.5793000, 121.5722700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69672, 'Maukaro', 'Maukaro', 'Maukaro', -8.6147600, 121.5249800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69673, 'Niopanda', 'Niopanda', 'Niopanda', -8.5513000, 121.9042000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69674, 'Loboniki', 'Loboniki', 'Loboniki', -8.5131000, 121.9270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69675, 'Sokonaja', 'Sokonaja', 'Sokonaja', -8.5916000, 121.9521000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69676, 'Lokolande', 'Lokolande', 'Lokolande', -8.5261000, 121.9715000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69677, 'Kotabaru', 'Kotabaru', 'Kotabaru', -8.5104000, 121.9911000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69678, 'Melati', 'Melati', 'Melati', -8.5666000, 118.9275000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69679, 'Sangia', 'Sangia', 'Sangia', -8.5632000, 118.9836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69680, 'Nae', 'Nae', 'Nae', -8.5646000, 118.9816000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69681, 'Raioi', 'Raioi', 'Raioi', -8.5632000, 118.9793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69682, 'Bau', 'Bau', 'Bau', -8.5625000, 118.9718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69683, 'Rasabau', 'Rasabau', 'Rasabau', -8.5662000, 118.9845000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69684, 'Kalede', 'Kalede', 'Kalede', -8.5714000, 118.9875000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69685, 'Naru', 'Naru', 'Naru', -8.5720000, 118.9929000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69686, 'Sukamaju', 'Sukamaju', 'Sukamaju', -8.5736000, 118.9725000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69687, 'Wadusari', 'Wadusari', 'Wadusari', -8.5736000, 118.9080000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69688, 'Lanta Timur', 'Lanta Timur', 'Lanta Timur', -8.6180000, 118.9994000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69689, 'Balai', 'Balai', 'Balai', -8.5992000, 118.9826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69690, 'Manggekompo', 'Manggekompo', 'Manggekompo', -8.4173000, 118.6173000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69691, 'Oo', 'Oo', 'Oo', -8.4215000, 118.5979000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69692, 'Donggo', 'Donggo', 'Donggo', -8.4247000, 118.5952000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69693, 'Manggenae', 'Manggenae', 'Manggenae', -8.4305000, 118.6176000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69694, 'Sangari', 'Sangari', 'Sangari', -8.4416000, 118.5794000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69695, 'Palama', 'Palama', 'Palama', -8.4746000, 118.5373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69696, 'Sangiang', 'Sangiang', 'Sangiang', -8.2969000, 118.9332000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69697, 'Hidirasa', 'Hidirasa', 'Hidirasa', -8.3249000, 118.9218000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69698, 'Oitui', 'Oitui', 'Oitui', -8.3331000, 118.9782000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69699, 'Bantawora', 'Bantawora', 'Bantawora', -8.3260000, 118.8938000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69700, 'Tawali', 'Tawali', 'Tawali', -8.3407000, 118.9145000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69701, 'Kara', 'Kara', 'Kara', -8.3401000, 118.9187000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69702, 'Benteng', 'Benteng', 'Benteng', -8.3620000, 118.9167000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69703, 'Tangratte', 'Tangratte', 'Tangratte', -3.0497000, 119.7643000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69704, 'Totumbang', 'Totumbang', 'Totumbang', -3.0779000, 119.9211000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69705, 'Tawui', 'Tawui', 'Tawui', -10.1430000, 120.0730000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69706, 'Nggongi', 'Nggongi', 'Nggongi', -10.1944000, 120.2336000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69707, 'Nggongi Satu', 'Nggongi Satu', 'Nggongi 1,Nggongi Satu', -10.1950000, 120.2313000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69708, 'Mburukullu', 'Mburukullu', 'Mburukullu', -10.0776000, 120.7569000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69709, 'Palamadu', 'Palamadu', 'Katakoe,Kataku,Palamadu', -10.0396000, 120.7540000, 'ID', '2013-03-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69710, 'Billa', 'Billa', 'Billa', -9.9469000, 120.0776000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69711, 'Malahar', 'Malahar', 'Malahar', -9.9492000, 120.0719000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69712, 'Karita', 'Karita', 'Karita', -9.9305000, 120.1006000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69713, 'Laetako', 'Laetako', 'Laetako', -9.8316000, 120.3905000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69714, 'Laau', 'Laau', 'Laau', -9.8594000, 120.4342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69715, 'Malabhaga', 'Malabhaga', 'Malabhaga', -8.8840000, 121.0057000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69716, 'Dona', 'Dona', 'Dona', -8.9011000, 121.0257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69717, 'Rutojawa', 'Rutojawa', 'Rutojawa', -8.9132000, 121.0142000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69718, 'Ngedhubasa', 'Ngedhubasa', 'Ngedhubasa', -8.9445000, 121.0593000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69719, 'Ngedhusuba', 'Ngedhusuba', 'Ngedhusuba', -8.9542000, 121.0320000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69720, 'Heret', 'Heret', 'Heret', -8.4076000, 120.6293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69721, 'Waenenda', 'Waenenda', 'Waenenda', -8.4539000, 120.6359000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69722, 'Rado', 'Rado', 'Rado', -8.4740000, 120.6709000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69723, 'Reweng', 'Reweng', 'Reweng', -8.4992000, 120.6439000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69724, 'Nangahurebukitpermai', 'Nangahurebukitpermai', 'Nangahurebukitpermai', -8.5634000, 122.1588000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69725, 'Nangahure', 'Nangahure', 'Nangahure', -8.5697000, 122.1661000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69726, 'Urungpigang', 'Urungpigang', 'Urungpigang', -8.6034000, 122.1878000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69727, 'Wolomarang', 'Wolomarang', 'Wolomarang', -8.6040000, 122.1994000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69728, 'Kotauneng', 'Kotauneng', 'Kotauneng', -8.6156000, 122.2160000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69729, 'Kabor', 'Kabor', 'Kabor', -8.6206600, 122.2148400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69730, 'Sengguruhkrajan', 'Sengguruhkrajan', 'Sengguruhkrajan', -8.1729000, 112.5497000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69731, 'Sumuran', 'Sumuran', 'Sumuran', -8.2103000, 112.5542000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69732, 'Banjarejokrajan', 'Banjarejokrajan', 'Banjarejokrajan', -8.1822000, 112.6248000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69733, 'Bulupitukrajan', 'Bulupitukrajan', 'Bulupitukrajan', -8.1331000, 112.6023000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69734, 'Kedungkrajan', 'Kedungkrajan', 'Kedungkrajan', -8.1476000, 112.5827000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69735, 'Sukosarikrajan', 'Sukosarikrajan', 'Sukosarikrajan', -8.1606000, 112.6009000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69736, 'Sidodadi', 'Sidodadi', 'Sidodadi', -8.3645000, 113.6558000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69737, 'Krajan Suco', 'Krajan Suco', 'Krajan Suco', -8.2672000, 113.7496000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69738, 'Sumber Tengah', 'Sumber Tengah', 'Sumber Tengah', -8.2596000, 113.7246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69739, 'Peji Satu', 'Peji Satu', 'Peji Satu', -8.2638000, 113.7063000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69740, 'Gayasan Kulon', 'Gayasan Kulon', 'Gayasan Kulon', -8.2657000, 113.6634000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69741, 'Tamansari', 'Tamansari', 'Tamansari', -8.2810000, 113.7232000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69742, 'Tempurejo', 'Tempurejo', 'Tempurejo', -8.2994000, 113.6793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69743, 'Sruni', 'Sruni', 'Sruni', -8.2983000, 113.6369000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69744, 'Andongsari', 'Andongsari', 'Andongsari', -8.3661000, 113.6340000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69745, 'Jatisari', 'Jatisari', 'Jatisari', -8.3183000, 113.6352000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69746, 'Sumberejo', 'Sumberejo', 'Sumberejo', -8.3424000, 113.6816000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69747, 'Pontang Tengah', 'Pontang Tengah', 'Pontang Tengah', -8.3464000, 113.6376000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69748, 'Sumbersalak', 'Sumbersalak', 'Sumbersalak', -8.1579000, 113.8835000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69749, 'Sumberbulus Dua', 'Sumberbulus Dua', 'Sumberbulus Dua', -8.1415000, 113.8972000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69750, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.2247000, 113.9278000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69751, 'Pengotaan', 'Pengotaan', 'Pengotaan', -8.0157000, 113.7790000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69752, 'Krajan Satu Pekauman', 'Krajan Satu Pekauman', 'Krajan Satu,Krajan Satu Pekauman', -8.0013000, 113.7934000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69753, 'Sumberkemuning', 'Sumberkemuning', 'Sumberkemuning', -8.0014000, 113.8351000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69754, 'Sumberjeruk', 'Sumberjeruk', 'Sumberjeruk', -8.0090000, 113.8716000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69755, 'Kalianyar Selatan', 'Kalianyar Selatan', 'Kalianyar Selatan', -8.0152000, 113.8291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69756, 'Kembangpasar', 'Kembangpasar', 'Kembangpasar', -8.0117000, 113.8637000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69757, 'Kemirian', 'Kemirian', 'Kemirian', -8.0235000, 113.8342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69758, 'Kidulsawah', 'Kidulsawah', 'Kidulsawah', -8.0205000, 113.8262000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69759, 'Tanahwulan', 'Tanahwulan', 'Tanahwulan', -8.0293000, 113.7592000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69760, 'Pujerbaru', 'Pujerbaru', 'Pujerbaru', -8.0322000, 113.7621000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69761, 'Gambangan', 'Gambangan', 'Gambangan', -8.0322000, 113.7689000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69762, 'Sumur', 'Sumur', 'Sumur', -8.0300000, 113.8172000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69763, 'Krajan Pocangan', 'Krajan Pocangan', 'Krajan,Krajan Pocangan', -8.0299000, 113.8526000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69764, 'Mengenkrajan', 'Mengenkrajan', 'Mengenkrajan', -8.0395000, 113.8512000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69765, 'Karangmelok', 'Karangmelok', 'Karangmelok', -8.0414000, 113.8293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69766, 'Krajan Dua Sumbersari', 'Krajan Dua Sumbersari', 'Krajan Dua,Krajan Dua Sumbersari', -8.0344000, 113.7806000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69767, 'Krajan Atas Suger Lor', 'Krajan Atas Suger Lor', 'Krajan Atas,Krajan Atas Suger Lor', -8.0381000, 113.7789000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69768, 'Sumberpakem', 'Sumberpakem', 'Sumberpakem', -8.0479000, 113.8026000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69769, 'Dawuhanmangli', 'Dawuhanmangli', 'Dawuhanmangli', -8.0513000, 113.8439000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69770, 'Plereyan', 'Plereyan', 'Plereyan', -8.0484000, 113.8715000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69771, 'Sumberpakem', 'Sumberpakem', 'Sumberpakem', -8.0562000, 113.8714000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69772, 'Krajan Sumberdanti', 'Krajan Sumberdanti', 'Krajan,Krajan Sumberdanti', -8.0521000, 113.8630000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69773, 'Ragang', 'Ragang', 'Ragang', -8.0505000, 113.8295000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69774, 'Sukokerto', 'Sukokerto', 'Sukokerto', -8.0549000, 113.8137000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69775, 'Mojogemi', 'Mojogemi', 'Mojogemi', -8.0578000, 113.7972000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69776, 'Krajan Timur Suger Kidul', 'Krajan Timur Suger Kidul', 'Krajan Timur,Krajan Timur Suger Kidul', -8.0526000, 113.7809000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69777, 'Sukojember', 'Sukojember', 'Sukojember', -8.0590000, 113.7698000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69778, 'Biting', 'Biting', 'Biting', -8.0730000, 113.8575000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69779, 'Sumbergayam', 'Sumbergayam', 'Sumbergayam', -8.0744000, 113.8305000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69780, 'Duklengkong', 'Duklengkong', 'Duklengkong', -8.0753000, 113.7986000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69781, 'Sukowiryo', 'Sukowiryo', 'Sukowiryo', -8.0818000, 113.7754000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69782, 'Sumberwaru', 'Sumberwaru', 'Sumberwaru', -8.0823000, 113.8246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69783, 'Sukosari', 'Sukosari', 'Sukosari', -8.0838000, 113.8413000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69784, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.0827000, 113.8269000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69785, 'Klole', 'Klole', 'Klole', -8.0839000, 113.8238000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69786, 'Krajan Barat Jelbuk', 'Krajan Barat Jelbuk', 'Krajan Barat,Krajan Barat Jelbuk', -8.0873000, 113.7592000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69787, 'Krajan Barat Candijati', 'Krajan Barat Candijati', 'Krajan Barat,Krajan Barat Candijati', -8.0976000, 113.7562000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69788, 'Grugul', 'Grugul', 'Grugul', -8.1007000, 113.7899000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69789, 'Sebanen', 'Sebanen', 'Sebanen', -8.1002000, 113.8224000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69790, 'Klanceng', 'Klanceng', 'Klanceng', -8.1023000, 113.7512000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69791, 'Krajan Dua Patempuran', 'Krajan Dua Patempuran', 'Krajan Dua,Krajan Dua Patempuran', -8.1081000, 113.7993000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69792, 'Krajan Sumberanget', 'Krajan Sumberanget', 'Krajan,Krajan Sumberanget', -8.1130000, 113.8437000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69793, 'Krajan Ledokombo', 'Krajan Ledokombo', 'Krajan,Krajan Ledokombo', -8.1200000, 113.8614000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69794, 'Sumberketempah', 'Sumberketempah', 'Sumberketempah', -8.1168000, 113.8273000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69795, 'Karangpeton', 'Karangpeton', 'Karangpeton', -8.1246000, 113.7813000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69796, 'Biting', 'Biting', 'Biting', -8.1184000, 113.7617000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69797, 'Tista', 'Tista', 'Tista', -8.3525000, 114.9211000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69798, 'Asahbadung', 'Asahbadung', 'Asahbadung', -8.3278000, 114.9055000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69799, 'Telaga', 'Telaga', 'Telaga', -8.2675000, 114.9506000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69800, 'Bongancina Kaja', 'Bongancina Kaja', 'Bongancina Kaja', -8.3343000, 114.9494000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69801, 'Puspajati', 'Puspajati', 'Puspajati', -8.2585000, 114.9930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69802, 'Pelapuan', 'Pelapuan', 'Pelapuan', -8.2669000, 114.9890000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69803, 'Kanginan', 'Kanginan', 'Kanginan', -8.2870000, 114.9819000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69804, 'Bantiran', 'Bantiran', 'Bantiran', -8.3095000, 114.9908000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69805, 'Klau', 'Klau', 'Klau', -8.3360000, 114.9882000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69806, 'Munduktemu Kelod', 'Munduktemu Kelod', 'Munduktemu Kelod', -8.3440000, 114.9689000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69807, 'Subuk', 'Subuk', 'Subuk', -8.2871000, 114.9763000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69808, 'Titab', 'Titab', 'Titab', -8.2701000, 114.9586000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69809, 'Busungbiu', 'Busungbiu', 'Busungbiu', -8.2565000, 114.9672000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69810, 'Kauhan', 'Kauhan', 'Kauhan', -8.2673000, 114.9718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69811, 'Tegalasih', 'Tegalasih', 'Tegalasih', -8.3156000, 114.9449000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69812, 'Banjar Kampungbugis', 'Banjar Kampungbugis', 'Banjar Kampungbugis', -8.1055000, 115.0865000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69813, 'Banjar Kampungkajanan', 'Banjar Kampungkajanan', 'Banjar Kampungkajanan', -8.1075000, 115.0918000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69814, 'Banjar Kaliuntu Satu', 'Banjar Kaliuntu Satu', 'Banjar Kaliuntu Satu', -8.1118000, 115.0820000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69815, 'Banjar Kampunganyar', 'Banjar Kampunganyar', 'Banjar Kampunganyar', -8.1091000, 115.0862000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69816, 'Banjar Tambaksari', 'Banjar Tambaksari', 'Banjar Tambaksari', -8.1020000, 115.0945000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69817, 'Banjar Barunasari', 'Banjar Barunasari', 'Banjar Barunasari', -8.1041000, 115.0936000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69818, 'Banjar Bali', 'Banjar Bali', 'Banjar Bali', -8.1095000, 115.0928000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69819, 'Banjar Banyuning Barat', 'Banjar Banyuning Barat', 'Banjar Banyuning Barat', -8.1145000, 115.1021000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69820, 'Banjar Peguyangan', 'Banjar Peguyangan', 'Banjar Peguyangan', -8.1188000, 115.0931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69821, 'Banjar Delodpeken', 'Banjar Delodpeken', 'Banjar Delodpeken', -8.1208000, 115.0955000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69822, 'Banjar Sidayu', 'Banjar Sidayu', 'Banjar Sidayu', -8.1027000, 115.1200000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69823, 'Curahkalak Tengah', 'Curahkalak Tengah', 'Curahkalak Tengah', -7.7516000, 114.1829000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69824, 'Trigonco Tengah', 'Trigonco Tengah', 'Trigonco Tengah', -7.7513000, 114.2178000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69825, 'Perante Utara', 'Perante Utara', 'Perante Utara', -7.7549000, 114.2167000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69826, 'Perante Tengah', 'Perante Tengah', 'Perante Tengah', -7.7588000, 114.2196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69827, 'Randuagung', 'Randuagung', 'Randuagung', -7.7660000, 114.2361000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69828, 'Bayeman', 'Bayeman', 'Bayeman', -7.7958000, 114.1276000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69829, 'Tanjungpecinan Utara', 'Tanjungpecinan Utara', 'Tanjungpecinan Utara', -7.6329000, 114.0337000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69830, 'Glugur Tengah', 'Glugur Tengah', 'Glugur Tengah', -7.6491000, 114.0464000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69831, 'Tanjungsari Barat', 'Tanjungsari Barat', 'Tanjungsari Barat', -7.6612000, 114.0492000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69832, 'Cempaka', 'Cempaka', 'Cempaka', -7.6558000, 114.0212000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69833, 'Tokelan Utara', 'Tokelan Utara', 'Tokelan Utara', -7.6841000, 114.0458000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69834, 'Krajan Satu Panji Lor', 'Krajan Satu Panji Lor', 'Krajan Satu,Krajan Satu Panji Lor', -7.6960000, 114.0416000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69835, 'Aengceleng', 'Aengceleng', 'Aengceleng', -7.7177000, 114.0741000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69836, 'Mimbaan Timur', 'Mimbaan Timur', 'Mimbaan Timur', -7.6990000, 114.0296000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69837, 'Kotakan Selatan', 'Kotakan Selatan', 'Kotakan Selatan', -7.7447000, 114.0098000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69838, 'Sliwungkrajan', 'Sliwungkrajan', 'Sliwungkrajan', -7.7486000, 114.0084000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69839, 'Sukadana Selatan', 'Sukadana Selatan', 'Sukadana Selatan', -8.6281000, 116.4076000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69840, 'Sikur', 'Sikur', 'Sikur', -8.6331000, 116.4463000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69841, 'Paokmotong Utara', 'Paokmotong Utara', 'Paokmotong Utara', -8.6260000, 116.4585000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69842, 'Mejelo Timur', 'Mejelo Timur', 'Mejelo Timur', -8.6378000, 116.3891000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69843, 'Terara Utara', 'Terara Utara', 'Terara Utara', -8.6394000, 116.4133000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69844, 'Montongbaan', 'Montongbaan', 'Montongbaan', -8.6365000, 116.4282000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69845, 'Nyiurtebel', 'Nyiurtebel', 'Nyiurtebel', -8.6361000, 116.4987000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69846, 'Laukrurung', 'Laukrurung', 'Laukrurung', -8.6393000, 116.4760000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69847, 'Terara', 'Terara', 'Terara', -8.6409000, 116.4110000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69848, 'Suradi Selatan', 'Suradi Selatan', 'Suradi Selatan', -8.6533000, 116.4161000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69849, 'Setanggor', 'Setanggor', 'Setanggor', -8.6537000, 116.4812000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69850, 'Pancoran', 'Pancoran', 'Pancoran', -8.6636000, 116.4877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69851, 'Kabar Utara', 'Kabar Utara', 'Kabar Utara', -8.6611000, 116.4758000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69852, 'Lintek', 'Lintek', 'Lintek', -8.6634000, 116.4564000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69853, 'Beson', 'Beson', 'Beson', -8.6739000, 116.3762000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69854, 'Dalam Daya', 'Dalam Daya', 'Dalam Daya', -8.6801000, 116.4705000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69855, 'Suwangi Utara', 'Suwangi Utara', 'Suwangi Utara', -8.6933000, 116.4442000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69856, 'Montongtangi Timuk', 'Montongtangi Timuk', 'Montongtangi Timuk', -8.6869000, 116.4947000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69857, 'Janapria', 'Janapria', 'Janapria', -8.6952000, 116.4015000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69858, 'Gunungrajak', 'Gunungrajak', 'Gunungrajak', -8.7067000, 116.4632000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69859, 'Sukarara Utara', 'Sukarara Utara', 'Sukarara Utara', -8.7097000, 116.4427000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69860, 'Jembe Timur', 'Jembe Timur', 'Jembe Timur', -8.7150000, 116.4113000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69861, 'Loangmaka', 'Loangmaka', 'Loangmaka', -8.7142000, 116.3931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69862, 'Bungtiang Barat', 'Bungtiang Barat', 'Bungtiang Barat', -8.7307000, 116.4843000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69863, 'Montongtebolak', 'Montongtebolak', 'Montongtebolak', -8.7261000, 116.4644000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69864, 'Lekor Barat', 'Lekor Barat', 'Lekor Barat', -8.7304000, 116.4349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69865, 'Beleka Satu', 'Beleka Satu', 'Beleka Satu', -8.7423000, 116.4033000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69866, 'Tibulakasasak', 'Tibulakasasak', 'Tibulakasasak', -8.4234000, 115.6309000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69867, 'Bungkulan', 'Bungkulan', 'Bungkulan', -8.4457000, 115.6424000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69868, 'Akarakar', 'Akarakar', 'Akarakar', -8.2214000, 116.3428000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69869, 'Pisangkemeng', 'Pisangkemeng', 'Pisangkemeng', -8.8025000, 117.7774000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69870, 'Boal Atas', 'Boal Atas', 'Boal Atas', -8.7914000, 117.9626000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69871, 'Kawangohari', 'Kawangohari', 'Kawangohari', -9.5411000, 119.0029000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69872, 'Maliiha', 'Maliiha', 'Maliiha', -9.5528000, 119.0195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69873, 'Dinjo', 'Dinjo', 'Dinjo', -9.5942000, 119.0138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69874, 'Leteloko', 'Leteloko', 'Leteloko', -9.6047000, 119.0188000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69875, 'Kori', 'Kori', 'Kori', -9.5081000, 119.0349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69876, 'Hombakaripit', 'Hombakaripit', 'Hombakaripit', -9.5214000, 119.0326000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69877, 'Hohawungo', 'Hohawungo', 'Hohawungo', -9.5320000, 119.0242000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69878, 'Lokorota', 'Lokorota', 'Lokorota', -9.5873000, 119.0655000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69879, 'Waiholo', 'Waiholo', 'Waiholo', -9.5179000, 119.0844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69880, 'Malulla', 'Malulla', 'Malulla', -9.6266000, 119.2507000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69881, 'Ngaduloda', 'Ngaduloda', 'Ngaduloda', -9.6917000, 119.3698000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69882, 'Bogorawatu', 'Bogorawatu', 'Bogorawatu', -9.7491000, 119.3273000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69883, 'Hodi', 'Hodi', 'Hodi', -9.7134000, 119.2546000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69884, 'Kapakabisa', 'Kapakabisa', 'Kapakabisa', -9.7219000, 119.2998000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69885, 'Welibo', 'Welibo', 'Welibo', -9.7259000, 119.3396000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69886, 'Wengaingo', 'Wengaingo', 'Wengaingo', -9.7327000, 119.3456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69887, 'Barakabita', 'Barakabita', 'Barakabita', -9.7229000, 119.3607000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69888, 'Kabukarudi', 'Kabukarudi', 'Kabukarudi', -9.7246000, 119.3596000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69889, 'Matumadua', 'Matumadua', 'Matumadua', -9.3894800, 119.7537100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69890, 'Kambatatamakawu', 'Kambatatamakawu', 'Kambatatamakawu', -9.4213700, 119.8938800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69891, 'Allu', 'Allu', 'Allu', -3.4247000, 118.9912000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69892, 'Petoosang', 'Petoosang', 'Petoosang', -3.4277000, 118.9906000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69893, 'Narang', 'Narang', 'Narang', -8.7767000, 120.3690000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69894, 'Benteng', 'Benteng', 'Benteng', -8.8165000, 120.3695000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69895, 'Keka', 'Keka', 'Keka', -8.8204000, 120.3498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69896, 'Wongka', 'Wongka', 'Wongka', -8.8160000, 120.3027000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69897, 'Paka', 'Paka', 'Paka', -8.7794000, 120.4190000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69898, 'Watuweri', 'Watuweri', 'Watuweri', -8.7843000, 120.4706000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69899, 'Woa', 'Woa', 'Woa', -8.7975000, 120.4996000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69900, 'Lamba', 'Lamba', 'Lamba', -8.8058000, 120.4345000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69901, 'Iteng', 'Iteng', 'Iteng', -8.8120000, 120.4219000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69902, 'Wunat', 'Wunat', 'Wunat', -8.5262000, 120.2214000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69903, 'Noa', 'Noa', 'Noa', -8.5305000, 120.2003000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69904, 'Handeng', 'Handeng', 'Handeng', -8.5297000, 120.1355000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69905, 'Waepitak', 'Waepitak', 'Waepitak', -8.5500000, 120.2499000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69906, 'Semang', 'Semang', 'Semang', -8.5783000, 120.2189000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69907, 'Jeong', 'Jeong', 'Jeong', -8.5852000, 120.2302000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69908, 'Wasogolo', 'Wasogolo', 'Wasogolo', -8.6268000, 120.4599000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69909, 'Pora', 'Pora', 'Pora', -8.7089000, 120.3838000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69910, 'Pongkor', 'Pongkor', 'Pongkor', -8.7136000, 120.3877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69911, 'Ponggeok', 'Ponggeok', 'Ponggeok', -8.7229000, 120.4146000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69912, 'Teber', 'Teber', 'Teber', -8.6562000, 120.5941000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69913, 'Bombu', 'Bombu', 'Bombu', -8.6909000, 120.5162000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69914, 'Ntaur Satu', 'Ntaur Satu', 'Ntaur Satu', -8.6910000, 120.5294000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69915, 'Rentung', 'Rentung', 'Rentung', -8.6746000, 120.5637000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69916, 'Tado', 'Tado', 'Tado', -8.7016000, 120.5956000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69917, 'Kawit', 'Kawit', 'Kawit', -8.7215000, 120.5520000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69918, 'Kaca', 'Kaca', 'Kaca', -8.7361000, 120.5721000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69919, 'Pesek', 'Pesek', 'Pesek', -8.7056000, 120.6177000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69920, 'Jawakisa', 'Jawakisa', 'Jawakisa', -8.6604000, 121.2238000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69921, 'Gero', 'Gero', 'Gero', -8.7039000, 121.1881000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69922, 'Watugase', 'Watugase', 'Watugase', -8.7310000, 121.1856000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69923, 'Funga', 'Funga', 'Funga', -8.6687000, 121.9878000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69924, 'Ratenggoji', 'Ratenggoji', 'Ratenggoji', -8.6851000, 121.9164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69925, 'Wolofeo', 'Wolofeo', 'Wolofeo', -8.7215000, 121.9897000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69926, 'Wolobela', 'Wolobela', 'Wolobela', -8.7375000, 121.9543000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69927, 'Woloara', 'Woloara', 'Woloara', -8.7468000, 121.9677000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69928, 'Woloau', 'Woloau', 'Woloau', -8.6401000, 122.0151000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69929, 'Detuleda', 'Detuleda', 'Detuleda', -8.6542000, 122.0433000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69930, 'Nirangkliung', 'Nirangkliung', 'Nirangkliung', -8.6550000, 122.0940000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69931, 'Retenggoma', 'Retenggoma', 'Retenggoma', -8.6662000, 122.0680000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69932, 'Feondari', 'Feondari', 'Feondari', -8.6678000, 122.0326000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69933, 'Tilang', 'Tilang', 'Tilang', -8.7006000, 122.1228000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69934, 'Riipua', 'Riipua', 'Riipua', -8.7113000, 122.0919000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69935, 'Detupia', 'Detupia', 'Detupia', -8.7290000, 122.0188000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69936, 'Masebewa', 'Masebewa', 'Masebewa', -8.7273000, 122.0223000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69937, 'Riit', 'Riit', 'Riit', -8.6553000, 122.1274000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69938, 'Brai', 'Brai', 'Brai', -8.6590000, 122.2263000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69939, 'Nitakloang', 'Nitakloang', 'Nitakloang', -8.6698000, 122.1636000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69940, 'Tebuk', 'Tebuk', 'Tebuk', -8.6835000, 122.1708000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69941, 'Bloro', 'Bloro', 'Bloro', -8.6837000, 122.1595000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69942, 'Kotingnatagete', 'Kotingnatagete', 'Kotingnatagete', -8.6816000, 122.1930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69943, 'Kojagete', 'Kojagete', 'Kojagete', -8.6899000, 122.1877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69944, 'Diller', 'Diller', 'Diller', -8.6942000, 122.1905000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69945, 'Gehaklau', 'Gehaklau', 'Gehaklau', -8.6951000, 122.1981000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69946, 'Detung', 'Detung', 'Detung', -8.6640000, 122.2157000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69947, 'Tadabliro', 'Tadabliro', 'Tadabliro', -8.6847000, 122.2162000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69948, 'Habingkloang', 'Habingkloang', 'Habingkloang', -8.6981000, 122.2470000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69949, 'Hokor', 'Hokor', 'Hokor', -8.7348000, 122.2441000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69950, 'Puho', 'Puho', 'Puho', -8.7136000, 122.1932000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69951, 'Watubura', 'Watubura', 'Watubura', -8.7180000, 122.1353000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69952, 'Hepang', 'Hepang', 'Hepang', -8.7105000, 122.1502000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69953, 'Fatualam', 'Fatualam', 'Fatualam', -9.5010000, 124.5454000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69954, 'Leof', 'Leof', 'Leof', -9.5773000, 124.6241000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69955, 'Oenak', 'Oenak', 'Oenak', -9.5614000, 124.5019000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69956, 'Naiola', 'Naiola', 'Naiola', -9.5480000, 124.5055000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69957, 'Nibaaf', 'Nibaaf', 'Nibaaf', -9.5859000, 124.5278000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69958, 'Baanfaun', 'Baanfaun', 'Baanfaun', -9.5860000, 124.5859000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69959, 'Neob', 'Neob', 'Neob', -9.6086000, 124.5978000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69960, 'Onan Ganjang Satu', 'Onan Ganjang Satu', 'Onan Ganjang 1,Onan Ganjang Satu', 2.1589000, 98.6304400, 'ID', '2013-11-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69961, 'Banjar Dukuh', 'Banjar Dukuh', 'Banjar Dukuh', -8.2819000, 115.5516000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69962, 'Banjar Kangkaang', 'Banjar Kangkaang', 'Banjar Kangkaang', -8.3571000, 115.6123000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69963, 'Banjar Buayang', 'Banjar Buayang', 'Banjar Buayang', -8.3464000, 115.6132000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69964, 'Banjar Kelodan', 'Banjar Kelodan', 'Banjar Kelodan', -8.3416000, 115.5975000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69965, 'Penggakrajeng', 'Penggakrajeng', 'Penggakrajeng', -8.3242000, 115.6180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69966, 'Biaslantang Kaler', 'Biaslantang Kaler', 'Biaslantang Kaler', -8.3360000, 115.6288000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69967, 'Loloan', 'Loloan', 'Loloan', -8.2562000, 116.4395000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69968, 'Lelongken', 'Lelongken', 'Lelongken', -8.3226000, 116.4966000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69969, 'Karanggedang', 'Karanggedang', 'Karanggedang', -8.2227000, 116.3988000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69970, 'Anyar', 'Anyar', 'Anyar', -8.2301000, 116.4250000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69971, 'Pali', 'Pali', 'Pali', -8.3765000, 118.3093000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69972, 'Nusajaya', 'Nusajaya', 'Nusajaya', -8.4817000, 118.3064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69973, 'Lanci Satu', 'Lanci Satu', 'Lanci Satu', -8.4932000, 118.3176000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69974, 'Sumur Lima', 'Sumur Lima', 'Sumur Lima', -8.4939000, 118.2991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69975, 'Samangawah', 'Samangawah', 'Samangawah', -8.4955000, 118.2991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69976, 'Komerda', 'Komerda', 'Komerda', -9.6324000, 119.4103000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69977, 'Kalimbukuni', 'Kalimbukuni', 'Kalimbukuni', -9.6362000, 119.4361000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69978, 'Tibutana', 'Tibutana', 'Tibutana', -9.6337000, 119.4259000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69979, 'Tebara', 'Tebara', 'Tebara', -9.6372000, 119.4308000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69980, 'Wailiang', 'Wailiang', 'Wailiang', -9.6355000, 119.4070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69981, 'Kotawaikabubak', 'Kotawaikabubak', 'Kotawaikabubak', -9.6376000, 119.4229000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69982, 'Puukadelu', 'Puukadelu', 'Puukadelu', -9.6508000, 119.4098000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69983, 'Litibakul', 'Litibakul', 'Litibakul', -9.6996000, 119.4360000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69984, 'Barabedang', 'Barabedang', 'Barabedang', -9.6936000, 119.4562000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69985, 'Toupopu', 'Toupopu', 'Toupopu', -9.7028000, 119.4717000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69986, 'Waimadaka', 'Waimadaka', 'Waimadaka', -9.7083000, 119.4108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69987, 'Praimutung', 'Praimutung', 'Praimutung', -9.7232000, 119.4562000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69988, 'Lahihagalang', 'Lahihagalang', 'Lahihagalang', -9.7220000, 119.4534000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69989, 'Maledona', 'Maledona', 'Maledona', -9.7230000, 119.3852000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69990, 'Padedewatu', 'Padedewatu', 'Padedewatu', -9.7481000, 119.4012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69991, 'Tarimbang', 'Tarimbang', 'Tarimbang', -9.9701400, 119.9536200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69992, 'Laiponda', 'Laiponda', 'Laiponda', -9.8625000, 119.8963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69993, 'Tanarara', 'Tanarara', 'Tanarara', -9.6336000, 119.5446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69994, 'Tamanaimahu', 'Tamanaimahu', 'Tamanaimahu', -9.6379000, 119.6008000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69995, 'Prailangina', 'Prailangina', 'Prailangina', -9.6485200, 119.7453600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69996, 'Ncera', 'Ncera', 'Ncera', -8.6349000, 118.7446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69997, 'Lido', 'Lido', 'Lido', -8.6294000, 118.7341000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69998, 'Ompuboi', 'Ompuboi', 'Ompuboi', -8.6284000, 118.7102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(69999, 'Simpasai', 'Simpasai', 'Simpasai', -8.6915000, 118.6654000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70000, 'Waworada', 'Waworada', 'Waworada', -8.6696000, 118.6881000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70001, 'Karano', 'Karano', 'Karano', -8.7076000, 118.7298000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70002, 'Watuka', 'Watuka', 'Watuka', -8.7552000, 120.7106000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70003, 'Waekolong', 'Waekolong', 'Waekolong', -8.7581000, 120.7293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70004, 'Gurung', 'Gurung', 'Gurung', -8.7715000, 120.6383000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70005, 'Waerana', 'Waerana', 'Waerana', -8.7818000, 120.7152000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70006, 'Kipo', 'Kipo', 'Kipo', -8.7760000, 120.6774000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70007, 'Munde', 'Munde', 'Munde', -8.7926000, 120.7373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70008, 'Sere', 'Sere', 'Sere', -8.8161000, 120.6680000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70009, 'Muting', 'Muting', 'Muting', -8.8488000, 120.6988600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70010, 'Boganatar', 'Boganatar', 'Boganatar', -8.5043000, 122.6405000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70011, 'Sukutukang', 'Sukutukang', 'Sukutukang', -8.5034000, 122.7139000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70012, 'Welamosa', 'Welamosa', 'Welamosa', -8.6058000, 121.7176300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70013, 'Aelande', 'Aelande', 'Aelande', -8.5956500, 121.7252000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70014, 'Wolomuku', 'Wolomuku', 'Wolomuku', -8.6042000, 121.7404100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70015, 'Londe', 'Londe', 'Londe', -8.6062100, 121.7285600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70016, 'Ritapiret', 'Ritapiret', 'Ritapiret', -8.6718000, 122.1746000, 'ID', '2010-08-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70017, 'Halat', 'Halat', 'Halat', -8.6832000, 122.2073000, 'ID', '2010-08-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70018, 'Natarleba', 'Natarleba', 'Natarleba', -8.5139000, 122.5410000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70019, 'Talibura', 'Talibura', 'Talibura', -8.5246000, 122.5255000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70020, 'Hila', 'Hila', 'Hila', -8.5628000, 122.6130000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70021, 'Wolometang', 'Wolometang', 'Wolometang', -8.5873000, 122.5971000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70022, 'Natarmage', 'Natarmage', 'Natarmage', -8.6031000, 122.5667000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70023, 'Ewa', 'Ewa', 'Ewa', -8.6235000, 122.5073000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70024, 'Boru', 'Boru', 'Boru', -8.5252000, 122.7108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70025, 'Duang', 'Duang', 'Duang', -8.5577000, 122.7275000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70026, 'Hewa', 'Hewa', 'Hewa', -8.5935000, 122.7057000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70027, 'Watubuku', 'Watubuku', 'Watubuku', -8.6050000, 122.7430000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70028, 'Kokang', 'Kokang', 'Kokang', -8.6158000, 122.6847000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70029, 'Palue', 'Palue', 'Palue', -8.4691000, 122.7070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70030, 'Adirejo', 'Adirejo', 'Adirejo', -8.2120100, 112.6387500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70031, 'Putat Lor', 'Putat Lor', 'Putat Lor', -8.1563100, 112.6434900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70032, 'Segaran', 'Segaran', 'Segaran', -8.2419900, 112.6307000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70033, 'Dajan Tangluk', 'Dajan Tangluk', 'Dajan Tangluk', -8.6458000, 115.2389000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70034, 'Karyadharma', 'Karyadharma', 'Karyadharma', -8.7037000, 115.2187000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70035, 'Jabajero', 'Jabajero', 'Jabajero', -8.7276700, 115.1750200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70036, 'Cempa Pasar', 'Cempa Pasar', 'Cempa Pasar', -3.7486000, 119.5842000, 'ID', '2010-09-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70037, 'Kelanabian', 'Kelanabian', 'Kelanabian', -8.7519000, 115.1769000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70038, 'Kangin', 'Kangin', 'Kangin', -8.8322000, 115.1255000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70039, 'Klatakan', 'Klatakan', 'Klatakan', -8.1762000, 114.3834000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70040, 'Kebunjeruk', 'Kebunjeruk', 'Kebunjeruk', -8.1977000, 114.3776000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70041, 'Grobokan', 'Grobokan', 'Grobokan', -8.2046000, 114.3792000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70042, 'Sritanjung', 'Sritanjung', 'Sritanjung', -8.2075000, 114.3771000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70043, 'Ujung', 'Ujung', 'Ujung', -8.2137000, 114.3818000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70044, 'Kaliasin', 'Kaliasin', 'Kaliasin', -8.2203000, 114.3778000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70045, 'Possumur', 'Possumur', 'Possumur', -8.0424000, 114.4197000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70046, 'Kampungbaru', 'Kampungbaru', 'Kampungbaru', -8.5021000, 116.6644000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70047, 'Pringgabaya', 'Pringgabaya', 'Pringgabaya', -8.5570000, 116.6319000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70048, 'Delod Pangkung', 'Delod Pangkung', 'Delod Pangkung', -8.3812000, 114.6354000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70049, 'Banjar Dauhmarga', 'Banjar Dauhmarga', 'Banjar Dauhmarga', -8.3916000, 114.6726000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70050, 'Banjar Tegakgede', 'Banjar Tegakgede', 'Banjar Tegakgede', -8.3937000, 114.7755000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70051, 'Banjar Delodsetra', 'Banjar Delodsetra', 'Banjar Delodsetra', -8.3987000, 114.8178000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70052, 'Pekutatan', 'Pekutatan', 'Pekutatan', -8.4207000, 114.8228000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70053, 'Banjar Dangin Pangkung', 'Banjar Dangin Pangkung', 'Banjar Dangin Pangkung', -8.4273000, 114.8386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70054, 'Banjar Asahduren', 'Banjar Asahduren', 'Banjar Asahduren', -8.3981000, 114.8525000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70055, 'Banjar Swastika', 'Banjar Swastika', 'Banjar Swastika', -8.4318000, 114.8600000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70056, 'Lokokrangan', 'Lokokrangan', 'Lokokrangan', -8.2550000, 116.2591000, 'ID', '2014-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70057, 'Tanahsong Daya', 'Tanahsong Daya', 'Tanahsong Daya', -8.3512000, 116.1678000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70058, 'Prawira', 'Prawira', 'Prawira', -8.3611000, 116.1441000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70059, 'Todo', 'Todo', 'Todo', -8.3718000, 116.1819000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70060, 'Santong', 'Santong', 'Santong', -8.3178000, 116.2867000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70061, 'Labuhankuris', 'Labuhankuris', 'Labuhankuris', -8.5806100, 117.6344000, 'ID', '2014-11-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70062, 'Lukkarya', 'Lukkarya', 'Lukkarya', -8.4288000, 117.2881000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70063, 'Waiha', 'Waiha', 'Waiha', -9.6356000, 119.0430000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70064, 'Ngondokandawu', 'Ngondokandawu', 'Ngondokandawu', -9.6602000, 119.0763000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70065, 'Panenggoede', 'Panenggoede', 'Panenggoede', -9.6701000, 119.0511000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70066, 'Kalembutillu', 'Kalembutillu', 'Kalembutillu', -9.5604000, 119.2436500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70067, 'Weetombo', 'Weetombo', 'Weetombo', -9.5660000, 119.1284000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70068, 'Weekombaka', 'Weekombaka', 'Weekombaka', -9.5100000, 119.1419000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70069, 'Radamata', 'Radamata', 'Radamata', -9.5490000, 119.1460000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70070, 'Pasonobenu', 'Pasonobenu', 'Pasonobenu', -9.5502000, 119.1705000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70071, 'Manola', 'Manola', 'Manola', -9.5639000, 119.2014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70072, 'Weekaka', 'Weekaka', 'Weekaka', -9.5662000, 119.2206000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70073, 'Delo', 'Delo', 'Delo', -9.5948000, 119.2125000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70074, 'Ombakamia', 'Ombakamia', 'Ombakamia', -9.5224000, 119.3037000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70075, 'Weegaingo', 'Weegaingo', 'Weegaingo', -9.5278000, 119.3521000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70076, 'Watulabara', 'Watulabara', 'Watulabara', -9.5295000, 119.2674000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70077, 'Weerame', 'Weerame', 'Weerame', -9.5418000, 119.2876000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70078, 'Andelara', 'Andelara', 'Andelara', -9.5433000, 119.3115000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70079, 'Weelimbu', 'Weelimbu', 'Weelimbu', -9.5623000, 119.3374000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70080, 'Ombarade', 'Ombarade', 'Ombarade', -9.5627800, 119.3022000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70081, 'Andekantor', 'Andekantor', 'Andekantor', -9.5820000, 119.3670000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70082, 'Weepanapi', 'Weepanapi', 'Weepanapi', -9.5739000, 119.4456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70083, 'Bondoboghila', 'Bondoboghila', 'Bondoboghila', -9.4116000, 119.3532000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70084, 'Weepangali', 'Weepangali', 'Weepangali', -9.4266000, 119.2635000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70085, 'Tanatoku', 'Tanatoku', 'Tanatoku', -9.5210000, 119.5393000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70086, 'Tamaau', 'Tamaau', 'Tamaau', -9.5904000, 119.5557000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70087, 'Katikuloko', 'Katikuloko', 'Katikuloko', -9.5977000, 119.5426000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70088, 'Wailolung', 'Wailolung', 'Wailolung', -9.5875000, 119.5816000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70089, 'Waihibar', 'Waihibar', 'Waihibar', -9.6099000, 119.6237000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70090, 'Manukaka', 'Manukaka', 'Manukaka', -9.5972000, 119.5876000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70091, 'Kabondok', 'Kabondok', 'Kabondok,Kabunduk', -9.5994000, 119.5720000, 'ID', '2013-03-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70092, 'Galubakul', 'Galubakul', 'Galubakul', -9.6207400, 119.5667100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70093, 'Teongtoda', 'Teongtoda', 'Teongtoda', -8.6431000, 120.0041000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70094, 'Werang', 'Werang', 'Werang', -8.6488000, 120.0106000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70095, 'Rambang', 'Rambang', 'Rambang', -8.6480000, 120.0462000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70096, 'Nunang', 'Nunang', 'Nunang', -8.7202000, 120.0044000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70097, 'Dahot', 'Dahot', 'Dahot', -8.6474000, 120.0723000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70098, 'Laci', 'Laci', 'Laci', -8.6939000, 120.1069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70099, 'Montongkemong', 'Montongkemong', 'Montongkemong', -8.4905000, 116.5543000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70100, 'Rasabou', 'Rasabou', 'Rasabou', -8.5369000, 118.2549000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70101, 'Npongge', 'Npongge', 'Npongge', -8.5531000, 118.2923000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70102, 'Waikambila', 'Waikambila', 'Waikambila', -9.5324000, 119.6690000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70103, 'Bolubewa', 'Bolubewa', 'Bolubewa', -9.5330000, 119.7136000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70104, 'Paukate', 'Paukate', 'Paukate', -8.8128000, 120.8544000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70105, 'Waelengga', 'Waelengga', 'Waelengga', -8.8261000, 120.8073000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70106, 'Lurut', 'Lurut', 'Lurut', -8.6528000, 120.6591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70107, 'Waling', 'Waling', 'Waling', -8.6466000, 120.6378000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70108, 'Ngusu', 'Ngusu', 'Ngusu', -8.7065000, 120.6769000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70109, 'Lewe', 'Lewe', 'Lewe', -8.7440000, 120.6452000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70110, 'Pejek', 'Pejek', 'Pejek', -8.6461000, 120.7225000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70111, 'Ranambeling', 'Ranambeling', 'Ranambeling', -8.6595000, 120.7129000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70112, 'Mukun', 'Mukun', 'Mukun', -8.6580000, 120.6961000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70113, 'Dalo', 'Dalo', 'Dalo', -8.6593000, 120.6965000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70114, 'Pedak', 'Pedak', 'Pedak', -8.6710000, 120.6931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70115, 'Sawirara', 'Sawirara', 'Sawirara', -9.3925000, 119.4780000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70116, 'Lokori', 'Lokori', 'Lokori', -9.4194000, 119.3980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70117, 'Malata', 'Malata', 'Malata', -9.4466000, 119.3845000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70118, 'Bolengpulau', 'Bolengpulau', 'Bolengpulau', -8.4384000, 119.9943000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70119, 'Rungkam', 'Rungkam', 'Rungkam', -8.4734000, 119.9896000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70120, 'Waewaso', 'Waewaso', 'Waewaso', -8.4905000, 119.8967000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70121, 'Cempa', 'Cempa', 'Cempa', -8.4930000, 119.8782000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70122, 'Puunage', 'Puunage', 'Puunage', -8.8816000, 121.2125000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70123, 'Maukeli', 'Maukeli', 'Maukeli', -8.8932000, 121.1616000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70124, 'Batawa', 'Batawa', 'Batawa', -8.8954000, 121.1482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70125, 'Maumbawa', 'Maumbawa', 'Maumbawa', -8.8985000, 121.1368000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70126, 'Maumaru', 'Maumaru', 'Maumaru', -10.0036000, 120.4978000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70127, 'Panjir', 'Panjir', 'Panjir', -10.0250000, 120.4072000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70128, 'Umanggudang', 'Umanggudang', 'Umanggudang', -10.0533000, 120.4839000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70129, 'Latang', 'Latang', 'Latang', -10.0963000, 120.3815000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70130, 'Landa', 'Landa', 'Landa', -9.5923000, 120.2233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70131, 'Tambulatana', 'Tambulatana', 'Tambulatana', -9.5128000, 120.1979000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70132, 'Praimarada', 'Praimarada', 'Praimarada', -9.8912800, 120.6216500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70133, 'Nasawewe', 'Nasawewe', 'Nasawewe', -8.8829000, 121.2796000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70134, 'Bongewu', 'Bongewu', 'Bongewu', -8.7785000, 120.9539000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70135, 'Bogenga', 'Bogenga', 'Bogenga', -8.7769000, 120.9613000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70136, 'Trikora', 'Trikora', 'Trikora', -8.7865000, 120.9715000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70137, 'Ngedukelu', 'Ngedukelu', 'Ngedukelu', -8.7877000, 120.9748000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70138, 'Kisanata', 'Kisanata', 'Kisanata', -8.7901000, 120.9697000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70139, 'Tanalodu', 'Tanalodu', 'Tanalodu', -8.7908000, 120.9740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70140, 'Mari', 'Mari', 'Mari', -8.8277000, 120.9617000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70141, 'Bojawa', 'Bojawa', 'Bojawa', -8.8341000, 120.9593000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70142, 'Maunuri', 'Maunuri', 'Maunuri', -8.8899000, 121.2806000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70143, 'Romba', 'Romba', 'Romba', -8.9039000, 121.2961000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70144, 'Bengga', 'Bengga', 'Bengga', -8.9084500, 121.3097100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70145, 'Wangkung', 'Wangkung', 'Wangkung', -8.5161000, 120.0092000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70146, 'Betong', 'Betong', 'Betong', -8.5160000, 120.0488000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70147, 'Ndewel', 'Ndewel', 'Ndewel', -8.5838600, 120.0486400, 'ID', '2012-09-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70148, 'Tondongraja', 'Tondongraja', 'Tondongraja', -8.5833000, 120.0582000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70149, 'Golondalas', 'Golondalas', 'Golondalas', -8.5938000, 120.0180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70150, 'Ranggawatu', 'Ranggawatu', 'Ranggawatu', -8.6121500, 120.0444100, 'ID', '2012-09-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70151, 'Bambor', 'Bambor', 'Bambor', -8.6126000, 120.0598000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70152, 'Mberheleng', 'Mberheleng', 'Mbrehelang', -8.5121000, 120.0661000, 'ID', '2012-09-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70153, 'Zepe', 'Zepe', 'Zepe', -8.7681300, 121.0931900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70154, 'Pogo', 'Pogo', 'Pogo', -8.7962000, 121.1086000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70155, 'Mangulewa', 'Mangulewa', 'Mangulewa', -8.8194000, 121.0186000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70156, 'Ranisoba', 'Ranisoba', 'Ranisoba', -8.8231000, 121.0194000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70157, 'Dorupare', 'Dorupare', 'Dorupare', -8.8229000, 121.0530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70158, 'Mataloko', 'Mataloko', 'Mataloko', -8.8206000, 121.0630000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70159, 'Sobo', 'Sobo', 'Sobo', -8.8237000, 121.0224000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70160, 'Taka', 'Taka', 'Taka', -8.8406000, 121.1140000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70161, 'Warekeo', 'Warekeo', 'Warekeo', -8.8445000, 121.0109000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70162, 'Jadho', 'Jadho', 'Jadho', -8.8428000, 121.0511000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70163, 'Nuamuzi', 'Nuamuzi', 'Nuamuzi', -8.8567000, 121.0120000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70164, 'Waturoka', 'Waturoka', 'Waturoka', -8.8714000, 121.0852000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70165, 'Kampungbajo', 'Kampungbajo', 'Kampungbajo', -8.3457000, 120.1481000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70166, 'Genang', 'Genang', 'Genang', -8.3462000, 120.2006000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70167, 'Toroloji', 'Toroloji', 'Toroloji', -8.3582000, 120.1693000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70168, 'Tibakisa', 'Tibakisa', 'Tibakisa', -8.7571000, 121.1788000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70169, 'Wologama', 'Wologama', 'Wologama', -8.7785000, 121.2438000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70170, 'Jawagae', 'Jawagae', 'Jawagae', -8.7681000, 121.2366000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70171, 'Mulakoli', 'Mulakoli', 'Mulakoli', -8.8044000, 121.2180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70172, 'Wolonio', 'Wolonio', 'Wolonio', -8.7833000, 121.2190000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70173, 'Rega', 'Rega', 'Rega', -8.7678000, 121.2086000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70174, 'Wudu', 'Wudu', 'Wudu', -8.7742000, 121.2034000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70175, 'Nunukae', 'Nunukae', 'Nunukae', -8.8011000, 121.1530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70176, 'Padhahegha', 'Padhahegha', 'Padhahegha', -8.7733000, 121.1370000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70177, 'Hobonio', 'Hobonio', 'Hobonio', -8.7867000, 121.1256000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70178, 'Wagha', 'Wagha', 'Wagha', -8.8678500, 121.1588600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70179, 'Doya', 'Doya', 'Doya', -8.8234000, 121.1626000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70180, 'Sukamaju', 'Sukamaju', 'Sukamaju', -8.8564000, 121.1930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70181, 'Pajoreja', 'Pajoreja', 'Pajoreja', -8.8449000, 121.1956000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70182, 'Dawe', 'Dawe', 'Dawe', -8.8456000, 121.2032000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70183, 'Lokawolo', 'Lokawolo', 'Lokawolo', -8.8406000, 121.2102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70184, 'Gelu', 'Gelu', 'Gelu', -8.8503000, 121.2180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70185, 'Pusu', 'Pusu', 'Pusu', -8.8328000, 121.2478000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70186, 'Nggilat', 'Nggilat', 'Nggilat', -8.3082000, 120.2503000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70187, 'Sambelia', 'Sambelia', 'Sambelia', -8.3791000, 116.6869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70188, 'Waetuwa', 'Waetuwa', 'Waetuwa', -8.3796000, 120.6062000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70189, 'Golopau', 'Golopau', 'Golopau', -8.4101000, 120.5502000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70190, 'Waso', 'Waso', 'Waso', -8.4298000, 120.5859000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70191, 'Bentengjawa', 'Bentengjawa', 'Bentengjawa', -8.4569000, 120.5722000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70192, 'Rentung', 'Rentung', 'Rentung', -8.4572000, 120.5498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70193, 'Golomunta', 'Golomunta', 'Golomunta', -8.4636000, 120.5128000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70194, 'Kenca', 'Kenca', 'Kenca', -8.4727000, 120.5590000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70195, 'Moso', 'Moso', 'Moso', -8.4781000, 120.5121000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70196, 'Necak', 'Necak', 'Necak', -8.4918000, 120.6190000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70197, 'Naru', 'Naru', 'Naru', -8.7645000, 120.9863000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70198, 'Lekosoro', 'Lekosoro', 'Lekosoro', -8.7826000, 120.9793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70199, 'Bosiko', 'Bosiko', 'Bosiko', -8.8101000, 120.9907000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70200, 'Pasolapida', 'Pasolapida', 'Pasolapida', -9.6400000, 119.1631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70201, 'Dampek', 'Dampek', 'Dampek', -8.3010000, 120.5938000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70202, 'Satarteu', 'Satarteu', 'Satarteu', -8.3210000, 120.5178000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70203, 'Weleng', 'Weleng', 'Weleng', -8.4050000, 120.5233100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70204, 'Nangahaledoi', 'Nangahaledoi', 'Nangahaledoi', -8.6325000, 122.3193000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70205, 'Waipare', 'Waipare', 'Waipare', -8.6374000, 122.2787000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70206, 'Higetegera', 'Higetegera', 'Higetegera', -8.6464000, 122.2744000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70207, 'Kawapante', 'Kawapante', 'Kawapante', -8.6461000, 122.2958000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70208, 'Nitakloang', 'Nitakloang', 'Nitakloang', -8.6622000, 122.2915000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70209, 'Watuliwung', 'Watuliwung', 'Watuliwung', -8.6579000, 122.2543000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70210, 'Potet', 'Potet', 'Potet', -8.6830000, 122.3081000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70211, 'Kloangrotat', 'Kloangrotat', 'Kloangrotat', -8.6793000, 122.3355000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70212, 'Aibura', 'Aibura', 'Aibura', -8.6670000, 122.3319000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70213, 'Baobatun', 'Baobatun', 'Baobatun', -8.6873000, 122.2811000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70214, 'Magetlegar', 'Magetlegar', 'Magetlegar', -8.6986000, 122.3514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70215, 'Ojan', 'Ojan', 'Ojan', -8.7026000, 122.2607000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70216, 'Bei', 'Bei', 'Bei', -8.7006000, 122.2707000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70217, 'Watublapi', 'Watublapi', 'Watublapi', -8.7010000, 122.3132000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70218, 'Kloangpopot', 'Kloangpopot', 'Kloangpopot', -8.7115000, 122.3518000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70219, 'Habibola', 'Habibola', 'Habibola', -8.7490000, 122.3704000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70220, 'Wolokoli', 'Wolokoli', 'Wolokoli', -8.7281000, 122.2805000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70221, 'Taranggatar', 'Taranggatar', 'Taranggatar', -8.7383000, 122.2709000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70222, 'Tiang', 'Tiang', 'Tiang', -8.0015000, 111.8883000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70223, 'Tebokan', 'Tebokan', 'Tebokan', -8.0056000, 111.9137000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70224, 'Pulerejo', 'Pulerejo', 'Pulerejo', -8.0030000, 111.9411000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70225, 'Temenggungan', 'Temenggungan', 'Temenggungan', -8.0015000, 111.9827000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70226, 'Ngamba', 'Ngamba', 'Ngamba', -8.0146000, 111.9856000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70227, 'Tambakrejo', 'Tambakrejo', 'Tambakrejo', -8.0110000, 111.9641000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70228, 'Ngasinan', 'Ngasinan', 'Ngasinan', -8.0116000, 111.9317000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70229, 'Sembon', 'Sembon', 'Sembon', -8.0137000, 111.9021000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70230, 'Sukowidodo Barat', 'Sukowidodo Barat', 'Sukowidodo Barat', -8.0116000, 111.8910000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70231, 'Setonobendo', 'Setonobendo', 'Setonobendo', -8.0186000, 111.8829000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70232, 'Tamanan', 'Tamanan', 'Tamanan', -8.0234000, 111.8932000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70233, 'Pinggirsari', 'Pinggirsari', 'Pinggirsari', -8.0245000, 111.9413000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70234, 'Salam', 'Salam', 'Salam', -8.0256000, 111.9759000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70235, 'Balong', 'Balong', 'Balong', -8.0321000, 111.9576000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70236, 'Tapan', 'Tapan', 'Tapan', -8.0332000, 111.9303000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70237, 'Gendingsari', 'Gendingsari', 'Gendingsari', -8.0283000, 111.9093000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70238, 'Bungur', 'Bungur', 'Bungur', -8.0271000, 111.8887000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70239, 'Simo Satu', 'Simo Satu', 'Simo Satu', -8.0366000, 111.9029000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70240, 'Majan', 'Majan', 'Majan', -8.0393000, 111.9024000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70241, 'Mayangan', 'Mayangan', 'Mayangan', -8.0387000, 111.9561000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70242, 'Ngrawan', 'Ngrawan', 'Ngrawan', -8.0339000, 111.9786000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70243, 'Tawangrejo', 'Tawangrejo', 'Tawangrejo', -8.0357000, 111.9937000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70244, 'Kaliboto', 'Kaliboto', 'Kaliboto', -8.0431000, 111.9799000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70245, 'Bangoan', 'Bangoan', 'Bangoan', -8.0443000, 111.9410000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70246, 'Rejoagung', 'Rejoagung', 'Rejoagung', -8.0439000, 111.9135000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70247, 'Kanugrahan', 'Kanugrahan', 'Kanugrahan', -8.0503000, 111.8995000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70248, 'Batangsaren', 'Batangsaren', 'Batangsaren', -8.0540000, 111.8810000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70249, 'Sentulan', 'Sentulan', 'Sentulan', -8.0591000, 111.8895000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70250, 'Kedungtaman', 'Kedungtaman', 'Kedungtaman', -8.0547000, 111.9114000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70251, 'Bulusari', 'Bulusari', 'Bulusari', -8.0502000, 111.9500000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70252, 'Kedungdoro', 'Kedungdoro', 'Kedungdoro', -8.0577000, 111.9502000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70253, 'Pucung', 'Pucung', 'Pucung', -8.0530000, 111.9732000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70254, 'Sambirobyong', 'Sambirobyong', 'Sambirobyong', -8.0649000, 111.9694000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70255, 'Ringinagung', 'Ringinagung', 'Ringinagung', -8.0608000, 111.9323000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70256, 'Mekarsari', 'Mekarsari', 'Mekarsari', -8.0648000, 111.9237000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70257, 'Kepatihan', 'Kepatihan', 'Kepatihan', -8.0629000, 111.9133000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70258, 'Sembung', 'Sembung', 'Sembung', -8.0610000, 111.8957000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70259, 'Kauman', 'Kauman', 'Kauman', -8.0649000, 111.8964000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70260, 'Kutoanyar', 'Kutoanyar', 'Kutoanyar', -8.0677000, 111.8900000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70261, 'Tertek', 'Tertek', 'Tertek', -8.0704000, 111.8919000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70262, 'Karangwaru', 'Karangwaru', 'Karangwaru', -8.0703000, 111.8984000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70263, 'Tamanan', 'Tamanan', 'Tamanan', -8.0722000, 111.9026000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70264, 'Bago', 'Bago', 'Bago', -8.0684000, 111.9091000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70265, 'Ngrukem', 'Ngrukem', 'Ngrukem', -8.0786000, 111.9794000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70266, 'Jabalan', 'Jabalan', 'Jabalan', -8.0822000, 111.9666000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70267, 'Selojeneng', 'Selojeneng', 'Selojeneng', -8.0783000, 111.9466000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70268, 'Kudusan', 'Kudusan', 'Kudusan', -8.0785000, 111.9268000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70269, 'Jepun', 'Jepun', 'Jepun', -8.0755000, 111.9108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70270, 'Serut', 'Serut', 'Serut', -8.0810000, 111.9097000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70271, 'Gedangsewu Selatan', 'Gedangsewu Selatan', 'Gedangsewu Selatan', -8.0759000, 111.8894000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70272, 'Pacet', 'Pacet', 'Pacet', -8.0786000, 111.8818000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70273, 'Tanggulangin', 'Tanggulangin', 'Tanggulangin', -8.0850000, 111.9257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70274, 'Bendilmuning', 'Bendilmuning', 'Bendilmuning', -8.0925000, 111.9417000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70275, 'Sadar', 'Sadar', 'Sadar', -8.0906000, 111.9522000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70276, 'Pulosari', 'Pulosari', 'Pulosari', -8.0928000, 111.9890000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70277, 'Kromasan', 'Kromasan', 'Kromasan', -8.0970000, 111.9790000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70278, 'Setonokalong', 'Setonokalong', 'Setonokalong', -8.0934000, 111.9629000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70279, 'Kedungsinggil', 'Kedungsinggil', 'Kedungsinggil', -8.0993000, 111.9161000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70280, 'Ngipik', 'Ngipik', 'Ngipik', -8.1036000, 111.8766000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70281, 'Karanggayam', 'Karanggayam', 'Karanggayam', -8.1002000, 111.9110000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70282, 'Bayanan', 'Bayanan', 'Bayanan', -8.1031000, 111.9128000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70283, 'Doropayung', 'Doropayung', 'Doropayung', -8.1069000, 111.9403000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70284, 'Tambaksumber', 'Tambaksumber', 'Tambaksumber', -8.1041000, 111.9518000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70285, 'Sadeng', 'Sadeng', 'Sadeng', -8.1073000, 111.9664000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70286, 'Sumberjo Kulon', 'Sumberjo Kulon', 'Sumberjo Kulon', -8.1082000, 111.9923000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70287, 'Dukuh', 'Dukuh', 'Dukuh', -8.1090000, 111.9764000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70288, 'Dawuhan', 'Dawuhan', 'Dawuhan', -8.1135000, 111.9474000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70289, 'Wajak', 'Wajak', 'Wajak', -8.1087000, 111.9153000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70290, 'Genting', 'Genting', 'Genting', -8.1191000, 111.8844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70291, 'Blimbing', 'Blimbing', 'Blimbing', -8.1238000, 111.8841000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70292, 'Pucung Kidul', 'Pucung Kidul', 'Pucung Kidul', -8.1208000, 111.9040000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70293, 'Sanggrahan Kidul', 'Sanggrahan Kidul', 'Sanggrahan Kidul', -8.1207000, 111.9147000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70294, 'Mojo', 'Mojo', 'Mojo', -8.1185000, 111.9206000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70295, 'Bendilwungu Lor', 'Bendilwungu Lor', 'Bendilwungu Lor', -8.1197000, 111.9532000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70296, 'Cangkringan', 'Cangkringan', 'Cangkringan', -8.1199000, 111.9707000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70297, 'Banyuanyar', 'Banyuanyar', 'Banyuanyar', -8.2664000, 113.9780000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70298, 'Kalibaru Kulon', 'Kalibaru Kulon', 'Kalibaru Kulon', -8.2877000, 113.9791000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70299, 'Satria', 'Satria', 'Satria', -8.3534000, 114.6267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70300, 'Loloan Timur', 'Loloan Timur', 'Loloan Timur', -8.3665000, 114.6258000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70301, 'Pamedilan', 'Pamedilan', 'Pamedilan', -8.3652000, 114.6433000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70302, 'Batuagung', 'Batuagung', 'Batuagung', -8.3592000, 114.6430000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70303, 'Banjar Sebual', 'Banjar Sebual', 'Banjar Sebual', -8.3661000, 114.6568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70304, 'Baler Baleagung', 'Baler Baleagung', 'Baler Baleagung', -8.3728000, 114.6710000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70305, 'Grujugan', 'Grujugan', 'Grujugan', -7.7776000, 114.0056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70306, 'Krajan Satu Klampokan', 'Krajan Satu Klampokan', 'Krajan Satu Klampokan', -7.7548000, 114.0519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70307, 'Sumuranyar', 'Sumuranyar', 'Sumuranyar', -7.7546000, 114.0625000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70308, 'Jatisari Satu', 'Jatisari Satu', 'Jatisari Satu', -7.7637000, 114.1015000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70309, 'Coratatal', 'Coratatal', 'Coratatal', -7.7799000, 114.0783000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70310, 'Suling Kulon', 'Suling Kulon', 'Suling Kulon', -7.7897000, 114.0375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70311, 'Ramban Kulon', 'Ramban Kulon', 'Ramban Kulon', -7.7773000, 114.0189000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70312, 'Krajan Bandilan', 'Krajan Bandilan', 'Krajan Bandilan', -7.7954000, 114.0117000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70313, 'Banyumas', 'Banyumas', 'Banyumas', -7.7972000, 114.0042000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70314, 'Duwe', 'Duwe', 'Duwe', -7.8742000, 114.0014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70315, 'Kladi', 'Kladi', 'Kladi', -7.8160000, 114.0859000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70316, 'Kepeg Satu', 'Kepeg Satu', 'Kepeg Satu', -7.8378000, 114.0712000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70317, 'Besisora', 'Besisora', 'Besisora', -8.8579000, 116.8277000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70318, 'Jelateng Timur', 'Jelateng Timur', 'Jelateng Timur', -8.7548000, 116.0850000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70319, 'Tawun', 'Tawun', 'Tawun', -8.7526000, 116.0081000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70320, 'Sukadana', 'Sukadana', 'Sukadana', -8.2273000, 115.5413000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70321, 'Baturinggit Kaja', 'Baturinggit Kaja', 'Baturinggit Kaja', -8.2464000, 115.5631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70322, 'Padedemanu', 'Padedemanu', 'Padedemanu', -9.4508000, 119.1032000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70323, 'Baroh', 'Baroh', 'Baroh', -9.4884000, 119.0430000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70324, 'Sangumata', 'Sangumata', 'Sangumata', -9.4033000, 119.5606000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70325, 'Tolomango', 'Tolomango', 'Tolomango', -8.5052000, 118.6133000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70326, 'Melati', 'Melati', 'Melati', -8.5072000, 118.6234000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70327, 'Leu', 'Leu', 'Leu', -8.5066000, 118.6245000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70328, 'Tambe', 'Tambe', 'Tambe', -8.5098000, 118.6050000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70329, 'Beringin', 'Beringin', 'Beringin', -8.5237000, 118.5721000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70330, 'Rate', 'Rate', 'Rate', -8.5402000, 118.5554000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70331, 'Woro', 'Woro', 'Woro', -8.5730000, 118.5437000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70332, 'Pataha', 'Pataha', 'Pataha', -8.5297000, 119.0095000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70333, 'Naebugis', 'Naebugis', 'Naebugis', -8.5774000, 119.0069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70334, 'Bombo', 'Bombo', 'Bombo', -8.6131000, 119.0131000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70335, 'Sigirato', 'Sigirato', 'Sigirato', -8.6189000, 119.0126000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70336, 'Harapankarya', 'Harapankarya', 'Harapankarya', -3.9893000, 119.6438000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70337, 'Walakeri', 'Walakeri', 'Walakeri', -10.2057000, 120.5290000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70338, 'Mbulung', 'Mbulung', 'Mbulung', -10.2241000, 120.5400000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70339, 'Pahenya', 'Pahenya', 'Pahenya', -10.2050000, 120.5344000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70340, 'Umakadambung', 'Umakadambung', 'Umakadambung', -10.2136000, 120.5602000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70341, 'Walakeri', 'Walakeri', 'Walakeri', -9.9367000, 120.1510000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70342, 'Bidikotak', 'Bidikotak', 'Bidikotak', -9.8323000, 120.1821000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70343, 'Penang', 'Penang', 'Penang', -9.8445600, 120.2463800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70344, 'Laimuda', 'Laimuda', 'Laimuda', -9.9866000, 120.3316000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70345, 'Belajen', 'Belajen', 'Belajen', -3.3235000, 119.8236000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70346, 'Karara', 'Karara', 'Karara', -9.6493000, 120.2418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70347, 'Umburarameha', 'Umburarameha', 'Umburarameha', -9.6638000, 120.2453000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70348, 'Kalumbang', 'Kalumbang', 'Kaloembang,Kalumbang', -9.8869000, 120.6535200, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70349, 'Apuhambati', 'Apuhambati', 'Apuhambati', -9.7228000, 120.2223000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70350, 'Meurumba', 'Meurumba', 'Meurumba', -9.9378000, 120.3910000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70351, 'Lajarik', 'Lajarik', 'Lajarik', -9.9755000, 120.4083000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70352, 'Lairoka', 'Lairoka', 'Lairoka', -9.9104000, 120.4871000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70353, 'Kawangu Satu', 'Kawangu Satu', 'Kawangu 1,Kawangu Satu', -9.6779000, 120.3281000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70354, 'Tanabara', 'Tanabara', 'Tanabara', -9.6907000, 120.2916000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70355, 'Tanahwurung', 'Tanahwurung', 'Tanahwurung', -9.6938000, 120.2763000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70356, 'Mangga Dua', 'Mangga Dua', 'Mangga 2,Mangga Dua', -9.6625000, 120.2926000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70357, 'Kamalaputi', 'Kamalaputi', 'Kamalaputi', -9.6484000, 120.2634000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70358, 'Gurusina', 'Gurusina', 'Gurusina', -8.8963000, 120.9906000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70359, 'Pomasule', 'Pomasule', 'Pomasule', -8.9091000, 120.9053000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70360, 'Malapedo B', 'Malapedo B', 'Malapedo B', -8.9180000, 120.9137000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70361, 'Ruto', 'Ruto', 'Ruto', -8.9254000, 120.9254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70362, 'Waebela', 'Waebela', 'Waebela', -8.9426000, 120.9731000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70363, 'Malapaubhara', 'Malapaubhara', 'Malapaubhara', -8.6467000, 121.1244000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70364, 'Waepana', 'Waepana', 'Waepana', -8.6926000, 121.0377000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70365, 'Soa', 'Soa', 'Soa', -8.6981000, 121.0361000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70366, 'Piga', 'Piga', 'Piga', -8.7140000, 121.0471000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70367, 'Loa', 'Loa', 'Loa', -8.7212000, 121.0464000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70368, 'Anafolo', 'Anafolo', 'Anafolo', -8.7207000, 121.0435000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70369, 'Masu', 'Masu', 'Masu', -8.7116000, 121.0397000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70370, 'Malawona', 'Malawona', 'Malawona', -8.6136000, 121.2309000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70371, 'Baobe', 'Baobe', 'Baobe', -8.5819000, 121.2337000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70372, 'Malabai', 'Malabai', 'Malabai', -8.5605000, 121.1514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70373, 'Nila Dua', 'Nila Dua', 'Nila Dua', -8.5106000, 121.2793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70374, 'Mbay', 'Mbay', 'Danga,Mbay', -8.5613000, 121.2717000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70375, 'Wewoloe', 'Wewoloe', 'Wewoloe', -8.5316000, 121.2600000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70376, 'Congkar', 'Congkar', 'Congkar', -8.2798000, 120.4090000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70377, 'Lanos', 'Lanos', 'Lanos', -8.2824000, 120.4087000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70378, 'Wangkung', 'Wangkung', 'Wangkung', -8.2874000, 120.4485000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70379, 'Sengari', 'Sengari', 'Sengari', -8.2891000, 120.4559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70380, 'Senggapi', 'Senggapi', 'Senggapi', -8.2980000, 120.4623000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70381, 'Baru', 'Baru', 'Baru', -8.3072000, 120.4911000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70382, 'Baru Timur', 'Baru Timur', 'Baru Timur', -8.3083000, 120.4912000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70383, 'Tanahputih', 'Tanahputih', 'Tanahputih', -8.3096000, 120.4830000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70384, 'Pering', 'Pering', 'Pering', -8.3230000, 120.3957000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70385, 'Ruis', 'Ruis', 'Ruis', -8.3651000, 120.4333000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70386, 'Punsu', 'Punsu', 'Punsu', -8.4191000, 121.0259000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70387, 'Golokutu', 'Golokutu', 'Golokutu', -8.4271000, 121.0264000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70388, 'Marolidhong', 'Marolidhong', 'Marolidhong', -8.4791000, 121.0306000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70389, 'Nduaria', 'Nduaria', 'Nduaria', -8.7121000, 121.8283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70390, 'Detusoko', 'Detusoko', 'Detusoko', -8.7166000, 121.7609000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70391, 'Koanara', 'Koanara', 'Koanara', -8.7485000, 121.8521000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70392, 'Nggelok', 'Nggelok', 'Nggelok', -8.6489000, 120.7616000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70393, 'Lete', 'Lete', 'Lete', -8.7409000, 120.7706000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70394, 'Bandaragung', 'Bandaragung', 'Bandaragung', -5.2922900, 105.6925500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70395, 'Gadingrejo', 'Gadingrejo', 'Gadingredjo,Gadingrejo,Gadingrĕdjŏ,Gandingredjo', -5.3723300, 105.0616300, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70396, 'Palas', 'Palas', 'Palas', -5.6519100, 105.6801100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70397, 'Sidorejo', 'Sidorejo', 'Sidorejo', -5.5847100, 105.5236400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70398, 'Pasuruan', 'Pasuruan', 'Pasuruan', -5.7463000, 105.6770700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70399, 'Penengahan', 'Penengahan', 'Panengahan,Penengahan', -5.7706000, 105.6969000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70400, 'Timurjaya', 'Timurjaya', 'Timurjaya', -5.8140900, 106.2850900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70401, 'Kedondong', 'Kedondong', 'Kedondong', -5.4628400, 105.0009000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70402, 'Pamotan', 'Pamotan', 'Pamotan', -7.6563900, 108.7666700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70403, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.6818000, 108.7633000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70404, 'Rawaapu', 'Rawaapu', 'Rawaapoe,Rawaapu', -7.6389400, 108.7570600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70405, 'Karanganyar', 'Karanganyar', 'Karanganjar,Karanganjar Satoe,Karanganyar', -7.6659000, 108.8205000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70406, 'Tambaksari', 'Tambaksari', 'Tambaksari', -7.5012000, 108.7511000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70407, 'Cipariuk', 'Cipariuk', 'Cipariuk', -7.5006800, 108.7683900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70408, 'Kedungbakung', 'Kedungbakung', 'Kedungbakung', -7.5052000, 108.7733300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70409, 'Mulyosari', 'Mulyosari', 'Mulyosari', -7.5073500, 108.7859300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70410, 'Muktisari', 'Muktisari', 'Muktisari', -7.5136000, 108.8564000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70411, 'Alurbulu', 'Alurbulu', 'Aloerboentoe,Alurbulu', -7.5121800, 108.8404200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70412, 'Ciklapa', 'Ciklapa', 'Ciklapa,Tjiklapa', -7.5097000, 108.8075000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70413, 'Kemantren Satu', 'Kemantren Satu', 'Kemantren Satu', -7.5272000, 108.8619000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70414, 'Gandrungmanis Lor', 'Gandrungmanis Lor', 'Gandrungmanis Lor', -7.5287000, 108.8568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70415, 'Wanadadi', 'Wanadadi', 'Wanadadi', -7.5331300, 108.8218000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70416, 'Sidaurip', 'Sidaurip', 'Sidaurip', -7.5417000, 108.7501000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70417, 'Kedungbulu', 'Kedungbulu', 'Kedoengboeloe,Kedungbulu', -7.5379000, 108.7836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70418, 'Cipari', 'Cipari', 'Cipari,Tjipari', -7.5370000, 108.8012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70419, 'Cawilayan', 'Cawilayan', 'Cawilayan', -7.5458000, 108.8555000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70420, 'Sidaurip', 'Sidaurip', 'Sidaurip', -7.5491600, 108.8378400, 'ID', '2014-01-23', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70421, 'Pondokwungu', 'Pondokwungu', 'Pondokwungu', -7.5556000, 108.7963100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70422, 'Cinyawang', 'Cinyawang', 'Cinyawang', -7.5741100, 108.7660600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70423, 'Sidakaya', 'Sidakaya', 'Sidakaya', -7.5753000, 108.8640000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70424, 'Kalenaren', 'Kalenaren', 'Kalenaren', -7.5800000, 108.7851400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70425, 'Kalenpring', 'Kalenpring', 'Kalenpring', -7.5850000, 108.7611000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70426, 'Purwodadi', 'Purwodadi', 'Purwodadi', -7.6020000, 108.7610000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70427, 'Kedungsalam', 'Kedungsalam', 'Kedungsalam', -7.6098000, 108.7556000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70428, 'Cimrutu', 'Cimrutu', 'Cimrutu', -7.6201000, 108.8005000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70429, 'Harian', 'Harian', 'Harian,Harianboho', 2.5561000, 98.6625000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70430, 'Tuktuk Sonak', 'Tuktuk Sonak', 'Toetoek Si Asoe,Tuktuk Sonak', 2.6689000, 98.8576000, 'ID', '2016-10-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70431, 'Tigarunggu', 'Tigarunggu', 'Tigarunggu', 2.8965000, 98.7226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70432, 'Sipintuangin', 'Sipintuangin', 'Sipintuangin', 2.8133000, 98.7904000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70433, 'Sarimatondang', 'Sarimatondang', 'Sarimatondang,Sori Ma Tondang', 2.8641000, 98.9155000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70434, 'Pane Tongah', 'Pane Tongah', 'Pane Tongah', 2.9059000, 98.9723000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70435, 'Cijapar', 'Cijapar', 'Cijapar', -6.8914000, 106.4291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70436, 'Cikamunding', 'Cikamunding', 'Cikamunding', -6.9065000, 106.3858000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70437, 'Gunungempuk', 'Gunungempuk', 'Gunungempuk', -6.9106000, 106.4401000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70438, 'Pasirbungur', 'Pasirbungur', 'Pasirbungur', -6.9319000, 106.3804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70439, 'Tugu', 'Tugu', 'Tugu', -6.9462000, 106.4469000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70440, 'Cibangban Girang', 'Cibangban Girang', 'Cibangban Girang', -6.9569000, 106.4280000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70441, 'Karangpapak', 'Karangpapak', 'Karangpapak', -6.9604000, 106.4717000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70442, 'Bantarjati', 'Bantarjati', 'Bantarjati', -6.9720000, 106.3899000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70443, 'Babakanbungur', 'Babakanbungur', 'Babakanbungur', -6.5533000, 105.7009000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70444, 'Songgom', 'Songgom', 'Songgom', -6.5627000, 105.7426000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70445, 'Cigeulis', 'Cigeulis', 'Cigeulis', -6.5876000, 105.6924000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70446, 'Marapat', 'Marapat', 'Marapat', -6.6099700, 105.6969200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70447, 'Warungbanten', 'Warungbanten', 'Warungbanten', -6.8327000, 106.3293000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70448, 'Ciburial', 'Ciburial', 'Ciburial', -6.8449000, 106.3740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70449, 'Cisuren', 'Cisuren', 'Cisuren', -6.8591000, 106.2639000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70450, 'Cipalasari', 'Cipalasari', 'Cipalasari', -6.8659000, 106.2821000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70451, 'Cihambali', 'Cihambali', 'Cihambali', -6.8036000, 106.3304000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70452, 'Ciayunan', 'Ciayunan', 'Ciayunan', -6.8211000, 106.3049000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70453, 'Peusar', 'Peusar', 'Peusar', -6.6332000, 105.7180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70454, 'Babakantengah', 'Babakantengah', 'Babakantengah', -6.6421000, 105.6979000, 'ID', '2011-09-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70455, 'Cikadondongdesa', 'Cikadondongdesa', 'Cikadondongdesa', -6.6609000, 105.6983000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70456, 'Gunungkendeng', 'Gunungkendeng', 'Gunungkendeng', -6.6794000, 105.7043000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70457, 'Salam', 'Salam', 'Salam', -6.6914000, 105.7176000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70458, 'Babakantonggoh', 'Babakantonggoh', 'Babakantonggoh', -6.6945000, 105.6296000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70459, 'Polos', 'Polos', 'Polos', -6.7001000, 105.6493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70460, 'Ciunil Barat', 'Ciunil Barat', 'Ciunil Barat', -6.6974000, 105.6639000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70461, 'Sukajadi', 'Sukajadi', 'Sukajadi', -6.7144000, 105.7062000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70462, 'Babakancibaliung', 'Babakancibaliung', 'Babakancibaliung', -6.7176000, 105.7369000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70463, 'Cangkeuteuk Sabrang', 'Cangkeuteuk Sabrang', 'Cangkeuteuk Sabrang', -6.7267000, 105.6259000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70464, 'Kadubadak', 'Kadubadak', 'Kadubadak', -6.6476000, 105.8611000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70465, 'Leuwibuleud', 'Leuwibuleud', 'Leuwibuleud', -6.6825000, 105.8573000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70466, 'Bungurdua', 'Bungurdua', 'Bungurdua', -6.7148000, 105.7805000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70467, 'Dahu Satu', 'Dahu Satu', 'Dahu Satu', -6.7373000, 105.8014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70468, 'Benger', 'Benger', 'Benger', -6.7358000, 105.8433000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70469, 'Cidikit Girang', 'Cidikit Girang', 'Cidikit Girang', -6.8783000, 106.3166000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70470, 'Cimancak', 'Cimancak', 'Cimancak', -6.8994000, 106.2619000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70471, 'Pasirgembong', 'Pasirgembong', 'Pasirgembong', -6.8966000, 106.2840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70472, 'Margamukti', 'Margamukti', 'Margamukti', -6.9068000, 106.3487000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70473, 'Warunglame', 'Warunglame', 'Warunglame', -6.9181000, 106.2625000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70474, 'Lebaktipar', 'Lebaktipar', 'Lebaktipar', -6.9428000, 106.3367000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70475, 'Sindanglaut', 'Sindanglaut', 'Sindanglaut', -6.9480000, 106.2561000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70476, 'Cisujen Satu', 'Cisujen Satu', 'Cisujen Satu', -6.9776000, 106.3056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70477, 'Rancasadang', 'Rancasadang', 'Rancasadang', -6.7554000, 105.6806000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70478, 'Sudimanik', 'Sudimanik', 'Sudimanik', -6.7528000, 105.7277000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70479, 'Sorongan', 'Sorongan', 'Sorongan', -6.7581000, 105.7483000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70480, 'Tugu Hilir', 'Tugu Hilir', 'Tugu Hilir', -6.8092000, 105.6292000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70481, 'Pematangluhur', 'Pematangluhur', 'Pematangluhur', -6.7706000, 105.6461000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70482, 'Sindanglaya', 'Sindanglaya', 'Sindanglaya', -6.7756000, 105.6781000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70483, 'Citeluk', 'Citeluk', 'Citeluk', -6.7950000, 105.6735000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70484, 'Cicadas', 'Cicadas', 'Cicadas', -6.8249000, 105.6618000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70485, 'Cinyurup', 'Cinyurup', 'Cinyurup', -6.7772000, 105.6946000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70486, 'Leuwibuaya', 'Leuwibuaya', 'Leuwibuaya', -6.8115000, 105.6974000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70487, 'Sukapura', 'Sukapura', 'Sukapura', -6.7636000, 105.7211000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70488, 'Cikiruh', 'Cikiruh', 'Cikiruh', -6.7737000, 105.7226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70489, 'Cihaur', 'Cihaur', 'Cihaur', -6.7824000, 105.7110000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70490, 'Karamat', 'Karamat', 'Karamat', -6.7876000, 105.7213000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70491, 'Curug', 'Curug', 'Curug', -6.7616000, 105.7639000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70492, 'Cicadas', 'Cicadas', 'Cicadas', -6.7587000, 105.8018000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70493, 'Cikaramat', 'Cikaramat', 'Cikaramat', -6.7638000, 105.8275000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70494, 'Tanjungan', 'Tanjungan', 'Tanjungan', -6.8245000, 105.8270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70495, 'Umbulan', 'Umbulan', 'Umbulan', -6.7650000, 105.8559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70496, 'Rancaseneng', 'Rancaseneng', 'Rancaseneng', -6.7589000, 105.8671000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70497, 'Sukawaris', 'Sukawaris', 'Sukawaris', -6.8041000, 105.8639000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70498, 'Cibunar', 'Cibunar', 'Cibunar', -6.7942000, 106.2132000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70499, 'Cipancur', 'Cipancur', 'Cipancur', -6.8305000, 106.2360000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70500, 'Bangbayang', 'Bangbayang', 'Bangbayang', -6.8581000, 106.1751000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70501, 'Lebak', 'Lebak', 'Lebak', -6.6407200, 105.8752000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70502, 'Cigalih', 'Cigalih', 'Cigalih', -6.6659000, 105.8948000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70503, 'Curuglanglang', 'Curuglanglang', 'Curuglanglang', -6.6301000, 105.9198000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70504, 'Perumahan Kopi', 'Perumahan Kopi', 'Perumahan Kopi', -6.6770300, 105.9608600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70505, 'Kampungsawah', 'Kampungsawah', 'Kampungsawah', -6.6755000, 105.9760000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70506, 'Ciseda', 'Ciseda', 'Ciseda', -6.6352000, 105.9883000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70507, 'Pagenggang Selatan', 'Pagenggang Selatan', 'Pagenggang,Pagenggang Selatan', -6.7482000, 105.9866000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70508, 'Gintung Utara', 'Gintung Utara', 'Gintung Utara', -6.7298000, 105.9785000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70509, 'Senanghati', 'Senanghati', 'Senanghati', -6.7165000, 105.9627000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70510, 'Bunut', 'Bunut', 'Bunut', -6.7293800, 105.9114900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70511, 'Babakan', 'Babakan', 'Babakan', -6.7289000, 105.9065000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70512, 'Kiarajangkung', 'Kiarajangkung', 'Kiarajangkung', -6.7419000, 105.8804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70513, 'Daleum', 'Daleum', 'Daleum', -6.7520000, 105.9691000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70514, 'Cikiruh Wetan', 'Cikiruh Wetan', 'Cikiruh Wetan', -6.8262000, 105.8757000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70515, 'Sukamulya', 'Sukamulya', 'Sukamulya', -6.8121000, 105.8874000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70516, 'Cisarap', 'Cisarap', 'Cisarap', -6.7850000, 105.9093000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70517, 'Sukatani', 'Sukatani', 'Sukatani', -6.8009000, 105.9406000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70518, 'Kubang', 'Kubang', 'Kubang', -6.7864000, 106.4849000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70519, 'Cisungsang', 'Cisungsang', 'Cisungsang', -6.8004000, 106.4245000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70520, 'Kujangsari', 'Kujangsari', 'Kujangsari', -6.7864000, 106.4278000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70521, 'Situmulya', 'Situmulya', 'Situmulya', -6.7866000, 106.4322000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70522, 'Cipanggung', 'Cipanggung', 'Cipanggung', -6.8153000, 106.3752000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70523, 'Cikadu', 'Cikadu', 'Cikadu', -6.8238000, 106.4220000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70524, 'Cinangka', 'Cinangka', 'Cinangka', -6.8707000, 106.3989000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70525, 'Pasirkadu', 'Pasirkadu', 'Pasirkadu', -6.5154000, 105.8530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70526, 'Teladan', 'Teladan', 'Teladan', -6.5224000, 105.8246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70527, 'Perintis', 'Perintis', 'Perintis', -6.5278000, 105.8029000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70528, 'Jambubol', 'Jambubol', 'Jambubol', -6.5465000, 105.8728000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70529, 'Rancahideung', 'Rancahideung', 'Rancahideung', -6.5425000, 105.8477000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70530, 'Seuseupan', 'Seuseupan', 'Seuseupan', -6.5464000, 105.8195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70531, 'Pangkalan', 'Pangkalan', 'Pangkalan', -6.5583000, 105.7574000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70532, 'Kalapadua', 'Kalapadua', 'Kalapadua', -6.5639100, 105.8549500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70533, 'Sobang', 'Sobang', 'Sobang', -6.5622000, 105.7571000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70534, 'Bojen Kulon', 'Bojen Kulon', 'Bojen Kulon', -6.5638000, 105.7878000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70535, 'Awilega', 'Awilega', 'Awilega', -6.5666600, 105.8481200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70536, 'Carodok', 'Carodok', 'Carodok', -6.5823000, 105.8508000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70537, 'Sumurwaru', 'Sumurwaru', 'Sumurwaru', -6.5770000, 105.8068000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70538, 'Cimara', 'Cimara', 'Cimara', -6.5843600, 105.8251700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70539, 'Cibodas', 'Cibodas', 'Cibodas', -6.5935000, 105.8584000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70540, 'Cangkeuteuk', 'Cangkeuteuk', 'Cangkeuteuk', -6.5985000, 105.7893000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70541, 'Keboncau', 'Keboncau', 'Keboncau', -6.6281000, 106.2101000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70542, 'Datarcae', 'Datarcae', 'Datarcae', -6.6509000, 106.1622000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70543, 'Parigi', 'Parigi', 'Parigi', -6.6535000, 106.1960000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70544, 'Nyungcung', 'Nyungcung', 'Nyungcung', -6.7154800, 106.1410300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70545, 'Tunasbaru', 'Tunasbaru', 'Tunasbaru', -6.5089000, 105.9995000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70546, 'Jalupang Dua', 'Jalupang Dua', 'Jalupang Dua', -6.5415000, 105.9962000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70547, 'Kukuluk', 'Kukuluk', 'Kukuluk', -6.5620000, 105.9917000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70548, 'Anggrik', 'Anggrik', 'Anggrik,Angrik', -6.6222700, 105.9844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70549, 'Turus', 'Turus', 'Turus', -6.5064000, 105.8816000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70550, 'Kampungbaru', 'Kampungbaru', 'Kampungbaru', -6.5330000, 105.9002000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70551, 'Pasirloa', 'Pasirloa', 'Pasirloa', -6.5412000, 105.8879000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70552, 'Kampungmasjid', 'Kampungmasjid', 'Kampungmasjid', -6.5661000, 105.8914000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70553, 'Kadumelati', 'Kadumelati', 'Kadumelati', -6.5056000, 105.9212000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70554, 'Campaka', 'Campaka', 'Campaka', -6.5444000, 105.9203000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70555, 'Langkapcaang Hilir', 'Langkapcaang Hilir', 'Langkapcaang Hilir', -6.5483000, 105.9235000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70556, 'Cibeureum', 'Cibeureum', 'Cibeureum', -6.5991000, 105.9199000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70557, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan', -6.6052000, 105.9045000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70558, 'Pematang', 'Pematang', 'Pematang', -6.5080000, 105.9373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70559, 'Pasarbaru', 'Pasarbaru', 'Pasarbaru', -6.5210000, 105.9369000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70560, 'Ciodeng', 'Ciodeng', 'Ciodeng', -6.5791000, 105.9487000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70561, 'Cimoyan', 'Cimoyan', 'Cimoyan', -6.5334000, 105.9653000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70562, 'Ciruji Dua', 'Ciruji Dua', 'Ciruji Dua', -6.5301000, 105.9875000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70563, 'Kampungruweh', 'Kampungruweh', 'Kampungruweh', -6.5828000, 105.9839000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70564, 'Warungsugan', 'Warungsugan', 'Warungsugan', -6.5931000, 105.9780000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70565, 'Manggu', 'Manggu', 'Manggu', -6.6082000, 105.9787000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70566, 'Kampunglistrik', 'Kampunglistrik', 'Kampunglistrik', -6.3777000, 105.8291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70567, 'Lantera', 'Lantera', 'Lantera', -6.3780000, 105.8233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70568, 'Balekersukamaju', 'Balekersukamaju', 'Balekersukamaju', -6.3825000, 105.8361000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70569, 'Tarogong', 'Tarogong', 'Tarogong', -6.3929000, 105.8391000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70570, 'Montor Timur', 'Montor Timur', 'Montor Timur', -6.3952000, 105.8733000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70571, 'Kadubadak', 'Kadubadak', 'Kadubadak', -6.3910300, 105.8708700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70572, 'Kadupayung', 'Kadupayung', 'Kadupayung', -6.3968000, 105.8477000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70573, 'Kadugadung', 'Kadugadung', 'Kadugadung', -6.3928000, 105.8562000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70574, 'Pangampoan', 'Pangampoan', 'Pangampoan', -6.3989500, 105.8515500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70575, 'Tegalpanjang', 'Tegalpanjang', 'Tegalpanjang', -6.4115000, 105.8291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70576, 'Margahayu', 'Margahayu', 'Margahayu', -6.4264000, 105.8646100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70577, 'Tegalpapak', 'Tegalpapak', 'Tegalpapak', -6.4396000, 105.8254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70578, 'Kampungpinggirkali', 'Kampungpinggirkali', 'Kampungpinggirkali', -6.4403000, 105.8466000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70579, 'Surianeun', 'Surianeun', 'Surianeun', -6.4468000, 105.8585000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70580, 'Kebonjaya', 'Kebonjaya', 'Kebonjaya', -6.4446000, 105.8530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70581, 'Sidamukti', 'Sidamukti', 'Sidamukti', -6.4870100, 105.8032500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70582, 'Panimbang', 'Panimbang', 'Panimbang', -6.4943000, 105.7961000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70583, 'Neglasari', 'Neglasari', 'Neglasari', -6.4951000, 105.7936000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70584, 'Paojan', 'Paojan', 'Paojan', -6.4968000, 105.8157000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70585, 'Leuwigede', 'Leuwigede', 'Leuwigede', -6.4966000, 105.8338000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70586, 'Kubangkampil', 'Kubangkampil', 'Kubangkampil', -6.4908000, 105.8395000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70587, 'Weru', 'Weru', 'Weru', -6.4623000, 105.8392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70588, 'Carenang Lor', 'Carenang Lor', 'Carenang Lor', -6.4623000, 105.8659000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70589, 'Parigi', 'Parigi', 'Parigi,Prigi', -6.3818000, 105.8756000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70590, 'Cirumput', 'Cirumput', 'Cirumput,Tjiroempoet', -6.3969000, 105.8842000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70591, 'Kuluwut Tengah', 'Kuluwut Tengah', 'Kloewoet,Kuluwut Tengah', -6.4136000, 105.8846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70592, 'Kubang', 'Kubang', 'Kubang', -6.4194000, 105.8830000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70593, 'Kubangkondanglapangan', 'Kubangkondanglapangan', 'Kubangkondanglapangan', -6.4154000, 105.9121000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70594, 'Kubangkondang', 'Kubangkondang', 'Kubangkondang', -6.4219000, 105.9089000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70595, 'Bangko Dua', 'Bangko Dua', 'Bangko Dua', -6.3858000, 105.8856000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70596, 'Kaducukang', 'Kaducukang', 'Kadoetjoekang,Kaducukang', -6.3929000, 105.9180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70597, 'Leuweungkolot', 'Leuweungkolot', 'Leuweungkolot,Leuwikolot', -6.3925000, 105.9286000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70598, 'Kebonjeruk', 'Kebonjeruk', 'Kebonjeruk', -6.3888000, 105.9223000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70599, 'Cikiray', 'Cikiray', 'Cikiray,Tjikiraj', -6.3794000, 105.9007000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70600, 'Sukamara', 'Sukamara', 'Soekamara,Sukamara', -6.3809000, 105.9406000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70601, 'Manungtung', 'Manungtung', 'Manoengtoeng,Manungtung', -6.3787000, 105.9432000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70602, 'Bongbong', 'Bongbong', 'Bonbgang,Bongbong', -6.3943000, 105.9495000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70603, 'Kadusirung Hilir', 'Kadusirung Hilir', 'Kadoesaroeng-hilir,Kadusirung Hilir', -6.4296000, 105.9350000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70604, 'Pasirtundun', 'Pasirtundun', 'Pasirtoendoen,Pasirtundun', -6.4139000, 105.9501000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70605, 'Pasirwaringin', 'Pasirwaringin', 'Pasirwaringin', -6.4096300, 105.9412200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70606, 'Timbang', 'Timbang', 'Timbang,Wanagiri', -6.3866000, 105.9818900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70607, 'Ganjur Girang', 'Ganjur Girang', 'Gandjoer,Ganjur Girang', -6.4034000, 105.9797000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70608, 'Kaduseeng', 'Kaduseeng', 'Kadoese''eng,Kadoese’eng,Kaduseeng', -6.3965000, 105.9693000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70609, 'Legokkopra', 'Legokkopra', 'Legokkopra', -6.3968000, 105.9591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70610, 'Saketipasar', 'Saketipasar', 'Saketipasar', -6.4014000, 105.9943000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70611, 'Saketipasir', 'Saketipasir', 'Saketipasir', -6.3976000, 105.9931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70612, 'Pamatang', 'Pamatang', 'Pamatang', -6.4232000, 105.9881000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70613, 'Kadupinang', 'Kadupinang', 'Kadupinang', -6.4197000, 105.9694000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70614, 'Kampungmasjid', 'Kampungmasjid', 'Kampungmasjid', -6.4267000, 105.9708000, 'ID', '2011-04-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70615, 'Karangsari', 'Karangsari', 'Karangsari', -6.4361000, 105.9725000, 'ID', '2011-04-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70616, 'Kadukandel', 'Kadukandel', 'Kadukandel', -6.4334000, 105.9098000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70617, 'Karangtengah', 'Karangtengah', 'Karangtengah', -6.4586000, 105.8868000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70618, 'Kebon', 'Kebon', 'Kebon', -6.4730000, 105.8782000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70619, 'Nambo', 'Nambo', 'Nambo', -6.4919000, 105.9507000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70620, 'Mekarsari', 'Mekarsari', 'Mekarsari', -6.4630000, 105.9864000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70621, 'Kadubera', 'Kadubera', 'Kadoebera,Kadubera', -6.4593000, 105.9208000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70622, 'Pasirpanjang', 'Pasirpanjang', 'Pasirpandjang,Pasirpanjang', -6.4785000, 105.9269000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70623, 'Kampungpasar', 'Kampungpasar', 'Kampungpasar', -6.5049000, 106.1943000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70624, 'Jati', 'Jati', 'Jati', -6.5153000, 106.1958000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70625, 'Cirangga Kidul', 'Cirangga Kidul', 'Cirangga Kidul', -6.5294000, 106.1719000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70626, 'Palopat', 'Palopat', 'Palopat', -6.5369000, 106.2287000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70627, 'Sukamaju', 'Sukamaju', 'Sukamaju', -6.5362000, 106.2299000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70628, 'Kadulari', 'Kadulari', 'Kadulari', -6.5445000, 106.1612000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70629, 'Kemancing', 'Kemancing', 'Kemancing', -6.5557000, 106.2257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70630, 'Bantarnaga Tonggoh', 'Bantarnaga Tonggoh', 'Bantarnaga Tonggoh', -6.5609000, 106.2443000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70631, 'Bulakan', 'Bulakan', 'Bulakan', -6.5663000, 106.2409000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70632, 'Kadurahayu', 'Kadurahayu', 'Kadurahayu', -6.5690000, 106.1287000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70633, 'Babakansukamulya', 'Babakansukamulya', 'Babakansukamulya', -6.5827000, 106.1676000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70634, 'Kaduketug', 'Kaduketug', 'Kaduketug', -6.5980000, 106.2248000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70635, 'Ciboleger', 'Ciboleger', 'Ciboleger', -6.5944000, 106.2255000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70636, 'Sumberwaras', 'Sumberwaras', 'Sumberwaras', -6.5954000, 106.1530000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70637, 'Pajagan', 'Pajagan', 'Pajagan', -6.6065000, 106.1667000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70638, 'Gunungjulang', 'Gunungjulang', 'Goenoengdjoelang,Gunungjulang', -6.6317000, 106.4161000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70639, 'Nagreg', 'Nagreg', 'Nagreg', -6.2556000, 106.0056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70640, 'Peuteuy', 'Peuteuy', 'Peuteuy', -6.2607000, 106.0028000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70641, 'Citajur', 'Citajur', 'Citajur', -6.2845000, 105.8273000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70642, 'Kasepen', 'Kasepen', 'Kasepen', -6.3124000, 105.8426000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70643, 'Tembol', 'Tembol', 'Tembol', -6.3221000, 105.8427000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70644, 'Pamatang', 'Pamatang', 'Pamatang', -6.3295000, 105.8343000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70645, 'Cibango', 'Cibango', 'Cibango', -6.3441000, 105.8339000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70646, 'Tangkil', 'Tangkil', 'Tangkil', -6.3153000, 105.8503000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70647, 'Kaducondong', 'Kaducondong', 'Kaducondong', -6.3472000, 105.8550000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70648, 'Picungbera', 'Picungbera', 'Picungbera', -6.3535700, 105.8443200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70649, 'Sepenmasjid', 'Sepenmasjid', 'Sepenmasjid', -6.3679600, 105.8475300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70650, 'Bogor', 'Bogor', 'Bogor', -6.3314000, 105.8684000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70651, 'Sukacai', 'Sukacai', 'Sukacai', -6.3487000, 105.8667000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70652, 'Sukacai Tengah', 'Sukacai Tengah', 'Sukacai Tengah', -6.3517000, 105.8652000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70653, 'Sarampu', 'Sarampu', 'Sarampu', -6.3643000, 105.8694000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70654, 'Padahayu', 'Padahayu', 'Padahayu', -6.3722000, 105.8609000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70655, 'Teluk', 'Teluk', 'Teluk', -6.3722000, 105.8252000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70656, 'Makui', 'Makui', 'Makui', -6.3731000, 105.8312000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70657, 'Kalepasan', 'Kalepasan', 'Kalepasan', -6.2600000, 106.0799000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70658, 'Tanagara', 'Tanagara', 'Tanagara', -6.2654000, 106.0953000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70659, 'Jalanbaru', 'Jalanbaru', 'Jalanbaru', -6.2612000, 106.1203000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70660, 'Sindanghayu', 'Sindanghayu', 'Sindanghayu', -6.2683000, 106.1046000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70661, 'Juhut', 'Juhut', 'Juhut', -6.2955000, 106.1064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70662, 'Mandalasari', 'Mandalasari', 'Mandalasari', -6.3019000, 106.0048000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70663, 'Gunungsari', 'Gunungsari', 'Gunungsari', -6.3070000, 106.0207000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70664, 'Campraksanta', 'Campraksanta', 'Campraksanta', -6.3019000, 106.0776000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70665, 'Keboncau', 'Keboncau', 'Keboncau', -6.3068000, 106.1051000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70666, 'Gobang', 'Gobang', 'Gobang', -6.3716000, 106.0072000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70667, 'Kadulomber', 'Kadulomber', 'Kadulomber', -6.3700000, 106.0414000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70668, 'Cileuksa', 'Cileuksa', 'Cileuksa', -6.3737000, 106.0867000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70669, 'Rancapiit', 'Rancapiit', 'Rancapiit', -6.3677000, 106.0908000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70670, 'Garawati', 'Garawati', 'Garawati', -6.3636000, 106.1193000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70671, 'Gunungputri', 'Gunungputri', 'Gunungputri', -6.3606000, 106.0937000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70672, 'Salinggara', 'Salinggara', 'Salinggara', -6.3638000, 106.0792000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70673, 'Kalahang', 'Kalahang', 'Kalahang', -6.3606000, 106.0531000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70674, 'Cimongkor', 'Cimongkor', 'Cimongkor', -6.3639000, 106.0248000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70675, 'Rocek', 'Rocek', 'Rocek', -6.3571000, 106.0476000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70676, 'Kadubincarung', 'Kadubincarung', 'Kadubincarung', -6.3523000, 106.1086000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70677, 'Curuggaru', 'Curuggaru', 'Curuggaru', -6.3441000, 106.0666000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70678, 'Panday', 'Panday', 'Panday', -6.3498000, 106.0457000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70679, 'Rancanyenang', 'Rancanyenang', 'Rancanyenang', -6.3376000, 106.0164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70680, 'Cibebek', 'Cibebek', 'Cibebek', -6.3415600, 106.0767400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70681, 'Kadomas', 'Kadomas', 'Kadomas', -6.3293000, 106.1101000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70682, 'Majamasjid', 'Majamasjid', 'Majamasjid', -6.3288000, 106.0931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70683, 'Cipacung Landeuh', 'Cipacung Landeuh', 'Cipacung Landeuh', -6.3290000, 106.0825000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70684, 'Girihieum', 'Girihieum', 'Girihieum', -6.3319000, 106.0690000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70685, 'Rokoy', 'Rokoy', 'Rokoy', -6.3328000, 106.0606000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70686, 'Kukulu', 'Kukulu', 'Kukulu', -6.3321000, 106.0476000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70687, 'Cilanggar', 'Cilanggar', 'Cilanggar', -6.3319000, 106.0414000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70688, 'Bengkung', 'Bengkung', 'Bengkung', -6.3306000, 106.0372000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70689, 'Pasarnangka', 'Pasarnangka', 'Pasarnangka', -6.3302000, 106.0343000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70690, 'Cibulakan', 'Cibulakan', 'Cibulakan', -6.3271000, 106.0213000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70691, 'Calincing', 'Calincing', 'Calincing', -6.3261000, 106.0051000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70692, 'Kurungkambing', 'Kurungkambing', 'Kurungkambing', -6.3102000, 106.0096000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70693, 'Garokgek', 'Garokgek', 'Garokgek', -6.3112000, 106.0322000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70694, 'Nagrog', 'Nagrog', 'Nagrog', -6.3182000, 106.0342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70695, 'Cidahu', 'Cidahu', 'Cidahu', -6.3113000, 106.0568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70696, 'Cilaja', 'Cilaja', 'Cilaja', -6.3128000, 106.0910000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70697, 'Ciekek', 'Ciekek', 'Ciekek', -6.3204000, 106.0996000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70698, 'Kabayancitiis', 'Kabayancitiis', 'Kabayancitiis', -6.3117000, 106.1097000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70699, 'Gardutanjak', 'Gardutanjak', 'Gardutanjak', -6.3133000, 106.1013000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70700, 'Penikebon', 'Penikebon', 'Penikebon', -6.3420000, 106.0875000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70701, 'Kadumantung', 'Kadumantung', 'Kadumantung', -6.2899100, 106.1183500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70702, 'Karangcombong', 'Karangcombong', 'Karangcombong', -6.6302000, 106.2666000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70703, 'Cidikit Girang', 'Cidikit Girang', 'Cidikit Girang', -6.6435000, 106.2826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70704, 'Hariang', 'Hariang', 'Hariang', -6.6301000, 106.2928000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70705, 'Pasireurih', 'Pasireurih', 'Pasireurih', -6.6564000, 106.3084000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70706, 'Babakannagamukti', 'Babakannagamukti', 'Babakannagamukti', -6.6986500, 106.3343400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70707, 'Cikuning', 'Cikuning', 'Cikuning', -6.6627000, 106.3391000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70708, 'Ciparasi', 'Ciparasi', 'Ciparasi', -6.6606000, 106.3441000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70709, 'Guradog', 'Guradog', 'Guradog', -6.6958000, 106.3381000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70710, 'Ciparay', 'Ciparay', 'Ciparay', -6.1326000, 105.8659000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70711, 'Kopibera', 'Kopibera', 'Kopibera', -6.1548000, 105.8734000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70712, 'Kopibaru', 'Kopibaru', 'Kopibaru', -6.1620000, 105.8729000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70713, 'Bantarwaru', 'Bantarwaru', 'Bantarwaru', -6.2026000, 105.8642000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70714, 'Dahu', 'Dahu', 'Dahu', -6.2163000, 105.8740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70715, 'Kawoyang', 'Kawoyang', 'Kawoyang', -6.2428000, 105.8627000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70716, 'Bengras', 'Bengras', 'Bengras', -6.2481000, 105.8324000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70717, 'Umbultanjung', 'Umbultanjung', 'Umbultanjung', -6.2337000, 105.8316000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70718, 'Tawingmuara', 'Tawingmuara', 'Tawingmuara', -6.1637000, 105.8548000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70719, 'Pondokwaru', 'Pondokwaru', 'Pondokwaru', -6.1972000, 105.8394000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70720, 'Talaga', 'Talaga', 'Talaga', -6.3209000, 105.9997000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70721, 'Banyuresmi', 'Banyuresmi', 'Banyuresmi', -6.3560000, 105.8804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70722, 'Kadukotok', 'Kadukotok', 'Kadukotok', -6.3571000, 105.8907000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70723, 'Jami', 'Jami', 'Jami', -6.3681000, 105.8826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70724, 'Panghadangan', 'Panghadangan', 'Panghadangan', -6.3052000, 105.8971000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70725, 'Kadubamban', 'Kadubamban', 'Kadubamban', -6.3192000, 105.8994000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70726, 'Kaduheuleut', 'Kaduheuleut', 'Kaduheuleut', -6.3361000, 105.8981000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70727, 'Pamarayan', 'Pamarayan', 'Pamarayan', -6.3554000, 105.8989000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70728, 'Cukangpanjang', 'Cukangpanjang', 'Cukangpanjang', -6.3340000, 105.9098000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70729, 'Cigadung', 'Cigadung', 'Cigadung', -6.3336000, 105.9227000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70730, 'Sampangbitung', 'Sampangbitung', 'Sampangbitung', -6.3502000, 105.9175000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70731, 'Sorodot', 'Sorodot', 'Sorodot', -6.3623000, 105.9128000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70732, 'Munjul', 'Munjul', 'Munjul', -6.3425000, 105.9364000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70733, 'Kadupager', 'Kadupager', 'Kadupager', -6.3487000, 105.9354000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70734, 'Cigandeng', 'Cigandeng', 'Cigandeng', -6.3692000, 105.9300000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70735, 'Kupahandap', 'Kupahandap', 'Kupahandap', -6.3745000, 105.9314000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70736, 'Mandalawangi', 'Mandalawangi', 'Mandalawangi', -6.3035000, 105.9931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70737, 'Kadujangkung', 'Kadujangkung', 'Kadujangkung', -6.2602000, 105.9467000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70738, 'Kadutalahab', 'Kadutalahab', 'Kadutalahab', -6.3475000, 105.9482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70739, 'Bojongpinang', 'Bojongpinang', 'Bojongpinang', -6.3612000, 105.9456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70740, 'Pasargunung', 'Pasargunung', 'Pasargunung', -6.3639000, 105.9523000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70741, 'Kadukoneng', 'Kadukoneng', 'Kadukoneng', -6.2650000, 105.9681000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70742, 'Cisaat', 'Cisaat', 'Cisaat', -6.2923000, 105.9717000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70743, 'Batulayang', 'Batulayang', 'Batulayang', -6.2890000, 105.9735000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70744, 'Kadujampang', 'Kadujampang', 'Kadujampang', -6.3060000, 105.9753000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70745, 'Pandat', 'Pandat', 'Pandat', -6.3138000, 105.9605000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70746, 'Kaduronyok', 'Kaduronyok', 'Kaduronyok', -6.3731000, 105.9607000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70747, 'Kalahang', 'Kalahang', 'Kalahang', -6.2805000, 105.9942000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70748, 'Sindangasih', 'Sindangasih', 'Sindangasih', -7.2432000, 106.4581000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70749, 'Ciwaru', 'Ciwaru', 'Ciwaru', -7.1936000, 106.4800000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70750, 'Gunungbatu', 'Gunungbatu', 'Gunungbatu', -7.3337000, 106.4372000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70751, 'Karangdawa Barat', 'Karangdawa Barat', 'Karangdawa Barat', -6.1318100, 106.1109400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70752, 'Bojongseler', 'Bojongseler', 'Bojongseler', -6.1427000, 106.0338000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70753, 'Uluarang', 'Uluarang', 'Uluarang', -6.1473000, 106.0452000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70754, 'Padukan', 'Padukan', 'Padukan', -6.1495000, 106.1043000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70755, 'Merapit', 'Merapit', 'Merapit', -6.1544000, 106.0625000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70756, 'Pasagipasir', 'Pasagipasir', 'Pasagipasir', -6.1821500, 106.1212300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70757, 'Pancanagara', 'Pancanagara', 'Pancanagara', -6.1919000, 106.0877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70758, 'Panyirapan', 'Panyirapan', 'Panyirapan', -6.2339000, 106.1233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70759, 'Lengor', 'Lengor', 'Lenggor,Lengor', -6.2279000, 106.1100000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70760, 'Kalibuntu', 'Kalibuntu', 'Kalibuntu', -6.2134000, 106.1138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70761, 'Sioah', 'Sioah', 'Sioah,Tjiowa', -6.2063000, 106.1107000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70762, 'Cigudang', 'Cigudang', 'Cigudang', -6.2442000, 106.1016000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70763, 'Kadukaung', 'Kadukaung', 'Kadukaung', -6.2479000, 106.1070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70764, 'Cipayung', 'Cipayung', 'Cipayung,Sipajoeng', -6.2074000, 106.0158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70765, 'Cibetung Dua', 'Cibetung Dua', 'Cibetung Dua', -6.2000000, 106.0247000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70766, 'Sampiran', 'Sampiran', 'Sampiran', -6.2084000, 106.0734000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70767, 'Cikaung', 'Cikaung', 'Cikaung,Tjikawoeng', -6.2040000, 106.0827000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70768, 'Sirnagalih', 'Sirnagalih', 'Sirnagalih', -6.2157000, 106.0437000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70769, 'Cikendi', 'Cikendi', 'Cikendi', -6.2107000, 106.0234000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70770, 'Talagabakti', 'Talagabakti', 'Talagabakti', -6.2081000, 106.0093000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70771, 'Curuggoong', 'Curuggoong', 'Curuggoong,Tjoeroeggoong,Tjoeroeggoöng', -6.2165000, 106.0035000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70772, 'Nagreg', 'Nagreg', 'Nagreg,Sindangmandi', -6.2194300, 106.0890700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70773, 'Cemplang', 'Cemplang', 'Cemplang', -6.2300000, 106.0752000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70774, 'Parapatan', 'Parapatan', 'Parapatan', -6.2286000, 106.0595000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70775, 'Cilongkrangpusaka', 'Cilongkrangpusaka', 'Cilongkrangpusaka', -6.2262500, 106.0253000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70776, 'Kurungkotok', 'Kurungkotok', 'Koeroengkotok,Kurungkotok', -6.2278000, 106.0372000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70777, 'Lebak', 'Lebak', 'Lebak', -6.2369000, 106.0119000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70778, 'Citaman', 'Citaman', 'Citaman,Tjitaman', -6.2356000, 106.0201000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70779, 'Kaduela', 'Kaduela', 'Kadoeela,Kaduela', -6.2452000, 106.0814000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70780, 'Kampungsawah Landeuh', 'Kampungsawah Landeuh', 'Kampungsawah,Kampungsawah Landeuh', -6.2485000, 106.0100000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70781, 'Kadubetara', 'Kadubetara', 'Kadubetara', -6.6274000, 106.0719000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70782, 'Parakanlima', 'Parakanlima', 'Parakanlima', -6.6319000, 106.1077000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70783, 'Sukakerta', 'Sukakerta', 'Sukakerta', -6.6759000, 106.0535000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70784, 'Pamundayan Kaler', 'Pamundayan Kaler', 'Pamundayan Kaler', -6.6966000, 106.0251000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70785, 'Kandangsapi', 'Kandangsapi', 'Kandangsapi', -6.7429000, 106.0291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70786, 'Simpanggarung', 'Simpanggarung', 'Garoeng,Simpanggarung', -6.7099000, 106.0494000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70787, 'Sukamaju', 'Sukamaju', 'Sukamaju', -6.7053000, 106.0701000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70788, 'Peucangpari', 'Peucangpari', 'Peucangpari', -6.7117000, 106.1111000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70789, 'Munturkaju', 'Munturkaju', 'Munturkaju', -6.5110000, 106.0243000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70790, 'Cahayamekar', 'Cahayamekar', 'Cahayamekar', -6.5138900, 106.0387400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70791, 'Tajur', 'Tajur', 'Tajur', -6.5294000, 106.0777000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70792, 'Sajir', 'Sajir', 'Sadjir,Sajir', -6.5068000, 106.0858000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70793, 'Keboncau', 'Keboncau', 'Keboncau,Kebontjaoe', -6.5217000, 106.1021000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70794, 'Cilutung', 'Cilutung', 'Cilutung', -6.5654000, 106.0777000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70795, 'Cibeusi', 'Cibeusi', 'Cibeusi,Tjibeusi', -6.5533000, 106.0351000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70796, 'Mangpeng', 'Mangpeng', 'Mangpeng', -6.5678000, 106.0194000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70797, 'Kebonkalapa', 'Kebonkalapa', 'Kebonkalapa', -6.5897000, 106.0269000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70798, 'Lebakmasjid', 'Lebakmasjid', 'Lebakmasjid', -6.6052200, 106.0865900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70799, 'Cihaladan', 'Cihaladan', 'Cihaladan,Cuhaladan,Tjihaladan', -6.5809600, 106.1063200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70800, 'Cempaka', 'Cempaka', 'Cempaka', -6.6078000, 106.1192000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70801, 'Citeureup', 'Citeureup', 'Citeureup', -6.7707000, 106.0025700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70802, 'Pasirgeleng', 'Pasirgeleng', 'Pasirgeleng', -6.8025300, 106.0128500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70803, 'Jatiraya', 'Jatiraya', 'Jatiraya', -6.8082300, 106.0176100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70804, 'Sukaraja', 'Sukaraja', 'Sukaraja', -6.7868800, 106.0248800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70805, 'Pasirhaur', 'Pasirhaur', 'Pasirhaur', -6.7767300, 106.0167400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70806, 'Citaritih', 'Citaritih', 'Citaritih', -6.8233600, 106.0528000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70807, 'Sukamaju', 'Sukamaju', 'Sukamaju', -6.7716600, 106.0506400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70808, 'Cikadu', 'Cikadu', 'Cikadu', -6.7881200, 106.0951700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70809, 'Manglid', 'Manglid', 'Manglid', -6.7625600, 106.1116000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70810, 'Cikedung', 'Cikedung', 'Cikedung', -6.1322000, 105.9853000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70811, 'Mekarsari', 'Mekarsari', 'Mekarsari', -6.1351000, 105.9047000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70812, 'Cinoyong', 'Cinoyong', 'Cinoyong', -6.2322000, 105.8885000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70813, 'Cibojong', 'Cibojong', 'Cibojong', -6.2202000, 105.9392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70814, 'Kaduranca', 'Kaduranca', 'Kaduranca', -6.2202000, 105.9254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70815, 'Cibunut', 'Cibunut', 'Cibunut', -6.1601000, 105.9113000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70816, 'Kadumonyong', 'Kadumonyong', 'Kadumonyong', -6.1725200, 105.8847300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70817, 'Cikuray', 'Cikuray', 'Cikuray', -6.1987000, 105.9254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70818, 'Nengger', 'Nengger', 'Nengger', -6.2083000, 105.9875000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70819, 'Citasuk', 'Citasuk', 'Citasuk', -6.2112000, 105.9606000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70820, 'Kalumpang', 'Kalumpang', 'Kalumpang', -6.2130000, 105.9529000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70821, 'Manggu', 'Manggu', 'Manggu', -6.2153000, 105.9497000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70822, 'Tambakan', 'Tambakan', 'Tambakan', -6.2028000, 105.9384000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70823, 'Rancaranji', 'Rancaranji', 'Rancaranji', -6.2124000, 105.9342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70824, 'Gili Trawangan', 'Gili Trawangan', 'Gili Travangan,Гили Траванган', -8.3489700, 116.0370000, 'ID', '2013-05-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70825, 'Pangradin Satu', 'Pangradin Satu', 'Pangradin Satu', -6.5084000, 106.4773000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70826, 'Lebakhuni', 'Lebakhuni', 'Lebakhuni', -6.5179000, 106.4631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70827, 'Sukamaju', 'Sukamaju', 'Sukamaju', -6.5302000, 106.3898000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70828, 'Lurah', 'Lurah', 'Lurah', -6.5332000, 106.3857000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70829, 'Hamberang Sabrang', 'Hamberang Sabrang', 'Hamberang Sabrang', -6.5380000, 106.4032000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70830, 'Cikarae', 'Cikarae', 'Cikarae', -6.5579000, 106.3817000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70831, 'Cikomara', 'Cikomara', 'Cikomara', -6.5683000, 106.4116000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70832, 'Cibadak', 'Cibadak', 'Cibadak', -6.5816000, 106.4846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70833, 'Padurung', 'Padurung', 'Padurung', -6.5871000, 106.3903000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70834, 'Jaha', 'Jaha', 'Jaha', -6.5869000, 106.4108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70835, 'Bojongsarung', 'Bojongsarung', 'Bojongsarung', -6.6224000, 106.3869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70836, 'Sumandang', 'Sumandang', 'Sumandang', -6.5068000, 106.3290000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70837, 'Neglasari', 'Neglasari', 'Neglasari', -6.5213000, 106.2941000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70838, 'Leuwisema', 'Leuwisema', 'Leuwisema', -6.5276000, 106.3740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70839, 'Cirangrang', 'Cirangrang', 'Cirangrang', -6.5391000, 106.2921000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70840, 'Ciminyak', 'Ciminyak', 'Ciminyak', -6.5440000, 106.2956000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70841, 'Puputan', 'Puputan', 'Puputan', -6.5582000, 106.3605000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70842, 'Cimarkum', 'Cimarkum', 'Cimarkum', -6.5633000, 106.3483000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70843, 'Cipunglu', 'Cipunglu', 'Cipunglu', -6.5675000, 106.3282000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70844, 'Siangin', 'Siangin', 'Siangin', -6.5686000, 106.3408000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70845, 'Cibunar', 'Cibunar', 'Cibunar', -6.5834000, 106.3076100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70846, 'Cikawah', 'Cikawah', 'Cikawah', -6.6168000, 106.3055000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70847, 'Pasirmalang', 'Pasirmalang', 'Pasirmalang', -7.2557000, 106.6142000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70848, 'Nagraksari', 'Nagraksari', 'Nagraksari', -7.2790000, 106.6228000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70849, 'Babakan Baru', 'Babakan Baru', 'Babakan Baru', -7.3152000, 106.6195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70850, 'Karadenan', 'Karadenan', 'Karadenan', -7.3385000, 106.6206000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70851, 'Cibungur', 'Cibungur', 'Cibungur', -7.3716000, 106.5392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70852, 'Munjul', 'Munjul', 'Munjul', -7.2810000, 106.5985000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70853, 'Ciparay', 'Ciparay', 'Ciparay', -7.2968000, 106.6121000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70854, 'Ciateul', 'Ciateul', 'Ciateul', -7.2975000, 106.5879000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70855, 'Pasirsongket Dua', 'Pasirsongket Dua', 'Pasirsongket Dua', -7.3106000, 106.5946000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70856, 'Ciawangsa', 'Ciawangsa', 'Ciawangsa', -7.3065000, 106.5519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70857, 'Citeureup', 'Citeureup', 'Citeureup', -7.3299000, 106.5186000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70858, 'Majalaya', 'Majalaya', 'Majalaya', -7.3378000, 106.6069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70859, 'Nagrak', 'Nagrak', 'Nagrak', -7.3356000, 106.5531000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70860, 'Pamoyanan', 'Pamoyanan', 'Pamoyanan', -7.3481000, 106.5761000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70861, 'Pondokaso', 'Pondokaso', 'Pondokaso', -7.3563000, 106.5424000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70862, 'Simpenan', 'Simpenan', 'Simpenan', -7.3497000, 106.5136000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70863, 'Cikujang', 'Cikujang', 'Cikujang', -7.3589000, 106.5726000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70864, 'Gajahmada', 'Gajahmada', 'Gajahmada', -6.3786000, 106.0123000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70865, 'Kadugadung', 'Kadugadung', 'Kadugadung', -6.3832000, 106.0180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70866, 'Citalahab', 'Citalahab', 'Citalahab', -6.3752000, 106.1019000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70867, 'Cikaduen', 'Cikaduen', 'Cikaduen', -6.3924000, 106.0041000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70868, 'Parumasan Timur', 'Parumasan Timur', 'Parumasan Timur', -6.3876000, 106.0283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70869, 'Sidamulya Satu', 'Sidamulya Satu', 'Sidamulya Satu', -6.3853000, 106.0844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70870, 'Sumurlebu Barat', 'Sumurlebu Barat', 'Sumurlebu Barat', -6.3959000, 106.1056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70871, 'Cikeper', 'Cikeper', 'Cikeper', -6.3935000, 106.1010000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70872, 'Sarakole', 'Sarakole', 'Sarakole', -6.3962400, 106.0721600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70873, 'Koncang', 'Koncang', 'Koncang', -6.4029900, 106.0133300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70874, 'Kampungdukuh', 'Kampungdukuh', 'Kampungdukuh', -6.4017000, 106.0304000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70875, 'Rancabugel', 'Rancabugel', 'Rancabugel', -6.4018500, 106.0321600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70876, 'Kadungabaris', 'Kadungabaris', 'Kadungabaris', -6.4046100, 106.0899700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70877, 'Cibeureum Satu', 'Cibeureum Satu', 'Cibeureum Satu', -6.4005000, 106.1044000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70878, 'Sarageni', 'Sarageni', 'Sarageni', -6.4653500, 106.1222400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70879, 'Kaum', 'Kaum', 'Kaum', -6.4781900, 106.1156500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70880, 'Umbul', 'Umbul', 'Umbul', -6.4453000, 106.0930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70881, 'Kadusimbar', 'Kadusimbar', 'Kadusimbar', -6.4222000, 106.0889000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70882, 'Lebakgempol', 'Lebakgempol', 'Lebakgempol', -6.4678000, 106.0909000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70883, 'Sidamukti', 'Sidamukti', 'Sidamukti', -6.4524000, 106.0559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70884, 'Kopi', 'Kopi', 'Kopi', -6.4401000, 106.0585000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70885, 'Cigembor', 'Cigembor', 'Cigembor', -6.4383100, 106.0372900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70886, 'Parag', 'Parag', 'Parag', -6.4774000, 106.0267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70887, 'Cipadung', 'Cipadung', 'Cipadung', -6.4904600, 106.0152000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70888, 'Parakan', 'Parakan', 'Parakan', -6.4191000, 106.0081000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70889, 'Jasugih Selatan', 'Jasugih Selatan', 'Jasugih Selatan', -6.4347000, 106.0015000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70890, 'Pasirjambu', 'Pasirjambu', 'Pasirjambu', -6.4452000, 106.0134000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70891, 'Cimadang', 'Cimadang', 'Cimadang', -6.4737000, 106.0001000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70892, 'Citegal', 'Citegal', 'Citegal', -7.0225000, 106.5999000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70893, 'Cilangkap', 'Cilangkap', 'Cilangkap', -7.0358000, 106.5633000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70894, 'Cihaur Girang', 'Cihaur Girang', 'Cihaur Girang', -7.1166000, 106.5628000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70895, 'Rancaerang', 'Rancaerang', 'Rancaerang', -7.4224000, 106.7180000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70896, 'Buniasih', 'Buniasih', 'Buniasih', -7.4229000, 106.7226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70897, 'Mekarjaya Satu', 'Mekarjaya Satu', 'Mekarjaya Satu', -7.4117000, 106.7010000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70898, 'Cimanggu', 'Cimanggu', 'Cimanggu', -7.2510000, 106.6714000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70899, 'Cinagrog Girang', 'Cinagrog Girang', 'Cinagrog Girang', -7.2525000, 106.6846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70900, 'Cibuntu', 'Cibuntu', 'Cibuntu', -7.2609000, 106.7271000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70901, 'Pasirbitung', 'Pasirbitung', 'Pasirbitung', -7.2636000, 106.6409000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70902, 'Ciawitali', 'Ciawitali', 'Ciawitali', -7.2628000, 106.6282000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70903, 'Tegalloa', 'Tegalloa', 'Tegalloa', -7.2770000, 106.6356000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70904, 'Cinangka', 'Cinangka', 'Cinangka', -7.3220000, 106.6296000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70905, 'Pasirangin Tiga', 'Pasirangin Tiga', 'Pasirangin Tiga', -7.2674000, 106.6514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70906, 'Cigadung', 'Cigadung', 'Cigadung', -7.2892000, 106.6937000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70907, 'Cikiwul Satu', 'Cikiwul Satu', 'Cikiwul Satu', -7.2941000, 106.6844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70908, 'Leuwinanggung Satu', 'Leuwinanggung Satu', 'Leuwinanggung Satu', -7.3004000, 106.6375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70909, 'Cikupa', 'Cikupa', 'Cikupa', -7.3453000, 106.6989000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70910, 'Cikamarang Satu', 'Cikamarang Satu', 'Cikamarang Satu', -7.3240000, 106.6533000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70911, 'Calingcing', 'Calingcing', 'Calingcing', -7.3946000, 106.7925000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70912, 'Karangnenggang', 'Karangnenggang', 'Karangnenggang', -7.3754000, 106.8154000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70913, 'Sinarharapan', 'Sinarharapan', 'Sinarharapan', -7.4278000, 106.8309000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70914, 'Panyaungan Timur', 'Panyaungan Timur', 'Panyaungan Timur', -6.9014000, 106.1535900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70915, 'Cisiih', 'Cisiih', 'Cisiih', -6.9066500, 106.1911200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70916, 'Panggarangandesa', 'Panggarangandesa', 'Panggarangandesa', -6.9007900, 106.2208400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70917, 'Cipinang', 'Cipinang', 'Cipinang', -6.8947400, 106.2092500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70918, 'Babakan', 'Babakan', 'Babakan', -6.8936500, 106.2118900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70919, 'Ciwaru', 'Ciwaru', 'Ciwaru', -6.9327200, 106.2450200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70920, 'Situwangi', 'Situwangi', 'Situwangi', -7.3940000, 106.9059000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70921, 'Cikarang', 'Cikarang', 'Cikarang', -7.3846000, 106.9543000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70922, 'Wanasari', 'Wanasari', 'Wanasari', -7.4068000, 106.9756000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70923, 'Cigembong', 'Cigembong', 'Cigembong', -7.1432000, 106.5101000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70924, 'Ciemas Satu', 'Ciemas Satu', 'Ciemas Satu', -7.1439000, 106.5431000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70925, 'Cibinong', 'Cibinong', 'Cibinong', -7.2037000, 106.5251000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70926, 'Galumpit', 'Galumpit', 'Galumpit', -7.2122000, 106.6233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70927, 'Pasirdalem', 'Pasirdalem', 'Pasirdalem', -7.2181000, 106.6037000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70928, 'Tamanjaya Satu', 'Tamanjaya Satu', 'Tamanjaya Satu', -7.2262000, 106.5283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70929, 'Rancabuaya', 'Rancabuaya', 'Rancabuaya', -7.5238000, 107.4909000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70930, 'Citeureup', 'Citeureup', 'Citeureup', -7.6319400, 107.7075100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70931, 'Puncaksari', 'Puncaksari', 'Puncaksari', -7.6395000, 107.7327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70932, 'Babakan', 'Babakan', 'Babakan', -7.6361000, 107.7116000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70933, 'Bunisari', 'Bunisari', 'Bunisari', -7.6474800, 107.7123500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70934, 'Nangoh', 'Nangoh', 'Nangoh', -7.6437600, 107.7225700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70935, 'Lembur Tengah', 'Lembur Tengah', 'Lembur Tengah', -7.6477000, 107.7280700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70936, 'Paas Girang', 'Paas Girang', 'Paas Girang', -7.6489000, 107.7413000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70937, 'Jajaway', 'Jajaway', 'Djadjawaj,Jajaway', -7.2652000, 106.7579000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70938, 'Buniwangi', 'Buniwangi', 'Buniwangi', -7.2793000, 106.7994000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70939, 'Puncaksempur', 'Puncaksempur', 'Puncaksempur', -7.2747000, 106.8388000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70940, 'Cigina', 'Cigina', 'Cigina,Tjigina', -7.2841000, 106.8417000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70941, 'Sinarjaya', 'Sinarjaya', 'Sinarjaya', -7.3047000, 106.8353000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70942, 'Cileutik', 'Cileutik', 'Cileutik', -7.3091000, 106.8375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70943, 'Babakansalam', 'Babakansalam', 'Babakansalam', -7.5020400, 107.6253600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70944, 'Cijaringao', 'Cijaringao', 'Cijaringao', -7.5311000, 107.5392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70945, 'Cijayana', 'Cijayana', 'Cijayana', -7.5514000, 107.5666000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70946, 'Pasireunteung', 'Pasireunteung', 'Pasireunteung', -7.5028000, 107.5787000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70947, 'Bokor', 'Bokor', 'Bokor', -7.5248000, 107.6126000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70948, 'Karangsari', 'Karangsari', 'Karangsari', -7.5758000, 107.6175000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70949, 'Cibitung', 'Cibitung', 'Cibitung', -7.5356200, 107.6864000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70950, 'Cigolewang', 'Cigolewang', 'Cigolewang', -7.5440000, 107.7392000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70951, 'Burujul', 'Burujul', 'Burujul', -7.5559000, 107.7177500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70952, 'Gunungsulah', 'Gunungsulah', 'Gunungsulah', -7.6069200, 107.6521000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70953, 'Cijambe', 'Cijambe', 'Cijambe', -7.6128000, 107.6744600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70954, 'Karees', 'Karees', 'Karees', -7.6510900, 107.8726800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70955, 'Ciawi', 'Ciawi', 'Ciawi', -7.6640000, 107.7631000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70956, 'Cibera', 'Cibera', 'Cibera', -7.6750600, 107.7902500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70957, 'Cigadog', 'Cigadog', 'Cigadog', -7.5086000, 107.8675000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70958, 'Margamulya', 'Margamulya', 'Margamulya', -7.5100000, 107.7711000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70959, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.5283300, 107.8065200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70960, 'Pasirlaja', 'Pasirlaja', 'Pasirlaja', -7.5377000, 107.8695000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70961, 'Selaawi', 'Selaawi', 'Selaawi', -7.5494600, 107.8128400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70962, 'Onyam', 'Onyam', 'Onyam', -7.5495000, 107.8324000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70963, 'Hegarmanah', 'Hegarmanah', 'Hegarmanah', -7.5601700, 107.7980500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70964, 'Cijagra', 'Cijagra', 'Cijagra', -7.5017100, 107.8418700, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70965, 'Cidahu', 'Cidahu', 'Cidahu', -7.5736900, 107.8168100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70966, 'Datarpasang', 'Datarpasang', 'Datarpasang', -7.5854100, 107.7721900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70967, 'Pangligaran', 'Pangligaran', 'Pangligaran', -7.6004600, 107.7703800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70968, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.3588000, 106.9997000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70969, 'Sukarama', 'Sukarama', 'Sukarama', -7.3738000, 106.9822000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70970, 'Cikarang', 'Cikarang', 'Cikarang', -7.2740000, 106.9036000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70971, 'Hegarmulya', 'Hegarmulya', 'Hegarmulya', -7.3141000, 106.9017000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70972, 'Binongsari', 'Binongsari', 'Binongsari', -7.3509000, 106.9189000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70973, 'Awilega', 'Awilega', 'Awilega', -7.3486000, 106.9336000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70974, 'Pasirporong', 'Pasirporong', 'Pasirporong', -7.2549000, 106.9377000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70975, 'Cidadap', 'Cidadap', 'Cidadap', -7.2910000, 106.9376000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70976, 'Pagadungan', 'Pagadungan', 'Pagadungan', -7.3628000, 106.9517000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70977, 'Nagasari', 'Nagasari', 'Nagasari', -7.3722000, 106.9592000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70978, 'Babakansumur', 'Babakansumur', 'Babakansumur', -7.2557000, 106.9809000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70979, 'Sinarbakti', 'Sinarbakti', 'Sinarbakti', -7.2758000, 106.9909000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70980, 'Cikendal', 'Cikendal', 'Cikendal', -7.3389000, 106.9756000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70981, 'Kendalngupuk', 'Kendalngupuk', 'Kendalngupuk', -7.4435000, 107.2553000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70982, 'Kebonkopi', 'Kebonkopi', 'Kebonkopi', -7.4855000, 107.2556000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70983, 'Cikole', 'Cikole', 'Cikole', -7.4892000, 107.2770000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70984, 'Gunungbatu', 'Gunungbatu', 'Gunungbatu', -7.4097000, 107.2871000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70985, 'Wangunjaya', 'Wangunjaya', 'Wangunjaya', -7.4009000, 107.3304000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70986, 'Kertajadi', 'Kertajadi', 'Kertajadi', -7.4876000, 107.3466000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70987, 'Ciawitali', 'Ciawitali', 'Ciawitali', -7.4230300, 107.3681100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70988, 'Karangpawitan', 'Karangpawitan', 'Karangpawitan', -7.4276000, 107.3834000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70989, 'Baranti', 'Baranti', 'Baranti', -7.4101000, 107.4242000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70990, 'Bantarmunding', 'Bantarmunding', 'Bantarmunding', -7.4796000, 107.4287000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70991, 'Indralayang', 'Indralayang', 'Indralayang', -7.4953100, 107.4839000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70992, 'Pasirbenda', 'Pasirbenda', 'Pasirbenda', -7.1291000, 106.7283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70993, 'Ciseuseupan', 'Ciseuseupan', 'Ciseuseupan', -7.1344000, 106.6979000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70994, 'Kalijaga', 'Kalijaga', 'Kalijaga', -7.2133000, 106.6486000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70995, 'Cibalung', 'Cibalung', 'Cibalung', -7.2302000, 106.6626000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70996, 'Babakankaret', 'Babakankaret', 'Babakankaret', -7.2376000, 106.6418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70997, 'Pamoyanan', 'Pamoyanan', 'Pamoyanan', -7.1403000, 106.7783000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70998, 'Datarnangka', 'Datarnangka', 'Datarnangka', -7.1994000, 106.8480000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(70999, 'Sirnasari', 'Sirnasari', 'Sirnasari', -7.1642000, 106.7782000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71000, 'Ancaen', 'Ancaen', 'Ancaen,Ancaeun', -7.1887000, 106.8702000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71001, 'Sindangraja', 'Sindangraja', 'Sindangraja', -7.1934000, 106.8340000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71002, 'Babakan', 'Babakan', 'Babakan', -7.2215000, 106.8019000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71003, 'Cimanggu', 'Cimanggu', 'Cimanggu', -7.2300000, 106.8396000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71004, 'Sukajaya', 'Sukajaya', 'Sukajaya', -7.2300000, 106.7633000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71005, 'Puncaktugu', 'Puncaktugu', 'Puncaktugu', -7.2053000, 106.8337000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71006, 'Sawahlegok', 'Sawahlegok', 'Sawahlegok', -7.2889000, 107.4655000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71007, 'Genteng', 'Genteng', 'Genteng', -7.2991000, 107.4955000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71008, 'Mekarjaya', 'Mekarjaya', 'Mekarjaya', -7.3021000, 107.4469000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71009, 'Puncakbaru', 'Puncakbaru', 'Puncakbaru', -7.3348000, 107.4481000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71010, 'Bojongjengkol', 'Bojongjengkol', 'Bojongjengkol', -7.0079000, 106.6910000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71011, 'Rancagadog', 'Rancagadog', 'Rancagadog', -7.0124000, 106.7042000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71012, 'Ciwaru', 'Ciwaru', 'Ciwaru', -7.0145000, 106.6670000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71013, 'Cipicung', 'Cipicung', 'Cipicung,Tjipitjoeng', -7.0236000, 106.6699000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71014, 'Puncakdago', 'Puncakdago', 'Puncakdago', -7.0920000, 106.7446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71015, 'Cigenca', 'Cigenca', 'Cigenca', -7.0930000, 106.6706000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71016, 'Cisireum', 'Cisireum', 'Cisireum', -7.1073000, 106.6479000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71017, 'Sukajadi', 'Sukajadi', 'Sukajadi', -7.4035000, 107.5368000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71018, 'Batutumpang', 'Batutumpang', 'Batutumpang', -7.4368000, 107.6237000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71019, 'Cibolang', 'Cibolang', 'Cibolang', -7.4378000, 107.6014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71020, 'Cibeureum', 'Cibeureum', 'Cibeureum', -7.4365000, 107.5613000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71021, 'Sukarame', 'Sukarame', 'Sukarame', -7.4376000, 107.5324000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71022, 'Nagrak', 'Nagrak', 'Nagrak', -7.4460000, 107.5963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71023, 'Cikuya', 'Cikuya', 'Cikuya', -7.4604000, 107.5764000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71024, 'Tegallega', 'Tegallega', 'Tegallega', -7.4708000, 107.5609000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71025, 'Pamungguan', 'Pamungguan', 'Pamungguan', -7.4772000, 107.6176000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71026, 'Tegalastana', 'Tegalastana', 'Tegalastana', -7.4866000, 107.5985000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71027, 'Cikalaces', 'Cikalaces', 'Cikalaces', -7.4899000, 107.5375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71028, 'Cimapag', 'Cimapag', 'Cimapag', -7.1323000, 106.8774000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71029, 'Dampit Satu', 'Dampit Satu', 'Dampit Satu', -7.1581000, 106.9901000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71030, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.1720000, 106.9493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71031, 'Puncakmanis', 'Puncakmanis', 'Puncakmanis', -7.2063000, 106.9634000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71032, 'Ciherang Dua', 'Ciherang Dua', 'Ciherang Dua', -7.2060000, 106.8971000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71033, 'Ciakar', 'Ciakar', 'Ciakar', -7.2128000, 106.9069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71034, 'Tegaljaya', 'Tegaljaya', 'Tegaljaya', -7.2124000, 106.9166000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71035, 'Karajeun', 'Karajeun', 'Karadjeun,Karajeun', -7.2198400, 106.8794800, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71036, 'Sinarjaya', 'Sinarjaya', 'Sinarjaya', -7.2311000, 106.9041000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71037, 'Cikulina', 'Cikulina', 'Cikulina', -7.2290000, 106.9856000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71038, 'Najeng', 'Najeng', 'Nadjeng,Najeng', -7.2359000, 106.9498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71039, 'Sumurnanjung', 'Sumurnanjung', 'Sumurnanjung', -7.2360000, 106.9249000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71040, 'Gelarpadang', 'Gelarpadang', 'Gelarpadang', -7.2473000, 106.9418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71041, 'Babakan', 'Babakan', 'Babakan', -7.2456000, 106.9814000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71042, 'Suryabakti', 'Suryabakti', 'Suryabakti', -7.0127000, 106.8411000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71043, 'Cipari Satu', 'Cipari Satu', 'Cipari Satu', -7.1205000, 106.8693000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71044, 'Ciareuy', 'Ciareuy', 'Ciareuy', -7.0294000, 106.8012000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71045, 'Pasirlaja', 'Pasirlaja', 'Pasirlaja', -7.0517000, 106.8601000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71046, 'Bojongduren', 'Bojongduren', 'Bojongduren', -7.0605000, 106.8194000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71047, 'Ciguna', 'Ciguna', 'Ciguna', -7.0729000, 106.8160000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71048, 'Ciroyom', 'Ciroyom', 'Ciroyom', -7.1022000, 106.8418000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71049, 'Nangerang', 'Nangerang', 'Nangerang', -7.1103000, 106.7991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71050, 'Tegalgede', 'Tegalgede', 'Tegalgede', -7.4921000, 107.6540000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71051, 'Cikalong', 'Cikalong', 'Cikalong', -7.4963000, 107.6669000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71052, 'Bebedahan', 'Bebedahan', 'Bebedahan', -7.4127000, 107.6591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71053, 'Rahayu', 'Rahayu', 'Rahayu', -7.4594000, 107.6440000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71054, 'Pasirgaru', 'Pasirgaru', 'Pasirgaru', -7.4096000, 107.6792000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71055, 'Simpang', 'Simpang', 'Simpang', -7.4737000, 107.6688000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71056, 'Sindangratu', 'Sindangratu', 'Sindangratu', -7.4651000, 107.6718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71057, 'Halimpu', 'Halimpu', 'Halimpu', -7.4333000, 107.6668000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71058, 'Pasirwangi', 'Pasirwangi', 'Pasirwangi', -7.4611000, 107.6644000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71059, 'Kadudampit', 'Kadudampit', 'Kadudampit', -7.4574000, 107.6758000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71060, 'Bangbayang', 'Bangbayang', 'Bangbayang', -7.4524000, 107.7259000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71061, 'Pasirhuni', 'Pasirhuni', 'Pasirhuni', -7.0262000, 106.9887000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71062, 'Liunggunung', 'Liunggunung', 'Liunggunung', -7.0313000, 106.9367000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71063, 'Cipesing', 'Cipesing', 'Cipesing', -7.0558000, 106.8946000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71064, 'Bungbangsari', 'Bungbangsari', 'Bungbangsari', -7.0646000, 106.9793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71065, 'Cisantri', 'Cisantri', 'Cisantri', -7.0614000, 106.9174000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71066, 'Cigawir', 'Cigawir', 'Cigawir', -7.0786000, 106.8980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71067, 'Cibiru', 'Cibiru', 'Cibiru,Tjibiroe', -7.0991000, 106.9221000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71068, 'Sindangraja', 'Sindangraja', 'Sindangraja', -7.1076000, 106.9338000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71069, 'Tanahbeureum', 'Tanahbeureum', 'Tanahbeureum', -7.1075000, 106.9642000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71070, 'Pasirangin Satu', 'Pasirangin Satu', 'Pasirangin Satu', -7.2800000, 107.5482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71071, 'Cibungur', 'Cibungur', 'Cibungur', -7.2913000, 107.5324000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71072, 'Talegong Dua', 'Talegong Dua', 'Talegong Dua', -7.2997000, 107.5119000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71073, 'Cihaur', 'Cihaur', 'Cihaur', -7.3086000, 107.5299000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71074, 'Pasirjambu', 'Pasirjambu', 'Pasirjambu', -7.3340000, 107.5386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71075, 'Mancagahar', 'Mancagahar', 'Mancagahar', -7.3289000, 107.5014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71076, 'Selajambe', 'Selajambe', 'Seladjambe,Selajambe', -7.3841000, 107.0800000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71077, 'Jatisari', 'Jatisari', 'Djatisari,Jatisari', -7.4100100, 107.0155500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71078, 'Sukarame', 'Sukarame', 'Sukarame', -7.4241000, 107.0679000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71079, 'Sukadami', 'Sukadami', 'Sukadami', -7.4339000, 107.0219000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71080, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.4452000, 107.0972000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71081, 'Bojonglarang', 'Bojonglarang', 'Bodjonglarang,Bojonglarang', -7.2609800, 107.0031000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71082, 'Batukarut', 'Batukarut', 'Batoekaroet,Batukarut', -7.2915200, 107.0143500, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71083, 'Sawahrandu', 'Sawahrandu', 'Sawahrandu', -7.2603000, 107.0207000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71084, 'Kampungpasar', 'Kampungpasar', 'Kampungpasar', -7.2600000, 107.0315000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71085, 'Sirnasari', 'Sirnasari', 'Sirnasari', -7.3212000, 107.0267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71086, 'Purabaya', 'Purabaya', 'Purabaya', -7.3517000, 107.0211000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71087, 'Karamat', 'Karamat', 'Karamat', -7.2582000, 107.0475000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71088, 'Cibodas', 'Cibodas', 'Cibodas', -7.2698000, 107.0456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71089, 'Sukasirna', 'Sukasirna', 'Sukasirna', -7.3548000, 107.0370000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71090, 'Tugu', 'Tugu', 'Tugu', -7.2604000, 107.0551000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71091, 'Puncakwangi', 'Puncakwangi', 'Puncakwangi', -7.2961000, 107.0660000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71092, 'Cihamerang', 'Cihamerang', 'Cihamerang', -7.3500000, 107.0655000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71093, 'Tegalheras', 'Tegalheras', 'Tegalheras', -7.2789000, 107.0659000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71094, 'Gelarmukti', 'Gelarmukti', 'Gelarmukti', -7.3398000, 107.0695000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71095, 'Babakantugu', 'Babakantugu', 'Babakantugu', -7.2588000, 107.0859000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71096, 'Sumur', 'Sumur', 'Sumur', -7.2812000, 107.0846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71097, 'Rawawilis', 'Rawawilis', 'Rawawilis', -7.2805000, 107.0912000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71098, 'Pasirmanggu', 'Pasirmanggu', 'Pasirmanggu', -7.2682000, 107.1077000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71099, 'Sinarwangi', 'Sinarwangi', 'Sinarwangi', -7.2787000, 107.1064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71100, 'Sukoharjo Satu', 'Sukoharjo Satu', 'Sukoharjo 1,Sukoharjo Satu', -5.3009400, 104.9832900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71101, 'Kuripan', 'Kuripan', 'Koeripan,Kuripan', -5.0354600, 103.7642000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71102, 'Kalirejo', 'Kalirejo', 'Kalirejo', -5.2258200, 104.9613100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71103, 'Pulaupanggung', 'Pulaupanggung', 'Oemboelan Poelaupanggoeng,Pulau Panggung,Pulaupanggung', -5.3181200, 104.7415200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71104, 'Singkup', 'Singkup', 'Singkup', -7.2634000, 107.2709000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71105, 'Mitrabakti', 'Mitrabakti', 'Mitrabakti', -7.2852000, 107.3584000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71106, 'Pancalan', 'Pancalan', 'Pancalan', -7.3159000, 107.3138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71107, 'Singkup', 'Singkup', 'Singkup', -7.3466000, 107.2919000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71108, 'Ciparay', 'Ciparay', 'Ciparay', -7.3705000, 107.3391000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71109, 'Negla', 'Negla', 'Negla', -7.2733000, 107.6757000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71110, 'Sukamahi Satu', 'Sukamahi Satu', 'Sukamahi Satu', -7.1290000, 107.0331000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71111, 'Cibogo Dua', 'Cibogo Dua', 'Cibago Dua,Cibogo Dua', -7.2055000, 107.0014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71112, 'Sukakarya', 'Sukakarya', 'Sukakarya', -7.2356000, 107.0083000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71113, 'Cimanggu', 'Cimanggu', 'Cimanggu,Tjimanggoe 2', -7.2449000, 107.0276000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71114, 'Kebonkaret', 'Kebonkaret', 'Kebonkaret', -7.2417000, 107.0718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71115, 'Legokbuluh', 'Legokbuluh', 'Legokbuluh', -7.2256000, 107.1219000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71116, 'Cisasak', 'Cisasak', 'Cisasak', -7.1929000, 107.1247000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71117, 'Parabon', 'Parabon', 'Parabon', -7.1386000, 107.1157000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71118, 'Kampungtengah', 'Kampungtengah', 'Kampungtengah', -7.1439000, 107.0826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71119, 'Gintungsari', 'Gintungsari', 'Gintungsari', -7.1536000, 107.0358000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71120, 'Warungawi', 'Warungawi', 'Warungawi', -7.1902000, 107.0269000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71121, 'Sukasari', 'Sukasari', 'Sukasari', -7.1916000, 107.0547000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71122, 'Ciduren', 'Ciduren', 'Ciduren,Tjidoeren 2', -7.1918000, 107.0754000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71123, 'Selagedang Dua', 'Selagedang Dua', 'Selagedang Dua', -7.1858000, 107.1106000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71124, 'Pasirreungit', 'Pasirreungit', 'Pasirreungit', -7.0097000, 107.0098000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71125, 'Mekarjaya', 'Mekarjaya', 'Mekarjaya', -7.0252000, 107.0252000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71126, 'Babakanbandung', 'Babakanbandung', 'Babakanbandung', -7.0960000, 107.0267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71127, 'Kalibaru', 'Kalibaru', 'Kalibaru', -7.0759000, 107.0426000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71128, 'Babakanlapang', 'Babakanlapang', 'Babakanlapang', -7.0656000, 107.0602000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71129, 'Wangun', 'Wangun', 'Wangun', -7.0308000, 107.0933000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71130, 'Ciodeng', 'Ciodeng', 'Ciodeng', -7.1127000, 107.0959000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71131, 'Sukaasih', 'Sukaasih', 'Sukaasih', -7.0115000, 107.1148000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71132, 'Kota Ternate', 'Kota Ternate', '', 0.7833300, 127.3666700, 'ID', '2011-08-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71133, 'Ciharus', 'Ciharus', 'Ciharus,Tjiharoes', -7.3808000, 107.8196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71134, 'Barubandung', 'Barubandung', 'Baroebandoeng,Barubandung', -7.3858000, 107.8307000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71135, 'Pawitra', 'Pawitra', 'Pawitra', -7.3959000, 107.8706000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71136, 'Cikembar', 'Cikembar', 'Cikembar', -7.3977000, 107.8386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71137, 'Talagajaya', 'Talagajaya', 'Talagajaya', -7.4158000, 107.8727000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71138, 'Potongan', 'Potongan', 'Potongan', -7.4374000, 107.8354000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71139, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan', -7.4991000, 107.8601000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71140, 'Amerta', 'Amerta', 'Amerta', -7.2770000, 107.7740000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71141, 'Simpang', 'Simpang', 'Simpang', -7.3669000, 107.7756000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71142, 'Panyingkiran', 'Panyingkiran', 'Panyingkiran', -7.3540000, 107.7804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71143, 'Ciwaru', 'Ciwaru', 'Ciwaru,Tjiwaroe', -7.2946000, 107.7864000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71144, 'Paledang', 'Paledang', 'Paledang', -7.3096000, 107.7909000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71145, 'Cisero', 'Cisero', 'Cisero,Tjisero', -7.3207000, 107.7938000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71146, 'Cipaku', 'Cipaku', 'Cipaku', -7.3707000, 107.7551000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71147, 'Cidatar Kulon', 'Cidatar Kulon', 'Cidatar Kulon', -7.3278000, 107.7939000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71148, 'Sukatani', 'Sukatani', 'Sukatani', -7.3434000, 107.7886000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71149, 'Sirnagalih', 'Sirnagalih', 'Sirnagalih', -7.3505000, 107.7999000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71150, 'Pasar Kidul', 'Pasar Kidul', 'Pasar Kidul', -7.3109000, 107.7936000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71151, 'Sukawangsa', 'Sukawangsa', 'Soekawangsa,Sukawangsa', -7.2589000, 107.8011000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71152, 'Rancabolang', 'Rancabolang', 'Rancabolang', -7.2715000, 107.8031000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71153, 'Pangauban', 'Pangauban', 'Pangauban', -7.2736000, 107.8035000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71154, 'Cigintung', 'Cigintung', 'Cigintung', -7.2793000, 107.8079000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71155, 'Losari', 'Losari', 'Losari', -7.2924000, 107.8052000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71156, 'Gudang', 'Gudang', 'Goedang,Gudang', -7.3070000, 107.7967000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71157, 'Cigeudeug', 'Cigeudeug', 'Cigeudeug', -7.3311000, 107.8070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71158, 'Padasono', 'Padasono', 'Padasono', -7.3559000, 107.8034000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71159, 'Cibodas', 'Cibodas', 'Cibodas', -7.3626000, 107.8146000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71160, 'Barusuda', 'Barusuda', 'Baroesoeda,Barusuda', -7.3525000, 107.8127000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71161, 'Kandangsapi', 'Kandangsapi', 'Kandangsapi', -7.3140000, 107.8114000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71162, 'Nagaracinta', 'Nagaracinta', 'Nagaracinta,Nagaratjinta', -7.2928000, 107.8143000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71163, 'Cipanggilingan', 'Cipanggilingan', 'Cipanggilingan', -7.2664000, 107.8164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71164, 'Cicayur', 'Cicayur', 'Cicayur,Tjitjajoer', -7.2864000, 107.8196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71165, 'Giriawas', 'Giriawas', 'Giriawas', -7.3640000, 107.8213000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71166, 'Tegalsari', 'Tegalsari', 'Tegalsari', -7.2955000, 107.8313000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71167, 'Cinisti', 'Cinisti', 'Cinisti', -7.2689000, 107.8298000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71168, 'Urug', 'Urug', 'Oeroeg,Urug', -7.2549000, 107.8324000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71169, 'Dangdeur', 'Dangdeur', 'Dangdeur', -7.2525000, 107.8294000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71170, 'Ciela Lebak', 'Ciela Lebak', 'Ciela Lebak', -7.2667000, 107.8369000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71171, 'Nangoh Tonggoh', 'Nangoh Tonggoh', 'Nangoh Tonggoh', -7.2672000, 107.8478000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71172, 'Gudang', 'Gudang', 'Gudang', -7.2605000, 107.8547000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71173, 'Cimacan', 'Cimacan', 'Cimacan,Tjimatjan', -7.2633000, 107.8580000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71174, 'Bangbayang', 'Bangbayang', 'Bangbayang', -7.2641000, 107.8623000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71175, 'Bebedahan', 'Bebedahan', 'Bebedahan', -7.2599000, 107.8746000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71176, 'Cibalieur', 'Cibalieur', 'Cibalieur', -7.6965000, 107.8826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71177, 'Ciandum', 'Ciandum', 'Ciandum', -7.7358000, 107.9975000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71178, 'Simpang', 'Simpang', 'Simpang', -7.6401000, 107.9066000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71179, 'Nagrog', 'Nagrog', 'Nagrog,Nagrog 3', -7.6598000, 107.9838000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71180, 'Babakankiray', 'Babakankiray', 'Babakankiray', -7.6839000, 107.9651000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71181, 'Cipanas', 'Cipanas', 'Cipanas', -7.7198000, 107.9681000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71182, 'Ciheras', 'Ciheras', 'Ciheras', -7.7309000, 107.9622000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71183, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum 1', -7.5039000, 107.9158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71184, 'Kebonkai', 'Kebonkai', 'Kebonkai', -7.5025000, 107.9670000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71185, 'Cibuntiris', 'Cibuntiris', 'Cibuntiris,Tjiboentiris', -7.5064000, 107.9775000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71186, 'Kertanegla', 'Kertanegla', 'Kertanegla', -7.5128000, 107.9575000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71187, 'Saribakti', 'Saribakti', 'Saribakti', -7.5341000, 107.9306000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71188, 'Parabon', 'Parabon', 'Parabon', -7.5351000, 107.9207000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71189, 'Awilega', 'Awilega', 'Awilega', -7.5391000, 107.9841000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71190, 'Pangrumasan', 'Pangrumasan', 'Pangroemasan,Pangrumasan', -7.5661000, 107.8973000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71191, 'Pasirirnem', 'Pasirirnem', 'Pasirirnem', -7.5647000, 107.9242000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71192, 'Datarnangka', 'Datarnangka', 'Datarnangka', -7.5711000, 107.9575000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71193, 'Cicomre', 'Cicomre', 'Cicomre,Tjitjombre', -7.5953000, 107.9559000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71194, 'Cirangkong', 'Cirangkong', 'Cirangkong,Tjirangkong', -7.6232000, 107.9291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71195, 'Sukamanah', 'Sukamanah', 'Sukamanah', -7.3932000, 107.9876000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71196, 'Cikondang', 'Cikondang', 'Cikondang,Tjikondang 1', -7.4090000, 107.8813000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71197, 'Padahurip', 'Padahurip', 'Padahurip', -7.4133000, 107.9156000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71198, 'Sawahbaru', 'Sawahbaru', 'Sawahbaru', -7.4213000, 107.9964000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71199, 'Talagasari', 'Talagasari', 'Talagasari', -7.4205000, 107.9231000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71200, 'Parungjawa', 'Parungjawa', 'Parungjawa', -7.4201000, 107.9025000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71201, 'Cikokong', 'Cikokong', 'Cikokong,Tjikokong', -7.4469000, 107.8940000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71202, 'Kudang', 'Kudang', 'Kudang', -7.4565000, 107.9716000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71203, 'Jayabakti', 'Jayabakti', 'Jayabakti', -7.4528000, 107.8849000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71204, 'Nangkapayung', 'Nangkapayung', 'Nangkapajoeng,Nangkapayung', -7.4599000, 107.9217000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71205, 'Pancasura', 'Pancasura', 'Pancasura,Pantjasoera', -7.4637000, 107.9342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71206, 'Ancol', 'Ancol', 'Ancol', -7.4599000, 107.9856000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71207, 'Sukawangi', 'Sukawangi', 'Sukawangi', -7.4709000, 107.9366000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71208, 'Cikadu', 'Cikadu', 'Cikadu,Tjikadoe 3', -7.4730000, 107.8920000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71209, 'Cibitung', 'Cibitung', 'Cibitung', -7.4831000, 107.9233000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71210, 'Cigintung', 'Cigintung', 'Cigintung,Tjigintoeng 2', -7.4857000, 107.9158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71211, 'Cijoho', 'Cijoho', 'Cijoho,Tjidjoho', -7.4958700, 107.9305600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71212, 'Kondangrege', 'Kondangrege', 'Kondangrege', -7.2721000, 107.8900000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71213, 'Desakolot', 'Desakolot', 'Desakolot', -7.2562000, 107.8930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71214, 'Cimaung Kidul', 'Cimaung Kidul', 'Cimaung Kidul', -7.2609000, 107.8979000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71215, 'Cikuwiwi', 'Cikuwiwi', 'Cikuwiwi,Tjikoewiwi', -7.2794000, 107.8936000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71216, 'Pasirlimus', 'Pasirlimus', 'Pasirlimoes,Pasirlimus', -7.2779000, 107.8997000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71217, 'Babakan Loak', 'Babakan Loak', 'Babakan Loak', -7.2916000, 107.9130000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71218, 'Cinyawar', 'Cinyawar', 'Cinyawar', -7.3325000, 107.9241000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71219, 'Cigarungsang', 'Cigarungsang', 'Cigarungsang', -7.2973000, 107.9236000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71220, 'Cigadog', 'Cigadog', 'Cigadog', -7.2825000, 107.9216000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71221, 'Babakan Baru', 'Babakan Baru', 'Babakan Baru', -7.2515000, 107.9271000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71222, 'Pasirhuni', 'Pasirhuni', 'Pasirhuni', -7.2975000, 107.9302000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71223, 'Sukamukti', 'Sukamukti', 'Sukamukti', -7.3727000, 107.9396000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71224, 'Bojongloa', 'Bojongloa', 'Bodjongloa,Bojongloa', -7.3199000, 107.9327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71225, 'Balemoyan', 'Balemoyan', 'Balemoyan', -7.3174000, 107.9452000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71226, 'Citeguh', 'Citeguh', 'Citeguh', -7.3372000, 107.9513000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71227, 'Pangalengan', 'Pangalengan', 'Pangalengan', -7.3473000, 107.9658000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71228, 'Cilated', 'Cilated', 'Cilated', -7.3312000, 107.9703000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71229, 'Langkop', 'Langkop', 'Langkop', -7.3603000, 107.9829000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71230, 'Pawitan', 'Pawitan', 'Pawitan', -7.3653000, 107.9971000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71231, 'Babakan Sukasari', 'Babakan Sukasari', 'Babakan Sukasari', -7.2696000, 107.8829000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71232, 'Sundawenang', 'Sundawenang', 'Sundawenang', -7.3719000, 107.9983000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71233, 'Sikluk', 'Sikluk', 'Sikloek,Sikluk', -7.1258000, 107.9603000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71234, 'Pasirjengkol', 'Pasirjengkol', 'Pasirdjengkol,Pasirjengkol', -7.1267000, 107.9903000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71235, 'Neglasari', 'Neglasari', 'Neglasari,Patjoel', -7.1267000, 107.9951000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71236, 'Jembatandua', 'Jembatandua', 'Jembatandua', -7.1361000, 107.9879000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71237, 'Batukarut', 'Batukarut', 'Batukarut', -7.1366000, 107.9713000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71238, 'Babakanloa', 'Babakanloa', 'Babakanloa', -7.1361000, 107.9481000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71239, 'Pangeureunan', 'Pangeureunan', 'Pangeureunan', -7.1376000, 107.9318000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71240, 'Karobokan', 'Karobokan', 'Karobokan,Karoebakan', -7.1831000, 107.8797000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71241, 'Nagara Tengah', 'Nagara Tengah', 'Nagara Tengah', -7.1934000, 107.8836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71242, 'Panunggangan', 'Panunggangan', 'Panoenggangan,Panunggangan', -7.2274000, 107.8874000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71243, 'Besarmanah', 'Besarmanah', 'Besarmanah', -7.2249000, 107.8918000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71244, 'Panawuan', 'Panawuan', 'Panawoean,Panawuan', -7.2147000, 107.8842000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71245, 'Astana Hilir', 'Astana Hilir', 'Astana Hilir', -7.2102100, 107.8891400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71246, 'Kalidung', 'Kalidung', 'Kalidung', -7.1913000, 107.8902000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71247, 'Pangkalan', 'Pangkalan', 'Pangkalan', -7.1773000, 107.8844000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71248, 'Warungtanjung', 'Warungtanjung', 'Waroengtandjoeng,Warungtanjung', -7.1685000, 107.8935000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71249, 'Perum', 'Perum', 'Perum', -7.1700000, 107.8975000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71250, 'Jayaraga Kaler', 'Jayaraga Kaler', 'Jayaraga Kaler', -7.2043000, 107.9004000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71251, 'Rengganis', 'Rengganis', 'Rengganis', -7.2127000, 107.8986000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71252, 'Cangkuang', 'Cangkuang', 'Cangkuang,Tjangkoeang', -7.2280000, 107.9010000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71253, 'Cilongkrangpasantren', 'Cilongkrangpasantren', 'Cilongkrangpasantren', -7.2044000, 107.9897000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71254, 'Pataruman', 'Pataruman', 'Pataroeman,Pataruman', -7.1966000, 107.9911000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71255, 'Tegalpanjang', 'Tegalpanjang', 'Tegalpandjang,Tegalpanjang', -7.1932000, 107.9839000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71256, 'Citangtu Kaler', 'Citangtu Kaler', 'Citangtu Kaler', -7.1675000, 107.9890000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71257, 'Sukagalih', 'Sukagalih', 'Sukagalih', -7.1462000, 107.9783000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71258, 'Samanggen', 'Samanggen', 'Samanggen', -7.1679000, 107.9838000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71259, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureumtoea', -7.1597000, 107.9933000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71260, 'Pangatikan', 'Pangatikan', 'Pangatikan', -7.1549000, 107.9883000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71261, 'Cikole Hilir', 'Cikole Hilir', 'Cikole Hilir', -7.1679000, 107.9786000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71262, 'Bebedahan', 'Bebedahan', 'Bebedahan', -7.1783000, 107.9804000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71263, 'Cinunuk Girang', 'Cinunuk Girang', 'Cinunuk Girang,Tjinoenoenk Girang', -7.1787000, 107.9751000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71264, 'Sadang Kulon', 'Sadang Kulon', 'Sadang Kulon', -7.1873000, 107.9736000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71265, 'Lemahsari', 'Lemahsari', 'Lemahsari', -7.1909000, 107.9684000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71266, 'Situsari', 'Situsari', 'Situsari', -7.1904000, 107.9719000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71267, 'Jati', 'Jati', 'Djati 4,Jati', -7.1959000, 107.9669000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71268, 'Peer', 'Peer', 'Peer', -7.2028000, 107.9765000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71269, 'Sidangpalay', 'Sidangpalay', 'Sidangpalay', -7.2091000, 107.9555000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71270, 'Sugihmukti', 'Sugihmukti', 'Sugihmukti', -7.2009000, 107.9597000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71271, 'Pidayeuheun', 'Pidayeuheun', 'Pidajeuheun,Pidayeuheun', -7.1948000, 107.9597000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71272, 'Cipatat', 'Cipatat', 'Cipatat', -7.1994000, 107.9504000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71273, 'Bojongkalapa', 'Bojongkalapa', 'Bodjongkalapa,Bojongkalapa', -7.1862000, 107.9557000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71274, 'Cipicung', 'Cipicung', 'Cipicung,Tjipitjoeng', -7.1762000, 107.9488000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71275, 'Parigi', 'Parigi', 'Parigi', -7.1565000, 107.9514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71276, 'Balakasap', 'Balakasap', 'Balakasap', -7.1499000, 107.9622000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71277, 'Cileungsing', 'Cileungsing', 'Cileungsing', -7.1482000, 107.9424000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71278, 'Rancapare', 'Rancapare', 'Rancapare,Rantjapare', -7.1568000, 107.9439000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71279, 'Sindanglaya', 'Sindanglaya', 'Sindanglaya', -7.1989000, 107.9471000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71280, 'Nagrog Wetan', 'Nagrog Wetan', 'Nagrog Wetan', -7.2071000, 107.9469000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71281, 'Sukamanah', 'Sukamanah', 'Sukamanah', -7.2030000, 107.9422000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71282, 'Cogreg Wetan', 'Cogreg Wetan', 'Cogreg Wetan', -7.2187000, 107.9367000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71283, 'Cipondok', 'Cipondok', 'Cipondok', -7.2388000, 107.9420000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71284, 'Cimaragas', 'Cimaragas', 'Cimaragas,Tjimaragas', -7.2447000, 107.9085000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71285, 'Babakan', 'Babakan', 'Babakan', -7.1543000, 107.9108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71286, 'Andir', 'Andir', 'Andir', -7.1548000, 107.9011000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71287, 'Gunungsatria', 'Gunungsatria', 'Gunungsatria', -7.2256000, 107.9062000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71288, 'Pakuwon', 'Pakuwon', 'Pakuwon', -7.2155000, 107.9036000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71289, 'Mawar', 'Mawar', 'Mawar', -7.2124000, 107.9050000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71290, 'Haurpanggung', 'Haurpanggung', 'Haurpanggung', -7.2056000, 107.9047000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71291, 'Gugunungan', 'Gugunungan', 'Gugunungan', -7.2349000, 107.9125000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71292, 'Taluncemara', 'Taluncemara', 'Taluncemara', -7.2196000, 107.9078000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71293, 'Ciwalen', 'Ciwalen', 'Ciwalen', -7.2155000, 107.9096000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71294, 'Bentar Girang', 'Bentar Girang', 'Bentar Girang', -7.2117000, 107.9114000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71295, 'Jangkurang Kidul', 'Jangkurang Kidul', 'Jangkurang Kidul', -7.2072000, 107.9087000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71296, 'Cilolohan', 'Cilolohan', 'Cilolohan,Tjisolokan', -7.1810000, 107.9127000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71297, 'Ngompot', 'Ngompot', 'Ngompot', -7.1733000, 107.9167000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71298, 'Suci Kaler', 'Suci Kaler', 'Suci Kaler', -7.2157000, 107.9226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71299, 'Suci Kidul', 'Suci Kidul', 'Suci Kidul', -7.2175000, 107.9226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71300, 'Nangerang', 'Nangerang', 'Nangerang,Nanggerang 2', -7.2357000, 107.9210000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71301, 'Cogreg Kulon', 'Cogreg Kulon', 'Cogreg Kulon', -7.2187000, 107.9308000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71302, 'Kudang', 'Kudang', 'Kudang', -7.2175000, 107.9279000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71303, 'Karangmulya', 'Karangmulya', 'Karangmulya', -7.2073000, 107.9289000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71304, 'Lengkongjaya', 'Lengkongjaya', 'Lengkongjaya', -7.2004000, 107.9286000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71305, 'Tegaljati', 'Tegaljati', 'Tegaldjati,Tegaljati', -7.1949000, 107.9299000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71306, 'Cireundang', 'Cireundang', 'Cireundang,Tjirendang', -7.2002100, 107.8781900, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71307, 'Peujeuh', 'Peujeuh', 'Peujeuh,Tjipeudjeuh 1', -7.0152000, 107.9780000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71308, 'Margabakti', 'Margabakti', 'Margabakti', -7.0137000, 107.8771000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71309, 'Cigorowong Kidul', 'Cigorowong Kidul', 'Cigorowong Kidul', -7.0220000, 107.8845000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71310, 'Ikar', 'Ikar', 'Ikar', -7.0204000, 107.9735000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71311, 'Bakom', 'Bakom', 'Bakom', -7.0319000, 107.9978000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71312, 'Kudang', 'Kudang', 'Kudang', -7.0331000, 107.9841000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71313, 'Saar Kaler', 'Saar Kaler', 'Saar Kaler', -7.0274000, 107.9253000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71314, 'Ciburial', 'Ciburial', 'Ciburial,Tjiboerial', -7.0396000, 107.9077000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71315, 'Tegallame', 'Tegallame', 'Tegallame', -7.0381000, 107.9379000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71316, 'Cilolongokan', 'Cilolongokan', 'Cilolongokan', -7.0378000, 107.9712000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71317, 'Burujul', 'Burujul', 'Burujul', -7.0376000, 107.9762000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71318, 'Gempol', 'Gempol', 'Gempol', -7.0368000, 107.9966000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71319, 'Talun', 'Talun', 'Talun', -7.0548000, 107.9347000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71320, 'Cigaluh', 'Cigaluh', 'Cigaluh,Tjigaloeh', -7.0526000, 107.9984000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71321, 'Saradan', 'Saradan', 'Saradan', -7.0577000, 107.9793000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71322, 'Karangtengah', 'Karangtengah', 'Karangtengah', -7.0744000, 107.8925000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71323, 'Cihuni', 'Cihuni', 'Cihuni', -7.0709000, 107.8997000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71324, 'Sinarbakti', 'Sinarbakti', 'Sinarbakti', -7.0694000, 107.9107000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71325, 'Tangulun', 'Tangulun', 'Tanggoeloen,Tangulun', -7.0688000, 107.9196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71326, 'Haruman', 'Haruman', 'Haruman', -7.0720000, 107.9265000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71327, 'Sukasari', 'Sukasari', 'Sukasari', -7.0686000, 107.9638000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71328, 'Bunisari', 'Bunisari', 'Boenisari,Bunisari', -7.0724000, 107.9614000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71329, 'Pasantrentengah', 'Pasantrentengah', 'Pasantren-tengah,Pasantrentengah', -7.0761000, 107.9675000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71330, 'Cileles', 'Cileles', 'Cileles,Tjileles 2', -7.0792000, 107.9812000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71331, 'Situbatu', 'Situbatu', 'Sitoebatoe,Situbatu', -7.0763000, 107.9575000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71332, 'Batugede Kulon', 'Batugede Kulon', 'Batugede Kulon', -7.0793000, 107.9131000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71333, 'Maribaya', 'Maribaya', 'Maribaya', -7.0861000, 107.8764000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71334, 'Hegarsari', 'Hegarsari', 'Hegarsari', -7.0883000, 107.8869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71335, 'Slamanyah', 'Slamanyah', 'Selamandjah,Slamanyah', -7.0902000, 107.8963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71336, 'Halteu', 'Halteu', 'Halteu', -7.0836000, 107.8991000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71337, 'Babakansingkur', 'Babakansingkur', 'Babakansingkur', -7.0910000, 107.9160000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71338, 'Citambal', 'Citambal', 'Citambal,Tjitambal', -7.0884000, 107.9947000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71339, 'Ciranca', 'Ciranca', 'Ciranca', -7.0832000, 107.9980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71340, 'Cibodas', 'Cibodas', 'Cibodas', -7.0962000, 107.9858000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71341, 'Cibolang', 'Cibolang', 'Cibolang,Pasirtjibolang', -7.0927000, 107.9333000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71342, 'Nangkasari', 'Nangkasari', 'Nangkasari', -7.0984000, 107.8827000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71343, 'Ciharus', 'Ciharus', 'Ciharus', -7.0977000, 107.8773000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71344, 'Salamnunggal', 'Salamnunggal', 'Salamnoenggal,Salamnunggal', -7.1064000, 107.8980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71345, 'Dungusiku', 'Dungusiku', 'Doengoessikoe,Dungusiku', -7.1077000, 107.9323000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71346, 'Sarkanjut', 'Sarkanjut', 'Sarkandjoet,Sarkanjut', -7.1089700, 107.9417300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71347, 'Pasirluhur', 'Pasirluhur', 'Pasirluhur', -7.1040000, 107.9546000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71348, 'Pasar', 'Pasar', 'Pasar', -7.1008000, 107.9577000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71349, 'Wanakerta', 'Wanakerta', 'Wanakerta', -7.1036000, 107.9870000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71350, 'Sindangkerta', 'Sindangkerta', 'Sindangkerta', -7.1100000, 107.9840000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71351, 'Sindangsari', 'Sindangsari', 'Sindangsari,Sindangsinar', -7.1169000, 107.9446000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71352, 'Ciperang', 'Ciperang', 'Ciperang,Tjiperang', -7.1163000, 107.9246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71353, 'Jati', 'Jati', 'Jati', -7.1158000, 107.9118000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71354, 'Pasar Kulon', 'Pasar Kulon', 'Pasar Kulon', -7.1112000, 107.8967000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71355, 'Pasirsalam', 'Pasirsalam', 'Pasirsalam', -7.1186000, 107.8954000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71356, 'Babakanloa', 'Babakanloa', 'Babakanloa', -7.1014000, 107.9796000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71357, 'Gununglimbangan', 'Gununglimbangan', 'Gununglimbangan', -7.1016000, 107.9841000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71358, 'Tagog', 'Tagog', 'Tagog,Tagok', -7.1206000, 107.9931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71359, 'Sindangkerta', 'Sindangkerta', 'Sindangkerta', -7.7652000, 108.0712000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71360, 'Cikawunggading', 'Cikawunggading', 'Cikawunggading,Tjikawoengading', -7.7701000, 108.1017000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71361, 'Burujul Tengah', 'Burujul Tengah', 'Burujul Tengah', -7.6286000, 108.0730000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71362, 'Pasirtujuhpuluh', 'Pasirtujuhpuluh', 'Pasirtujuhpuluh', -7.6270000, 108.1025000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71363, 'Cibatear', 'Cibatear', 'Cibatear,Tjibatear', -7.6378000, 108.0327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71364, 'Menol', 'Menol', 'Menol', -7.6430000, 108.0879000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71365, 'Cikaret', 'Cikaret', 'Cikaret,Tjikaret', -7.6465000, 108.1196000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71366, 'Babakankadu', 'Babakankadu', 'Babakan Kadoe 3,Babakankadu', -7.6610000, 108.0266000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71367, 'Gintung', 'Gintung', 'Gintoeng,Gintung', -7.6593000, 108.0476000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71368, 'Gawul', 'Gawul', 'Gawul', -7.6600000, 108.0786000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71369, 'Ciceuri', 'Ciceuri', 'Ciceuri', -7.6823000, 108.0494000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71370, 'Cilangla', 'Cilangla', 'Cilangla', -7.6753000, 108.1217000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71371, 'Cikatulampa', 'Cikatulampa', 'Cikatulampa,Tjikatoelampa', -7.6927000, 108.0470000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71372, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.5045000, 108.0069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71373, 'Derah', 'Derah', 'Derah', -7.5112000, 108.0911000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71374, 'Kubangsari', 'Kubangsari', 'Kubangsari', -7.5174000, 108.0307000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71375, 'Wakap', 'Wakap', 'Wakap', -7.5241000, 108.0838000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71376, 'Pugeran', 'Pugeran', 'Poegeran,Pugeran', -7.5389000, 108.0939000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71377, 'Cibabakan', 'Cibabakan', 'Cibabakan,Tjibabakan 2', -7.5480000, 108.1064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71378, 'Wangunsari', 'Wangunsari', 'Wangunsari', -7.5412000, 108.0455000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71379, 'Cikadu', 'Cikadu', 'Cikadu', -7.5959000, 108.0583000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71380, 'Simpang', 'Simpang', 'Simpang', -7.6231000, 108.1064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71381, 'Cibongkok', 'Cibongkok', 'Cibongkok', -7.3883000, 108.0178000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71382, 'Lengkongsari', 'Lengkongsari', 'Lengkongsari', -7.4116000, 108.0163000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71383, 'Nagrog', 'Nagrog', 'Nagrog', -7.3896000, 108.0301000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71384, 'Ciawitali', 'Ciawitali', 'Ciawitali,Tjiawitali', -7.3837000, 108.0618000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71385, 'Pasirsalam', 'Pasirsalam', 'Pasirsalam', -7.3958000, 108.0775000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71386, 'Cimanggu', 'Cimanggu', 'Cimanggu,Tjimanggoe 2', -7.4045000, 108.0885000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71387, 'Cimaung', 'Cimaung', 'Cimaung,Tjimaoeng', -7.4034000, 108.1016000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71388, 'Tanjungjaya', 'Tanjungjaya', 'Tanjungjaya', -7.3882000, 108.1215000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71389, 'Bebedahan', 'Bebedahan', 'Bebedahan', -7.4065000, 108.1187000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71390, 'Cikeusal', 'Cikeusal', 'Cikeusal', -7.4328000, 108.1149000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71391, 'Karangsari', 'Karangsari', 'Karangsari', -7.4461000, 108.0843000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71392, 'Puspajaya', 'Puspajaya', 'Puspajaya', -7.4164000, 108.0697000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71393, 'Pusparahayu', 'Pusparahayu', 'Pusparahayu', -7.4284000, 108.0593000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71394, 'Singasari', 'Singasari', 'Singasari', -7.4505000, 108.0184000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71395, 'Pangeureunan', 'Pangeureunan', 'Pangeureunan', -7.4295000, 108.0065000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71396, 'Raksajaya', 'Raksajaya', 'Raksajaya', -7.4894000, 108.0842000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71397, 'Cipaingeun', 'Cipaingeun', 'Cipaingeun,Tjipaingeun', -7.4811000, 108.0935000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71398, 'Pakalongan', 'Pakalongan', 'Pakalongan', -7.4729000, 108.1079000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71399, 'Cigunung', 'Cigunung', 'Cigunung', -7.4942000, 108.1146000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71400, 'Kubang', 'Kubang', 'Kubang', -7.4585000, 108.1106000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71401, 'Cihaseum', 'Cihaseum', 'Cihaseum,Tjihaseum 2', -7.2781000, 108.1138000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71402, 'Cibenda', 'Cibenda', 'Cibenda,Tjibende,Tjibĕnde', -7.3089000, 108.1217000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71403, 'Ciawang', 'Ciawang', 'Ciawang,Tjiawang', -7.3223000, 108.1135000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71404, 'Pasiripis', 'Pasiripis', 'Pasiripis', -7.2994000, 108.1133000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71405, 'Peundeuy', 'Peundeuy', 'Peundeuj 3,Peundeuy', -7.3036000, 108.1007000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71406, 'Nanggorak', 'Nanggorak', 'Nanggorak,Nangorak', -7.3164000, 108.1001000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71407, 'Bebedahan', 'Bebedahan', 'Bebedahan,Bebedahan 3,Bĕbĕdahan 3', -7.3035000, 108.0956000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71408, 'Pinggirsari', 'Pinggirsari', 'Pinggirsari', -7.3173000, 108.0853000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71409, 'Kalieung', 'Kalieung', 'Kalieung', -7.3185000, 108.0821000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71410, 'Nangewer', 'Nangewer', 'Nangewer', -7.3137000, 108.0696000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71411, 'Pacihayan', 'Pacihayan', 'Pacihayan', -7.3215000, 108.0341000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71412, 'Lajaluhur', 'Lajaluhur', 'Lajaluhur', -7.3532000, 108.0100000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71413, 'Salawi', 'Salawi', 'Salawi,Slawi', -7.3411000, 108.0096000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71414, 'Pepayan', 'Pepayan', 'Pepayan', -7.3669000, 108.0221000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71415, 'Jayapura', 'Jayapura', 'Jayapura', -7.3520000, 108.0322000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71416, 'Cimonyong', 'Cimonyong', 'Cimonyong', -7.3251000, 108.0264000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71417, 'Pesantren', 'Pesantren', 'Pesantren', -7.3710000, 108.0485000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71418, 'Parawan', 'Parawan', 'Parawan', -7.3564000, 108.0515000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71419, 'Ciuyah', 'Ciuyah', 'Ciuyah,Tjioejah', -7.3508000, 108.0582000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71420, 'Rancapeundey', 'Rancapeundey', 'Rancapeundey,Rantjapeudeuj', -7.3314000, 108.0665000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71421, 'Cibatu Kaler', 'Cibatu Kaler', 'Cibatu Kaler', -7.3252000, 108.0699000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71422, 'Ciwidara', 'Ciwidara', 'Ciwidara', -7.3727000, 108.0681000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71423, 'Sukasukur', 'Sukasukur', 'Soekasoekoer,Sukasukur', -7.3737000, 108.0753000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71424, 'Parakanpanjang', 'Parakanpanjang', 'Parakanpandjang,Parakanpanjang', -7.3493000, 108.0820000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71425, 'Padakarya', 'Padakarya', 'Padakarya', -7.3359000, 108.0822000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71426, 'Kertasari', 'Kertasari', 'Kertasari', -7.3288000, 108.0784000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71427, 'Dangur', 'Dangur', 'Dangur', -7.3598000, 108.0836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71428, 'Citatah Kaler', 'Citatah Kaler', 'Citatah Kaler', -7.3471000, 108.0971000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71429, 'Selawangi', 'Selawangi', 'Selawangi', -7.3346000, 108.0962000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71430, 'Arjasari', 'Arjasari', 'Arjasari', -7.3367000, 108.1011000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71431, 'Sayuran', 'Sayuran', 'Sayuran', -7.3383000, 108.1070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71432, 'Cintawana', 'Cintawana', 'Cintawana,Tjintawana', -7.3552000, 108.1053000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71433, 'Panugeran', 'Panugeran', 'Panoegaran,Panugeran', -7.3653000, 108.1034000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71434, 'Panayagan', 'Panayagan', 'Panayagan', -7.3545000, 108.1102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71435, 'Cimanglid', 'Cimanglid', 'Cimanglid', -7.3451000, 108.1132000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71436, 'Cisaro', 'Cisaro', 'Cisaro,Tjisaro', -7.3531000, 108.1217000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71437, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.3595000, 108.1198000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71438, 'Cihampelas', 'Cihampelas', 'Cihampelas', -7.3647000, 108.1230000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71439, 'Tambakan', 'Tambakan', 'Tambakan', -7.3732000, 108.1198000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71440, 'Putrajawa', 'Putrajawa', 'Poetradjawa,Putrajawa', -7.0054000, 108.0109000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71441, 'Cihayam', 'Cihayam', 'Cihayam', -7.0079000, 108.0195000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71442, 'Sindangkopo', 'Sindangkopo', 'Sindangkopo', -7.0026000, 108.0281000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71443, 'Babakancikaso', 'Babakancikaso', 'Babakan Tjikaso,Babakancikaso', -7.0186000, 108.0040000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71444, 'Rancapanjang', 'Rancapanjang', 'Rancapanjang,Rantjapandjang 1', -7.0267000, 108.0059000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71445, 'Surabaya', 'Surabaya', 'Soerabaja 2,Surabaya', -7.0259000, 108.0209000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71446, 'Ciloa', 'Ciloa', 'Ciloa', -7.0210000, 108.0261000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71447, 'Mekarasih', 'Mekarasih', 'Mekarasih', -7.0269000, 108.0860000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71448, 'Rancamaya', 'Rancamaya', 'Rancamaya,Rantjamaja', -7.0359000, 108.0769000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71449, 'Babakan Nyampay', 'Babakan Nyampay', 'Babakan Njampaj,Babakan Nyampay', -7.0465000, 108.0870000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71450, 'Cibunar', 'Cibunar', 'Cibunar,Tjibonar 2', -7.0458000, 108.0676000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71451, 'Bandrek', 'Bandrek', 'Bandrek', -7.0553000, 108.0097000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71452, 'Kubang', 'Kubang', 'Kubang', -7.0526000, 108.0200000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71453, 'Sukaratu', 'Sukaratu', 'Sukaratu', -7.0532000, 108.0482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71454, 'Pasarkolot', 'Pasarkolot', 'Pasarkolot', -7.0565000, 108.0900000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71455, 'Cipeuyeum', 'Cipeuyeum', 'Cipeuyeum', -7.0664000, 108.0889000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71456, 'Cisalakdesa', 'Cisalakdesa', 'Cisalakdesa,Tjisalak 1', -7.0606000, 108.0056000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71457, 'Babakancilamo', 'Babakancilamo', 'Babakancilamo', -7.0740000, 108.0121000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71458, 'Padaimut', 'Padaimut', 'Padaimoet,Padaimut', -7.0727000, 108.0258000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71459, 'Baros', 'Baros', 'Baros', -7.0746000, 108.0442000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71460, 'Citalahab', 'Citalahab', 'Citalahab,Tjitalahab', -7.0675000, 108.0842000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71461, 'Pasirbaros', 'Pasirbaros', 'Pasirbaros', -7.0763000, 108.0948000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71462, 'Sukabatu', 'Sukabatu', 'Soekabatoe,Sukabatu', -7.0807000, 108.0663000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71463, 'Pasar', 'Pasar', 'Pasar', -7.0953000, 108.1002000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71464, 'Cibugel', 'Cibugel', 'Cibugel', -7.0985000, 108.1010000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71465, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.0957000, 108.0768000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71466, 'Patrol', 'Patrol', 'Patrol,Patrol 2', -7.1100000, 108.1066000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71467, 'Wage Cibahayu', 'Wage Cibahayu', 'Wage 1,Wage Cibahayu', -7.1206000, 108.1111000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71468, 'Palumbungan', 'Palumbungan', 'Paloemboengan,Palumbungan', -7.1262000, 108.1126000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71469, 'Babgot', 'Babgot', 'Babgot', -7.1425000, 108.0095000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71470, 'Kostarea Satu', 'Kostarea Satu', 'Kostarea,Kostarea Satu', -7.1457000, 108.0104000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71471, 'Sinapel', 'Sinapel', 'Sinapel', -7.1581000, 108.0547000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71472, 'Cikulahan', 'Cikulahan', 'Cikulahan,Tjikoelahan', -7.1569000, 108.0375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71473, 'Sukamandi', 'Sukamandi', 'Sukamandi', -7.1606000, 108.0142000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71474, 'Cipeucang', 'Cipeucang', 'Cipeucang,Tjipeutjang', -7.1595000, 108.0074000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71475, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan', -7.1632000, 108.0084000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71476, 'Tegalgede', 'Tegalgede', 'Tegalgede', -7.1815000, 108.0016000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71477, 'Cicapar Lebak', 'Cicapar Lebak', 'Cicapar Lebak', -7.1845000, 108.0319000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71478, 'Kertamukti', 'Kertamukti', 'Kertamukti', -7.1958000, 108.1224000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71479, 'Tajurdesa', 'Tajurdesa', 'Tajurdesa', -7.2045000, 108.0078000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71480, 'Kertapura', 'Kertapura', 'Kertapura', -7.2345000, 108.0183000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71481, 'Cikancra', 'Cikancra', 'Cikancra,Tjikantjra 3', -7.7527000, 108.2110000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71482, 'Nangerang', 'Nangerang', 'Nangerang', -7.7559000, 108.2248000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71483, 'Sukahaji Satu', 'Sukahaji Satu', 'Sukahaji Satu', -7.7748000, 108.1848000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71484, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.7983000, 108.2354000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71485, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.6320000, 108.1326000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71486, 'Cibatuireng', 'Cibatuireng', 'Cibatuireng,Tjibatoeireng', -7.6355000, 108.1753000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71487, 'Citamiang', 'Citamiang', 'Citamiang,Tjitamiang', -7.6363000, 108.2380000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71488, 'Ciawi', 'Ciawi', 'Ciawi,Tjiawi', -7.6616000, 108.1266000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71489, 'Jatiwangi', 'Jatiwangi', 'Jatiwangi', -7.6610000, 108.2277000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71490, 'Gununggoong', 'Gununggoong', 'Goenoenggoong,Gununggoong', -7.6759000, 108.2177000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71491, 'Petakan', 'Petakan', 'Petakan', -7.6907000, 108.1283000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71492, 'Barengkok', 'Barengkok', 'Barengkok', -7.7152000, 108.1762000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71493, 'Cidadali', 'Cidadali', 'Cidadali', -7.7127000, 108.2090000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71494, 'Singkir', 'Singkir', 'Singkir', -7.7295000, 108.1782000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71495, 'Cibunter', 'Cibunter', 'Cibunter,Tjiboenter', -7.7385000, 108.2149000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71496, 'Tonjongsari', 'Tonjongsari', 'Tonjongsari', -7.7376000, 108.1826000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71497, 'Kujang', 'Kujang', 'Kujang', -7.7435000, 108.1370000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71498, 'Cibungur', 'Cibungur', 'Cibungur,Tjiboengoer 2', -7.5126000, 108.1333000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71499, 'Lengkongjaya', 'Lengkongjaya', 'Lengkongjaya', -7.5131000, 108.1597000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71500, 'Nangkasari', 'Nangkasari', 'Nangkasari', -7.5266000, 108.1770000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71501, 'Rancamulya', 'Rancamulya', 'Rancamulya', -7.5069000, 108.1886000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71502, 'Sukasenang', 'Sukasenang', 'Sukasenang', -7.5099000, 108.1937000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71503, 'Cikendi', 'Cikendi', 'Cikendi', -7.5181000, 108.1943000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71504, 'Datarsitu', 'Datarsitu', 'Datarsitu', -7.5088000, 108.2386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71505, 'Sukasenang', 'Sukasenang', 'Sukasenang', -7.5477000, 108.2173000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71506, 'Batulawang', 'Batulawang', 'Batoelawang,Batulawang', -7.5672000, 108.1818000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71507, 'Cipedes', 'Cipedes', 'Cipedes', -7.5523000, 108.1483000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71508, 'Madur', 'Madur', 'Madoer,Madur', -7.5812000, 108.1311000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71509, 'Rancabakung', 'Rancabakung', 'Rancabakung,Rantjabakoeng', -7.6235000, 108.1373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71510, 'Cimanggu', 'Cimanggu', 'Cimanggu,Tjimanggoe', -7.6106000, 108.1414000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71511, 'Tenjosari', 'Tenjosari', 'Tenjosari', -7.6031000, 108.1573000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71512, 'Cinunjang', 'Cinunjang', 'Cinunjang', -7.5771000, 108.1623000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71513, 'Cigembor', 'Cigembor', 'Cigembor,Tjigembor 2', -7.6164000, 108.1902000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71514, 'Datarkadu', 'Datarkadu', 'Datarkadu', -7.5866000, 108.2105000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71515, 'Bantar', 'Bantar', 'Bantar', -7.6217000, 108.2076000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71516, 'Cihaur', 'Cihaur', 'Cihaur,Tjihaoer 1', -7.3781000, 108.1351000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71517, 'Wargakerta', 'Wargakerta', 'Wargakerta', -7.3838000, 108.1495000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71518, 'Babakankalong', 'Babakankalong', 'Babakankalong', -7.3825000, 108.1600000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71519, 'Nagrok', 'Nagrok', 'Nagrok', -7.3754000, 108.1646000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71520, 'Tambir', 'Tambir', 'Tambir', -7.3770000, 108.1765000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71521, 'Cibeureum', 'Cibeureum', 'Cibeureum', -7.3871000, 108.2349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71522, 'Gegernoong', 'Gegernoong', 'Gegernoong', -7.3862000, 108.2323000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71523, 'Cianjur Kidul', 'Cianjur Kidul', 'Cianjur Kidul', -7.3911000, 108.2175000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71524, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan', -7.3872000, 108.2040000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71525, 'Sagobog', 'Sagobog', 'Sagobog', -7.3920000, 108.1498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71526, 'Talun', 'Talun', 'Taloen,Talun', -7.3850000, 108.1270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71527, 'Cigorowong', 'Cigorowong', 'Cigorowong', -7.3926000, 108.1371000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71528, 'Awilega', 'Awilega', 'Awilega', -7.3924000, 108.2093000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71529, 'Citamiang', 'Citamiang', 'Citamiang,Tjitamiang', -7.4058000, 108.1861000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71530, 'Tambakbaya', 'Tambakbaya', 'Tambakbaya,Tambaklaja', -7.4034000, 108.1786000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71531, 'Cukangawi', 'Cukangawi', 'Cukangawi', -7.4085000, 108.1741000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71532, 'Rancabelut', 'Rancabelut', 'Rancabelut,Rantjabeloet', -7.4017000, 108.1566000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71533, 'Nyemplong', 'Nyemplong', 'Njemplong,Nyemplong', -7.4180000, 108.2474000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71534, 'Tamansari', 'Tamansari', 'Tamansari', -7.4230000, 108.1931000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71535, 'Cimawate', 'Cimawate', 'Cimawate', -7.4202000, 108.1822000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71536, 'Kiaranonggeng', 'Kiaranonggeng', 'Kiaranonggeng', -7.4253000, 108.1424000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71537, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.4325000, 108.1932000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71538, 'Cijoho', 'Cijoho', 'Cijoho', -7.4403000, 108.1547000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71539, 'Sukahurip', 'Sukahurip', 'Sukahurip', -7.4475000, 108.1848000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71540, 'Unden', 'Unden', 'Unden', -7.4546000, 108.2099000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71541, 'Parakantiga', 'Parakantiga', 'Parakantiga', -7.4552000, 108.1908000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71542, 'Garunggang', 'Garunggang', 'Garunggang', -7.4659000, 108.2234000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71543, 'Cikopo', 'Cikopo', 'Cikopo,Tjikopo', -7.4606000, 108.2476000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71544, 'Pasir', 'Pasir', 'Pasir,Pasirsirah', -7.4742000, 108.1836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71545, 'Januti', 'Januti', 'Januti', -7.4709000, 108.1291000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71546, 'Datartua', 'Datartua', 'Datartua', -7.4839000, 108.2332000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71547, 'Kampungbaru', 'Kampungbaru', 'Kampungbaru', -7.4903000, 108.1582000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71548, 'Desakolot', 'Desakolot', 'Desakolot', -7.4863000, 108.1267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71549, 'Cihanjuang', 'Cihanjuang', 'Cihanjuang,Tjihandjoeang', -7.2805000, 108.1323000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71550, 'Kubangeceng', 'Kubangeceng', 'Koebangetjeng,Kubangeceng', -7.2966000, 108.1264000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71551, 'Gunungbatara', 'Gunungbatara', 'Gunungbatara,Koebangbatara', -7.3194000, 108.1407000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71552, 'Cicurug', 'Cicurug', 'Cicurug', -7.2681000, 108.1382000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71553, 'Leuwibodas', 'Leuwibodas', 'Leuwibodas', -7.2537000, 108.1351000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71554, 'Kudang', 'Kudang', 'Kudang', -7.2762000, 108.1434000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71555, 'Banjarsari', 'Banjarsari', 'Banjarsari', -7.3152000, 108.1456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71556, 'Pagaden', 'Pagaden', 'Pagaden', -7.3208000, 108.1566000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71557, 'Cibogor', 'Cibogor', 'Cibogor', -7.2549000, 108.1536000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71558, 'Karangmulya', 'Karangmulya', 'Karangmulya', -7.2613000, 108.1626000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71559, 'Pasirangin', 'Pasirangin', 'Pasirangin', -7.3158000, 108.1717000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71560, 'Bungursari', 'Bungursari', 'Bungursari', -7.3031000, 108.1709000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71561, 'Cikondang', 'Cikondang', 'Cikondang,Kondang', -7.2963000, 108.1689000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71562, 'Simpang', 'Simpang', 'Simpang', -7.2796000, 108.1674000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71563, 'Sindanggalih', 'Sindanggalih', 'Sindanggalih', -7.2769000, 108.1730000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71564, 'Neundeut', 'Neundeut', 'Neundeut', -7.2606000, 108.1713000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71565, 'Ciburuyhilir', 'Ciburuyhilir', 'Ciburuyhilir', -7.2686000, 108.1774000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71566, 'Rancageneng Satu', 'Rancageneng Satu', 'Rancageneng Satu', -7.3176000, 108.1861000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71567, 'Sukarindik', 'Sukarindik', 'Soekarindik 1,Sukarindik', -7.3011000, 108.1869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71568, 'Sukamaju Kidul', 'Sukamaju Kidul', 'Sukamaju Kidul', -7.2831000, 108.1867000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71569, 'Pagendingan', 'Pagendingan', 'Pagendingan', -7.2659000, 108.1864000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71570, 'Kebonbencoy', 'Kebonbencoy', 'Kebonbencoy', -7.2535000, 108.1874000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71571, 'Sukahaji', 'Sukahaji', 'Sukahaji', -7.2662000, 108.1984000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71572, 'Parakanhonje Wetan', 'Parakanhonje Wetan', 'Parakanhonje Wetan', -7.2801000, 108.1944000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71573, 'Sindangpalay', 'Sindangpalay', 'Sindangpalaj,Sindangpalay', -7.2891000, 108.1980000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71574, 'Pakemitan', 'Pakemitan', 'Pakemitan', -7.2924000, 108.1998000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71575, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.3149000, 108.1930000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71576, 'Argasari', 'Argasari', 'Argasari', -7.3247000, 108.2057000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71577, 'Gunungbatu', 'Gunungbatu', 'Goenoengbatoe,Gunungbatu', -7.3116000, 108.2040000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71578, 'Jati', 'Jati', 'Jati', -7.3037000, 108.2033000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71579, 'Kosangka', 'Kosangka', 'Kosangka', -7.2918000, 108.2060000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71580, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.2786000, 108.2040000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71581, 'Cisingkah', 'Cisingkah', 'Cisingkah,Tjisingkah', -7.2792000, 108.2069000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71582, 'Ampera', 'Ampera', 'Ampera', -7.3226000, 108.2108000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71583, 'Leuwidahu', 'Leuwidahu', 'Leuwidahoe,Leuwidahu', -7.3044000, 108.2109000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71584, 'Rajapeni', 'Rajapeni', 'Rajapeni', -7.2841000, 108.2148000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71585, 'Sukahurip', 'Sukahurip', 'Sukahurip', -7.2619000, 108.2169000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71586, 'Saripin', 'Saripin', 'Babakan Saripin,Saripin', -7.3325000, 108.2455000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71587, 'Nagarasari', 'Nagarasari', 'Nagarasari', -7.3003000, 108.2213000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71588, 'Mancogeh', 'Mancogeh', 'Mancogeh', -7.3087000, 108.2172000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71589, 'Tawangsari', 'Tawangsari', 'Tawangsari', -7.3227000, 108.2206000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71590, 'Sukasari', 'Sukasari', 'Sukasari', -7.3258000, 108.2322000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71591, 'Cibogor', 'Cibogor', 'Cibogor', -7.3141000, 108.2299000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71592, 'Cihideung Satu', 'Cihideung Satu', 'Cihideung Satu', -7.2845000, 108.2327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71593, 'Pengkolan', 'Pengkolan', 'Pengkolan', -7.3042000, 108.2438000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71594, 'Bojongnangka', 'Bojongnangka', 'Bodjongnangka,Bojongnangka', -7.3318000, 108.2498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71595, 'Tugu', 'Tugu', 'Tugu', -7.2962000, 108.2470000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71596, 'Golacir', 'Golacir', 'Golacir,Golatjir Dua', -7.3295000, 108.1257000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71597, 'Tabrik', 'Tabrik', 'Tabrik', -7.3610000, 108.1371000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71598, 'Cidamar', 'Cidamar', 'Cidamar', -7.3459000, 108.1388000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71599, 'Gunungkawung', 'Gunungkawung', 'Gunungkawung', -7.3389000, 108.1493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71600, 'Gunungangka', 'Gunungangka', 'Goenoengnangka,Gunungangka', -7.3430700, 108.1643400, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71601, 'Pasiripis', 'Pasiripis', 'Pasiripis,Pasiripis Satu', -7.3459000, 108.1656000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71602, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.3698000, 108.1614000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71603, 'Rancakukun', 'Rancakukun', 'Rancakukun', -7.3447000, 108.1744000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71604, 'Sudimara', 'Sudimara', 'Soedimara,Sudimara', -7.3626000, 108.1774000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71605, 'Cigantang Hilir', 'Cigantang Hilir', 'Cigantang Hilir', -7.3606000, 108.1900000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71606, 'Panyarang', 'Panyarang', 'Panyarang', -7.3472000, 108.1873000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71607, 'Cilingga', 'Cilingga', 'Cilingga,Tjilingga', -7.3373000, 108.1984000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71608, 'Gunungsubang', 'Gunungsubang', 'Goenoengsoebang,Gunungsubang', -7.3716000, 108.1949000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71609, 'Sengkol', 'Sengkol', 'Sengkol', -7.3711000, 108.2135000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71610, 'Sambongpari', 'Sambongpari', 'Sambongpari', -7.3462000, 108.2050000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71611, 'Sukagenah', 'Sukagenah', 'Sukagenah', -7.3546000, 108.2086000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71612, 'Tugusirna', 'Tugusirna', 'Tugusirna', -7.3441000, 108.2158000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71613, 'Panututan', 'Panututan', 'Panoetoetan,Panututan', -7.3410000, 108.2088000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71614, 'Gunungkoneng', 'Gunungkoneng', 'Gunungkoneng', -7.3286000, 108.2105000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71615, 'Yudanagara', 'Yudanagara', 'Yudanagara', -7.3307000, 108.2164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71616, 'Dadaha', 'Dadaha', 'Dadaha', -7.3343000, 108.2221000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71617, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.3709000, 108.2273000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71618, 'Kahuripan', 'Kahuripan', 'Kahuripan', -7.3471000, 108.2281000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71619, 'Margalaksana', 'Margalaksana', 'Margalaksana', -7.3444000, 108.2240000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71620, 'Cikalang', 'Cikalang', 'Cikalang,Tjikalang', -7.3390000, 108.2306000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71621, 'Kebontiwu', 'Kebontiwu', 'Kebontiwu', -7.3299000, 108.2274000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71622, 'Siluman', 'Siluman', 'Siluman', -7.3421000, 108.2365000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71623, 'Gunungmuncang', 'Gunungmuncang', 'Goenoengmoentjang,Gunungmuncang', -7.3510000, 108.2382000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71624, 'Rahayu Dua', 'Rahayu Dua', 'Rahayu Dua', -7.3722000, 108.2349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71625, 'Bantargedang', 'Bantargedang', 'Bantargedang', -7.3586000, 108.2497000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71626, 'Bojongbenteng', 'Bojongbenteng', 'Bodjongbenteng,Bojongbenteng', -7.1278000, 108.2102000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71627, 'Medangdatar', 'Medangdatar', 'Medangdatar', -7.1578000, 108.1254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71628, 'Tejakalapa', 'Tejakalapa', 'Tedjakalapa,Tejakalapa,Tejakelapa', -7.2324000, 108.1252000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71629, 'Sukasetia', 'Sukasetia', 'Sukasetia', -7.2481000, 108.1957000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71630, 'Nanggela', 'Nanggela', 'Nangela,Nanggela', -7.1327000, 108.1321000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71631, 'Ciseuti Girang', 'Ciseuti Girang', 'Ciseuti Girang', -7.1289000, 108.1703000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71632, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.1309000, 108.1785000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71633, 'Sukasenang', 'Sukasenang', 'Sukasenang', -7.1287000, 108.2273000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71634, 'Cimuncang', 'Cimuncang', 'Cimuncang,Tjimoentjang Dua', -7.1357000, 108.2359000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71635, 'Ciroke', 'Ciroke', 'Ciroke', -7.1413000, 108.2229000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71636, 'Panoongan', 'Panoongan', 'Panoongan', -7.1382000, 108.2054000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71637, 'Tanjunghurip', 'Tanjunghurip', 'Tanjunghurip', -7.1425000, 108.1637000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71638, 'Cijangkar', 'Cijangkar', 'Cijangkar', -7.1414000, 108.1425000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71639, 'Sindangtamu', 'Sindangtamu', 'Sindangtamu', -7.1429000, 108.1483000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71640, 'Rancakuya', 'Rancakuya', 'Rancakuya', -7.1448000, 108.1472000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71641, 'Sukapancar', 'Sukapancar', 'Soekapantjar,Sukapancar', -7.1420000, 108.1808000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71642, 'Banjarsari', 'Banjarsari', 'Bandjarsari,Banjarsari', -7.1508000, 108.1902000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71643, 'Cicalung', 'Cicalung', 'Cicalung', -7.1420000, 108.2005000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71644, 'Sukaraja', 'Sukaraja', 'Soekaradja Dua,Sukaraja', -7.1466000, 108.2140000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71645, 'Sukasari', 'Sukasari', 'Sukasari', -7.1481000, 108.2149000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71646, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum', -7.1529000, 108.2084000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71647, 'Cihanjuang', 'Cihanjuang', 'Cihanjuang', -7.1560000, 108.1897000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71648, 'Pakemitan', 'Pakemitan', 'Pakemitan,Pakemitan-kidoel', -7.1571000, 108.1494000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71649, 'Asem', 'Asem', 'Asem', -7.1567000, 108.1432000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71650, 'Kaum Kaler', 'Kaum Kaler', 'Kaum Kaler', -7.1590000, 108.1477000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71651, 'Kudang', 'Kudang', 'Kudang', -7.1641000, 108.1519000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71652, 'Cipanjang', 'Cipanjang', 'Cipanjang,Tjipandjang', -7.1599000, 108.1684000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71653, 'Sindangharja', 'Sindangharja', 'Sindangharja', -7.1611000, 108.1848000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71654, 'Babakan', 'Babakan', 'Babakan', -7.1617000, 108.2039000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71655, 'Sukamenak', 'Sukamenak', 'Soekamenak Satu,Sukamenak', -7.1692000, 108.1812000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71656, 'Sukasenang', 'Sukasenang', 'Sukasenang', -7.1700000, 108.1669000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71657, 'Gereba', 'Gereba', 'Gereba', -7.1716000, 108.1540000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71658, 'Anto', 'Anto', 'Anto', -7.1684000, 108.1309000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71659, 'Bugel', 'Bugel', 'Boegel,Bugel', -7.1840000, 108.1298000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71660, 'Ciomas', 'Ciomas', 'Ciomas,Tjiomas Dua', -7.1783000, 108.1691000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71661, 'Rajamandala', 'Rajamandala', 'Rajamandala', -7.1838000, 108.1818000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71662, 'Pasireurih', 'Pasireurih', 'Pasireurih', -7.1758000, 108.1982000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71663, 'Jamanis', 'Jamanis', 'Djamanis,Jamanis', -7.1894000, 108.1836000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71664, 'Nyalindung', 'Nyalindung', 'Njalindoeng Satu,Nyalindung', -7.1913000, 108.1762000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71665, 'Sangiangteras', 'Sangiangteras', 'Sangiangteras', -7.1861000, 108.1542000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71666, 'Timbulsari', 'Timbulsari', 'Timbulsari', -7.1925000, 108.1510000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71667, 'Condong', 'Condong', 'Condong,Tjondong Satu', -7.1981000, 108.1573000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71668, 'Singabarong', 'Singabarong', 'Singabarong', -7.1984000, 108.1785000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71669, 'Kampungdesa Pamokolan', 'Kampungdesa Pamokolan', 'Kampungdesa Pamokolan', -7.1971000, 108.2000000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71670, 'Padamulya', 'Padamulya', 'Padamulya', -7.2028000, 108.2022000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71671, 'Ciinjuk', 'Ciinjuk', 'Ciinjuk,Tjiindjoek', -7.2069000, 108.1868000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71672, 'Sukahening', 'Sukahening', 'Soekahening,Sukahening', -7.2057000, 108.1520000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71673, 'Cijoho', 'Cijoho', 'Cijoho', -7.2064000, 108.1312000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71674, 'Ciengang', 'Ciengang', 'Ciengang,Tjiengang', -7.2180000, 108.1327000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71675, 'Cihateup', 'Cihateup', 'Cihateup', -7.2139000, 108.1700000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71676, 'Sukaraja', 'Sukaraja', 'Sukaraja', -7.2116000, 108.1768000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71677, 'Pasirtamiang', 'Pasirtamiang', 'Pasirtamiang', -7.2114000, 108.2097000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71678, 'Dusun Tengah Cihaurbeuti', 'Dusun Tengah Cihaurbeuti', 'Dusun Tengah Cihaurbeuti', -7.2248000, 108.2027000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71679, 'Pasarlama', 'Pasarlama', 'Pasarlama', -7.2227000, 108.1898000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71680, 'Cikadu', 'Cikadu', 'Cikadu,Tjikadoe Dua', -7.2240000, 108.1738000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71681, 'Sukasenang', 'Sukasenang', 'Sukasenang', -7.2191000, 108.1565000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71682, 'Sukasetia', 'Sukasetia', 'Sukasetia', -7.2313000, 108.1308000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71683, 'Cigebay', 'Cigebay', 'Cigebay', -7.2275000, 108.1620000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71684, 'Sirnarasa', 'Sirnarasa', 'Sirnarasa', -7.2338000, 108.1632000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71685, 'Dawagung', 'Dawagung', 'Dawagoeng,Dawagung', -7.2345000, 108.1884000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71686, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.2416000, 108.2205000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71687, 'Nanggela', 'Nanggela', 'Nanggela', -7.2416000, 108.1963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71688, 'Jantake', 'Jantake', 'Djantaka,Jantake', -7.2475000, 108.1563000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71689, 'Sariwangi', 'Sariwangi', 'Sariwangi', -7.2459000, 108.1805000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71690, 'Sukadana', 'Sukadana', 'Soekadana,Sukadana', -7.0179000, 108.2228000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71691, 'Desa Sindanghurip', 'Desa Sindanghurip', 'Desa Sindanghurip', -7.0168000, 108.2420000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71692, 'Bangbayang', 'Bangbayang', 'Bangbajang,Bangbayang', -7.0393000, 108.2058000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71693, 'Buninegara', 'Buninegara', 'Boeninagara,Buninegara', -7.0382000, 108.2270000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71694, 'Desa Borogojol', 'Desa Borogojol', 'Brogodjol,Desa Borogojol', -7.0438000, 108.1819000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71695, 'Sindangbarang', 'Sindangbarang', 'Sindangbarang', -7.0791000, 108.2059000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71696, 'Nanggewer', 'Nanggewer', 'Nanggewer', -7.1016000, 108.1629000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71697, 'Pamekaran', 'Pamekaran', 'Pamekaran', -7.1087000, 108.2441000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71698, 'Puteran Kidul', 'Puteran Kidul', 'Puteran Kidul', -7.1189000, 108.1996000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71699, 'Pagerageung Tengah', 'Pagerageung Tengah', 'Pagerageung Tengah', -7.1103000, 108.1664000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71700, 'Citeureup', 'Citeureup', 'Citeureup', -7.1180000, 108.1493000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71701, 'Tagog', 'Tagog', 'Tagog', -7.1210000, 108.1397000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71702, 'Cimanglid', 'Cimanglid', 'Cimanglid', -7.1173000, 108.1831000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71703, 'Payungsari', 'Payungsari', 'Pajoengsari,Payungsari', -7.1207000, 108.2397000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71704, 'Kalapanunggal', 'Kalapanunggal', 'Kalapanunggal', -7.2146000, 107.0047000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71705, 'Cimalati', 'Cimalati', 'Cimalati,Tjimalati', -7.3932000, 107.2169000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71706, 'Simpang', 'Simpang', 'Simpang,Simpang Dua', -7.4188000, 107.1592000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71707, 'Puncak', 'Puncak', 'Puncak', -7.4487000, 107.1260000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71708, 'Cigarogol', 'Cigarogol', 'Cigarogol,Tjigarogol', -7.4752000, 107.2076000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71709, 'Bebedahan', 'Bebedahan', 'Bebedahan', -7.2586000, 107.1401000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71710, 'Tanggeung Kolot', 'Tanggeung Kolot', 'Tanggeung Kolot', -7.2758000, 107.1329000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71711, 'Cireundeu', 'Cireundeu', 'Cireundeu', -7.3234000, 107.1565000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71712, 'Gunungbatu', 'Gunungbatu', 'Goenoengbatoe,Gunungbatu', -7.2519000, 107.1640000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71713, 'Pamadangan', 'Pamadangan', 'Pamadangan,Tjipamadangan', -7.3335000, 107.1738000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71714, 'Panineungan', 'Panineungan', 'Panineungan', -7.2725000, 107.1956000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71715, 'Solokpandan', 'Solokpandan', 'Solokpandan', -7.3360000, 107.2015000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71716, 'Cibitung', 'Cibitung', 'Cibitung', -7.3492000, 107.2307000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71717, 'Warungsimpang', 'Warungsimpang', 'Waroengsimpang,Warungsimpang', -7.0131000, 107.1412000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71718, 'Kebonkaret', 'Kebonkaret', 'Kebonkaret', -7.0558000, 107.1591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71719, 'Kupel', 'Kupel', 'Kupel', -7.0760000, 107.1737000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71720, 'Walagar', 'Walagar', 'Walagar', -7.0743000, 107.1963000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71721, 'Citamiang', 'Citamiang', 'Citamiang', -7.0714000, 107.2036000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71722, 'Nagrog', 'Nagrog', 'Nagrog', -7.0347000, 107.2297000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71723, 'Karanganyar', 'Karanganyar', 'Karanganjar Dua,Karanganyar', -7.7926000, 108.3405000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71724, 'Sukamenak', 'Sukamenak', 'Sukamenak', -7.8097000, 108.3165000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71725, 'Cibongas', 'Cibongas', 'Cibongas,Tjibongas', -7.6593000, 108.2721000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71726, 'Bojongsari', 'Bojongsari', 'Bojongsari', -7.6798000, 108.2718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71727, 'Rancabungur', 'Rancabungur', 'Rancabungur', -7.7359000, 108.2792000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71728, 'Cibeureum', 'Cibeureum', 'Cibeureum', -7.6396800, 108.2937600, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71729, 'Cikawung', 'Cikawung', 'Cikawung', -7.6764000, 108.3110000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71730, 'Ciranca', 'Ciranca', 'Ciranca,Tjirantja', -7.6614000, 108.3254000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71731, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.6682000, 108.3375000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71732, 'Purwosari', 'Purwosari', 'Purwosari', -7.7339000, 108.3352000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71733, 'Cikiangir', 'Cikiangir', 'Cikiangir,Tjikiangir', -7.5056000, 108.2787000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71734, 'Cipicung', 'Cipicung', 'Cipicung,Tjipitjoeng Satu', -7.5050000, 108.3008000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71735, 'Kawitan', 'Kawitan', 'Kawitan', -7.5107000, 108.2701000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71736, 'Cikiray', 'Cikiray', 'Cikiray', -7.5231000, 108.3246000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71737, 'Cigangsa', 'Cigangsa', 'Cigangsa,Tjigangsa', -7.5237000, 108.3633000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71738, 'Cilegi', 'Cilegi', 'Cilegi,Tjilegi', -7.5284000, 108.2718000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71739, 'Jayasari', 'Jayasari', 'Jayasari', -7.5380000, 108.3488000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71740, 'Ciganaria', 'Ciganaria', 'Ciganaria', -7.5605000, 108.2573000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71741, 'Sinagar', 'Sinagar', 'Sinagar', -7.5774000, 108.3241000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71742, 'Cayur', 'Cayur', 'Cayur,Tjajoer Satu', -7.5875000, 108.2810000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71743, 'Pegadungan', 'Pegadungan', 'Pegadungan', -7.5933000, 108.3714000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71744, 'Pakemitan Dua', 'Pakemitan Dua', 'Pakemitan Dua', -7.6221000, 108.2564000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71745, 'Sempur', 'Sempur', 'Sempoer,Sempur', -7.6214000, 108.3386000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71746, 'Jatiwangi', 'Jatiwangi', 'Jatiwangi', -7.3785000, 108.2580000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71747, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.3779000, 108.2880000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71748, 'Darmasari', 'Darmasari', 'Darmasari', -7.3808000, 108.3541000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71749, 'Jamupu', 'Jamupu', 'Jamupu', -7.4931000, 108.2525000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71750, 'Cilangkap', 'Cilangkap', 'Cilangkap', -7.4523000, 108.2560000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71751, 'Rahayu', 'Rahayu', 'Rahayu', -7.3896000, 108.3570000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71752, 'Cihurip Satu', 'Cihurip Satu', 'Cihurip Satu', -7.3986000, 108.3328000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71753, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.3911000, 108.3238000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71754, 'Bojongsari', 'Bojongsari', 'Bojongsari', -7.3914000, 108.3095000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71755, 'Lengkong', 'Lengkong', 'Lengkong', -7.3953000, 108.2883000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71756, 'Bandung', 'Bandung', 'Bandoeng,Bandung', -7.3993000, 108.2607000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71757, 'Dusundesa', 'Dusundesa', 'Dusundesa', -7.4051000, 108.2846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71758, 'Ciriri', 'Ciriri', 'Ciriri,Tjiriri', -7.4087000, 108.3595000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71759, 'Panuusan', 'Panuusan', 'Panoeoesan,Panuusan', -7.4094000, 108.3124000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71760, 'Cinunjang', 'Cinunjang', 'Cinunjang,Tjinoendjang', -7.4204000, 108.2835000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71761, 'Mekarjaya', 'Mekarjaya', 'Mekarjaya', -7.4237000, 108.3434000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71762, 'Poponcol', 'Poponcol', 'Poponcol', -7.4271000, 108.2970000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71763, 'Cidamar', 'Cidamar', 'Cidamar', -7.4390000, 108.3009000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71764, 'Pasirmukti', 'Pasirmukti', 'Pasirmukti', -7.4405000, 108.3423000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71765, 'Sindangsetra', 'Sindangsetra', 'Sindangsetra', -7.4579000, 108.3525000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71766, 'Jayawangi', 'Jayawangi', 'Jayawangi', -7.4592000, 108.2735000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71767, 'Desa Darmacaang', 'Desa Darmacaang', 'Desa Darmacaang', -7.2746000, 108.2725000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71768, 'Cirahab', 'Cirahab', 'Cirahab', -7.2714000, 108.3071000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71769, 'Desa Gunungsari', 'Desa Gunungsari', 'Desa Gunungsari', -7.2556000, 108.3109000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71770, 'Cukanguncal', 'Cukanguncal', 'Cukanguncal,Tjoekangoentjal', -7.2560000, 108.3155000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71771, 'Warungjarak', 'Warungjarak', 'Waroengdjarak,Warungjarak', -7.2627100, 108.3738100, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71772, 'Rimpakgede', 'Rimpakgede', 'Rimpakgede', -7.2763000, 108.3561000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71773, 'Desa Saguling', 'Desa Saguling', 'Desa Saguling,Sagoeling', -7.2977000, 108.3555000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71774, 'Desa Werasari', 'Desa Werasari', 'Desa Werasari', -7.2799000, 108.3165000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71775, 'Desa Mangkubumi', 'Desa Mangkubumi', 'Desa Mangkubumi', -7.2819000, 108.3082000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71776, 'Desa Nasol', 'Desa Nasol', 'Desa Nasol', -7.2815000, 108.2903000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71777, 'Walahir', 'Walahir', 'Walahir', -7.2797000, 108.2553000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71778, 'Desa Margaluyu', 'Desa Margaluyu', 'Desa Margaluyu', -7.3080000, 108.2558000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71779, 'Cimamut', 'Cimamut', 'Cimamut', -7.3116000, 108.2568000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71780, 'Gunungpeundeuy', 'Gunungpeundeuy', 'Gunungpeundeuy', -7.3231000, 108.2514000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71781, 'Pasar Sabtu', 'Pasar Sabtu', 'Pasar Sabtu', -7.3102000, 108.2667000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71782, 'Pasirjaya', 'Pasirjaya', 'Pasirjaya', -7.3251000, 108.2681000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71783, 'Cibodas', 'Cibodas', 'Cibodas', -7.3027000, 108.2770000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71784, 'Colendra', 'Colendra', 'Colendra', -7.3051000, 108.2941000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71785, 'Desa Cimari', 'Desa Cimari', 'Cimari,Desa Cimari,Tjimari', -7.3121000, 108.2880000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71786, 'Cisadap', 'Cisadap', 'Cisadap,Tjisadap', -7.3102000, 108.3066000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71787, 'Warung Kulon', 'Warung Kulon', 'Warung Kulon', -7.3162000, 108.2998000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71788, 'Warung Wetan', 'Warung Wetan', 'Warung Wetan', -7.3174000, 108.3070000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71789, 'Desa Sukajadi', 'Desa Sukajadi', 'Desa Sukajadi', -7.3092000, 108.3294000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71790, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum Satu', -7.3226000, 108.3268000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71791, 'Kreteg', 'Kreteg', 'Kreteg', -7.3103000, 108.3350000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71792, 'Mekarsari', 'Mekarsari', 'Mekarsari', -7.3042000, 108.3456000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71793, 'Karangsari', 'Karangsari', 'Karangsari', -7.3224000, 108.3466000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71794, 'Desa Baregbeg', 'Desa Baregbeg', 'Desa Baregbeg', -7.3039000, 108.3601000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71795, 'Desa Sukamaju', 'Desa Sukamaju', 'Desa Sukamaju', -7.3086000, 108.3720000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71796, 'Desa Kertasari', 'Desa Kertasari', 'Desa Kertasari', -7.3268000, 108.3690000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71797, 'Desa Cigembor', 'Desa Cigembor', 'Desa Cigembor,Tjigembor', -7.3409000, 108.3688000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71798, 'Cibitung', 'Cibitung', 'Cibitung', -7.3335000, 108.3629000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71799, 'Desa Benteng', 'Desa Benteng', 'Desa Benteng', -7.3404000, 108.3488000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71800, 'Ciherang', 'Ciherang', 'Ciherang', -7.3365000, 108.3379000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71801, 'Bunirasa', 'Bunirasa', 'Boenirasa Dua,Bunirasa', -7.3343000, 108.3279000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71802, 'Linggamanik', 'Linggamanik', 'Linggamanik', -7.3274000, 108.3161000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71803, 'Tangsi', 'Tangsi', 'Tangsi', -7.3480000, 108.3078000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71804, 'Desa Gegempalan', 'Desa Gegempalan', 'Desa Gegempalan', -7.3269000, 108.2906000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71805, 'Gerempay', 'Gerempay', 'Gerempay', -7.3379000, 108.2882000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71806, 'Kertasari', 'Kertasari', 'Kertasari', -7.3461000, 108.2814000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71807, 'Lemburwarung', 'Lemburwarung', 'Lemburwarung', -7.3351000, 108.2627000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71808, 'Condong', 'Condong', 'Condong', -7.3447000, 108.2591000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71809, 'Kadupandak', 'Kadupandak', 'Kadoepandak,Kadupandak', -7.3717000, 108.2525000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71810, 'Gunajaya', 'Gunajaya', 'Gunajaya', -7.3720000, 108.2765000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71811, 'Kotabaru', 'Kotabaru', 'Kotabaru', -7.3546000, 108.2604000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71812, 'Cibangun Tengah', 'Cibangun Tengah', 'Cibangun Tengah', -7.3595000, 108.2656000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71813, 'Walagar', 'Walagar', 'Walagar', -7.3528000, 108.2886000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71814, 'Cimuncang', 'Cimuncang', 'Cimuncang,Tjimoentjang', -7.3602000, 108.2964000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71815, 'Cisitu Kaler', 'Cisitu Kaler', 'Cisitu Kaler', -7.3623000, 108.3064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71816, 'Nempel', 'Nempel', 'Nempel', -7.3635000, 108.3156000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71817, 'Desa Cilangkap', 'Desa Cilangkap', 'Desa Cilangkap,Tjilangkap Satu', -7.3616000, 108.3345000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71818, 'Pasirbatang', 'Pasirbatang', 'Pasirbatang', -7.3631000, 108.3580000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71819, 'Taringgul', 'Taringgul', 'Taringgul', -7.1505000, 108.2528000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71820, 'Mandala', 'Mandala', 'Mandala,Mandala Dua', -7.1459000, 108.2661000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71821, 'Pabuaran', 'Pabuaran', 'Pabuaran', -7.1336000, 108.2715000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71822, 'Karoya', 'Karoya', 'Karoya', -7.1499000, 108.3043000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71823, 'Bungursari', 'Bungursari', 'Bungursari', -7.1548000, 108.3292000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71824, 'Singgugu', 'Singgugu', 'Singgugu,Singoegoe', -7.1398000, 108.3549000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71825, 'Citeureup', 'Citeureup', 'Citeureup,Tjiteureup Satu', -7.1581000, 108.3527000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71826, 'Kawalimukti', 'Kawalimukti', 'Kawalimukti', -7.1823000, 108.3654000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71827, 'Kiaralawang', 'Kiaralawang', 'Kiaralawang', -7.1952000, 108.3745000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71828, 'Winduraja', 'Winduraja', 'Windoeradja,Winduraja', -7.1773000, 108.3638000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71829, 'Cilongo', 'Cilongo', 'Babakan Tjilongok,Cilongo', -7.1846000, 108.3527000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71830, 'Desa Wetan Ciakar', 'Desa Wetan Ciakar', 'Desa Wetan Ciakar', -7.1944000, 108.3552000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71831, 'Kertanagara', 'Kertanagara', 'Kertanagara', -7.1880000, 108.3457000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71832, 'Cikoneng', 'Cikoneng', 'Cikoneng,Tjikoneng', -7.1763000, 108.3429000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71833, 'Tanjungjaya', 'Tanjungjaya', 'Tanjungjaya', -7.1689000, 108.3494000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71834, 'Babantar', 'Babantar', 'Babantar', -7.1639000, 108.3395000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71835, 'Kertaharja', 'Kertaharja', 'Kertaharja', -7.1814000, 108.3242000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71836, 'Sukaraharja', 'Sukaraharja', 'Sukaraharja', -7.1680000, 108.3267000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71837, 'Lumbung Kidul', 'Lumbung Kidul', 'Lumbung Kidul', -7.1619000, 108.3285000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71838, 'Rawa Satu', 'Rawa Satu', 'Rawa Satu', -7.1581000, 108.3171000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71839, 'Sukamukti', 'Sukamukti', 'Sukamukti', -7.2348000, 108.3280000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71840, 'Bangbayang Kaler', 'Bangbayang Kaler', 'Bangbayang Kaler', -7.2096000, 108.3383000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71841, 'Kampungdesa', 'Kampungdesa', 'Kampungdesa', -7.2063000, 108.3498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71842, 'Cieurih Satu', 'Cieurih Satu', 'Cieurih Satu,Tjieurih Satu', -7.2148000, 108.3551000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71843, 'Urug Hilir', 'Urug Hilir', 'Urug Hilir', -7.2363000, 108.3639000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71844, 'Gareba', 'Gareba', 'Gareba,Gereba Dua', -7.2013000, 108.3692000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71845, 'Cimanggu Hilir', 'Cimanggu Hilir', 'Cimanggu Hilir,Tjimanggoe-hilir', -7.0039000, 108.2594000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71846, 'Margamukti', 'Margamukti', 'Margamukti', -7.0092000, 108.2846000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71847, 'Cikeusal', 'Cikeusal', 'Cikeusal,Tjikeusal', -7.0137000, 108.3076000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71848, 'Sidaraja', 'Sidaraja', 'Sedaradja,Sidaraja', -7.0282000, 108.3058000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71849, 'Sarimukti', 'Sarimukti', 'Sarimukti', -7.0315000, 108.3130000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71850, 'Ciranca Satu', 'Ciranca Satu', 'Ciranca Satu,Tjirantja', -7.0332900, 108.2829300, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71851, 'Lebakwangi', 'Lebakwangi', 'Lebakwangi', -7.0318000, 108.2686000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71852, 'Malausma Kidul', 'Malausma Kidul', 'Malausma Kidul', -7.0440000, 108.2513000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71853, 'Cilimus', 'Cilimus', 'Cilimus,Tjilimoes Dua', -7.0460000, 108.2594000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71854, 'Jaga', 'Jaga', 'Djaga,Jaga', -7.0451000, 108.2690000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71855, 'Cidulang', 'Cidulang', 'Cidulang,Tjidoelang', -7.0114000, 108.3715000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71856, 'Kasturi', 'Kasturi', 'Kastoeri,Kasturi', -7.0128000, 108.3572000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71857, 'Jagasari', 'Jagasari', 'Jagasari', -7.0065000, 108.3676000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71858, 'Bagjasari', 'Bagjasari', 'Bagjasari,Bandjaransari', -7.0043000, 108.3581000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71859, 'Cintasari', 'Cintasari', 'Cintasari', -7.0049000, 108.3464000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71860, 'Sindang', 'Sindang', 'Sindang', -7.0047000, 108.3350000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71861, 'Cidadap', 'Cidadap', 'Cidadap,Tjidadap', -7.0298000, 108.3156000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71862, 'Rawa', 'Rawa', 'Rawa', -7.0276000, 108.3352000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71863, 'Cikondang', 'Cikondang', 'Cikondang,Tjikondang', -7.0429000, 108.3693000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71864, 'Cingambul', 'Cingambul', 'Cingambul,Tjigamboel', -7.0449000, 108.3532000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71865, 'Mulyasari', 'Mulyasari', 'Mulyasari', -7.0394000, 108.3542000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71866, 'Cimanggu Girang', 'Cimanggu Girang', 'Cimanggu Girang', -7.0450000, 108.3465000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71867, 'Wangkelang', 'Wangkelang', 'Wangkelang,Wangklang', -7.0466000, 108.3389000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71868, 'Nagarakembang', 'Nagarakembang', 'Nagarakembang,Negarakembang', -7.0397000, 108.3342000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71869, 'Sadapaingan', 'Sadapaingan', 'Sadapaingan', -7.0590000, 108.3638000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71870, 'Cinyasag', 'Cinyasag', 'Cinyasag,Tjinjasak', -7.0912000, 108.3732000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71871, 'Legok Satu', 'Legok Satu', 'Legok Satu', -7.1102000, 108.3600000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71872, 'Jugantang', 'Jugantang', 'Jugantang,Tjoegantang', -7.1004000, 108.3301000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71873, 'Pajagan', 'Pajagan', 'Padjagan,Pajagan', -7.0923000, 108.3445000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71874, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.0937000, 108.3207000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71875, 'Karangsari', 'Karangsari', 'Karangsari', -7.0885000, 108.2951000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71876, 'Sukamantri Satu', 'Sukamantri Satu', 'Soekamantri,Sukamantri Satu', -7.0877000, 108.2815000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71877, 'Hujungtiwu', 'Hujungtiwu', 'Hujungtiwu,Oedjoengtiwoe', -7.0956000, 108.2742000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71878, 'Jongorsari', 'Jongorsari', 'Jongorsari', -7.1008000, 108.2796000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71879, 'Babakan', 'Babakan', 'Babakan', -7.7713000, 108.4608000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71880, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.8108000, 108.4396000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71881, 'Citotok', 'Citotok', 'Citotok', -7.8149000, 108.4024000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71882, 'Bulakgebang', 'Bulakgebang', 'Bulakgebang', -7.7431000, 108.4064000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71883, 'Cigugur', 'Cigugur', 'Cigugur', -7.6347000, 108.4203000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71884, 'Cicurug', 'Cicurug', 'Cicurug,Tjitjoeroeg', -7.6603000, 108.4191000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71885, 'Cibiru', 'Cibiru', 'Cibiru,Tjibiroe', -7.6431000, 108.4345000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71886, 'Tenjolaya', 'Tenjolaya', 'Tendjolaja,Tenjolaya', -7.7158000, 108.4467000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71887, 'Parakan', 'Parakan', 'Parakan', -7.6542000, 108.4724000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71888, 'Binangun', 'Binangun', 'Binangun', -7.7191000, 108.4747000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71889, 'Mandala', 'Mandala', 'Mandala', -7.7402000, 108.4732000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71890, 'Balengbeng', 'Balengbeng', 'Balengbeng', -7.7087000, 108.4892000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71891, 'Limusnunggal', 'Limusnunggal', 'Limusnunggal', -7.5039000, 108.4022000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71892, 'Lembursawah', 'Lembursawah', 'Lembursawah', -7.5061000, 108.3772000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71893, 'Girikarya', 'Girikarya', 'Girikarya', -7.5315000, 108.3847000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71894, 'Bangunsari', 'Bangunsari', 'Bangunsari', -7.5314000, 108.4498000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71895, 'Cintajaya', 'Cintajaya', 'Cintajaya', -7.5318000, 108.4422000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71896, 'Cisagu', 'Cisagu', 'Cisagu', -7.5850000, 108.4734000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71897, 'Ciguha', 'Ciguha', 'Ciguha,Tjigoeha', -7.6003000, 108.4134000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71898, 'Cinangsih Satu', 'Cinangsih Satu', 'Cinangsih Satu,Tjinangsi Satu', -7.3800000, 108.3869000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71899, 'Raksabaya', 'Raksabaya', 'Raksabaya,Raksaboja', -7.3802000, 108.4560000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71900, 'Bojong', 'Bojong', 'Bojong', -7.3858000, 108.4941000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71901, 'Cilangkap', 'Cilangkap', 'Cilangkap,Tjilangkap', -7.4041000, 108.4981000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71902, 'Kalangsari', 'Kalangsari', 'Kalangsari', -7.4933000, 108.4241000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71903, 'Karangsirna', 'Karangsirna', 'Karangsirna', -7.4216000, 108.3799000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71904, 'Sindangrasa', 'Sindangrasa', 'Sindangrasa', -7.3933000, 108.3780000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71905, 'Sukadana', 'Sukadana', 'Sukadana', -7.3906000, 108.4045000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71906, 'Gandapura', 'Gandapura', 'Gandapura', -7.3922000, 108.4220000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71907, 'Bojongmalang', 'Bojongmalang', 'Bojongmalang', -7.3984000, 108.4630000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71908, 'Bunirasa', 'Bunirasa', 'Bunirasa', -7.4109000, 108.4482000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71909, 'Ciwarulang', 'Ciwarulang', 'Ciwarulang', -7.4120000, 108.3918000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71910, 'Karangpete', 'Karangpete', 'Karangpete,Karangpeuteuj', -7.4287000, 108.3966000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71911, 'Sukajaya', 'Sukajaya', 'Sukajaya', -7.4521000, 108.4125000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71912, 'Walahir', 'Walahir', 'Walahir', -7.4472000, 108.4400000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71913, 'Cimarga', 'Cimarga', 'Cimarga', -7.4498000, 108.4652000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71914, 'Malabar', 'Malabar', 'Malabar', -7.4868000, 108.4676000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71915, 'Bantarsari', 'Bantarsari', 'Bantarsari', -7.2798000, 108.4978000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71916, 'Tenjolaya', 'Tenjolaya', 'Tendjolaja,Tenjolaya', -7.3235000, 108.4921000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71917, 'Dusun Desa Handapherang', 'Dusun Desa Handapherang', 'Dusun Desa Handapherang,Dusundesa', -7.3429000, 108.3796000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71918, 'Utama Wetan', 'Utama Wetan', 'Utama Wetan', -7.3216000, 108.3821000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71919, 'Dusun Desa Sukadana', 'Dusun Desa Sukadana', 'Dusun Desa Sukadana,Dusundesa', -7.2617000, 108.4322000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71920, 'Sukadana', 'Sukadana', 'Sukadana', -7.2655000, 108.4403000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71921, 'Karangampel Kaler', 'Karangampel Kaler', 'Kaler,Karangampel Kaler', -7.2770000, 108.4072000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71922, 'Dusun Desa Bunter', 'Dusun Desa Bunter', 'Dusun Desa Bunter,Dusundesa', -7.2901000, 108.4664000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71923, 'Lawong', 'Lawong', 'Lawong', -7.2951000, 108.3877000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71924, 'Cigaleuh Kulon', 'Cigaleuh Kulon', 'Cigaleuh Kulon', -7.3031300, 108.4352200, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71925, 'Cibeulah', 'Cibeulah', 'Cibeulah,Tjibeulah', -7.3193000, 108.4672000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71926, 'Pende', 'Pende', 'Pende,Peundeuj', -7.3301000, 108.4014000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71927, 'Kepel', 'Kepel', 'Kepel', -7.3378000, 108.4863000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71928, 'Cijeungjing Kaler', 'Cijeungjing Kaler', 'Cijeungjing Kaler', -7.3352000, 108.4184000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71929, 'Dewasari', 'Dewasari', 'Dewasari', -7.3337000, 108.3860000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71930, 'Ciharalang', 'Ciharalang', 'Ciharalang,Tjiharalang Satu', -7.3503000, 108.4113000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71931, 'Cibeta', 'Cibeta', 'Cibeta', -7.3502000, 108.4732000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71932, 'Ancol', 'Ancol', 'Ancol,Antjol', -7.3651000, 108.3871000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71933, 'Pasirnangka', 'Pasirnangka', 'Pasirnangka', -7.3654000, 108.4373000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71934, 'Sindangpanji', 'Sindangpanji', 'Sindangpandji,Sindangpanji', -7.0208000, 108.3807000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71935, 'Sakerta Barat', 'Sakerta Barat', 'Sakerta Barat', -7.0342000, 108.4055000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71936, 'Paninggaran', 'Paninggaran', 'Paninggaran', -7.0210000, 108.4024000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71937, 'Cipasung', 'Cipasung', 'Cipasung,Tjipasoeng Satu', -7.0164000, 108.3947000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71938, 'Kawahmanuk', 'Kawahmanuk', 'Kawahmanoek,Kawahmanuk', -7.0122000, 108.3928000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71939, 'Cikupa', 'Cikupa', 'Cikupa,Tjikoepa Satu', -7.0067000, 108.3975000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71940, 'Parung', 'Parung', 'Paroeng,Parung', -7.0045000, 108.3984000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71941, 'Jagara', 'Jagara', 'Djagara,Jagara', -7.0092000, 108.4173000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71942, 'Sakerta Timur', 'Sakerta Timur', 'Sakerta Timur', -7.0366000, 108.4159000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71943, 'Cibengang', 'Cibengang', 'Cibengang,Tjibengang', -7.0388000, 108.3942000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71944, 'Cisoka', 'Cisoka', 'Cisoka,Tjisoka Satu', -7.0393000, 108.3768000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71945, 'Cigeur', 'Cigeur', 'Cageur,Cigeur,Tjageur', -7.0559000, 108.3992000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71946, 'Wedangtemu', 'Wedangtemu', 'Wedangtemoe,Wedangtemu', -7.0708000, 108.3939000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71947, 'Bojongsari', 'Bojongsari', 'Bojongsari', -7.0696000, 108.3845000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71948, 'Tundagan', 'Tundagan', 'Toendagan,Tundagan', -7.0649000, 108.4335000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71949, 'Cikondang', 'Cikondang', 'Cikondang', -7.0662000, 108.4546000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71950, 'Pasiragung', 'Pasiragung', 'Pasiragung', -7.0637000, 108.4705000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71951, 'Citapen', 'Citapen', 'Citapen,Tjitapen', -7.0657000, 108.4756000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71952, 'Pakapasan Ilir', 'Pakapasan Ilir', 'Pakapasan Ilir,Pakapasan-hilir', -7.0610000, 108.4750000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71953, 'Cijemit', 'Cijemit', 'Cijemit,Tjidjemit', -7.0490000, 108.4984000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71954, 'Pakapasan Girang', 'Pakapasan Girang', 'Pakapasan Girang', -7.0465000, 108.4636000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71955, 'Margabakti', 'Margabakti', 'Margabakti', -7.0427000, 108.4457000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71956, 'Hantara', 'Hantara', 'Hantara', -7.0579000, 108.4553000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71957, 'Rambatan', 'Rambatan', 'Rambatan', -7.0305000, 108.4875000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71958, 'Munggang', 'Munggang', 'Moenggang,Munggang', -7.0231000, 108.4789000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71959, 'Mungkaldatar', 'Mungkaldatar', 'Moengkaldatar,Mungkaldatar', -7.0204000, 108.4876000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71960, 'Nangka', 'Nangka', 'Nangka', -7.0069000, 108.4708000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71961, 'Sindangjawa', 'Sindangjawa', 'Sindangdjawa,Sindangjawa', -7.0301000, 108.4535000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71962, 'Kertayuga', 'Kertayuga', 'Katajoega,Kertayuga', -7.0299000, 108.4376000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71963, 'Kaliwon Kertawirama', 'Kaliwon Kertawirama', 'Kaliwon Kertawirama', -7.0112000, 108.4272000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71964, 'Nusaherang', 'Nusaherang', 'Noesaherang,Nusaherang', -7.0094000, 108.4445000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71965, 'Windusari', 'Windusari', 'Windoesari,Windusari', -7.0195000, 108.4456000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71966, 'Ciketak', 'Ciketak', 'Ciketak,Tjiketak', -7.0105000, 108.4588000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71967, 'Babatan', 'Babatan', 'Babatan,Pabatan-lor', -7.0016000, 108.4546000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71968, 'Cimenga', 'Cimenga', 'Cimenga,Tjimenga', -7.0844000, 108.4024000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71969, 'Sagalaherang', 'Sagalaherang', 'Sagalaherang,Segalaherang', -7.1202000, 108.3942000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71970, 'Jagabaya Dua', 'Jagabaya Dua', 'Jagabaya Dua', -7.1053000, 108.3946000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71971, 'Ciberung', 'Ciberung', 'Ciberung,Tjiberoeng', -7.1209000, 108.4830000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71972, 'Selajambe Satu', 'Selajambe Satu', 'Selajambe Satu', -7.1185000, 108.4608000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71973, 'Cilimus', 'Cilimus', 'Cilimus,Tjilimoes Dua', -7.1096000, 108.4660000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71974, 'Tegalgede', 'Tegalgede', 'Tegalgede', -7.1075000, 108.4796000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71975, 'Bojong', 'Bojong', 'Bodjong Satu,Bojong', -7.1164000, 108.4367000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71976, 'Babakan', 'Babakan', 'Babakan', -7.0915000, 108.4328000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71977, 'Tlogo', 'Tlogo', 'Tlogo', -6.5094000, 111.0227000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71978, 'Krajan Bakalan', 'Krajan Bakalan', 'Krajan Bakalan', -6.5050000, 111.0425000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71979, 'Gondosari', 'Gondosari', 'Gondosari', -6.5244000, 111.0209000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71980, 'Winong', 'Winong', 'Winong', -6.5202000, 111.0367000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71981, 'Pecinan', 'Pecinan', 'Pecinan', -6.5316000, 111.0550000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71982, 'Pule', 'Pule', 'Pule', -6.5336000, 111.0252000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71983, 'Bangkol', 'Bangkol', 'Bangkol', -6.5336000, 111.0075000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71984, 'Baleber', 'Baleber', 'Baleber', -6.5415000, 111.0064000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71985, 'Tayu Kulon', 'Tayu Kulon', 'Tayu Kulon', -6.5351700, 111.0425400, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71986, 'Gawanan', 'Gawanan', 'Gawanan', -6.5341000, 111.0485000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71987, 'Belah Lor', 'Belah Lor', 'Belah Lor', -6.5371000, 111.0538300, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71988, 'Krajan Keboromo', 'Krajan Keboromo', 'Krajan Keboromo', -6.5440000, 111.0515000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71989, 'Rowo', 'Rowo', 'Rowo', -6.5488000, 111.0396000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71990, 'Kedungbang', 'Kedungbang', 'Kedungbang', -6.5428000, 111.0202000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71991, 'Golong', 'Golong', 'Golong', -6.5567000, 111.0159000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71992, 'Ketapang', 'Ketapang', 'Ketapang', -6.5589000, 111.0379000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71993, 'Tunggulsari', 'Tunggulsari', 'Tunggulsari', -6.5541000, 111.0594000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71994, 'Jepat Kidul', 'Jepat Kidul', 'Jepat Kidul', -6.5574000, 111.0519000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71995, 'Ngetuk', 'Ngetuk', 'Ngetuk', -6.5664000, 111.0147000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71996, 'Drajak', 'Drajak', 'Drajak', -6.5701900, 111.0325400, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71997, 'Krajan Kedungsari', 'Krajan Kedungsari', 'Krajan Kedungsari', -6.5733700, 111.0399500, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71998, 'Tanggung', 'Tanggung', 'Tanggung', -6.5671000, 111.0407000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(71999, 'Belahan', 'Belahan', 'Belahan', -6.5716000, 111.0602000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72000, 'Semerak', 'Semerak', 'Semerak', -6.5800000, 111.0559000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72001, 'Bancaran', 'Bancaran', 'Bancaran', -6.5793000, 111.0431000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72002, 'Krajan Gajihan', 'Krajan Gajihan', 'Krajan Gajihan', -6.5802000, 111.0018000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72003, 'Tunjungrejo', 'Tunjungrejo', 'Tunjungrejo', -6.5963900, 111.0661200, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72004, 'Krajan Waturoyo', 'Krajan Waturoyo', 'Krajan Waturoyo', -6.5951000, 111.0566000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72005, 'Mrican', 'Mrican', 'Mrican', -6.5936000, 111.0413000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72006, 'Pesagen', 'Pesagen', 'Pesagen', -6.6027000, 111.0133000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72007, 'Kajen', 'Kajen', 'Kajen', -6.6067000, 111.0594000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72008, 'Cibolek Kidul', 'Cibolek Kidul', 'Cibolek Kidul', -6.6009900, 111.0658100, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72009, 'Bulumanis Lor', 'Bulumanis Lor', 'Bulumanis Lor', -6.6083000, 111.0666000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72010, 'Sekarjalak', 'Sekarjalak', 'Sekarjalak', -6.6132000, 111.0654000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72011, 'Babatan', 'Babatan', 'Babatan', -6.6110000, 111.0542000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72012, 'Sumber', 'Sumber', 'Sumber', -6.6131000, 111.0325000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72013, 'Tegalarum', 'Tegalarum', 'Tegalarum', -6.6103000, 111.0110000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72014, 'Pangkalan', 'Pangkalan', 'Pangkalan', -6.6183000, 111.0783000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72015, 'Sidomukti', 'Sidomukti', 'Sidomukti', -6.6247000, 111.0526000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72016, 'Panglanjan', 'Panglanjan', 'Pangladjan,Panglanjan', -7.6405000, 108.5124000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72017, 'Karangwangkal', 'Karangwangkal', 'Karangwangkal,Karangwangkal Tiga', -7.6448000, 108.6065000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72018, 'Pajaten', 'Pajaten', 'Pajaten', -7.6549000, 108.6106000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72019, 'Sukasari', 'Sukasari', 'Sukasari', -7.6579000, 108.5525000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72020, 'Ciawi', 'Ciawi', 'Ciawi,Tjiawi', -7.6547000, 108.5043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72021, 'Desa Cikambulan', 'Desa Cikambulan', 'Desa Cikambulan', -7.6737000, 108.6136000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72022, 'Cipari', 'Cipari', 'Cipari,Tjipari', -7.6746000, 108.5776000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72023, 'Girijaya', 'Girijaya', 'Girijaya', -7.6862000, 108.5352000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72024, 'Karangjaladri', 'Karangjaladri', 'Karangjaladri', -7.7041000, 108.5027000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72025, 'Sukadana', 'Sukadana', 'Sukadana', -7.5021000, 108.5579000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72026, 'Sumanding', 'Sumanding', 'Sumanding', -7.5132000, 108.6198000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72027, 'Cikuya', 'Cikuya', 'Cikuya,Tjikoeja Satu', -7.5108000, 108.5861000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72028, 'Banjaranyar', 'Banjaranyar', 'Banjaranyar', -7.5106000, 108.5487000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72029, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.5574700, 108.5341400, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72030, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.5571000, 108.5715000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72031, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.5778700, 108.6035200, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72032, 'Karangbungur', 'Karangbungur', 'Karangboengoer,Karangbungur', -7.5902000, 108.5095000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72033, 'Cilisung', 'Cilisung', 'Cilisung,Tjilisoeng', -7.4165000, 108.5124000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72034, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.4342000, 108.5177000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72035, 'Neglasari', 'Neglasari', 'Neglasari', -7.4436000, 108.5207000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72036, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.4937000, 108.5165000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72037, 'Sukarame', 'Sukarame', 'Sukarame', -7.3779000, 108.5375000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72038, 'Cikabuyutan Barat', 'Cikabuyutan Barat', 'Cikabuyutan Barat,Tjikaboejoetan', -7.3785000, 108.5422000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72039, 'Hegarsari', 'Hegarsari', 'Hegarsari', -7.3859000, 108.5394000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72040, 'Sambungjaya', 'Sambungjaya', 'Sambungjaya', -7.4622000, 108.5366000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72041, 'Karangsari', 'Karangsari', 'Karangsari', -7.4381000, 108.5552000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72042, 'Kertahayu', 'Kertahayu', 'Kertahayu', -7.4594000, 108.5584000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72043, 'Cimanggu', 'Cimanggu', 'Cimanggu', -7.4160000, 108.5676000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72044, 'Bobojong', 'Bobojong', 'Bobojong', -7.4072000, 108.5861000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72045, 'Neglasari', 'Neglasari', 'Neglasari', -7.4434000, 108.5845000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72046, 'Rancabungur', 'Rancabungur', 'Rancabungur', -7.4849000, 108.5920000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72047, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.4671000, 108.6015000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72048, 'Sidaharja', 'Sidaharja', 'Sidaharja', -7.4474000, 108.5984000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72049, 'Cijurey', 'Cijurey', 'Cijurey', -7.3940000, 108.6048000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72050, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.4843000, 108.6031000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72051, 'Neglasari', 'Neglasari', 'Neglasari', -7.4900000, 108.6108000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72052, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.4778000, 108.6147000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72053, 'Tugusari', 'Tugusari', 'Tugusari', -7.4636000, 108.6112000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72054, 'Sukaratu', 'Sukaratu', 'Sukaratu', -7.4219000, 108.6100000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72055, 'Sukamukti', 'Sukamukti', 'Sukamukti', -7.4090000, 108.6147000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72056, 'Langkaplancar', 'Langkaplancar', 'Langkaplancar,Langkoplantjar', -7.3777000, 108.6141000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72057, 'Cibadak', 'Cibadak', 'Cibadak,Tjibadak', -7.4904000, 108.6204000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72058, 'Warungbuah', 'Warungbuah', 'Waroengboeah,Warungbuah', -7.3858000, 108.5044000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72059, 'Bungasrejo', 'Bungasrejo', 'Bungasrejo', -6.7432000, 111.1231000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72060, 'Batur Kidul', 'Batur Kidul', 'Batur Kidul', -6.7571000, 111.1360000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72061, 'Genetan', 'Genetan', 'Genetan', -6.7541000, 111.1585000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72062, 'Pagak Kulon', 'Pagak Kulon', 'Pagak Kulon', -6.7582000, 111.2152000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72063, 'Plalangan', 'Plalangan', 'Plalangan', -6.7550000, 111.2264000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72064, 'Kalimati', 'Kalimati', 'Kalimati', -6.7588000, 111.2382000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72065, 'Kebonturi', 'Kebonturi', 'Kebonturi', -6.7589000, 111.1842000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72066, 'Sempu', 'Sempu', 'Sempu', -6.7617000, 111.1511000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72067, 'Daulan', 'Daulan', 'Daulan', -6.7700000, 111.1365000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72068, 'Kemiri', 'Kemiri', 'Kemiri', -6.7679000, 111.1635000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72069, 'Blingi', 'Blingi', 'Blingi', -6.7739000, 111.1855000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72070, 'Lundo', 'Lundo', 'Lundo', -6.7717000, 111.2016000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72071, 'Sobo', 'Sobo', 'Sobo', -6.7677000, 111.2149000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72072, 'Taunan', 'Taunan', 'Taunan', -6.7751000, 111.2159000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72073, 'Manjang Kidul', 'Manjang Kidul', 'Manjang Kidul', -6.7753000, 111.2425000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72074, 'Ngulakan', 'Ngulakan', 'Ngulakan', -6.7761000, 111.2248000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72075, 'Kemangi', 'Kemangi', 'Kemangi', -6.7835000, 111.1945000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72076, 'Klumpit', 'Klumpit', 'Klumpit', -6.7797000, 111.1650000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72077, 'Dersah', 'Dersah', 'Dersah', -6.7836000, 111.1564000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72078, 'Mantingantengah', 'Mantingantengah', 'Mantingantengah', -6.7757000, 111.1423000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72079, 'Sentul', 'Sentul', 'Sentul', -6.7888000, 111.1647000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72080, 'Sumberan', 'Sumberan', 'Sumberan', -6.7917000, 111.2037000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72081, 'Doyok', 'Doyok', 'Doyok', -6.7873000, 111.2494000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72082, 'Barisan', 'Barisan', 'Barisan', -6.7993000, 111.2430000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72083, 'Wungwung', 'Wungwung', 'Wungwung', -6.8000000, 111.2214000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72084, 'Mojolampir', 'Mojolampir', 'Mojolampir', -6.7997000, 111.2087000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72085, 'Gendolo', 'Gendolo', 'Gendolo', -6.8000000, 111.1956000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72086, 'Tegalwero', 'Tegalwero', 'Tegalwero', -6.7979000, 111.1675000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72087, 'Malangan', 'Malangan', 'Malangan', -6.8033000, 111.1341000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72088, 'Ploso', 'Ploso', 'Ploso', -6.8005000, 111.1463000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72089, 'Mantup', 'Mantup', 'Mantup', -6.8045000, 111.2465000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72090, 'Boto', 'Boto', 'Boto', -6.8099000, 111.1954000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72091, 'Karang Wetan', 'Karang Wetan', 'Karang Wetan', -6.8124000, 111.1749000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72092, 'Pengilon', 'Pengilon', 'Pengilon', -6.8180000, 111.1561000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72093, 'Terteg', 'Terteg', 'Terteg', -6.8207000, 111.2178000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72094, 'Kletek', 'Kletek', 'Kletek', -6.8339000, 111.2230000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72095, 'Palemgede', 'Palemgede', 'Palemgede', -6.8314000, 111.1792000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72096, 'Bodeh', 'Bodeh', 'Bodeh', -6.8357000, 111.1318000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72097, 'Manding', 'Manding', 'Manding', -6.8366000, 111.1360000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72098, 'Mencon', 'Mencon', 'Mencon', -6.8342000, 111.1909000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72099, 'Koro', 'Koro', 'Koro', -6.8670000, 111.2157000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72100, 'Kedungbacin', 'Kedungbacin', 'Kedungbacin', -6.8669000, 111.2256000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72101, 'Mantingan', 'Mantingan', 'Mantingan', -6.8097000, 111.2295000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72102, 'Suwatu', 'Suwatu', 'Suwatu', -6.6312000, 111.0080000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72103, 'Pohijo', 'Pohijo', 'Pohijo', -6.6266000, 111.0717000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72104, 'Krajan Langenharjo', 'Krajan Langenharjo', 'Krajan Langenharjo', -6.6296000, 111.0850000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72105, 'Tegalharjo', 'Tegalharjo', 'Tegalharjo', -6.6413000, 111.0260000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72106, 'Krajan Tanjungrejo', 'Krajan Tanjungrejo', 'Krajan Tanjungrejo', -6.6337000, 111.0441000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72107, 'Tapen', 'Tapen', 'Tapen', -6.6390000, 111.0818000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72108, 'Krajan Karangwage', 'Krajan Karangwage', 'Krajan Karangwage', -6.6435000, 111.0711000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72109, 'Kadilangu', 'Kadilangu', 'Kadilangu', -6.6465000, 111.0863000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72110, 'Tlutup', 'Tlutup', 'Tlutup', -6.6492000, 111.0889000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72111, 'Pasucen', 'Pasucen', 'Pasucen', -6.6579000, 111.0518000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72112, 'Ketanen', 'Ketanen', 'Ketanen', -6.6539000, 111.0637000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72113, 'Krandan', 'Krandan', 'Krandan', -6.6516000, 111.0831000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72114, 'Geneng', 'Geneng', 'Geneng', -6.6544000, 111.0971000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72115, 'Sanglur', 'Sanglur', 'Sanglur', -6.6626000, 111.0024000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72116, 'Bagangan', 'Bagangan', 'Bagangan', -6.6595000, 111.0244000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72117, 'Bantengan', 'Bantengan', 'Bantengan', -6.6597000, 111.0634000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72118, 'Rejoso', 'Rejoso', 'Rejoso', -6.6586000, 111.0700000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72119, 'Bonagung', 'Bonagung', 'Bonagung', -6.6608000, 111.0888000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72120, 'Sambilawang', 'Sambilawang', 'Sambilawang', -6.6602000, 111.1025000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72121, 'Krajan Kajar', 'Krajan Kajar', 'Krajan Kajar', -6.6685000, 111.0724000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72122, 'Jetak Kulon', 'Jetak Kulon', 'Jetak Kulon', -6.6739000, 111.0910000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72123, 'Jetak', 'Jetak', 'Jetak', -6.6725000, 111.0982000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72124, 'Asempapan', 'Asempapan', 'Asempapan', -6.6677000, 111.1028000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72125, 'Tlogoharum', 'Tlogoharum', 'Tlogoharum', -6.6698000, 111.1059000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72126, 'Suwaduk', 'Suwaduk', 'Suwaduk', -6.6805000, 111.0603000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72127, 'Pagerharjo', 'Pagerharjo', 'Pagerharjo', -6.6793000, 111.0853000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72128, 'Kepoh', 'Kepoh', 'Kepoh', -6.6752000, 111.1043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72129, 'Tluwuk', 'Tluwuk', 'Tluwuk', -6.6786000, 111.1158000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72130, 'Koroyo', 'Koroyo', 'Koroyo', -6.6893000, 111.0669000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72131, 'Jontro', 'Jontro', 'Jontro', -6.6920000, 111.0708000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72132, 'Dodol', 'Dodol', 'Dodol', -6.6831000, 111.1032000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72133, 'Pentungan', 'Pentungan', 'Pentungan', -6.6910000, 111.1104000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72134, 'Geneng Tengah', 'Geneng Tengah', 'Geneng Tengah', -6.6854000, 111.1217000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72135, 'Regaloh', 'Regaloh', 'Regaloh', -6.6975000, 111.0249000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72136, 'Ngurenrejo', 'Ngurenrejo', 'Ngurenrejo', -6.6962000, 111.0817000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72137, 'Purwosari', 'Purwosari', 'Purwosari', -6.7012000, 111.0018000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72138, 'Ngaliyan', 'Ngaliyan', 'Ngaliyan', -6.7039000, 111.0431000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72139, 'Ngulaan', 'Ngulaan', 'Ngulaan', -6.7026000, 111.0660000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72140, 'Kalangan', 'Kalangan', 'Kalangan', -6.7054000, 111.1065000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72141, 'Kincir Wetan', 'Kincir Wetan', 'Kincir Wetan', -6.7011000, 111.1203000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72142, 'Kebonagung', 'Kebonagung', 'Kebonagung', -6.7117000, 111.0668000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72143, 'Karangnongko', 'Karangnongko', 'Karangnongko', -6.7184000, 111.0201000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72144, 'Runting', 'Runting', 'Runting', -6.7218000, 111.0530000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72145, 'Ngepungkrajan', 'Ngepungkrajan', 'Ngepungkrajan', -6.7205000, 111.0717000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72146, 'Triwil', 'Triwil', 'Triwil', -6.7204000, 111.0994000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72147, 'Rendole', 'Rendole', 'Rendole', -6.7330000, 111.0120000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72148, 'Bongsri', 'Bongsri', 'Bongsri', -6.7280000, 111.0490000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72149, 'Payang', 'Payang', 'Payang', -6.7284000, 111.0598000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72150, 'Pondohan', 'Pondohan', 'Pondohan', -6.7302000, 111.0837000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72151, 'Guwo', 'Guwo', 'Guwo', -6.7302000, 111.1056000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72152, 'Ngarus', 'Ngarus', 'Ngarus', -6.7406000, 111.0331000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72153, 'Pencil', 'Pencil', 'Pencil', -6.7412000, 111.1145000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72154, 'Winong', 'Winong', 'Winong', -6.7445000, 111.0305000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72155, 'Kaborongan', 'Kaborongan', 'Kaborongan', -6.7462000, 111.0394000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72156, 'Parenggan', 'Parenggan', 'Parenggan', -6.7469000, 111.0430000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72157, 'Sarirejo', 'Sarirejo', 'Sarirejo', -6.7473000, 111.0508000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72158, 'Tambakromo', 'Tambakromo', 'Tambakromo', -6.7259000, 111.0677000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72159, 'Lambangan', 'Lambangan', 'Lambangan', -6.7479000, 111.0679000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72160, 'Widorokandang', 'Widorokandang', 'Widorokandang', -6.7412000, 111.0790000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72161, 'Karangrowo', 'Karangrowo', 'Karangrowo', -6.7453000, 111.0893000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72162, 'Ngurensiti', 'Ngurensiti', 'Ngurensiti', -6.6989000, 111.0864000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72163, 'Cigalumpit', 'Cigalumpit', 'Cigalumpit,Tjigaloempit', -7.3033000, 108.6069000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72164, 'Cirateun', 'Cirateun', 'Cirateun,Tjirateun', -7.2767000, 108.5937000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72165, 'Batububut', 'Batububut', 'Batububut', -7.3047000, 108.5739000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72166, 'Cibeureum', 'Cibeureum', 'Cibeureum,Tjibeureum', -7.3707000, 108.5087000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72167, 'Sembungjaya', 'Sembungjaya', 'Sembungjaya', -7.3492000, 108.5084000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72168, 'Cikuda', 'Cikuda', 'Cikuda,Tjikoeda', -7.2585000, 108.5129000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72169, 'Cempaka', 'Cempaka', 'Cempaka', -7.3236000, 108.5166000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72170, 'Cipadung Timur', 'Cipadung Timur', 'Cipadung Timur', -7.3594000, 108.5414000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72171, 'Margamulya', 'Margamulya', 'Margamulya', -7.2674000, 108.5587000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72172, 'Bangunharja', 'Bangunharja', 'Bangunharja', -7.2928000, 108.5510000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72173, 'Ciaren', 'Ciaren', 'Ciaren', -7.3680000, 108.5565000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72174, 'Babakansari', 'Babakansari', 'Babakansari', -7.3699000, 108.5609000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72175, 'Randegan Dua', 'Randegan Dua', 'Randegan Dua', -7.3556000, 108.5683000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72176, 'Rancakole', 'Rancakole', 'Rancakole', -7.3715000, 108.5891000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72177, 'Sindanggalih', 'Sindanggalih', 'Sindanggalih', -7.3615000, 108.6238000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72178, 'Cikembang', 'Cikembang', 'Cikembang,Tjikembang', -7.1271000, 108.5152000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72179, 'Manis Subang', 'Manis Subang', 'Manis Subang', -7.1284000, 108.5313000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72180, 'Pahing Jalatrang', 'Pahing Jalatrang', 'Pahing Jalatrang', -7.1311000, 108.5671000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72181, 'Bungur', 'Bungur', 'Boengoerberes,Boengoerbèrès,Bungur', -7.1376000, 108.5964000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72182, 'Curug', 'Curug', 'Curug,Tjoeroeg', -7.1363000, 108.5010000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72183, 'Janglapa', 'Janglapa', 'Djanglapa,Janglapa', -7.1437000, 108.5053000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72184, 'Pahing Pamulihan', 'Pahing Pamulihan', 'Pahing Pamulihan', -7.1467000, 108.5467000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72185, 'Jatisari', 'Jatisari', 'Jatisari', -7.1534000, 108.5488000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72186, 'Dadiharja', 'Dadiharja', 'Dadiharja', -7.1520000, 108.5098000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72187, 'Bantardendang', 'Bantardendang', 'Bantardendang,Bantardengdeng,Bantardèngdèng', -7.1645000, 108.5092000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72188, 'Tangkolo', 'Tangkolo', 'Tangkolo', -7.1593000, 108.5108000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72189, 'Manis Legokherang', 'Manis Legokherang', 'Manis Legokherang', -7.1598000, 108.5730000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72190, 'Mandapajaya', 'Mandapajaya', 'Mandapa,Mandapajaya', -7.1730000, 108.5464000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72191, 'Cilumping', 'Cilumping', 'Cilumping,Tjiloemping', -7.1865000, 108.6215000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72192, 'Kujang', 'Kujang', 'Kujang', -7.1957000, 108.6022000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72193, 'Cimahi', 'Cimahi', 'Cimahi', -7.2026000, 108.5860000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72194, 'Sitularang Landeuh', 'Sitularang Landeuh', 'Sitularang Landeuh', -7.2040000, 108.5127000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72195, 'Kadupandak', 'Kadupandak', 'Kadoepandak,Kadupandak', -7.2173000, 108.5645000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72196, 'Harjamukti', 'Harjamukti', 'Harjamukti', -7.2198000, 108.5140000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72197, 'Samarang', 'Samarang', 'Samarang', -7.2279000, 108.5349000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72198, 'Pasirmanggu', 'Pasirmanggu', 'Pasirmanggoe,Pasirmanggu', -7.2368000, 108.5922000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72199, 'Balegede', 'Balegede', 'Balegede', -7.2388000, 108.5574000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72200, 'Krajan Tegalombo', 'Krajan Tegalombo', 'Krajan Tegalombo', -6.4367000, 111.0032000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72201, 'Krajan Satu Kembang', 'Krajan Satu Kembang', 'Krajan 1 Kembang,Krajan Satu Kembang', -6.4520000, 111.0223000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72202, 'Krajan Dukuhseti', 'Krajan Dukuhseti', 'Krajan Dukuhseti', -6.4570000, 111.0315000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72203, 'Banyutowo', 'Banyutowo', 'Banyutowo', -6.4583000, 111.0461000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72204, 'Krajan Kinanti', 'Krajan Kinanti', 'Krajan Kinanti', -6.4881400, 111.0411300, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72205, 'Krajan Grogolan', 'Krajan Grogolan', 'Krajan Grogolan', -6.4853000, 111.0227000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72206, 'Krajan Alasdowo', 'Krajan Alasdowo', 'Krajan Alasdowo', -6.4772900, 111.0379400, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72207, 'Krajan Ngagel', 'Krajan Ngagel', 'Krajan Ngagel', -6.4868600, 111.0380600, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72208, 'Tunggulsari', 'Tunggulsari', 'Tunggulsari', -6.6964000, 111.2358000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72209, 'Pacangaan', 'Pacangaan', 'Pacangaan', -6.6969000, 111.2339000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72210, 'Kalisabuk', 'Kalisabuk', 'Kalisabuk', -6.6929000, 111.1295000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72211, 'Plosojenar', 'Plosojenar', 'Plosojenar', -6.7489000, 111.1771000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72212, 'Bakaran Kulon', 'Bakaran Kulon', 'Bakaran Kulon', -6.7047000, 111.1260000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72213, 'Bakaran Wetan', 'Bakaran Wetan', 'Bakaran Wetan', -6.7066000, 111.1355000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72214, 'Lengkong', 'Lengkong', 'Lengkong', -6.7089000, 111.2145000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72215, 'Mangonan', 'Mangonan', 'Mangonan', -6.7080000, 111.2252000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72216, 'Delok', 'Delok', 'Delok', -6.7068700, 111.2398900, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72217, 'Batursari', 'Batursari', 'Batursari', -6.7092000, 111.2315000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72218, 'Jembangan', 'Jembangan', 'Jembangan', -6.7113000, 111.2111000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72219, 'Bumimulyo', 'Bumimulyo', 'Bumimulyo', -6.7089000, 111.2010000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72220, 'Ketitang Wetan', 'Ketitang Wetan', 'Ketitang Wetan', -6.7108000, 111.1898000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72221, 'Raci', 'Raci', 'Raci', -6.7118000, 111.1810000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72222, 'Kembang', 'Kembang', 'Kembang', -6.7130000, 111.1634000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72223, 'Bendar', 'Bendar', 'Bendar', -6.7094000, 111.1559000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72224, 'Bajomulyo', 'Bajomulyo', 'Bajomulyo', -6.7107000, 111.1516000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72225, 'Kudukeras', 'Kudukeras', 'Kudukeras', -6.7133000, 111.1494000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72226, 'Pajeksan', 'Pajeksan', 'Pajeksan', -6.7138000, 111.1453000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72227, 'Kebonsawahan', 'Kebonsawahan', 'Kebonsawahan', -6.7108000, 111.1459000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72228, 'Growong Lor', 'Growong Lor', 'Growong Lor', -6.7115000, 111.1413000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72229, 'Dukutalit', 'Dukutalit', 'Dukutalit', -6.7094000, 111.1367000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72230, 'Growong Kidul', 'Growong Kidul', 'Growong Kidul', -6.7148000, 111.1380000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72231, 'Doropayung', 'Doropayung', 'Doropayung', -6.7204000, 111.1439000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72232, 'Pulorejo', 'Pulorejo', 'Pulorejo', -6.7216000, 111.1473000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72233, 'Kauman', 'Kauman', 'Kauman', -6.7175000, 111.1460000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72234, 'Pekuwon', 'Pekuwon', 'Pekuwon', -6.7238000, 111.1608000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72235, 'Ngening', 'Ngening', 'Ngening', -6.7212000, 111.1804000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72236, 'Klayusiwalan', 'Klayusiwalan', 'Klayusiwalan', -6.7215000, 111.2001000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72237, 'Kedalon', 'Kedalon', 'Kedalon', -6.7217000, 111.2270000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72238, 'Ledok', 'Ledok', 'Ledok', -6.7268000, 111.2370000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72239, 'Gunungsari', 'Gunungsari', 'Gunungsari', -6.7309000, 111.2343000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72240, 'Bulumulyo', 'Bulumulyo', 'Bulumulyo', -6.7328000, 111.1991000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72241, 'Ketip', 'Ketip', 'Ketip', -6.7323000, 111.1665000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72242, 'Karangboyo', 'Karangboyo', 'Karangboyo', -6.7316000, 111.1525000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72243, 'Kedungpancing', 'Kedungpancing', 'Kedungpancing', -6.7247000, 111.1462000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72244, 'Jepuro', 'Jepuro', 'Jepuro', -6.7280000, 111.1446000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72245, 'Tluwah', 'Tluwah', 'Tluwah', -6.7309000, 111.1439000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72246, 'Bagu', 'Bagu', 'Bagu', -6.7262000, 111.1295000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72247, 'Karang', 'Karang', 'Karang', -6.7335000, 111.1589000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72248, 'Maguan', 'Maguan', 'Maguan', -6.7419000, 111.2383000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72249, 'Jemblem', 'Jemblem', 'Jemblem', -6.7497000, 111.2395000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72250, 'Kuniran', 'Kuniran', 'Kuniran', -6.7437000, 111.2319000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72251, 'Trolu', 'Trolu', 'Trolu', -6.7415000, 111.2149000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72252, 'Legok', 'Legok', 'Legok', -6.7457000, 111.1933000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72253, 'Tlogomojo', 'Tlogomojo', 'Tlogomojo', -6.7425000, 111.1726000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72254, 'Beringin', 'Beringin', 'Beringin', -6.7437000, 111.1545000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72255, 'Sejomulyo', 'Sejomulyo', 'Sejomulyo', -6.7429000, 111.1432000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72256, 'Druju', 'Druju', 'Druju', -6.7457000, 111.1300000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72257, 'Delok', 'Delok', '', -6.7064300, 111.2428700, 'ID', '2011-11-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72258, 'Ngelak', 'Ngelak', 'Ngelak', -6.6923000, 111.2677000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72259, 'Dresen', 'Dresen', 'Dresen', -6.6953000, 111.2837000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72260, 'Karangturi', 'Karangturi', 'Karangturi', -6.6980000, 111.3075000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72261, 'Banyudono', 'Banyudono', 'Banyudono', -6.6999000, 111.3094000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72262, 'Tireman Timur', 'Tireman Timur', 'Tireman,Tireman Timur', -6.7058000, 111.3717000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72263, 'Kabongan Lor', 'Kabongan Lor', 'Kabongan Lor', -6.7052000, 111.3570000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72264, 'Kasingan', 'Kasingan', 'Kasingan', -6.7070000, 111.3520000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72265, 'Rembang', 'Rembang', 'Rembang', -6.7070000, 111.3498000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72266, 'Pandean', 'Pandean', 'Pandean', -6.7044000, 111.3480000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72267, 'Kutoharjo', 'Kutoharjo', 'Kutoharjo', -6.7056000, 111.3450000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72268, 'Pabean', 'Pabean', 'Pabean', -6.7025000, 111.3340000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72269, 'Karanggeneng', 'Karanggeneng', 'Karanggeneng', -6.7023000, 111.3296000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72270, 'Magersari', 'Magersari', 'Magersari', -6.7025000, 111.3252000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72271, 'Mojo', 'Mojo', 'Mojo', -6.7109000, 111.2564000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72272, 'Dresi Wetan', 'Dresi Wetan', 'Dresi Wetan', -6.7128000, 111.2765000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72273, 'Karangsekar', 'Karangsekar', 'Karangsekar', -6.7112000, 111.2958000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72274, 'Sawahan', 'Sawahan', 'Sawahan', -6.7086000, 111.3392000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72275, 'Sumberejo', 'Sumberejo', 'Sumberejo', -6.7116000, 111.3399000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72276, 'Sidowayah Lor', 'Sidowayah Lor', 'Sidowayah Lor', -6.7108000, 111.3493000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72277, 'Kedungdoro', 'Kedungdoro', 'Kedungdoro', -6.7174000, 111.3461000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72278, 'Kabongan Kidul', 'Kabongan Kidul', 'Kabongan Kidul', -6.7081000, 111.3580000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72279, 'Sidowayah Kidul', 'Sidowayah Kidul', 'Sidowayah Kidul', -6.7202000, 111.3470000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72280, 'Waru Selatan', 'Waru Selatan', 'Waru Selatan', -6.7180000, 111.3248000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72281, 'Babadan', 'Babadan', 'Babadan', -6.7219000, 111.2948000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72282, 'Sambiyan', 'Sambiyan', 'Sambiyan', -6.7315000, 111.2698000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72283, 'Pengkol', 'Pengkol', 'Pengkol', -6.7340000, 111.2922000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72284, 'Bangker', 'Bangker', 'Bangker', -6.7321000, 111.3289000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72285, 'Pulo', 'Pulo', 'Pulo', -6.7268000, 111.3311000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72286, 'Ketanggi', 'Ketanggi', 'Ketanggi', -6.7317000, 111.3395000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72287, 'Ngotet Kidul', 'Ngotet Kidul', 'Ngotet Kidul', -6.7309000, 111.3582000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72288, 'Weton', 'Weton', 'Weton', -6.7331000, 111.3698000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72289, 'Nrondo', 'Nrondo', 'Nrondo', -6.7400000, 111.3677000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72290, 'Mondoteko', 'Mondoteko', 'Mondoteko', -6.7359000, 111.3451000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72291, 'Ngadem', 'Ngadem', 'Ngadem', -6.7382000, 111.3376000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72292, 'Gingsir', 'Gingsir', 'Gingsir', -6.7417000, 111.2684000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72293, 'Banggi', 'Banggi', 'Banggi', -6.7468000, 111.2908000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72294, 'Kuangsan', 'Kuangsan', 'Kuangsan', -6.7459000, 111.2993000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72295, 'Kebon', 'Kebon', 'Kebon', -6.7499000, 111.3513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72296, 'Lojigawaran', 'Lojigawaran', 'Lojigawaran', -6.7422000, 111.3587000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72297, 'Wiroto', 'Wiroto', 'Wiroto', -6.7576000, 111.2554000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72298, 'Tlogotunggal', 'Tlogotunggal', 'Tlogotunggal', -6.7570000, 111.2971000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72299, 'Pentil', 'Pentil', 'Pentil', -6.7501000, 111.3078000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72300, 'Trambalan', 'Trambalan', 'Trambalan', -6.7597000, 111.3245000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72301, 'Pragu', 'Pragu', 'Pragu', -6.7525000, 111.3361000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72302, 'Kebonagung', 'Kebonagung', 'Kebonagung', -6.7523000, 111.3447000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72303, 'Majasem', 'Majasem', 'Majasem', -6.7624000, 111.2559000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72304, 'Mojogajeh', 'Mojogajeh', 'Mojogajeh', -6.7637000, 111.2770000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72305, 'Legok', 'Legok', 'Legok', -6.7611000, 111.3134000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72306, 'Seren Barat', 'Seren Barat', 'Seren Barat', -6.7591000, 111.3313000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72307, 'Pranti', 'Pranti', 'Pranti', -6.7611000, 111.3550000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72308, 'Bogorame', 'Bogorame', 'Bogorame', -6.7660000, 111.3568000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72309, 'Krajan Landoh', 'Krajan Landoh', 'Krajan Landoh', -6.7635000, 111.3709000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72310, 'Megulung', 'Megulung', 'Megulung', -6.7722000, 111.2661000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72311, 'Bulak', 'Bulak', 'Bulak', -6.7744000, 111.2998000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72312, 'Sekararum', 'Sekararum', 'Sekararum', -6.7769000, 111.2573000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72313, 'Jadi', 'Jadi', 'Jadi', -6.7772000, 111.2717000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72314, 'Sudo', 'Sudo', 'Sudo', -6.7881000, 111.3243000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72315, 'Kaliombo Wetan', 'Kaliombo Wetan', 'Kaliombo Wetan', -6.7868000, 111.3621000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72316, 'Banyuurip', 'Banyuurip', 'Banyuurip', -6.8042000, 111.2685000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72317, 'Tanjung Utara', 'Tanjung Utara', 'Tanjung Utara', -6.8170000, 111.3704000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72318, 'Kedungtulup', 'Kedungtulup', 'Kedungtulup', -6.8235000, 111.2710000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72319, 'Krikilan', 'Krikilan', 'Krikilan', -6.8289000, 111.2748000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72320, 'Logung', 'Logung', 'Logung', -6.8303000, 111.2877000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72321, 'Pelemsari', 'Pelemsari', 'Pelemsari', -6.8317000, 111.3118000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72322, 'Lambangan Kulon', 'Lambangan Kulon', 'Lambangan Kulon', -6.8352000, 111.3585000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72323, 'Lambangan Wetan', 'Lambangan Wetan', 'Lambangan Wetan', -6.8288000, 111.3666000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72324, 'Ronggo', 'Ronggo', 'Ronggo', -6.8414000, 111.2564000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72325, 'Pandansili', 'Pandansili', 'Pandansili', -6.8369000, 111.2911000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72326, 'Pondokrejo Wetan', 'Pondokrejo Wetan', 'Pondokrejo Wetan', -6.8365000, 111.3243000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72327, 'Ngrojo', 'Ngrojo', 'Ngrojo', -6.8348000, 111.3525000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72328, 'Cabean', 'Cabean', 'Cabean', -6.8420000, 111.3560000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72329, 'Ngaglik', 'Ngaglik', 'Ngaglik', -6.8400000, 111.3671000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72330, 'Goge', 'Goge', 'Goge', -6.8451000, 111.2719000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72331, 'Mlatirejo', 'Mlatirejo', 'Mlatirejo', -6.8460000, 111.3046000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72332, 'Pinggan', 'Pinggan', 'Pinggan', -6.8488000, 111.3445000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72333, 'Krajan Tengah Sendangmulyo', 'Krajan Tengah Sendangmulyo', 'Krajan Tengah Sendangmulyo', -6.8531000, 111.3223000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72334, 'Karangasem', 'Karangasem', 'Karangasem', -6.8512000, 111.3638000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72335, 'Kalinanas', 'Kalinanas', 'Kalinanas', -6.8629000, 111.2608000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72336, 'Madura', 'Madura', 'Madoera,Madura', -7.1478000, 108.3789000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72337, 'Emblegan', 'Emblegan', 'Emblegan', -7.1325000, 108.4212000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72338, 'Kaom', 'Kaom', 'Kaom', -7.1297000, 108.4164000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72339, 'Cibeuruy', 'Cibeuruy', 'Cibeuruy,Tjiboeroej', -7.1485000, 108.4315000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72340, 'Mekarjaya', 'Mekarjaya', 'Mekarjaya', -7.1597000, 108.4502000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72341, 'Citapenpasir', 'Citapenpasir', 'Citapenpasir', -7.1381000, 108.4803000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72342, 'Sukaharja', 'Sukaharja', 'Sukaharja', -7.1522000, 108.4768000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72343, 'Tanjungjaya', 'Tanjungjaya', 'Tanjungjaya', -7.1770000, 108.4524000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72344, 'Cibingbin', 'Cibingbin', 'Cibingbin', -7.1825000, 108.4349000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72345, 'Pabuaran', 'Pabuaran', 'Pabuaran', -7.1674000, 108.4367000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72346, 'Cigoong', 'Cigoong', 'Cigoong', -7.1824000, 108.4317000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72347, 'Bayasari Kulon', 'Bayasari Kulon', 'Bayasari Kulon', -7.1758000, 108.4226000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72348, 'Jatinagara Kulon', 'Jatinagara Kulon', 'Jatinagara Kulon', -7.1719000, 108.4190000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72349, 'Pasiramis', 'Pasiramis', 'Pasiramis', -7.1658000, 108.3987000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72350, 'Kedawung', 'Kedawung', 'Kadawoeng,Kedawung', -7.2304000, 108.3768000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72351, 'Pangrumasan', 'Pangrumasan', 'Pangroemasan,Pangrumasan', -7.2046000, 108.4077000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72352, 'Cileueur', 'Cileueur', 'Cileueur,Tjileueur', -7.2100000, 108.4274000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72353, 'Kiarapayung', 'Kiarapayung', 'Kiarapajoeng,Kiarapayung', -7.2127000, 108.4656000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72354, 'Karangpari', 'Karangpari', 'Karangpari', -7.2419000, 108.4786000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72355, 'Cileungsir', 'Cileungsir', 'Cileungsir,Tjileungsir', -7.2051000, 108.4895000, 'ID', '2012-01-21', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72356, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo,Soedamoelih Satu', -7.6554000, 108.6257000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72357, 'Cibuluh Satu', 'Cibuluh Satu', 'Cibuluh Satu', -7.6400000, 108.7414000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72358, 'Sukamanah', 'Sukamanah', 'Sukamanah', -7.6590000, 108.6514000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72359, 'Bengkekan', 'Bengkekan', 'Bengkekan', -7.6628000, 108.6662000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72360, 'Emplak', 'Emplak', 'Emplak', -7.6608000, 108.7302000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72361, 'Karangsari', 'Karangsari', 'Karangsari', -7.6701000, 108.7025000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72362, 'Wonoharjo', 'Wonoharjo', 'Wanahardja,Wonoharjo', -7.6764000, 108.6324000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72363, 'Kamurang', 'Kamurang', 'Kamoerang,Kamurang', -7.6761000, 108.6763000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72364, 'Parapat', 'Parapat', 'Parapat', -7.6892000, 108.6572000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72365, 'Pananjung', 'Pananjung', 'Panandjoeng,Pananjung', -7.6826000, 108.6503000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72366, 'Godong', 'Godong', 'Gedong,Godong', -7.0044000, 108.5409000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72367, 'Sukaimut', 'Sukaimut', 'Sukaimut', -7.0051000, 108.5458000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72368, 'Cikananga', 'Cikananga', 'Cikananga', -7.0068000, 108.5501000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72369, 'Tambakbaya', 'Tambakbaya', 'Tambakbaja,Tambakbaya', -7.0054000, 108.5578000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72370, 'Modis', 'Modis', 'Modin,Modis', -7.0066000, 108.5648000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72371, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.1037000, 108.6148000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72372, 'Sindang', 'Sindang', 'Sindang', -7.0006000, 108.5819000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72373, 'Rahayu', 'Rahayu', 'Rahayu', -7.0167000, 108.6183000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72374, 'Dukuh Kaler', 'Dukuh Kaler', 'Dukuh Kaler', -7.0268000, 108.5778000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72375, 'Langseb', 'Langseb', 'Langseb', -7.0188000, 108.5797000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72376, 'Cineumbeuy', 'Cineumbeuy', 'Cineumbeuy,Tjineumbeuj', -7.0240000, 108.5918000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72377, 'Cipetir', 'Cipetir', 'Cipetir,Tjipetir', -7.0248000, 108.6048000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72378, 'Margasari', 'Margasari', 'Margasari', -7.0189000, 108.6237000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72379, 'Cinagara', 'Cinagara', 'Cinagara,Tjinagara', -7.0249000, 108.5870000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72380, 'Buniaga', 'Buniaga', 'Boeniaga,Buniaga', -7.0320000, 108.5809000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72381, 'Manis Karangtengah', 'Manis Karangtengah', 'Manis Karangtengah', -7.0299000, 108.5737000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72382, 'Cibuah', 'Cibuah', 'Cibuah', -7.0268000, 108.5662000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72383, 'Parakan', 'Parakan', 'Parakan', -7.0314000, 108.5566000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72384, 'Kutamandarakan', 'Kutamandarakan', 'Kutamandarakan', -7.0277000, 108.5577000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72385, 'Gewok', 'Gewok', 'Gewok', -7.0300000, 108.5242000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72386, 'Kutamangu', 'Kutamangu', 'Koetamanggoe,Kutamangu', -7.1203000, 108.5051000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72387, 'Cikahuripan', 'Cikahuripan', 'Cikahuripan,Tjikahoeripan', -7.0354000, 108.5484000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72388, 'Kedatuan', 'Kedatuan', 'Kedatoean,Kedatuan', -7.0410000, 108.5879000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72389, 'Walahar', 'Walahar', 'Walahar', -7.0391000, 108.6093000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72390, 'Garahaji', 'Garahaji', 'Garahadji,Garahaji', -7.0497000, 108.6112000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72391, 'Ciakar', 'Ciakar', 'Ciakar,Tjiakar', -7.0431000, 108.5651000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72392, 'Pamupukan', 'Pamupukan', 'Pamupukan', -7.0469000, 108.5303000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72393, 'Cipakem', 'Cipakem', 'Cipakem,Tjipakem', -7.0755000, 108.5779000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72394, 'Gunungmanik', 'Gunungmanik', 'Gunungmanik', -7.0869000, 108.5051000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72395, 'Giriwaringin', 'Giriwaringin', 'Giriwaringin', -7.0875000, 108.5813000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72396, 'Girang', 'Girang', 'Girang', -7.0901000, 108.5988000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72397, 'Cilayung', 'Cilayung', 'Cilayung', -7.0842000, 108.6213000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72398, 'Cilimus Kulon', 'Cilimus Kulon', 'Cilimus Kulon', -7.0992000, 108.5874000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72399, 'Patala', 'Patala', 'Patala', -7.1103000, 108.5813000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72400, 'Blokdesa Situgede', 'Blokdesa Situgede', 'Blokdesa Situgede', -7.1053000, 108.5570000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72401, 'Gunungaci', 'Gunungaci', 'Gunungaci', -7.1032000, 108.5359000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72402, 'Manis Mekarwangi', 'Manis Mekarwangi', 'Manis Mekarwangi', -7.0108000, 108.6019000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72403, 'Kutaraja', 'Kutaraja', 'Koetaradja,Kutaraja', -7.0213200, 108.5613200, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72404, 'Gaplokan', 'Gaplokan', 'Gaplokan', -6.8951000, 111.2724000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72405, 'Ngiyono', 'Ngiyono', 'Ngiyono', -6.8992000, 111.3116000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72406, 'Sumberejo', 'Sumberejo', 'Sumberejo', -6.9141000, 111.3116000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72407, 'Tlogowungu', 'Tlogowungu', 'Tlogowungu', -6.9324000, 111.2785000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72408, 'Karangori', 'Karangori', 'Karangori', -6.9318000, 111.2882000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72409, 'Kalangan', 'Kalangan', 'Kalangan', -6.9421000, 111.3716000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72410, 'Bogorejo', 'Bogorejo', 'Bogorejo', -6.9382000, 111.3276000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72411, 'Pulo', 'Pulo', 'Pulo', -6.9377000, 111.2597000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72412, 'Padaan', 'Padaan', 'Padaan', -6.9435000, 111.2995000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72413, 'Wotbakah', 'Wotbakah', 'Wotbakah', -6.9441000, 111.3175000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72414, 'Triteh', 'Triteh', 'Triteh', -6.9594000, 111.3617000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72415, 'Beganjing', 'Beganjing', 'Beganjing', -6.9571000, 111.2973000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72416, 'Ngrambitan', 'Ngrambitan', 'Ngrambitan', -6.9629000, 111.3067000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72417, 'Pengkolrejo', 'Pengkolrejo', 'Pengkolrejo', -6.9604000, 111.3243000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72418, 'Sembung', 'Sembung', 'Sembung', -6.9699000, 111.3694000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72419, 'Tawangsari', 'Tawangsari', 'Tawangsari', -6.9744000, 111.3431000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72420, 'Bocowanti', 'Bocowanti', 'Bocowanti', -6.9707000, 111.3203000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72421, 'Wantil', 'Wantil', 'Wantil', -6.9742000, 111.3225000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72422, 'Suren', 'Suren', 'Suren', -6.9732000, 111.3035000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72423, 'Krocok', 'Krocok', 'Krocok', -6.9735000, 111.2754000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72424, 'Pelem', 'Pelem', 'Pelem', -6.9817000, 111.2581000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72425, 'Sambongrejo', 'Sambongrejo', 'Sambongrejo', -6.9787000, 111.3166000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72426, 'Kedungringin', 'Kedungringin', 'Kedungringin', -6.9883000, 111.3560000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72427, 'Pudak', 'Pudak', 'Pudak', -6.9885000, 111.3258000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72428, 'Gotputuk', 'Gotputuk', 'Gotputuk', -6.9890000, 111.3057000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72429, 'Plosorejo', 'Plosorejo', 'Plosorejo', -6.9919000, 111.2612000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72430, 'Bradag', 'Bradag', 'Bradag', -6.9933000, 111.2953000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72431, 'Berbak', 'Berbak', 'Berbak', -6.9981000, 111.3134000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72432, 'Kembang', 'Kembang', 'Kembang', -6.9979000, 111.3515000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72433, 'Sendangsari', 'Sendangsari', 'Sendangsari', -6.9812000, 111.3354000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72434, 'Kulonkali', 'Kulonkali', 'Kulonkali', -6.9904000, 111.3746000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72435, 'Trahan Wetan', 'Trahan Wetan', 'Trahan Wetan', -6.6367000, 111.4822000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72436, 'Jurangjero', 'Jurangjero', 'Jurangjero', -6.6455000, 111.4832000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72437, 'Dukoh', 'Dukoh', 'Dukoh', -6.6488000, 111.4735000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72438, 'Ngenden', 'Ngenden', 'Ngenden', -6.6688000, 111.4585000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72439, 'Logading', 'Logading', 'Logading', -6.6684000, 111.4739000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72440, 'Kalilu', 'Kalilu', 'Kalilu', -6.6825000, 111.4877000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72441, 'Ngodo', 'Ngodo', 'Ngodo', -6.6915000, 111.4146000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72442, 'Gedongmulyo', 'Gedongmulyo', 'Gedongmulyo', -6.6920000, 111.4391000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72443, 'Karangrejo', 'Karangrejo', 'Karangrejo', -6.6905100, 111.4529900, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72444, 'Bendan', 'Bendan', 'Bendan', -6.6838000, 111.4609000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72445, 'Kajar', 'Kajar', 'Kajar', -6.6909000, 111.4765000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72446, 'Mentoro Wetan', 'Mentoro Wetan', 'Mentoro Wetan', -6.6993000, 111.4904000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72447, 'Ngargomulyo', 'Ngargomulyo', 'Ngargomulyo', -6.6921000, 111.4882000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72448, 'Ngandangan', 'Ngandangan', 'Ngandangan', -6.6950000, 111.4640000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72449, 'Belahan', 'Belahan', 'Belahan', -6.6929000, 111.4513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72450, 'Sambong', 'Sambong', 'Sambong', -6.6952000, 111.4348000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72451, 'Tritunggal', 'Tritunggal', 'Tritunggal', -6.6977000, 111.3969000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72452, 'Babagan', 'Babagan', 'Babagan', -6.7003000, 111.4400000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72453, 'Jolotundo', 'Jolotundo', 'Jolotundo', -6.7039000, 111.4465000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72454, 'Karangturi', 'Karangturi', 'Karangturi', -6.7016000, 111.4454000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72455, 'Pandeyan', 'Pandeyan', 'Pandeyan', -6.7009000, 111.4513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72456, 'Warugunung', 'Warugunung', 'Warugunung', -6.7076000, 111.4570000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72457, 'Criwik', 'Criwik', 'Criwik', -6.7064000, 111.4952000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72458, 'Banyuurip', 'Banyuurip', 'Banyuurip', -6.7107000, 111.4976000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72459, 'Pohlandak', 'Pohlandak', 'Pohlandak', -6.7139000, 111.4523000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72460, 'Karasgede', 'Karasgede', 'Karasgede', -6.7100000, 111.4342000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72461, 'Gandik', 'Gandik', 'Gandik', -6.7205000, 111.3755000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72462, 'Padaran', 'Padaran', 'Padaran', -6.7218000, 111.4004000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72463, 'Garang', 'Garang', 'Garang', -6.7234000, 111.4035000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72464, 'Kasreman', 'Kasreman', 'Kasreman', -6.7201000, 111.4152000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72465, 'Karaskepoh', 'Karaskepoh', 'Karaskepoh', -6.7216000, 111.4389000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72466, 'Karanglo', 'Karanglo', 'Karanglo', -6.7221000, 111.4429000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72467, 'Krajan Wuwur', 'Krajan Wuwur', 'Krajan Wuwur', -6.7212000, 111.4830000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72468, 'Ngulangan', 'Ngulangan', 'Ngulangan', -6.7180000, 111.4870000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72469, 'Kedung', 'Kedung', 'Kedung', -6.7294000, 111.4935000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72470, 'Punggurharjo', 'Punggurharjo', 'Punggurharjo', -6.7257000, 111.4756000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72471, 'Langkir', 'Langkir', 'Langkir', -6.7303000, 111.4660000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72472, 'Gemblengmulyo', 'Gemblengmulyo', 'Gemblengmulyo', -6.7328000, 111.4675000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72473, 'Doropayung', 'Doropayung', 'Doropayung', -6.7251000, 111.4350000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72474, 'Ngangpo', 'Ngangpo', 'Ngangpo', -6.7306000, 111.3880000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72475, 'Balong Kulon', 'Balong Kulon', 'Balong Kulon', -6.7350000, 111.3782000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72476, 'Jeruk', 'Jeruk', 'Jeruk', -6.7353000, 111.4406000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72477, 'Sumberagung', 'Sumberagung', 'Sumberagung', -6.7368000, 111.4777000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72478, 'Sambongmulyo', 'Sambongmulyo', 'Sambongmulyo', -6.7353000, 111.4931000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72479, 'Gayam', 'Gayam', 'Gayam', -6.7470000, 111.4781000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72480, 'Tulung', 'Tulung', 'Tulung', -6.7445000, 111.4542000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72481, 'Japeledok', 'Japeledok', 'Japeledok', -6.7443000, 111.4411000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72482, 'Sendangagung', 'Sendangagung', 'Sendangagung', -6.7448000, 111.4247000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72483, 'Langgar', 'Langgar', 'Langgar', -6.6491000, 111.5047000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72484, 'Nggambel', 'Nggambel', 'Nggambel', -6.6544000, 111.5034000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72485, 'Carian', 'Carian', 'Carian', -6.7221000, 111.5249000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72486, 'Bendo', 'Bendo', 'Bendo', -6.6588000, 111.5335000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72487, 'Pendok', 'Pendok', 'Pendok', -6.6313000, 111.5280000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72488, 'Blimbing', 'Blimbing', 'Blimbing', -6.6340000, 111.5365000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72489, 'Dadapan', 'Dadapan', 'Dadapan', -6.7094000, 111.5396000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72490, 'Karangnongko', 'Karangnongko', 'Karangnongko', -6.7497000, 111.5370000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72491, 'Sambong', 'Sambong', 'Sambong', -6.7241000, 111.5475000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72492, 'Gerdu', 'Gerdu', 'Gerdu', -6.7264000, 111.5232000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72493, 'Ngroto', 'Ngroto', 'Ngroto', -6.7129000, 111.5196000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72494, 'Jatisari', 'Jatisari', 'Jatisari', -6.6333000, 111.5085000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72495, 'Rakitan', 'Rakitan', 'Rakitan', -6.6667000, 111.5161000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72496, 'Trenggulunan', 'Trenggulunan', 'Trenggulunan', -6.7202000, 111.5147000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72497, 'Sidowayah', 'Sidowayah', 'Sidowayah', -6.7357000, 111.5026000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72498, 'Johogunung', 'Johogunung', 'Johogunung', -6.7175000, 111.5025000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72499, 'Dukuan', 'Dukuan', 'Dukuan', -6.6918000, 111.5439000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72500, 'Culeng', 'Culeng', 'Culeng', -6.6491000, 111.5473000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72501, 'Sendangmulyo', 'Sendangmulyo', 'Sendangmulyo', -6.6390000, 111.5523000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72502, 'Sendang', 'Sendang', 'Sendang', -6.6956000, 111.5553000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72503, 'Tanjungsari', 'Tanjungsari', 'Tanjungsari', -6.7078000, 111.5540000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72504, 'Bogorejo', 'Bogorejo', 'Bogorejo', -6.7283000, 111.5601000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72505, 'Juwen', 'Juwen', 'Juwen', -6.7099000, 111.5659000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72506, 'Terjan', 'Terjan', 'Terjan', -6.6945000, 111.5641000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72507, 'Krajan Woro', 'Krajan Woro', 'Krajan Woro', -6.6701000, 111.5639000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72508, 'Krajan Sumurtawang', 'Krajan Sumurtawang', 'Krajan Sumurtawang', -6.6641000, 111.5655000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72509, 'Sumbersari', 'Sumbersari', 'Sumbersari', -6.6462000, 111.5665000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72510, 'Sendangwaru', 'Sendangwaru', 'Sendangwaru', -6.7071000, 111.5742000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72511, 'Krajan Gandrirejo', 'Krajan Gandrirejo', 'Krajan Gandrirejo', -6.7291000, 111.5663000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72512, 'Sulo', 'Sulo', 'Sulo', -6.7306000, 111.5732000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72513, 'Kedungringin', 'Kedungringin', 'Kedungringin', -6.7387000, 111.5843000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72514, 'Jambeyan', 'Jambeyan', 'Jambeyan', -6.7290000, 111.5808000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72515, 'Sudan', 'Sudan', 'Sudan', -6.6963000, 111.5789000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72516, 'Narukan', 'Narukan', 'Narukan', -6.6943000, 111.5826000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72517, 'Sumurpule', 'Sumurpule', 'Sumurpule', -6.6874000, 111.5822000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72518, 'Pandangan Kulon', 'Pandangan Kulon', 'Pandangan Kulon', -6.6669000, 111.5890000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72519, 'Pandangan Wetan', 'Pandangan Wetan', 'Pandangan Wetan', -6.6702000, 111.5896000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72520, 'Sumbergayam', 'Sumbergayam', 'Sumbergayam', -6.6748000, 111.5884000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72521, 'Ngasinan', 'Ngasinan', 'Ngasinan', -6.7144000, 111.5866000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72522, 'Menara', 'Menara', 'Menara', -6.7283000, 111.5918000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72523, 'Plawangan', 'Plawangan', 'Plawangan', -6.6741000, 111.5942000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72524, 'Balongmulyo', 'Balongmulyo', 'Balongmulyo', -6.6806000, 111.6014000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72525, 'Kendalagung', 'Kendalagung', 'Kendalagung', -6.7093000, 111.6038000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72526, 'Mojokerto', 'Mojokerto', 'Mojokerto', -6.7334000, 111.6089000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72527, 'Balongteki', 'Balongteki', 'Balongteki', -6.7457000, 111.6174000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72528, 'Bulakbanjar', 'Bulakbanjar', 'Bulakbanjar', -7.6237000, 108.7205000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72529, 'Pasirgeulis', 'Pasirgeulis', 'Pasirgeulis', -7.5100000, 108.6736000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72530, 'Ciulu', 'Ciulu', 'Ciulu', -7.5130000, 108.6537000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72531, 'Cangkring', 'Cangkring', 'Cangkring', -7.5115000, 108.6319000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72532, 'Sopla', 'Sopla', 'Sopla', -7.5208000, 108.6747000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72533, 'Maruyungsari', 'Maruyungsari', 'Maruyungsari', -7.5176000, 108.7307000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72534, 'Ciilat', 'Ciilat', 'Ciilat', -7.5407000, 108.7258000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72535, 'Patingen Dua', 'Patingen Dua', 'Patingen Dua', -7.5418000, 108.6973000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72536, 'Burujul', 'Burujul', 'Boeroedjoel,Burujul', -7.5458000, 108.6847000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72537, 'Cinangka', 'Cinangka', 'Cinangka,Karangnangka', -7.5566000, 108.6536000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72538, 'Nagrak', 'Nagrak', 'Nagrak', -7.5632000, 108.6946000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72539, 'Kawarasan', 'Kawarasan', 'Kawarasan', -7.5699000, 108.6997000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72540, 'Babakanjaya', 'Babakanjaya', 'Babakanjaya', -7.5780000, 108.6763000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72541, 'Cihideung', 'Cihideung', 'Cihideung', -7.5857000, 108.7144000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72542, 'Ciparakan', 'Ciparakan', 'Ciparakan,Tjiparakan', -7.5979000, 108.6716000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72543, 'Cintamaju', 'Cintamaju', 'Cintamaju', -7.6132000, 108.7246000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72544, 'Kragan', 'Kragan', '', -6.6972600, 111.6222900, 'ID', '2011-12-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72545, 'Sukanagara', 'Sukanagara', 'Sukanagara', -7.4039000, 108.6557000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72546, 'Kalapagada', 'Kalapagada', 'Kalapagada', -7.3943000, 108.6614000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72547, 'Tambakreja', 'Tambakreja', 'Tambakreja', -7.3825000, 108.6565000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72548, 'Pondokunyur', 'Pondokunyur', 'Pondokunyur', -7.3887000, 108.6759000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72549, 'Baregbeg', 'Baregbeg', 'Baregbeg', -7.4011000, 108.6828000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72550, 'Cilongkrang', 'Cilongkrang', 'Cilongkrang,Tjilongkrang', -7.4084000, 108.7127000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72551, 'Sawangan', 'Sawangan', 'Sawangan', -7.4001000, 108.7482000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72552, 'Gayamsari', 'Gayamsari', 'Gajamsari,Gayamsari', -7.4375000, 108.7324000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72553, 'Candimulya', 'Candimulya', 'Candimulya', -7.4329000, 108.7491000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72554, 'Sarimukti Kaler', 'Sarimukti Kaler', 'Sarimukti Kaler', -7.4301000, 108.7146000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72555, 'Talangbanteng', 'Talangbanteng', 'Talangbanteng', -7.4453000, 108.7035000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72556, 'Jamban', 'Jamban', 'Jamban', -7.4204000, 108.6951000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72557, 'Banjarharja', 'Banjarharja', 'Banjarharja', -7.4187000, 108.6656000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72558, 'Karangpaningal', 'Karangpaningal', 'Karangpaningal', -7.4365000, 108.6664000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72559, 'Ciherang', 'Ciherang', 'Ciherang', -7.4936000, 108.6277000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72560, 'Cakungsari', 'Cakungsari', 'Cakungsari', -7.4536000, 108.6423000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72561, 'Pangarengan', 'Pangarengan', 'Pangarengan', -7.4621900, 108.6455300, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72562, 'Purwasari', 'Purwasari', 'Purwasari', -7.4769000, 108.6409000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72563, 'Jangraga', 'Jangraga', 'Djangraga,Jangraga', -7.4872000, 108.6708000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72564, 'Sindangrasa', 'Sindangrasa', 'Sindangrasa', -7.4589000, 108.6872000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72565, 'Cogekan', 'Cogekan', 'Cogekan', -7.4896000, 108.7175000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72566, 'Pasirgaru', 'Pasirgaru', 'Pasirgaru', -7.4560000, 108.7311000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72567, 'Margasari', 'Margasari', 'Margasari', -7.4676000, 108.7449000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72568, 'Kerep Wetan', 'Kerep Wetan', 'Kerep Wetan', -6.7561000, 111.3904000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72569, 'Ringin', 'Ringin', 'Ringin', -6.7551000, 111.4640000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72570, 'Segoro', 'Segoro', 'Segoro', -6.7674000, 111.4127000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72571, 'Gondang', 'Gondang', 'Gondang', -6.7585000, 111.4281000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72572, 'Sridadi', 'Sridadi', 'Sridadi', -6.7625000, 111.4877000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72573, 'Kepohagung', 'Kepohagung', 'Kepohagung', -6.7696000, 111.4205000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72574, 'Mlawat', 'Mlawat', 'Mlawat', -6.7754000, 111.4178000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72575, 'Kembang', 'Kembang', 'Kembang', -6.7712000, 111.4311000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72576, 'Sidorejo', 'Sidorejo', 'Sidorejo', -6.7675000, 111.4741000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72577, 'Samaran', 'Samaran', 'Samaran', -6.7747000, 111.4759000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72578, 'Kapasan', 'Kapasan', 'Kapasan', -6.7773000, 111.3789000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72579, 'Mlagen', 'Mlagen', 'Mlagen', -6.7830000, 111.4244000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72580, 'Tempaling', 'Tempaling', 'Tempaling', -6.7755000, 111.4474000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72581, 'Korowelang', 'Korowelang', 'Korowelang', -6.7896000, 111.4176000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72582, 'Tempel', 'Tempel', 'Tempel', -6.7854000, 111.4484000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72583, 'Ngemplakrejo Lor', 'Ngemplakrejo Lor', 'Ngemplakrejo Lor', -6.7888000, 111.4548000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72584, 'Pragen Selatan', 'Pragen Selatan', 'Pragen Selatan', -6.7896000, 111.4651000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72585, 'Karangori Kidul', 'Karangori Kidul', 'Karangori Kidul', -6.7960000, 111.3999000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72586, 'Sambong', 'Sambong', 'Sambong', -6.7986000, 111.4202000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72587, 'Karanganyar', 'Karanganyar', 'Karanganyar', -6.7946000, 111.4282000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72588, 'Gambiran', 'Gambiran', 'Gambiran', -6.7988000, 111.4951000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72589, 'Ngemplak Kidul', 'Ngemplak Kidul', 'Ngemplak Kidul', -6.8032000, 111.3914000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72590, 'Rukem', 'Rukem', 'Rukem', -6.8029000, 111.4150000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72591, 'Demaan', 'Demaan', 'Demaan', -6.8072000, 111.4303000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72592, 'Kulutan', 'Kulutan', 'Kulutan', -6.7996000, 111.4646000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72593, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -6.8060000, 111.4605000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72594, 'Tegalsari', 'Tegalsari', 'Tegalsari', -6.8101000, 111.3797000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72595, 'Kemadu', 'Kemadu', 'Kemadu', -6.8165000, 111.3822000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72596, 'Pomahan', 'Pomahan', 'Pomahan', -6.8138000, 111.4126000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72597, 'Panohan', 'Panohan', 'Panohan', -6.8150000, 111.4370000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72598, 'Telgawah', 'Telgawah', 'Telgawah', -6.8129000, 111.4545000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72599, 'Trembes', 'Trembes', 'Trembes', -6.8101000, 111.4904000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72600, 'Ponjen', 'Ponjen', 'Ponjen', -6.8373000, 111.3864000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72601, 'Jukung', 'Jukung', 'Jukung', -6.8430000, 111.4056000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72602, 'Pesucen', 'Pesucen', 'Pesucen', -6.8541000, 111.4826000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72603, 'Pasedan Dua', 'Pasedan Dua', 'Pasedan Dua', -6.8632000, 111.3818000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72604, 'Kebon', 'Kebon', 'Kebon', -6.8598000, 111.4288000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72605, 'Kadiwono', 'Kadiwono', 'Kadiwono', -6.8601000, 111.4312000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72606, 'Timbrangan', 'Timbrangan', 'Timbrangan', -6.8598000, 111.4872000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72607, 'Sendangmulyo', 'Sendangmulyo', 'Sendangmulyo', -6.8141000, 111.4464000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72608, 'Kajar', 'Kajar', 'Kajar', -6.8821000, 111.4806000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72609, 'Ngampel', 'Ngampel', 'Ngampel', -6.8933000, 111.4417000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72610, 'Waru', 'Waru', 'Waru', -6.8894000, 111.4923000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72611, 'Kemiren', 'Kemiren', 'Kemiren', -6.8988000, 111.4685000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72612, 'Karangasem', 'Karangasem', 'Karangasem', -6.8994000, 111.4873000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72613, 'Semanten', 'Semanten', 'Semanten', -6.9150000, 111.3828000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72614, 'Geneng', 'Geneng', 'Geneng', -6.9112000, 111.4115000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72615, 'Sitirejo', 'Sitirejo', 'Sitirejo', -6.9113000, 111.4339000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72616, 'Medang', 'Medang', 'Medang', -6.9136000, 111.4396000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72617, 'Ngadipurwo', 'Ngadipurwo', 'Ngadipurwo', -6.9141000, 111.4469000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72618, 'Tempuran', 'Tempuran', 'Tempuran', -6.9116000, 111.4612000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72619, 'Kalirejo', 'Kalirejo', 'Kalirejo', -6.9231000, 111.4343000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72620, 'Karanggeneng', 'Karanggeneng', 'Karanggeneng', -6.9246000, 111.4504000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72621, 'Jatirejo', 'Jatirejo', 'Jatirejo', -6.9204000, 111.4714000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72622, 'Ngundaan', 'Ngundaan', 'Ngundaan', -6.9263000, 111.3980000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72623, 'Tambaksari Satu', 'Tambaksari Satu', 'Tambaksari Satu', -6.9340000, 111.4309000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72624, 'Bacem', 'Bacem', 'Bacem', -6.9273000, 111.4695000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72625, 'Sarirejo', 'Sarirejo', 'Sarirejo', -6.9327000, 111.4810000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72626, 'Karanganyar', 'Karanganyar', 'Karanganyar', -6.9284000, 111.4886000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72627, 'Puledagel', 'Puledagel', 'Puledagel', -6.9345000, 111.4591000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72628, 'Kawengan', 'Kawengan', 'Kawengan', -6.9387000, 111.4724000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72629, 'Gombang', 'Gombang', 'Gombang', -6.9406000, 111.4859000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72630, 'Karang', 'Karang', 'Karang', -6.9381000, 111.4968000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72631, 'Weru', 'Weru', 'Weru', -6.9475000, 111.4184000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72632, 'Patalan', 'Patalan', 'Patalan', -6.9442000, 111.4451000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72633, 'Gendangdowo', 'Gendangdowo', 'Gendangdowo', -6.9483000, 111.4562000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72634, 'Jembangan', 'Jembangan', 'Jembangan', -6.9540000, 111.3802000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72635, 'Karangjati', 'Karangjati', 'Karangjati', -6.9560000, 111.4262000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72636, 'Wonosari', 'Wonosari', 'Wonosari', -6.9516000, 111.4335000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72637, 'Gersi', 'Gersi', 'Gersi', -6.9572000, 111.4566000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72638, 'Maguwon', 'Maguwon', 'Maguwon', -6.9661000, 111.3769000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72639, 'Kunden', 'Kunden', 'Kunden', -6.9627000, 111.4117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72640, 'Kauman', 'Kauman', 'Kauman', -6.9693000, 111.4084000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72641, 'Tempelan', 'Tempelan', 'Tempelan', -6.9656000, 111.4156000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72642, 'Tegalgunung', 'Tegalgunung', 'Tegalgunung', -6.9609000, 111.4195000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72643, 'Nglaroh', 'Nglaroh', 'Nglaroh', -6.9622000, 111.4516000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72644, 'Gondang', 'Gondang', 'Gondang', -6.9635000, 111.4634000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72645, 'Nglarohgunung', 'Nglarohgunung', 'Nglarohgunung', -6.9635000, 111.4823000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72646, 'Tutup', 'Tutup', 'Tutup', -6.9705000, 111.3901000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72647, 'Kajangansawan', 'Kajangansawan', 'Kajangansawan', -6.9696000, 111.3998000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72648, 'Potlot', 'Potlot', 'Potlot', -6.9746000, 111.4071000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72649, 'Mlangsen', 'Mlangsen', 'Mlangsen', -6.9741000, 111.4152000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72650, 'Bangkle', 'Bangkle', 'Bangkle', -6.9706000, 111.4307000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72651, 'Jejerukrajan', 'Jejerukrajan', 'Jejerukrajan', -6.9751000, 111.4492000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72652, 'Seso', 'Seso', 'Seso', -6.9683000, 111.4547000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72653, 'Cangkringan', 'Cangkringan', 'Cangkringan', -6.9766000, 111.4583000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72654, 'Jeponkrajan', 'Jeponkrajan', 'Jeponkrajan', -6.9790000, 111.4790000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72655, 'Tempel', 'Tempel', 'Tempel', -6.9773000, 111.4961000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72656, 'Jetis', 'Jetis', 'Jetis', -6.9764000, 111.4102000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72657, 'Kedungjenar', 'Kedungjenar', 'Kedungjenar', -6.9758000, 111.4210000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72658, 'Karangnongko', 'Karangnongko', 'Karangnongko', -6.9871000, 111.3970000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72659, 'Sumurboto', 'Sumurboto', 'Sumurboto', -6.9822000, 111.4501000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72660, 'Turirejo', 'Turirejo', 'Turirejo', -6.9868000, 111.4646000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72661, 'Kemiri', 'Kemiri', 'Kemiri', -6.9913000, 111.4877000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72662, 'Bangeran', 'Bangeran', 'Bangeran', -6.9949000, 111.4130000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72663, 'Pelem', 'Pelem', 'Pelem', -6.9976000, 111.4327000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72664, 'Dengok', 'Dengok', 'Dengok', -6.9943000, 111.4398000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72665, 'Semampir', 'Semampir', 'Semampir', -6.9883000, 111.4828000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72666, 'Prantaan', 'Prantaan', 'Prantaan', -6.9463000, 111.4981000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72667, 'Kubang', 'Kubang', 'Koebang Dua,Kubang', -7.2738000, 108.6382000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72668, 'Cibeunying', 'Cibeunying', 'Cibeunying,Tjibeunjing Tiga', -7.2934000, 108.7441000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72669, 'Karanggedang', 'Karanggedang', 'Karanggedang', -7.3015000, 108.7249000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72670, 'Limbangan', 'Limbangan', 'Limbangan', -7.3025000, 108.7102000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72671, 'Malabar', 'Malabar', 'Malabar', -7.3041000, 108.6862000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72672, 'Cimalati', 'Cimalati', 'Cimalati,Tjimelati', -7.3056000, 108.6471000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72673, 'Babakan', 'Babakan', 'Babakan', -7.3657000, 108.6405000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72674, 'Sinargalih', 'Sinargalih', 'Sinargalih', -7.3574000, 108.6382000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72675, 'Sukahurip', 'Sukahurip', 'Sukahurip', -7.3521000, 108.6363000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72676, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.3314000, 108.6450000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72677, 'Cintaratu', 'Cintaratu', 'Cintaratu', -7.3715000, 108.6789000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72678, 'Sogati', 'Sogati', 'Sogati', -7.3279000, 108.6833000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72679, 'Cihandiwung Lor', 'Cihandiwung Lor', 'Cihandiwung Lor', -7.3337100, 108.6898300, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72680, 'Winangun', 'Winangun', 'Winangun', -7.3572000, 108.7026000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72681, 'Pacing', 'Pacing', 'Pacing', -6.7660000, 111.5331000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72682, 'Ngulahan', 'Ngulahan', 'Ngulahan', -6.7614000, 111.5272000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72683, 'Bangunrejo', 'Bangunrejo', 'Bangunrejo', -6.7751000, 111.5150000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72684, 'Bamban', 'Bamban', 'Bamban', -6.7936000, 111.5194000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72685, 'Ukir', 'Ukir', 'Ukir', -6.8042000, 111.5117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72686, 'Rendeng', 'Rendeng', 'Rendeng', -6.8099000, 111.5137000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72687, 'Tengger', 'Tengger', 'Tengger', -6.8371000, 111.5438000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72688, 'Dowan', 'Dowan', 'Dowan', -6.8396000, 111.5043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72689, 'Suntri', 'Suntri', 'Suntri', -6.8475000, 111.5081000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72690, 'Tegaldowo', 'Tegaldowo', 'Tegaldowo', -6.8563000, 111.5032000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72691, 'Jatirego', 'Jatirego', 'Jatirego', -6.8401000, 111.5204000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72692, 'Nglojo', 'Nglojo', 'Nglojo', -6.7501000, 111.6160000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72693, 'Gobreh', 'Gobreh', 'Gobreh', -6.7559000, 111.5945000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72694, 'Kedungdowo', 'Kedungdowo', 'Kedungdowo', -6.7625000, 111.5765000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72695, 'Krajankaras', 'Krajankaras', 'Krajankaras', -6.7782000, 111.5566000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72696, 'Mangseng', 'Mangseng', 'Mangseng', -6.7794000, 111.5659000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72697, 'Gesikan', 'Gesikan', 'Gesikan', -6.7785000, 111.5712000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72698, 'Sambirata', 'Sambirata', 'Sambirata', -6.7859000, 111.5744000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72699, 'Krajan Lodan Kulon', 'Krajan Lodan Kulon', 'Krajan Lodan Kulon', -6.7841000, 111.6066000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72700, 'Tanggulangin', 'Tanggulangin', 'Tanggulangin', -6.7628000, 111.6133000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72701, 'Selo', 'Selo', 'Selo', -6.7664000, 111.6096000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72702, 'Wonokerto', 'Wonokerto', 'Wonokerto', -6.8526000, 111.5848000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72703, 'Kebonharjo', 'Kebonharjo', 'Kebonharjo', -6.8640000, 111.6247000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72704, 'Krajan Sale', 'Krajan Sale', 'Krajan Sale', -6.8617000, 111.6067000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72705, 'Joho', 'Joho', 'Joho', -6.8664000, 111.5861000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72706, 'Kaduluhur', 'Kaduluhur', 'Kadoe-loehoer,Kaduluhur', -7.1928000, 108.6334000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72707, 'Palugon', 'Palugon', 'Paloegon,Palugon', -7.2319000, 108.6735000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72708, 'Sindangjati', 'Sindangjati', 'Sindangjati', -7.2435000, 108.7435000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72709, 'Gunungjaya', 'Gunungjaya', 'Gunungjaya', -7.1834000, 108.7420000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72710, 'Salanegara', 'Salanegara', 'Salanegara,Selanegara', -7.1616000, 108.7433000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72711, 'Krajanpondong', 'Krajanpondong', '', -6.7530700, 111.5638800, 'ID', '2011-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72712, 'Pakis', 'Pakis', '', -6.8243900, 111.5093300, 'ID', '2011-12-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72713, 'Dukuhmaja', 'Dukuhmaja', 'Dukuhmaja', -7.0082000, 108.6482000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72714, 'Pakusari', 'Pakusari', 'Pakusari', -7.0041000, 108.7106000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72715, 'Luragung Tonggoh', 'Luragung Tonggoh', 'Luragung Tonggoh', -7.0208000, 108.6359000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72716, 'Sindangsuka', 'Sindangsuka', 'Sindangsuka', -7.0103000, 108.6329000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72717, 'Cikadu Wetan', 'Cikadu Wetan', 'Cikadu Wetan,Tjikadoe-wetan', -7.0199000, 108.6658000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72718, 'Cileuya', 'Cileuya', 'Cileuya,Tjileuja', -7.0257000, 108.6752000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72719, 'Cimulya', 'Cimulya', 'Cimulya', -7.0202000, 108.7257000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72720, 'Cigedang', 'Cigedang', 'Cigedang,Tjigedang', -7.0280000, 108.6352000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72721, 'Sindangsari', 'Sindangsari', 'Sindangsari', -7.0309000, 108.6253000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72722, 'Wilanagara', 'Wilanagara', 'Wilanagara', -7.0378000, 108.6263000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72723, 'Baok', 'Baok', 'Baok', -7.0386000, 108.6387000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72724, 'Andamui', 'Andamui', 'Andamoei,Andamui', -7.0379000, 108.6524000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72725, 'Cirangrang', 'Cirangrang', 'Cirangrang,Tjirarang', -7.0376000, 108.7215000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72726, 'Cisaat', 'Cisaat', 'Cisaat,Tjisa''at,Tjisa’at', -7.0351000, 108.7479000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72727, 'Parenca Wetan', 'Parenca Wetan', 'Parenca Wetan', -7.0442000, 108.7293000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72728, 'Dukuhpicung', 'Dukuhpicung', 'Doekoehpitjoeng,Dukuhpicung', -7.0437000, 108.6283000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72729, 'Karangbaru', 'Karangbaru', 'Karangbaroe,Karangbaru', -7.0573000, 108.6373000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72730, 'Randusari', 'Randusari', 'Randusari', -7.0545000, 108.7086000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72731, 'Sukagalih', 'Sukagalih', 'Sukagalih', -7.0621000, 108.6802000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72732, 'Kawungsari', 'Kawungsari', 'Kawungsari', -7.0678000, 108.6957000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72733, 'Gembol', 'Gembol', 'Gembol', -7.0739000, 108.7293000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72734, 'Ciangir', 'Ciangir', 'Ciangir,Tjiangir', -7.0791000, 108.7464000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72735, 'Sukarapih', 'Sukarapih', 'Sukarapih', -7.0841000, 108.7176000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72736, 'Karangkancana', 'Karangkancana', 'Karangkancana', -7.0943000, 108.6575000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72737, 'Kaduagung', 'Kaduagung', 'Kaduagung', -7.0999000, 108.6572000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72738, 'Margacina', 'Margacina', 'Margacina', -7.1108000, 108.6449000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72739, 'Sagara', 'Sagara', 'Sagara', -7.1115000, 108.6399000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72740, 'Jabranti', 'Jabranti', 'Jabranti', -7.1198000, 108.6780000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72741, 'Jurangjero', 'Jurangjero', 'Jurangjero', -6.9035000, 111.5004000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72742, 'Krajan Jamprong', 'Krajan Jamprong', 'Krajan Jamprong', -6.9604000, 111.6157000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72743, 'Jeruk', 'Jeruk', 'Jeruk', -6.9386000, 111.5070000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72744, 'Jiworejo', 'Jiworejo', 'Jiworejo', -6.9815000, 111.5076000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72745, 'Singonegoro', 'Singonegoro', 'Singonegoro', -6.9776000, 111.5242000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72746, 'Banyubang', 'Banyubang', 'Banyubang', -6.9505000, 111.5236000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72747, 'Gembol', 'Gembol', 'Gembol', -6.9468000, 111.5383000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72748, 'Gayamdesa', 'Gayamdesa', 'Gayamdesa', -6.9257000, 111.5418000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72749, 'Wanutengah', 'Wanutengah', 'Wanutengah', -6.9248000, 111.5298000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72750, 'Blimbing', 'Blimbing', 'Blimbing', -6.9116000, 111.5355000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72751, 'Gading Barat', 'Gading Barat', 'Gading Barat', -6.8803000, 111.5599000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72752, 'Jinanten', 'Jinanten', 'Jinanten', -6.8756000, 111.5730000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72753, 'Tahunan', 'Tahunan', 'Tahunan', -6.8850000, 111.5530000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72754, 'Sendangrejo', 'Sendangrejo', 'Sendangrejo', -6.9191000, 111.5591000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72755, 'Ketringan', 'Ketringan', 'Ketringan', -6.9617000, 111.5600000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72756, 'Sukogunungkrajan', 'Sukogunungkrajan', 'Sukogunungkrajan', -6.9399000, 111.5950000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72757, 'Jlodro', 'Jlodro', 'Jlodro', -6.9274000, 111.5839000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72758, 'Kaliprak', 'Kaliprak', 'Kaliprak', -6.8864000, 111.5830000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72759, 'Bancang', 'Bancang', 'Bancang', -6.8852000, 111.5989000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72760, 'Tawaran', 'Tawaran', 'Tawaran', -6.9099000, 111.6109000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72761, 'Pasanggrahan', 'Pasanggrahan', 'Pasanggrahan,Pasanggrahan 2,Pesanggrahan', -7.3835800, 108.8710200, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72762, 'Pangawaren', 'Pangawaren', 'Pangawaren', -7.3878000, 108.8695000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72763, 'Cibatu', 'Cibatu', 'Cibatu,Tjibatoe', -7.4069000, 108.7597000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72764, 'Karangtengah', 'Karangtengah', 'Karangtengah', -7.4429000, 108.7614000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72765, 'Prumpung', 'Prumpung', 'Proempoeng,Prumpung', -7.4629900, 108.7630200, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72766, 'Kedungwringin', 'Kedungwringin', 'Kedoengwaringin,Kedungwringin', -7.4769000, 108.7680000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72767, 'Purwosari', 'Purwosari', 'Purwosari', -7.3863000, 108.7830000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72768, 'Dukuhsawah', 'Dukuhsawah', 'Doekoehsawah,Dukuhsawah', -7.4418000, 108.7818000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72769, 'Citengah', 'Citengah', 'Citengah,Tjitengah', -7.4849000, 108.7766000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72770, 'Tawangsari', 'Tawangsari', 'Tawangsari', -7.3961000, 108.8044000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72771, 'Gunungwilis', 'Gunungwilis', 'Goenoengwilis,Gunungwilis', -7.4201000, 108.8029000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72772, 'Cikalong', 'Cikalong', 'Cikalong,Tjikalong', -7.4810000, 108.7921000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72773, 'Kauman', 'Kauman', 'Kaoeman,Kauman', -7.4801000, 108.7864000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72774, 'Cikondang', 'Cikondang', 'Cikondang,Tjikondang', -7.4736000, 108.8089000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72775, 'Sidamulya', 'Sidamulya', 'Sidamoelja,Sidamulya', -7.4884000, 108.8048000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72776, 'Gendiwu', 'Gendiwu', 'Gendiwu', -7.4898000, 108.8115000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72777, 'Karangsalam', 'Karangsalam', 'Karangsalam', -7.4428000, 108.8275000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72778, 'Tambangan', 'Tambangan', 'Tambangan', -7.4860000, 108.8217000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72779, 'Cidadap', 'Cidadap', 'Cidadap,Tjidadap', -7.3976000, 108.8525000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72780, 'Rungkang', 'Rungkang', 'Roengkang,Rungkang', -7.4363000, 108.8526000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72781, 'Ciloning', 'Ciloning', 'Ciloning', -7.4746000, 108.8517000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72782, 'Karanggintung', 'Karanggintung', 'Karanggintoeng,Karanggintung', -7.4579000, 108.8590000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72783, 'Karangharjo', 'Karangharjo', 'Karangharjo', -6.6994000, 111.6254000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72784, 'Karanglincak', 'Karanglincak', 'Karanglincak', -6.7014000, 111.6282000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72785, 'Karanganyar', 'Karanganyar', 'Karanganyar', -6.7041000, 111.6312000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72786, 'Kebloran', 'Kebloran', 'Kebloran', -6.7065000, 111.6346000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72787, 'Tanjungan', 'Tanjungan', 'Tanjungan', -6.7082000, 111.6356000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72788, 'Bajingmeduro', 'Bajingmeduro', 'Bajingmeduro', -6.7392000, 111.6719000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72789, 'Sendangmulyo', 'Sendangmulyo', 'Sendangmulyo', -6.7373000, 111.6678000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72790, 'Karangmangu', 'Karangmangu', 'Karangmangu', -6.7416000, 111.6744000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72791, 'Bajingjowo', 'Bajingjowo', 'Bajingjowo', -6.7411000, 111.6709000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72792, 'Temperak', 'Temperak', 'Temperak', -6.7452000, 111.6794000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72793, 'Krajandadapmulyo', 'Krajandadapmulyo', 'Krajandadapmulyo', -6.7485000, 111.6342000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72794, 'Gonggang', 'Gonggang', 'Gonggang', -6.7357000, 111.6303000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72795, 'Ngilengan', 'Ngilengan', 'Ngilengan', -6.7228000, 111.6330000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72796, 'Banowan', 'Banowan', 'Banowan', -6.7565000, 111.6636000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72797, 'Krajanbaturno', 'Krajanbaturno', 'Krajanbaturno', -6.7657000, 111.6511000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72798, 'Babak', 'Babak', 'Babak', -6.7689000, 111.6431000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72799, 'Krajanbonjor', 'Krajanbonjor', 'Krajanbonjor', -6.7839000, 111.6394000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72800, 'Sampung', 'Sampung', 'Sampung', -6.7838000, 111.6520000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72801, 'Tawangrejo', 'Tawangrejo', 'Tawangrejo', -6.7934000, 111.6516000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72802, 'Kradenan', 'Kradenan', 'Kradenan', -6.7669000, 111.7095000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72803, 'Banjarjo', 'Banjarjo', 'Banjarjo', -6.7727000, 111.7257000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72804, 'Kelabang', 'Kelabang', 'Kelabang', -6.7799000, 111.7274000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72805, 'Boncong', 'Boncong', 'Boncong', -6.7725000, 111.7363000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72806, 'Bulumeduro', 'Bulumeduro', 'Bulumeduro', -6.7722000, 111.7303000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72807, 'Siding', 'Siding', 'Siding', -6.7990000, 111.7310000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72808, 'Jahulu', 'Jahulu', 'Jahulu', -6.8106000, 111.7459000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72809, 'Jatisari', 'Jatisari', 'Jatisari', -6.8253000, 111.7393000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72810, 'Kayen', 'Kayen', 'Kayen', -6.8253000, 111.7411000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72811, 'Ngujuran', 'Ngujuran', 'Ngujuran', -6.8235000, 111.6930000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72812, 'Weden', 'Weden', 'Weden', -6.8295000, 111.6786000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72813, 'Tengger', 'Tengger', 'Tengger', -6.7954000, 111.7115000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72814, 'Latsari', 'Latsari', 'Latsari', -6.7785000, 111.6918000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72815, 'Tlogoagung', 'Tlogoagung', 'Tlogoagung', -6.7780000, 111.6702000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72816, 'Ketodan', 'Ketodan', 'Ketodan', -6.8497000, 111.6420000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72817, 'Wangi', 'Wangi', 'Wangi', -6.8558000, 111.6312000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72818, 'Besowo', 'Besowo', 'Besowo', -6.8508000, 111.6558000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72819, 'Bader', 'Bader', 'Bader', -6.8667000, 111.6553000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72820, 'Dukuhdukuhan', 'Dukuhdukuhan', 'Dukuhdukuhan', -6.8680000, 111.7156000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72821, 'Krojo', 'Krojo', 'Krojo', -6.8602000, 111.6866000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72822, 'Karangtengah', 'Karangtengah', 'Karangtengah', -6.8791000, 111.6322000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72823, 'Paseyan', 'Paseyan', 'Paseyan', -6.8752000, 111.6413000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72824, 'Jombok', 'Jombok', 'Jombok', -6.8823000, 111.6458000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72825, 'Krajan Demit', 'Krajan Demit', 'Krajan Demit', -6.8933000, 111.6899000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72826, 'Purwosari', 'Purwosari', 'Purwosari', -6.8884000, 111.6619000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72827, 'Wotsogo', 'Wotsogo', 'Wotsogo', -6.8898000, 111.6539000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72828, 'Dingil', 'Dingil', 'Dingil', -6.9046000, 111.7087000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72829, 'Jetis', 'Jetis', 'Jetis', -6.9122000, 111.6263000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72830, 'Balong', 'Balong', 'Balong', -6.9119000, 111.6595000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72831, 'Muruni', 'Muruni', 'Muruni', -6.9126000, 111.6755000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72832, 'Ngijo', 'Ngijo', 'Ngijo', -6.9190000, 111.6859000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72833, 'Ngancar', 'Ngancar', 'Ngancar', -6.9217000, 111.6681000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72834, 'Tanggung', 'Tanggung', 'Tanggung', -6.9365000, 111.6928000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72835, 'Karanggeneng', 'Karanggeneng', 'Karanggeneng', -6.9386000, 111.6721000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72836, 'Banjarworo', 'Banjarworo', 'Banjarworo', -6.9536000, 111.7158000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72837, 'Mundri', 'Mundri', 'Mundri', -6.9558000, 111.7100000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72838, 'Nglateng Barat', 'Nglateng Barat', 'Nglateng Barat', -6.9554000, 111.6440000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72839, 'Sumuragung', 'Sumuragung', 'Sumuragung', -6.9641000, 111.7132000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72840, 'Kedungmulyo', 'Kedungmulyo', 'Kedungmulyo', -6.9569000, 111.7191000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72841, 'Laju Kidul', 'Laju Kidul', 'Ladjo Kidoel,Laju Kidul', -6.9708000, 111.7477000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72842, 'Kejuron', 'Kejuron', 'Kejuron', -6.9707000, 111.6858000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72843, 'Klakeh', 'Klakeh', 'Klakeh', -6.9783000, 111.6852000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72844, 'Talok', 'Talok', 'Talok', -6.9775000, 111.7107000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72845, 'Kablukan', 'Kablukan', 'Kablukan', -6.9845000, 111.7096000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72846, 'Ngrojo', 'Ngrojo', 'Ngrojo', -6.9817000, 111.7169000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72847, 'Kedungharjo', 'Kedungharjo', 'Kedungharjo', -6.9777000, 111.7230000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72848, 'Krajan Weden', 'Krajan Weden', 'Krajan Weden', -6.9797000, 111.7223000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72849, 'Ngembak', 'Ngembak', 'Ngembak', -6.7800000, 111.7677000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72850, 'Sembungin', 'Sembungin', 'Semboengin,Sembungin', -6.7949000, 111.7535000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72851, 'Sedandang', 'Sedandang', 'Sedandang', -6.8169000, 111.7633000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72852, 'Pugoh', 'Pugoh', 'Poegoh,Pugoh', -6.8098000, 111.7700000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72853, 'Mojoroto', 'Mojoroto', 'Mojoroto', -6.8117000, 111.7798000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72854, 'Simo', 'Simo', 'Sima,Simo', -6.8213000, 111.7751000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72855, 'Dikir', 'Dikir', 'Dikir', -6.8692000, 111.7784000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72856, 'Sriwing', 'Sriwing', 'Sriwing', -6.8250000, 111.7907000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72857, 'Plajan', 'Plajan', 'Plajan', -6.8518000, 111.7849000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72858, 'Sruki', 'Sruki', 'Sruki', -6.8073000, 111.8104000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72859, 'Cingklung', 'Cingklung', 'Cingklung', -6.8114000, 111.8117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72860, 'Pasatan', 'Pasatan', 'Pasatan', -6.8227000, 111.8146000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72861, 'Belik', 'Belik', 'Belik', -6.8297000, 111.8115000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72862, 'Gadon', 'Gadon', 'Gadon', -6.8016000, 111.8332000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72863, 'Tanjang', 'Tanjang', 'Tanjang', -6.8075000, 111.8206000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72864, 'Dukoh', 'Dukoh', 'Dukoh', -6.8205000, 111.8236000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72865, 'Karangrejo', 'Karangrejo', 'Karangrejo', -6.8020000, 111.8363000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72866, 'Tawangrejo', 'Tawangrejo', 'Tawangrejo', -6.8024000, 111.8430000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72867, 'Kenanti', 'Kenanti', 'Kenanti', -6.8023000, 111.8492000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72868, 'Klutuk', 'Klutuk', 'Klutuk', -6.8184000, 111.8387000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72869, 'Pesantren', 'Pesantren', 'Pesantren', -6.8148000, 111.8443000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72870, 'Mekarsari', 'Mekarsari', 'Mekarsari', -6.8696000, 111.8402000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72871, 'Jamong', 'Jamong', 'Jamong', -6.8016000, 111.8552000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72872, 'Sobontoro', 'Sobontoro', 'Sobontoro', -6.8006000, 111.8635000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72873, 'Sumberejo', 'Sumberejo', 'Sumberejo', -6.8109000, 111.8703000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72874, 'Ngulahan', 'Ngulahan', 'Ngoelakan,Ngulahan', -6.8771000, 111.7834000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72875, 'Gemulung', 'Gemulung', 'Gemoeloeng,Gemulung', -6.8788000, 111.8083000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72876, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -6.8777000, 111.8610000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72877, 'Bawi Kulon', 'Bawi Kulon', 'Bawi Koelon,Bawi Kulon', -6.9322000, 111.8728000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72878, 'Tanggungrejo', 'Tanggungrejo', 'Tanggungrejo', -6.9943000, 111.8522000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72879, 'Pandayan Dua', 'Pandayan Dua', 'Pandayan Dua', -6.9966000, 111.7865000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72880, 'Tawangsari', 'Tawangsari', 'Tawangsari', -6.9961000, 111.7748000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72881, 'Trantang', 'Trantang', 'Trantang', -6.8896000, 111.8158000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72882, 'Sidonganti', 'Sidonganti', 'Sidonganti', -6.9215000, 111.8216000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72883, 'Tengger', 'Tengger', 'Tengger', -6.9183000, 111.8486000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72884, 'Guwoterus', 'Guwoterus', 'Goewateroes,Guwoterus', -6.9537000, 111.8276000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72885, 'Talangkembar', 'Talangkembar', 'Talangkembar', -6.9573000, 111.8587000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72886, 'Mulyoagung', 'Mulyoagung', 'Mulyoagung', -6.9649000, 111.7878000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72887, 'Ngablak', 'Ngablak', 'Ngablak', -6.9732000, 111.7950000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72888, 'Nguluhan', 'Nguluhan', 'Ngoeloean,Nguluhan', -6.9789000, 111.8356000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72889, 'Tanggir Timur', 'Tanggir Timur', 'Tanggir Timur', -6.9809000, 111.7587000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72890, 'Bantarmangu', 'Bantarmangu', 'Bantarmangoe,Bantarmangu', -7.3393000, 108.8661000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72891, 'Cigintung', 'Cigintung', 'Cigintung', -7.3743000, 108.8043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72892, 'Mulyadadi', 'Mulyadadi', 'Mulyadadi', -7.3205000, 108.7513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72893, 'Cipasang', 'Cipasang', 'Cipasang,Tjipasang', -7.2704000, 108.7585000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72894, 'Jenang Selatan', 'Jenang Selatan', 'Jenang Selatan', -7.3002000, 108.7599000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72895, 'Tanjungsari', 'Tanjungsari', 'Tanjungsari', -7.3009000, 108.7680000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72896, 'Bojongsari', 'Bojongsari', 'Bojongsari', -7.3109000, 108.7626000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72897, 'Walahir', 'Walahir', 'Walahir', -7.2545000, 108.7837000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72898, 'Kutasari', 'Kutasari', 'Kutasari', -7.3127000, 108.7829000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72899, 'Padangsari', 'Padangsari', 'Padangsari', -7.3342000, 108.7786000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72900, 'Kubangwaru', 'Kubangwaru', 'Kubangwaru', -7.3249000, 108.8004000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72901, 'Cipeusing', 'Cipeusing', 'Cipeusing,Tjipesing', -7.2670000, 108.8116000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72902, 'Karangtengah Lor', 'Karangtengah Lor', 'Karangtengah Lor', -7.3547000, 108.8043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72903, 'Pesahangan', 'Pesahangan', 'Pesahangan', -7.2786000, 108.8277000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72904, 'Telagasari', 'Telagasari', 'Telagasari', -7.3065000, 108.8328000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72905, 'Cilempuyang', 'Cilempuyang', 'Cilempuyang', -7.3421000, 108.8333000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72906, 'Cimanggu Wetan', 'Cimanggu Wetan', 'Cimanggu Wetan', -7.3508000, 108.8405000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72907, 'Sindanghaji', 'Sindanghaji', 'Sindanghadji,Sindanghaji', -7.3608000, 108.8557000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72908, 'Ngluwuk', 'Ngluwuk', 'Luwuk,Ngluwuk', -6.8775000, 111.8752000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72909, 'Sendang', 'Sendang', 'Sendang,Sendanghaji', -6.8767000, 112.0020500, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72910, 'Margorejo', 'Margorejo', 'Margaredja,Margorejo', -6.8920000, 111.8773000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72911, 'Sumberarum', 'Sumberarum', 'Soemberaroem,Sumberarum', -6.8767000, 111.8923000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72912, 'Karangmulyo', 'Karangmulyo', 'Karangmulyo', -6.8902000, 111.9076000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72913, 'Padasan', 'Padasan', 'Padasan', -6.9037000, 111.9036000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72914, 'Temayang', 'Temayang', 'Temayang', -6.9039000, 111.8897000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72915, 'Pucangan', 'Pucangan', 'Poetjangan,Pucangan', -6.9442000, 111.9005000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72916, 'Pakel', 'Pakel', 'Pakel', -6.9567000, 111.8969000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72917, 'Bean', 'Bean', 'Bean', -6.9638000, 111.9013000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72918, 'Jetak', 'Jetak', 'Djetak,Jetak', -6.9562000, 111.9070000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72919, 'Talun', 'Talun', 'Taloen,Talun', -6.9535000, 111.9179000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72920, 'Sambonggede', 'Sambonggede', 'Sambonggede', -6.8752000, 111.9842000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72921, 'Kapu', 'Kapu', 'Kapu', -6.8888000, 111.9885000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72922, 'Jadi', 'Jadi', 'Jadi', -6.9603000, 111.9918000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72923, 'Pelang', 'Pelang', 'Pelang', -6.8956000, 111.9932000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72924, 'Balekambang', 'Balekambang', 'Balekambang', -7.2319000, 108.7661000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72925, 'Kandayakan Satu', 'Kandayakan Satu', 'Kandayakan Satu', -7.1370000, 108.7827000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72926, 'Cisitu', 'Cisitu', 'Cisitu', -7.1418900, 108.7989700, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72927, 'Cogreg', 'Cogreg', 'Cogreg', -7.1474000, 108.8017000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72928, 'Bentar', 'Bentar', 'Bentar', -7.1506000, 108.8095000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72929, 'Bentarsari', 'Bentarsari', 'Bentarsari', -7.1539000, 108.8161000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72930, 'Ganggawang', 'Ganggawang', 'Ganggawang', -7.1637000, 108.8172000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72931, 'Salem Kidul', 'Salem Kidul', 'Salem Kidul', -7.1855000, 108.8040000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72932, 'Ciputih', 'Ciputih', 'Ciputih,Tjipoetih', -7.1564000, 108.8231000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72933, 'Legoknyenang', 'Legoknyenang', 'Legoknjenang,Legoknyenang', -7.1740000, 108.8295000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72934, 'Gununglarang', 'Gununglarang', 'Gununglarang', -7.1970000, 108.8309000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72935, 'Legok', 'Legok', 'Legok', -7.2174000, 108.8301000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72936, 'Gandoang', 'Gandoang', 'Gandoang', -7.1668000, 108.8436000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72937, 'Citimbang', 'Citimbang', 'Citimbang', -7.1894000, 108.8567000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72938, 'Sukasari', 'Sukasari', 'Sukasari', -7.2346000, 108.8607000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72939, 'Kasiman', 'Kasiman', 'Kasiman', -6.8741000, 111.8862000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72940, 'Mliwang', 'Mliwang', 'Mliwang', -6.8337000, 111.8910000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72941, 'Merkawang', 'Merkawang', 'Merkawang', -6.8075000, 111.8888000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72942, 'Wadung', 'Wadung', 'Wadoeng,Wadung', -6.8144000, 111.9853000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72943, 'Karangasem', 'Karangasem', 'Karangasem', -6.8057000, 111.8916000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72944, 'Temuji', 'Temuji', 'Temadji,Temuji', -6.7919000, 111.9161000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72945, 'Tlogowaru', 'Tlogowaru', 'Telagawaroe,Tlogowaru', -6.8528000, 111.9237000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72946, 'Sumber', 'Sumber', 'Sumber', -6.8596000, 111.9831000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72947, 'Tobo', 'Tobo', 'Tobo', -6.8375000, 111.9330000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72948, 'Temandangjero', 'Temandangjero', 'Temandang,Temandangjero', -6.8626000, 111.9335000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72949, 'Pongpongan', 'Pongpongan', 'Pongpongan', -6.8715000, 111.9456000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72950, 'Banaran', 'Banaran', 'Banaran', -6.8617000, 111.9565000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72951, 'Sugihan', 'Sugihan', 'Sugihan', -6.8406000, 111.9513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72952, 'Suwalan', 'Suwalan', 'Suwalan', -6.8428000, 111.9810000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72953, 'Remen', 'Remen', 'Remen', -6.7739000, 111.9633000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72954, 'Sumurgeneng', 'Sumurgeneng', 'Soemoergeneng,Sumurgeneng', -6.8012000, 111.9609000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72955, 'Tuwiri Kulon', 'Tuwiri Kulon', 'Toewiri-Koelon,Tuwiri Kulon', -6.8733000, 111.9717000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72956, 'Borehbangle', 'Borehbangle', 'Borehbangle', -6.8665000, 111.9706000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72957, 'Mentoso', 'Mentoso', 'Mentoso', -6.7941000, 111.9811000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72958, 'Rawasan', 'Rawasan', 'Rawasan', -6.7969000, 111.9780000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72959, 'Citenjo', 'Citenjo', 'Citenjo,Tjitendjo', -7.0440000, 108.7563000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72960, 'Kliwon Cibingbin', 'Kliwon Cibingbin', 'Kliwon Cibingbin', -7.0583000, 108.7592000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72961, 'Sukasari', 'Sukasari', 'Sukasari', -7.0557000, 108.7511000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72962, 'Sindangjawa', 'Sindangjawa', 'Sindangdjawa,Sindangjawa', -7.0652000, 108.7523000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72963, 'Cipanjang', 'Cipanjang', 'Cipanjang,Tjipandjang', -7.0645000, 108.8117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72964, 'Bandungsari', 'Bandungsari', 'Bandoengsari,Bandungsari', -7.0771000, 108.8205000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72965, 'Dukuhkopi', 'Dukuhkopi', 'Dukuhkopi', -7.0142000, 108.8375000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72966, 'Kertasari', 'Kertasari', 'Kertasari', -7.0685000, 108.8290000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72967, 'Blandongan', 'Blandongan', 'Baladongan,Blandongan', -7.0886000, 108.8378000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72968, 'Pamedaran', 'Pamedaran', 'Pamedaran', -7.0680000, 108.8647000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72969, 'Kuti', 'Kuti', 'Kuti', -6.8791000, 112.0164000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72970, 'Krajan Karangsari', 'Krajan Karangsari', 'Krajan Karangsari', -6.8843000, 112.0387000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72971, 'Paloh', 'Paloh', 'Paloh', -6.8894000, 112.0542000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72972, 'Karangsari', 'Karangsari', 'Karangsari', -6.8854300, 112.0494500, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72973, 'Latsari', 'Latsari', 'Latsari', -6.8928000, 112.0461000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72974, 'Kranggan', 'Kranggan', 'Kranggan', -6.8943000, 112.0528000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72975, 'Kajongan', 'Kajongan', 'Kajongan', -6.8933000, 112.0604000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72976, 'Kutorejo', 'Kutorejo', 'Kutorejo', -6.8942000, 112.0629000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72977, 'Sendangharjo', 'Sendangharjo', 'Sendangharjo', -6.8946000, 112.0681000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72978, 'Kuncen', 'Kuncen', 'Kuncen', -6.8983000, 112.0707000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72979, 'Sukolilo', 'Sukolilo', 'Soekolilo,Sukolilo', -6.8960000, 112.0772000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72980, 'Panyuran', 'Panyuran', 'Panjoeran,Panyuran', -6.8980000, 112.0875000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72981, 'Krandenan', 'Krandenan', 'Krandenan', -6.9024000, 112.1192000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72982, 'Sumurgung', 'Sumurgung', 'Soemoergoeng,Sumurgung', -6.9082000, 112.1060000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72983, 'Prambatan', 'Prambatan', 'Prambatan', -6.8997000, 112.0942000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72984, 'Kebonsari', 'Kebonsari', 'Kebonsari', -6.9044000, 112.0645000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72985, 'Sidomukti', 'Sidomukti', 'Sidomukti', -6.9027000, 112.0582000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72986, 'Merik', 'Merik', 'Merik', -6.9021000, 112.0493000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72987, 'Kembangbilo', 'Kembangbilo', 'Kembangbilo', -6.9031000, 112.0284000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72988, 'Sugiharjo', 'Sugiharjo', 'Sugiharjo', -6.9013000, 112.0163000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72989, 'Bonggol Satu', 'Bonggol Satu', 'Bonggol Satu', -6.9011000, 112.0101000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72990, 'Taraan', 'Taraan', 'Taraan', -6.9046000, 112.0032000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72991, 'Boto', 'Boto', 'Boto', -6.9159000, 112.0017000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72992, 'Tegalagung', 'Tegalagung', 'Tegalagoeng,Tegalagung', -6.9137000, 112.0502000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72993, 'Karang', 'Karang', 'Karang', -6.9086000, 112.0558000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72994, 'Krajan Bejagung', 'Krajan Bejagung', 'Krajan Bejagung', -6.9160000, 112.0637000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72995, 'Gedongombo', 'Gedongombo', 'Gedongombo', -6.9094000, 112.0647000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72996, 'Semanding Barat', 'Semanding Barat', 'Semanding Barat', -6.9258000, 112.0648000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72997, 'Bejagung Kidul', 'Bejagung Kidul', 'Bejagung Kidul', -6.9205000, 112.0636000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72998, 'Pericik', 'Pericik', 'Pericik', -6.9229000, 112.0522000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(72999, 'Jadikrajan', 'Jadikrajan', 'Jadikrajan', -6.9292000, 112.0036000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73000, 'Bandaran', 'Bandaran', 'Bandaran', -6.9278000, 112.0570000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73001, 'Banjarsari', 'Banjarsari', 'Banjarsari', -6.9286000, 112.0989000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73002, 'Dawung', 'Dawung', 'Dawoeng,Dawung', -6.9291000, 112.1117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73003, 'Kebondempet', 'Kebondempet', 'Kebondempet', -6.9405000, 112.1004000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73004, 'Penambangan', 'Penambangan', 'Penambangan', -6.9379000, 112.0609000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73005, 'Krajan Prunggahan Wetan', 'Krajan Prunggahan Wetan', 'Krajan Prunggahan Wetan', -6.9381000, 112.0494000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73006, 'Kowang Utara', 'Kowang Utara', 'Kowang Utara', -6.9439000, 112.0864000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73007, 'Krajan Genaharjo', 'Krajan Genaharjo', 'Krajan Genaharjo', -6.9631000, 112.0707000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73008, 'Gesing', 'Gesing', 'Gesing', -6.9646000, 112.1092000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73009, 'Drudikrajan', 'Drudikrajan', 'Drudikrajan', -6.9771000, 112.0626000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73010, 'Bakung Utara', 'Bakung Utara', 'Bakung Utara', -8.2537000, 112.0704000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73011, 'Bakung', 'Bakung', 'Bakoeng,Bakung', -8.2588000, 112.0726000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73012, 'Sumberdadi', 'Sumberdadi', 'Soemberwadi,Sumberdadi', -8.2615000, 112.0641000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73013, 'Apakbranjang', 'Apakbranjang', 'Apakbranjang', -8.2671000, 112.0188000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73014, 'Plandirejo', 'Plandirejo', 'Plandiredjo,Plandirejo', -8.2667000, 112.0324000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73015, 'Tumpakoyot', 'Tumpakoyot', 'Toempakojot,Tumpakoyot', -8.2706000, 112.0409000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73016, 'Kalimeneng', 'Kalimeneng', 'Kalimeneng', -8.2843000, 112.0903000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73017, 'Kedunggajul', 'Kedunggajul', 'Kedunggajul', -8.2852000, 112.0763000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73018, 'Tumpakkepuh', 'Tumpakkepuh', 'Toempakkepoeh,Tumpakkepuh', -8.2913000, 112.1069000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73019, 'Gununggede', 'Gununggede', 'Gununggede', -8.2537000, 112.1701000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73020, 'Ngadipuro', 'Ngadipuro', 'Ngadipoero,Ngadipuro', -8.2706000, 112.2309000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73021, 'Kaligrenjeng', 'Kaligrenjeng', 'Kaligrenjeng', -8.2739000, 112.1292000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73022, 'Tambakrejo', 'Tambakrejo', 'Tambak,Tambakrejo', -8.3111000, 112.1429000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73023, 'Balerejo', 'Balerejo', 'Balerejo', -8.2542000, 112.3000000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73024, 'Sumbersih', 'Sumbersih', 'Soembersih,Sumbersih', -8.3249000, 112.2597000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73025, 'Sukorejo', 'Sukorejo', 'Soekoredjo,Sukorejo', -8.2754000, 112.3608000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73026, 'Ringinrejo', 'Ringinrejo', 'Ringinredjo,Ringinrejo', -8.2765000, 112.3483000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73027, 'Kaligambir', 'Kaligambir', 'Kaligambir', -8.2790000, 112.2760000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73028, 'Purworejo', 'Purworejo', 'Purworejo', -8.2685000, 112.3227000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73029, 'Tulungrejo', 'Tulungrejo', 'Toeloengredjo,Tulungrejo', -8.2697000, 112.3302000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73030, 'Wates', 'Wates', 'Wates', -8.2538000, 112.3763000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73031, 'Cendoro Utara', 'Cendoro Utara', 'Cendoro Utara', -6.9294000, 112.1346000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73032, 'Pucangkrajan', 'Pucangkrajan', 'Pucangkrajan', -6.9222000, 112.1412000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73033, 'Bogorejo', 'Bogorejo', 'Bogorejo', -6.9077000, 112.1485000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73034, 'Leran Kulon', 'Leran Kulon', 'Leran Kulon', -6.9230000, 112.1507000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73035, 'Ngimbang', 'Ngimbang', 'Ngimbang', -6.9635000, 112.1439000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73036, 'Leran Wetan', 'Leran Wetan', 'Leran Wetan', -6.9230000, 112.1543000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73037, 'Banjaranyar', 'Banjaranyar', 'Banjaranyar', -6.9013000, 112.1538000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73038, 'Karangagung Timur', 'Karangagung Timur', 'Karangagung Timur', -6.8997000, 112.1677000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73039, 'Wangun', 'Wangun', 'Wangoen,Wangun', -6.9290000, 112.1663000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73040, 'Sumberjo', 'Sumberjo', 'Soemberredjo,Sumberjo', -6.9977000, 112.1668000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73041, 'Karang Lor', 'Karang Lor', 'Karang Lor', -6.9203000, 112.1707000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73042, 'Pliwetan', 'Pliwetan', 'Pliwetan', -6.9042000, 112.1716000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73043, 'Tambakrejo', 'Tambakrejo', 'Tambakrejo', -6.9002000, 112.1753000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73044, 'Setro', 'Setro', 'Setro', -6.9241000, 112.1875000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73045, 'Sidomukti', 'Sidomukti', 'Sidomukti', -6.9081000, 112.1968000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73046, 'Labuhan', 'Labuhan', 'Laboehan,Labuhan', -6.8844000, 112.2051000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73047, 'Boho', 'Boho', 'Boho', -6.9075000, 112.2093000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73048, 'Brengkok', 'Brengkok', 'Brengkok', -6.8956000, 112.2178000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73049, 'Lembor', 'Lembor', 'Lembor', -6.9277000, 112.2347000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73050, 'Dateng', 'Dateng', 'Dateng', -6.9765000, 112.2314000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73051, 'Jabung', 'Jabung', 'Djaboeng,Jabung', -6.9963000, 112.2295000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73052, 'Gelap', 'Gelap', 'Gelap', -6.9749000, 112.2378000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73053, 'Sendangharjo', 'Sendangharjo', 'Sendangharjo', -6.9196000, 112.2411000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73054, 'Tlogosari', 'Tlogosari', 'Telogosari,Tlogosari', -8.2810000, 112.4733000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73055, 'Tugurejo Satu', 'Tugurejo Satu', 'Toegoeredjo 1,Tugurejo Satu', -8.2890000, 112.3803000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73056, 'Kalisangkrah Lor', 'Kalisangkrah Lor', 'Kalisangkrah Lor', -8.2852000, 112.3885000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73057, 'Krajan Kulon Purworejo', 'Krajan Kulon Purworejo', 'Krajan Kulon Purworejo', -8.2870000, 112.3952000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73058, 'Mentaraman Satu', 'Mentaraman Satu', 'Mataraman 1,Mentaraman Satu', -8.3049000, 112.4246000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73059, 'Tempursarikrajan', 'Tempursarikrajan', 'Tempursarikrajan', -8.3016000, 112.4398000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73060, 'Banjarejo', 'Banjarejo', 'Bandjairedjo,Banjarejo', -8.3161000, 112.4829000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73061, 'Tulungrejo', 'Tulungrejo', 'Toeloengredjo,Tulungrejo', -8.3317000, 112.4940000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73062, 'Krajan Kedungsalam', 'Krajan Kedungsalam', 'Krajan Kedungsalam', -8.3251000, 112.4501000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73063, 'Blimbing', 'Blimbing', 'Blimbing', -6.8762000, 112.2962000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73064, 'Sedayulawas', 'Sedayulawas', 'Sedayulawas,Sidajoelawas', -6.8800000, 112.2726000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73065, 'Tunggul', 'Tunggul', 'Tunggul', -6.8759000, 112.3739000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73066, 'Brangsi', 'Brangsi', 'Brangsi', -6.9726000, 112.3667000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73067, 'Sawo', 'Sawo', 'Sawo,Sawoe', -6.9693000, 112.3746000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73068, 'Sumurgayam', 'Sumurgayam', 'Sumurgayam', -6.8850000, 112.3437000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73069, 'Solokuro', 'Solokuro', 'Solokuro', -6.9334000, 112.3561000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73070, 'Karangwungu Lor', 'Karangwungu Lor', 'Karangwoengoe Lor,Karangwungu Lor', -6.9959000, 112.3654000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73071, 'Kaligerman', 'Kaligerman', 'Kaligerman', -6.9985000, 112.3289000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73072, 'Pilang', 'Pilang', 'Pilang', -6.9876000, 112.3417000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73073, 'Karangrejo', 'Karangrejo', 'Karangrejo', -6.9927000, 112.3221000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73074, 'Turi', 'Turi', 'Toeri,Turi', -6.9877000, 112.3043000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73075, 'Kanugrahan', 'Kanugrahan', 'Kanoegrahan,Kanugrahan', -6.9920000, 112.2987000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73076, 'Jangkungkusumo', 'Jangkungkusumo', 'Jangkungkusumo', -6.9873000, 112.2846000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73077, 'Pelangwot', 'Pelangwot', 'Pelangwot', -6.9856000, 112.2793000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73078, 'Sumberagung', 'Sumberagung', 'Soemberagoeng,Sumberagung', -6.8940000, 112.2949000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73079, 'Sendangduwur', 'Sendangduwur', 'Sendangduwur', -6.8963000, 112.3473000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73080, 'Sendangagung', 'Sendangagung', 'Sendangagung', -6.8994000, 112.3461000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73081, 'Payaman', 'Payaman', 'Payaman', -6.9169000, 112.3528000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73082, 'Sugihan', 'Sugihan', 'Sugihan', -6.9157000, 112.3270000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73083, 'Dadapan', 'Dadapan', 'Dadapan', -6.9222000, 112.3145000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73084, 'Tebluru', 'Tebluru', 'Tebluru', -6.9261000, 112.3208000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73085, 'Tenggulun', 'Tenggulun', 'Tenggulun', -6.9345000, 112.3361000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73086, 'Karangtawar', 'Karangtawar', 'Karangtawar', -6.9645000, 112.3387000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73087, 'Godog', 'Godog', 'Godog', -6.9633000, 112.3487000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73088, 'Bulubrangsi', 'Bulubrangsi', 'Bulubrangsi', -6.9632000, 112.3540000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73089, 'Prijek', 'Prijek', 'Prijek', -6.9723000, 112.3251000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73090, 'Blumbang', 'Blumbang', 'Bloembang,Blumbang', -6.9726000, 112.3088000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73091, 'Gedangan', 'Gedangan', 'Gedangan', -6.9689000, 112.2995000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73092, 'Parengan', 'Parengan', 'Parengan', -6.9822000, 112.2864000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73093, 'Pangkatrejo', 'Pangkatrejo', 'Pangkatrejo', -6.9815000, 112.2919000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73094, 'Pringgoboyo', 'Pringgoboyo', 'Pringgoboyo', -6.9813000, 112.2969000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73095, 'Taman', 'Taman', 'Taman', -6.9776000, 112.3149000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73096, 'Tracal', 'Tracal', 'Tracal', -6.9824000, 112.3381000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73097, 'Jagran', 'Jagran', 'Jagran', -6.9987000, 112.3539000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73098, 'Klagen', 'Klagen', 'Klagen', -6.9990000, 112.3509000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73099, 'Sempolkrajan', 'Sempolkrajan', 'Sempolkrajan', -8.2546000, 112.5025000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73100, 'Pandanrejokrajan', 'Pandanrejokrajan', 'Pandanredjo,Pandanrejokrajan', -8.3047000, 112.5039000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73101, 'Bandungrejo', 'Bandungrejo', 'Bandoengredjo,Bandungrejo', -8.3044000, 112.5123000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73102, 'Sumberkertokrajan', 'Sumberkertokrajan', 'Soemberkerto,Sumberkertokrajan,Sunberkertokrajan', -8.2693000, 112.5218000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73103, 'Krajan Sumberbening', 'Krajan Sumberbening', 'Krajan Sumberbening', -8.3334000, 112.5422000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73104, 'Krajan Srigonco', 'Krajan Srigonco', 'Krajan Srigonco,Srigantja', -8.3418000, 112.5618000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73105, 'Pringgodanikrajan', 'Pringgodanikrajan', 'Pringgodani,Pringgodanikrajan', -8.2744000, 112.5613000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73106, 'Banturkrajan', 'Banturkrajan', 'Banturkrajan', -8.3068000, 112.5763000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73107, 'Wonorejo', 'Wonorejo', 'Wonoredjo,Wonorejo', -8.3178000, 112.5741000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73108, 'Gombangan', 'Gombangan', 'Gombangan', -8.3519000, 112.5878000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73109, 'Krajan Rejosari', 'Krajan Rejosari', 'Krajan Rejosari', -8.2745000, 112.5987000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73110, 'Ketangi', 'Ketangi', 'Ketangi', -6.7482000, 111.4084000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73111, 'Banjaranyar', 'Banjaranyar', 'Banjaranyar', -6.8775000, 112.3902000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73112, 'Paloh', 'Paloh', 'Paloh', -6.8776000, 112.4484000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73113, 'Weru', 'Weru', 'Weroe,Weru', -6.8801000, 112.4509000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73114, 'Sidokumpul', 'Sidokumpul', 'Sidokeompoel,Sidokumpul', -6.8823000, 112.4533000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73115, 'Waru Lor', 'Waru Lor', 'Waru Lor', -6.8835000, 112.4544000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73116, 'Campurrejo', 'Campurrejo', 'Campurrejo,Tjampoerredjo', -6.8843000, 112.4529000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73117, 'Doudo', 'Doudo', 'Dahoedo,Doudo', -6.9564000, 112.4989000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73118, 'Wotan', 'Wotan', 'Wotan', -6.9594000, 112.4862000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73119, 'Gedangan', 'Gedangan', 'Gedangan', -6.9699000, 112.4964000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73120, 'Sambogunung', 'Sambogunung', 'Sambogunung', -6.9885000, 112.4978000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73121, 'Babakbawo', 'Babakbawo', 'Babakbawo', -6.9886000, 112.4872000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73122, 'Saniwonorejo', 'Saniwonorejo', 'Saniwonorejo', -6.9842000, 112.4909000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73123, 'Madumulyorejo', 'Madumulyorejo', 'Madumulyorejo', -6.9980000, 112.4485000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73124, 'Kediren', 'Kediren', 'Kediren', -6.9949000, 112.4056000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73125, 'Karangcangkring', 'Karangcangkring', 'Karangcangkring', -6.9852000, 112.3776000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73126, 'Pangansalan', 'Pangansalan', 'Pangansalan', -6.9919000, 112.3847000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73127, 'Gedongkedoan', 'Gedongkedoan', 'Gedongkedoan', -6.9860000, 112.3823000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73128, 'Banyutengah', 'Banyutengah', 'Banyutengah', -6.8919000, 112.4528000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73129, 'Delegan', 'Delegan', 'Delegan', -6.9008000, 112.4626000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73130, 'Tlogosadang', 'Tlogosadang', 'Tlogosadang', -6.8870000, 112.4429000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73131, 'Watuguling', 'Watuguling', 'Watuguling', -6.9187000, 112.4530000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73132, 'Pantenan', 'Pantenan', 'Pantenan', -6.9199000, 112.4381000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73133, 'Ketanen', 'Ketanen', 'Ketanen', -6.9252000, 112.4415000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73134, 'Bluri', 'Bluri', 'Bluri', -6.9145000, 112.4206000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73135, 'Dagan', 'Dagan', 'Dagan', -6.9164000, 112.4117000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73136, 'Banyubang', 'Banyubang', 'Banyubang', -6.9261000, 112.4148000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73137, 'Takerharjo', 'Takerharjo', 'Takerhardjo,Takerharjo', -6.9407000, 112.4116000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73138, 'Siwalan', 'Siwalan', 'Siwalan', -6.9390000, 112.4343000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73139, 'Gampeng', 'Gampeng', 'Gampeng', -6.9365000, 112.4530000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73140, 'Sumurber', 'Sumurber', 'Soemoerber,Sumurber', -6.9495000, 112.4288000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73141, 'Serah', 'Serah', 'Serah', -6.9490000, 112.4439000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73142, 'Sukodono', 'Sukodono', 'Sukodono', -6.9586000, 112.4567000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73143, 'Wonokerto', 'Wonokerto', 'Wonokerto', -6.9685000, 112.3975000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73144, 'Lowayu', 'Lowayu', 'Lowayu', -6.9737000, 112.4192000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73145, 'Petung', 'Petung', 'Petung', -6.9725000, 112.4776000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73146, 'Imaan', 'Imaan', 'Imaan', -6.9849000, 112.4737000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73147, 'Mojopetung', 'Mojopetung', 'Mojopetung', -6.9803000, 112.4678000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73148, 'Mentaras', 'Mentaras', 'Mentaras', -6.9816000, 112.4469000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73149, 'Tebuwung', 'Tebuwung', 'Tebuwung', -6.9813000, 112.4398000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73150, 'Jetis', 'Jetis', 'Jetis', -6.9776000, 112.4323000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73151, 'Bangeran', 'Bangeran', 'Bangeran', -6.9817000, 112.4048000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73152, 'Bulangan', 'Bulangan', 'Bulangan', -6.9788000, 112.3918000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73153, 'Kemantren', 'Kemantren', 'Kemantren', -6.8753000, 112.4030000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73154, 'Butungan', 'Butungan', 'Butungan', -6.9936000, 112.3940000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73155, 'Tiremenggal', 'Tiremenggal', 'Tiremenggal', -6.9979000, 112.4263000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73156, 'Prupuh', 'Prupuh', 'Proepoeh,Prupuh', -6.9127000, 112.4578000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73157, 'Sumampir', 'Sumampir', 'Sumampir', -6.9998000, 112.4436000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73158, 'Canga’an', 'Canga''an', 'Canga''an,Canga’an,Tjangakan', -6.9218000, 112.5058000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73159, 'Lasem', 'Lasem', 'Lasem', -6.9889000, 112.5075000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73160, 'Gupakan', 'Gupakan', 'Gupakan', -6.9997000, 112.5089000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73161, 'Kertosonopilang', 'Kertosonopilang', 'Kertosonopilang', -6.9856000, 112.5206000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73162, 'Asempapak', 'Asempapak', 'Asempapak', -6.9950000, 112.5642000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73163, 'Mojoasem', 'Mojoasem', 'Modjoasem,Mojoasem', -6.9965000, 112.5728000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73164, 'Asemanis', 'Asemanis', 'Asemanis', -6.9987000, 112.5755000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73165, 'Kemeduran', 'Kemeduran', 'Kemeduran', -6.9160000, 112.5575000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73166, 'Banyulegi', 'Banyulegi', 'Banyulegi', -6.9123000, 112.5310000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73167, 'Gosari', 'Gosari', 'Gosari', -6.9391000, 112.5095000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73168, 'Kebonagung', 'Kebonagung', 'Kebonagung', -6.9435000, 112.5322000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73169, 'Karangrejo', 'Karangrejo', 'Karangredjo,Karangrejo', -6.9523000, 112.5551000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73170, 'Ketapang', 'Ketapang', 'Ketapang,Ketapang Lor', -6.9589000, 112.5545000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73171, 'Bolo', 'Bolo', 'Bolo', -6.9621000, 112.5233000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73172, 'Wadeng', 'Wadeng', 'Wadeng', -6.9664000, 112.5139000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73173, 'Sambipondok', 'Sambipondok', 'Sambipondok', -6.9720000, 112.5250000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73174, 'Glatik', 'Glatik', 'Glatik', -6.9710000, 112.5386000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73175, 'Srowo', 'Srowo', 'Srowo', -6.9838000, 112.5644000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73176, 'Purwodadi', 'Purwodadi', 'Purwodadi', -6.9856000, 112.5623000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73177, 'Sedagaran', 'Sedagaran', 'Sedagaran', -6.9857000, 112.5651000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73178, 'Pengulu', 'Pengulu', 'Pengulu', -6.9872000, 112.5634000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73179, 'Kauman', 'Kauman', 'Kaoeman,Kauman', -6.9901000, 112.5632000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73180, 'Mriyunan', 'Mriyunan', 'Mriyunan', -6.9902000, 112.5664000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73181, 'Bunderan', 'Bunderan', 'Bunderan', -6.9908000, 112.5614000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73182, 'Wonocoyo Utara', 'Wonocoyo Utara', 'Wonocoyo Utara', -8.2511000, 111.4538000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73183, 'Nglebeng', 'Nglebeng', 'Nglebeng', -8.2562000, 111.4541000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73184, 'Krajan Ngrambingan', 'Krajan Ngrambingan', 'Krajan Ngrambingan', -8.2595000, 111.4889000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73185, 'Banjar', 'Banjar', 'Banjar', -8.2676000, 111.4799000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73186, 'Ngulung Wetan', 'Ngulung Wetan', 'Ngulung Wetan', -8.2928000, 111.4867000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73187, 'Bangil', 'Bangil', 'Bangil', -8.1357000, 111.3953000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73188, 'Sendang', 'Sendang', 'Sendang', -8.1440000, 111.4392000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73189, 'Depok', 'Depok', 'Depok', -8.1878000, 111.4425000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73190, 'Sunduk', 'Sunduk', 'Sunduk', -8.1879000, 111.4182000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73191, 'Ketanggung', 'Ketanggung', 'Ketanggung', -8.1953000, 111.3815000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73192, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.2471000, 111.3803000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73193, 'Ngangkruk', 'Ngangkruk', 'Ngangkruk', -8.2368000, 111.4118000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73194, 'Gayam', 'Gayam', 'Gayam', -8.2348000, 111.4513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73195, 'Kertosono', 'Kertosono', 'Kertosono', -8.2183000, 111.4504000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73196, 'Ngromo', 'Ngromo', 'Ngromo', -8.2025000, 111.4181000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73197, 'Karangtengah', 'Karangtengah', 'Karangtengah', -8.2136000, 111.4277000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73198, 'Puyung', 'Puyung', 'Puyung', -8.1272000, 111.4956000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73199, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.1346000, 111.4813000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73200, 'Plalar', 'Plalar', 'Plalar', -8.1840000, 111.4853000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73201, 'Banteng', 'Banteng', 'Banteng', -8.2056000, 111.4824000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73202, 'Sawahan', 'Sawahan', 'Sawahan', -8.2133000, 111.4752000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73203, 'Ngrencak', 'Ngrencak', 'Ngrencak', -8.2384000, 111.4641000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73204, 'Kebonagung', 'Kebonagung', 'Kebonagoeng,Kebonagung', -8.2355000, 111.4567000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73205, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.2151000, 111.4578000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73206, 'Barang', 'Barang', 'Barang', -8.2178000, 111.4668000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73207, 'Gajahrejo Krajan', 'Gajahrejo Krajan', 'Gajahrejo Krajan', -8.3413000, 112.6493000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73208, 'Gedangan', 'Gedangan', 'Gedangan', -8.2949000, 112.6517000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73209, 'Sumbergesing Wetan', 'Sumbergesing Wetan', 'Sumbergesing Wetan', -8.2986000, 112.6602000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73210, 'Krajan Sidodadi', 'Krajan Sidodadi', 'Krajan Sidodadi', -8.3702000, 112.6580000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73211, 'Ringinsari Krajan', 'Ringinsari Krajan', 'Ringinsari Krajan', -8.2773000, 112.6755000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73212, 'Argotirto Krajan', 'Argotirto Krajan', 'Argotirto Krajan', -8.2885000, 112.6884000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73213, 'Sumbermanjing Krajan', 'Sumbermanjing Krajan', 'Sumbermanjing Krajan', -8.2604000, 112.6858000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73214, 'Kedungbanteng Krajan', 'Kedungbanteng Krajan', 'Kedungbanteng Krajan', -8.3666000, 112.7135000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73215, 'Krajan Harjokuncaran', 'Krajan Harjokuncaran', 'Krajan Harjokuncaran', -8.2639000, 112.7035000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73216, 'Ringin Kembar', 'Ringin Kembar', 'Ringin Kembar', -8.2779000, 112.7275000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73217, 'Donorejo', 'Donorejo', 'Donorejo', -8.2808000, 112.7421000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73218, 'Sidomulyo Kulon', 'Sidomulyo Kulon', 'Sidomulyo Kulon', -8.3512000, 112.7438000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73219, 'Wirotaman', 'Wirotaman', 'Wirotaman', -8.2529000, 112.8514000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73220, 'Boncis', 'Boncis', 'Boncis', -8.2635000, 112.8698000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73221, 'Sekarbanyu', 'Sekarbanyu', 'Sekarbanyu', -8.2633000, 112.7525000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73222, 'Panggungsari', 'Panggungsari', 'Panggungsari', -8.2682000, 112.8082000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73223, 'Sumberarum', 'Sumberarum', 'Sumberarum', -8.2671000, 112.7772000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73224, 'Sumbersarikrajan', 'Sumbersarikrajan', 'Sumbersarikrajan', -8.2995000, 112.8410000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73225, 'Sawur Tengah', 'Sawur Tengah', 'Sawur Tengah', -8.3015000, 112.7819000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73226, 'Gampingan', 'Gampingan', 'Gampingan', -8.3078000, 112.8470000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73227, 'Purwodadi Lor', 'Purwodadi Lor', 'Purwodadi Lor', -8.3536000, 112.8452000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73228, 'Kaliuling', 'Kaliuling', 'Kalioeling,Kaliuling', -8.2670000, 112.9513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73229, 'Tempursari', 'Tempursari', 'Tempoersari,Tempursari', -8.2864000, 112.9791000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73230, 'Krajan Pundungsari', 'Krajan Pundungsari', 'Krajan Pundungsari', -8.2791000, 112.9733000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73231, 'Krajan Tempursari', 'Krajan Tempursari', 'Krajan Tempursari', -8.2915000, 112.9741000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73232, 'Glagahan', 'Glagahan', 'Glagahan', -8.2969000, 112.9528000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73233, 'Krajan Satu B Lebakharjo', 'Krajan Satu B Lebakharjo', 'Krajan Satu B Lebakharjo', -8.3016000, 112.9033000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73234, 'Purorejo', 'Purorejo', 'Purorejo', -8.3041000, 112.9473000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73235, 'Umbulsari', 'Umbulsari', 'Umbulsari', -8.3075000, 112.9503000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73236, 'Tegalrejo', 'Tegalrejo', 'Tegalrejo', -8.3294000, 112.9513000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73237, 'Sumberwongso', 'Sumberwongso', 'Sumberwongso', -8.2616000, 113.2247000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73238, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.2588000, 113.2706000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73239, 'Wotgalih', 'Wotgalih', 'Wotgalih', -8.2700000, 113.2793000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73240, 'Tanjungrejo Lor', 'Tanjungrejo Lor', 'Tanjungrejo Lor', -8.2661000, 113.3074000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73241, 'Krajan Dua Keting', 'Krajan Dua Keting', 'Krajan Dua Keting', -8.2625000, 113.3267000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73242, 'Igir-igir', 'Igir-igir', 'Igir-igir', -8.2834000, 113.3361000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73243, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.3105000, 113.3317000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73244, 'Kraton', 'Kraton', 'Kraton', -8.2997000, 113.3489000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73245, 'Kepanjen', 'Kepanjen', 'Kepanjen', -8.3436000, 113.3728000, 'ID', '2012-01-22', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73246, 'Krajan Tengah', 'Krajan Tengah', 'Krajan Tengah', -8.0163000, 111.3796000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73247, 'Krajan Tugurejo', 'Krajan Tugurejo', 'Krajan Tugurejo', -8.0361000, 111.3893000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73248, 'Broto', 'Broto', 'Broto', -8.0210000, 111.4100000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73249, 'Melikan', 'Melikan', 'Melikan', -8.0065000, 111.4141000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73250, 'Banggel', 'Banggel', 'Banggel', -8.0014000, 111.4220000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73251, 'Maron', 'Maron', 'Maron', -8.0059000, 111.4216000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73252, 'Krajan Menggare', 'Krajan Menggare', 'Krajan Menggare', -8.0138000, 111.4166000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73253, 'Dawang', 'Dawang', 'Dawang', -8.0353000, 111.4145000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73254, 'Krajan Caluk', 'Krajan Caluk', 'Krajan Caluk', -8.0381000, 111.3975000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73255, 'Krajan Senepo', 'Krajan Senepo', 'Krajan Senepo', -8.0435000, 111.3934000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73256, 'Klatakan', 'Klatakan', 'Klatakan', -8.0069000, 111.4619000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73257, 'Kudo', 'Kudo', 'Kudo', -8.0058000, 111.4526000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73258, 'Gabahan', 'Gabahan', 'Gabahan', -8.0186000, 111.4525000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73259, 'Beluk', 'Beluk', 'Beluk', -8.0041000, 111.4465000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73260, 'Nambak Tengah', 'Nambak Tengah', 'Nambak Tengah', -8.0090000, 111.4462000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73261, 'Bugis', 'Bugis', 'Bugis', -8.0198000, 111.4441000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73262, 'Tiron', 'Tiron', 'Tiron', -8.0300000, 111.4537000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73263, 'Munung', 'Munung', 'Munung', -8.0294000, 111.4627000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73264, 'Setono', 'Setono', 'Setono', -8.0083000, 111.4321000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73265, 'Krajan Mrayan', 'Krajan Mrayan', 'Krajan Mrayan', -8.0846000, 111.3851000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73266, 'Ngembel', 'Ngembel', 'Ngembel', -8.0894000, 111.4146000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73267, 'Krajan Selur', 'Krajan Selur', 'Krajan Selur', -8.0942000, 111.4699000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73268, 'Nglorogan', 'Nglorogan', 'Nglorogan', -8.0935000, 111.4626000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73269, 'Gununglincingkrajan', 'Gununglincingkrajan', 'Gununglincingkrajan', -8.2558000, 113.4302000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73270, 'Karangduren Dua', 'Karangduren Dua', 'Karangduren Dua', -8.2717000, 113.4939000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73271, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.2641000, 113.4477000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73272, 'Kebonsari Kidul', 'Kebonsari Kidul', 'Kebonsari Kidul', -8.2766000, 113.4518000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73273, 'Rejosarikrajan', 'Rejosarikrajan', 'Rejosarikrajan', -8.2796000, 113.4288000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73274, 'Kesambilerenkrajan', 'Kesambilerenkrajan', 'Kesambilerenkrajan', -8.2794000, 113.4073000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73275, 'Grendenkrajan Satu', 'Grendenkrajan Satu', 'Grendenkrajan Satu', -8.3344000, 113.4728000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73276, 'Krebetkrajan', 'Krebetkrajan', 'Krebetkrajan', -8.2967000, 113.3967000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73277, 'Wringintelu', 'Wringintelu', 'Wringinteloe,Wringintelu', -8.2875000, 113.4777000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73278, 'Kedungsumurkrajan', 'Kedungsumurkrajan', 'Kedungsumurkrajan', -8.2867000, 113.4874000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73279, 'Krajan A Wonorejo', 'Krajan A Wonorejo', 'Krajan A Wonorejo', -8.2864000, 113.3819000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73280, 'Krajan C Wonorejo', 'Krajan C Wonorejo', 'Krajan C Wonorejo', -8.2901000, 113.3862000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73281, 'Purwoharjokrajan Satu', 'Purwoharjokrajan Satu', 'Purwoharjokrajan Satu', -8.3166000, 113.4826000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73282, 'Krajan Timur Mlokorejo', 'Krajan Timur Mlokorejo', 'Krajan Timur Mlokorejo', -8.3081000, 113.4586000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73283, 'Ampeldentokrajan', 'Ampeldentokrajan', 'Ampeldentokrajan', -8.3080000, 113.4337000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73284, 'Kebonan', 'Kebonan', 'Kebonan', -8.3122000, 113.4079000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73285, 'Munengkrajan', 'Munengkrajan', 'Munengkrajan', -8.3365000, 113.3842000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73286, 'Mojomulyokrajan', 'Mojomulyokrajan', 'Mojomulyokrajan', -8.3445000, 113.4296000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73287, 'Mojosarikrajan', 'Mojosarikrajan', 'Mojosarikrajan', -8.3553000, 113.4466000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73288, 'Krajan Puger Wetan', 'Krajan Puger Wetan', 'Krajan Puger Wetan', -8.3728000, 113.4791000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73289, 'Kauman', 'Kauman', 'Kauman', -8.3722000, 113.4759000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73290, 'Menampukrajan', 'Menampukrajan', 'Menampukrajan', -8.3307000, 113.4145000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73291, 'Krajan Lor Gumelar', 'Krajan Lor Gumelar', 'Kradjan-lor,Krajan Lor Gumelar', -8.2546000, 113.5515000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73292, 'Sumberejo', 'Sumberejo', 'Sumberejo', -8.3970000, 113.5920000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73293, 'Gunungsari', 'Gunungsari', 'Goenoengsari,Gunungsari', -8.2622000, 113.5656000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73294, 'Lohong', 'Lohong', 'Lohong', -8.2714000, 113.5055000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73295, 'Glundengankrajan', 'Glundengankrajan', 'Glundengankrajan', -8.2810000, 113.5567000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73296, 'Tutul', 'Tutul', 'Toetoel,Tutul', -8.2836000, 113.5196000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73297, 'Krajan Lor Balung Kulon', 'Krajan Lor Balung Kulon', 'Krajan Lor Balung Kulon', -8.2897000, 113.5293000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73298, 'Balungkopi', 'Balungkopi', 'Balungkopi', -8.2902000, 113.5421000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73299, 'Kemuning', 'Kemuning', 'Kemoening,Kemuning', -8.2919000, 113.6227000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73300, 'Darungan', 'Darungan', 'Darungan', -8.2987000, 113.5076000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73301, 'Krajan Kertonegoro', 'Krajan Kertonegoro', 'Krajan Kertonegoro', -8.3082000, 113.6154000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73302, 'Penitik', 'Penitik', 'Penitik', -8.3252000, 113.5035000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73303, 'Kebonsari', 'Kebonsari', 'Kebonsari', -8.3187000, 113.5266000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73304, 'Karanganyarkrajan', 'Karanganyarkrajan', 'Karanganyarkrajan', -8.3208000, 113.6123000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73305, 'Krajan Wetan Tanjungrejo', 'Krajan Wetan Tanjungrejo', 'Krajan Wetan Tanjungrejo', -8.3439000, 113.5678000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73306, 'Sumberan', 'Sumberan', 'Soemberan,Sumberan', -8.3426000, 113.6060000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73307, 'Kesilirkrajan', 'Kesilirkrajan', 'Kesilirkrajan', -8.3436000, 113.5825000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73308, 'Bonsari', 'Bonsari', 'Bonsari', -8.3729000, 113.6036000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73309, 'Sambiringkik', 'Sambiringkik', 'Sambiringkik', -8.3558000, 113.5376000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73310, 'Dukuhsia', 'Dukuhsia', 'Dukuhsia', -8.1953000, 113.6183000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73311, 'Curahlele Wetan', 'Curahlele Wetan', 'Curahlele Wetan', -8.2452000, 113.5464000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73312, 'Gludug', 'Gludug', 'Gloedoeg,Gludug', -8.1394000, 113.5974000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73313, 'Dukuh Dua', 'Dukuh Dua', 'Dukuh Dua', -8.1645000, 113.5609000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73314, 'Andongsari', 'Andongsari', 'Andongsari', -8.1697000, 113.5505000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73315, 'Kemuningsari', 'Kemuningsari', 'Kemuningsari', -8.1741000, 113.6031000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73316, 'Gugut', 'Gugut', 'Gloegoet,Gugut', -8.1838000, 113.6121000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73317, 'Bangsalsari', 'Bangsalsari', 'Bangsalsari', -8.2029000, 113.5346000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73318, 'Langkap', 'Langkap', 'Langkap', -8.2028000, 113.5560000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73319, 'Jetis', 'Jetis', 'Djetis,Jetis', -8.2010000, 113.5648000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73320, 'Pecoro', 'Pecoro', 'Pecara,Pecoro', -8.2089000, 113.5911000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73321, 'Sukorejo', 'Sukorejo', 'Soekaredja,Sukorejo', -8.2227000, 113.5291000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73322, 'Bedadung Kulon', 'Bedadung Kulon', 'Bedadung Kulon', -8.2198000, 113.6075000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73323, 'Rowotamtu', 'Rowotamtu', 'Rawatamtoe,Rowotamtu', -8.2315000, 113.5808000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73324, 'Gumawang', 'Gumawang', 'Gumawang', -8.2398000, 113.5693000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73325, 'Kraton', 'Kraton', 'Kraton', -8.3849000, 113.6773000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73326, 'Andongrejo', 'Andongrejo', 'Andongrejo', -8.4068000, 113.7406000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73327, 'Kandangan', 'Kandangan', 'Kandangan', -8.5415000, 113.9709000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73328, 'Rejoagung', 'Rejoagung', 'Rejoagung', -8.5618000, 114.0603000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73329, 'Sidorukun', 'Sidorukun', 'Sidorukun', -8.5898000, 114.1189000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73330, 'Sumberbening', 'Sumberbening', 'Sumberbening', -8.5394000, 114.1103000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73331, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.5052000, 114.1138000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73332, 'Mulyosari', 'Mulyosari', 'Mulyosari', -8.5596000, 114.0904000, 'ID', '2012-02-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73333, 'City of Balikpapan', 'City of Balikpapan', '', -1.2420400, 116.8941900, 'ID', '2012-03-25', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73334, 'Pasirpanjang', 'Pasirpanjang', 'Pasirpanjang', 1.1259500, 103.3500500, 'ID', '2015-08-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73335, 'Tebing', 'Tebing', 'Tebing', 1.0321100, 103.4207100, 'ID', '2015-08-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73336, 'Watuagung', 'Watuagung', 'Watuagung', -8.2517000, 111.5172000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73337, 'Besuki', 'Besuki', 'Besuki', -8.2614000, 111.5941000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73338, 'Krajan Craken', 'Krajan Craken', 'Krajan Craken', -8.2962000, 111.5437000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73339, 'Ngulung Kulon', 'Ngulung Kulon', 'Ngulung Kulon', -8.3044000, 111.5070000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73340, 'Masaran', 'Masaran', 'Masaran', -8.3040000, 111.5603000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73341, 'Tawing', 'Tawing', 'Tawing', -8.3067000, 111.5959000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73342, 'Bendoroto', 'Bendoroto', 'Bendoroto', -8.3077000, 111.6101000, 'ID', '2012-05-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73343, 'Stasiun', 'Stasiun', 'Stasiun', -8.0413000, 113.2789000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73344, 'Nangakeo', 'Nangakeo', 'Nangakeo', -8.7946000, 121.5676000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73345, 'Menala', 'Menala', 'Menala', -8.7440000, 116.8565000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73346, 'Gontar', 'Gontar', 'Gontar', -8.5112000, 116.9775000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73347, 'Jambewangi', 'Jambewangi', 'Jambewangi', -8.1308000, 112.3064000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73348, 'Kedungwungu', 'Kedungwungu', 'Kedungwungu', -8.1710000, 112.3030000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73349, 'Penunjak', 'Penunjak', 'Penunjak', -8.7452000, 116.2400000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73350, 'Manggissari', 'Manggissari', 'Manggissari', -8.3735000, 114.8950000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73351, 'Pengkelakmas', 'Pengkelakmas', 'Pengkelakmas', -8.7338000, 116.4990000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73352, 'Seraya', 'Seraya', 'Seraya', -8.4301000, 115.6577000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73353, 'Tampes', 'Tampes', 'Tampes', -8.2346000, 116.3008000, 'ID', '2012-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73354, 'Kombapari', 'Kombapari', 'Kombapari', -9.7863000, 119.9375000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73355, 'Marokota', 'Marokota', 'Marokota', -9.5011000, 119.1766000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73356, 'Maredakalada', 'Maredakalada', 'Maredakalada', -9.5970000, 119.3203000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73357, 'Soriutu', 'Soriutu', 'Soriutu', -8.5191000, 118.3229000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73358, 'Tohong', 'Tohong', 'Tohong', -8.5573000, 120.0033000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73359, 'Laja', 'Laja', 'Laja', -8.8545000, 121.1029000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73360, 'Were', 'Were', 'Were', -8.8725000, 121.0602000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73361, 'Wontong', 'Wontong', 'Wontong', -8.3410000, 120.3730000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73362, 'Gandekan', 'Gandekan', 'Gandekan', -8.0826000, 111.9982000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73363, 'Sekotong Tengah', 'Sekotong Tengah', 'Sekotong Tengah', -8.7782000, 116.0485000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73364, 'Rato', 'Rato', 'Rato', -8.5058000, 118.6209000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73365, 'Campa', 'Campa', 'Campa', -8.5857000, 118.5804000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73366, 'Wairinding', 'Wairinding', 'Wairinding', -9.6739000, 120.1302000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73367, 'Palindi', 'Palindi', 'Palindi', -9.7098000, 120.3259000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73368, 'Sirnaresmi', 'Sirnaresmi', 'Sirnaresmi', -6.8373000, 106.4493000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73369, 'Guradog', 'Guradog', 'Guradog', -6.5059000, 106.3923000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73370, 'Sukacai', 'Sukacai', 'Soekatjai,Sukacai', -6.2365000, 106.1105000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73371, 'Sekong', 'Sekong', 'Sekong', -6.3761600, 106.0338800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73372, 'Citarik', 'Citarik', 'Citarik', -7.0095000, 106.5822000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73373, 'Sanghiang', 'Sanghiang', 'Sanghiang', -6.7648700, 106.0022600, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73374, 'Malati', 'Malati', 'Malati', -7.3611000, 107.3218000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73375, 'Cipancar', 'Cipancar', 'Cipancar,Tjipantjar', -7.1041000, 107.8899000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73376, 'Girijaya', 'Girijaya', 'Girijaya', -7.5734000, 108.1319000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73377, 'Banteng', 'Banteng', 'Banteng', -6.5966000, 111.0157000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73378, 'Tlogowungu', 'Tlogowungu', 'Tlogowungu', -6.7068500, 111.0141100, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73379, 'Puri', 'Puri', 'Puri', -6.7487000, 111.0254000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73380, 'Lakbok', 'Lakbok', 'Lakbok', -7.4040000, 108.6573000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73381, 'Bate', 'Bate', 'Bate', -6.9954000, 111.6874000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73382, 'Muara', 'Muara', 'Moeara,Muara', -7.2557000, 108.8729000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73383, 'Kadumanis', 'Kadumanis', 'Kadumanis', -7.1762000, 108.8671000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73384, 'Awarawar', 'Awarawar', 'Awarawar', -6.7724000, 111.9362000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73385, 'Mlangi', 'Mlangi', 'Mlangi', -6.9986000, 112.1834000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73386, 'Kujung', 'Kujung', 'Koedjoeng,Kujung', -6.9869000, 112.1989000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73387, 'Kranji', 'Kranji', 'Kranji', -6.8775000, 112.3830000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73388, 'Kuluran', 'Kuluran', 'Kuluran', -6.9981000, 112.4120000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73389, 'Dibee', 'Dibee', 'Dibee', -6.9996000, 112.3896000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73390, 'Mertani', 'Mertani', 'Mertani', -6.9917000, 112.3760000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73391, 'Wonodadi', 'Wonodadi', 'Wonodadi', -8.1593000, 111.4550000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73392, 'Sumbermanggis', 'Sumbermanggis', 'Soembermanggis,Sumbermanggis', -8.2537000, 112.8380000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73393, 'Glagahwero', 'Glagahwero', 'Glagahwera,Glagahwero', -8.1770000, 113.6188000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73394, 'Silodakon', 'Silodakon', 'Silodakon', -8.1675000, 113.5024000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73395, 'Siliragung', 'Siliragung', 'Siliragung', -8.5574000, 114.1120000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73396, 'Jajar', 'Jajar', 'Djadjar 11,Djadjar Sebelas,Jajar', -8.2933000, 111.6290000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73397, 'Krajan Sawahan', 'Krajan Sawahan', 'Krajan Sawahan', -8.2618000, 111.6990000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73398, 'Gading', 'Gading', 'Gading', -8.2921000, 111.6967000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73399, 'Margo Wetan', 'Margo Wetan', 'Margo Wetan', -8.2710000, 111.7110000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73400, 'Prigi', 'Prigi', 'Prigi', -8.2721000, 111.7151000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73401, 'Ketawang', 'Ketawang', 'Ketawang', -8.2805000, 111.7257000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73402, 'Krajan Puru', 'Krajan Puru', 'Krajan Puru', -8.1261000, 111.5967000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73403, 'Crabak', 'Crabak', 'Crabak', -8.1398000, 111.6135000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73404, 'Krajan Pakel', 'Krajan Pakel', 'Krajan Pakel', -8.1387000, 111.5463000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73405, 'Turi', 'Turi', 'Turi', -8.1463000, 111.5352000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73406, 'Krajan Joho', 'Krajan Joho', 'Krajan Joho', -8.1567000, 111.5263000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73407, 'Krajan Pringapus', 'Krajan Pringapus', 'Krajan Pringapus', -8.1757000, 111.6050000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73408, 'Mloko', 'Mloko', 'Mloko', -8.1684000, 111.5780000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73409, 'Krajan Dongko', 'Krajan Dongko', 'Krajan Dongko', -8.1872000, 111.5808000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73410, 'Krajan Siki', 'Krajan Siki', 'Krajan Siki', -8.1831000, 111.5359000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73411, 'Krajan Petung', 'Krajan Petung', 'Krajan Petung', -8.1964000, 111.5622000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73412, 'Krajan Ngerdani', 'Krajan Ngerdani', 'Krajan Ngerdani', -8.1966000, 111.6110000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73413, 'Karangsudo', 'Karangsudo', 'Karangsudo', -8.2232000, 111.5292000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73414, 'Salamwates', 'Salamwates', 'Salamwates', -8.2260000, 111.5650000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73415, 'Pandean', 'Pandean', 'Pandean', -8.2388000, 111.5346000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73416, 'Jatirejo', 'Jatirejo', 'Jatirejo', -8.1254000, 111.7035000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73417, 'Sukorejo', 'Sukorejo', 'Sukorejo', -8.1332000, 111.6995000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73418, 'Timahankrajan', 'Timahankrajan', 'Timahankrajan', -8.1487000, 111.6539000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73419, 'Wonorejo', 'Wonorejo', 'Wonorejo', -8.1471000, 111.6946000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73420, 'Jajarkrajan', 'Jajarkrajan', 'Jajarkrajan', -8.1539000, 111.7051000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73421, 'Wates', 'Wates', 'Wates', -8.1629000, 111.6771000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73422, 'Pojok', 'Pojok', 'Pojok', -8.1608000, 111.6827000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73423, 'Bogoran', 'Bogoran', 'Bogoran', -8.1817000, 111.6609000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73424, 'Kademangan', 'Kademangan', 'Kademangan', -8.1800000, 111.6677000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73425, 'Krajantalun Kulon', 'Krajantalun Kulon', 'Krajantalun Kulon', -8.1784000, 111.7463000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73426, 'Kradinan', 'Kradinan', 'Kradinan', -8.1837000, 111.7497000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73427, 'Nglampir', 'Nglampir', 'Nglampir', -8.1910000, 111.7340000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73428, 'Ngembel', 'Ngembel', 'Ngembel', -8.1908000, 111.6990000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73429, 'Senden', 'Senden', 'Senden', -8.1859000, 111.6742000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73430, 'Tanjung', 'Tanjung', 'Tanjung', -8.1997000, 111.6396000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73431, 'Karangrejokrajan', 'Karangrejokrajan', 'Karangrejokrajan', -8.1918600, 111.6586900, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73432, 'Watuagung', 'Watuagung', 'Watuagung', -8.1965000, 111.7159000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73433, 'Sedayugunung', 'Sedayugunung', 'Sedayugunung', -8.2055000, 111.7470000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73434, 'Gelatik', 'Gelatik', 'Gelatik', -8.2098000, 111.6845000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73435, 'Gemaharjo', 'Gemaharjo', 'Gemaharjo', -8.2388000, 111.7045000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73436, 'Ponggok', 'Ponggok', 'Ponggok', -8.2377000, 111.6863000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73437, 'Sebo', 'Sebo', 'Sebo', -8.2433000, 111.7036000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73438, 'Wonokerto', 'Wonokerto', 'Wonokerto', -8.1225000, 111.6012000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73439, 'Tawang', 'Tawang', 'Tawang', -8.1149000, 111.6032000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73440, 'Sidem', 'Sidem', 'Sidem', -8.0966000, 111.5831000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73441, 'Krajan Tenggaran', 'Krajan Tenggaran', 'Krajan Tenggaran', -8.0895000, 111.5505000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73442, 'Gandu', 'Gandu', 'Gandu', -8.0894000, 111.6034000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73443, 'Krajan Pucanganak', 'Krajan Pucanganak', 'Krajan Pucanganak', -8.0267000, 111.6102000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73444, 'Krajan Gading', 'Krajan Gading', 'Krajan Gading', -8.0217000, 111.5941000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73445, 'Blumbang', 'Blumbang', 'Blumbang', -8.0217000, 111.5794000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73446, 'Krajan Nglinggis', 'Krajan Nglinggis', 'Krajan Nglinggis', -8.0402000, 111.6023000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73447, 'Gajah', 'Gajah', 'Gajah', -8.0455000, 111.6020000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73448, 'Krajan Suko Kidul', 'Krajan Suko Kidul', 'Krajan Suko Kidul', -8.0604000, 111.5793000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73449, 'Kembang', 'Kembang', 'Kembang', -8.0652000, 111.5030000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73450, 'Krajan Karanganyar', 'Krajan Karanganyar', 'Krajan Karanganyar', -8.0831000, 111.5618000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73451, 'Pule', 'Pule', 'Pule', -8.0372000, 111.5021000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73452, 'Jujur', 'Jujur', 'Jujur', -8.0076000, 111.7362000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73453, 'Sumberdadi', 'Sumberdadi', 'Sumberdadi', -8.0175000, 111.7145000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73454, 'Tegarenkrajan', 'Tegarenkrajan', 'Tegarenkrajan', -8.0244000, 111.6441000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73455, 'Prambonkrajan', 'Prambonkrajan', 'Prambonkrajan', -8.0251000, 111.6691000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73456, 'Sentul', 'Sentul', 'Sentul', -8.0226000, 111.7362000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73457, 'Ngares', 'Ngares', 'Ngares', -8.0290000, 111.7084000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73458, 'Krajan Winong', 'Krajan Winong', 'Krajan Winong', -8.0300000, 111.6462000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73459, 'Sukorejokrajan', 'Sukorejokrajan', 'Sukorejokrajan', -8.0408000, 111.6438000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73460, 'Banarankrajan', 'Banarankrajan', 'Banarankrajan', -8.0412000, 111.6694000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73461, 'Parakan', 'Parakan', 'Parakan', -8.0412000, 111.7348000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73462, 'Rejowinangun', 'Rejowinangun', 'Rejowinangun', -8.0484000, 111.7327000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73463, 'Surodakan', 'Surodakan', 'Surodakan', -8.0490000, 111.7170000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73464, 'Sumbergedong', 'Sumbergedong', 'Sumbergedong', -8.0525000, 111.7078000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73465, 'Ngantrukrajan', 'Ngantrukrajan', 'Ngantrukrajan', -8.0547000, 111.7052000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73466, 'Sumberkrajan', 'Sumberkrajan', 'Sumberkrajan', -8.0504000, 111.6878000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73467, 'Ngentrong', 'Ngentrong', 'Ngentrong', -8.0435000, 111.6803000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73468, 'Kebon', 'Kebon', 'Kebon', -8.0430000, 111.6546000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73469, 'Tumpuk', 'Tumpuk', 'Tumpuk', -8.0548000, 111.6470000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73470, 'Bendo', 'Bendo', 'Bendo', -8.0946000, 111.7440000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73471, 'Ngulankulonkrajan', 'Ngulankulonkrajan', 'Ngulankulonkrajan', -8.0631000, 111.7419000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73472, 'Tamanan', 'Tamanan', 'Tamanan', -8.0589000, 111.7021000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73473, 'Kelutan', 'Kelutan', 'Kelutan', -8.0665000, 111.7036000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73474, 'Krajan Kerjo', 'Krajan Kerjo', 'Krajan Kerjo', -8.0607000, 111.6636000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73475, 'Rejosari', 'Rejosari', 'Rejosari', -8.0715000, 111.6747000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73476, 'Wadi Kidul', 'Wadi Kidul', 'Wadi Kidul', -8.0764000, 111.7423000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73477, 'Ngepoh', 'Ngepoh', 'Ngepoh', -8.0777000, 111.7188000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73478, 'Sokobanteng', 'Sokobanteng', 'Sokobanteng', -8.0806000, 111.7084000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73479, 'Banjar', 'Banjar', 'Banjar', -8.0781000, 111.6781000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73480, 'Krayen', 'Krayen', 'Krayen', -8.0871000, 111.6426000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73481, 'Duwet', 'Duwet', 'Duwet', -8.0955000, 111.7337000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73482, 'Jatiprahu', 'Jatiprahu', 'Jatiprahu', -8.0958000, 111.6914000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73483, 'Jati', 'Jati', 'Jati', -8.0964000, 111.6517000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73484, 'Jatirejo', 'Jatirejo', 'Jatirejo', -8.0965000, 111.6328000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73485, 'Wonocoyo', 'Wonocoyo', 'Wonocoyo', -8.1022000, 111.7217000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73486, 'Suwaru', 'Suwaru', 'Suwaru', -8.1086000, 111.7447000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73487, 'Jugang', 'Jugang', 'Jugang', -8.1161000, 111.7381000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73488, 'Manggis', 'Manggis', 'Manggis', -8.1104000, 111.7107000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73489, 'Suko Wetan', 'Suko Wetan', 'Suko Wetan', -8.1106000, 111.6798000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73490, 'Soho', 'Soho', 'Soho', -8.1141000, 111.6535000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73491, 'Widoro', 'Widoro', 'Widoro', -8.1213000, 111.7212000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73492, 'Jedung', 'Jedung', 'Jedung', -8.1174000, 111.7299000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73493, 'Telan', 'Telan', 'Telan', -8.1316000, 111.7957000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73494, 'Gandong', 'Gandong', 'Gandong', -8.1421000, 111.7920000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73495, 'Sambi', 'Sambi', 'Sambi', -8.1516000, 111.7976000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73496, 'Gombang', 'Gombang', 'Gombang', -8.1578000, 111.8044000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73497, 'Sukoanyar', 'Sukoanyar', 'Sukoanyar', -8.1704000, 111.8064000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73498, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -8.1777000, 111.8093000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73499, 'Kroyo', 'Kroyo', 'Kroyo', -8.1784000, 111.7824000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73500, 'Bagusan', 'Bagusan', 'Bagusan', -8.1777000, 111.7637000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73501, 'Kedungbuntung', 'Kedungbuntung', 'Kedungbuntung', -8.1713000, 111.7666000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73502, 'Bantengan', 'Bantengan', 'Bantengan', -8.1701000, 111.7546000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73503, 'Sebalor', 'Sebalor', 'Sebalor', -8.1609000, 111.7603000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73504, 'Mergayu', 'Mergayu', 'Mergajoe,Mergayu', -8.1693000, 111.7818000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73505, 'Contong', 'Contong', 'Contong', -8.1715000, 111.7853000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73506, 'Suwaru', 'Suwaru', 'Soewaroe,Suwaru', -8.1756100, 111.7807900, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73507, 'Ngunggahan', 'Ngunggahan', 'Ngoenggahan 1,Ngunggahan', -8.1773000, 111.7880000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73508, 'Mulyo', 'Mulyo', 'Mulyo', -8.1714000, 111.7981000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73509, 'Bakalan', 'Bakalan', 'Bakalan', -8.1703000, 111.7917000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73510, 'Singgit', 'Singgit', 'Singgit', -8.1542000, 111.7757000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73511, 'Nglempung', 'Nglempung', 'Nglempung', -8.1528000, 111.7672000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73512, 'Gambang', 'Gambang', 'Gambang', -8.1349000, 111.7708000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73513, 'Sanggar', 'Sanggar', 'Sanggar', -8.1418000, 111.7742000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73514, 'Soko', 'Soko', 'Soko', -8.1424000, 111.7700000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73515, 'Bulus', 'Bulus', 'Bulus', -8.1438000, 111.7820000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73516, 'Gesikan', 'Gesikan', 'Gesikan', -8.1283000, 111.8645000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73517, 'Dungkul', 'Dungkul', 'Dungkul', -8.1265000, 111.8433000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73518, 'Campok', 'Campok', 'Campok', -8.1257000, 111.8268000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73519, 'Sanan', 'Sanan', 'Sanan', -8.1377000, 111.8339000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73520, 'Genengan Kulon', 'Genengan Kulon', 'Genengan Kulon', -8.1302000, 111.8362000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73521, 'Ngrance', 'Ngrance', 'Ngrance', -8.1383000, 111.8419000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73522, 'Kasreman Wetan', 'Kasreman Wetan', 'Kasreman Wetan', -8.1455000, 111.8408000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73523, 'Pecuk', 'Pecuk', 'Pecuk', -8.1455000, 111.8309000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73524, 'Suwaluh', 'Suwaluh', 'Suwaluh', -8.1389000, 111.8134000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73525, 'Bangunmulyo', 'Bangunmulyo', 'Bangunmulyo', -8.1529000, 111.8347000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73526, 'Krenggan', 'Krenggan', 'Krenggan', -8.1659000, 111.8378000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73527, 'Sodo', 'Sodo', 'Sodo', -8.1661300, 111.8254800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73528, 'Gebang', 'Gebang', 'Gebang', -8.1761000, 111.8169000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73529, 'Gendingan', 'Gendingan', 'Gendingan', -8.1738000, 111.8375000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73530, 'Cerme Kidul', 'Cerme Kidul', 'Cerme Kidul', -8.1808000, 111.8413000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73531, 'Campurjanggang', 'Campurjanggang', 'Campurjanggang', -8.1620000, 111.8581000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73532, 'Bangus Kulon', 'Bangus Kulon', 'Bangus Kulon', -8.1430000, 111.8614000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73533, 'Ngayem', 'Ngayem', 'Ngayem', -8.1955000, 111.8734000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73534, 'Ngepoh Kidul', 'Ngepoh Kidul', 'Ngepoh Kidul', -8.2088000, 111.8670000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73535, 'Ngrejo', 'Ngrejo', 'Ngrejo', -8.2285000, 111.8526000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73536, 'Besole', 'Besole', 'Besole', -8.2241000, 111.8194000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73537, 'Ngentrong', 'Ngentrong', 'Ngentrong', -8.2092000, 111.8260000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73538, 'Sawo', 'Sawo', 'Sawo', -8.2018000, 111.8338000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73539, 'Gedangan', 'Gedangan', 'Gedangan', -8.1986000, 111.8271000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73540, 'Keboireng', 'Keboireng', 'Keboireng', -8.2118000, 111.7692000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73541, 'Turus', 'Turus', 'Turus', -8.2070000, 111.7733000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73542, 'Besuki Dua', 'Besuki Dua', 'Besuki Dua', -8.2156000, 111.7829000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73543, 'Welahan', 'Welahan', 'Welahan', -8.2094000, 111.7838000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73544, 'Kundung', 'Kundung', 'Kundung', -8.1927000, 111.7770000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73545, 'Boro', 'Boro', 'Boro', -8.0165000, 111.7774000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73546, 'Kedungcangkring', 'Kedungcangkring', 'Kedungcangkring', -8.0371000, 111.8079000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73547, 'Ngulan Wetan', 'Ngulan Wetan', 'Ngoelan-wetan,Ngulan Wetan', -8.0629000, 111.7520000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73548, 'Tumpang', 'Tumpang', 'Tumpang', -8.0744000, 111.7507000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73549, 'Jungke', 'Jungke', 'Jungke', -8.1173000, 111.7534000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73550, 'Brongkah', 'Brongkah', 'Brongkah', -8.1141000, 111.7762000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73551, 'Cangkringan', 'Cangkringan', 'Cangkringan', -8.1075000, 111.7977000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73552, 'Randu', 'Randu', 'Randu', -8.1197000, 111.7935000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73553, 'Payaman', 'Payaman', 'Payaman', -8.1238000, 111.8066000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73554, 'Pandean', 'Pandean', 'Pandean', -8.1196000, 111.8076000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73555, 'Pakis', 'Pakis', 'Pakis', -8.1150000, 111.8049000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73556, 'Sendangkemulian', 'Sendangkemulian', 'Sendangkemulian', -8.0972000, 111.8163000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73557, 'Gador', 'Gador', 'Gador', -8.0915000, 111.8103000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73558, 'Sidem', 'Sidem', 'Sidem', -8.0797000, 111.8117000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73559, 'Sumberejo', 'Sumberejo', 'Sumberejo', -8.0719000, 111.8018000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73560, 'Blendis', 'Blendis', 'Blendis', -8.0603000, 111.8254000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73561, 'Kleben', 'Kleben', 'Kleben', -8.0506000, 111.8404000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73562, 'Bolorejo', 'Bolorejo', 'Bolorejo', -8.0534000, 111.8625000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73563, 'Irongganan', 'Irongganan', 'Irongganan', -8.0506700, 111.8714200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73564, 'Boneng', 'Boneng', 'Boneng', -8.0487000, 111.8675000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73565, 'Pucangan', 'Pucangan', 'Pucangan', -8.0384000, 111.8462000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73566, 'Srabah', 'Srabah', 'Srabah', -8.0392000, 111.8493000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73567, 'Mojasari', 'Mojasari', 'Mojasari', -8.0462000, 111.8619000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73568, 'Jabon', 'Jabon', 'Jabon', -8.0347000, 111.8731000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73569, 'Sendung', 'Sendung', 'Sendung', -8.0272000, 111.8611000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73570, 'Bebekan', 'Bebekan', 'Bebekan', -8.0610000, 111.8726000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73571, 'Ngrendeng', 'Ngrendeng', 'Ngrendeng', -8.0677000, 111.8493000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73572, 'Bendungan', 'Bendungan', 'Bendungan', -8.0705800, 111.8458400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73573, 'Bendo', 'Bendo', 'Bendo', -8.0735000, 111.8668000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73574, 'Dami', 'Dami', 'Dami', -8.0805000, 111.8651000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73575, 'Kiping', 'Kiping', 'Kiping', -8.0788000, 111.8492000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73576, 'Karangsari', 'Karangsari', 'Karangsari', -8.0712000, 111.8245000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73577, 'Karangtengah', 'Karangtengah', 'Karangtengah', -8.0861000, 111.8232000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73578, 'Sepatan', 'Sepatan', 'Sepatan', -8.0871000, 111.8484000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73579, 'Dukuh', 'Dukuh', 'Dukuh', -8.0934000, 111.8504000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73580, 'Gajah', 'Gajah', 'Gadjah,Gajah', -8.0929000, 111.8556000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73581, 'Gondosuli', 'Gondosuli', 'Gondosoeli,Gondosuli', -8.0950000, 111.8596000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73582, 'Gempolan Wetan', 'Gempolan Wetan', 'Gempolan Wetan', -8.1145000, 111.8582000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73583, 'Kendal', 'Kendal', 'Kendal', -8.1099000, 111.8483000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73584, 'Temenggungan', 'Temenggungan', 'Temenggungan', -8.1041000, 111.8657000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73585, 'Baruklinting Dua', 'Baruklinting Dua', 'Baruklinting Dua', -8.0962000, 111.8252000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73586, 'Nglengkong', 'Nglengkong', 'Nglengkong', -8.1077000, 111.8347000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73587, 'Jajar', 'Jajar', 'Jajar', -8.1091000, 111.8192000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73588, 'Tertek', 'Tertek', 'Tertek', -8.1224000, 111.8148000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73589, 'Jabung Wetan', 'Jabung Wetan', 'Jabung Wetan', -7.7420000, 113.4873000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73590, 'Tanjung Kidul', 'Tanjung Kidul', 'Tanjung Kidul', -7.7213000, 113.4982000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73591, 'Randumerak', 'Randumerak', 'Randumerak', -7.7278000, 113.4811000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73592, 'Krajan Jabungcandi', 'Krajan Jabungcandi', 'Krajan Jabungcandi', -7.7342000, 113.4815000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73593, 'Sidodadi', 'Sidodadi', 'Sidodadi', -7.7385000, 113.4947000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73594, 'Kalibuntu', 'Kalibuntu', 'Kalibuntu', -7.7361000, 113.4170000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73595, 'Krajan Kebonagung', 'Krajan Kebonagung', 'Krajan Kebonagung', -7.7477000, 113.4486000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73596, 'Bringinanom', 'Bringinanom', 'Bringinanom', -7.7427000, 113.4538000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73597, 'Parseh', 'Parseh', 'Parseh', -7.7494000, 113.4607000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73598, 'Krajan Alastengah', 'Krajan Alastengah', 'Krajan Alastengah', -7.7492000, 113.4952000, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73599, 'Grujugan', 'Grujugan', 'Grujugan', -7.1279000, 113.5383800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73600, 'Trasak', 'Trasak', 'Trasak', -7.1323100, 113.5235100, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73601, 'Tentenan', 'Tentenan', 'Tentenan', -7.1303600, 113.5333400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73602, 'Barajalan', 'Barajalan', 'Barajalan', -7.1332000, 113.5347200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73603, 'Toampar', 'Toampar', 'Toampar', -7.1309900, 113.5424500, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73604, 'Larangan', 'Larangan', 'Larangan', -7.1287500, 113.5470200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73605, 'Pandiyan', 'Pandiyan', 'Pandiyan', -7.1315200, 113.5578500, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73606, 'Tanahmerah', 'Tanahmerah', 'Tanahmerah', -7.1336600, 113.5711900, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73607, 'Platok', 'Platok', 'Platok', -7.1302500, 113.5787400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73608, 'Raas', 'Raas', 'Raas', -7.1247400, 113.6005100, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73609, 'Polagan Tengah', 'Polagan Tengah', 'Polagan Tengah', -7.1385200, 113.5606900, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73610, 'Temorlorong', 'Temorlorong', 'Temorlorong', -7.1338600, 113.5199700, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73611, 'Bulay', 'Bulay', 'Bulay', -7.1426500, 113.5484700, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73612, 'Nampera', 'Nampera', 'Nampera', -7.1582400, 113.5554200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73613, 'Rongrongan', 'Rongrongan', 'Rongrongan', -7.1505300, 113.5283500, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73614, 'Biris Daja', 'Biris Daja', 'Biris Daja', -7.1537600, 113.5196900, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73615, 'Bulung', 'Bulung', 'Bulung', -7.1583400, 113.5100300, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73616, 'Lobuk', 'Lobuk', 'Lobuk', -7.1590800, 113.5186400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73617, 'Tandes', 'Tandes', 'Tandes', -7.1579100, 113.5405400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73618, 'Lembung Tengah', 'Lembung Tengah', 'Lembung Tengah', -7.1620800, 113.5618700, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73619, 'Plasah', 'Plasah', 'Plasah', -7.1745900, 113.5536400, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73620, 'Murtajih', 'Murtajih', 'Murtajih', -7.1668900, 113.5091200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73621, 'Karangdalam', 'Karangdalam', 'Karangdalam', -7.1887700, 113.5124500, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73622, 'Kebon', 'Kebon', 'Kebon', -7.1849500, 113.5024700, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73623, 'Dorbuk Utara', 'Dorbuk Utara', 'Dorbuk Utara', -7.1932200, 113.5037800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73624, 'Mungging', 'Mungging', 'Mungging', -7.2042900, 113.5319800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73625, 'Jambul', 'Jambul', 'Jambul', -7.2186300, 113.5306100, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73626, 'Mor Laok', 'Mor Laok', 'Mor Laok', -7.2243900, 113.5150800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73627, 'Bong', 'Bong', 'Bong', -7.2260800, 113.5000800, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73628, 'Bangkal', 'Bangkal', 'Bangkal', -7.2270400, 113.5304200, 'ID', '2012-06-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73629, 'Banjar Sempidi', 'Banjar Sempidi', 'Banjar Sempidi', -8.5233000, 115.2068000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73630, 'Terang', 'Terang', 'Terang', -8.4563000, 120.0792000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73631, 'Rora', 'Rora', 'Rora', -8.4772000, 118.5115000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73632, 'Woja', 'Woja', 'Woja', -8.6366000, 118.3542000, 'ID', '2014-01-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73633, 'Bangsring', 'Bangsring', 'Bangsring', -8.0582000, 114.4169000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73634, 'Pakel', 'Pakel', 'Pakel', -8.0018000, 111.9063000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73635, 'Tegalpakis', 'Tegalpakis', 'Tegalpakis', -8.2989000, 113.9927000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73636, 'Tonggoh', 'Tonggoh', 'Tonggoh', -7.2693000, 108.3140000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73637, 'Girang', 'Girang', 'Girang', -7.2697000, 108.4222000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73638, 'Jambean', 'Jambean', 'Jambean', -6.7371000, 111.0352000, 'ID', '2012-08-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73639, 'Beran', 'Beran', 'Beran', -6.9793000, 111.4102000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73640, 'Kalidawe', 'Kalidawe', 'Kalidawe', -8.2533000, 112.0120000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73641, 'Pucanglaban', 'Pucanglaban', 'Poetjanglaban,Pucanglaban', -8.2626000, 112.0153000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73642, 'Ngeni', 'Ngeni', 'Ngeni', -8.2538000, 112.2095000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73643, 'Mojorejo', 'Mojorejo', 'Mojorejo', -8.2609000, 112.3558000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73644, 'Bibis', 'Bibis', 'Bibis', -8.0087000, 111.4670000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73645, 'Sumberbuncis', 'Sumberbuncis', 'Soemberboentjis,Sumberbuncis', -8.2703000, 112.8825000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73646, 'Badean', 'Badean', 'Badean,Badejan', -8.1445000, 113.5947000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73647, 'Curahkalong', 'Curahkalong', 'Curahkalong', -8.1733000, 113.5128000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73648, 'Muaradua', 'Muaradua', 'Muaradua,Muaraduo', -4.1176800, 103.6121000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73649, 'Bara Datu', 'Bara Datu', 'Bara Datu', -4.7442300, 104.4964000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73650, 'Pasar Banjit', 'Pasar Banjit', 'Pasar Banjit', -4.7994500, 104.4832300, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73651, 'Kurungannyawa', 'Kurungannyawa', 'Kurungannyawa', -4.2380400, 104.4648200, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73652, 'Oganlima', 'Oganlima', 'Oganlima', -4.8673600, 104.7030800, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73653, 'Umbulan Kapiak', 'Umbulan Kapiak', 'Umbulan Kapiak,Umbulankapiak', -4.8343800, 104.5286700, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73654, 'Gunung', 'Gunung', 'Gunung', -7.0148000, 113.5819000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73655, 'Trebungonjur', 'Trebungonjur', 'Trebungonjur', -7.0089000, 113.5144000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73656, 'Grujugan', 'Grujugan', 'Grujugan', -7.0287000, 113.6157000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73657, 'Parengan Laok', 'Parengan Laok', 'Parengan Laok', -7.0331000, 113.5917000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73658, 'Patapan', 'Patapan', 'Patapan', -7.0279000, 113.5081000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73659, 'Duko', 'Duko', 'Duko', -7.0360000, 113.5467000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73660, 'Gungguh', 'Gungguh', 'Gungguh', -7.0350000, 113.5599000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73661, 'Ba’rigi', 'Ba''rigi', 'Ba''rigi,Ba’rigi', -7.0402000, 113.6026000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73662, 'Birsa', 'Birsa', 'Birsa', -7.0458000, 113.6158000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73663, 'Sumberaya Barat', 'Sumberaya Barat', 'Sumberaya Barat', -7.0434000, 113.5924000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73664, 'Kendal', 'Kendal', 'Kendal', -7.0436000, 113.5874000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73665, 'Sannip', 'Sannip', 'Sannip', -7.0475000, 113.5842000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73666, 'Sumberbatas', 'Sumberbatas', 'Sumberbatas', -7.0497000, 113.5583000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73667, 'Polay Atas', 'Polay Atas', 'Polay Atas', -7.0662000, 113.5964000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73668, 'Tonggakjati', 'Tonggakjati', 'Tonggakjati', -7.0612000, 113.5280000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73669, 'Sumberbendo', 'Sumberbendo', 'Sumberbendo', -7.0655000, 113.5272000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73670, 'Pogag', 'Pogag', 'Pogag', -7.0638000, 113.5187000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73671, 'Bakbatu', 'Bakbatu', 'Bakbatu', -7.0831000, 113.5943000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73672, 'Sumberngerjat', 'Sumberngerjat', 'Sumberngerjat', -7.0888000, 113.5901000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73673, 'Kadur', 'Kadur', 'Kadur', -7.0930000, 113.5586000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73674, 'Pancoran', 'Pancoran', 'Pancoran', -7.1035000, 113.5201000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73675, 'Daleman Tengah', 'Daleman Tengah', 'Daleman Tengah', -7.1050000, 113.5913000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73676, 'Gagah', 'Gagah', 'Gagah', -7.1073000, 113.5949000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73677, 'Mangkaan', 'Mangkaan', 'Mangkaan', -7.1048000, 113.6086000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73678, 'Kolor', 'Kolor', 'Kolor', -7.1061000, 113.6173000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73679, 'Sekolahan', 'Sekolahan', 'Sekolahan', -7.1143000, 113.5829000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73680, 'Taraban Timur', 'Taraban Timur', 'Taraban Timur', -7.1149000, 113.5773000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73681, 'Bertah', 'Bertah', 'Bertah', -7.1152000, 113.5487000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73682, 'Duwaktenggi', 'Duwaktenggi', 'Duwaktenggi', -7.1108000, 113.5265000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73683, 'Batuputih', 'Batuputih', 'Batuputih', -7.1183000, 113.5523000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73684, 'Panggulan', 'Panggulan', 'Panggulan', -7.1188000, 113.6123000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73685, 'Sendang Timur', 'Sendang Timur', 'Sendang Timur', -7.1173000, 113.6214000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73686, 'Palalang', 'Palalang', 'Palalang', -7.0326000, 113.5735000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73687, 'Budan Daja', 'Budan Daja', 'Budan Daja', -7.1986000, 113.8946000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73688, 'Dadap', 'Dadap', 'Dadap', -7.1761000, 113.9247000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73689, 'Gedugan Barat', 'Gedugan Barat', 'Gedugan Barat', -7.1977000, 113.9326000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73690, 'Ledeunu', 'Ledeunu', 'Ledeunu', -10.6058000, 121.6106000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73691, 'Ujudima', 'Ujudima', 'Ujudima', -10.6078000, 121.6085000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73692, 'Maae', 'Maae', 'Maae', -10.6184000, 121.5991000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73693, 'Loboma', 'Loboma', 'Loboma', -10.6212000, 121.5749000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73694, 'Bogi', 'Bogi', 'Bogi', -10.6162000, 121.5743000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73695, 'Lupe', 'Lupe', 'Lupe', -10.6167000, 121.5531000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73696, 'Danirai', 'Danirai', 'Danirai', -10.5732000, 121.7388000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73697, 'Para', 'Para', 'Para', -10.5972000, 121.7303000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73698, 'Lederaba', 'Lederaba', 'Lederaba', -10.5737000, 121.7219000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73699, 'Loboae', 'Loboae', 'Loboae', -10.5048000, 121.8280000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73700, 'Dinititi', 'Dinititi', 'Dinititi', -10.5125000, 121.8513000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73701, 'Raeliu', 'Raeliu', 'Raeliu', -10.5137000, 121.8112000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73702, 'Ubajami', 'Ubajami', 'Ubajami', -10.5182000, 121.7895000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73703, 'Raehawu', 'Raehawu', 'Raehawu', -10.5336000, 121.8313000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73704, 'Dairiti', 'Dairiti', 'Dairiti', -10.5390000, 121.8525000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73705, 'Ligu', 'Ligu', 'Ligu', -10.5422000, 121.7566000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73706, 'Raemude', 'Raemude', 'Raemude', -10.5524000, 121.8475000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73707, 'Raenalulu', 'Raenalulu', 'Raenalulu', -10.5599000, 121.8123000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73708, 'Aimadamodo', 'Aimadamodo', 'Aimadamodo', -10.5822000, 121.8062000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73709, 'Pudi', 'Pudi', 'Pudi', -10.5891000, 121.7575000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73710, 'Mehona', 'Mehona', 'Mehona', -10.5951000, 121.8335000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73711, 'Duku', 'Duku', 'Duku', -10.5971000, 121.8625000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73712, 'Danidehe', 'Danidehe', 'Danidehe', -10.6072000, 121.8214000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73713, 'Gelanalalu', 'Gelanalalu', 'Gelanalalu', -10.6030000, 121.7837000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73714, 'Lenakapa', 'Lenakapa', 'Lenakapa', -10.6012000, 121.7557000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73715, 'Waduwala', 'Waduwala', 'Waduwala', -10.6140000, 121.8634000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73716, 'Nahura', 'Nahura', 'Nahura', -10.4611000, 121.8698000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73717, 'Eikapaka', 'Eikapaka', 'Eikapaka', -10.4997000, 121.8535000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73718, 'Raejeru', 'Raejeru', 'Raejeru', -10.4555000, 121.9359000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73719, 'Padadue', 'Padadue', 'Padadue', -10.4987000, 121.9349000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73720, 'Jiwuwu', 'Jiwuwu', 'Jiwuwu', -10.4636000, 121.9600000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73721, 'Guluhawu', 'Guluhawu', 'Guluhawu', -10.4948000, 121.9766000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73722, 'Bolou', 'Bolou', 'Bolou', -10.4979000, 121.9733000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73723, 'Unukume', 'Unukume', 'Unukume', -10.5023000, 121.9783000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73724, 'Jarada', 'Jarada', 'Jarada', -10.5224000, 121.9409000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73725, 'Loboma', 'Loboma', 'Loboma', -10.5219000, 121.9666000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73726, 'Lokorae', 'Lokorae', 'Lokorae', -10.5297000, 121.9058000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73727, 'Eilau', 'Eilau', 'Eilau', -10.5454000, 121.9511000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73728, 'Kahabe', 'Kahabe', 'Kahabe', -10.5676000, 121.9306000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73729, 'Daikela', 'Daikela', 'Daikela', -10.5684000, 121.8988000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73730, 'Parajara', 'Parajara', 'Parajara', -10.5971000, 121.8889000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73731, 'Aduoen', 'Aduoen', 'Aduoen', -10.7965000, 122.8570000, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73732, 'Olo', 'Olo', 'Olo', -10.8471200, 122.8647300, 'ID', '2012-08-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73733, 'Angsana Timur', 'Angsana Timur', 'Angsana Timur', -7.0913000, 113.5430000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73734, 'Bangrat', 'Bangrat', 'Bangrat', -7.0405000, 113.6397000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73735, 'Masaran', 'Masaran', 'Masaran', -7.0503000, 113.6264000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73736, 'Pordapor Barat', 'Pordapor Barat', 'Pordapor Barat', -7.0504000, 113.6357000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73737, 'Sabitak', 'Sabitak', 'Sabitak', -7.0877000, 113.6327000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73738, 'Prengtale', 'Prengtale', 'Prengtale', -7.0972000, 113.6404000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73739, 'Banlapa', 'Banlapa', 'Banlapa', -7.0332000, 113.6597000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73740, 'Mrongi Daja', 'Mrongi Daja', 'Mrongi Daja', -7.0967000, 113.6588000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73741, 'Ketapang Daja', 'Ketapang Daja', 'Ketapang Daja', -7.1131000, 113.6527000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73742, 'Galis Dua', 'Galis Dua', 'Galis Dua', -7.1133000, 113.6441000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73743, 'Timurleke', 'Timurleke', 'Timurleke', -7.0370000, 113.6765000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73744, 'Batojaran', 'Batojaran', 'Batojaran', -7.0938000, 113.6665000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73745, 'Pragaan', 'Pragaan', 'Pragaan', -7.1109000, 113.6600000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73746, 'Masjid', 'Masjid', 'Masjid', -7.0412000, 113.6863000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73747, 'Duko', 'Duko', 'Duko', -7.0490000, 113.6889000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73748, 'Sumberkindagan', 'Sumberkindagan', 'Sumberkindagan', -7.0621000, 113.6886000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73749, 'Talambung Laok', 'Talambung Laok', 'Talambung Laok', -7.0382000, 113.7022000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73750, 'Naga', 'Naga', 'Naga', -7.0442000, 113.6933000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73751, 'Panggungdaja', 'Panggungdaja', 'Panggungdaja', -7.0532000, 113.6931000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73752, 'Barru', 'Barru', 'Barru', -7.0943000, 113.7045000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73753, 'Mangar', 'Mangar', 'Mangar', -7.0150000, 113.7187000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73754, 'Kebunan', 'Kebunan', 'Kebunan', -7.0541000, 113.7081000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73755, 'Karangjati', 'Karangjati', 'Karangjati', -7.0524000, 113.7220000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73756, 'Dajalorong', 'Dajalorong', 'Dajalorong', -7.0609000, 113.7136000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73757, 'Sumberpandan', 'Sumberpandan', 'Sumberpandan', -7.1088000, 113.7173000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73758, 'Biyan', 'Biyan', 'Biyan', -7.1105000, 113.7226000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73759, 'Jambumonyet', 'Jambumonyet', 'Jambumonyet', -7.0358000, 113.7355000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73760, 'Dajasongai', 'Dajasongai', 'Dajasongai', -7.0448600, 113.7342200, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73761, 'Loaksongai', 'Loaksongai', 'Loaksongai', -7.0505000, 113.7276000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73762, 'Sasar', 'Sasar', 'Sasar', -7.0827000, 113.7343000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73763, 'Taman', 'Taman', 'Taman', -7.0512000, 113.7445000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73764, 'Solok Timur', 'Solok Timur', 'Solok Timur', -7.0594000, 113.7474000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73765, 'Solok', 'Solok', 'Solok', -7.0687000, 113.7448000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73766, 'Pesisir', 'Pesisir', 'Pesisir', -7.1145000, 113.7489000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73767, 'Sedeoen', 'Sedeoen', 'Sedeoen', -10.8792600, 122.8302200, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73768, 'Tunggaoen Timur', 'Tunggaoen Timur', 'Tunggaoen Timur', -10.9232000, 122.8283000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73769, 'Oemau', 'Oemau', 'Oemau', -10.9340000, 122.8482000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73770, 'Leteki', 'Leteki', 'Leteki', -10.8996000, 122.9017000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73771, 'Oebou', 'Oebou', 'Oebou', -10.8986000, 122.9426000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73772, 'Oelaba', 'Oelaba', 'Oelaba', -10.7540000, 122.9123000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73773, 'Netenain', 'Netenain', 'Netenain', -10.7650000, 122.9564000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73774, 'Oetutulul', 'Oetutulul', 'Oetutulul', -10.7733000, 122.9872000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73775, 'Oebaffok Satu', 'Oebaffok Satu', 'Oebaffok Satu', -10.8144000, 122.9828000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73776, 'Modosinal', 'Modosinal', 'Modosinal', -10.7949000, 122.9617000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73777, 'Kotafeuk', 'Kotafeuk', 'Kotafeuk', -10.7862000, 122.9496000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73778, 'Faeanak Dua', 'Faeanak Dua', 'Faeanak Dua', -10.7964000, 122.9437000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73779, 'Lidor', 'Lidor', 'Lidor', -10.8454000, 122.9150000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73780, 'Lalukoen Dua', 'Lalukoen Dua', 'Lalukoen Dua', -10.8632000, 122.9266000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73781, 'Oehandi Utara', 'Oehandi Utara', 'Oehandi Utara', -10.8521000, 122.9543000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73782, 'Roioen', 'Roioen', 'Roioen', -10.8439000, 122.9526000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73783, 'Inggudale', 'Inggudale', 'Inggudale', -10.8491000, 122.9991000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73784, 'Batutua', 'Batutua', 'Batutua', -10.8593000, 122.9843000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73785, 'Batutua Satu', 'Batutua Satu', 'Batutua Satu', -10.8609000, 122.9831000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73786, 'Talambung Laok', 'Talambung Laok', 'Talambung Laok', -7.0395000, 113.6982300, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73787, 'Oemaulain', 'Oemaulain', 'Oemaulain', -10.7525000, 123.0330000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73788, 'Deranitan', 'Deranitan', 'Deranitan', -10.8614000, 123.0124000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73789, 'Laes', 'Laes', 'Laes', -10.8433000, 123.0275000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73790, 'Gayabaru', 'Gayabaru', 'Gayabaru', -10.8435000, 123.0579000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73791, 'Nggalai Barat', 'Nggalai Barat', 'Nggalai Barat', -10.8293000, 123.0201000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73792, 'Oebatu', 'Oebatu', 'Oebatu', -10.8142000, 123.0128000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73793, 'Souktuanan', 'Souktuanan', 'Souktuanan', -10.8162000, 123.0830000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73794, 'Busalangga', 'Busalangga', 'Busalangga', -10.8040000, 123.0035000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73795, 'Lekik', 'Lekik', 'Lekik', -10.7726000, 123.1001000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73796, 'Asamboka', 'Asamboka', 'Asamboka', -10.7731000, 123.0326000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73797, 'Sanggaoen', 'Sanggaoen', 'Sanggaoen', -10.7660000, 123.0437000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73798, 'Potikosin', 'Potikosin', 'Potikosin', -10.7246000, 123.0979000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73799, 'Oelunggu Satu', 'Oelunggu Satu', 'Oelunggu Satu', -10.7298000, 123.0664000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73800, 'Alukama', 'Alukama', 'Alukama', -10.7432000, 123.0464000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73801, 'Likioen', 'Likioen', 'Likioen', -10.7484000, 123.0446000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73802, 'Sukarame', 'Sukarame', 'Sukarame', -7.2170000, 113.7718000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73803, 'Kalangmangga', 'Kalangmangga', 'Kalangmangga', -7.2252000, 113.7822000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73804, 'Taman', 'Taman', 'Taman', -7.2252000, 113.7974000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73805, 'Lobuk', 'Lobuk', 'Lobuk', -7.1289000, 113.8187000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73806, 'Pagarbatu', 'Pagarbatu', 'Pagarbatu', -7.1328000, 113.8614000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73807, 'Nggenamadale', 'Nggenamadale', 'Nggenamadale', -10.7614000, 123.1966000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73808, 'Oele', 'Oele', 'Oele', -10.7852000, 123.1593000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73809, 'Folaoen Satu', 'Folaoen Satu', 'Folaoen Satu', -10.7972000, 123.2250000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73810, 'Kolobolon', 'Kolobolon', 'Kolobolon', -10.8026000, 123.1350000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73811, 'Kolla', 'Kolla', 'Kolla', -10.6579000, 123.1579000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73812, 'Momanalu', 'Momanalu', 'Momanalu', -10.6631000, 123.1415000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73813, 'Nitanggoeng', 'Nitanggoeng', 'Nitanggoeng', -10.7127000, 123.1642000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73814, 'Puamata', 'Puamata', 'Puamata', -10.7314000, 123.1322000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73815, 'Batulilok Satu', 'Batulilok Satu', 'Batulilok Satu', -10.7358000, 123.2422000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73816, 'Bengubelan', 'Bengubelan', 'Bengubelan', -10.7475000, 123.2394000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73817, 'Padusan', 'Padusan', 'Padusan', -7.0005000, 113.8754000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73818, 'Patenongan', 'Patenongan', 'Patenongan', -7.0009000, 113.8811000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73819, 'Talbantal', 'Talbantal', 'Talbantal', -7.0081000, 113.8791000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73820, 'Pasarkayu', 'Pasarkayu', 'Pasarkayu', -7.0272000, 113.8824000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73821, 'Masjid', 'Masjid', 'Masjid', -7.0385000, 113.8954000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73822, 'Palebunan', 'Palebunan', 'Palebunan', -7.0563000, 113.8787000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73823, 'Bereklorong', 'Bereklorong', 'Bereklorong', -7.0351000, 113.9070000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73824, 'Cemara', 'Cemara', 'Cemara', -7.0359000, 113.8955000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73825, 'Penatu', 'Penatu', 'Penatu', -7.0378000, 113.8989000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73826, 'Karanganyar', 'Karanganyar', 'Karanganyar', -7.0007000, 113.9180000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73827, 'Mecadan', 'Mecadan', 'Mecadan', -7.0005000, 113.9248000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73828, 'Kebunkelapa', 'Kebunkelapa', 'Kebunkelapa', -7.0437000, 113.9281000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73829, 'Padurekso', 'Padurekso', 'Padurekso', -7.0484000, 113.9421000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73830, 'Sumurasin', 'Sumurasin', 'Sumurasin', -7.0765000, 113.9399000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73831, 'Talango', 'Talango', 'Talango', -7.0630000, 113.9507000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73832, 'Mandala', 'Mandala', 'Mandala', -7.0001000, 113.9697000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73833, 'Darmaayu', 'Darmaayu', 'Darmaayu', -7.0001000, 113.9732000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73834, 'Daeosin Satu', 'Daeosin Satu', 'Daeosin Satu', -10.6245000, 123.1965000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73835, 'Biuk', 'Biuk', 'Biuk', -10.6033000, 123.2127000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73836, 'Paobulan', 'Paobulan', 'Paobulan', -6.9967000, 112.8419000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73837, 'Timurembong', 'Timurembong', 'Timurembong', -6.9964000, 112.7812000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73838, 'Kalkal Barat', 'Kalkal Barat', 'Kalkal Barat', -6.9965000, 112.8193000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73839, 'Panjun', 'Panjun', 'Panjun', -6.9944000, 112.8263000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73840, 'Balung Barat', 'Balung Barat', 'Balung Barat', -6.9695000, 112.8282000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73841, 'Gintongan', 'Gintongan', 'Gintongan', -6.9088000, 112.8650000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73842, 'Kool Tengah', 'Kool Tengah', 'Kool Tengah', -6.9195000, 112.8446000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73843, 'Sebuh', 'Sebuh', 'Sebuh', -6.9191000, 112.8564000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73844, 'Trogan Barat', 'Trogan Barat', 'Trogan Barat', -6.9237000, 112.8607000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73845, 'Raas', 'Raas', 'Raas', -6.9281000, 112.8461000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73846, 'Mursaba', 'Mursaba', 'Mursaba', -6.9717000, 112.8592000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73847, 'Moarah Barat', 'Moarah Barat', 'Moarah Barat', -6.9355000, 112.8406000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73848, 'Lebak Timur', 'Lebak Timur', 'Lebak Timur', -6.9400000, 112.8383000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73849, 'Polongan Daja', 'Polongan Daja', 'Polongan Daja', -6.9409000, 112.8652000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73850, 'Karangasem Laok', 'Karangasem Laok', 'Karangasem Laok', -6.9360000, 112.8633000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73851, 'Makan', 'Makan', 'Makan', -6.9485000, 112.8575000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73852, 'Ketampak', 'Ketampak', 'Ketampak', -6.9876000, 112.7875000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73853, 'Ta’anyar', 'Ta''anyar', 'Ta''anyar,Ta’anyar', -6.9505000, 112.8442000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73854, 'Karangpao', 'Karangpao', 'Karangpao', -6.9545000, 112.8512000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73855, 'Tambeggan Satu', 'Tambeggan Satu', 'Tambeggan Satu', -6.9540000, 112.8541000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73856, 'Cendagah', 'Cendagah', 'Cendagah', -6.9571000, 112.8531000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73857, 'Berbeluk Timur', 'Berbeluk Timur', 'Berbeluk Timur', -6.9625000, 112.8642000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73858, 'Mangkon Daja', 'Mangkon Daja', 'Mangkon Daja', -6.9602000, 112.8521000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73859, 'Makamagung', 'Makamagung', 'Makamagung', -6.9577000, 112.8481000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73860, 'Dlemer', 'Dlemer', 'Dlemer', -6.9625000, 112.8468000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73861, 'Karangduwak', 'Karangduwak', 'Karangduwak', -6.9788000, 112.8473000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73862, 'Ombul Barat', 'Ombul Barat', 'Ombul Barat', -6.9880000, 112.8346000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73863, 'Nesubatu', 'Nesubatu', 'Nesubatu', -10.6496000, 123.3303000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73864, 'Fukadale', 'Fukadale', 'Fukadale', -10.6818000, 123.3537000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73865, 'Bebengu', 'Bebengu', 'Bebengu', -10.6981000, 123.3114000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73866, 'Puan Selatan', 'Puan Selatan', 'Puan Selatan', -10.7141000, 123.2908000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73867, 'Kandang', 'Kandang', 'Kandang', -6.9322000, 112.8792000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73868, 'Basen', 'Basen', 'Basen', -6.9606000, 112.8759000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73869, 'Doroagung', 'Doroagung', 'Doroagung', -6.9637000, 112.8764000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73870, 'Batambak', 'Batambak', 'Batambak', -6.9976000, 112.9813000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73871, 'Sahplasah', 'Sahplasah', 'Sahplasah', -6.9691000, 112.9981000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73872, 'Baratleke', 'Baratleke', 'Baratleke', -6.9506000, 112.9961000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73873, 'Jeratmaling', 'Jeratmaling', 'Jeratmaling', -6.8970000, 112.9963000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73874, 'Masaran', 'Masaran', 'Masaran', -6.8873000, 112.9872000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73875, 'Pesisir', 'Pesisir', 'Pesisir', -6.8890000, 112.9655000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73876, 'Bator', 'Bator', 'Bator', -6.8963000, 112.9019000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73877, 'Balong', 'Balong', 'Balong', -6.8937000, 112.9108000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73878, 'Tenggun Dajah', 'Tenggun Dajah', 'Tenggun Dajah', -6.8971000, 112.9175000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73879, 'Birempa', 'Birempa', 'Birempa', -6.9004000, 112.9240000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73880, 'Laranganglintong', 'Laranganglintong', 'Laranganglintong', -6.8961000, 112.9320000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73881, 'Karang', 'Karang', 'Karang', -6.8953000, 112.9394000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73882, 'Jeleuk', 'Jeleuk', 'Jeleuk', -6.8930000, 112.9638000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73883, 'Marlabeng', 'Marlabeng', 'Marlabeng', -6.8943000, 112.9838000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73884, 'Lendan', 'Lendan', 'Lendan', -6.9028000, 112.9709000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73885, 'Rojing', 'Rojing', 'Rojing', -6.9078000, 112.8829000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73886, 'Bindang', 'Bindang', 'Bindang', -6.9174000, 112.9614000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73887, 'Glugur', 'Glugur', 'Glugur', -6.9232000, 112.9143000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73888, 'Ambat', 'Ambat', 'Ambat', -6.9230000, 112.8876000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73889, 'Bragang Tengah', 'Bragang Tengah', 'Bragang Tengah', -6.9350000, 112.9056000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73890, 'Nakajah', 'Nakajah', 'Nakajah', -6.9458000, 112.9113000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73891, 'Labang', 'Labang', 'Labang', -6.9466000, 112.9583000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73892, 'Longka', 'Longka', 'Longka', -6.9458000, 112.9653000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73893, 'Terbuh', 'Terbuh', 'Terbuh', -6.9576000, 112.9056000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73894, 'Palenggihan', 'Palenggihan', 'Palenggihan', -6.9621000, 112.9277000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73895, 'Pakes', 'Pakes', 'Pakes', -6.9651000, 112.9849000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73896, 'Koronganayam', 'Koronganayam', 'Koronganayam', -6.9784000, 112.9409000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73897, 'Torserajah', 'Torserajah', 'Torserajah', -6.9797000, 112.8991000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73898, 'Kenamoen', 'Kenamoen', 'Kenamoen', -10.5411000, 123.2875000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73899, 'Hailean', 'Hailean', 'Hailean', -10.6214000, 123.3615000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73900, 'Karafao', 'Karafao', 'Karafao', -10.5817000, 123.2590000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73901, 'Oesuti Dua', 'Oesuti Dua', 'Oesuti Dua', -10.6160000, 123.3092000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73902, 'Sua', 'Sua', 'Sua', -10.6210000, 123.2637000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73903, 'Sowau', 'Sowau', 'Sowau', -10.5694000, 123.3753000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73904, 'Tuanai', 'Tuanai', 'Tuanai', -10.6146000, 123.3875000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73905, 'Baeoen', 'Baeoen', 'Baeoen', -10.6266400, 123.3963600, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73906, 'Talon', 'Talon', 'Talon', -6.9003000, 113.0014000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73907, 'Rukgaruk', 'Rukgaruk', 'Rukgaruk', -6.9544000, 113.0022000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73908, 'Mandepa Barat', 'Mandepa Barat', 'Mandepa Barat', -6.9888000, 113.0036000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73909, 'Lobuk', 'Lobuk', 'Lobuk', -6.8943000, 113.1236000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73910, 'Timur', 'Timur', 'Timur', -6.8856000, 113.0286000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73911, 'Temana', 'Temana', 'Temana', -6.8894000, 113.0450000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73912, 'Pangalangan', 'Pangalangan', 'Pangalangan', -6.8913000, 113.0621000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73913, 'Dangkah', 'Dangkah', 'Dangkah', -6.9078000, 113.0641000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73914, 'Pedaringan', 'Pedaringan', 'Pedaringan', -6.9021000, 113.0268000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73915, 'Pakpak', 'Pakpak', 'Pakpak', -6.9125000, 113.0240000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73916, 'Korogan Timur', 'Korogan Timur', 'Korogan Timur', -6.9322000, 113.0284000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73917, 'Masjid', 'Masjid', 'Masjid', -6.9197000, 113.0304000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73918, 'Kerbuyan', 'Kerbuyan', 'Kerbuyan', -6.9663000, 113.0286000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73919, 'Sreseh', 'Sreseh', 'Sreseh', -6.9514000, 113.0643000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73920, 'Dangbigih', 'Dangbigih', 'Dangbigih', -6.9700000, 113.0758000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73921, 'Dangbigih', 'Dangbigih', 'Dangbigih', -6.9872000, 113.0875000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73922, 'Tanahmerah', 'Tanahmerah', 'Tanahmerah', -6.9117000, 113.1058000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73923, 'Sokadan', 'Sokadan', 'Sokadan', -6.9174000, 113.0914000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73924, 'Rangmanten', 'Rangmanten', 'Rangmanten', -6.8903000, 113.0852000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73925, 'Tebanah', 'Tebanah', 'Tebanah', -6.9096000, 113.0781000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73926, 'Karang Tengah', 'Karang Tengah', 'Karang Tengah', -6.8883000, 113.0805000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73927, 'Kaisalun', 'Kaisalun', 'Kaisalun', -10.3016000, 123.3573000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73928, 'Batakte', 'Batakte', 'Batakte', -10.2559000, 123.5566000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73929, 'Oenesu', 'Oenesu', 'Oenesu', -10.2624000, 123.5682000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73930, 'Luti', 'Luti', 'Luti', -10.2545000, 123.6040000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73931, 'Klamik', 'Klamik', 'Klamik', -10.3201000, 123.4942000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73932, 'Uiasa', 'Uiasa', 'Uiasa', -10.1542000, 123.4625000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73933, 'Otan', 'Otan', 'Otan', -10.1732000, 123.3891000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73934, 'Koblain', 'Koblain', 'Koblain', -10.1680000, 123.4767000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73935, 'Uitao', 'Uitao', 'Uitao', -10.1907000, 123.4073000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73936, 'Huilelot', 'Huilelot', 'Huilelot', -10.1897000, 123.4417000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73937, 'Piaklain', 'Piaklain', 'Piaklain', -10.2117000, 123.3839000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73938, 'Pasirpanjang', 'Pasirpanjang', 'Pasirpanjang', -10.1561000, 123.6021000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73939, 'Todekisar', 'Todekisar', 'Todekisar', -10.1577000, 123.5842000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73940, 'Fatufeto', 'Fatufeto', 'Fatufeto', -10.1635000, 123.5751000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73941, 'Mukifeto', 'Mukifeto', 'Mukifeto', -10.3157000, 123.6204000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73942, 'Tasikona', 'Tasikona', 'Tasikona', -10.3568000, 123.6207000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73943, 'Tuanak', 'Tuanak', 'Tuanak', -10.3081000, 123.5119000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73944, 'Oematnunu', 'Oematnunu', 'Oematnunu', -10.2931000, 123.5382000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73945, 'Sumlili', 'Sumlili', 'Sumlili', -10.3007000, 123.5473000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73946, 'Timon', 'Timon', 'Timon', -10.3172000, 123.6069000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73947, 'Bonipoi', 'Bonipoi', 'Bonipoi', -10.1616600, 123.5802800, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73948, 'Solor', 'Solor', 'Solor', -10.1609000, 123.5819000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73949, 'Fontein', 'Fontein', 'Fontein', -10.1661000, 123.5822000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73950, 'Merdeka', 'Merdeka', 'Merdeka', -10.1620000, 123.5865000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73951, 'Oetete', 'Oetete', 'Oetete', -10.1650000, 123.5873000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73952, 'Oeba', 'Oeba', 'Oeba', -10.1594000, 123.5918000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73953, 'Oebufu', 'Oebufu', 'Oebufu', -10.1786000, 123.6210000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73954, 'Oebobo', 'Oebobo', 'Oebobo', -10.1678000, 123.5992000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73955, 'Kuanino', 'Kuanino', 'Kuanino', -10.1709000, 123.5898000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73956, 'Naikoten Dua', 'Naikoten Dua', 'Naikoten Dua', -10.1729000, 123.5980000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73957, 'Airnona', 'Airnona', 'Airnona', -10.1814000, 123.5847000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73958, 'Airmata', 'Airmata', 'Airmata', -10.1663000, 123.5777000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73959, 'Mantasi', 'Mantasi', 'Mantasi', -10.1733000, 123.5804000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73960, 'Manutapen', 'Manutapen', 'Manutapen', -10.1766000, 123.5764000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73961, 'Nunhila', 'Nunhila', 'Nunhila', -10.1675000, 123.5714000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73962, 'Nunbaundelha', 'Nunbaundelha', 'Nunbaundelha', -10.1720000, 123.5698000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73963, 'Nunbaunsabu', 'Nunbaunsabu', 'Nunbaunsabu', -10.1724000, 123.5662000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73964, 'Alak', 'Alak', 'Alak', -10.1973000, 123.5334000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73965, 'Airsagu', 'Airsagu', 'Airsagu', -10.1999000, 123.5800000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73966, 'Bakunase', 'Bakunase', 'Bakunase', -10.1860000, 123.5864000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73967, 'Oepura', 'Oepura', 'Oepura', -10.1890000, 123.6076000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73968, 'Bonik', 'Bonik', 'Bonik', -10.2016000, 123.6056000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73969, 'Tabun', 'Tabun', 'Tabun', -10.2175000, 123.5751000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73970, 'Kuanheum', 'Kuanheum', 'Kuanheum', -10.2403000, 123.5109000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73971, 'Bolok', 'Bolok', 'Bolok', -10.2250000, 123.5186000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73972, 'Kuanfeu', 'Kuanfeu', 'Kuanfeu', -10.2272000, 123.5266000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73973, 'Fatukoa', 'Fatukoa', 'Fatukoa', -10.2315000, 123.6069000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73974, 'Lai Lai Bisi Kopan', 'Lai Lai Bisi Kopan', 'Lai Lai Bisi Kopan', -10.1628000, 123.5781000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73975, 'Lobuk', 'Lobuk', 'Lobuk', -6.8943000, 113.1264000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73976, 'Pajung', 'Pajung', 'Pajung', -6.8982000, 113.2463000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73977, 'Nepa', 'Nepa', 'Nepa', -6.8964000, 113.2136000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73978, 'Ramaram', 'Ramaram', 'Ramaram', -6.8982000, 113.1705000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73979, 'Sembung', 'Sembung', 'Sembung', -6.8936000, 113.1498000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73980, 'Mandeman Daya', 'Mandeman Daya', 'Mandeman Daya', -6.9000000, 113.1565000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73981, 'Kapasan', 'Kapasan', 'Kapasan', -6.8996000, 113.1860000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73982, 'Masaran', 'Masaran', 'Masaran', -6.9116000, 113.2323000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73983, 'Tlagah Timur', 'Tlagah Timur', 'Tlagah Timur', -6.9153000, 113.2127000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73984, 'Morbatoh', 'Morbatoh', 'Morbatoh', -6.9168000, 113.1660000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73985, 'Pandian', 'Pandian', 'Pandian', -6.9163000, 113.1449000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73986, 'Minian', 'Minian', 'Minian', -6.9159000, 113.1389000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73987, 'Korbukor', 'Korbukor', 'Korbukor', -6.9234000, 113.1926000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73988, 'Tebanah', 'Tebanah', 'Tebanah', -6.9213000, 113.2043000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73989, 'Tiara', 'Tiara', 'Tiara', -6.9403000, 113.1341000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73990, 'Sebegen', 'Sebegen', 'Sebegen', -6.9480000, 113.1874000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73991, 'Tapaan Timur', 'Tapaan Timur', 'Tapaan Timur', -6.9525000, 113.1640000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73992, 'Taposan', 'Taposan', 'Taposan', -6.9579000, 113.1741000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73993, 'Galis', 'Galis', 'Galis', -6.9672000, 113.2212000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73994, 'Tenggina Daya', 'Tenggina Daya', 'Tenggina Daya', -6.9596000, 113.1965000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73995, 'Bateke', 'Bateke', 'Bateke', -6.9629000, 113.1754000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73996, 'Baih', 'Baih', 'Baih', -6.9706000, 113.1353000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73997, 'Kiupakas', 'Kiupakas', 'Kiupakas', -10.2739700, 123.6583300, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73998, 'Tanenofunan', 'Tanenofunan', 'Tanenofunan', -10.2700900, 123.6745500, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(73999, 'Nonpuah', 'Nonpuah', 'Nonpuah', -10.2555500, 123.6679200, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74000, 'Bieto', 'Bieto', 'Bieto', -10.2891700, 123.7003700, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74001, 'Soba', 'Soba', 'Soba', -10.2840700, 123.7215100, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74002, 'Oeri’u', 'Oeri''u', 'Oeri''u,Oeri’u', -10.3100000, 123.6998300, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74003, 'Sonaf', 'Sonaf', 'Sonaf', -10.3202000, 123.7127700, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74004, 'Oesain', 'Oesain', 'Oesain', -10.3530300, 123.7406700, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74005, 'Potibaun', 'Potibaun', 'Potibaun', -10.2758700, 123.7394000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74006, 'Sumberbakti', 'Sumberbakti', 'Sumberbakti', -6.8960000, 113.2737000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74007, 'Duk Timur', 'Duk Timur', 'Duk Timur', -6.8926000, 113.2874000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74008, 'Gilin', 'Gilin', 'Gilin', -6.8960000, 113.3130000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74009, 'Tetean', 'Tetean', 'Tetean', -6.8913000, 113.3510000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74010, 'Kendung Timur', 'Kendung Timur', 'Kendung Timur', -6.9185000, 113.3676000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74011, 'Ragung', 'Ragung', 'Ragung', -6.9434000, 113.3702000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74012, 'Jalgung', 'Jalgung', 'Jalgung', -6.9973000, 113.2809000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74013, 'Derbing', 'Derbing', 'Derbing', -6.9951000, 113.2586000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74014, 'Dampol', 'Dampol', 'Dampol', -6.9131000, 113.2513000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74015, 'Taman', 'Taman', 'Taman', -6.9104000, 113.2793000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74016, 'Sorren Daya', 'Sorren Daya', 'Sorren Daya', -6.9236000, 113.2611000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74017, 'Kemereh', 'Kemereh', 'Kemereh', -6.9415800, 113.3576900, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74018, 'Tengah', 'Tengah', 'Tengah', -6.9467000, 113.3021000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74019, 'Tengah', 'Tengah', 'Tengah', -6.9413000, 113.2848000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74020, 'Kemiri Daya', 'Kemiri Daya', 'Kemiri Daya', -6.9700000, 113.2718000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74021, 'Lekedalem', 'Lekedalem', 'Lekedalem', -6.9789000, 113.3261000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74022, 'Nanger', 'Nanger', 'Nanger', -6.9836000, 113.3066000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74023, 'Bungkeduk', 'Bungkeduk', 'Bungkeduk', -6.9631000, 113.3777000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74024, 'Batulenger Barat', 'Batulenger Barat', 'Batulenger Barat', -6.8890000, 113.3835000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74025, 'Bira', 'Bira', 'Bira', -6.8998000, 113.3917000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74026, 'Duwakkandung', 'Duwakkandung', 'Duwakkandung,Duwekondung', -6.9924000, 113.3859000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74027, 'Kopok', 'Kopok', 'Kopok', -6.9436000, 113.4060000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74028, 'Palecenan', 'Palecenan', 'Palecenan', -6.9557000, 113.4028000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74029, 'Kombangan', 'Kombangan', 'Kombangan', -6.9891000, 113.4064000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74030, 'Pangtangis Dajah', 'Pangtangis Dajah', 'Pangtangis Dajah', -6.9203000, 113.4257000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74031, 'Kranjih', 'Kranjih', 'Kranjih', -6.9354000, 113.4503000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74032, 'Secang Barat', 'Secang Barat', 'Secang Barat', -6.9738000, 113.4418000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74033, 'Nongkesan', 'Nongkesan', 'Nongkesan', -6.9281000, 113.4598000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74034, 'Bukbatang', 'Bukbatang', 'Bukbatang', -6.8956000, 113.4758000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74035, 'Pandeyan', 'Pandeyan', 'Pandeyan', -6.8993000, 113.4790000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74036, 'Kalebun', 'Kalebun', 'Kalebun', -6.9434000, 113.4837000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74037, 'Nomih', 'Nomih', 'Nomih', -6.9828000, 113.4857000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74038, 'Lonpao Dajah', 'Lonpao Dajah', 'Lonpao Dajah', -6.8989000, 113.4891000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74039, 'Baban', 'Baban', 'Baban', -6.9266000, 113.4911000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74040, 'Nunutba', 'Nunutba', 'Nunutba', -10.2183000, 123.6274000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74041, 'Naimata', 'Naimata', 'Naimata', -10.1841000, 123.6405000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74042, 'Liliba', 'Liliba', 'Liliba', -10.1733000, 123.6374000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74043, 'Kolhua', 'Kolhua', 'Kolhua', -10.2139000, 123.6425000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74044, 'Tualeu', 'Tualeu', 'Tualeu', -10.2475900, 123.6560500, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74045, 'Penfui', 'Penfui', 'Penfui', -10.1766000, 123.6581000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74046, 'Lasiana', 'Lasiana', 'Lasiana', -10.1371000, 123.6690000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74047, 'Oeltua', 'Oeltua', 'Oeltua', -10.2139000, 123.6763000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74048, 'Mekon', 'Mekon', 'Mekon', -10.1633000, 123.6880000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74049, 'Tarus', 'Tarus', 'Tarus', -10.1329000, 123.6878000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74050, 'Kolomanu', 'Kolomanu', 'Kolomanu', -10.2413000, 123.6990000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74051, 'Oehani', 'Oehani', 'Oehani', -10.2314000, 123.7095000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74052, 'Kiuteta', 'Kiuteta', 'Kiuteta', -10.1276000, 123.7112000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74053, 'Bijaenaka', 'Bijaenaka', 'Bijaenaka', -10.1479000, 123.7464000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74054, 'Sangoleng', 'Sangoleng', 'Sangoleng', -6.9001000, 113.5144000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74055, 'Brumbung Laok', 'Brumbung Laok', 'Brumbung Laok', -6.9271000, 113.5165000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74056, 'Rapas', 'Rapas', 'Rapas', -6.9366000, 113.5121000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74057, 'Timur Dajah', 'Timur Dajah', 'Timur Dajah', -6.8971000, 113.5218000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74058, 'Rokem Barat', 'Rokem Barat', 'Rokem Barat', -6.8973000, 113.5316000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74059, 'Danpateh', 'Danpateh', 'Danpateh', -6.9293000, 113.5368000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74060, 'Wakduwa’ Barat', 'Wakduwa'' Barat', 'Wakduwa'' Barat,Wakduwa’ Barat', -6.9394000, 113.5273000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74061, 'Pregi', 'Pregi', 'Pregi', -6.9810000, 113.5398000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74062, 'Tengah', 'Tengah', 'Tengah', -6.9200000, 113.5364000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74063, 'Tengah', 'Tengah', 'Tengah', -6.9313000, 113.5515000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74064, 'Telangi Satu', 'Telangi Satu', 'Telangi Satu', -6.9451000, 113.5464000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74065, 'Gunungtengah', 'Gunungtengah', 'Gunungtengah', -6.9653000, 113.5521000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74066, 'Oro Timur', 'Oro Timur', 'Oro Timur', -6.8954000, 113.5713000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74067, 'Laokgunung', 'Laokgunung', 'Laokgunung', -6.9489000, 113.5825000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74068, 'Lanpelan', 'Lanpelan', 'Lanpelan', -6.9819000, 113.5989000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74069, 'Masaran', 'Masaran', 'Masaran', -6.9869000, 113.5950000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74070, 'Toroy', 'Toroy', 'Toroy', -6.9179000, 113.6087000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74071, 'Langdulang', 'Langdulang', 'Langdulang', -6.9508000, 113.6066000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74072, 'Duko', 'Duko', 'Duko', -6.9189000, 113.6224000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74073, 'Paolasen', 'Paolasen', 'Paolasen,Paolaseng', -6.9993000, 113.5325000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74074, 'Batuna Satu', 'Batuna Satu', 'Batuna Satu', -10.2551000, 123.7755000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74075, 'Sonraen', 'Sonraen', 'Sonraen', -10.2862000, 123.8456000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74076, 'Buraen', 'Buraen', 'Buraen', -10.2859000, 123.8578000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74077, 'Habo', 'Habo', 'Habo', -10.3110000, 123.8371000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74078, 'Oekuu', 'Oekuu', 'Oekuu', -10.3270000, 123.7881000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74079, 'Banupo', 'Banupo', 'Banupo', -10.1445000, 123.7787000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74080, 'Nis’oni', 'Nis''oni', 'Nis''oni,Nis’oni', -10.1399000, 123.8458000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74081, 'Kuanheum', 'Kuanheum', 'Kuanheum', -10.1733000, 123.8735000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74082, 'Fuan', 'Fuan', 'Fuan', -10.2079000, 123.7745000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74083, 'Hausisi', 'Hausisi', 'Hausisi', -10.2359000, 123.8259000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74084, 'Oibioin', 'Oibioin', 'Oibioin', -10.2167000, 123.8222000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74085, 'Ponain', 'Ponain', 'Ponain', -10.2075000, 123.8523000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74086, 'Kampungbaru', 'Kampungbaru', 'Kampungbaru', -9.9090000, 123.6493000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74087, 'Oeteta', 'Oeteta', 'Oeteta', -10.0126000, 123.7561000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74088, 'Bipolo', 'Bipolo', 'Bipolo', -10.0191000, 123.8217000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74089, 'Nunkurus', 'Nunkurus', 'Nunkurus', -10.0635000, 123.8268000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74090, 'Tuapukan', 'Tuapukan', 'Tuapukan', -10.1087000, 123.7740000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74091, 'Merdeka', 'Merdeka', 'Merdeka', -10.1067000, 123.7793000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74092, 'Taklale', 'Taklale', 'Taklale', -10.1073000, 123.7994000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74093, 'Naibonat', 'Naibonat', 'Naibonat', -10.1033000, 123.8257000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74094, 'Naifalo', 'Naifalo', 'Naifalo', -9.9755000, 123.8731000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74095, 'Oelbiteno', 'Oelbiteno', 'Oelbiteno', -9.9251000, 123.8427000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74096, 'Siumate', 'Siumate', 'Siumate', -9.8415000, 123.6933000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74097, 'Tunmunih', 'Tunmunih', 'Tunmunih', -10.0470000, 123.9833000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74098, 'Naikolan', 'Naikolan', 'Naikolan', -10.0516000, 123.9209000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74099, 'Oenaek', 'Oenaek', 'Oenaek', -10.0348000, 123.9228000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74100, 'Muke', 'Muke', 'Muke', -10.1212000, 124.0983000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74101, 'Oenuntono', 'Oenuntono', 'Oenuntono', -10.0924000, 124.0693000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74102, 'Oemofa', 'Oemofa', 'Oemofa', -10.0879000, 124.1149000, 'ID', '2012-09-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74103, 'Cangkreng', 'Cangkreng', 'Cangkreng', -6.9673000, 112.9595000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74104, 'Bandungan Timur', 'Bandungan Timur', 'Bandungan Timur', -6.9634000, 113.4884000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74105, 'Jepon', 'Jepon', 'Jepon', -6.9123000, 113.6287000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74106, 'Komes', 'Komes', 'Komes', -6.9766000, 113.6334000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74107, 'Bilamabuk', 'Bilamabuk', 'Bilamabuk', -6.9849000, 113.6433000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74108, 'Kokembang', 'Kokembang', 'Kokembang', -6.9524000, 113.6487000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74109, 'Den Timur', 'Den Timur', 'Den Timur', -6.9634000, 113.6771000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74110, 'Duwakbuter', 'Duwakbuter', 'Duwakbuter', -6.9093000, 113.6846000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74111, 'Langgulang', 'Langgulang', 'Langgulang', -6.9267000, 113.7006000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74112, 'Samparna', 'Samparna', 'Samparna', -6.9866000, 113.6930000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74113, 'Durbugan', 'Durbugan', 'Durbugan', -6.9040000, 113.7056000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74114, 'Pakis', 'Pakis', 'Pakis', -6.9492000, 113.6980000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74115, 'Pandan', 'Pandan', 'Pandan', -6.8892000, 113.7280000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74116, 'Candi', 'Candi', 'Candi', -6.9128000, 113.7465000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74117, 'Gunungtunggal', 'Gunungtunggal', 'Gunungtunggal', -6.9193000, 113.7295000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74118, 'Naekan', 'Naekan', 'Naekan', -6.9260000, 113.7412000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74119, 'Pedatar Timur', 'Pedatar Timur', 'Pedatar Timur', -6.9418000, 113.7391000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74120, 'Bonak', 'Bonak', 'Bonak', -9.8949000, 123.8961000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74121, 'Ekateta', 'Ekateta', 'Ekateta', -9.9708000, 123.9480000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74122, 'Koa', 'Koa', 'Koa', -9.9313000, 124.0901000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74123, 'Kusbese', 'Kusbese', 'Kusbese,Kusbesi', -9.9479000, 124.0005000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74124, 'Takari', 'Takari', 'Takari', -9.9727000, 124.0469000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74125, 'Tubunain', 'Tubunain', 'Tubunain', -9.9815000, 124.1179000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74126, 'Palampal', 'Palampal', 'Palampal', -6.9670000, 113.7517000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74127, 'Timursabah', 'Timursabah', 'Timursabah', -6.9510000, 113.7559000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74128, 'Salegading', 'Salegading', 'Salegading', -6.9392000, 113.7538000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74129, 'Naikan', 'Naikan', 'Naikan', -6.9172000, 113.7527000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74130, 'Bukabu', 'Bukabu', 'Bukabu', -6.9014000, 113.7519000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74131, 'Campor', 'Campor', 'Campor', -6.8872000, 113.7593000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74132, 'Daleman', 'Daleman', 'Daleman', -6.8965000, 113.7606000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74133, 'Ares Tengah', 'Ares Tengah', 'Ares Tengah', -6.8905000, 113.7790000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74134, 'Bata Tengah', 'Bata Tengah', 'Bata Tengah', -6.9057000, 113.7775000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74135, 'Gunong', 'Gunong', 'Gunong', -6.9292000, 113.7813000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74136, 'Keles Timur', 'Keles Timur', 'Keles Timur', -6.9321000, 113.7741000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74137, 'Dajalorong', 'Dajalorong', 'Dajalorong', -6.9371000, 113.7688000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74138, 'Bun Barat', 'Bun Barat', 'Bun Barat', -6.9547000, 113.7802000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74139, 'Burneh', 'Burneh', 'Burneh', -6.9804000, 113.7776000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74140, 'Tajan', 'Tajan', 'Tajan', -6.8977000, 113.7907000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74141, 'Kaceng', 'Kaceng', 'Kaceng', -6.9138000, 113.7952000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74142, 'Tengah', 'Tengah', 'Tengah', -6.9280000, 113.7921000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74143, 'Laok', 'Laok', 'Laok', -6.9378000, 113.8018000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74144, 'Daja', 'Daja', 'Daja', -6.9498000, 113.7984000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74145, 'Betangan', 'Betangan', 'Betangan', -6.8945000, 113.8033000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74146, 'Daja', 'Daja', 'Daja', -6.9188000, 113.8132000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74147, 'Banasare Barat', 'Banasare Barat', 'Banasare Barat', -6.9635000, 113.8011000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74148, 'Banakaja', 'Banakaja', 'Banakaja', -6.9758000, 113.8009000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74149, 'Korbak', 'Korbak', 'Korbak', -6.8952000, 113.8177000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74150, 'Gununglajang', 'Gununglajang', 'Gununglajang', -6.9465000, 113.8331000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74151, 'Kleker', 'Kleker', 'Kleker', -6.9667000, 113.8240000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74152, 'Keleleng', 'Keleleng', 'Keleleng', -6.9895000, 113.8191000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74153, 'Kombang', 'Kombang', 'Kombang', -6.8984000, 113.8403000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74154, 'Karangpocok', 'Karangpocok', 'Karangpocok', -6.9209000, 113.8478000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74155, 'Jungjungan', 'Jungjungan', 'Jungjungan', -6.9344000, 113.8386000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74156, 'Cangkreng', 'Cangkreng', 'Cangkreng', -6.9712000, 113.8437000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74157, 'Oro', 'Oro', 'Oro', -6.9748000, 113.8366000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74158, 'Bungereng', 'Bungereng', 'Bungereng', -6.9070000, 113.8666000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74159, 'Giring Barat', 'Giring Barat', 'Giring Barat', -6.9668000, 113.8680000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74160, 'Ganjur', 'Ganjur', 'Ganjur', -6.9806000, 113.8602000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74161, 'Senmasen', 'Senmasen', 'Senmasen', -6.9891000, 113.8650000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74162, 'Tubuhue', 'Tubuhue', 'Tubuhue', -9.8851000, 124.2455000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74163, 'Kuatnana', 'Kuatnana', 'Kuatnana', -9.8937000, 124.2243000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74164, 'Hane', 'Hane', 'Hane', -9.9147000, 124.2223000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74165, 'Kampungtengah', 'Kampungtengah', 'Kampungtengah', -9.9246000, 124.1421000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74166, 'Taekas', 'Taekas', 'Taekas', -9.9340000, 124.1723000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74167, 'Oehumusu', 'Oehumusu', 'Oehumusu', -9.9396000, 124.1984000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74168, 'Kuafeu', 'Kuafeu', 'Kuafeu', -9.9544000, 124.1255000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74169, 'Tubunaen', 'Tubunaen', 'Tubunaen', -9.9788000, 124.1392000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74170, 'Oebai', 'Oebai', 'Oebai', -9.9831000, 124.1849000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74171, 'Neonmat', 'Neonmat', 'Neonmat', -9.8757000, 124.3317000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74172, 'Oemanu', 'Oemanu', 'Oemanu', -9.9250000, 124.2836000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74173, 'Tuaneten', 'Tuaneten', 'Tuaneten', -9.9976000, 124.2743000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74174, 'Mnelalete', 'Mnelalete', 'Mnelalete', -9.8860000, 124.3112000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74175, 'Pusu', 'Pusu', 'Pusu', -9.8968000, 124.3204000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74176, 'Tuanalepe', 'Tuanalepe', 'Tuanalepe', -9.9404000, 124.3147000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74177, 'Naensaet', 'Naensaet', 'Naensaet', -9.9865000, 124.3316000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74178, 'Siso', 'Siso', 'Siso', -9.8719000, 124.2209000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74179, 'Nunbaki', 'Nunbaki', 'Nunbaki', -9.8481000, 124.1668000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74180, 'Neofbaun', 'Neofbaun', 'Neofbaun', -9.8529000, 124.2342000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74181, 'Nefonaek', 'Nefonaek', 'Nefonaek', -9.7518000, 124.2958000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74182, 'Oenunu', 'Oenunu', 'Oenunu', -9.8543000, 124.2531000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74183, 'Oekamusa', 'Oekamusa', 'Oekamusa', -9.8747000, 124.3064000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74184, 'Numeto', 'Numeto', 'Numeto', -9.7677000, 124.2759000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74185, 'Sakteo', 'Sakteo', 'Sakteo', -9.7955000, 124.2800000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74186, 'Nifuboko', 'Nifuboko', 'Nifuboko', -9.8580000, 124.2698000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74187, 'Kampungbaru', 'Kampungbaru', 'Kampungbaru', -9.8630000, 124.2799000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74188, 'Rote', 'Rote', 'Rote', -9.8662000, 124.2748000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74189, 'Oeana', 'Oeana', 'Oeana', -9.8676000, 124.2584000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74190, 'Nonohonis', 'Nonohonis', 'Nonohonis', -9.8450000, 124.2858000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74191, 'Oefau', 'Oefau', 'Oefau', -9.8491000, 124.2962000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74192, 'Kotabaru', 'Kotabaru', 'Kotabaru', -9.8568000, 124.2865000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74193, 'Taubneno', 'Taubneno', 'Taubneno', -9.8615000, 124.2850000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74194, 'Oekefan', 'Oekefan', 'Oekefan', -9.8605000, 124.2901000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74195, 'Nunumeu Timur', 'Nunumeu Timur', 'Nunumeu Timur', -9.8626000, 124.2993000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74196, 'Oepuah', 'Oepuah', 'Oepuah', -9.8714000, 124.3025000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74197, 'Polo Satu', 'Polo Satu', 'Polo Satu', -9.7943000, 124.3550000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74198, 'Kusi', 'Kusi', 'Kusi', -9.8640000, 124.3625000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74199, 'Mio', 'Mio', 'Mio', -9.8414000, 124.3424000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74200, 'Oepula', 'Oepula', 'Oepula', -9.8726000, 124.3365000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74201, 'Oebesa', 'Oebesa', 'Oebesa', -9.8665000, 124.2903000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74202, 'Talondang', 'Talondang', 'Talondang', -6.8787000, 113.9035000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74203, 'Bulubarat', 'Bulubarat', 'Bulubarat', -6.8768000, 113.9178000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74204, 'Perreng', 'Perreng', 'Perreng', -6.8762000, 113.9689000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74205, 'Gunungpapan', 'Gunungpapan', 'Gunungpapan', -6.8835000, 113.9557000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74206, 'Gunung Timur', 'Gunung Timur', 'Gunung Timur', -6.8839000, 113.8909000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74207, 'Pandaringan Barat', 'Pandaringan Barat', 'Padaringan Barat,Pandaringan Barat', -6.9991000, 113.8906000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74208, 'Canggetelo', 'Canggetelo', 'Canggetelo', -6.9072000, 113.8825000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74209, 'Panjeran', 'Panjeran', 'Panjeran', -6.9119000, 113.9388000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74210, 'Jurak Lao’', 'Jurak Lao''', 'Jurak Lao'',Jurak Lao’', -6.9070000, 113.9572000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74211, 'Jurgang Timur', 'Jurgang Timur', 'Jurgang Timur', -6.9142000, 113.9833000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74212, 'Marang', 'Marang', 'Marang', -6.9259000, 113.8913000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74213, 'Teramu', 'Teramu', 'Teramu', -6.9284000, 113.9034000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74214, 'Kayukembang', 'Kayukembang', 'Kayukembang', -6.9338000, 113.9812000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74215, 'Noom Timur', 'Noom Timur', 'Noom Timur', -6.9448000, 113.9437000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74216, 'Togu', 'Togu', 'Togu', -6.9571000, 113.9711000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74217, 'Pangtinggi', 'Pangtinggi', 'Pangtinggi', -6.9565000, 113.8789000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74218, 'Jandir', 'Jandir', 'Jandir', -6.9609000, 113.9938000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74219, 'Ares Tengah', 'Ares Tengah', 'Ares Tengah', -6.9732000, 113.9192000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74220, 'Mandala', 'Mandala', 'Mandala', -6.9866000, 113.8753000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74221, 'Dikkodik', 'Dikkodik', 'Dikkodik', -6.9863000, 113.9763000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74222, 'Batujaran', 'Batujaran', 'Batujaran', -6.9934000, 113.9031000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74223, 'Dajalorong', 'Dajalorong', 'Dajalorong', -6.9964000, 113.9329000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74224, 'Kramat', 'Kramat', 'Kramat', -6.9974000, 113.9399000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74225, 'Ahadan', 'Ahadan', 'Ahadan', -6.9975000, 113.9426000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74226, 'Panggung', 'Panggung', 'Panggung', -6.9976000, 113.9449000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74227, 'Raas', 'Raas', 'Raas', -6.9962000, 113.9503000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74228, 'Banjeru', 'Banjeru', 'Banjeru', -6.9988000, 113.9631000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74229, 'Neto', 'Neto', 'Neto', -9.8504500, 124.3946300, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74230, 'Oefatu', 'Oefatu', 'Oefatu', -9.8541300, 124.4151100, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74231, 'Melahue', 'Melahue', 'Melahue', -9.7521600, 124.4100400, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74232, 'Hoi', 'Hoi', 'Hoi', -9.8151700, 124.4337800, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74233, 'Naukae', 'Naukae', 'Naukae', -9.8248700, 124.4312600, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74234, 'Tetaf', 'Tetaf', 'Tetaf', -9.8356500, 124.4327100, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74235, 'Supul', 'Supul', 'Supul', -9.8443600, 124.4468300, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74236, 'Noebesa', 'Noebesa', 'Noebesa', -9.8574900, 124.4642500, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74237, 'Tumu', 'Tumu', 'Tumu', -9.8570800, 124.4903100, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74238, 'Nobinobi', 'Nobinobi', 'Nobinobi', -9.8353600, 124.4588000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74239, 'Bone', 'Bone', 'Bone', -9.8136000, 124.4641300, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74240, 'Sopo', 'Sopo', 'Sopo', -9.7741800, 124.4749200, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74241, 'Neosob', 'Neosob', 'Neosob', -9.7605600, 124.4816100, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74242, 'Oemollo', 'Oemollo', 'Oemollo', -9.7089000, 124.2564000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74243, 'Talmanu', 'Talmanu', 'Talmanu', -9.7424000, 124.2601000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74244, 'Tutem', 'Tutem', 'Tutem', -9.6553000, 124.2654000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74245, 'Besnakeh', 'Besnakeh', 'Besnakeh', -9.6825000, 124.2733000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74246, 'Obesi', 'Obesi', 'Obesi', -9.7273000, 124.2760000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74247, 'Lalin', 'Lalin', 'Lalin', -9.7365000, 124.2781000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74248, 'Beskolen', 'Beskolen', 'Beskolen', -9.6883000, 124.2784000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74249, 'Tobu', 'Tobu', 'Tobu', -9.6578000, 124.2883000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74250, 'Bosen', 'Bosen', 'Bosen', -9.7187000, 124.2883000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74251, 'Bestamuti', 'Bestamuti', 'Bestamuti', -9.6370000, 124.3011000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74252, 'Bijeli', 'Bijeli', 'Bijeli', -9.6682000, 124.3329000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74253, 'Laob', 'Laob', 'Laob', -9.6980000, 124.3495000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74254, 'Bijeli', 'Bijeli', 'Bijeli', -9.6543000, 124.3765000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74255, 'Toifae', 'Toifae', 'Toifae', -9.6994000, 124.4268000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74256, 'Oeoh', 'Oeoh', 'Oeoh', -9.7366000, 124.4852000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74257, 'Nifunaibesi', 'Nifunaibesi', 'Nifunaibesi', -9.6685000, 124.4889000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74258, 'Polen', 'Polen', 'Polen', -9.6870000, 124.4804000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74259, 'Nelabesa', 'Nelabesa', 'Nelabesa', -9.6268000, 124.6068000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74260, 'Kolo', 'Kolo', 'Kolo', -9.7439000, 124.5826000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74261, 'Oelet', 'Oelet', 'Oelet', -9.7075000, 124.5329000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74262, 'Biito', 'Biito', 'Biito', -9.6481000, 124.5579000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74263, 'Kuaeno', 'Kuaeno', 'Kuaeno', -9.7084000, 124.5803000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74264, 'Oetua', 'Oetua', 'Oetua', -9.6841000, 124.6051000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74265, 'Oeekam', 'Oeekam', 'Oeekam', -9.7087000, 124.5886000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74266, 'Pisan', 'Pisan', 'Pisan', -9.7364000, 124.5975000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74267, 'Oesapi', 'Oesapi', 'Oesapi', -9.7181000, 124.6103000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74268, 'Partikan', 'Partikan', 'Partikan', -6.9070000, 114.0174000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74269, 'Jerukporot', 'Jerukporot', 'Jerukporot', -6.9403000, 114.0010000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74270, 'Sekolan', 'Sekolan', 'Sekolan', -6.9470000, 114.0376000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74271, 'Kalerker', 'Kalerker', 'Kalerker', -6.9181000, 114.0365000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74272, 'Samburat', 'Samburat', 'Samburat', -6.9082000, 114.0376000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74273, 'Tekay', 'Tekay', 'Tekay', -6.9080000, 114.0311000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74274, 'Karangkeng', 'Karangkeng', 'Karangkeng', -6.9304000, 114.0184000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74275, 'Ares Tengah', 'Ares Tengah', 'Ares Tengah', -6.9274000, 114.0513000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74276, 'Pandian', 'Pandian', 'Pandian', -6.9297000, 114.0591000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74277, 'Bungin-Bungin', 'Bungin-Bungin', 'Bungin-Bungin', -6.9380000, 114.0820000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74278, 'Tengah', 'Tengah', 'Tengah', -6.9415000, 114.0938000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74279, 'Ares Tengah', 'Ares Tengah', 'Ares Tengah', -6.9640000, 114.1043000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74280, 'Dungkek Laok', 'Dungkek Laok', 'Dungkek Laok', -6.9769000, 114.0854000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74281, 'Budagan', 'Budagan', 'Budagan', -6.9854000, 114.0808000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74282, 'Daja Lorong', 'Daja Lorong', 'Daja Lorong', -6.9715000, 114.0757000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74283, 'Ginyang', 'Ginyang', 'Ginyang', -6.9706000, 114.0613000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74284, 'Somorpenang', 'Somorpenang', 'Somorpenang', -6.9949000, 114.0612000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74285, 'Patandun', 'Patandun', 'Patandun', -6.9969000, 114.0524000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74286, 'Poja', 'Poja', 'Poja', -6.9620000, 114.0351000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74287, 'Ngabungan', 'Ngabungan', 'Ngabungan', -6.9574000, 114.0267000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74288, 'Ares Tengah', 'Ares Tengah', 'Ares Tengah', -6.9508000, 114.0064000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74289, 'Jurangara', 'Jurangara', 'Jurangara', -6.9727000, 114.0153000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74290, 'Petong', 'Petong', 'Petong', -6.9735000, 114.0254000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74291, 'Polay', 'Polay', 'Polay', -6.9964000, 114.0011000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74292, 'Muesanaik', 'Muesanaik', 'Muesanaik', -9.5084000, 124.3692000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74293, 'Saenam', 'Saenam', 'Saenam', -9.5409000, 124.3034000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74294, 'Oesena', 'Oesena', 'Oesena', -9.5553000, 124.2908000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74295, 'Oenaek', 'Oenaek', 'Oenaek', -9.5514000, 124.2950000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74296, 'Fatufaun', 'Fatufaun', 'Fatufaun', -9.5517000, 124.3173000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74297, 'Eban', 'Eban', 'Eban', -9.5541000, 124.3242000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74298, 'Seoam', 'Seoam', 'Seoam', -9.5550000, 124.3307000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74299, 'Suanae', 'Suanae', 'Suanae', -9.5644000, 124.3333000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74300, 'Oenaik', 'Oenaik', 'Oenaik', -9.5701000, 124.3556000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74301, 'Binab', 'Binab', 'Binab', -9.5834000, 124.2896000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74302, 'Oenam', 'Oenam', 'Oenam', -9.5953000, 124.3317000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74303, 'Nunsena', 'Nunsena', 'Nunsena', -9.5188000, 124.4488000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74304, 'Bijaepasu', 'Bijaepasu', 'Bijaepasu', -9.5281000, 124.4252000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74305, 'Metkono', 'Metkono', 'Metkono', -9.5392000, 124.4130000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74306, 'Oebaki', 'Oebaki', 'Oebaki', -9.5541000, 124.3850000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74307, 'Kampungtengah', 'Kampungtengah', 'Kampungtengah', -9.5675000, 124.4653000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74308, 'Fatumuti', 'Fatumuti', 'Fatumuti', -9.5682000, 124.4853000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74309, 'Pakaebena', 'Pakaebena', 'Pakaebena', -9.5739000, 124.4933000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74310, 'Kiuola', 'Kiuola', 'Kiuola', -9.5889000, 124.4580000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74311, 'Bijeli', 'Bijeli', 'Bijeli', -9.5894000, 124.4894000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74312, 'Galtek', 'Galtek', 'Galtek', -7.0728000, 114.0294000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74313, 'Talaga', 'Talaga', 'Talaga', -7.1044000, 114.0407000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74314, 'Taen Tengah', 'Taen Tengah', 'Taen Tengah', -9.6406000, 123.6832000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74315, 'Kasmabaki', 'Kasmabaki', 'Kasmabaki', -9.6700000, 123.6839000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74316, 'Kaem', 'Kaem', 'Kaem', -9.7732000, 123.8661000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74317, 'Letkole', 'Letkole', 'Letkole', -9.6853000, 123.8044000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74318, 'Taimaman', 'Taimaman', 'Taimaman', -9.8076000, 123.9023000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74319, 'Meobesi', 'Meobesi', 'Meobesi', -9.8458000, 123.9827000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74320, 'Bitobe', 'Bitobe', 'Bitobe', -9.6331000, 123.9870000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74321, 'Fatupael', 'Fatupael', 'Fatupael', -9.7054000, 123.9555000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74322, 'Leloboko', 'Leloboko', 'Leloboko', -9.7008000, 123.9288000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74323, 'Oelbanu', 'Oelbanu', 'Oelbanu', -9.7057000, 123.8993000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74324, 'Anoek', 'Anoek', 'Anoek', -9.7172000, 123.9899000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74325, 'Fatumetan', 'Fatumetan', 'Fatumetan', -9.7403000, 123.9520000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74326, 'Oepula', 'Oepula', 'Oepula', -9.7986000, 124.0157000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74327, 'Hueknutu', 'Hueknutu', 'Hueknutu', -9.8576000, 124.0216000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74328, 'Binafun', 'Binafun', 'Binafun', -9.6617000, 124.0356000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74329, 'Oenenas', 'Oenenas', 'Oenenas', -9.6764000, 124.0118000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74330, 'Huelkail', 'Huelkail', 'Huelkail', -9.6239000, 124.0019000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74331, 'Talaga', 'Talaga', 'Talaga', -7.0616000, 114.3255000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74332, 'Nonggunong', 'Nonggunong', 'Nonggunong', -7.0731000, 114.3490000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74333, 'Tanamera', 'Tanamera', 'Tanamera', -7.0769000, 114.3371000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74334, 'Daleman', 'Daleman', 'Daleman', -7.0920000, 114.3230000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74335, 'Pocok', 'Pocok', 'Pocok', -7.0979000, 114.3642000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74336, 'Kemuning', 'Kemuning', 'Kemuning', -7.0934000, 114.3353000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74337, 'Klebu', 'Klebu', 'Klebu', -7.1371000, 114.3054000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74338, 'Guder Lao', 'Guder Lao', 'Guder Lao', -7.1396000, 114.3272000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74339, 'Kengkang', 'Kengkang', 'Kengkang', -7.1373000, 114.3425000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74340, 'Koatas Lao', 'Koatas Lao', 'Koatas Lao', -7.1432000, 114.3603000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74341, 'Prengbatu', 'Prengbatu', 'Prengbatu', -7.1454000, 114.3443000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74342, 'Jambuir Timur', 'Jambuir Timur', 'Jambuir Timur', -7.1532000, 114.3304000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74343, 'Rokoro', 'Rokoro', 'Rokoro', -7.1609000, 114.3431000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74344, 'Fatumnasi', 'Fatumnasi', 'Fatumnasi', -9.6511000, 124.2218000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74345, 'Nifu', 'Nifu', 'Nifu', -9.6711000, 124.1503000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74346, 'Oehala', 'Oehala', 'Oehala', -9.6821000, 124.2478000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74347, 'Leloboko', 'Leloboko', 'Leloboko', -9.6844000, 124.1878000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74348, 'Liliana', 'Liliana', 'Liliana', -9.6976000, 124.1397000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74349, 'Nefokoko', 'Nefokoko', 'Nefokoko', -9.7249000, 124.1532000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74350, 'Huineno', 'Huineno', 'Huineno', -9.7372000, 124.2198000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74351, 'Pabungkon Daja', 'Pabungkon Daja', 'Pabungkon Daja', -7.1551000, 114.3929000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74352, 'Nunsena', 'Nunsena', 'Nunsena', -9.5280000, 124.1693000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74353, 'Nenas', 'Nenas', 'Nenas', -9.5827000, 124.2047000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74354, 'Alasmalang', 'Alasmalang', 'Alasmalang', -7.1390000, 114.5895000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74355, 'Timurembung', 'Timurembung', 'Timurembung', -7.1497000, 114.6131000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74356, 'Poteran', 'Poteran', 'Poteran', -7.1523000, 114.6001000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74357, 'Karangnangka', 'Karangnangka', 'Karangnangka', -7.1517000, 114.5703000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74358, 'Kiukasen', 'Kiukasen', 'Kiukasen', -10.1331000, 123.9060000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74359, 'Kairane', 'Kairane', 'Kairane', -10.1557000, 123.9442000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74360, 'Fatukanutu', 'Fatukanutu', 'Fatukanutu', -10.1690000, 123.9003000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74361, 'Tanbira', 'Tanbira', 'Tanbira', -10.2078000, 123.8852000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74362, 'Buka', 'Buka', 'Buka', -10.2105000, 123.9349000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74363, 'Fuskou', 'Fuskou', 'Fuskou', -10.2105000, 123.9968000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74364, 'Hauhena', 'Hauhena', 'Hauhena', -10.2322000, 123.9182000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74365, 'Boitimu', 'Boitimu', 'Boitimu', -10.2264000, 124.0018000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74366, 'Oekero', 'Oekero', 'Oekero', -10.1557000, 124.0498000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74367, 'Mandar', 'Mandar', 'Mandar', -6.8547000, 115.2549000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74368, 'Timurlorong', 'Timurlorong', 'Timurlorong', -6.8621000, 115.2645000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74369, 'Tampakdandang', 'Tampakdandang', 'Tampakdandang', -6.8603000, 115.2633000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74370, 'Gerelayang', 'Gerelayang', 'Gerelayang', -6.8527000, 115.2624000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74371, 'Sumbernangka Tengah', 'Sumbernangka Tengah', 'Sumbernangka Tengah', -6.8534000, 115.2688000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74372, 'Parse', 'Parse', 'Parse', -6.8602000, 115.2711000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74373, 'Duko Tengah', 'Duko Tengah', 'Duko Tengah', -6.8573000, 115.2797000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74374, 'Utarapasar', 'Utarapasar', 'Utarapasar', -6.8553000, 115.2869000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74375, 'Kettep', 'Kettep', 'Kettep', -6.8611000, 115.2842000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74376, 'Anyar', 'Anyar', 'Anyar', -6.8584000, 115.2963000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74377, 'Nyangkleng', 'Nyangkleng', 'Nyangkleng', -6.8551000, 115.2926000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74378, 'Pasarbaru', 'Pasarbaru', 'Pasarbaru', -6.8599000, 115.3171000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74379, 'Beting', 'Beting', 'Beting', -6.8558000, 115.3107000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74380, 'Pasar', 'Pasar', 'Pasar', -6.8591000, 115.3193000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74381, 'Wakaf', 'Wakaf', 'Wakaf', -6.8352000, 115.3419000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74382, 'Bantilan', 'Bantilan', 'Bantilan', -6.8363000, 115.3741000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74383, 'Batuputih Atas', 'Batuputih Atas', 'Batuputih Atas', -6.8745000, 115.3704000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74384, 'Oehaunu', 'Oehaunu', 'Oehaunu', -10.0569000, 124.1295000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74385, 'Oetaman', 'Oetaman', 'Oetaman', -10.0455000, 124.1806000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74386, 'Polo', 'Polo', 'Polo', -10.0647000, 124.2293000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74387, 'Luluf', 'Luluf', 'Luluf', -10.0704000, 124.2419000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74388, 'Panite', 'Panite', 'Panite', -10.0703000, 124.2284000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74389, 'Toifeu', 'Toifeu', 'Toifeu', -10.0919000, 124.2304000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74390, 'Aeka', 'Aeka', 'Aeka', -10.0874000, 124.1618000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74391, 'Bikoen', 'Bikoen', 'Bikoen', -10.1156000, 124.1871000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74392, 'Tabu', 'Tabu', 'Tabu', -10.0350000, 124.2655000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74393, 'Naip', 'Naip', 'Naip', -10.0382000, 124.3427000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74394, 'Nunmanu', 'Nunmanu', 'Nunmanu', -10.0431000, 124.3382000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74395, 'Suman', 'Suman', 'Suman', -10.0662000, 124.3449000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74396, 'Kuafeu', 'Kuafeu', 'Kuafeu', -10.0017000, 124.4251000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74397, 'Kotai', 'Kotai', 'Kotai', -10.0482000, 124.4076000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74398, 'Tutnae', 'Tutnae', 'Tutnae', -10.0959000, 124.4007000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74399, 'Fauthanin', 'Fauthanin', 'Fauthanin', -10.0218000, 124.4394000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74400, 'Kuanfatu', 'Kuanfatu', 'Kuanfatu', -10.0236000, 124.4480000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74401, 'Lani', 'Lani', 'Lani', -10.0860000, 124.4488000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74402, 'Kakan', 'Kakan', 'Kakan', -10.0061000, 124.4637000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74403, 'Kusi', 'Kusi', 'Kusi', -10.0406000, 124.4709000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74404, 'Oni', 'Oni', 'Oni', -10.0813000, 124.4633000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74405, 'Niupmetan', 'Niupmetan', 'Niupmetan', -10.0742000, 124.4796000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74406, 'Tumu', 'Tumu', 'Tumu', -9.8883000, 124.4967000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74407, 'Belua', 'Belua', 'Belua', -9.9337000, 124.3777000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74408, 'Baki', 'Baki', 'Baki', -9.9293000, 124.4743000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74409, 'Nifufuni', 'Nifufuni', 'Nifufuni', -9.9403000, 124.4848000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74410, 'Oelui', 'Oelui', 'Oelui', -9.9543000, 124.4632000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74411, 'Amononi', 'Amononi', 'Amononi', -9.9607000, 124.4841000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74412, 'Oof', 'Oof', 'Oof', -9.9714000, 124.4523000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74413, 'Ayofanu', 'Ayofanu', 'Ayofanu', -9.8753000, 124.5908000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74414, 'Nunleu', 'Nunleu', 'Nunleu', -9.8799000, 124.6244000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74415, 'Timutuka', 'Timutuka', 'Timutuka', -9.9974000, 124.5339000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74416, 'Fatuulan', 'Fatuulan', 'Fatuulan', -9.9070000, 124.6140000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74417, 'Poto', 'Poto', 'Poto', -9.9050000, 124.5771000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74418, 'Oefau', 'Oefau', 'Oefau', -9.9060000, 124.5313000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74419, 'Oeekam', 'Oeekam', 'Oeekam', -9.9481000, 124.5139000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74420, 'Haunubenak', 'Haunubenak', 'Haunubenak', -9.9478000, 124.5363000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74421, 'Oobibi', 'Oobibi', 'Oobibi', -9.9450000, 124.5882000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74422, 'Tubel', 'Tubel', 'Tubel', -9.9621000, 124.5329000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74423, 'Olin', 'Olin', 'Olin', -9.9613000, 124.5989000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74424, 'Putun', 'Putun', 'Putun', -9.8781000, 124.6683000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74425, 'Maemutip', 'Maemutip', 'Maemutip', -9.8773000, 124.6785000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74426, 'Haumeni', 'Haumeni', 'Haumeni', -9.8851000, 124.6563000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74427, 'Sahan', 'Sahan', 'Sahan', -9.9063000, 124.6798000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74428, 'Op', 'Op', 'Op', -9.9152000, 124.6472000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74429, 'Nunutoko', 'Nunutoko', 'Nunutoko', -9.9481000, 124.6331000, 'ID', '2012-10-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74430, 'Larangan', 'Larangan', 'Larangan', -6.8903000, 115.3155000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74431, 'Kolla', 'Kolla', 'Kolla', -6.8833000, 115.3489000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74432, 'Tembang', 'Tembang', 'Tembang', -6.9910000, 115.2664000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74433, 'Baratsungai', 'Baratsungai', 'Baratsungai', -6.8979000, 115.4337000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74434, 'Pajannangger', 'Pajannangger', 'Pajannangger', -6.9804000, 115.3975000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74435, 'Mesjid', 'Mesjid', 'Mesjid', -6.9811000, 115.4299000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74436, 'Pili', 'Pili', 'Pili', -9.7770000, 124.5057000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74437, 'Tunis', 'Tunis', 'Tunis', -9.7600000, 124.6056000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74438, 'Fatuhilik', 'Fatuhilik', 'Fatuhilik', -9.8038000, 124.6041000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74439, 'Linakelopu', 'Linakelopu', 'Linakelopu', -9.8067000, 124.6029000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74440, 'Oeleon', 'Oeleon', 'Oeleon', -9.7913000, 124.5766000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74441, 'Bileon', 'Bileon', 'Bileon', -9.7853000, 124.5364000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74442, 'Fatubia', 'Fatubia', 'Fatubia', -9.8204000, 124.5113000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74443, 'Kie', 'Kie', 'Kie', -9.8448000, 124.5481000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74444, 'Oenpeotnai', 'Oenpeotnai', 'Oenpeotnai', -9.8524000, 124.5707000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74445, 'Oinlasi', 'Oinlasi', 'Oinlasi', -9.8499000, 124.5744000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74446, 'Anin', 'Anin', 'Anin', -9.8429000, 124.5793000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74447, 'Oebubun', 'Oebubun', 'Oebubun', -9.8586000, 124.6012000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74448, 'Noebana', 'Noebana', 'Noebana', -9.7724000, 124.6575000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74449, 'Oefenu', 'Oefenu', 'Oefenu', -9.7567000, 124.6739000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74450, 'Poli', 'Poli', 'Poli', -9.7680000, 124.7026000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74451, 'Malla', 'Malla', 'Malla', -9.7938000, 124.6945000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74452, 'Nenotes', 'Nenotes', 'Nenotes', -9.8072000, 124.6766000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74453, 'Sunu', 'Sunu', 'Sunu', -9.8196000, 124.6412000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74454, 'Tene', 'Tene', 'Tene', -9.8403000, 124.6307000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74455, 'Kualeu', 'Kualeu', 'Kualeu', -9.8617000, 124.6525000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74456, 'Sbo’o', 'Sbo''o', 'Sbo''o,Sbo’o', -9.8392000, 124.6549000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74457, 'Koana', 'Koana', 'Koana', -9.8293000, 124.6913000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74458, 'Oenopu', 'Oenopu', 'Oenopu', -9.8722000, 124.7049000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74459, 'Oetotom', 'Oetotom', 'Oetotom', -9.8434000, 124.7207000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74460, 'Kajisara', 'Kajisara', 'Kajisara', -6.8779200, 115.5068900, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74461, 'Besnam', 'Besnam', 'Besnam', -9.6507000, 124.6565000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74462, 'Mmaaf', 'Mmaaf', 'Mmaaf', -9.6774000, 124.7004000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74463, 'Bonefatu', 'Bonefatu', 'Bonefatu', -9.6784000, 124.7090000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74464, 'Sonlit', 'Sonlit', 'Sonlit', -9.6800000, 124.7403000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74465, 'Tnaomat', 'Tnaomat', 'Tnaomat', -9.6969000, 124.7034000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74466, 'Ayotupas', 'Ayotupas', 'Ayotupas', -9.6971000, 124.7076000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74467, 'Mnelabano', 'Mnelabano', 'Mnelabano', -9.7125000, 124.6695000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74468, 'Tuateta', 'Tuateta', 'Tuateta', -9.7222000, 124.6496000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74469, 'Oesoot', 'Oesoot', 'Oesoot', -9.7259000, 124.7223000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74470, 'Oeleu', 'Oeleu', 'Oeleu', -9.7457000, 124.7412000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74471, 'Fotilo', 'Fotilo', 'Fotilo', -9.7369000, 124.6935000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74472, 'Susunan', 'Susunan', 'Susunan', -7.0030000, 115.6751000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74473, 'Kiutoko', 'Kiutoko', 'Kiutoko', -9.5502000, 124.6804000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74474, 'Maurisu', 'Maurisu', 'Maurisu', -9.5740000, 124.6563000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74475, 'Biudukfoho', 'Biudukfoho', 'Biudukfoho', -9.6066000, 124.7395000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74476, 'Nularan', 'Nularan', 'Nularan', -9.6136000, 124.6658000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74477, 'Oeleno', 'Oeleno', 'Oeleno', -9.6211000, 124.7378000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74478, 'Malimaneek', 'Malimaneek', 'Malimaneek', -9.6165000, 124.7420000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74479, 'Toroh', 'Toroh', 'Toroh', -7.0081000, 115.5399000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74480, 'Sepanjang', 'Sepanjang', 'Sepanjang', -7.1797000, 115.7847000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74481, 'Yehpanas', 'Yehpanas', 'Yehpanas', -8.1456000, 114.6539000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74482, 'Banyupoh', 'Banyupoh', 'Banyupoh', -8.1484000, 114.6935000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74483, 'Penyabangan', 'Penyabangan', 'Penyabangan', -8.1649000, 114.7284000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74484, 'Madan', 'Madan', 'Madan', -8.1710000, 114.7405000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74485, 'Akubala', 'Akubala', 'Akubala', -8.2613500, 125.1383800, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74486, 'Muyaka', 'Muyaka', 'Muyaka', -8.2824000, 125.0434000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74487, 'Maritaing', 'Maritaing', 'Maritaing', -8.2907000, 125.1242000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74488, 'Lakateng', 'Lakateng', 'Lakateng', -8.2357000, 124.9124000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74489, 'Lawaikanal', 'Lawaikanal', 'Lawaikanal', -8.1697000, 124.7726000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74490, 'Kemang', 'Kemang', 'Kemang', -8.1658000, 124.7548000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74491, 'Bukapiting', 'Bukapiting', 'Bukapiting', -8.1812000, 124.7606000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74492, 'Pumai', 'Pumai', 'Pumai', -8.1904000, 124.7748000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74493, 'Alemba', 'Alemba', 'Alemba', -8.1518000, 124.7436000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74494, 'Likwatang Timur', 'Likwatang Timur', 'Likwatang Timur', -8.1649000, 124.6680000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74495, 'Makemi', 'Makemi', 'Makemi', -8.2146000, 124.6893000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74496, 'Atengmelang', 'Atengmelang', 'Atengmelang', -8.2262000, 124.6706000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74497, 'Bunggeta', 'Bunggeta', 'Bunggeta', -8.3426000, 124.6294000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74498, 'Mainang', 'Mainang', 'Mainang', -8.2831000, 124.6254000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74499, 'Apui', 'Apui', 'Apui', -8.2732000, 124.7231000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74500, 'Masape', 'Masape', 'Masape', -8.2853000, 124.6892000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74501, 'Silonang', 'Silonang', 'Silonang', -8.3217000, 124.7213000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74502, 'Kalunan', 'Kalunan', 'Kalunan', -8.3900000, 124.6683000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74503, 'Padangalang', 'Padangalang', 'Padangalang', -8.3786000, 124.7140000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74504, 'Tukbur', 'Tukbur', 'Tukbur', -8.3884000, 124.6616000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74505, 'Mademang', 'Mademang', 'Mademang', -8.3847600, 124.8345900, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74506, 'Sifala', 'Sifala', 'Sifala', -8.4371000, 124.5441000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74507, 'Moru', 'Moru', 'Moru', -8.2568000, 124.5155000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74508, 'Maiwal', 'Maiwal', 'Maiwal', -8.3246000, 124.5190000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74509, 'Aloindonu', 'Aloindonu', 'Aloindonu', -8.1577000, 124.5079000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74510, 'Wahawaha', 'Wahawaha', 'Wahawaha', -8.1654000, 124.5403000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74511, 'Buyungta', 'Buyungta', 'Buyungta', -8.1633000, 124.5918000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74512, 'Doibang', 'Doibang', 'Doibang', -8.1960000, 124.5015000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74513, 'Kamentaha', 'Kamentaha', 'Kamentaha', -8.1970000, 124.6119000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74514, 'Kampungraja', 'Kampungraja', 'Kampungraja', -8.2160000, 124.5175000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74515, 'Batutanata', 'Batutanata', 'Batutanata', -8.2148000, 124.5256000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74516, 'Tongbang', 'Tongbang', 'Tongbang', -8.2135000, 124.5390000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74517, 'Watatuku', 'Watatuku', 'Watatuku', -8.2116000, 124.5598000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74518, 'Jembayan Hitam', 'Jembayan Hitam', 'Jembayan Hitam', -8.2211000, 124.5432000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74519, 'Binongko', 'Binongko', 'Binongko', -8.2180000, 124.5134000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74520, 'Kenarilang', 'Kenarilang', 'Kenarilang', -8.2212000, 124.5020000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74521, 'Welai', 'Welai', 'Welai', -8.2354000, 124.5605000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74522, 'Ulimonong', 'Ulimonong', 'Ulimonong', -8.2399000, 124.4052000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74523, 'Seieng', 'Seieng', 'Seieng', -8.1824000, 124.4326000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74524, 'Lewolang', 'Lewolang', 'Lewolang', -8.2653000, 124.4281000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74525, 'Pantaimakasar', 'Pantaimakasar', 'Pantaimakasar', -8.2693000, 124.4097000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74526, 'Mataraben', 'Mataraben', 'Mataraben', -8.3739000, 124.4172000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74527, 'Fa’aming', 'Fa''aming', 'Fa''aming,Fa’aming', -8.2715000, 124.4485000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74528, 'Bakalang', 'Bakalang', 'Bakalang', -8.2658000, 124.2986000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74529, 'Solangbali', 'Solangbali', 'Solangbali', -8.2766000, 124.3488000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74530, 'Apuri', 'Apuri', 'Apuri', -8.3161000, 124.3651000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74531, 'Pandai', 'Pandai', 'Pandai', -8.1894000, 124.2612000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74532, 'Maliang', 'Maliang', 'Maliang', -8.3828000, 124.1307000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74533, 'Tobitambor', 'Tobitambor', 'Tobitambor', -8.2463700, 124.2203900, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74534, 'Jungutbatu Kaja Dua', 'Jungutbatu Kaja Dua', 'Jungutbatu Kaja Dua', -8.6766000, 115.4480000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74535, 'Sakti', 'Sakti', 'Sakti', -8.7060000, 115.4822000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74536, 'Pondokkaha Kelod', 'Pondokkaha Kelod', 'Pondokkaha Kelod', -8.7360000, 115.4945000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74537, 'Mauta', 'Mauta', 'Mauta', -8.4631000, 124.1308000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74538, 'Puntaru', 'Puntaru', 'Puntaru', -8.4498300, 124.0540200, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74539, 'Ped', 'Ped', 'Ped', -8.6739000, 115.5064000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74540, 'Kutampi', 'Kutampi', 'Kutampi', -8.6742000, 115.5523000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74541, 'Gelagah', 'Gelagah', 'Gelagah', -8.7072000, 115.5594000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74542, 'Klumbu', 'Klumbu', 'Klumbu', -8.7183000, 115.5233000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74543, 'Suana', 'Suana', 'Suana', -8.7280000, 115.5985000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74544, 'Pejukutan', 'Pejukutan', 'Pejukutan', -8.7493000, 115.5858000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74545, 'Tanjung', 'Tanjung', 'Tanjung', -8.7573000, 115.5335000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74546, 'Sekartaji', 'Sekartaji', 'Sekartaji', -8.8010000, 115.5691000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74547, 'Leuwohung', 'Leuwohung', 'Leuwohung', -8.1732000, 123.7918000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74548, 'Peuhaq', 'Peuhaq', 'Peuhaq', -8.1772000, 123.7975000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74549, 'Werangrae', 'Werangrae', 'Werangrae', -8.1793000, 123.7638000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74550, 'Atarodangwautu', 'Atarodangwautu', 'Atarodangwautu', -8.1836000, 123.7590000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74551, 'Lewutung', 'Lewutung', 'Lewutung', -8.1895000, 123.8127000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74552, 'Wairiang', 'Wairiang', 'Wairiang', -8.1921000, 123.8187000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74553, 'Weikoro', 'Weikoro', 'Weikoro', -8.1986000, 123.8282000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74554, 'Bungalaleng', 'Bungalaleng', 'Bungalaleng', -8.1916000, 123.7529000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74555, 'Kaohua', 'Kaohua', 'Kaohua', -8.2059000, 123.8183000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74556, 'Leuburi', 'Leuburi', 'Leuburi', -8.2109000, 123.8157000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74557, 'Leudawan', 'Leudawan', 'Leudawan', -8.2191000, 123.8145000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74558, 'Roun Satu', 'Roun Satu', 'Roun Satu', -8.2235000, 123.8128000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74559, 'Leutubung Satu', 'Leutubung Satu', 'Leutubung Satu', -8.2282000, 123.8087000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74560, 'Aliuroba', 'Aliuroba', 'Aliuroba', -8.2383000, 123.7896000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74561, 'Hadingrobi', 'Hadingrobi', 'Hadingrobi', -8.2398000, 123.7865000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74562, 'Riangbao', 'Riangbao', 'Riangbao', -8.2440000, 123.7805000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74563, 'Orolaleng', 'Orolaleng', 'Orolaleng', -8.2452000, 123.7655000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74564, 'Leubatang', 'Leubatang', 'Leubatang', -8.2476000, 123.7581000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74565, 'Meluwiting', 'Meluwiting', 'Meluwiting', -8.2415000, 123.7464000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74566, 'Leuweheq', 'Leuweheq', 'Leuweheq', -8.2284000, 123.7414000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74567, 'Hoelea', 'Hoelea', 'Hoelea', -8.2156000, 123.7414000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74568, 'Dolulolong', 'Dolulolong', 'Dolulolong', -8.2123000, 123.7261000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74569, 'Atarodangkedang', 'Atarodangkedang', 'Atarodangkedang', -8.1993000, 123.7451000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74570, 'Leuwayang', 'Leuwayang', 'Leuwayang', -8.1971000, 123.7484000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74571, 'Wailolong', 'Wailolong', 'Wailolong', -8.2562000, 123.6601000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74572, 'Nilanapo', 'Nilanapo', 'Nilanapo', -8.3275000, 123.7235000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74573, 'Lodobelolong', 'Lodobelolong', 'Lodobelolong', -8.3359000, 123.6424000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74574, 'Lewodoli', 'Lewodoli', 'Lewodoli', -8.3488000, 123.6542000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74575, 'Lamawolo', 'Lamawolo', 'Lamawolo', -8.2679000, 123.5470000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74576, 'Baopukang', 'Baopukang', 'Baopukang', -8.3080000, 123.5186000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74577, 'Tapolangu', 'Tapolangu', 'Tapolangu', -8.3067000, 123.6184000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74578, 'Kimakamak', 'Kimakamak', 'Kimakamak', -8.3341000, 123.5007000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74579, 'Tanakereket', 'Tanakereket', 'Tanakereket', -8.3609000, 123.5018000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74580, 'Merdeka', 'Merdeka', 'Merdeka', -8.3660000, 123.5268000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74581, 'Lerahinga', 'Lerahinga', 'Lerahinga', -8.3690000, 123.5545000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74582, 'Ebak', 'Ebak', 'Ebak', -8.2382700, 123.5195300, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74583, 'Watuwawer', 'Watuwawer', 'Watuwawer', -8.5068000, 123.5418000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74584, 'Karangora', 'Karangora', 'Karangora', -8.4478000, 123.5082000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74585, 'Paulolong', 'Paulolong', 'Paulolong', -8.4889000, 123.5003000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74586, 'Waiwejak', 'Waiwejak', 'Waiwejak', -8.4985000, 123.5226000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74587, 'Atawolo', 'Atawolo', 'Atawolo', -8.5128000, 123.5229000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74588, 'Tobilolong', 'Tobilolong', 'Tobilolong', -8.5210000, 123.5353000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74589, 'Lerek', 'Lerek', 'Lerek', -8.5230000, 123.5456000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74590, 'Mulandoro', 'Mulandoro', 'Mulandoro', -8.5381000, 123.5100000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74591, 'Boto', 'Boto', 'Boto', -8.5078000, 123.3761000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74592, 'Puor', 'Puor', 'Puor', -8.5361000, 123.4108000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74593, 'Luki', 'Luki', 'Luki', -8.5308000, 123.4531000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74594, 'Imulolong', 'Imulolong', 'Imulolong', -8.5452000, 123.4081000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74595, 'Lamabaka', 'Lamabaka', 'Lamabaka', -8.5788000, 123.4031000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74596, 'Batanamang', 'Batanamang', 'Batanamang', -8.5767000, 123.4152000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74597, 'Lewokukung', 'Lewokukung', 'Lewokukung', -8.4472000, 123.4468000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74598, 'Bakan', 'Bakan', 'Bakan', -8.4659000, 123.4709000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74599, 'Lewuka', 'Lewuka', 'Lewuka', -8.4982000, 123.4479000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74600, 'Paobokol', 'Paobokol', 'Paobokol', -8.4862000, 123.4050000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74601, 'Watugolok', 'Watugolok', 'Watugolok', -8.4382000, 123.4734000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74602, 'Kolirerek', 'Kolirerek', 'Kolirerek', -8.4447000, 123.4715000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74603, 'Watomean', 'Watomean', 'Watomean', -8.2535000, 123.4769000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74604, 'Tanjungbatu', 'Tanjungbatu', 'Tanjungbatu', -8.2690000, 123.4655000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74605, 'Dualein', 'Dualein', 'Dualein', -8.2708000, 123.4608000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74606, 'Holoriang', 'Holoriang', 'Holoriang', -8.2725000, 123.3991000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74607, 'Ohe', 'Ohe', 'Ohe', -8.3135000, 123.4579000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74608, 'Lamatuka', 'Lamatuka', 'Lamatuka', -8.3641000, 123.4965000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74609, 'Muruona', 'Muruona', 'Muruona', -8.3296000, 123.4766000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74610, 'Mawa', 'Mawa', 'Mawa', -8.2457900, 123.4864800, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74611, 'Watowiti', 'Watowiti', 'Watowiti', -8.2764000, 123.0005000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74612, 'Waitenepang', 'Waitenepang', 'Waitenepang', -8.2713000, 123.1109000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74613, 'Waiwadan', 'Waiwadan', 'Waiwadan', -8.2763000, 123.0928000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74614, 'Senadan', 'Senadan', 'Senadan', -8.3855000, 123.2579000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74615, 'Lidang A', 'Lidang A', 'Lidang A', -8.3803000, 123.2581000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74616, 'Lewopao', 'Lewopao', 'Lewopao', -8.3823000, 123.2664000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74617, 'Lewokemie', 'Lewokemie', 'Lewokemie', -8.2830000, 123.2749000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74618, 'Loga', 'Loga', 'Loga', -8.2869000, 123.2571000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74619, 'Auona', 'Auona', 'Auona', -8.2872000, 123.2594000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74620, 'Pledo', 'Pledo', 'Pledo', -8.2968000, 123.2638000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74621, 'Lamablawa', 'Lamablawa', 'Lamablawa', -8.2975000, 123.2597000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74622, 'Kotablolong', 'Kotablolong', 'Kotablolong', -8.2994000, 123.2655000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74623, 'Watoone', 'Watoone', 'Watoone', -8.3022000, 123.2635000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74624, 'Werangere', 'Werangere', 'Werangere', -8.3011000, 123.2613000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74625, 'Lewoblolong', 'Lewoblolong', 'Lewoblolong', -8.3151000, 123.2788000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74626, 'Riangblolong', 'Riangblolong', 'Riangblolong', -8.3140000, 123.2520000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74627, 'Pukaona B', 'Pukaona B', 'Pukaona B', -8.3711000, 123.2792000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74628, 'Tanjungbahagia', 'Tanjungbahagia', 'Tanjungbahagia', -8.2986000, 123.3582000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74629, 'Gayak', 'Gayak', 'Gayak', -8.3772000, 123.2956000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74630, 'Belang', 'Belang', 'Belang', -8.4297000, 123.3605000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74631, 'Loang', 'Loang', 'Loang', -8.4710000, 123.2849000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74632, 'Lamalewar', 'Lamalewar', 'Lamalewar', -8.4837000, 123.3582000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74633, 'Kolibali', 'Kolibali', 'Kolibali', -8.2887000, 123.2492000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74634, 'Idalolong', 'Idalolong', 'Idalolong', -8.5298000, 123.3227000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74635, 'Lewopenutung', 'Lewopenutung', 'Lewopenutung', -8.5621000, 123.3542000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74636, 'Pasirputih', 'Pasirputih', 'Pasirputih', -8.5431000, 123.2628000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74637, 'Kuyalewun', 'Kuyalewun', 'Kuyalewun', -8.3763000, 123.2407000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74638, 'Riangwale', 'Riangwale', 'Riangwale', -8.3841000, 123.2415000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74639, 'Lamawolo', 'Lamawolo', 'Lamawolo', -8.3859000, 123.2496000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74640, 'Gorang', 'Gorang', 'Gorang', -8.4290000, 123.1311000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74641, 'Waipapan Satu', 'Waipapan Satu', 'Waipapan Satu', -8.3879000, 123.1694000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74642, 'Wotan', 'Wotan', 'Wotan', -8.3849000, 123.1634000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74643, 'Lamahala', 'Lamahala', 'Lamahala', -8.3895000, 123.1510000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74644, 'Nihaona', 'Nihaona', 'Nihaona', -8.3736000, 123.2384000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74645, 'Ipiebang', 'Ipiebang', 'Ipiebang', -8.3664000, 123.1325000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74646, 'Lewoduli', 'Lewoduli', 'Lewoduli', -8.3539000, 123.2260000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74647, 'Tanuwore', 'Tanuwore', 'Tanuwore', -8.2798000, 123.1993000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74648, 'Narawayong', 'Narawayong', 'Narawayong', -8.2909000, 123.2391000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74649, 'Kereta', 'Kereta', 'Kereta', -8.2888000, 123.2232000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74650, 'Lowotukan', 'Lowotukan', 'Lowotukan', -8.2930000, 123.1963000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74651, 'Wainira', 'Wainira', 'Wainira', -8.2997000, 123.1951000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74652, 'Ladoang', 'Ladoang', 'Ladoang', -8.2957000, 123.2087000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74653, 'Klubagolit', 'Klubagolit', 'Klubagolit', -8.2980000, 123.2284000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74654, 'Kampungsusah', 'Kampungsusah', 'Kampungsusah', -8.3052000, 123.2370000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74655, 'Wuaona', 'Wuaona', 'Wuaona', -8.3042000, 123.2348000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74656, 'Lewobelek', 'Lewobelek', 'Lewobelek', -8.3104000, 123.2290000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74657, 'Horowura', 'Horowura', 'Horowura', -8.3155000, 123.2201000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74658, 'Wewit', 'Wewit', 'Wewit', -8.3018000, 123.1571000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74659, 'Waibereno', 'Waibereno', 'Waibereno', -8.3060000, 123.1422000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74660, 'Lewotukan', 'Lewotukan', 'Lewotukan', -8.3198000, 123.2298000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74661, 'Tanahpukang', 'Tanahpukang', 'Tanahpukang', -8.3162000, 123.1499000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74662, 'Mulawato', 'Mulawato', 'Mulawato', -8.3257000, 123.1505000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74663, 'Riangpao', 'Riangpao', 'Riangpao', -8.3308000, 123.1517000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74664, 'Bayuwan', 'Bayuwan', 'Bayuwan', -8.3207000, 123.1414000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74665, 'Lamalouk', 'Lamalouk', 'Lamalouk', -8.3400000, 123.2139000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74666, 'Ongabelen', 'Ongabelen', 'Ongabelen', -8.3346000, 123.2015000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74667, 'Riangwerang', 'Riangwerang', 'Riangwerang', -8.3427000, 123.2029000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74668, 'Wakapuken', 'Wakapuken', 'Wakapuken', -8.3426000, 123.2055000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74669, 'Lamaluwo', 'Lamaluwo', 'Lamaluwo', -8.3435000, 123.1542000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74670, 'Lewolen', 'Lewolen', 'Lewolen', -8.3474000, 123.2104000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74671, 'Lewonara', 'Lewonara', 'Lewonara', -8.3566000, 123.1719000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74672, 'Kotakaya Dua', 'Kotakaya Dua', 'Kotakaya Dua', -8.2407700, 123.1385700, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74673, 'Kanariblolong', 'Kanariblolong', 'Kanariblolong', -8.2893000, 123.0685000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74674, 'Era', 'Era', 'Era', -8.3263000, 123.1107000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74675, 'Leter', 'Leter', 'Leter', -8.3211000, 123.1202000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74676, 'Watodei', 'Watodei', 'Watodei', -8.3381000, 123.0980000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74677, 'Wayangona', 'Wayangona', 'Wayangona', -8.3548000, 123.0695000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74678, 'Lebao', 'Lebao', 'Lebao', -8.3234000, 123.0063000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74679, 'Tabali', 'Tabali', 'Tabali', -8.3179000, 123.0142000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74680, 'Haridimun', 'Haridimun', 'Haridimun', -8.4923000, 123.0015000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74681, 'Ongalereng', 'Ongalereng', 'Ongalereng', -8.4447000, 123.0085000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74682, 'Woto', 'Woto', 'Woto', -8.3871000, 123.0130000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74683, 'Basarani', 'Basarani', 'Basarani', -8.3985000, 123.0463000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74684, 'Waiwukak', 'Waiwukak', 'Waiwukak', -8.4071000, 123.0649000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74685, 'Baniona', 'Baniona', 'Baniona', -8.4000000, 123.0848000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74686, 'Klukeng', 'Klukeng', 'Klukeng', -8.3965000, 123.0856000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74687, 'Mewet', 'Mewet', 'Mewet', -8.3997000, 123.0981000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74688, 'Menanga', 'Menanga', 'Menanga', -8.4360000, 123.0868000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74689, 'Wulublolong', 'Wulublolong', 'Wulublolong', -8.4391000, 123.0420000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74690, 'Karawatung', 'Karawatung', 'Karawatung', -8.4516000, 123.0170000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74691, 'Lamawai', 'Lamawai', 'Lamawai', -8.4699000, 123.1074000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74692, 'Lewograran', 'Lewograran', 'Lewograran', -8.4760000, 123.0303000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74693, 'Lamagohang', 'Lamagohang', 'Lamagohang', -8.4800000, 123.0162000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74694, 'Watoona', 'Watoona', 'Watoona', -8.4793000, 123.0902000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74695, 'Lemboleng', 'Lemboleng', 'Lemboleng', -8.4878000, 123.0756000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74696, 'Sulengwaseng', 'Sulengwaseng', 'Sulengwaseng', -8.5069000, 122.9757000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74697, 'Ritaebang Satu', 'Ritaebang Satu', 'Ritaebang Satu', -8.5274000, 122.8851000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74698, 'Ritaebang', 'Ritaebang', 'Ritaebang', -8.5308000, 122.8836000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74699, 'Kalelu', 'Kalelu', 'Kalelu', -8.5418000, 122.9373000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74700, 'Tanahedang', 'Tanahedang', 'Tanahedang', -8.5534000, 122.9028000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74701, 'Lewohokeng', 'Lewohokeng', 'Lewohokeng', -8.5856000, 122.8906000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74702, 'Lamalewo', 'Lamalewo', 'Lamalewo', -8.4498000, 122.9628000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74703, 'Rianglaka', 'Rianglaka', 'Rianglaka', -8.4714000, 122.9549000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74704, 'Daniwato', 'Daniwato', 'Daniwato', -8.4883000, 122.9516000, 'ID', '2012-11-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74705, 'Data Dian', 'Data Dian', 'Data Dian,Datadian,Long Iroen,Mabaka,Mahakan', 2.0165100, 115.2586900, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74706, 'Lamakera Dua', 'Lamakera Dua', 'Lamakera Dua', -8.4332000, 123.1632000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74707, 'Riangpedang', 'Riangpedang', 'Riangpedang', -8.2904000, 122.8797000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74708, 'Kawaliwu', 'Kawaliwu', 'Kawaliwu', -8.2722000, 122.8962000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74709, 'Raganama', 'Raganama', 'Raganama', -8.3368000, 122.9080000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74710, 'Lewotola', 'Lewotola', 'Lewotola', -8.2916000, 122.9193000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74711, 'Lamatou', 'Lamatou', 'Lamatou', -8.2873000, 122.9267000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74712, 'Wailolong', 'Wailolong', 'Wailolong', -8.3159000, 122.9265000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74713, 'Lewoloba', 'Lewoloba', 'Lewoloba', -8.3240000, 122.9306000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74714, 'Lamawalang', 'Lamawalang', 'Lamawalang', -8.3330000, 122.9330000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74715, 'Watotenga', 'Watotenga', 'Watotenga', -8.2874000, 122.9470000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74716, 'Pantaibesar', 'Pantaibesar', 'Pantaibesar', -8.3492000, 122.9685000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74717, 'Waimana Satu', 'Waimana Satu', 'Waimana Satu', -8.2502000, 122.9797000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74718, 'Amagarapati', 'Amagarapati', 'Amagarapati', -8.3348000, 122.9927000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74719, 'Postoh', 'Postoh', 'Postoh', -8.3386000, 122.9895000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74720, 'Lokea', 'Lokea', 'Lokea', -8.3410000, 122.9864000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74721, 'Lahayong', 'Lahayong', 'Lahayong', -8.3420000, 122.9845000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74722, 'Pohonsirih', 'Pohonsirih', 'Pohonsirih', -8.3438000, 122.9823000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74723, 'Balela', 'Balela', 'Balela', -8.3453000, 122.9803000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74724, 'Ekasapta', 'Ekasapta', 'Ekasapta', -8.3311000, 122.9988000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74725, 'Samalantan', 'Samalantan', 'Samalantan', 0.7927000, 109.1966900, 'ID', '2014-05-01', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74726, 'Rundeng', 'Rundeng', 'Rundeng', 2.6855400, 97.8349400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74727, 'Rantau Prapat', 'Rantau Prapat', 'Rantau Prapat,Rantauprapat', 2.3321000, 100.0520500, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74728, 'Belogili', 'Belogili', 'Belogili', -8.2095000, 122.9230000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74729, 'Laka', 'Laka', 'Laka', -8.1603000, 122.9700000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74730, 'Riangkoli', 'Riangkoli', 'Riangkoli', -8.1884000, 122.9301000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74731, 'Waiklibang', 'Waiklibang', 'Waiklibang', -8.1745000, 122.8955000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74732, 'Basira Satu', 'Basira Satu', 'Basira Satu', -8.0785000, 122.8514000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74733, 'Koten', 'Koten', 'Koten', -8.0989000, 122.8333000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74734, 'Ebak', 'Ebak', 'Ebak', -8.1697000, 122.8508000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74735, 'Bedalewun', 'Bedalewun', 'Bedalewun', -8.1904000, 122.8251000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74736, 'Riangpuho', 'Riangpuho', 'Riangpuho', -8.1974000, 122.8052000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74737, 'Riangkroko', 'Riangkroko', 'Riangkroko', -8.1544000, 122.7890000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74738, 'Turubeang', 'Turubeang', 'Turubeang', -8.1361000, 122.7890000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74739, 'Lewoluo', 'Lewoluo', 'Lewoluo', -8.3169000, 122.7907000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74740, 'Lato', 'Lato', 'Lato', -8.3677000, 122.7584000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74741, 'Kanada', 'Kanada', 'Kanada', -8.4300000, 122.7683000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74742, 'Blaloudeng', 'Blaloudeng', 'Blaloudeng', -8.3992000, 122.7892000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74743, 'Gerong', 'Gerong', 'Gerong', -8.4091000, 122.7873000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74744, 'Buri', 'Buri', 'Buri', -8.3907000, 122.8135000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74745, 'Leworook', 'Leworook', 'Leworook', -8.3870000, 122.8276000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74746, 'Eputobi', 'Eputobi', 'Eputobi', -8.4090000, 122.8324000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74747, 'Lewokluok', 'Lewokluok', 'Lewokluok', -8.3949000, 122.8511000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74748, 'Lamika', 'Lamika', 'Lamika', -8.4163000, 122.8417000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74749, 'Nurabelen', 'Nurabelen', 'Nurabelen', -8.5171000, 122.8259000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74750, 'Riangkaha', 'Riangkaha', 'Riangkaha', -8.5469000, 122.8418000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74751, 'Riangbaring', 'Riangbaring', 'Lerangwutun,Riangbaring', -8.6076000, 122.7794000, 'ID', '2014-08-03', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74752, 'Natargran', 'Natargran', 'Natargran', -8.6139000, 122.4200000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74753, 'Natakoli', 'Natakoli', 'Natakoli', -8.7132000, 122.4269000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74754, 'Pedat', 'Pedat', 'Pedat', -8.7124000, 122.4615000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74755, 'Parumaan', 'Parumaan', 'Parumaan', -8.4546000, 122.4434000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74756, 'Koja Besar', 'Koja Besar', 'Koja Besar', -8.4882000, 122.3951000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74757, 'Mauloo', 'Mauloo', 'Mauloo', -8.7827000, 122.0353000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74758, 'Cua', 'Cua', 'Cua', -8.3226000, 121.6877000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74759, 'Cawalo', 'Cawalo', 'Cawalo', -8.3115000, 121.6978000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74760, 'Lei', 'Lei', 'Lei', -8.3096000, 121.7048000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74761, 'Uwa', 'Uwa', 'Uwa', -8.2970000, 121.7258000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74762, 'Edo', 'Edo', 'Edo', -8.3098000, 121.7277000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74763, 'Natu', 'Natu', 'Natu', -8.3401000, 121.7409000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74764, 'Pemana', 'Pemana', 'Pemana', -8.3501400, 122.3209100, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74765, 'Oli', 'Oli', 'Oli', -10.8159900, 122.6691000, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74766, 'Daudulu', 'Daudulu', 'Daudulu', -10.7439000, 122.9844900, 'ID', '2012-12-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74767, 'Sarae', 'Sarae', 'Sarae', -8.3395000, 120.7594000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74768, 'Lengkorandang', 'Lengkorandang', 'Lengkorandang', -8.3470000, 120.7843000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74769, 'Nangabere', 'Nangabere', 'Nangabere', -8.8173000, 119.9648000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74770, 'Tao', 'Tao', 'Tao', -8.6885000, 119.8241000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74771, 'Mesa', 'Mesa', 'Mesa', -8.5280000, 119.7461000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74772, 'Bidihunggar', 'Bidihunggar', 'Bidihunggar', -9.4006000, 120.0248000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74773, 'Kapunduk', 'Kapunduk', 'Kapunduk', -9.4495000, 120.0481000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74774, 'Rambangaru', 'Rambangaru', 'Rambangaru', -9.4499000, 120.0524000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74775, 'Kowingir', 'Kowingir', 'Kowingir', -9.4583000, 120.0497000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74776, 'Retijawa', 'Retijawa', 'Retijawa', -9.4885000, 120.1016000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74777, 'Tanamiting', 'Tanamiting', 'Tanamiting', -9.7018000, 120.4918000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74778, 'Rutu', 'Rutu', 'Rutu', -9.7444000, 120.4868000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74779, 'Wanga', 'Wanga', 'Wanga', -9.7546000, 120.5840000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74780, 'Matawaimaringu', 'Matawaimaringu', 'Matawaimaringu', -9.8521000, 120.5470000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74781, 'Karawatu', 'Karawatu', 'Karawatu', -9.7020900, 120.5140600, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74782, 'Ngalu', 'Ngalu', 'Ngalu', -10.1453000, 120.7084000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74783, 'Ratilangi', 'Ratilangi', 'Ratilangi', -10.1419000, 120.7186000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74784, 'Kandangubuku', 'Kandangubuku', 'Kandangubuku', -9.8727300, 120.6524800, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74785, 'Kaliuda', 'Kaliuda', 'Kaliuda', -10.1646000, 120.7144000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74786, 'Kalangga', 'Kalangga', 'Kalangga', -10.1600000, 120.3135000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74787, 'Maradabangga', 'Maradabangga', 'Maradabangga', -10.1774000, 120.3595000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74788, 'Nggai', 'Nggai', 'Nggai', -10.2065000, 120.3529000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74789, 'Laironja', 'Laironja', 'Laironja', -10.0798000, 120.2781000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74790, 'Tatunggu', 'Tatunggu', 'Tatunggu', -10.1028000, 120.3294000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74791, 'Hamonggolele', 'Hamonggolele', 'Hamonggolele', -9.5808000, 118.9951000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74792, 'Kaloghodalo', 'Kaloghodalo', 'Kaloghodalo', -9.5473000, 118.9868000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74793, 'Batang', 'Batang', 'Batang', -9.5923000, 118.9871000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74794, 'Bonggor', 'Bonggor', 'Bonggor', -9.5593000, 118.9400000, 'ID', '2013-01-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74795, 'Mangge', 'Mangge', 'Mangge', -8.6772000, 118.9458000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74796, 'Mawu', 'Mawu', 'Mawu', -8.2834000, 118.8372000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74797, 'Bente', 'Bente', 'Bente', -8.3501000, 118.7822000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74798, 'Saneo', 'Saneo', 'Saneo', -8.4711000, 118.4495000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74799, 'Lasi Dua', 'Lasi Dua', 'Lasi Dua', -8.3019000, 118.4027000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74800, 'Piong', 'Piong', 'Piong', -8.3567000, 118.2545000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74801, 'Boro', 'Boro', 'Boro', -8.3688000, 118.2767000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74802, 'Kore Barat', 'Kore Barat', 'Kore Barat', -8.3746000, 118.2954000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74803, 'Kalate', 'Kalate', 'Kalate', -8.5425000, 118.2470000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74804, 'Konte', 'Konte', 'Konte', -8.5448000, 118.2340000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74805, 'Sorinomo', 'Sorinomo', 'Sorinomo', -8.2630000, 117.7961000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74806, 'Karangmete', 'Karangmete', 'Karangmete', -8.2761000, 117.7502000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74807, 'Parang', 'Parang', 'Parang', -8.7440000, 117.9813000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74808, 'Ampu', 'Ampu', 'Ampu', -8.7230000, 118.0054000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74809, 'Bantu', 'Bantu', 'Bantu', -8.7334000, 118.0271000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74810, 'Ongko', 'Ongko', 'Ongko', -8.7392000, 118.0436000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74811, 'Doropeti', 'Doropeti', 'Doropeti', -8.3468000, 117.8216000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74812, 'Mekarjaya', 'Mekarjaya', 'Mekarjaya', -8.8875000, 117.7929000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74813, 'Labangka Satu', 'Labangka Satu', 'Labangka Satu', -8.9001000, 117.7682000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74814, 'Baodesasampar', 'Baodesasampar', 'Baodesasampar', -8.6393000, 117.1508000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74815, 'Tangkanpulit', 'Tangkanpulit', 'Tangkanpulit', -8.6603000, 117.1735000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74816, 'Muhajirin', 'Muhajirin', 'Muhajirin', -8.9027000, 117.7183000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74817, 'Marisgama', 'Marisgama', 'Marisgama', -8.9117000, 117.6840000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74818, 'Karangtengah', 'Karangtengah', 'Karangtengah', -8.9016000, 117.7436000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74819, 'Songkar B', 'Songkar B', 'Songkar B', -8.4849000, 117.4974000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74820, 'Poto', 'Poto', 'Poto', -8.4989000, 117.4785000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74821, 'Osapsio', 'Osapsio', 'Osapsio', -8.4788000, 117.4132000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74822, 'Kembansari', 'Kembansari', 'Kembansari', -8.4811000, 117.4096000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74823, 'Karangbalong', 'Karangbalong', 'Karangbalong', -8.4898000, 117.4248000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74824, 'Sempe Atas', 'Sempe Atas', 'Sempe Atas', -8.6546000, 117.3629000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74825, 'Tatebal', 'Tatebal', 'Tatebal', -8.7536000, 117.3536000, 'ID', '2013-01-13', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74826, 'Pekan Bahapal', 'Pekan Bahapal', '', 3.1131300, 99.1735200, 'ID', '2013-01-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74827, 'Sukamaju', 'Sukamaju', 'Sukamaju', -8.9738000, 117.2018000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74828, 'Krida', 'Krida', 'Krida', -8.9780000, 117.1875000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74829, 'Padasuka', 'Padasuka', 'Padasuka', -8.9933000, 117.2070000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74830, 'Mandarahan', 'Mandarahan', 'Mandarahan', -1.7961000, 100.8295000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74831, 'Rantauambacang', 'Rantauambacang', 'Rantauambacang', -1.3978000, 101.9202000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74832, 'Siulakderasmudik', 'Siulakderasmudik', 'Siulakderasmudik', -1.9067000, 101.2303000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74833, 'Sobeok', 'Sobeok', 'Sobeok', -8.7581500, 117.1860200, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74834, 'Senayan', 'Senayan', 'Senayan', -8.6127000, 116.8505000, 'ID', '2014-10-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74835, 'Mantar', 'Mantar', 'Mantar', -8.6160000, 116.8257000, 'ID', '2013-02-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74836, 'Tanjung Lubuk', 'Tanjung Lubuk', 'Tanjung Lubuk', -3.3599000, 104.8429000, 'ID', '2013-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74837, 'Negeriagung', 'Negeriagung', 'Negeriagung', -3.7673000, 103.6516000, 'ID', '2013-04-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74838, 'Waghete', 'Waghete', 'Waghete', -4.0390100, 136.2748900, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74839, 'Eci', 'Eci', 'Eci,Etsi', -6.1238200, 139.1536500, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74840, 'Getentiri', 'Getentiri', 'Getentiri', -6.5888700, 140.3461300, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74841, 'Muting', 'Muting', 'Muting', -7.3075900, 140.5578200, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74842, 'Mindiptana', 'Mindiptana', 'Mindiptana', -5.8638600, 140.6925300, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74843, 'Warmare', 'Warmare', 'Warmare', -1.1143000, 133.9361000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74844, 'Kebar', 'Kebar', 'Kebar', -0.8474000, 133.1457000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74845, 'Bomomani', 'Bomomani', 'Bomomani', -4.0659000, 135.8182000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74846, 'Merdey', 'Merdey', 'Merdey', -1.6623000, 133.3485000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74847, 'Bofuer', 'Bofuer', 'Bofuer', -3.0114000, 133.7626000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74848, 'Topo', 'Topo', 'Topo', -3.5403000, 135.5375000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74849, 'Homeyo', 'Homeyo', 'Homeyo', -3.6630000, 136.4692000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74850, 'Kumopa', 'Kumopa', 'Kumopa', -3.8216000, 136.5092000, 'ID', '2017-02-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74851, 'Moanemani', 'Moanemani', 'Moanemani', -3.9679000, 136.1116000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74852, 'Bilogai', 'Bilogai', 'Bilogai', -3.7181000, 136.6683000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74853, 'Beoga', 'Beoga', 'Beoga', -3.8395000, 137.1667000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74854, 'Trimuris', 'Trimuris', 'Trimuris', -1.9582000, 137.8366000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74855, 'Arbais', 'Arbais', 'Arbais', -1.7393000, 138.4043000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74856, 'Samanente', 'Samanente', 'Samanente', -2.1992000, 138.8803000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74857, 'Guay', 'Guay', 'Guay', -2.5033000, 139.8099000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74858, 'Banda', 'Banda', 'Banda', -3.1796000, 140.9419000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74859, 'Wurigelebur', 'Wurigelebur', 'Wurigelebur', -3.7627000, 138.8085000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74860, 'Karubaga', 'Karubaga', 'Karubaga', -3.6994000, 138.4579000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74861, 'Sawoi', 'Sawoi', 'Sawoi', -2.6246000, 140.3356000, 'ID', '2013-05-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74862, 'Krajan Dua', 'Krajan Dua', 'Krajan Dua', -8.0250000, 113.2508000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74863, 'Banjar Pande', 'Banjar Pande', 'Banjar Pande', -8.5126000, 115.2399000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74864, 'Banjar Batur', 'Banjar Batur', 'Banjar Batur', -8.5997000, 115.2135000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74865, 'Sumberan', 'Sumberan', 'Sumberan', -8.4003000, 114.2681000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74866, 'Banjar Dajanmargi', 'Banjar Dajanmargi', 'Banjar Dajanmargi', -8.1499000, 115.1236000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74867, 'Krajan Kulon', 'Krajan Kulon', 'Krajan Kulon', -8.1454000, 113.1829000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74868, 'Banjar Ubud', 'Banjar Ubud', 'Banjar Ubud', -8.4761000, 115.2932000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74869, 'Banjar Tengah', 'Banjar Tengah', 'Banjar Tengah', -8.4509000, 115.2895000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74870, 'Banjar Kelodan', 'Banjar Kelodan', 'Banjar Kelodan', -8.4986000, 115.3683000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74871, 'Karangbaru', 'Karangbaru', 'Karangbaru', -8.6212000, 116.4759000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74872, 'Kanjilu', 'Kanjilu', 'Kanjilu', -9.7783000, 120.0577000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74873, 'Nao', 'Nao', 'Nao', -8.4936000, 120.7339000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74874, 'Wonojati', 'Wonojati', 'Wonojati', -8.2754000, 113.6537000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74875, 'Sumberpandan', 'Sumberpandan', 'Sumberpandan', -8.0010000, 113.7848000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74876, 'Jatian', 'Jatian', 'Jatian', -8.0196000, 113.7953000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74877, 'Penanggungan', 'Penanggungan', 'Penanggungan', -8.0189000, 113.7785000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74878, 'Banjar Tegal', 'Banjar Tegal', 'Banjar Tegal', -8.1243000, 115.0891000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74879, 'Banjar Kajanan', 'Banjar Kajanan', 'Banjar Kajanan', -8.1235000, 115.1225000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74880, 'Krajan Wonokoyo', 'Krajan Wonokoyo', 'Krajan,Krajan Wonokoyo', -7.7141000, 114.0835000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74881, 'Krajan Curahcotok', 'Krajan Curahcotok', 'Krajan,Krajan Curahcotok', -7.7169000, 114.0643000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74882, 'Gubuk Lauk', 'Gubuk Lauk', 'Gubuk Lauk', -8.6324000, 116.4512000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74883, 'Rawuk', 'Rawuk', 'Rawuk', -8.5625000, 120.2369000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74884, 'Banjar Mundukanggrek', 'Banjar Mundukanggrek', 'Banjar Mundukanggrek,Mundukanggrek', -8.3775800, 114.7427400, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74885, 'Tuwa', 'Tuwa', 'Tuwa', -8.7295000, 120.6987000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74886, 'Doka', 'Doka', 'Doka', -8.8509000, 121.0547000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74887, 'Winong', 'Winong', 'Winong', -8.0441000, 111.9003000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74888, 'Jati', 'Jati', 'Jati', -8.0562000, 111.9585000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74889, 'Pakel', 'Pakel', 'Pakel', -8.0684000, 111.9891000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74890, 'Prayan', 'Prayan', 'Prayan', -8.0788000, 111.8951000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74891, 'Banjar Tengah', 'Banjar Tengah', 'Banjar Tengah', -8.3658000, 114.6671000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74892, 'Munduk', 'Munduk', 'Munduk', -8.3695000, 114.6781000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74893, 'Liang', 'Liang', 'Liang', -8.8601000, 116.8293000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74894, 'Monggo', 'Monggo', 'Monggo', -8.5140000, 118.5669000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74895, 'Poja Nae', 'Poja Nae', 'Poja Nae', -8.5024700, 119.0386700, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74896, 'Kabandang', 'Kabandang', 'Kabandang', -9.7448000, 120.2511000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74897, 'Tarikolot', 'Tarikolot', 'Tarikolot', -6.3630000, 106.0174000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74898, 'Babakan', 'Babakan', 'Babakan', -6.3520000, 106.0736000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74899, 'Parigi', 'Parigi', 'Parigi', -6.3497000, 106.0254000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74900, 'Parigi', 'Parigi', 'Parigi', -6.3658000, 105.9924000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74901, 'Panenjoan', 'Panenjoan', 'Panenjoan', -6.1292000, 106.0044000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74902, 'Sobong', 'Sobong', 'Sobong', -6.3809000, 106.0096000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74903, 'Cibogo', 'Cibogo', 'Cibogo', -6.3788000, 106.1210000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74904, 'Pasirawi', 'Pasirawi', 'Pasirawi', -6.3873000, 106.0483000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74905, 'Babakan', 'Babakan', 'Babakan', -6.4174000, 106.0188000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74906, 'Sukamaju', 'Sukamaju', 'Sukamaju', -7.0051000, 106.8868000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74907, 'Legok', 'Legok', 'Legok', -7.0189000, 106.9553000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74908, 'Cikopo', 'Cikopo', 'Cikopo', -7.3707000, 107.6749000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74909, 'Negla', 'Negla', 'Negla', -7.2754000, 107.7809000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74910, 'Cidarengdeng', 'Cidarengdeng', 'Cidarengdeng', -7.2600000, 107.7864000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74911, 'Panyingkiran', 'Panyingkiran', 'Panyingkiran', -7.2609000, 107.8115000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74912, 'Desakolot', 'Desakolot', 'Desakolot', -7.3339000, 107.8064000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74913, 'Kota Agung', 'Kota Agung', 'Kota Agung,Kotaagung,Koto Agoeng,Kotŏ Agoeng', -5.5025700, 104.6453800, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74914, 'Sukamulya', 'Sukamulya', 'Sukamulya', -7.1859000, 107.1028000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74915, 'Cintasari', 'Cintasari', 'Cintasari', -7.2260000, 107.0356000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74916, 'Munjul', 'Munjul', 'Moendjoel,Munjul', -7.2488000, 107.8811000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74917, 'Pataruman', 'Pataruman', 'Pataroeman,Pataruman', -7.1995000, 107.8931000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74918, 'Babakandesa', 'Babakandesa', 'Babakandesa', -7.0485000, 107.9684000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74919, 'Cipeundeuy', 'Cipeundeuy', 'Cipeundeuy', -7.0769000, 107.8913000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74920, 'Cikubang', 'Cikubang', 'Cikubang', -7.4453000, 108.0225000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74921, 'Muncang', 'Muncang', 'Moentjang,Muncang', -7.4702000, 108.0796000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74922, 'Babakan', 'Babakan', 'Babakan', -7.3202000, 108.0591000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74923, 'Situ', 'Situ', 'Situ', -7.3003000, 108.0405000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74924, 'Pulosari', 'Pulosari', 'Pulosari', -7.0091000, 108.0174000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74925, 'Cilengkrang', 'Cilengkrang', 'Cilengkrang,Tjilengkrang', -7.0102000, 108.0984000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74926, 'Pangkalan', 'Pangkalan', 'Pangkalan,Pangkalan 1', -7.0211000, 108.0710000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74927, 'Cigadog', 'Cigadog', 'Cigadog,Tjigadog 1', -7.0482000, 108.0450000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74928, 'Kurnia', 'Kurnia', 'Kurnia', -7.0522000, 108.0363000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74929, 'Saar', 'Saar', 'Saar', -7.0578000, 108.0730000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74930, 'Cimuncang', 'Cimuncang', 'Cimuncang,Tjimoentjang 1', -7.0763000, 108.0525000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74931, 'Sukarasa', 'Sukarasa', 'Sukarasa', -7.1612000, 108.0002000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74932, 'Sukaraja', 'Sukaraja', 'Soekaradja 2,Sukaraja', -7.1635000, 108.0002000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74933, 'Cipeundeuy', 'Cipeundeuy', 'Cipeundeuy,Tjipeundeuj', -7.0147000, 108.2315000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74934, 'Caringin', 'Caringin', 'Caringin', -7.0881000, 107.1380000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74935, 'Ciherang', 'Ciherang', 'Ciherang,Tjiherang', -7.0599000, 107.2137000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74936, 'Cipari', 'Cipari', 'Cipari,Tjipari Tiga', -7.7594000, 108.2751000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74937, 'Karyamandala', 'Karyamandala', 'Karyamandala', -7.5443000, 108.2817000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74938, 'Lengkongbarang', 'Lengkongbarang', 'Lengkongbarang', -7.5712000, 108.2814000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74939, 'Panyingkiran', 'Panyingkiran', 'Panjingkiran Tiga,Panyingkiran', -7.2960000, 108.2647000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74940, 'Sukasirna', 'Sukasirna', 'Sukasirna', -7.3655000, 108.2778000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74941, 'Sukamukti', 'Sukamukti', 'Sukamukti', -7.0166600, 108.3632000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74942, 'Karanganyar', 'Karanganyar', 'Karanganjar,Karanganyar', -7.3063000, 108.4213000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74943, 'Kertaharja', 'Kertaharja', 'Kertaharja', -7.3110000, 108.3952000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74944, 'Sukaharja', 'Sukaharja', 'Sukaharja', -7.3236000, 108.4515000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74945, 'Cicadas', 'Cicadas', 'Cicadas,Tjitjadas Satu', -7.1564000, 108.4192000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74946, 'Nangewer', 'Nangewer', 'Nangewer,Nanggewer', -7.2489000, 108.4071000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74947, 'Margajaya', 'Margajaya', 'Margajaya', -7.2356000, 108.4245000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74948, 'Garunggang', 'Garunggang', 'Garoenggang,Garunggang', -7.2046000, 108.4423000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74949, 'Kampunganyar', 'Kampunganyar', 'Kampunganyar', -6.5109000, 111.0359000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74950, 'Kampunganyar', 'Kampunganyar', 'Kampunganyar', -6.5507000, 111.0507000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74951, 'Jetak', 'Jetak', 'Jetak', -6.8144000, 111.1299000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74952, 'Padas', 'Padas', 'Padas', -6.8613000, 111.1760000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74953, 'Bringin', 'Bringin', 'Bringin', -6.7110000, 111.0320000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74954, 'Bojongaren', 'Bojongaren', 'Bojongaren', -7.6445000, 108.6451000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74955, 'Mancagar', 'Mancagar', 'Mancagar,Mantjagar', -7.0171000, 108.5853000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74956, 'Tarikolot', 'Tarikolot', 'Tarikolot', -7.0223000, 108.5084000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74957, 'Babakan', 'Babakan', 'Babakan', -7.0273000, 108.5348000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74958, 'Pabuaran', 'Pabuaran', 'Pabuaran', -7.0511000, 108.6038000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74959, 'Tengger', 'Tengger', 'Tengger', -6.9856000, 111.2975000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74960, 'Cibeureum', 'Cibeureum', 'Cibeureum', -7.5141000, 108.6837000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74961, 'Sukaharja', 'Sukaharja', 'Sukaharja', -7.4306000, 108.6261000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74962, 'Karanggeneng', 'Karanggeneng', 'Karanggeneng', -6.7858000, 111.3953000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74963, 'Banyuurip', 'Banyuurip', 'Banyuurip', -6.8148000, 111.4193000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74964, 'Wonodadi', 'Wonodadi', 'Wanadadi,Wonodadi', -7.4574000, 108.8332000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74965, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -6.9930000, 112.5644000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74966, 'Sidomulyo', 'Sidomulyo', 'Sidomulyo', -6.9674000, 112.5513000, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74967, 'Sukorejo', 'Sukorejo', 'Sukorejo', -6.9820400, 112.4998600, 'ID', '2013-06-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74968, 'Sobo', 'Sobo', 'Sobo', -8.2821000, 111.5113000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74969, 'Gondang', 'Gondang', 'Gondang', -8.0312000, 111.5606000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74970, 'Jambu', 'Jambu', 'Jambu', -8.0338000, 111.6379000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74971, 'Gondang', 'Gondang', 'Gondang', -8.0462000, 111.6566000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74972, 'Wonokromo', 'Wonokromo', 'Wonokromo', -8.0565000, 111.8494000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74973, 'Jarakan', 'Jarakan', 'Djarakan,Jarakan', -8.0601000, 111.8520000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74974, 'Banaran', 'Banaran', 'Banaran', -8.0331000, 111.8661000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74975, 'Kramat', 'Kramat', 'Kramat', -7.7004000, 113.4896000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74976, 'Sumber Tengah', 'Sumber Tengah', 'Sumber Tengah', -7.0406000, 113.5349000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74977, 'Pakong Laok', 'Pakong Laok', 'Pakong Laok', -7.0417000, 113.5567000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74978, 'Batas Barat', 'Batas Barat', 'Batas Barat', -7.0506000, 113.5429000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74979, 'Tenggina', 'Tenggina', 'Tenggina', -7.0544000, 113.5653000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74980, 'Nangger', 'Nangger', 'Nangger', -7.0327000, 113.6329000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74981, 'Tengginan', 'Tengginan', 'Tengginan', -7.1039000, 113.6287000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74982, 'Lembanah', 'Lembanah', 'Lembanah', -7.1036000, 113.6364000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74983, 'Konkokon', 'Konkokon', 'Konkokon', -7.0361000, 113.6851000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74984, 'Karengan', 'Karengan', 'Karengan', -7.0676000, 113.9589000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74985, 'Gapurana Daya', 'Gapurana Daya', 'Gapurana Daya', -7.0743000, 113.9884000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74986, 'Kokop', 'Kokop', 'Kokop', -6.9425000, 113.0303000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74987, 'Tenggina', 'Tenggina', 'Tenggina', -6.9987000, 113.5648000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74988, 'Lebak', 'Lebak', 'Lebak', -6.8882000, 113.6541000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74989, 'Lenteng', 'Lenteng', 'Lenteng', -6.9540000, 113.7386000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74990, 'Feuknoni', 'Feuknoni', 'Feuknoni', -9.8502000, 124.5163000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74991, 'Manufui', 'Manufui', 'Manufui', -9.7903000, 124.7262000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74992, 'Bontang Baru', 'Bontang Baru', 'Bontang Baru', 0.1194000, 117.4866000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74993, 'Larantuka', 'Larantuka', 'Larantuka', -8.3272000, 123.0023000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74994, 'Tangguhang', 'Tangguhang', 'Tangguhang', -10.1535000, 120.6278000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74995, 'Tanarara Timur', 'Tanarara Timur', 'Tanarara Timur', -10.0106000, 120.2949000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74996, 'Rora Timur', 'Rora Timur', 'Rora Timur', -8.4867000, 118.4816000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74997, 'Karangdima', 'Karangdima', 'Karangdima', -8.4754000, 117.3918000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74998, 'Wasior', 'Wasior', 'Wasior', -2.6423000, 134.4883000, 'ID', '2013-06-06', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(74999, 'Pulau Punjung', 'Pulau Punjung', 'Pulau Punjung,Pulaupunjung', -0.9590000, 101.5002000, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75000, 'Teluk Pinang', 'Teluk Pinang', 'Teluk Pinang,Telukpinang', -0.1819800, 103.3589300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75001, 'Suak Bakung', 'Suak Bakung', 'Suak Bakung', 3.0056000, 97.3645500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75002, 'Paya Dapur', 'Paya Dapur', 'Paya Dapur', 3.2098400, 97.4176800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75003, 'Labuhan Bajau', 'Labuhan Bajau', 'Labuhan Bajau', 2.4011900, 96.4551600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75004, 'Luan Balu', 'Luan Balu', 'Luan Balu', 2.5258200, 96.3317200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75005, 'Lauke', 'Lauke', 'Lauke', 2.5840000, 96.0414200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75006, 'Kuala Baru', 'Kuala Baru', 'Kuala Baru', 2.2473100, 97.7869700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75007, 'Rimo', 'Rimo', 'Rimo', 2.3594400, 97.9608300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75008, 'Danauparis', 'Danauparis', 'Danauparis', 2.4109600, 98.0853700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75009, 'Pulo Batal', 'Pulo Batal', 'Pulo Batal', 2.2253200, 97.2341300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75010, 'Pulopaya', 'Pulopaya', 'Pulopaya', 2.8734900, 97.6517800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75011, 'Pulo Ie', 'Pulo Ie', 'Pulo Ie', 3.2819200, 97.3554500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75012, 'Terbangan', 'Terbangan', 'Terbangan', 3.2154600, 97.2716300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75013, 'Tapaktuan', 'Tapaktuan', 'Tapaktuan', 3.2862500, 97.1604500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75014, 'Samadua', 'Samadua', 'Samadua', 3.3356000, 97.1307800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75015, 'Sawang', 'Sawang', 'Sawang', 3.4034200, 97.1011000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75016, 'Meukek', 'Meukek', 'Meukek', 3.4760800, 97.0623500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75017, 'Peuleumat', 'Peuleumat', 'Peuleumat', 3.5272500, 97.0308600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75018, 'Kota Trieng', 'Kota Trieng', 'Kota Trieng', 3.5984000, 96.9624300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75019, 'Mersak', 'Mersak', 'Mersak', 3.5141600, 97.3820900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75020, 'Seupakat', 'Seupakat', 'Seupakat', 3.6433300, 97.4627900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75021, 'Tanah Merah', 'Tanah Merah', 'Tanah Merah', 3.6322100, 97.7023400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75022, 'Kutacane', 'Kutacane', 'Kutacane', 3.5221100, 97.7962500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75023, 'Bambol', 'Bambol', 'Bambol', 3.4499100, 97.8797200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75024, 'Lawesigalagala Timur', 'Lawesigalagala Timur', 'Lawesigalagala Timur', 3.3322200, 97.9421200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75025, 'Ngkan', 'Ngkan', 'Ngkan', 3.4017300, 97.6687200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75026, 'Idi Rayeuk', 'Idi Rayeuk', 'Idi Rayeuk', 4.9303700, 97.7912900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75027, 'Idi Cut', 'Idi Cut', 'Idi Cut', 4.9779700, 97.7319800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75028, 'Bagok', 'Bagok', 'Bagok', 4.9470700, 97.6651900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75029, 'Beusa Seberang', 'Beusa Seberang', 'Beusa Seberang', 4.8738000, 97.8570800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75030, 'Sungai Raya', 'Sungai Raya', 'Sungai Raya', 4.7611600, 97.9116500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75031, 'Rantau Panjang', 'Rantau Panjang', 'Rantau Panjang', 4.7271100, 97.7572400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75032, 'Buket Teukuh', 'Buket Teukuh', 'Buket Teukuh', 4.8087900, 97.6589300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75033, 'Seuneubok Bayu', 'Seuneubok Bayu', 'Seuneubok Bayu', 4.8779400, 97.5748300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75034, 'Simpang Ulim', 'Simpang Ulim', 'Simpang Ulim', 5.1222300, 97.5623000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75035, 'Kota Binjai', 'Kota Binjai', 'Kota Binjai', 5.0469000, 97.6090300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75036, 'Luthu', 'Luthu', 'Luthu', 5.3135100, 95.4029400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75037, 'Indrapuri', 'Indrapuri', 'Indrapuri', 5.4770400, 95.4173600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75038, 'Angan', 'Angan', 'Angan', 5.6057200, 95.3914400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75039, 'Lampuuk', 'Lampuuk', 'Lampuuk', 5.5709800, 95.3895400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75040, 'Sibreh', 'Sibreh', 'Sibreh', 5.5186300, 95.3733600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75041, 'Mata Ie', 'Mata Ie', 'Mata Ie', 5.5278000, 95.3347300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75042, 'Keumala', 'Keumala', 'Keumala', 5.2493000, 95.9238200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75043, 'Geuleumpangminyeuk', 'Geuleumpangminyeuk', 'Geuleumpangminyeuk', 5.2500000, 96.0290400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75044, 'Rusip', 'Rusip', 'Rusip', 4.6680800, 96.6099500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75045, 'Kute Panang', 'Kute Panang', 'Kute Panang', 4.6510700, 96.7344300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75046, 'Kemil', 'Kemil', 'Kemil', 4.6207900, 96.7568600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75047, 'Pegasing', 'Pegasing', 'Pegasing', 4.5766900, 96.7759200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75048, 'Kuala Bintang', 'Kuala Bintang', 'Kuala Bintang', 4.5750000, 96.9628200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75049, 'Jagongjeget', 'Jagongjeget', 'Jagongjeget', 4.3872700, 96.7929800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75050, 'Banda Layung', 'Banda Layung', 'Banda Layung', 4.2416100, 96.0969500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75051, 'Keudee Aron', 'Keudee Aron', 'Keudee Aron', 4.2145000, 96.1787800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75052, 'Pantai Ceuremen', 'Pantai Ceuremen', 'Pantai Ceuremen', 4.3690100, 96.1955500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75053, 'Uleeglee', 'Uleeglee', 'Uleeglee', 5.1906600, 96.3487500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75054, 'Jumpangdua', 'Jumpangdua', 'Jumpangdua', 5.1966900, 96.7844500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75055, 'Cot Baroh', 'Cot Baroh', 'Cot Baroh', 5.2155400, 96.8408400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75056, 'Adil Makmur', 'Adil Makmur', 'Adil Makmur', 5.1984300, 96.8701500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75057, 'Juli', 'Juli', 'Juli', 5.1078200, 96.7105800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75058, 'Alue Glumpang', 'Alue Glumpang', 'Alue Glumpang', 5.0794200, 96.7648600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75059, 'Blang Ara', 'Blang Ara', 'Blang Ara', 4.2817500, 96.3708700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75060, 'Beutong Ateuh', 'Beutong Ateuh', 'Beutong Ateuh', 4.2512900, 96.4372600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75061, 'Alue Bilie', 'Alue Bilie', 'Alue Bilie', 4.0052600, 96.5602800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75062, 'Suka Makmue', 'Suka Makmue', 'Suka Makmue', 4.0031200, 96.6176200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75063, 'Blang Mane', 'Blang Mane', 'Blang Mane', 5.0174000, 96.7721400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75064, 'Kalde Panga', 'Kalde Panga', 'Kalde Panga', 4.5557000, 95.7150800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75065, 'Lageun', 'Lageun', 'Lageun', 4.6936100, 95.5303200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75066, 'Blang Dalam', 'Blang Dalam', 'Blang Dalam', 4.8961500, 95.6197400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75067, 'Kajeung', 'Kajeung', 'Kajeung', 4.5138500, 96.1324400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75068, 'Peukanbada', 'Peukanbada', 'Peukanbada', 5.5360600, 95.2284000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75069, 'Jantho', 'Jantho', 'Jantho', 5.3334000, 95.6133600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75070, 'Geumpang', 'Geumpang', 'Geumpang', 4.8287600, 96.1607300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75071, 'Mane', 'Mane', 'Mane', 4.9378900, 96.0063000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75072, 'Tiro', 'Tiro', 'Tiro', 5.1919600, 95.9366600, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75073, 'Lampoih', 'Lampoih', 'Lampoih', 5.3178000, 95.9862800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75074, 'Caloue', 'Caloue', 'Caloue', 5.3149400, 95.9706000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75075, 'Matangkuli', 'Matangkuli', 'Matangkuli', 5.0319800, 97.2835100, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75076, 'Matangpayang', 'Matangpayang', 'Matangpayang', 5.1257700, 97.2494900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75077, 'Seunudon', 'Seunudon', 'Seunudon', 5.2086400, 97.4488900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75078, 'Bulahblangaro', 'Bulahblangaro', 'Bulahblangaro', 5.0862600, 96.8527300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75079, 'Blang Ara', 'Blang Ara', 'Blang Ara', 5.1108800, 97.0295800, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75080, 'Babah Rot', 'Babah Rot', 'Babah Rot', 3.9288000, 96.6890200, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75081, 'Suek', 'Suek', 'Suek', 3.7749500, 96.8177900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75082, 'Kutapanjang', 'Kutapanjang', 'Kutapanjang', 4.0375300, 97.2371000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75083, 'Sangir', 'Sangir', 'Sangir', 3.8862200, 97.5278700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75084, 'Sungai Iyu', 'Sungai Iyu', 'Sungai Iyu', 4.4051500, 98.1324900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75085, 'Karangbaru', 'Karangbaru', 'Karangbaru', 4.3056300, 98.0270900, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75086, 'Sungi Liput', 'Sungi Liput', 'Sungi Liput', 4.2073700, 98.0127500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75087, 'Tenggulun', 'Tenggulun', 'Tenggulun', 3.9913100, 98.0070500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75088, 'Pulau Tiga', 'Pulau Tiga', 'Pulau Tiga', 4.1268500, 97.8776000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75089, 'Simpang Teritit', 'Simpang Teritit', 'Simpang Teritit', 4.6970700, 96.8567000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75090, 'Ulee Gle', 'Ulee Gle', 'Ulee Gle', 5.2031400, 96.3269000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75091, 'Trienggadeng', 'Trienggadeng', 'Trienggadeng', 5.2402000, 96.2018000, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75092, 'Pante Raja', 'Pante Raja', 'Pante Raja', 5.2452500, 96.1462400, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75093, 'Lambaro', 'Lambaro', 'Lambaro', 5.5557900, 95.3438500, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75094, 'Pasir Panjang', 'Pasir Panjang', 'Pasir Panjang', 2.6745500, 98.0005700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75095, 'Lawepakam', 'Lawepakam', 'Lawepakam', 3.3043600, 97.9679300, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75096, 'Kuala Baru Sungai', 'Kuala Baru Sungai', 'Kuala Baru Sungai', 2.4077900, 97.7404700, 'ID', '2013-07-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75097, 'South Tangerang', 'South Tangerang', 'Tangerang Selatan', -6.2886200, 106.7178900, 'ID', '2013-11-29', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75098, 'Krajan Mangaran', 'Krajan Mangaran', 'Krajan,Krajan Mangaran', -7.6623000, 114.0425000, 'ID', '2013-08-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75099, 'Krajan Battal', 'Krajan Battal', 'Krajan,Krajan Battal', -7.7474000, 114.0409000, 'ID', '2013-08-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75100, 'Kotabahagia', 'Kotabahagia', 'Kotabahagia', 3.8190000, 96.7658000, 'ID', '2013-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75101, 'Blangpulo', 'Blangpulo', 'Blangpulo', 5.2068000, 97.0774300, 'ID', '2013-08-10', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75102, 'Bangsal Aceh', 'Bangsal Aceh', 'Bangsal Aceh', 1.7320200, 101.3761400, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75103, 'Rimba Sekampung', 'Rimba Sekampung', 'Rimba Sekampung', 1.6756000, 101.4374800, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75104, 'Teluk Binjai', 'Teluk Binjai', 'Teluk Binjai,Telukbinjai', 1.6719500, 101.4497200, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75105, 'Buluh Kasap', 'Buluh Kasap', 'Buluh Kasap,Bulukasap', 1.6807700, 101.4561200, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75106, 'Kampung Laksamana', 'Kampung Laksamana', 'Kampung Laksamana', 1.6793400, 101.4388500, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75107, 'Tanjung Palas', 'Tanjung Palas', 'Tanjung Palas', 1.6785300, 101.4700800, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75108, 'Bagan Besar', 'Bagan Besar', 'Bagan Besar,Baganbesar', 1.5818300, 101.3866600, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75109, 'Sarulla', 'Sarulla', 'Sarulla', 1.7859600, 99.1137500, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75110, 'Long Peso', 'Long Peso', 'Long Peso', 2.6902800, 116.7849000, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75111, 'Long Beluah', 'Long Beluah', 'Long Beliah,Long Beluah', 2.7599200, 117.0890500, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75112, 'Long Bang', 'Long Bang', 'Long Bang', 2.8479200, 116.9045400, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75113, 'Sungai Nyamuk', 'Sungai Nyamuk', 'Sungai Nyamuk', 4.1438300, 117.9108700, 'ID', '2014-03-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75114, 'Binalawan', 'Binalawan', 'Binalawan', 4.0919700, 117.7732200, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75115, 'Long Layu', 'Long Layu', 'Long Layu', 3.6102300, 115.6999300, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75116, 'Sungaiboh', 'Sungaiboh', 'Sungaiboh', 1.6386300, 115.2331900, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75117, 'Long Loreh', 'Long Loreh', 'Leroh,Long Loreh,Loreh', 3.1679000, 116.4702700, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75118, 'Sekatak Bengara', 'Sekatak Bengara', 'Sekatak Bengara', 3.0875700, 117.2134500, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75119, 'Tanjung Palas', 'Tanjung Palas', 'Tanjung Palas,Tanjungpalas', 2.8298800, 117.3425500, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75120, 'Kerangagung', 'Kerangagung', 'Kerangagung', 3.0012300, 117.2171400, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75121, 'Kayan Hulu', 'Kayan Hulu', 'Kayan Hulu', 3.8257200, 115.8667100, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75122, 'Pasarujungbatu', 'Pasarujungbatu', 'Pasarujungbatu', 1.0359600, 99.9484000, 'ID', '2013-09-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75123, 'Panyabungan', 'Panyabungan', 'Panyabungan', 1.9320600, 99.6911300, 'ID', '2016-01-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75124, 'Sipoholon', 'Sipoholon', 'Sipoholon', 2.0649000, 98.9465000, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75125, 'Sampuran', 'Sampuran', 'Sampuran', 2.0084800, 98.9665800, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75126, 'Sukarama', 'Sukarama', 'Sukarama', 2.6465000, 98.3015000, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75127, 'Sumbul', 'Sumbul', 'Sumbul', 2.7410000, 98.3975000, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75128, 'Pulautemiang', 'Pulautemiang', 'Pulautemiang', -1.2249500, 102.2422800, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75129, 'Handilenam', 'Handilenam', 'Handilenam', -0.8244000, 117.2488000, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75130, 'Palaran', 'Palaran', 'Palaran', -0.5711900, 117.1956800, 'ID', '2013-11-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75131, 'Batusopang', 'Batusopang', 'Batusopang', -1.8236000, 115.9126000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75132, 'Awayan', 'Awayan', 'Awayan', -2.4622000, 115.6538000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75133, 'Matangai', 'Matangai', 'Matangai', -2.5825000, 114.3728000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75134, 'Jenamas', 'Jenamas', 'Jenamas', -2.4464000, 114.9080000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75135, 'Danaupanggang', 'Danaupanggang', 'Danaupanggang', -2.4082000, 115.0398000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75136, 'Telagaselaba', 'Telagaselaba', 'Telagaselaba', -2.3829000, 115.3144000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75137, 'Sungaiturak', 'Sungaiturak', 'Sungaiturak', -2.3535000, 115.3866000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75138, 'Pasararba', 'Pasararba', 'Pasararba', -2.2591000, 115.3166000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75139, 'Tanta', 'Tanta', 'Tanta', -2.2285000, 115.4522000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75140, 'Tambarangan', 'Tambarangan', 'Tambarangan', -3.0039000, 115.1321000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75141, 'Tapintengah', 'Tapintengah', 'Tapintengah', -2.9564000, 115.0372000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75142, 'Margasari', 'Margasari', 'Margasari', -2.8558000, 115.0367000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75143, 'Margasarihilir', 'Margasarihilir', 'Margasarihilir', -2.8266000, 115.0066000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75144, 'Angkimang', 'Angkimang', 'Angkimang', -2.7344000, 115.3101000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75145, 'Pasingkan', 'Pasingkan', 'Pasingkan', -2.6860000, 115.2105000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75146, 'Pendawanbaru', 'Pendawanbaru', 'Pendawanbaru', -2.5303000, 115.2418000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75147, 'Sungaitatas', 'Sungaitatas', 'Sungaitatas', -2.8353000, 114.4887000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75148, 'Bantul', 'Bantul', 'Bantul', -3.0432000, 114.7614000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75149, 'Barimba', 'Barimba', 'Barimba', -2.9418000, 114.4427000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75150, 'Anjirserapat', 'Anjirserapat', 'Anjirserapat', -3.0391000, 114.3845000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75151, 'Basarang', 'Basarang', 'Basarang', -2.9637000, 114.2994000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75152, 'Anjirmuara', 'Anjirmuara', 'Anjirmuara', -3.1973000, 114.5667000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75153, 'Sungaigampa', 'Sungaigampa', 'Sungaigampa', -3.0849000, 114.6996000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75154, 'Sungaipuntik', 'Sungaipuntik', 'Sungaipuntik', -3.1690000, 114.6830000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75155, 'Sungaitabuk', 'Sungaitabuk', 'Sungaitabuk', -3.2473000, 114.7709000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75156, 'Gambut', 'Gambut', 'Gambut', -3.3961000, 114.6752000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75157, 'Astambul', 'Astambul', 'Astambul', -3.3696000, 114.9143000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75158, 'Sungairaya', 'Sungairaya', 'Sungairaya', -3.2864000, 115.0561000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75159, 'Kurau', 'Kurau', 'Kurau', -3.5658000, 114.5795000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75160, 'Bakau', 'Bakau', 'Bakau', -2.4105000, 116.2387000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75161, 'Pudi', 'Pudi', 'Pudi', -2.8878000, 116.3435000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75162, 'Putatbasiun', 'Putatbasiun', 'Putatbasiun', -2.4206000, 115.5294000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75163, 'Mungkuruyam', 'Mungkuruyam', 'Mungkuruyam', -2.2668000, 115.5759000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75164, 'Halong', 'Halong', 'Halong', -2.2580000, 115.6511000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75165, 'Manunggulama', 'Manunggulama', 'Manunggulama', -2.5142000, 116.1656000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75166, 'Binawara', 'Binawara', 'Binawara', -3.4853000, 115.7946000, 'ID', '2013-12-16', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75167, 'Lontar', 'Lontar', 'Lontar', -3.9751000, 116.0698000, 'ID', '2013-12-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75168, 'Allealle', 'Allealle', 'Allealle', -3.9116000, 116.3038000, 'ID', '2013-12-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75169, 'Telagalangsat', 'Telagalangsat', 'Telagalangsat', -2.7908000, 115.5643000, 'ID', '2013-12-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75170, 'Juai', 'Juai', 'Juai', -2.3044000, 115.5622000, 'ID', '2013-12-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75171, 'Mapurujaya', 'Mapurujaya', 'Mapurujaya', -4.6752000, 136.8297000, 'ID', '2013-12-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75172, 'Woha', 'Woha', 'Woha', -8.6180200, 118.6478800, 'ID', '2014-01-05', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75173, 'Kuala Pembuang', 'Kuala Pembuang', 'KLP,Kuala Pembuang,Kualapembuang', -3.3922800, 112.5504900, 'ID', '2016-06-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75174, 'Doom', 'Doom', 'Doom', -0.8871800, 131.2364400, 'ID', '2014-01-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75175, 'Aifat', 'Aifat', 'Aifat', -1.1664000, 132.5015000, 'ID', '2014-01-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75176, 'Masohi', 'Masohi', 'Masohi', -3.2983300, 128.9688200, 'ID', '2014-01-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75177, 'Waipia', 'Waipia', 'Waipia', -3.1878000, 128.9030000, 'ID', '2014-01-18', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75178, 'Petani', 'Petani', 'Petani', 0.3288400, 128.6527000, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75179, 'Buli', 'Buli', 'Buli', 0.6851800, 128.2909000, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75180, 'Basiong', 'Basiong', 'Basiong', 0.7729400, 127.3748400, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75181, 'Malifud', 'Malifud', 'Malifud', 0.3638100, 127.4227900, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75182, 'Guruafin', 'Guruafin', 'Guruafin', 0.1014400, 127.4340200, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75183, 'Dufa-Dufa', 'Dufa-Dufa', 'Dufa-Dufa', -0.4618200, 127.1500000, 'ID', '2016-08-04', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75184, 'Tungoo', 'Tungoo', 'Tungoo', 0.7469200, 124.2610600, 'ID', '2014-03-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75185, 'Teritip', 'Teritip', 'Teritip', -1.8334700, 105.3698500, 'ID', '2014-04-07', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75186, 'Labuhantanggabesar', 'Labuhantanggabesar', 'Labuhantanggabesar', 2.0332300, 100.8882300, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75187, 'Tanjunglumbalumba', 'Tanjunglumbalumba', 'Tanjunglumbalumba', 2.0882700, 100.6500500, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75188, 'Sungaimaja', 'Sungaimaja', 'Sungaimaja', 2.0384900, 100.6386800, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75189, 'Paritkalipatopah', 'Paritkalipatopah', 'Paritkalipatopah', 2.0203700, 100.6454500, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75190, 'Rantaupanjangkiri', 'Rantaupanjangkiri', 'Rantaupanjangkiri', 2.0502300, 100.6323000, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75191, 'Sungaisegajah', 'Sungaisegajah', 'Sungaisegajah', 2.0718000, 100.6412400, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75192, 'Simpangpasir', 'Simpangpasir', 'Simpangpasir', 2.0825200, 100.5921000, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75193, 'Simpangbandung', 'Simpangbandung', 'Simpangbandung', 2.0733700, 100.5854200, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75194, 'Paritjunus', 'Paritjunus', 'Paritjunus', 2.0682300, 100.5908200, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75195, 'Pasir', 'Pasir', 'Pasir', 2.1399400, 100.8074700, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75196, 'Bintang', 'Bintang', 'Bintang', 2.1367300, 100.8139200, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75197, 'Baganhulubaru', 'Baganhulubaru', 'Baganhulubaru', 2.1487700, 100.8070800, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75198, 'Baganhilir', 'Baganhilir', 'Baganhilir', 2.1804700, 100.8105800, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75199, 'Kampung Jawa', 'Kampung Jawa', 'Kampung Jawa', 2.1767400, 100.8171000, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75200, 'Paritaman', 'Paritaman', 'Paritaman', 2.1996600, 100.8132200, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75201, 'Serusa', 'Serusa', 'Serusa', 2.2194800, 100.8192800, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75202, 'Pajak', 'Pajak', 'Pajak', 2.1078700, 101.6411400, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75203, 'Kador', 'Kador', 'Kador', 2.0413900, 101.6970000, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75204, 'Mislak', 'Mislak', 'Mislak', -1.7280600, 105.4532500, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75205, 'Kenali Asam', 'Kenali Asam', 'Kenali Asam', -1.6646000, 103.6204100, 'ID', '2014-04-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75206, 'Terentang', 'Terentang', 'Terentang', -0.3823300, 109.6209800, 'ID', '2014-05-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75207, 'Batuampar', 'Batuampar', 'Batuampar', -0.7385000, 109.5245400, 'ID', '2014-05-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75208, 'Kenyau', 'Kenyau', 'Kenyau', -0.8947700, 110.5038200, 'ID', '2014-05-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75209, 'Pontianak Barat', 'Pontianak Barat', 'Pontianak Barat', -0.0189400, 109.3186800, 'ID', '2014-05-02', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75210, 'Halimaung Jaya (F-3)', 'Halimaung Jaya (F-3)', '', -3.2499500, 112.5441200, 'ID', '2014-08-19', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75211, 'Barikin', 'Barikin', '', -2.6798600, 115.3250300, 'ID', '2015-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75212, 'Loklaga', 'Loklaga', '', -2.7124400, 115.3728000, 'ID', '2015-01-14', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75213, 'Senayang', 'Senayang', 'Senayang', 0.0375000, 104.6544400, 'ID', '2015-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75214, 'Matak', 'Matak', 'Matak', 3.3480600, 106.2913900, 'ID', '2015-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75215, 'Sabang Mawang Barat', 'Sabang Mawang Barat', 'Sabang Mawang Barat', 3.6330600, 108.1133300, 'ID', '2015-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75216, 'Cemaga', 'Cemaga', 'Cemaga', 3.7833300, 108.3652800, 'ID', '2015-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75217, 'Harapan Jaya', 'Harapan Jaya', 'Harapan Jaya', 3.8747200, 108.3030600, 'ID', '2015-05-08', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75218, 'Mangupura', 'Mangupura', 'Mangupura', -8.5438900, 115.1700000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75219, 'Tigaraksa', 'Tigaraksa', 'Tigaraksa', -6.2280600, 106.5138900, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75220, 'Tubei', 'Tubei', 'Tubei', -3.1191700, 102.2000000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75221, 'Karang Tinggi', 'Karang Tinggi', 'Karang Tinggi', -3.7500000, 102.4225000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75222, 'Pulau Pramuka', 'Pulau Pramuka', 'Pulau Pramuka', -5.7458300, 106.6138900, 'ID', '2016-01-17', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75223, 'Suwawa', 'Suwawa', 'Suwawa', 0.5325000, 123.1469400, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75224, 'Siulak', 'Siulak', 'Siulak', -1.9466700, 101.3341700, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75225, 'Batang', 'Batang', 'Batang', -6.9077800, 109.7302800, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75226, 'Ngasem', 'Ngasem', 'Ngasem', -7.8058300, 112.0408300, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75227, 'Sungai Raya', 'Sungai Raya', 'Sungai Raya', -0.1269400, 109.4038900, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75228, 'Sendawar', 'Sendawar', 'Sendawar', -0.2363900, 115.6947200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75229, 'Bandar Seri Bentan', 'Bandar Seri Bentan', 'Bandar Seri Bentan', 1.0541700, 104.4800000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75230, 'Wiralaga Mulya', 'Wiralaga Mulya', 'Wiralaga Mulya', -3.8427800, 105.4938900, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75231, 'Tiakur', 'Tiakur', 'JIO,Tiakur', -8.1500000, 127.7950000, 'ID', '2016-06-12', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75232, 'Kigamani', 'Kigamani', 'Kigamani', -3.9613900, 135.9436100, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75233, 'Sugapa', 'Sugapa', 'Sugapa', -3.7430600, 137.0500000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75234, 'Burmeso', 'Burmeso', 'Burmeso', -2.3261100, 138.0413900, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75235, 'Kobakma', 'Kobakma', 'Kobakma', -3.6641700, 139.0650000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75236, 'Kenyam', 'Kenyam', 'Kenyam', -4.5997200, 138.3841700, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75237, 'Oksibil', 'Oksibil', 'Oksibil', -4.9041700, 140.6297200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75238, 'Ilaga', 'Ilaga', 'Ilaga', -3.9500000, 137.4000000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75239, 'Botawa', 'Botawa', 'Botawa', -2.2100000, 136.4472200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75240, 'Sumohai', 'Sumohai', 'Sumohai', -4.6894400, 139.3547200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75241, 'Elelim', 'Elelim', 'Elelim', -3.7590000, 139.7075000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75242, 'Ullong', 'Ullong', 'Ullong', -1.3708300, 133.9130600, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75243, 'Aimas', 'Aimas', 'Aimas', -0.9569800, 131.3353500, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75244, 'Fef', 'Fef', 'Fef', -0.8088900, 132.4322200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75245, 'Sigi Biromaru', 'Sigi Biromaru', 'Sigi Biromaru', -0.9498200, 119.9180500, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75246, 'Buranga', 'Buranga', 'Buranga', -4.8009800, 122.9830800, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75247, 'Laworo', 'Laworo', 'Laworo', -4.7833300, 122.5247200, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75248, 'Tuapejat', 'Tuapejat', 'Tuapejat', -2.0283300, 99.5894400, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75249, 'Arosuka', 'Arosuka', 'Arosuka', -0.9522100, 100.6210000, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75250, 'Padang Aro', 'Padang Aro', 'Padang Aro', -1.5272200, 101.2636100, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75251, 'Lotu', 'Lotu', 'Lotu', 1.4299000, 97.3536500, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75252, 'Labungkari', 'Labungkari', '', -5.2631800, 122.5510400, 'ID', '2016-01-09', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75253, 'Jembrana Subdistrict', 'Jembrana Subdistrict', '', -8.3149200, 114.5758600, 'ID', '2016-06-20', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75254, 'Seminyak town', 'Seminyak town', 'Semin''jak,Seminyak,Семиньяк', -8.6888300, 115.1599800, 'ID', '2017-02-11', 104);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75255, 'Buncrana', 'Buncrana', 'Bankrana,Bun Cranncha,Buncrana,Bunkrana,Банкрана,Бънкрана,ბანკრანა', 55.1333300, -7.4500000, 'IE', '2016-04-10', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75256, 'Youghal', 'Youghal', 'Eochaill,Jol,Yoal,Youghal,ioli,ywghl,Йол,یوغل,იოლი', 51.9500000, -7.8505600, 'IE', '2014-05-31', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75257, 'Wicklow', 'Wicklow', 'Cill Maintain,Cill Maintainn,Cill Maintáinn,Cill Manntein,Cill Manntéin,Cill Mantan,Cill Mhanntain,Cill Mhantain,Cill Mhantáin,Wicklow', 52.9750000, -6.0494400, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75258, 'Whitegate', 'Whitegate', 'An Geata Ban,An Geata Bán,Whitegate', 51.8305600, -8.2297200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75259, 'Loch Garman', 'Loch Garman', 'Loch Garman,Wexford', 52.3341700, -6.4575000, 'IE', '2013-08-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75260, 'Westport', 'Westport', 'Caair ny Mart,Cathair na Mart,Uehstport,Uestport,Westport,u~esutopoto,weseuteupoteu,Уестпорт,Уэстпорт,ویسٹپورت، کاؤنٹی میو,უესტპორტი,ウェストポート,웨스트포트', 53.8000000, -9.5166700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75261, 'Watergrasshill', 'Watergrasshill', 'Cnocan na Biolrai,Cnocán na Biolraí,Watergrasshill', 52.0113900, -8.3441700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75262, 'Waterford', 'Waterford', 'Port Lairge,Port Làirge,Port Láirge,Purt Largey,Uoterford,Uoturford,Voterford,Voterfordas,WAT,Waterford,Waterford city,u~otafodo,watrfwrd,wo te fu de,woteopeodeu,Вотерфорд,Уотерфорд,Уотърфорд,واترفورد,واٹرفرڈ,უოტერფორდი,ウォーターフォード,沃特福德,워터퍼드', 52.2583300, -7.1119400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75263, 'Virginia', 'Virginia', 'Achadh an Iuir,Achadh an Iúir,Verdzhinija,Virginia,Vurdzhinija,Верджиния,Върджиния', 53.8338900, -7.0755600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75264, 'Tullyallen', 'Tullyallen', 'Tullyallen', 53.7361100, -6.4227800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75265, 'Tullow', 'Tullow', 'An Tulach,Tallou,Tullow,Таллоу,ٹولئو,ტალოუ', 52.8002800, -6.7369400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75266, 'Tullamore', 'Tullamore', 'Talamor,Talamoras,Tallamor,Tulach Mhor,Tulach Mhór,Tulamor,Tullamore,ta la mo er,taramoa,teolleomo-eo,thul la mxr,twlamwr,Таламор,Талламор,Тъламор,تولامور,ٹولامور,ทูลลามอร์,ტალამორი,タラモア,塔拉莫尔,털러모어', 53.2738900, -7.4888900, 'IE', '2012-03-01', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75267, 'Tuam', 'Tuam', 'Tuaim,Tuam,Tuum,chuamu,chumi,twam,Туам,Туъм,ٹیویم,ჩუმი,チュアム,퇌', 53.5166700, -8.8500000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75268, 'Trim', 'Trim', 'Baile Atha Troim,Baile Átha Troim,Trim,Трим,ٹرم، کاؤنٹی میدھ,ტრიმი', 53.5550000, -6.7916700, 'IE', '2011-05-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75269, 'Trá Mhór', 'Tra Mhor', 'Tramore', 52.1623500, -7.1524400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75270, 'Tralee', 'Tralee', 'Tra Li,Traie Lee,Tralee,Trali,Trá Lí,te la li,teuleolli,torari,traly,Трали,Тралі,ترالی,ٹریلی,ტრალი,トラリー,特拉利,트럴리', 52.2704200, -9.7026400, 'IE', '2014-12-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75271, 'Tower', 'Tower', 'Tower,Tower Village', 51.9166700, -8.6000000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75272, 'Tobercurry', 'Tobercurry', 'Tobar an Choire,Tobercurry,Tubbercurry', 54.0500000, -8.7333300, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75273, 'Tipperary', 'Tipperary', 'Tiobraid Arann,Tiobraid Árann,Tipperaria,Tipperary,Tipperehri,Tipurari,di po lei li,tipeoleli,Типперэри,Типърари,ٹپاریری,蒂珀雷里,티퍼레리', 52.4733300, -8.1558300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75274, 'Thurles', 'Thurles', 'Durlas,Durlas Eile,Dúrlas Éile,Thurles,Tjorls,Turles,se lei si,teolleseu,terlesi,Търлес,Тёрлс,თერლესი,瑟勒斯,털레스', 52.6819400, -7.8022200, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75275, 'Thomastown', 'Thomastown', 'Baile Mhic Andain,Baile Mhic Andáin,Thomastown,Tomastaun,Томастаун', 52.5266700, -7.1372200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75276, 'Termonfeckin', 'Termonfeckin', 'Tearmann Feichin,Tearmann Feichín,Termonfeckin', 53.7633300, -6.2677800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75277, 'Terenure', 'Terenure', 'Roundtown,Terenure', 53.3097200, -6.2852800, 'IE', '2013-12-11', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75278, 'Templemore', 'Templemore', 'An Teampall Mor,An Teampall Mór,Templemore,Templmor,Tempulmor,Темплмор,Темпълмор', 52.7947200, -7.8338900, 'IE', '2015-05-24', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75279, 'Tallaght', 'Tallaght', 'Talagtas,Talat,Talla,Tallaght,Tallakht,Tamhlacht,ta la,talla,tla,Талат,Талла,Таллахт,تلا,塔拉,탈라', 53.2859000, -6.3734400, 'IE', '2016-10-01', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75280, 'Swords', 'Swords', 'Sord,Sord Cholmcille,Sords,Sordsas,Sordz,Suords,Swords,aswrdz,seuwojeu,si wo si,swwrds,Сордз,Сордс,Суордс,סוורדס,اسوردز,سورڈز، ڈبلن,斯沃司,스워즈', 53.4597200, -6.2180600, 'IE', '2014-07-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75281, 'Swinford', 'Swinford', 'Beal Atha na Muice,Béal Átha na Muice,Swineford,Swinford', 53.9500000, -8.9500000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75282, 'Sutton', 'Sutton', 'Sutton', 53.3894700, -6.1105900, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75283, 'Stradbally', 'Stradbally', 'An Sraidbhaile,An Sráidbhaile,Stradbally', 53.0155600, -7.1527800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75284, 'Stamullin', 'Stamullin', 'Stamullen', 53.6288900, -6.2683300, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75285, 'Sligo', 'Sligo', 'SXL,Shliggagh,Slaigo,Slajgo,Slajgou,Sligeach,Sligo,aslaygw,seullaigo,slyjw,suraigo,Слайго,Слайгоу,Слајго,اسلایگو,سليجو,スライゴ,슬라이고', 54.2696900, -8.4694300, 'IE', '2014-07-16', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75286, 'Slane', 'Slane', 'Baile Shlaine,Baile Shláine,Slane,Slejn,Слейн', 53.7100000, -6.5433300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75287, 'Skibbereen', 'Skibbereen', 'An Sciobairin,An Sciobairín,Skibbereen,Skibberin,Скибберин', 51.5500000, -9.2666700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75288, 'Skerries', 'Skerries', 'Na Sceiri,Na Sceirí,Skerijs,Skerries,Skerris,Скерийс,Скеррис', 53.5827800, -6.1083300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75289, 'Sixmilebridge', 'Sixmilebridge', 'Droichead Abhann O gCearnaigh,Droichead Abhann Ui gCearnaigh,Droichead Abhann Uí gCearnaigh,Droíchead Abhann Ó gCearnaigh,Siksmajlbridzh,Sixmilebridge,Сиксмайлбридж', 52.7413900, -8.7741700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75290, 'Shankill', 'Shankill', 'Shankill', 53.2261100, -6.1244400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75291, 'Sandymount', 'Sandymount', 'Sandymount', 53.3350000, -6.2113900, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75292, 'Sallins', 'Sallins', 'Na Sollain,Na Solláin,Sallins', 53.2488900, -6.6661100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75293, 'Saggart', 'Saggart', 'Saggart,Teach Sagard', 53.2802800, -6.4444400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75294, 'An Ros', 'An Ros', 'Rush', 53.5242400, -6.1049700, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75295, 'Rosslare', 'Rosslare', 'Ros Lair,Ros Láir,Rosslare', 52.2758300, -6.3844400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75296, 'Roscrea', 'Roscrea', 'Ros Cre,Ros Cré,Roscrea,Roskrej,Роскрей', 52.9511100, -7.8016700, 'IE', '2015-05-24', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75297, 'Roscommon', 'Roscommon', 'Ros Comain,Ros Comáin,Roscommon,Rosecommon,Roskommon,Roskomon,Roskomonas,Roskomun,loseukeomeon,luo si kang mang,Ροσκόμον,Роскоммон,Роскомон,Роскомън,როსკომონი,罗斯康芒,로스커먼', 53.6333300, -8.1833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75298, 'Rochfortbridge', 'Rochfortbridge', 'Droichead Chaislean Loiste,Droichead Chaisleán Loiste,Rochfortbridge', 53.4141700, -7.2961100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75299, 'Ringsend', 'Ringsend', 'Ringsend', 53.3419400, -6.2263900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75300, 'Ratoath', 'Ratoath', 'Rath To,Ratoath,Ráth Tó', 53.5080600, -6.4625000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75301, 'Rathwire', 'Rathwire', '', 53.5076700, -7.1351000, 'IE', '2014-12-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75302, 'Rathnew', 'Rathnew', 'Rath Naoi,Rathnew,Ráth Naoi', 52.9905600, -6.0852800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75303, 'Rathmines', 'Rathmines', 'Rath Maonais,Rathmines,Ratmajns,Ráth Maonais,Ратмайнс', 53.3202800, -6.2633300, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75304, 'Ramelton', 'Ramelton', 'Ramelton,Rath Mealtain,Rathmelton,Ráth Mealtain', 55.0367300, -7.6492300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75305, 'Rathkeale', 'Rathkeale', 'Rath Caola,Rathkeale,Ráth Caola', 52.5244400, -8.9380600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75306, 'Rathdrum', 'Rathdrum', 'Rath Droma,Rathdrum,Ráth Droma', 52.9263900, -6.2355600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75307, 'Rathdowney', 'Rathdowney', 'Rath Domhnaigh,Rathdowney,Ráth Domhnaigh', 52.8547200, -7.5802800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75308, 'Rathcormac', 'Rathcormac', 'Rath Chormaic,Rathcormac,Rathcormack,Ráth Chormaic', 52.0769400, -8.2819400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75309, 'Rathcoole', 'Rathcoole', 'Rath Cuil,Rathcoole,Ráth Cúil', 53.2827800, -6.4727800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75310, 'Rathangan', 'Rathangan', 'Rath Iomghain,Rathangan,Ráth Iomgháin', 53.2213900, -6.9950000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75311, 'Raphoe', 'Raphoe', 'Rafo,Rafou,Raphoe,Rath Bhoth,Ráth Bhoth,Рафо,Рафоу', 54.8747200, -7.5983300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75312, 'Raheny', 'Raheny', 'Rakheni,Rath Eanaigh,Ráth Eanaigh,Рахени,Рахені', 53.3868100, -6.1806700, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75313, 'Prosperous', 'Prosperous', 'An Chorrchoill,Prosperous', 53.2902800, -6.7538900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75314, 'Portumna', 'Portumna', 'Port Omna,Portamna,Portumna,Портамна,პორტამნა', 53.0891700, -8.2188900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75315, 'Portmarnock', 'Portmarnock', 'Port Mearnog,Port Mearnóg,Portmarnock', 53.4230600, -6.1375000, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75316, 'Portlaw', 'Portlaw', 'Port Lach,Port Lách,Portlaw', 52.2883300, -7.3205600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75317, 'Portlaoise', 'Portlaoise', 'Maryboro'',Maryborough,Port Laoighise,Port Laoise,Port Leix,Portlaoise', 53.0344100, -7.2997900, 'IE', '2011-05-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75318, 'Portarlington', 'Portarlington', 'Cuil an tSudaire,Cúil an tSúdaire,Portarlington,Portarlingtun,Портарлингтон,Портарлингтън,پورٹارلینٹن، کاؤنٹی لیش', 53.1622200, -7.1911100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75319, 'Piltown', 'Piltown', 'Baile an Phoill,Pilltown,Piltown', 52.3533300, -7.3402800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75320, 'Daingean', 'Daingean', 'An Daingean,Daingean,Philipstown', 53.2961100, -7.2894400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75321, 'Passage West', 'Passage West', 'An Pasaiste,An Pasáiste,Pasidzh Uest,Passage,Passage West,Passidzh-Uehst,Пасидж Уест,Пассидж-Уэст,پیسج ویسٹ', 51.8738900, -8.3444400, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75322, 'Oughterard', 'Oughterard', 'Oughterard,Uachtar Ard', 53.4166700, -9.3333300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75323, 'Oranmore', 'Oranmore', 'Oran Mor,Oranmore,Órán Mór', 53.2683300, -8.9200000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75324, 'Old Kilcullen', 'Old Kilcullen', 'Old Kilcullen', 53.1063900, -6.7652800, 'IE', '2012-02-02', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75325, 'Oldcastle', 'Oldcastle', 'An Seanchaislean,An Seanchaisleán,Olcastle,Oldcastle', 53.7664800, -7.1628400, 'IE', '2014-12-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75326, 'Newtown Trim', 'Newtown Trim', '', 53.5561100, -6.7700000, 'IE', '2014-12-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75327, 'Newtown Cunningham', 'Newtown Cunningham', 'An Baile Nua,Newtown Cunningham,Newtowncunningham', 54.9963900, -7.5191700, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75328, 'New Ross', 'New Ross', 'N''ju-Ross,New Ross,Nju Ros,Nueva Ross,Ros Mhic Thriuin,Ros Mhic Thriúin,Ross,nyw ras,Нью-Росс,Ню Рос,نیو راس', 52.3966700, -6.9366700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75329, 'Newport', 'Newport', 'An Port Nua,Newport', 52.7111100, -8.4097200, 'IE', '2015-05-24', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75330, 'Newmarket on Fergus', 'Newmarket on Fergus', 'Cora Chaitlin,Cora Chaitlín,Newmarket on Fergus,Newmarket-On-Fergus', 52.7600000, -8.8955600, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75331, 'Newcastle', 'Newcastle', 'An Caislean Nua,An Caisleán Nua,Newcastle', 53.3011100, -6.5022200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75332, 'Newcastle West', 'Newcastle West', 'An Caislean Nua,An Caislean Nua Thiar,An Caisleán Nua,An Caisleán Nua Thiar,N''jukasl-Uehst,Newcastle,Newcastle West,Njukasul Uest,Ньюкасл-Уэст,Нюкасъл Уест,نیو کیسل ویسٹ', 52.4491700, -9.0611100, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75333, 'Droichead Nua', 'Droichead Nua', 'Droichead Nua,Droichead Nuadh,Newbridge', 53.1819400, -6.7966700, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75334, 'Nenagh', 'Nenagh', 'An tAonach,Aonach Urmhumhan,Nenagh,Nina,The Meeting,ni na,nina,nyna,Нина,Ніна,نینا,ნინა,尼纳,니나', 52.8619400, -8.1966700, 'IE', '2015-05-24', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75335, 'Navan', 'Navan', 'An Uaimh,An-Uav'',Navan,Navanas,Yn Ooive,na wen,naebeon,navani,navu~an,nawyn,Ан-Уавь,Наван,נאבאן,ناوین,ნავანი,ナヴァン,納文,내번', 53.6527800, -6.6813900, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75336, 'Naas', 'Naas', 'An Nas,An Nás,Naas,Nas na Riogh,Neisas,Nejs,Nás na Ríogh,nei si,neiseu,neisi,nys,Нейс,Нејс,נאס,نئس,نیس,ნეისი,内斯,네이스', 53.2158300, -6.6669400, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75337, 'An Muileann gCearr', 'An Muileann gCearr', 'An Muileann gCearr,Mullingar', 53.5333300, -7.3500000, 'IE', '2010-09-05', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75338, 'Mullagh', 'Mullagh', 'An Mullach,Mullagh', 53.8130600, -6.9513900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75339, 'Muff', 'Muff', 'Magh,Muff', 55.0666700, -7.2666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75340, 'Moycullen', 'Moycullen', 'Maigh Cuilinn', 53.3378300, -9.1800200, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75341, 'Moville', 'Moville', 'Bun an Phobail,Moville', 55.1833300, -7.0500000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75342, 'Mountrath', 'Mountrath', 'Maighean Ratha,Maighean Rátha,Mountrath', 52.9988900, -7.4727800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75343, 'Mountmellick', 'Mountmellick', 'Mointeach Milic,Mountmellick,Móinteach Mílic', 53.1136100, -7.3200000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75344, 'Moroe', 'Moroe', '', 52.6511100, -8.3961100, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75345, 'Moone', 'Moone', 'Maoin,Moone', 52.9755600, -6.8150000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75346, 'Mooncoin', 'Mooncoin', 'Moin Choinn,Mooncoin,Móin Choinn', 52.2894400, -7.2483300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75347, 'Monkstown', 'Monkstown', '', 53.2930800, -6.1531200, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75348, 'Monasterevin', 'Monasterevin', 'Mainistir Eimhin,Mainistir Eimhín,Monasterevan,Monasterevin,Монастеревин', 53.1405600, -7.0663900, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75349, 'Monaghan', 'Monaghan', 'Monachanas,Monaghan,Monakhan,Muineachan,Muineachán,monahan,monahani,Монахан,მონაჰანი,モナハン', 54.2500000, -6.9666700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75350, 'Moate', 'Moate', '', 53.5500000, -7.7166700, 'IE', '2010-08-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75351, 'Mitchelstown', 'Mitchelstown', 'Baile Mhisteala,Baile Mhistéala,Michulstaun,Mitchelstaun,Mitchelstown,Митчелстаун,Мичълстаун', 52.2658300, -8.2680600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75352, 'Millstreet', 'Millstreet', 'Millstreet,Milstrit,Sraid an Mhuilinn,Sráid an Mhuilinn,mirusutorito,Милстрит,ミルストリート', 52.0666700, -9.0666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75353, 'Midleton', 'Midleton', 'Mainister na Corann,Mainistir na Corann,Middleton,Midleton,Midlton,Midultun,mi de lei dun,Мидлтон,Мидълтън,مڈلٹن,米德勒頓', 51.9152600, -8.1805200, 'IE', '2011-05-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75354, 'Mount Merrion', 'Mount Merrion', 'Cnoc Mhuirfean,Merrion', 53.3000800, -6.2150400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75355, 'Maynooth', 'Maynooth', 'Maigh Nuad,Manutia,Maynooth,Meinutas,Mejnut,mei nu si,meinusu,mnwth,myynwt,Мейнут,מיינות,منوث,مینوتھ,メイヌース,梅努斯', 53.3850000, -6.5936100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75356, 'Marino', 'Marino', '', 53.3702200, -6.2364600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75357, 'Manorhamilton', 'Manorhamilton', 'Cluainin,Cluainín,Manorhamilton,Manorkhamilton,Манорхамилтон,მანორჰამილტონი', 54.3063900, -8.1761100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75358, 'Mallow', 'Mallow', 'Maigh Eala,Mala,Mallou,Mallow,Malou,Malovas,ma luo,Маллоу,Малоу,مالوو، کاؤنٹی کورک,馬羅', 52.1333300, -8.6333300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75359, 'Malahide', 'Malahide', 'Malahaidas,Malahide,Malakhajd,Mullach Ide,Mullach Íde,ma la hai de,malahayd,Малахайд,مالاهاید,مالاہائڈ,馬拉海德', 53.4508300, -6.1544400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75360, 'Macroom', 'Macroom', 'Macroom,Maigh Chromtha,Makrum,mykrwm,Макрум,میکروم', 51.9000000, -8.9500000, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75361, 'Lusk', 'Lusk', 'Lusca,Lusk', 53.5274300, -6.1642300, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75362, 'Lucan', 'Lucan', 'Leamhcan,Leamhcán,Lucan', 53.3573600, -6.4485900, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75363, 'Loughrea', 'Loughrea', 'Baile Locha Riach,Lokhrej,Loughrea,lokhrei,Лохрей,لوخرے,ლოხრეი', 53.1969400, -8.5669400, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75364, 'Loughlinstown', 'Loughlinstown', 'Loughlinstown', 53.2438900, -6.1330600, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75365, 'Longwood', 'Longwood', 'Longwood', 53.4538900, -6.9219400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75366, 'Longford', 'Longford', 'An Longfort,Longford,Longfordas,lamgafarda,lang fu de,longpeodeu,longpordi,lwnjfwrd,rongufodo,Лонгфорд,لونجفورد,لونگفرڈ,लाँगफ़र्ड,ლონგფორდი,ロングフォード,朗福德,롱퍼드', 53.7253600, -7.7982300, 'IE', '2012-03-01', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75367, 'Listowel', 'Listowel', 'Lios Tuathail,Listouehl,Listouul,Listowel,li si tuo er,liseutowel,Листоуъл,Листоуэл,لیسٹول,利斯托尔,리스토웰', 52.4463900, -9.4850000, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75368, 'Luimneach', 'Luimneach', 'Limereick,Limerick,Limerick city,Limerik,Limerika,Limerikas,Luimneach,lymryq,rimurikku,Лимерик,לימריק,リムリック', 52.6647200, -8.6230600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75369, 'Leifear', 'Leifear', 'Leifear,Lifford', 54.8319400, -7.4836100, 'IE', '2013-11-22', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75370, 'Letterkenny', 'Letterkenny', 'LTR,Leitir Ceanainn,Leterkeni,Leterkenis,Letterkenni,Letterkenny,Leturkeni,Littyr Kennain,lai te ken ni,Летеркени,Леттеркенни,Летъркени,لیٹرکینی,萊特肯尼', 54.9500000, -7.7333300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75371, 'Leixlip', 'Leixlip', 'Leikslipas,Leim an Bhradain,Leixlip,Lejkslip,Lijkslip,Likslip,Léim an Bhradáin,lai ke si li pu,lykslyp,Лейкслип,Лийкслип,Ликслип,لیکسلیپ,萊克斯利普', 53.3658300, -6.4955600, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75372, 'Laytown', 'Laytown', 'An Inse,Laytown', 53.6819400, -6.2391700, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75373, 'Strandhill', 'Strandhill', 'An Leathros,Larass,Strandhill', 54.2719400, -8.5933300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75374, 'Lanesborough', 'Lanesborough', 'Beal Atha Liag,Béal Átha Liag,Lanesborough,Lanesborough-Ballyleague', 53.6666700, -7.9833300, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75375, 'Kinsale', 'Kinsale', 'Cionn tSaile,Cionn tSáile,Kinsale,Kinseilis,Kinsejl,Kione Sailley,knsyyl,qynsyyl,Кинсейл,קינסייל,کنسیئل', 51.7075000, -8.5305600, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75376, 'Kinnegad', 'Kinnegad', 'Cionn Atha Gad,Cionn Átha Gad,Kinnegad', 53.4522200, -7.0997200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75377, 'Kinlough', 'Kinlough', 'Cionn Locha,Kinlough', 54.4500000, -8.2833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75378, 'Kingscourt', 'Kingscourt', 'Dun An Ri,Dún An Ri,Kingscourt', 53.9080600, -6.8055600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75379, 'Kiltamagh', 'Kiltamagh', 'Coillte Mach,Kiltamagh,Kiltimagh', 53.8500000, -9.0000000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75380, 'Kilrush', 'Kilrush', 'Cill Rois,Kilrash,Kilrush,Килраш', 52.6397200, -9.4833300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75381, 'Kilmallock', 'Kilmallock', 'Cill Mocheallog,Cill Mocheallóg,Kilmailock,Kilmallock', 52.4000000, -8.5772200, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75382, 'Killybegs', 'Killybegs', 'Kilibegs,Killibegs,Killybegs,Na Ceala Beaga,Na Cealla Beaga,Килибегс,Киллибегс', 54.6333300, -8.4500000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75383, 'Killumney', 'Killumney', 'Killumney', 51.8666700, -8.6500000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75384, 'Killorglin', 'Killorglin', 'Cill Orglan,Killorglin,Киллорглин', 52.1000000, -9.7833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75385, 'Cill Airne', 'Cill Airne', 'Cill Airne,Killarney', 52.0500000, -9.5166700, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75386, 'Killaloe', 'Killaloe', 'Cill Dalua,Killalo,Killaloe,Киллало', 52.8066700, -8.4436100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75387, 'Kilkenny', 'Kilkenny', 'Canicopolis,Cill Chainnigh,KKY,Keeill Chennee,Kilkeni,Kilkenis,Kilkenni,Kilkenny,kilkeni,kirukeni,Килкени,Килкенни,キルケニー,킬케니', 52.6541700, -7.2522200, 'IE', '2014-05-09', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75388, 'Kildare', 'Kildare', 'Cill Dara,Keeill Darey,Kildehr,Kilderas,Kildeur,Килдеър,Килдэр,کلڈیئر', 53.1561100, -6.9144400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75389, 'Kilcullen', 'Kilcullen', 'Cill Chuillinn,Kilcullen,Kilkallen,Килкаллен', 53.1302800, -6.7444400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75390, 'Kilcoole', 'Kilcoole', 'Cill Chomhghaill,Kilcoole', 53.1027800, -6.0650000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75391, 'Kilcock', 'Kilcock', 'Cill Choca,Kilcock,Kilkok,Kilkuk,klkwk,Килкок,Килкък,کلکوک', 53.4022200, -6.6708300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75392, 'Kilbeggan', 'Kilbeggan', 'Cill Bheagain,Cill Bheagáin,Kilbeggan', 53.3694400, -7.5033300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75393, 'Kenmare', 'Kenmare', 'An Neidin,An Neidín,Kenmare,Kenmehr,Kevmare,Neidin,Кенмэр', 51.8833300, -9.5833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75394, 'Kells', 'Kells', 'Ceanannas,Ceanannus Mor,Ceanannus Mór,Kells,Kels,Келлс,Келс,کیلز، کاؤنٹی میدھ', 53.7263900, -6.8791700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75395, 'Kanturk', 'Kanturk', 'Ceann Toirc,Kanturk', 52.1666700, -8.9000000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75396, 'Johnstown', 'Johnstown', '', 53.2383300, -6.6222200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75397, 'Inishcrone', 'Inishcrone', 'Inis Crabhann,Inishcrone,Inniscrone', 54.2166700, -9.1000000, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75398, 'Howth', 'Howth', 'Binn Eadair,Binn Éadair,Howth,Khout,hoseu,Хоут,호스', 53.3877800, -6.0652800, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75399, 'Gweedore', 'Gweedore', 'Gaoth Dobhair,Gweedore,Krokh''li,Крохьли', 55.0502800, -8.2319400, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75400, 'Greystones', 'Greystones', 'Greistonsas,Grejstons,Grejstouns,Greystones,Na Clocha Liatha,ge lei si tong,geuleiseutonseu,Грейстонс,Грейстоунс,Грејстонс,گرےسٹونز,გრეისტოუნსი,格雷斯通,그레이스톤스', 53.1408300, -6.0630600, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75401, 'Granard', 'Granard', 'Granard,Gránard,granardi,Гранард,გრანარდი', 53.7666700, -7.5000000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75402, 'Graiguenamanagh', 'Graiguenamanagh', 'Graig na Manach,Graigue,Graiguenamanagh,Gráig na Manach', 52.5402800, -6.9547200, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75403, 'Gort', 'Gort', 'An Gort,Gort,Gort Inse Guaire,gwrt,Горт,גורט,გორტი', 53.0663900, -8.8166700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75404, 'Gorey', 'Gorey', 'Gorey,Gori,Guaire,gori,gwry,Гори,گؤری,გორი', 52.6747200, -6.2925000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75405, 'Glasnevin', 'Glasnevin', 'Glas Naion,Glas Naíon,Glasnevin,Гласневин', 53.3802800, -6.2641700, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75406, 'Gaillimh', 'Gaillimh', 'GWY,Gaillimh,Galway,Galway - Gaillimh,Galway city,Goluehj,Goluej,Golveja,Golvejus,Golvėjus,ge er wei,goruu~ei,Голуей,Голуэй,ゴールウェイ,戈尔韦', 53.2719400, -9.0488900, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75407, 'Foxford', 'Foxford', 'Beal Easa,Béal Easa,Foxford', 53.9807000, -9.1155100, 'IE', '2015-03-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75408, 'Finglas', 'Finglas', 'Finglas,Fionnghlas,Tinglas,fyngls,Финглас,فینگلس', 53.3891700, -6.2969400, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75409, 'Fethard', 'Fethard', 'Fethard,Fiodh Ard', 52.4672200, -7.6911100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75410, 'Ferns', 'Ferns', 'Alder Trees,Fearna,Ferns', 52.5883300, -6.4997200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75411, 'Fermoy', 'Fermoy', 'Fermoj,Fermoy,Furmoj,Mainistir Fhear Mai,Mainistir Fhear Maí,Mannishter er Maigh,famoi,Фермой,Фърмой,فرموئے,ファーモイ', 52.1358300, -8.2758300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75412, 'Ferbane', 'Ferbane', 'An Fear Ban,An Féar Bán,Ferbane', 53.2694400, -7.8269400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75413, 'Enniskerry', 'Enniskerry', 'Ath na Sceire,Enniskerry,Áth na Sceire', 53.1925000, -6.1691700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75414, 'Enniscorthy', 'Enniscorthy', 'Enniscorthy,Inis Corthaidh,Inis Córthaidh', 52.5008300, -6.5577800, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75415, 'Ennis', 'Ennis', 'Ehnnis,Enis,Enisas,Ennis,Inis,Innys,anys,en ni si,eniseu,enisi,enisu,Енис,Енніс,Эннис,אניס,انیس,ენისი,エニス,恩尼斯,에니스', 52.8436100, -8.9863900, 'IE', '2016-05-10', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75416, 'Enfield', 'Enfield', 'An Bothar Bui,An Bóthar Buí,Enfield,Innfield', 53.4141900, -6.8322900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75417, 'Edgeworthstown', 'Edgeworthstown', 'Edgeworthstown,Meathas Troim,Meathas Truim,Meathus Truim,Mostrim', 53.7000000, -7.6166700, 'IE', '2013-11-21', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75418, 'Edenderry', 'Edenderry', 'Eadan Doire,Eaden Doire,Edenderry,Idenderri,Idunderi,edenderi,Éadan Doire,Éaden Doire,Идендерри,Идъндери,ედენდერი', 53.3452800, -7.0497200, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75419, 'Dunshaughlin', 'Dunshaughlin', 'Dun Seachlainn,Dunshaughlin,Dún Seachlainn', 53.5125000, -6.5400000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75420, 'Dunmore East', 'Dunmore East', 'Dun Mor,Dunmore,Dunmore East,Dún Mór', 52.1510800, -6.9987200, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75421, 'Dunmanway', 'Dunmanway', 'Danmanui,Dun Manmhai,Dunmanway,Dunmaonmhui,Dún Mánmhaí,Dúnmaonmhuí,Данмануи', 51.7166700, -9.1166700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75422, 'Dunlewy', 'Dunlewy', 'Dun Luiche,Dun Lukhe,Dunlewy,Dún Lúiche,Дун Лухе', 55.0166700, -8.1000000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75423, 'Dunleer', 'Dunleer', 'Dun Leire,Dunleer,Dún Léire', 53.8350000, -6.3961100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75424, 'Dún Laoghaire', 'Dun Laoghaire', 'Dan Lere,Dan Leri,Dan Lerė,Dan Liri,Dun Laoghaire,Dun Laoire,Dun-Lehare,Dunleary,Dunum Loigarii,Dún Laoghaire,Dún Laoire,Kingstown,danlyry,deng lai li,deonleleo,dn lyry,dunlere,Дан Лері,Дан Лири,Дун-Лэаре,דן לירי,دانلیری,ڈون لاری,ดูนเลเร,ダン・レアリー,邓莱里,던레러', 53.2939500, -6.1358600, 'IE', '2014-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75425, 'Dungloe', 'Dungloe', 'An Clochan Liath,An Clochán Liath,Dungloe,Dunglow', 54.9511100, -8.3591700, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75426, 'Dungarvan', 'Dungarvan', 'Dangarvan,Dun Garbhan,Dungarvan,Dún Garbhán,dangarvani,deng jia wen,deongabeon,Дангарван,Дънгарван,ڈنگارون,დანგარვანი,邓加文,던가번', 52.0880600, -7.6252800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75427, 'Dundrum', 'Dundrum', '', 53.2906700, -6.2571400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75428, 'Dundalk', 'Dundalk', 'Dandalk,Dandolk,Dandolkas,Doon Jialgan,Dun Dealgan,Dundalk,Dundolk,Dún Dealgan,dandak,dandoku,deng duo ke,deondokeu,Дандалк,Дандолк,Дъндолк,دانداک,ڈونڈوک,დანდოლკი,ダンドーク,邓多克,던도크', 54.0000000, -6.4166700, 'IE', '2012-03-01', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75429, 'Dunboyne', 'Dunboyne', 'Danbojn,Dun Buinne,Dunbojn,Dunboyne,Dún Búinne,Данбойн,Дънбойн,ڈنبوئن', 53.4000000, -6.4666700, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75430, 'Duleek', 'Duleek', 'Damhliag,Duleek', 53.6566700, -6.4191700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75431, 'Dublin', 'Dublin', 'Baile Atha Cliath,Baile Átha Cliath,Ciuda de Dublin,Ciudá de Dublín,DUB,Dablin,Diblin,Difelin,Divlyn,Doublino,Dublin,Dublin city,Dublina,Dublinas,Dublini,Dublino,Dublinu,Dublín,Dublîn,Dueblin,Dulenn,Dulyn,Dyflinn,Düblin,Eblana,Gorad Dublin,dabalina,dablin,dablina,daburin,dbln,dblyn,deobeullin,dou bai lin,dublini,dwblyn,taplin,Δουβλίνο,Горад Дублін,Даблин,Дублин,Дублін,Дъблин,Դուբլին,דבלין,דובלין,دبلن,دوبلين,دوبلین,دۇبلىن,ڈبلن,ډبلن,ܕܒܠܢ,डब्लिन,दब्लिन,ডাবলিন,ਡਬਲਿਨ,டப்லின்,ಡಬ್ಲಿನ್,ഡബ്ലിൻ,ดับลิน,དུབ་ལིན།,ဒပ်ဗလင်မြို့,დუბლინი,ደብሊን,ダブリン,都柏林,더블린', 53.3330600, -6.2488900, 'IE', '2013-05-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75432, 'Dromiskin', 'Dromiskin', 'Dromiskin', 53.9275000, -6.4113900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75433, 'Drogheda', 'Drogheda', 'Droeda,Droehda,Drogeda,Droghad Aah,Drogheda,Drogheda - Droichead Atha,Drogheda - Droichead Átha,Droichead Atha,Droichead Átha,Droida,de luo he da,deuloida,doroheda,drahyda,Дрогеда,Дроида,Дроэда,دراهیدا,ڈراہیڈا,ドロヘダ,德羅赫達,드로이다', 53.7188900, -6.3477800, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75434, 'Donnybrook', 'Donnybrook', '', 53.3137500, -6.2227400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75435, 'Donegal', 'Donegal', 'CFN,Donegal,Dun na nGall,Dún na nGall', 54.6537800, -8.1113400, 'IE', '2016-04-22', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75436, 'Donabate', 'Donabate', 'Domhnach Bat,Donabate,Donabejt,Dounabejt,Донабейт,Доунабейт,ڈونابیٹ', 53.4872200, -6.1519400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75437, 'Dollymount', 'Dollymount', '', 53.3648900, -6.1803200, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75438, 'Dingle', 'Dingle', 'An Daingean,Daingean Ui Chuis,Daingean Uí Chuis,Dingl,Dingle,Dinglis,Yn Dein,dinguru,dyngl,Дингл,دینگل,ディングル', 52.1408300, -10.2688900, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75439, 'Derrybeg', 'Derrybeg', 'An Bun Beag-Doiri Beaga,An Bun Beag-Doirí Beaga,Derrybeg,Doiri Beaga,Doirí Beaga', 55.0833300, -8.2894400, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75440, 'Derry', 'Derry', '', 51.5866600, -9.0502600, 'IE', '2010-08-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75441, 'Derrinturn', 'Derrinturn', 'Derrinturn', 53.3416700, -6.9411100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75442, 'Dalkey', 'Dalkey', 'Dalkey,Deilginis,Dolki,Долки', 53.2783300, -6.1002800, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75443, 'Crumlin', 'Crumlin', 'Crumlin', 53.3241700, -6.3286100, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75444, 'Crossmolina', 'Crossmolina', 'Crois Mhaoiliona,Crois Mhaoilíona,Crossmolina', 54.1000000, -9.3166700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75445, 'Crosshaven', 'Crosshaven', 'Bun an Tabhairne,Bun an Tábhairne,Crosshaven,Crosshaven-Churchbay', 51.7983300, -8.3008300, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75446, 'Croom', 'Croom', 'Cromadh,Croom', 52.5194400, -8.7177800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75447, 'Courtown', 'Courtown', 'Baile na Cuirte,Baile na Cúirte,Courtown,Courtown Harbour,Cuan Bhaile na Cuirte,Cuan Bhaile na Cúirte', 52.6442400, -6.2289900, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75448, 'Cork', 'Cork', 'Corc,Corcagia,Corcaigh,Cork,Cork - Corcaigh,Cork city,Corkee,Gorad Kork,Kork,Korka,Korkas,Korkig,ORK,ke ke,khxrk,kokeu,koku,korka,kwrk,qwrq,Κορκ,Горад Корк,Корк,Կորկ,קורק,كورك,کورک,कॉर्क,คอร์ก,კორკი,コーク,科克,코크', 51.8979700, -8.4706100, 'IE', '2011-11-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75449, 'Cootehill', 'Cootehill', 'Cootehill,Muinchille', 54.0725000, -7.0819400, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75450, 'Convoy', 'Convoy', 'Conmhaigh,Convoy', 54.8608300, -7.6655600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75451, 'Collooney', 'Collooney', 'Collooney,Cuil Mhuine,Cúil Mhuine', 54.1833300, -8.5000000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75452, 'Cobh', 'Cobh', 'An Cobh,An Cóbh,Cobh,Kouv,Kov,Kovas,Queenstown,ke fu,kovu,kwf,Ков,Коув,كوف,کوہوہ,コーヴ,科芙', 51.8572200, -8.2991700, 'IE', '2014-10-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75453, 'Cloyne', 'Cloyne', 'Cloyne,Cluain', 51.8627800, -8.1244400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75454, 'Cluain Meala', 'Cluain Meala', 'Clonmel,Cluain Meala', 52.3550000, -7.7038900, 'IE', '2015-05-24', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75455, 'Clones', 'Clones', 'Clones,Cluain Eois,Klons,Клонс', 54.1833300, -7.2333300, 'IE', '2014-05-31', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75456, 'Clondalkin', 'Clondalkin', 'Clondalkin,Cluain Dolcain,Cluain Dolcáin,Klondolkin,klandalkyn,Клондолкин,کلاندالکین,კლონდოლკინი', 53.3244400, -6.3972200, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75457, 'Clonakilty', 'Clonakilty', 'Cloich na Coillte,Clonakilty,Klonakilti,Klounakilti,klwnykyly,Клонакилти,Клоунакилти,کلونیکیلی', 51.6230600, -8.8705600, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75458, 'Clogherhead', 'Clogherhead', 'Ceann Chlochair,Clogher,Clogherhead', 53.7936100, -6.2375000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75459, 'Clifden', 'Clifden', 'An Clochan,An Clochán,Clifden,Klifden,Клифден,კლიფდენი', 53.4890700, -10.0191000, 'IE', '2015-02-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75460, 'Claremorris', 'Claremorris', 'Clar Chlainne Mhuiris,Clar Clainne Mhuiris,Claremorris,Clár Chlainne Mhuiris,Clár Clainne Mhuiris,Klehrmorris,Kleurmoris,Клеърморис,Клэрморрис,კლერმორისი', 53.7166700, -9.0000000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75461, 'Claregalway', 'Claregalway', 'Baile Chlair,Baile Chláir,Claregalway', 53.3386100, -8.9450000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75462, 'Clara', 'Clara', 'Clara,Cloirtheach,Clóirtheach,Klara,ke la la,klara,Клара,كلارا,克拉拉', 53.3425000, -7.6138900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75463, 'Clane', 'Clane', 'Clane,Claonadh,Klejn,klyyn,Клейн,کلئین', 53.2913900, -6.6891700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75464, 'Cherryville', 'Cherryville', '', 53.1569400, -6.9666700, 'IE', '2010-08-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75465, 'Ráth Luirc', 'Rath Luirc', 'Charleville,Rath Luirc,Rathluirc,Ráth Luirc', 52.3500000, -8.6833300, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75466, 'Chapelizod', 'Chapelizod', 'Chapelizod', 53.3488900, -6.3466700, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75467, 'Celbridge', 'Celbridge', 'Celbridge,Cill Droichid,Selbridzas,Selbridzh,Selbridžas,sai er bu li qi,slbryj,Селбридж,سلبریج,塞爾布里奇', 53.3386100, -6.5436100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75468, 'Cavan', 'Cavan', 'An Cabhan,An Cabhán,Cavan,Kavan,Kavanas,Yn Cavan,ka wen,kaebeon,kyaban,kywan,Каван,کیوان,კავანი,キャバン,卡文,캐번', 53.9908300, -7.3605600, 'IE', '2012-03-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75469, 'Castlerea', 'Castlerea', 'An Caislean Riabhach,An Caisleán Riabhach,Castlerea,Castlereagh', 53.7666700, -8.5000000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75470, 'Castlepollard', 'Castlepollard', 'Baile na gCros,Castelpollard,Castlepollard', 53.6666700, -7.3000000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75471, 'Castlemartyr', 'Castlemartyr', 'Baile na Martra,Castlemartyr', 51.9102800, -8.0538900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75472, 'Castleknock', 'Castleknock', 'Caislean Cnucha,Caisleán Cnucha,Kaslnok,kslnak,Каслнок,کسلناک', 53.3748300, -6.3633600, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75473, 'Castleisland', 'Castleisland', 'Castleisland,Oilean Ciarrai,Oileán Ciarraí', 52.2333300, -9.4666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75474, 'Castledermot', 'Castledermot', 'Castledermot,Castledermoti nagykeresztek,Diseart Diarmada,Díseart Diarmada,Kasldermat,Kasldermot,Каслдермат,Каслдермот', 52.9088900, -6.8422200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75475, 'Castlecomer', 'Castlecomer', 'Caislean an Chomair,Caisleán an Chomair,Castlecomer,Castlecomer-Donaguile,Kaslkomer,Каслкомер', 52.8061100, -7.2105600, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75476, 'Castlebridge', 'Castlebridge', 'Castlebridge,Castlebridge-Blackwater,Droichead an Chaisleain,Droichead an Chaisleáin', 52.3863900, -6.4494400, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75477, 'Castleblayney', 'Castleblayney', 'Baile na Lorgan,Castleblayney,Kaslblejni,Каслблейни', 54.1166700, -6.7333300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75478, 'Castlebellingham', 'Castlebellingham', 'Baile an Ghearlanaigh,Baile an Ghearlánaigh,Castlebellingham,Castlebellingham-Kilsaran', 53.9008300, -6.3902800, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75479, 'Castlebar', 'Castlebar', 'Caislean an Bharraigh,Caisleán an Bharraigh,Castlebar,Kaslbar,Kaslbaras,Kasulbar,ka si er ba,kaeseulba,kasuruba,kslbar,kyslbar,Каслбар,Касълбар,Կասլբար,کسلبار,کیسلبار,კასლბარი,カスルバー,卡斯尔巴,캐슬바', 53.8500000, -9.3000000, 'IE', '2012-03-01', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75480, 'Cashel', 'Cashel', 'Caiseal,Cashel', 52.5158300, -7.8855600, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75481, 'Carrigtwohill', 'Carrigtwohill', 'Carraig Thuathail,Carrigtohill,Carrigtwohill', 51.9083300, -8.2633300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75482, 'Carrigaline', 'Carrigaline', 'Carraig Ui Leighin,Carraig Uí Leighin,Carrigaline,Karigalajn,Karigalinas,Karrigalin,ka li ge lai en,karigarain,karygalayn,Каригалайн,Карригалин,کاریگالائن,کاریگالاین,カリガライン,卡里格萊恩', 51.8116700, -8.3986100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75483, 'Carrick-on-Suir', 'Carrick-on-Suir', 'Carraig na Siuire,Carraig na Siúire,Carrick-on-Suir,Karik on Shur,Karrik-on-Shur,kyrk-an-swyr,Карик он Шур,Каррик-он-Шур,کیرک-آن-سوئر,კერიკ-ონ-შური', 52.3491700, -7.4130600, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75484, 'Carrick-on-Shannon', 'Carrick-on-Shannon', 'Carrick on Shannon,Carrick-On-Shannon,Carrick-on-Shannon,Cora Droma Ruisc,Cora Droma Rúisc,Karik na Shenonu,Karik on Shanun,Karikas prie Sanono,Karikas prie Šanono,Karrik-na-Shannoni,Karrik-on-Shannon,kaelig-onsyaeneon,kyarikku=on=shanon,kyrk-an-shynn,xiang nong he pan ka li ke,Карик на Шенону,Карик он Шанън,Каррик-он-Шаннон,Каррік-на-Шанноні,کیرک-آن-شینن,კერიკ-ონ-შენონი,キャリック＝オン＝シャノン,香农河畔卡里克,캐릭온섀넌', 53.9469400, -8.0900000, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75485, 'Carrickmacross', 'Carrickmacross', 'Carraig Mhachaire Rois,Carrickmacross,Karikmakros,Karrikmakross,Magheross,kyrkmykras,Карикмакрос,Каррикмакросс,کیرکمیکراس', 53.9727800, -6.7188900, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75486, 'Carnew', 'Carnew', 'Carn an Bhua,Carnew', 52.7080600, -6.4944400, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75487, 'Carndonagh', 'Carndonagh', 'Cardonagh,Carn Domhnach,Carndonagh', 55.2500000, -7.2666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75488, 'Carlow', 'Carlow', 'Carlow,Ceatharlach', 52.8408300, -6.9261100, 'IE', '2011-05-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75489, 'Carlingford', 'Carlingford', 'Cairlinn,Carlingford,Karlingford,Карлингфорд', 54.0400000, -6.1883300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75490, 'Callan', 'Callan', 'Callain,Callan', 52.5450000, -7.3911100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75491, 'Cahersiveen', 'Cahersiveen', 'Cahersiveen,Cahersween,Cahirciveen,Cathair Saidhbhin,Cathair Saidhbhín', 51.9486100, -10.2222200, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75492, 'Caherconlish', 'Caherconlish', 'Caherconlish,Cathair Chinn Lis', 52.5936100, -8.4702800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75493, 'Cahir', 'Cahir', 'An Chathair,Caher,Cahir,Kehr,Keur,Án Chathair,Кеър,Кэр', 52.3769400, -7.9216700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75494, 'Cabinteely', 'Cabinteely', '', 53.2697300, -6.1605800, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75495, 'Bundoran', 'Bundoran', 'Bandoran,Bun Dobhrain,Bun Dobhráin,Bundoran,bandorani,Бандоран,Бъндоран,ბანდორანი', 54.4778200, -8.2809400, 'IE', '2011-06-09', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75496, 'Bunclody', 'Bunclody', 'Bun Cloidi,Bun Clóidi,Bunclody,Bunclody-Carrickduff,Newtonbarry,Newtownbarry', 52.6553000, -6.6535900, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75497, 'Bray', 'Bray', 'Bray,Bre,Brej,Brejus,Brey,Bri Chualann,Bré,Brėjus,beulei,brei,bry  ayrlnd,bu rui,burei,Брей,Бреј,Բրեյ,بری، ایرلند,ბრეი,ブレイ,布瑞,브레이', 53.2027800, -6.0983300, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75498, 'Boyle', 'Boyle', 'Bojl,Boyle,Mainistir na Buille,Mainistir na Búille,boili,bwyl,Бойл,بويل,ბოილი', 53.9666700, -8.3000000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75499, 'Blessington', 'Blessington', 'Baile Coimin,Baile Coimín,Blesingtun,Blessington,Блесингтън,Блессингтон', 53.1700000, -6.5325000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75500, 'Blarney', 'Blarney', 'An Bhlarna,Blarney', 51.9333300, -8.5666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75501, 'Blanchardstown', 'Blanchardstown', 'Baile Bhlainseir,Baile Bhlainséir,Blachardstown,Blanchardstaun,Blanchardstown,blanchrdstawn,Бланчардстаун,بلانچردستاون', 53.3880600, -6.3755600, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75502, 'Blackrock', 'Blackrock', '', 53.9640500, -6.3651400, 'IE', '2010-08-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75503, 'Blackrock', 'Blackrock', 'An Charraig Dhubh,Blackrock,Blehkrok,Carraig Dubh,blkrak,Блэкрок,بلکراک', 53.3015000, -6.1778000, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75504, 'Birr', 'Birr', 'Biorra,Bir,Birr,Parsonstown,biri,Бир,Бирр,ბირი', 53.0913900, -7.9133300, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75505, 'Belturbet', 'Belturbet', 'Beal Tairbirt,Beltjorbet,Belturbet,Beul Tairbeirt,Béal Tairbirt,Белтурбет,Белтёрбет,ბელტურბეტი', 54.1000000, -7.4500000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75506, 'Belmullet', 'Belmullet', 'BLY,Beal An Mhuirthead,Beal an Mhuirthead,Belmuliet,Belmullet,Béal An Mhuirthead,Béal an Mhuirthead', 54.2250000, -9.9908300, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75507, 'Bearna', 'Bearna', 'Barna,Bearna', 53.2519400, -9.1497200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75508, 'Bantry', 'Bantry', 'BYT,Bantri,Bantry,Beanntrai,Beanntraí,baenteuli,ban te li,Бантри,ბანტრი,班特里,밴트리', 51.6833300, -9.4500000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75509, 'Bandon', 'Bandon', 'Bandon,Bandun,Droichead na Bandan,Droichead na Bandon,bandoni,Бандон,Бандън,ბანდონი', 51.7469400, -8.7425000, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75510, 'Banagher', 'Banagher', 'Banagher,Banakher,Beannchar,Банахер', 53.1886100, -7.9866700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75511, 'Baltinglass', 'Baltinglass', 'Baltinglass,Bealach Conglais', 52.9372200, -6.7091700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75512, 'Balrothery', 'Balrothery', 'Balrothery', 53.5882800, -6.1872800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75513, 'Ballyshannon', 'Ballyshannon', 'Balishanun,Ballishannon,Ballyshannon,Beal Atha Seanaidh,Béal Átha Seanaidh,balishenoni,Балишанън,Баллишаннон,Баллішаннон,ბალიშენონი', 54.5000000, -8.1833300, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75514, 'Ballyragget', 'Ballyragget', 'Ballyragget,Beal Atha Ragad,Béal Átha Ragad', 52.7888900, -7.3302800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75515, 'Ballymote', 'Ballymote', 'Baile an Mhota,Baile an Mhóta,Ballymote', 54.0833300, -8.5166700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75516, 'Ballymahon', 'Ballymahon', 'Baile Ui Mhathain,Baile Uí Mhatháin,Ballymahon', 53.5666700, -7.7666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75517, 'Ballyjamesduff', 'Ballyjamesduff', 'Baile Sheamais Dhuibh,Baile Shéamais Dhuibh,Ballyjamesduff', 53.8652800, -7.2027800, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75518, 'Ballyhaunis', 'Ballyhaunis', 'Ballyhaunis,Beal Atha hAmhnais,Béal Átha hAmhnais', 53.7666700, -8.7666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75519, 'Ballyconnell', 'Ballyconnell', 'Ballikonnell,Ballyconnell,Beal Atha Conaill,Béal Átha Conaill,Балликоннелл', 54.1166700, -7.5833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75520, 'Ballybunnion', 'Ballybunnion', 'Baile an Bhuinneanaigh,Baile an Bhuinneánaigh,Ballybunion,Ballybunnion', 52.5110800, -9.6709700, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75521, 'Ballybofey', 'Ballybofey', 'Balibofis,Baliboufi,Ballibofi,Ballybofey,Bealach Feich,Bealach Féich,Балибоуфи,Баллибофи,Баллібофі', 54.8000000, -7.7833300, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75522, 'Ballyboden', 'Ballyboden', 'Ballyboden', 53.2805600, -6.3163900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75523, 'Ballivor', 'Ballivor', 'Baile Iomhair,Baile Íomhair,Ballivor', 53.5316700, -6.9611100, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75524, 'Ballinrobe', 'Ballinrobe', 'Baile an Roba,Baile an Ròba,Baile an Róba,Ballinrob,Ballinrobe,balinrobi,Баллинроб,ბალინრობი', 53.6333300, -9.2333300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75525, 'Ballinasloe', 'Ballinasloe', 'Balinaslou,Ballinaslo,Ballinasloe,Beal Atha na Sluaighe,Beeal Aah ny Sluigh,Béal Átha na Sluaighe,balinaslo,ballinaseullo,barinasuro,Балинаслоу,Баллинасло,ბალინასლო,バリナスロー,발리나슬로', 53.3275000, -8.2194400, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75526, 'Ballina', 'Ballina', 'Balina,Ballina,Beal An Atha,Beal an Atha,Beeal yn Aah,Béal An Átha,Béal an Átha,ba li na,baellina,balina,balyna,Балина,Баллина,بالینا,ბალინა,巴利纳,밸리나', 54.1166700, -9.1666700, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75527, 'Ballina', 'Ballina', 'Ballina', 52.8077800, -8.4355600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75528, 'Ballaghaderreen', 'Ballaghaderreen', 'Ballaghaderreen,Bealach an Doirin,Bealach an Doirín', 53.9000000, -8.5833300, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75529, 'Baldoyle', 'Baldoyle', 'Baile Duill,Baile Dúill,Baldoyle', 53.3997200, -6.1258300, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75530, 'Balbriggan', 'Balbriggan', 'Baile Brigin,Baile Brigín,Balbrigan,Balbriganas,Balbriggan,ba er bu li gen,balbrigani,balbrygan,Балбриган,Балбригган,بالبریگان,ბალბრიგანი,巴爾布里根', 53.6127800, -6.1819400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75531, 'Bailieborough', 'Bailieborough', 'Baileborough,Bailieborough,Coill an Chollaigh', 53.9166700, -6.9666700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75532, 'Bagenalstown', 'Bagenalstown', 'Bagenalstown,Moneybeg,Muine Bheag,Muinebeag', 52.7003100, -6.9618100, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75533, 'Aughrim', 'Aughrim', 'Aughrim,Eachroim', 52.8533300, -6.3275000, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75534, 'Athy', 'Athy', 'Adaj,Ataj,Athy,Baile Atha I,Baile Átha Í,atai,Адай,Атай,Атај,ათაი', 52.9913900, -6.9802800, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75535, 'Athlone', 'Athlone', 'Athlone,Baile Atha Luain,Baile Átha Luain', 53.4333300, -7.9500000, 'IE', '2012-02-28', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75536, 'Athgarvan', 'Athgarvan', 'Athgarvan', 53.1538900, -6.8050000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75537, 'Athenry', 'Athenry', 'Aah yn Ree,Adunraj,Atenraj,Athenry,Baile Atha an Ri,Baile Átha an Rí,adenlai,atenrai,Адънрай,Атенрай,اتن‌رای,ათენრაი,아덴라이', 53.2963900, -8.7430600, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75538, 'Athboy', 'Athboy', 'Athboy,Baile Atha Bui,Baile Átha Buí', 53.6232700, -6.9143400, 'IE', '2014-12-03', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75539, 'Askeaton', 'Askeaton', 'Askeaton,Eas Geitine,Eas Géitine', 52.5997200, -8.9755600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75540, 'Ashbourne', 'Ashbourne', 'Ashborn,Ashbourne,Cill Dheaglain,Cill Dhéagláin,Ашборн', 53.5116300, -6.3982100, 'IE', '2013-12-10', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75541, 'Arklow', 'Arklow', 'An tInbhear Mor,An tInbhear Mór,Arklou,Arklow,Inver Mooar,a ke luo,akeullo,arklw,Арклоу,آرکلو,არკლოუ,阿克洛,아클로', 52.7930600, -6.1413900, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75542, 'Ardnacrusha', 'Ardnacrusha', 'Ardnacrusha,Castlebank', 52.7090800, -8.6143100, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75543, 'Ardee', 'Ardee', 'Ardee,Ardi,Baile Atha Fhirdhia,Baile Átha Fhirdhia,ardi,Арди,არდი', 53.8597200, -6.5405600, 'IE', '2012-01-18', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75544, 'Aghada', 'Aghada', 'Aghada', 51.8391700, -8.2122200, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75545, 'Adare', 'Adare', 'Adare,Ath Dara,Áth Dara', 52.5619400, -8.7955600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75546, 'Abbeyleix', 'Abbeyleix', 'Abbeyleix,Abbilejks,Abileiksas,Mainistir Laoise,Pasjolak Abilejks,a bi lai ke si,abylyks,Аббилейкс,Аббілейкс,Пасёлак Абілейкс,ابیلیکس,阿比莱克斯', 52.8991700, -7.3575000, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75547, 'Abbeyfeale', 'Abbeyfeale', 'Abbeyfeale,Abbifil,Mainistir na Feile,Mainistir na Féile,a bi fei er,abyfyl,Аббифил,Аббіфіл,ابیفیل,阿比菲尔', 52.3813900, -9.3025000, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75548, 'Castletown', 'Castletown', 'Castletown', 52.7230600, -6.1894400, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75549, 'Portraine', 'Portraine', 'Portrane', 53.4966700, -6.1111100, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75550, 'Ballygerry', 'Ballygerry', '', 52.2491700, -6.3573900, 'IE', '2015-02-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75551, 'Ballinroad', 'Ballinroad', '', 52.5178900, -6.4061900, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75552, 'Annacotty', 'Annacotty', 'Annacotty', 52.6680600, -8.5472200, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75553, 'Castleconnell', 'Castleconnell', 'Caislean Ui Chonaill,Caisleáñ Ui Chonaill,Castleconnell', 52.7138900, -8.4994400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75554, 'Nenagh Bridge', 'Nenagh Bridge', '', 52.8816700, -8.1958300, 'IE', '2010-08-14', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75555, 'Shannon', 'Shannon', 'An tSionna,Gorad Shehnan,SNN,Sanonas,Shannon,Shannon Town,Shanun,Shenon,Sionainn,syaeneon,Šanonas,Горад Шэнан,Шаннон,Шанън,Шенон,شینن، کاؤنٹی کلیئر,섀넌', 52.7038900, -8.8641700, 'IE', '2014-07-21', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75556, 'Moate', 'Moate', 'An Mota,An Móta,Moate', 53.3938900, -7.7172200, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75557, 'Kill', 'Kill', 'An Chill,Kill', 53.2513900, -6.5916700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75558, 'Ashford', 'Ashford', 'Ashford,Ath na Fuinseoige', 53.0083300, -6.1113900, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75559, 'Kilpedder', 'Kilpedder', 'Kilpedder', 53.1091700, -6.1066700, 'IE', '2013-11-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75560, 'Valleymount', 'Valleymount', 'Valleymount', 53.1038900, -6.5536100, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75561, 'Kilmacanoge', 'Kilmacanoge', 'Kilmacanogue', 53.1672200, -6.1336100, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75562, 'Eadestown', 'Eadestown', '', 53.2027800, -6.5780600, 'IE', '2013-12-08', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75563, 'Little Bray', 'Little Bray', '', 53.2044400, -6.1208300, 'IE', '2017-07-26', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75564, 'Firhouse', 'Firhouse', 'Firhouse', 53.2816700, -6.3391700, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75565, 'Sandyford', 'Sandyford', '', 53.2747000, -6.2253000, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75566, 'Foxrock', 'Foxrock', 'Foxrock', 53.2666700, -6.1741700, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75567, 'Sallynoggin', 'Sallynoggin', '', 53.2791700, -6.1405800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75568, 'Rathgar', 'Rathgar', '', 53.3145700, -6.2750000, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75569, 'Artane', 'Artane', '', 53.3871200, -6.2138000, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75570, 'Beaumont', 'Beaumont', 'Beaumont', 53.3913900, -6.2405600, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75571, 'Drumcondra', 'Drumcondra', 'Dramkondra,Droim Conrach,Драмкондра', 53.3705800, -6.2529800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75572, 'Ballymun', 'Ballymun', '', 53.3980700, -6.2669300, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75573, 'Cabra', 'Cabra', 'Cabra', 53.3669400, -6.2944400, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75574, 'Hartstown', 'Hartstown', '', 53.3930600, -6.4269400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75575, 'Ballyfermot', 'Ballyfermot', 'Baile Formaid,Ballifermot,Ballyfermot,Баллифермот', 53.3452800, -6.3588900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75576, 'Templeogue', 'Templeogue', 'Teach Mealog,Teach Mealóg,Templeogue,Temploug,tmplwg,Темплоуг,تمپلوگ', 53.2952800, -6.3088900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75577, 'Oldbawn', 'Oldbawn', 'Oldbawn', 53.2755600, -6.3675000, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75578, 'Cherry Orchard', 'Cherry Orchard', '', 53.3360500, -6.3779900, 'IE', '2015-11-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75579, 'Rialto', 'Rialto', '', 53.3362500, -6.2971800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75580, 'Milltown', 'Milltown', '', 53.3130100, -6.2453000, 'IE', '2017-07-20', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75581, 'Clonskeagh', 'Clonskeagh', '', 53.3146700, -6.2314800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75582, 'Booterstown', 'Booterstown', 'Baile an Bhothair,Baile an Bhóthair', 53.3044700, -6.1998500, 'IE', '2017-07-20', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75583, 'Ballinteer', 'Ballinteer', '', 53.2740900, -6.2539700, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75584, 'Greenhills', 'Greenhills', '', 53.3346700, -6.3030200, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75585, 'Coolock', 'Coolock', 'An Chulog,An Chúlóg,Kulok,Кулок', 53.3887000, -6.1999800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75586, 'Bonnybrook', 'Bonnybrook', '', 53.3983500, -6.2074900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75587, 'Donaghmede', 'Donaghmede', 'Domhnach Mide', 53.3984500, -6.1617900, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75588, 'Darndale', 'Darndale', '', 53.3994800, -6.1888600, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75589, 'Donnycarney', 'Donnycarney', '', 53.3735000, -6.2097600, 'IE', '2017-07-20', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75590, 'Bayside', 'Bayside', '', 53.3889500, -6.1404100, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75591, 'Charlesland', 'Charlesland', 'Charlesland', 53.1277100, -6.0634700, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75592, 'Moyross', 'Moyross', 'Moyross', 52.6819800, -8.6395500, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75593, 'Ballisodare', 'Ballisodare', '', 54.2111000, -8.5086500, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75594, 'Ballylinan', 'Ballylinan', '', 52.9449700, -7.0407300, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75595, 'Fairview', 'Fairview', '', 53.3659700, -6.2398500, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75596, 'Knocklyon', 'Knocklyon', '', 53.2803000, -6.3313000, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75597, 'Palmerstown', 'Palmerstown', '', 53.3501900, -6.3777800, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75598, 'Jobstown', 'Jobstown', '', 53.2786600, -6.4080300, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75599, 'Killester', 'Killester', '', 53.3732200, -6.2043100, 'IE', '2016-09-12', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75600, 'Confey', 'Confey', '', 53.3792300, -6.4905200, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75601, 'Kentstown', 'Kentstown', '', 53.6275400, -6.5267400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75602, 'Kilquade', 'Kilquade', '', 53.0974300, -6.0841100, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75603, 'Newtownmountkennedy', 'Newtownmountkennedy', '', 53.0905200, -6.1114900, 'IE', '2015-12-07', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75604, 'Balally', 'Balally', 'Baile Amhlaoibh', 53.2750400, -6.2359400, 'IE', '2017-07-20', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75605, 'Kinsealy-Drinan', 'Kinsealy-Drinan', '', 53.4439500, -6.2033400, 'IE', '2017-07-25', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75606, 'Courtbrack', 'Courtbrack', '', 51.9667700, -8.6461100, 'IE', '2017-07-29', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75607, 'Ballybofey-Stranorlar', 'Ballybofey-Stranorlar', '', 54.8016500, -7.7743700, 'IE', '2017-07-30', 107);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75608, 'Jerusalem', 'Jerusalem', 'Adonai-jireh,Aelia Capitolina,Al Quds,Al-Kuds,Al-Qudis,Al-Quds,Al-Qudıs,Ariel,Baitul Maqdis,Baitulmuqaddis,Bajtul Makudis,Bayt al-Maqdis,Bayt al-Muqaddas,Cherusalem,Colonia Aelia Capitolina,Djeruzalem,El Kuds,El Quds esh Sherif,Erusagem,Erusalim,Geruesalem,Gerusalem,Gerusalemme,Gerüsalem,Gierusalemme,Girusalemmi,Gorad Ierusalim,Herusale,Herusalem,Herusalẽ,Hierosolyma,Hierousalem,Hierousalēm,Hierusalem,Hiruharama,IJerusalem,Ia-lo-sak-leng,Ia-lo-sat-leng,Iarusaileim,Iarúsailéim,Iebous,Iebus,Ierosolyma,Ierousalem,Ierousalimu,Ierusalem,Ierusalema,Ierusalim,Ir David,Ir Ha-Qdoosha,Ir Ha-Qodesh,Iyerusalim,Ià-lô-sák-lēng,Iâ-lō͘-sat-léng,Iýerusalim,JRS,Jarusalen,Jeriwsalem,Jerozale,Jerozalė,Jerozolema,Jerozolima,Jerozolëma,Jerusalem,Jerusalemi,Jerusalemo,Jerusalemu,Jerusalen,Jerusalim,Jerusalèm,Jerusalém,Jerusalén,Jeruusalemm,Jeruzale,Jeruzalem,Jeruzaleme,Jeruzalim,Jeruzalém,Jeruzalė,Jeruzsalem,Jeruzsálem,Jerúsalem,Jerúsálẹ́mù,Jorsala,Jorsalaborg,Jorsalir,Jérusalem,Jórsalaborg,Jórsalir,Kouds,Kudues,Kudus,Kudüs,Kuuds-GӀala,Moria,Morias,Orcalim,Orselim,Orşelîm,Quddus,Qudus,Queds,Qüds,Salem,Shalem,Sion,Solyma,Ursalimmu,Urselim,Urshalim,Urusalim,Urušalim,Urşelim,Uršalimmu,Xerusalen,Xerusalén,Ya-lu-sat-lang,Yerusalem,Yerusalemi,Yerusalemu,Yerusalémi,Yerushalayim,Yirushalayim,Yirushalāyim,Yâ-lu-sat-lâng,Yérusalem,Zion,al-Balat,al-Quds as-Sarif,al-Quds aš-Šarīf,albla,alqds,alqds alshryf,aryyyl,awrshlym,byt almqds,erucalem,erusaremu,haqodes,ierusalimi,jerusalama,jerusalem,jerusalema,jeruselama,lqds,mrya,mworiyah,mwryh,qudus,qۇds,salem,salym,shywn,slm,wrshlym,yarusalama,ybws,ye lu sa leng,ye ru sa lem,yebws,yelusallem,yerwsalami,yerwsalayim,yerwselem,yrwshlm,yrwslm,yrwslym,ywrshەlym,ziywon,zywn,Αριηλ,Ιεβους,Ιεροσολυμα,Ιεροσόλυμα,Ιερουσαλήμ,Ιερουσαλημ,Μωριας,Σαλημ,Σιων,Σολυμα,Єрусалим,Їєроусалимъ,Јерусалим,Байтул Макъдис,Горад Іерусалім,Ерусалим,Иерусалим,Йерусалим,Кудус,Къудс-ГӀала,Уршалим,Երուսաղեմ,אֵילִיָּה קַפִּיטוֹלִינָה,הַקֹּדֶשׁ,יְבוּס,יְרוּשְׁלֶם,יְרוּשָׁלַיִם,יְרוּשָׁלַםִ,יְרוּשָׁלָםִ,יבוס,ירושלים,ירושלם,מוֹרִיָּה,מוריה,צִיּוֹן,ציון,שָׁלֵם,שלם,إيلياء,ئورشەلیم,اريئيل,البلا,القدس,القدس الشريف,اورشلیم,بيت المقدس,بیت المقدس,ساليم,صهيون,قۇدس,لقدس,مريّا,ورشليم,يبوس,یروشلم,ܐܘܪܫܠܡ,ܨܗܝܘܢ,ޤުދުސް,जेरुसलेम,जेरुसेलम,जेरूसलम,यरुशलम,জেরুসালেম,ਜੇਰੂਸਲਮ,ଜେରୁସାଲେମ,எருசலேம்,జెరూసలేం,ಜೆರುಸಲೆಂ,ജെറുസലേം,เยรูซาเลม,ເຢ​ຣູ​ຊາ​ເລັມ,ཇེ་རུ་ས་ལེམ།,ဂျေရုဆလင်မြို့,იერუსალიმი,እየሩሳሌም,エルサレム,耶路撒冷,예루살렘,', 31.7690400, 35.2163300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75609, 'Har Adar', 'Har Adar', 'Har Adar,Khirbat Najm,Khirbat en Nijam', 31.8275400, 35.1309300, 'IL', '2014-08-21', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75610, 'Modi‘in Makkabbim Re‘ut', 'Modi''in Makkabbim Re''ut', 'Gane Modi''in,Gane Modi‘in,Makkabbim,Makkabbim Re`ut,Makkabbim Re‘ut,Makkabim,Modi''in,Modi''in Makkabbim Re''ut,Modiin,Modi‘in,Modi‘in Makkabbim Re‘ut,Nahal Modi''im,Naẖal Modi‘im,Ramot Modi''in,Ramot Modi‘in,Re`ut,Re‘ut,mwdyʻyn,מודיעין,מודיעין מכבים רעות,מכבים רעות,רעות', 31.8938500, 35.0150400, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75611, 'Ẕur Moshe', 'Zur Moshe', 'Tsur Moshe,Tsur Mosheh,Zur Moshe,zwr msh,צור משה,Ẕur Moshe', 32.2981900, 34.9131300, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75612, 'Ẕur Hadassa', 'Zur Hadassa', 'Tsur Hadassa,Zur Hadassa,zwr hdsh,צור הדסה,Ẕur Hadassa', 31.7191200, 35.0970800, 'IL', '2015-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75613, 'Safed', 'Safed', 'Cfat,Safad,Safed,Safet,Sfat,Tsefat,Tsfat,Zefat,cai fa te,ceppat,jepateu,sfd,tspati,tsufatto,zpt,Сафед,Цфат,צפת,صفد,சேப்பாத்,ცფათი,Ẕefat,ツファット,采法特,제파트', 32.9646500, 35.4960000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75614, 'Yeroẖam', 'Yeroham', 'Kefar Yeroham,Kfar Yeroham,Yeroham,Yeroẖam,Yeruham,yrhm,yrwhm,ירוחם,ירחם', 30.9882200, 34.9317600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75615, 'Yehud', 'Yehud', 'Al Yahudiya,El Yehudiye,El Yehūdīye,Jekhud,Kefar Yehud,Yahud,Yahudiya,Yahudiyyah,Yahūdīya,Yehud,Yehudie,Yhud,`Abbasiya,yhwd,Йехуд,יהוד,‘Abbāsīya', 32.0331700, 34.8909100, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75616, 'Yavne’el', 'Yavne''el', 'Bayt Jinn,Beit Gan,Beith Gan,Bet Gan,Bethgan,Kefar Yamma,Mishmar HaShelosha,Mishmar Hasheloshah,Mishmar Hashloshah,Yabneel,Yabniel,Yamah,Yamma,Yavne''el,Yavne’el,Yavni''el,Yavniel,Yavni’el,byt gn,msmr hslwsh,בית גן,יבנאל,משמר השלושה', 32.7061900, 35.5043500, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75617, 'Yavné', 'Yavne', 'Jamnia,Javne,Javnė,Jawne,Kefar Yavne,Kfar Yavne,Kfar Yavneh,New Yavne,Yamnia,Yavne,Yavné,ya fu nei,yabeune,yabune,ybnh,Явне,יבנה,یبنه,ヤブネ,亞夫內,야브네', 31.8807800, 34.7384300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75618, 'Jaffa', 'Jaffa', 'Giaffa,Iope,Iopē,Jafa,Jaffa,Jafo,Joppa,Joppe,Yafa,Yafah,Yaffa,Yaffo,Yafo,Yāfa,yafa,ypw,Яфо,Яффа,יפו,يافا,یافا', 32.0504300, 34.7522400, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75619, '‘Uzeir', '`Uzeir', 'Uzeir,`Azir,`Uzayr,`Uzeir,עזיר,‘Azir,‘Uzayr,‘Uzeir', 32.7921200, 35.3298400, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75620, 'Umm el Faḥm', 'Umm el Fahm', 'El Fahm,Umm al Fahm,Umm el Faham,Umm el Fahm,Umm el Faḥm,אם אל פחם', 32.5172500, 35.1534900, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75621, 'Tirat Karmel', 'Tirat Karmel', 'At Tira,Tira,Tirah,Tirat Carmel,Tirat Hakarmel,Tirat Karmel,Tirat Karmel'',Tirat KhaKarmel'',Tire,tyrt krml,Тират Кармель,Тират ХаКармель,טירת כרמל', 32.7602100, 34.9718300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75622, 'Timrat', 'Timrat', 'Timrat,tmrt,תמרת', 32.7030200, 35.2235900, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75623, 'Tiberias', 'Tiberias', 'Tabariya,Tabariyeh,Tabariyyah,Tabarīya,Tevarya,Tevaryā,Teverya,Tiberiada,Tiberiade,Tiberiades,Tiberiado,Tiberias,Tiberija,Tiberijada,Tiberijas,Tiberiya,Tiberiàs,Tiberiás,Tiberya,Tiberíades,Tibériade,Tiveriada,Tiveriáda,Tubaria,Tverija,Tverja,Tverya,Tyberiada,tbrya,tbryh,tbryt,ti bi li ya,tibeliaseu,tiberia,tiperiyu,Τιβεριάδα,Τιβεριάς,Тверия,Тверія,Тиберия,Тиберијада,טבריה,طبريا,طبرية,طبریه,طبریہ,திபேரியு,ტიბერია,Ṭabariyyah,ティベリア,提比里亞,티베리아스', 32.7922100, 35.5312400, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75624, 'Tel Mond', 'Tel Mond', 'Tel Mond,tl mwnd,תל מונד', 32.2499500, 34.9173700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75625, 'Tel Aviv', 'Tel Aviv', 'Lungsod ng Tel Aviv-Yafo,TLV,Tehl''-Aviu,Tel Avevs,Tel Aviv,Tel Aviv Yaffo,Tel Aviv Yafo,Tel Aviv-Jaffa,Tel Aviv-Jafo,Tel Aviv-Yafo,Tel Avivas,Tel Avív,Tel Avėvs,Tel Awiw,Tel Eviv,Tel''-Aviv,Tel-Aviv,Tel-Avivo,Tel-aviv,Tel-Əviv,Telaviva,Telavivum,Tell Abib,Tell Abīb,Tell Afif,te la wei fu,tel aviv,tel-abibeu,tel-avivi,tela abhibha,tela abhiva,tela aviva,teruabibu,thel xa wif,tl abyb,tl ʼbyb,tێl yەvyv,Τελ Αβίβ,Тел Авив,Тел-Авив,Тель-Авив,Тель-Авів,Тэль-Авіў,Թել Ավիվ,תל אביב,תל אביב-יפו,تل أبيب,تل ابيب,تل ابیب,تل‌آویو,تێل ئەڤیڤ,تېلاۋىف,ܬܠ ܐܒܝܒ,तेल अभिव,तेल अविव,तेल अवीव,তেল আভিভ,டெல் அவீவ்,ടെൽ അവീവ്,เทลอาวีฟ,თელ-ავივი,ቴል አቪቭ,テルアビブ,特拉維夫,特拉维夫,텔아비브', 32.0808800, 34.7805700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75626, 'maalot Tarshīhā', 'maalot Tarshiha', 'Ma''alot-Tarshiha,Maalot Tarshiha,Maalot-Tarshikha,Me`ona `Ironit,Tarchiha,Tarshihah,Teir Shiha,mʻlwt trsyhʼ,Маалот-Таршиха,מעלות תרשיחא', 33.0166700, 35.2666700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75627, 'Tamra', 'Tamra', 'Tamra,Tamrah,Temarah,ta mu la,tamra,tmrh,tmrt,Тамра,טמרה,תמרה,طمرة,طمرہ,தம்ரா,ტამრა,塔姆拉', 32.8530100, 35.1987000, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75628, 'Sūlam', 'Sulam', 'Shunem,Sulam,Sūlam,swlm,swnm,סולם,שונם', 32.6060600, 35.3340800, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75786, 'Thang', 'Thang', '', 34.9274000, 76.7933600, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75787, 'Pūnch', 'Punch', 'Poonch,Punch,Pūnch', 33.7703300, 74.0925400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75788, 'Keelakarai', 'Keelakarai', 'Kilakarai,Kilakari,Kīlakarai,kai ai la ka lai,kilakara''i,kilakkarai,कीलाकाराई,কীলাকারাই,கீழக்கரை,凯埃拉卡赖', 9.2318300, 78.7854500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75789, 'Zunheboto', 'Zunheboto', 'Zunheboto', 25.9666700, 94.5166700, 'IN', '2016-06-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75790, 'Ziro', 'Ziro', 'ZER,Zero,Ziro', 27.5949700, 93.8385400, 'IN', '2016-12-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75791, 'Zamānia', 'Zamania', 'Zamania,Zaminia,Zamānia', 25.4196100, 83.5578600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75792, 'Zaidpur', 'Zaidpur', 'Zaidpur', 26.8309300, 81.3292900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75793, 'Zahirābād', 'Zahirabad', 'Zahirabad,Zahirābād', 17.6813800, 77.6074300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75794, 'Zafarābād', 'Zafarabad', '', 25.6986700, 82.7335400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75795, 'Yol', 'Yol', 'Yol', 32.1642300, 76.1962200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75796, 'Yeola', 'Yeola', 'Yeola,Yevale,Yewle', 20.0424000, 74.4894400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75797, 'Yellāpur', 'Yellapur', 'Yellapur,Yellāpur', 14.9637000, 74.7092900, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75798, 'Yellandu', 'Yellandu', 'Yellandlapad,Yellandlapād,Yellandrapad,Yellandu', 17.5906400, 80.3214600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75799, 'Yelbarga', 'Yelbarga', 'Yelbarga', 15.6154500, 76.0118400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75800, 'Yelandūr', 'Yelandur', 'Jagir,Jāgīr,Yelandur,Yelandūr', 12.0462900, 77.0303400, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75801, 'Yelahanka', 'Yelahanka', 'Yelahanka,yalahanka,ye la han ka,yelahanka,یلہانکا,यलहंक,য়েলাহান্কা,ಯಲಹಂಕ,耶拉汉卡', 13.1007300, 77.5963200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75802, 'Yavatmāl', 'Yavatmal', 'Yavatmal,Yavatmāl,Yeotmal,Yeotmāl', 20.3932400, 78.1320100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75803, 'Yāval', 'Yaval', '', 21.1677200, 75.6976200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75804, 'Yārāda', 'Yarada', '', 17.6587200, 83.2741900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75805, 'Yanam', 'Yanam', 'Janam,Yanam,Yanaon,Янам', 16.7330800, 82.2136400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75806, 'Yamunānagar', 'Yamunanagar', 'Abdullahpur,Abdullapur,Abdullāhpur,Jamna Nagar,Yamuna Nagar,Yamunanagar,Yamunānagar', 30.1279600, 77.2837100, 'IN', '2016-05-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75807, 'Yairipok', 'Yairipok', 'Yairipok', 24.6779200, 94.0476700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75808, 'Yādgīr', 'Yadgir', 'Yadgir,Yādgīr', 16.7700700, 77.1375500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75809, 'Wokha', 'Wokha', 'Wokha', 26.0971700, 94.2581700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75810, 'Wer', 'Wer', '', 27.0186000, 77.1763600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75811, 'Wellington', 'Wellington', 'Vellington,Wellington,Wellington Town,Веллингтон', 11.3655200, 76.7844200, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75812, 'Wazīrganj', 'Wazirganj', 'Wazirganj,Wazīrganj', 28.2114500, 79.0566500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75813, 'Wāshīm', 'Washim', 'Basim,Băsim,Washim,Wāshīm', 20.1112800, 77.1330000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75814, 'Warud', 'Warud', 'Warud,oyaruda,raaruda,varuda,wa lu de,وروڑ,वरुड,वरुद,ওয়ারুদ,ৱারুদ,瓦鲁德', 21.4710100, 78.2696500, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75815, 'Warora', 'Warora', 'Warora', 20.2288500, 79.0027700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75816, 'Wāris Alīganj', 'Waris Aliganj', 'Waris Aliganj,Waris Ariganj,Wāris Alīganj,Wāris Arīganj', 25.0172000, 85.6404700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75817, 'Wardha', 'Wardha', 'Vardha,Vardhá,Vardkha,Varntcha,Wardha,oyaradha,raaradha,vardha,varta,waruda,wo er ta,Βαρντχά,Вардха,وردھا,वर्धा,ওয়ারধা,ৱারধা,વર્ધા,வர்தா,ワルダー,沃尔塔', 20.7393300, 78.5978400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75818, 'Wārāseonī', 'Waraseoni', 'Waraseoni,Wārāseoni,Wārāseonī', 21.7618400, 80.0430100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75819, 'Warangal', 'Warangal', 'Ekasila Nagaram,Orugallu,Varangal,Varangalas,WGC,Warangal,raarangala,varangal,varangal jilla,varangala,varangala-nagaram,varankal,wa lang jia er,walang-gal,warangala,warangaru,warangl,wrnjl,Варангал,وارانگل,ورنجل,वरंगल,वरङ्गल-नगरम्,वारंगल,वारंगळ,ৱারাঙ্গাল,વારંગલ,ୱାରଙ୍ଗଲ,வாரங்கல்,వరంగల్ జిల్లా,ವರಂಗಲ್,വാറങ്കൽ,ワランガル,瓦朗加尔,와랑갈', 18.0000000, 79.5833300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75820, 'Wanparti', 'Wanparti', 'Wanaparthy,Wanparti', 16.3673800, 78.0688900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75821, 'Wānkāner', 'Wankaner', 'Vankaner Kathiawar,Wankaner,Wānkāner', 22.6119800, 70.9437900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75822, 'Wani', 'Wani', 'Vanja,Wani,Wun,Wūn,Ваня', 20.0550700, 78.9531300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75823, 'Wāngjing', 'Wangjing', 'Vanczin,Wangjing,Wāngjing,Ванцзин', 24.5892100, 94.0638600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75824, 'Walajapet', 'Walajapet', 'Walaja,Walajapet,Wālājāpet', 12.9251000, 79.3662600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75825, 'Wallajahbad', 'Wallajahbad', 'Dandei Sivaram,Dandei Sīvaram,Walajabad,Wallajahbad,Wālājābād', 12.7904100, 79.8235800, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75826, 'Wai', 'Wai', 'Vaj,Wai,va''i,Вай,وئی، مہاراشٹر,वाई,વાઇ', 17.9527600, 73.8905800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75827, 'Waghāi', 'Waghai', 'Waghai,Waghāi', 20.7704800, 73.5007400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75828, 'Wādi', 'Wadi', 'Vadi,Wadi,Wādi,Вади', 17.0518300, 76.9904800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75829, 'Wadgaon', 'Wadgaon', 'Vadgaon,Wadgaon', 18.7392000, 73.6394500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75830, 'Vyāra', 'Vyara', 'Vvara,Vyara,Vyāra', 21.1107900, 73.3936500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75831, 'Vuyyūru', 'Vuyyuru', 'Vuyyuru,Vuyyūru', 16.3630700, 80.8440600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75832, 'Vrindāvan', 'Vrindavan', 'Brindaban,Brindāban,Vrindaban,Vrindavan,Vrindāban,Vrindāvan,Вриндаван', 27.5810500, 77.6966200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75833, 'Vriddhāchalam', 'Vriddhachalam', '', 11.5183000, 79.3241100, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75834, 'Vizianagaram', 'Vizianagaram', 'Viguyanagram,Vizianagaram,Vizianagarm,Vizianagram,Vizianagram City,Vizijanagaram,bijayanagarama,bijianagalam,bijiyanagarama,fyzynjarm,vijayanagara,vijayanagaram,vijayanagarama,vijayanakaram,vu~ijayanagaramu,wei ji ya ne ge lei mu,wjayangrm,Визианагарам,Визијанагарам,فيزينجارم,وجایانگرم,विजयनगरम,विजयनगरम्,বিজিয়ানগরম,વિજયનગર,ବିଜୟନଗରମ,விஜயநகரம்,విజయనగరం,ヴィジャヤナガラム,维济亚讷格勒姆,비지아나가람', 18.1169200, 83.4114800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75835, 'Vite', 'Vite', 'Vita,Vite,Вита', 17.2734300, 74.5379200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75836, 'Visnagar', 'Visnagar', 'Visnagar', 23.6985500, 72.5521000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75837, 'Visakhapatnam', 'Visakhapatnam', 'Gorad Vishakkhapatnam,VTZ,Vaisakhapattanam,Vaisākhapattanam,Visak,Visakha,Visakhapatnam,Visakhapatnamas,Vishakhapatnam,Vishakkhapatnam,Vishākhapatnam,Visákhapatnam,Vizag,Vizag City,Vizagapatam,Vizagapatnam,bisakhapatana,bisakhapattama,bisyakapateunam,fysakhabatnam,vicakappattinam,visakhapatanama,visakhapatnam,visakhapattanam,visakhapattanama,vu~ishakapatonamu,wei sha ka pa te nan,wisakha pat tnam,wshakھapٹnm,wysakapatnam,Визагапатнам,Вишакхапатнaм,Вишакхапатнам,Вішакхапатнам,Горад Вішакхапатнам,فيساخاباتنام,وشاکھاپٹنم,ويساکاپټنام,ویساکاپاتنام,ویساکھاپتنام,विशाखपट्टणम्,विशाखापट्टणम,विशाखापत्तनम,বিশাখাপত্তম,વિશાખાપટનમ,ବିଶାଖାପାଟଣା,விசாகப்பட்டினம்,విశాఖపట్నం,ವಿಶಾಖಪಟ್ಟಣಂ,വിശാഖപട്ടണം,วิศาขาปัตตนัม,ვიშაქაპატნამი,ვიშაქჰაპატნამი,ヴィシャーカパトナム,维沙卡帕特南,비샤카파트남', 17.6800900, 83.2016100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75838, 'Vīsāvadar', 'Visavadar', 'Visavadar,Visavedar,Vīsāvadar', 21.3395400, 70.7496600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75839, 'Virudunagar', 'Virudunagar', 'Virudhupatti,Virudunagar,Virudupatti', 9.5850900, 77.9578700, 'IN', '2016-06-30', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75840, 'Virpur', 'Virpur', 'Virpur', 23.1892000, 73.4798700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75841, 'Viravanallūr', 'Viravanallur', 'Vadakku Viravanallur,Vadakku Viravanallūr,Viravanallur,Viravanallūr', 8.6961000, 77.5189500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75842, 'Vīrarājendrapet', 'Virarajendrapet', 'Virajpet,Virarajendrapet,Virājpet,Vīrarājendrapet', 12.1964400, 75.8051200, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75843, 'Virār', 'Virar', 'Virar,Virār', 19.4559100, 72.8113600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75844, 'Vīraganūr', 'Viraganur', '', 11.4749100, 78.7372500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75845, 'Vinukonda', 'Vinukonda', 'Vinukonda', 16.0531000, 79.7396400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75846, 'Vinchia', 'Vinchia', 'Vichhia,Vinchia', 22.2102700, 71.3796700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75847, 'Villupuram', 'Villupuram', 'Villapurum,Villupuram', 11.9397500, 79.4924400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75848, 'Vilattikulam', 'Vilattikulam', 'Vilatikulam,Vilattikulam,Vilāttikulam', 9.1322700, 78.1663500, 'IN', '2016-06-30', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75849, 'Vikravāndi', 'Vikravandi', 'Vikravandi,Vikravāndi', 12.0369000, 79.5459500, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75850, 'Vikārābād', 'Vikarabad', 'Vicarabad,Vikarabad,Vikārābād', 17.3381000, 77.9044100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75851, 'Vijayawada', 'Vijayawada', 'Bezawada,Bezwada,Bezwāda,VGA,Vidzajavada,Vidzhajavada,Vidzsajavada,Vidzsajavádá,Vidžajavada,Vijajauada,Vijajaŭada,Vijayavada,Vijayavādā,Vijayawada,Vijayawāda,Widzajawada,Widźajawada,bejavada,bijayabada,bijayarada,bijayawada,bijayawara,fyjayawada,vicayavata,vijaiavada,vijaivara,vijayavada,vijayavara,vu~ijayawada,wei jie ya wa da,wyjyawada,Виджаявада,Виџајавада,Віджаявада,ויגיאוואדה,فيجاياوادا,وجئے واڑہ,ويجیواډا,ویجایاواڈا,ویجیاوادا,विजयवाड़ा,विजयवाडा,বিজযবাডা,বিজয়াৱদা,ਵਿਜਯਵਾਡਾ,ਵਿਜੈਵਾੜਾ,વિજયવાડા,ବିଜୟୱାଡ଼ା,ଵିଜଯଵାଡା,விசயவாடா,బెజవాడ,విజయవాడ,ವಿಜಯವಾಡ,വിജയവാഡ,ვიჯაიავადა,ヴィジャヤワーダ,维杰亚瓦达,비자야와다', 16.5074500, 80.6466000, 'IN', '2016-04-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75852, 'Vijayapuri', 'Vijayapuri', 'Vijayapuri', 11.2453000, 77.5006600, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75853, 'Vijāpur', 'Vijapur', 'Vijapur,Vijāpur', 23.5623000, 72.7484800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75854, 'Vidisha', 'Vidisha', 'Bhilsa,Bhīlsa,Vidisa,Vidisha,Vidiša,bidisa,vidisa,vu~idisha,wdysha,wei di si ha,Видиша,ودیشا,विदिशा,বিদিশা,વિદિશા,ヴィディシャー,维迪斯哈', 23.5260400, 77.8109200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75855, 'Vettūr', 'Vettur', 'Vetchur,Vettoor,Vettur,Vettūr', 8.7174200, 76.7258200, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75856, 'Vettavalam', 'Vettavalam', 'Vettavalam', 12.1076900, 79.2451600, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75857, 'Vettaikkaranpudur', 'Vettaikkaranpudur', 'Vettagaranpudur,Vettaikkaranpudur,Vettaikkāranpudūr,Vettakkaranpudur,Vettakkāranpudūr', 10.5620700, 76.9130500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75858, 'Vetapālem', 'Vetapalem', 'Vetapalem,Vetapālem,Vetāpālem', 15.7850200, 80.3066300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75859, 'Verāval', 'Veraval', 'Veraval,Verāval', 20.9077000, 70.3678600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75860, 'Vepagunta', 'Vepagunta', '', 17.7784400, 83.2157700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75861, 'Venkatagiri', 'Venkatagiri', 'Venkatagiri,Venkatagiri Town', 13.9600500, 79.5803200, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75862, 'Vengurla', 'Vengurla', 'Vengurla,oyenagurala,raenagurala,vengurla,wen ge wu er la,wngwrla,wyngrla,ونگورلا,وینگرلا,वेंगुर्ल,वेंगुर्ला,ওয়েনগুরলা,ৱেনগুরলা,文格乌尔拉', 15.8612500, 73.6318200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75863, 'Vemalwāda', 'Vemalwada', 'Lembulavataka,Lemulavada,Vemalwada,Vemalwāda,Vemulavada', 18.4652300, 78.8689400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75864, 'Velur', 'Velur', 'Velur,Velūr', 11.1082500, 78.0011300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75865, 'Vellore', 'Vellore', 'Gorad Veluru,Vellor,Vellore,Velluru,Velur,Veluru,belloleu,bellore,bhellora,vellor,vellora,vellura,velluru,velur,velura,vu~eruru,wei luo er,wylwr,Веллор,Веллуру,Горад Велуру,ویلور,भेल्लोर,वेल्लूर,वेल्लूरु,वेल्लोर,বেল্লোরে,ਵੇਲੂਰ,વેલ્લોર,வேலூர்,ವೆಲ್ಲೋರ್,വെല്ലൂർ,ヴェールール,韦洛尔,벨로르', 12.9184000, 79.1325500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75866, 'Velankanni', 'Velankanni', 'Vailankanni,Velangann,Velanganni,Velankanni,Velānganni,velankanni,வேளாங்கண்ணி', 10.6833300, 79.8333300, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75867, 'Vejalpur', 'Vejalpur', 'Vejalpur', 22.6902100, 73.5629900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75868, 'Vedasandūr', 'Vedasandur', 'Vedasandur,Vedasandūr', 10.5305400, 77.9497000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75869, 'Vedaraniyam', 'Vedaraniyam', 'Vedaranayam,Vedaraniam,Vedaranniyam,Vedāranniyam', 10.3720800, 79.8509500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75870, 'Vayalār', 'Vayalar', 'Vayalar,Vayalār,vayalaru,வயலாறு', 9.7115800, 76.3388800, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75871, 'Vattalkundu', 'Vattalkundu', '', 10.1606900, 77.7588300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75872, 'Vāsudevanallūr', 'Vasudevanallur', 'Vasudevanallur,Vāsudevanallūr', 9.2392100, 77.4113200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75873, 'Vasind', 'Vasind', 'Vasind', 19.4084400, 73.2628500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75874, 'Vāsco Da Gāma', 'Vasco Da Gama', 'Vasco,Vasco Da Gama,Vasco da Gama,Vasko-da-Gama,Vāsco Da Gāma,Васко-да-Гама', 15.3958500, 73.8156800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75875, 'Vasa', 'Vasa', '', 22.6607900, 72.7551900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75876, 'Vartej', 'Vartej', 'Vartej', 21.7394700, 72.0655300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75877, 'Varkala', 'Varkala', 'Varkala,barakala,varkal,varkala,varkale,varkkalai,wa er ka la,wrkla,Варкала,ورکلا,वर्कला,वर्कले,वर्कल्,বারকল,வர்க்கலை,വർക്കല,瓦尔卡拉', 8.7333000, 76.7167000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75878, 'Varca', 'Varca', 'Varca', 15.2323700, 73.9431100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75879, 'Varangaon', 'Varangaon', 'Varangaon', 21.0176700, 75.9104200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75880, 'Varanasi', 'Varanasi', 'Banaras,Banares,Banāras,Benares,Benarés,Kashi,Kasi,Kāsi,VNS,Varanasi,Varanasio,Varanasis,Varanassi,Vârânasî,Vārānasi,Waranasi,balanasi,baranasi,kasi,pha ran si,varanaci,varanasi,wa la na xi,waranashi,Варанаси,काशी,वाराणसी,বারানসি,வாரணாசி,พาราณสี,ワーラーナシー,瓦臘納西,바라나시', 25.3166800, 83.0104100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75881, 'Vānsada', 'Vansada', 'Bansda,Bānsda,Vansada,Vānsada,Wansda,Wānsda', 20.7581700, 73.3638900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75882, 'Vaniyambadi', 'Vaniyambadi', 'Vanivambadi,Vaniyambadi,Vānivambādi,Vāniyambādi,baniyamabari,fanymbdy,vaniyamabadi,vaniyampati,wa ni ye mu ba di,wanyyambady,wnymbdy,فانيمبدي,وانییامبادی,ونیمبدی,वनियामबादी,বানিয়ামবড়ি,வாணியம்பாடி,瓦尼耶姆巴迪', 12.6816200, 78.6201400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75883, 'Vandavāsi', 'Vandavasi', 'Vandavasi,Vandavāsi,Wandiwash,Wandiwāsh', 12.5042900, 79.6055600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75884, 'Vandalūr', 'Vandalur', 'Vandalur,Vandalūr', 12.8924000, 80.0807900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75885, 'Valsād', 'Valsad', 'Bulsar,Bulsār,Valsad,Valsād,Walsad,Walsād', 20.6101300, 72.9342800, 'IN', '2016-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75886, 'Valpoy', 'Valpoy', 'Valpoi,Valpoi Town,Valpoy', 15.5323900, 74.1367100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75887, 'Valparai', 'Valparai', 'Valparai,Vālpārai', 10.3269100, 76.9511600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75888, 'Vallam', 'Vallam', 'Vallam', 10.7198800, 79.0598100, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75889, 'Vallabh Vidyanagar', 'Vallabh Vidyanagar', 'Vallabh,Vallabh Vidhyanagar,Vallabh Vidyanagar', 22.5333300, 72.9000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75890, 'Valavanur', 'Valavanur', 'Valavanur,Valavanūr', 11.9209400, 79.5823900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75891, 'Azhikkal', 'Azhikkal', 'Azhikal,Azhikkal,Baliapatam,Beliapatanam,Valapattanam,Valarpattanam', 11.9152400, 75.3476100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75892, 'Valangaiman', 'Valangaiman', '', 10.8901200, 79.3932200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75893, 'Valabhīpur', 'Valabhipur', 'Vala,Valabhipur,Valabhīpur,Vallabhipur', 21.8886800, 71.8793500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75894, 'Vaikam', 'Vaikam', 'Vaikam,Vaikom', 9.7485800, 76.3963700, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75895, 'Vaijāpur', 'Vaijapur', 'Vaijapur,Vaijāpur', 19.9267200, 74.7275000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75896, 'Vāghodia', 'Vaghodia', 'Vaghodia,Vāghodia,Waghoria', 22.3050500, 73.4001600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75897, 'Vadodara', 'Vadodara', 'BDQ,Baroda,Vadodara,Vapadedara,ba luo da,badodala,barodara,fadwdara,radodara,vadeadara,vadodara,vatotara,vu~adodara,wadwdara,wdwdrh,Вaдодaрa,Вадодара,Վադոդարա,فادودارا,وادودارا,واڈوڈارا,ودودره,وڈودرا,बड़ोदरा,वडोदरा,वदोदरा,বড়োদরা,ৱডোদরা,ਵਡੋਦਰਾ,વડોદરા,ବଡ଼ୋଦରା,வடோதரா,వడోదర,ವಡೋದರಾ,വഡോദര,ვადოდარა,ヴァドダラ,ヴァドーダラー,巴罗达,바도다라', 22.2994100, 73.2081200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75898, 'Vadnagar', 'Vadnagar', 'Vadnagar', 23.7859300, 72.6389300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75899, 'Vadlapūdi', 'Vadlapudi', '', 14.3111900, 79.8043000, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75900, 'Vādippatti', 'Vadippatti', 'Vadipatti,Vadippatti', 10.0848100, 77.9611300, 'IN', '2016-06-26', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75901, 'Vadamadurai', 'Vadamadurai', 'Vada-Madura,Vadamadurai', 10.4402600, 78.0999900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75902, 'Vadakku Valliyūr', 'Vadakku Valliyur', '', 8.3809500, 77.6132000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75903, 'Vāda', 'Vada', 'Vada,Vāda', 19.6534700, 73.1481100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75904, 'Ūttukkuli', 'Uttukkuli', 'Uttukkuli,Uttukuli,Ūttukkuli', 11.1689200, 77.4543100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75905, 'Uttiramerūr', 'Uttiramerur', 'Uttaramerur,Uttaramerūr,Uttiramerur,Uttiramerūr', 12.6143300, 79.7574800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75906, 'Uttarkāshi', 'Uttarkashi', 'Barahat,Bārāhāt,Uttarkashi,Uttarkāshi', 30.7298600, 78.4434200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75907, 'Uttamapālaiyam', 'Uttamapalaiyam', 'Uthamapalayam,Uttamapalaiyam', 9.8070100, 77.3271800, 'IN', '2016-06-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75908, 'Utraula', 'Utraula', 'Utraula,Utraulā', 27.3193300, 82.4187200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75909, 'Utrān', 'Utran', 'Utran,Utrān', 21.2333300, 72.8666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75910, 'Usilampatti', 'Usilampatti', 'Usilampatti', 9.9693600, 77.7862100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75911, 'Usehat', 'Usehat', 'Usehat', 27.7979600, 79.2376300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75912, 'Uri', 'Uri', 'Uri', 34.0806400, 74.0508800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75913, 'Uravakonda', 'Uravakonda', 'Uravakonda', 14.9456000, 77.2592800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75914, 'Uran', 'Uran', 'Uran,arn,urana,Уран,ارن,उरण,উরান', 18.8781300, 72.9392400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75915, 'Uppiliyapuram', 'Uppiliyapuram', 'Uppiliapuram,Uppiliyapuram', 11.2631600, 78.5132600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75916, 'Upleta', 'Upleta', 'Upleta', 21.7401500, 70.2825600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75917, 'Uppal Kalan', 'Uppal Kalan', 'Oopal,Pedda Uppal,Upal,Uppal,Uppal Kalan', 17.4057700, 78.5591100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75918, 'Unnāo', 'Unnao', 'Unao,Unnao,Unnāo', 26.5470600, 80.4878100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75919, 'Unjha', 'Unjha', 'Unjha', 23.8036600, 72.3910100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75920, 'Uniāra', 'Uniara', 'Uniara,Uniyara Khurd,Uniyāra Khurd,Uniāra', 26.1533600, 75.2152300, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75921, 'Unhel', 'Unhel', 'Unhel', 23.3379400, 75.5593100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75922, 'Una', 'Una', 'Una', 31.4649300, 76.2691400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75923, 'Una', 'Una', 'Una', 20.8231800, 71.0379500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75924, 'Ūn', 'Un', 'Un,Ūn', 29.5847900, 77.2554000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75925, 'Un', 'Un', 'Un', 23.8874500, 71.7697500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75926, 'Umri', 'Umri', '', 26.5105600, 78.9366700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75927, 'Umreth', 'Umreth', 'Umreth', 22.6988100, 73.1156100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75928, 'Umred', 'Umred', 'Umred,Umrer', 20.8539600, 79.3246600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75929, 'Umrāla', 'Umrala', '', 21.8435300, 71.8030500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75930, 'Umarkot', 'Umarkot', '', 19.6652900, 82.2062900, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75931, 'Umarkhed', 'Umarkhed', 'Umarkhed', 19.6014400, 77.6887800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75932, 'Umaria', 'Umaria', 'Umaria,Umariā', 23.5247300, 80.8371600, 'IN', '2016-07-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75933, 'Umarga', 'Umarga', 'Umarga', 17.8384100, 76.6233100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75934, 'Ullal', 'Ullal', 'Ulaul,Ullai,Ullal,Ullāl', 12.8056900, 74.8605800, 'IN', '2016-06-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75935, 'Ulhasnagar', 'Ulhasnagar', 'Ulasnagar,Ulhasnagar,Ulhāsnagar,Ulkhasnagar,alہasngr,awlasnagr,awlhsngr,ul''hasanagara,ulahasanagara,ulhaseunagaleu,ullasanagara,uruhasunagaru,wu er ha si ne ge er,Уласнагар,Улхаснагар,الھاس نگر ممبئي,الہاسنگر,الہسنگر,اولاسناگر,اولهسنگر,उल्हासनगर,উল্লাসনগর,ਉਲਹਾਸਨਗਰ,ウルハースナガル,烏爾哈斯訥格爾,울하스나가르', 19.2166700, 73.1500000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75936, 'Ukwā', 'Ukwa', 'Ukwa,Ukwā', 21.9710200, 80.4662500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75937, 'Uklāna', 'Uklana', 'Uklana,Uklana Mandi,Uklāna', 29.5112400, 75.8782300, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75938, 'Ujjain', 'Ujjain', 'Uddzhajn,Uddzsain,Uddzsaín,Udzajin,Udzdzain,Udždžain,Ujjain,ajyn,awjayn,awjayyn,awjyn,ujain,ujaina,ujaini,ujjain,ujjaina,ujjayini,ujjeyan,wu du yan na,Удджайн,Уџајин,اجین,اوجائین,اوجاين,اوجین,اوجېن,उज्जैन,উজ্জয়িনী,উজ্জৈন,ਉੱਜੈਨ,ઉજ્જૈન,ଉଜ୍ଜୟିନୀ,உஜ்ஜைன்,ಉಜ್ಜೆಯನ್,ഉജ്ജയിൻ,უჯაინი,ウッジャイン,鄔闍衍那,우자인', 23.1823900, 75.7764300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75939, 'Ujhāni', 'Ujhani', 'Ujhani,Ujhāni', 28.0031100, 79.0082100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75940, 'Ugu', 'Ugu', 'Ugu', 26.7968100, 80.3209300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75941, 'Udumalaippettai', 'Udumalaippettai', 'Udamalpet,Udumalaippettai', 10.5880600, 77.2477900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75942, 'Udpura', 'Udpura', 'Udpura', 24.7335500, 75.9751400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75943, 'Udipi', 'Udipi', 'Udipi,Udupi,udupi,wu du pi,ಉಡುಪಿ,乌杜皮', 13.3346700, 74.7461700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75944, 'Udhampur', 'Udhampur', 'Udhampur,Udkhampur,udamapura,udhamapura,udhamapuram,utampur,wu da mu pu er,Удхампур,ادھم پور,اودہم پور,उधमपुर,उधमपुरम्,उधमपूर,উদমপুর,ਉਧਮਪੁਰ,ઉધમપુર,உதம்பூர்,乌达姆普尔', 32.9243100, 75.1357300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75945, 'Udgīr', 'Udgir', 'Udgir,Udgīr', 18.3925800, 77.1175600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75946, 'Udankudi', 'Udankudi', '', 8.4304800, 78.0288200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75947, 'Udalguri', 'Udalguri', 'Udalguri', 26.7536700, 92.1021500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75948, 'Udaipura', 'Udaipura', 'Udaipura', 23.0743400, 78.5110800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75949, 'Udaipur', 'Udaipur', '', 27.7229700, 75.4717800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75950, 'Udaipur', 'Udaipur', 'Oodeypore,UDR,Udaipur,Udajpur,adے pwr,awdy pwr,udaipuleu,udaipura,udaipuru,udayapur,udayapura,udayapuram,utayappur,wu dai pu,Удайпур,Удајпур,ادے پور,اودہےپور,اودی پور,اودی‌پور,उदयपुर,उदयपुरम्,उदयपूर,উদয়পুর,ਉਦੈਪੁਰ,ઉદયપુર,ଉଦୟପୁର,உதயப்பூர்,ఉదయపూర్,ಉದಯಪುರ,ഉദയ്‌പൂർ,ウダイプル,烏代浦,우다이푸르', 24.5858400, 73.7134600, 'IN', '2016-10-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75951, 'Udaipur', 'Udaipur', 'Udaipur,Udajpur,Удайпур', 23.5333300, 91.4833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75952, 'Udaigiri', 'Udaigiri', 'Ghumusar Udayagiri,Udaigiri,Udayagiri', 20.1234500, 84.3690600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75953, 'Ooty', 'Ooty', 'Ootacamund,Ooty,Udagamandalam,Udagamandalām,Udakamandalam,Udhagai,Udhagamandalam,Utakamand,udagamandalama,udakamandaramu,udhagamandalama,utakai,utakamantalam,Утакаманд,उदगमंदलम,উধগমন্ডলম,உதகமண்டலம்,உதகை,ウダカマンダラム', 11.4134000, 76.6952100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75954, 'Bara Uchāna', 'Bara Uchana', 'Bara Uchana,Bara Uchāna,Uchana,Uchāna', 29.4674700, 76.1779800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75955, 'Turuvekere', 'Turuvekere', 'Turuvekere', 13.1637400, 76.6664100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75956, 'Turaiyūr', 'Turaiyur', 'Turaiyur,Turaiyūr,Turalyur', 11.1498500, 78.5988800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75957, 'Tura', 'Tura', 'Tura', 25.5142100, 90.2023900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75958, 'Tuni', 'Tuni', 'Tuni', 17.3590500, 82.5460700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75959, 'Tūndla', 'Tundla', 'Tundla,Tūndla', 27.2146000, 78.2368300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75960, 'Tumsar', 'Tumsar', 'Tumsar,tmsr,tu mu sa er,tumasara,تمسر,तुमसर,তুমসার,图姆萨尔', 21.3833300, 79.7333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75961, 'Tumkūr', 'Tumkur', 'Tumakooru,Tumakuru,Tumakūru,Tumkur,Tumkūr,tumakuru,ತುಮಕೂರು', 13.3413600, 77.1022000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75962, 'Tulsīpur', 'Tulsipur', 'Tulsipur,Tulsīpur', 27.5337000, 82.4165300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75963, 'Tuljāpur', 'Tuljapur', 'Tuljapur,Tuljāpur', 18.0080400, 76.0701100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75964, 'Tufānganj', 'Tufanganj', 'Tufanganj,Tufānganj', 26.3168800, 89.6654900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75965, 'Tuensang', 'Tuensang', 'Mozungjami,Mozūngjāmi,Tuensang', 26.2670400, 94.8241500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75966, 'Tsrār Sharīf', 'Tsrar Sharif', 'Charar Sharif,Charar-i-Sharif,Cherar-i-Sharif,Tasrar Sharif,Tasrār Sharīf,Tsrar Sharif,Tsrār Sharīf', 33.8631900, 74.7652400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75967, 'Thiruvananthapuram', 'Thiruvananthapuram', 'City of Lord Anantha,Gorad Tkhiruvanantkhapuram,TRV,Thiruvananthapuram,Tiruvananantapuram,Tiruvanantapuram,Tiruvanantapuramas,Trivandrum,te li fan de lang,thyrwfananthabwram,tilubanantapulam,tiru''anantapuram,tirubanantapurama,tiruvanantapuram,tiruvanantapurama,tiruvu~anantapuramu,tribanadrama,tribendrama,trywandrwm,trywwndrwm,Горад Тхіруванантхапурам,Тируванантапурам,טריוונדרום,تریواندروم,تریوینڈرم,تھیروواننتھاپورم,ثيروفانانثابورام,तिरुअनन्तपुरम्,तिरुवनंतपुरम,तिरुवनन्तपुरम,तिरुवनन्तपुरम्,তিরুবনন্তপুরম,ত্রিবানদ্রাম,તિરુવનંતપુરમ્,ତ୍ରିବେନ୍ଦ୍ରମ,திருவனந்தபுரம்,తిరువనంతపురం,ತಿರುವನಂತಪುರಮ್,തിരുവനന്തപുരം,ティルヴァナンタプラム,特里凡得琅,티루바난타푸람', 8.4855000, 76.9492400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75968, 'Trimbak', 'Trimbak', 'Trimbak', 19.9326800, 73.5290700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75969, 'Trichūr', 'Trichur', 'Thrissur,Trichura,tiruccur,trssuർ,Тричура,திருச்சூர்,തൃശ്ശൂർ', 10.5166700, 76.2166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75970, 'Trāl', 'Tral', 'Tral,Trāl', 33.9270800, 75.1158500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75971, 'Toshām', 'Tosham', 'Tosbam,Tosbām,Tosham,Toshām', 28.8699300, 75.9165000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75972, 'Tori-Fatehpur', 'Tori-Fatehpur', 'Tori-Fatehpur', 25.4550500, 79.1142800, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75973, 'Topchānchi', 'Topchanchi', 'Topchanchi,Topchānchi', 23.9038100, 86.1979200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75974, 'Tonk', 'Tonk', 'Tonk,Tonk City', 26.1663800, 75.7882400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75975, 'Tondi', 'Tondi', '', 9.7417300, 79.0177400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75976, 'Tohāna', 'Tohana', 'Tohana,Tohāna', 29.7133200, 75.9044100, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75977, 'Todaraisingh', 'Todaraisingh', 'Toda Raisingh,Toda Rāisingh,Todarasingh', 26.0240100, 75.4818200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75978, 'Todabhim', 'Todabhim', '', 26.9166700, 76.8166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75979, 'Titron', 'Titron', 'Titron', 29.6682400, 77.3239100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75980, 'Titlāgarh', 'Titlagarh', 'Titilagarh,Titlagar,Titlagarh,Titlāgarh', 20.2896100, 83.1523300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75981, 'Titāgarh', 'Titagarh', 'Titagarh,Titāgarh', 22.7425200, 88.3732600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75982, 'Titābar', 'Titabar', '', 26.6014000, 94.2038600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75983, 'Tisaiyanvilai', 'Tisaiyanvilai', '', 8.3324900, 77.8658600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75984, 'Tiruvottiyūr', 'Tiruvottiyur', 'Tiruvattiyur,Tiruvattiyūr,Tiruvottiyur,Tiruvottiyūr', 13.1582300, 80.3018100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75985, 'Thiruvidaimaruthur', 'Thiruvidaimaruthur', 'Tiruvadaimarudur,Tiruvadamarudur,Tiruvadamarudūr,Tiruvidaimardur,Tiruvidaimarudur,Tiruvidaimarudūr', 10.9985700, 79.4522700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75986, 'Cheyyar', 'Cheyyar', 'Cheyyar,Tiruvattiyur,Tiruvattiyūr,Tiruvetipuram,Tiruvettipuram', 12.6605200, 79.5430800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75987, 'Tiruvannāmalai', 'Tiruvannamalai', 'Tirruvannamalai,Tiruvannamalai,Tiruvannamalaj,Tiruvannāmalai,tiruvannamalai,tiruvu~an''namarai,Тируваннамалай,திருவண்ணாமலை,ティルヴァンナーマライ', 12.2266200, 79.0746100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75988, 'Tiruvallur', 'Tiruvallur', 'Thiruvallur,Tiruvallur,Tiruvallūr,Tiruvellore,di lu wa lu er,tharuballura,tiluballuleu,tirubharura,tiruvallur,tiruvallura,tiruvalluru,tiruvu~arruru,tyrwwalwr,Тируваллур,تیرووالور,तिरुवल्लुर,तिरुवळ्ळूरु,তিরুভারুর,থরুবাল্লুর,તિરુવલ્લુર,திருவள்ளூர்,తిరువళ్ళూరు,ティルヴァッルール,蒂鲁瓦卢尔,티루발루르', 13.1437600, 79.9088900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75989, 'Tiruvalla', 'Tiruvalla', 'Thiruvalla,Tiruvalla', 9.3816000, 76.5748900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75990, 'Thiruthani', 'Thiruthani', 'Tirutani,Tiruttani', 13.1759400, 79.6163700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75991, 'Tiruttangal', 'Tiruttangal', '', 9.4833300, 77.8333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75992, 'Tirur', 'Tirur', 'Tirur,Tirur Station,Tirūr,di lu er,tirur,tirura,tyrwr,تیرور,তিরুর,திரூர்,തിരൂർ,蒂鲁尔', 10.9136800, 75.9211800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75993, 'Tiruppuvanam', 'Tiruppuvanam', '', 9.8255600, 78.2579200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75994, 'Tiruppur', 'Tiruppur', 'Tiruppur,Tiruppūr,Tirupur,di lu pu,tiruppur,tiruppura,tiruppuru,tirupura,tyrwpwr,Тируппур,Тирупур,تيروپور,تیروپور,तिरुपुर,तिरुपूर,तिरूपुर,তিরুপ্পুর,திருப்பூர்,ತಿರುಪ್ಪೂರು,തിരുപ്പൂർ,蒂魯普', 11.1154100, 77.3545600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75995, 'Tirupparangunram', 'Tirupparangunram', 'Thiruparangundram,Thirupparankundram,Tiruparankundram,Tirupparangunram,Tirupparankunram', 9.8808500, 78.0725200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75996, 'Tiruppālaikudi', 'Tiruppalaikudi', 'Thiruppalaikudi,Tirupalakudi,Tiruppalaikkudi,Tiruppalaikudi,Tiruppālaikkudi,Tiruppālaikudi', 9.5454800, 78.9177000, 'IN', '2017-03-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75997, 'Tirupati', 'Tirupati', 'TIR,Tirumala - Tirupati,Tirumalai,Tirupati,di lu pa di,tirumala,tirupati,tirupatih,tiruppati,trwpty,tyrwpaty,tyrwpty,Тирупати,Тірупаті,تروپتی,تیروپاتی,تیروپتی,तिरुपति,तिरुपतिः,तिरुपती,तिरुप्पति,তিরুমালা,ତିରୁପତି,திருப்பதி,తిరుపతి,తిరుమల,ತಿರುಪತಿ,蒂鲁帕蒂', 13.6355100, 79.4198900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75998, 'Tirunelveli', 'Tirunelveli', 'Tinnevelli,Tinnevelly,Tinnevelly Junction,Tirunelveli,Tirunelweli,di lu nei er wei li,tilunelbelli,tirunalaveli,tirunelabeli,tirunelaveli,tirunelveli,tiruneruvu~eri,trwnlwyly,tyrwnlfly,tyrwnlwly,tyrwnlwyly,tyrwnylwyly,Тирунелвели,ترونلویلی,تيرونلفلي,تيرونيلويلي,تیرونلولی,تیرونلویلی,तिरुनलवेली,तिरुनॆल्वेलि,तिरुनेल्वेली,तिरूनेलवेली,তিরুনেলবেলি,તિરુનેલવેલી,திருநெல்வேலி,తిరునెల్వేలి,ತಿರುನೆಲ್ವೆಲಿ,തിരുനെൽ‌വേലി,ティルネルヴェーリ,蒂魯內爾維利,티루넬벨리', 8.7251800, 77.6845200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75999, 'Tirumullaivāsal', 'Tirumullaivasal', 'Thirumalavasal,Tirumullaivasal,Tirumullaivāsal', 11.2402500, 79.8380100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76000, 'Tirumala', 'Tirumala', 'Tirumala,Upper Tirupati', 13.6833300, 79.3500000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76001, 'Tirumakūdal Narsipur', 'Tirumakudal Narsipur', 'Tirumakudal Narsipur,Tirumakūdal Narsipur', 12.2120700, 76.9018000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76002, 'Tirukkoyilur', 'Tirukkoyilur', 'Tirukkovilur,Tirukkoyilur,Tirukkoyilūr', 11.9662000, 79.2025900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76003, 'Thirukattupalli', 'Thirukattupalli', 'Tirukattupalli,Tirukkattuppalli,Tirukkāttuppalli', 10.8443100, 78.9564700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76004, 'Tiruchengode', 'Tiruchengode', 'di lu qin ge ao de,tiruccenkotu,tirucengode,تروچینگوڑے,তিরুচেঙ্গোডে,திருச்செங்கோடு,蒂鲁琴格奥德', 11.3801600, 77.8944400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76005, 'Tiruchirappalli', 'Tiruchirappalli', 'TRZ,Tiruccirappalli,Tiruccsirapalli,Tiruccsirápalli,Tiruchchinappalli,Tiruchchināppalli,Tiruchchirappalli,Tiruchchirāppalli,Tiruchi,Tiruchirapali,Tiruchirapalli,Tiruchirappalli,Tiruchirappal·li,Tirucirapali,Tiruĉirapali,Tiruččiráppalli,Trichinapalli,Trichinopoli,Trichinopoly,Trichy,Trinchinopoly,di lu ji la pa li,tiluchilapalli,tiruccirappalli,tiruchiraparri,tirucirapalli,tirutchirapparri,tricimalaidurgam,trwchraply,tyrwchyrapaly,tyrwchyraply,Тиручирапали,Тируччираппалли,Тіручірапаллі,تروچراپلی,تيروچيراپلي,تیروچیراپالی,ٹyrwchyrapaly,ٹیروچیراپالی,ट्रिचिमलैदुर्गम्,तिरुचिरापल्ली,तिरुचिरापळ्ळि,তিরুচিরাপল্লী,திருச்சிராப்பள்ளி,ತಿರುಚ್ಚಿರಾಪ್ಪಳ್ಳಿ,തിരുച്ചിറപ്പള്ളി,ティルチラーパッリ,ティルッチラーッパッリ,蒂魯吉拉帕利,티루치라팔리', 10.8155000, 78.6965100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76006, 'Tiruchchendur', 'Tiruchchendur', 'Tiruchchendur,Tiruchchendūr,Tiruchendur,Tiruchendūr', 8.4972500, 78.1190600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76007, 'Tīrthahalli', 'Tirthahalli', 'Tirthahalli,Tīrthahalli', 13.6883500, 75.2454800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76008, 'Tirodi', 'Tirodi', 'Tirodi', 21.6852200, 79.7190600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76009, 'Tīra Sujānpur', 'Tira Sujanpur', 'Sujanpur,Sujanpur Tira,Sujānpur,Tira Sujanpur,Tīra Sujānpur', 31.8336400, 76.5053900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76010, 'Tiptūr', 'Tiptur', 'Tiptur,Tiptūr', 13.2563000, 76.4776800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76011, 'Tinsukia', 'Tinsukia', 'Tinsukia', 27.4890500, 95.3599200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76012, 'Tinnanūr', 'Tinnanur', 'Thiruninravur,Tinnanur,Tinnanūr', 13.1144800, 80.0271300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76013, 'Tindwāri', 'Tindwari', 'Tindwari,Tindwāri', 25.6173900, 80.5271800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76014, 'Tindivanam', 'Tindivanam', 'Tindivanam,Tindivangam', 12.2340000, 79.6555100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76015, 'Tilhar', 'Tilhar', 'Tilhar', 27.9628200, 79.7382700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76016, 'Tīkri', 'Tikri', 'Tikri,Tīkri', 29.2291000, 77.3547900, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76017, 'Tīkamgarh', 'Tikamgarh', 'Tikamgarh,Tīkamgarh', 24.7432700, 78.8306100, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76018, 'Tikaitnagar', 'Tikaitnagar', '', 26.9461200, 81.5658300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76019, 'Tijāra', 'Tijara', 'Tijara,Tijāra', 27.9341100, 76.8554100, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76020, 'Thoubāl', 'Thoubal', 'Thoubal,Thoubāl', 24.6388100, 93.9963900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76021, 'Thiruvarur', 'Thiruvarur', 'Thiruvarur,Thiruvārūr,Tirnvalur,Tiruvalur,Tiruvarur,Tiruvālūr,di lu wa lu er,thirubarura,tiruvarur,tiruvarura,tiruvaruru,tiruvu~aruru,Тируварур,تھرووارور,तिरुवरुर,तिरुवारूर,तिरुवारूरु,থিরুবারুর,திருவாரூர்,ティルヴァールール,蒂鲁瓦鲁尔', 10.7726900, 79.6368000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76022, 'Thiruvaiyaru', 'Thiruvaiyaru', 'Thiruvaiyaru,Thiruvaiyāru,Tiruvadi,Tiruvādi', 10.8840500, 79.1036200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76023, 'Theog', 'Theog', 'Theog', 31.1215500, 77.3583800, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76024, 'Thenzawl', 'Thenzawl', 'Thenzawl', 23.3166700, 92.7500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76025, 'Thāsra', 'Thasra', '', 22.7983100, 73.2117400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76026, 'Tharād', 'Tharad', 'Tharad,Tharād', 24.3959700, 71.6257700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76027, 'Thanniyam', 'Thanniyam', 'Thanniyam', 10.4166700, 76.1333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76028, 'Thanna Mandi', 'Thanna Mandi', '', 33.5420400, 74.3810000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76029, 'Tanjore', 'Tanjore', 'TJV,Tanjavur,Tanjavûr,Tanjor,Tanjore,Tanjāvūr,Thanjavur,Thanjāvūr,Tkhandzhavur,tancavur,tancavuർ,tanjavura,tanjavuru,Тханджавур,तंजावुर,தஞ்சாவூர்,തഞ്ചാവൂർ,タンジャーヴール', 10.7852300, 79.1390900, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76030, 'Thānesar', 'Thanesar', 'Thanesar,Thānesar', 29.9732300, 76.8321400, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76031, 'Thāne', 'Thane', 'Tanja,Tanna,Thana,Thane,Thāna,Thāne,Таня', 19.1970400, 72.9635500, 'IN', '2016-05-26', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76032, 'Thandla', 'Thandla', 'Thandla,Thāndla', 23.0095900, 74.5774700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76033, 'Thāna Bhawan', 'Thana Bhawan', 'Thana Bhawan,Thāna Bhawan', 29.5860500, 77.4181100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76034, 'Thān', 'Than', 'Than,Thangadh,Thān', 22.5742200, 71.1994200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76035, 'Thākurganj', 'Thakurganj', 'Thakurganj,Thākurganj', 26.4274200, 88.1311200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76036, 'Thakurdwara', 'Thakurdwara', 'Thakurdwara,Thākurdwāra', 29.1920300, 78.8614500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76037, 'Tezu', 'Tezu', 'TEI,Teju,Teju Basha,Teju Bāsha,Tezu', 27.9125600, 96.1288200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76038, 'Tezpur', 'Tezpur', 'Darrang,TEZ,Tezpur,tai ci pu er,tejapura,tyzpwr,Тезпур,تیزپور,तेजपुर,तेजपूर,তেজপুর,তেজপুৰ,ତେଜପୁର,泰兹普尔', 26.6333300, 92.8000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76039, 'Terdāl', 'Terdal', 'Terdal,Terdāl', 16.4937900, 75.0466700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76040, 'Teonthar', 'Teonthar', 'Teonthar', 24.9820700, 81.6419400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76041, 'Thenkasi', 'Thenkasi', 'Tenkasi,Tenkāsi', 8.9600300, 77.3152500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76042, 'Teni', 'Teni', 'Teni,Theni,Tkheni,Тхени', 10.0153100, 77.4820000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76043, 'Tendūkheda', 'Tendukheda', 'Tendukheda,Tendukhera,Tendukhera Sailwara,Tendūkheda', 23.3962000, 79.5394700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76044, 'Tellicherry', 'Tellicherry', 'Talasseri,Tellicherri,Tellicherry,Tellichery,Thalassery,ta la si sai er yi,talacceri,talasseri,thalas''serya,tlshyry,تلشیری,থালস্সের্য,தலச்சேரி,തലശ്ശേരി,塔拉斯塞尔伊', 11.7481100, 75.4929000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76045, 'Telhāra', 'Telhara', 'Telhara,Telhāra', 21.0269400, 76.8388900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76046, 'Tekkali', 'Tekkali', 'Tekkali,tekkali,టెక్కలి', 18.6057000, 84.2354600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76047, 'Tekkalakote', 'Tekkalakote', 'Takkalakote,Tekkalakota,Tekkalakote', 15.5344400, 76.8770300, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76048, 'Tekāri', 'Tekari', 'Tekari,Tekāri', 24.9425300, 84.8426500, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76049, 'Tekanpur', 'Tekanpur', 'Takenpur,Tekanpur', 25.9940100, 78.2832200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76050, 'Tehri', 'Tehri', 'N''ju-Tekhri,N''ju-Tikhri,New Tehri,Tehri,Tehri-Garhwal,Tehri-Garhwāl,Tekhri,na''i tihari,nave tehari,te he li,tehari,tihari,Нью-Техрі,Нью-Тихри,Техри,ٹہری,टिहरी,नई टिहरी,नवे तेहरी,তেহরি,ତେହରି,特赫里', 30.3908600, 78.4803000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76051, 'Teghra', 'Teghra', '', 25.4904300, 85.9400100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76052, 'Tawang', 'Tawang', 'Mon Tawang,Mön Tawang,T''a-wan,Tang Shyo,Tavang,Tawang,Tawang Shyo,Tawang Town,Towang,T’a-wan,da wang zhen,ta''oyam,taraam,tavan nakaram,tavanga,tawanga,tawanj,Таванг,تاوانج,तवांग,টাৱাং,তওয়াং,তাওয়াং,તવાંગ,ତୱାଙ୍ଗ,டவாங் நகரம்,达旺镇', 27.5741700, 91.9243700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76053, 'Tāttayyangārpettai', 'Tattayyangarpettai', '', 11.1233700, 78.4497200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76054, 'Tāsgaon', 'Tasgaon', 'Tasgaon,Tāsgaon', 17.0370000, 74.6017100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76055, 'Tarn Tāran', 'Tarn Taran', 'Tarn Taran,Tarn Tāran', 31.4519100, 74.9277700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76056, 'Tarikere', 'Tarikere', 'Tarikere', 13.7095400, 75.8138200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76057, 'Tārāpur', 'Tarapur', 'Tarapore,Tarapur,Tarapur town,Tārāpur,Tārāpur town', 19.8649900, 72.6842600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76058, 'Tharangambadi', 'Tharangambadi', 'Fort Dansborg,Tarangambadi,Tarangambādi,Tranguebar,Trankebar,Tranquebar,tarankampati,te lan kui ba,tharangamabari,Транкебар,تھرنگامبدی,থারাঙ্গামবাড়ি,தரங்கம்பாடி,特蘭奎巴', 11.0276400, 79.8542500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76059, 'Tārānagar', 'Taranagar', 'Reni,Taranagar,Tārānagar', 28.6686000, 75.0320700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76060, 'Tarāna', 'Tarana', 'Tarana,Tarāna,Тарана', 23.3338300, 76.0425300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76061, 'Tāramangalam', 'Taramangalam', '', 11.6940300, 77.9703500, 'IN', '2017-05-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76062, 'Tarakeswar', 'Tarakeswar', 'Tarakeswar,ta la kai si wa er,tarakesbara,tarakesvara,tarakyshwr,تاراکیشور,তারকেশ্বর,ତାରକେଶ୍ଵର,塔拉凯斯瓦尔', 22.8860500, 88.0136300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76063, 'Tarabha', 'Tarabha', 'Tarabha,Tarbha,Torba', 20.7325200, 83.6744300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76064, 'Tāoru', 'Taoru', 'Taoru,Tāoru', 28.2117300, 76.9498400, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76065, 'Tanuku', 'Tanuku', 'Tanuku,ta nu ku,tanukku,tanuku,tanuku mandala,tnwkw,تنوکو,तणुकु मण्डल,তানুকু,ତାନୁକୁ,தணுக்கு,తణుకు,塔努库', 16.7543800, 81.6814300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76066, 'Tankāra', 'Tankara', 'Tankara,Tankāra', 22.6562200, 70.7494500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76067, 'Tāndūr', 'Tandur', 'Tandur,Tāndūr', 17.2484900, 77.5769800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76068, 'Tānda', 'Tanda', 'Tanda,Tānda', 28.9762100, 78.9418700, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76069, 'Tāndā', 'Tanda', 'Tanda,Tāndā', 26.5495300, 82.6584100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76070, 'Tanakpur', 'Tanakpur', 'Tanakpur', 29.0740000, 80.1113900, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76071, 'Tamlūk', 'Tamluk', 'Tamluk,Tamlūk', 22.3008300, 87.9259300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76072, 'Tambaram', 'Tambaram', 'Tambaram,ta mu ba la mu,tambarama,tamparam,तांबरम,তাম্বারাম,தாம்பரம்,塔姆巴拉姆', 12.9246000, 80.1270700, 'IN', '2017-03-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76073, 'Talwāra', 'Talwara', 'Talwara,Talwāra', 31.9376000, 75.8865700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76074, 'Talwandi Bhai', 'Talwandi Bhai', 'Talwandi Bhai,Talwandi Bhāi', 30.8558400, 74.9297900, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76075, 'Taloda', 'Taloda', '', 21.5612800, 74.2123800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76076, 'Talipparamba', 'Talipparamba', 'Taliparamba,Talipparamba,Tullipurmbu,ta li pa la mu ba,taliparamba,talipparamp,talipparampa,টলিপরম্ব,தளிப்பறம்பா,തളിപ്പറമ്പ്,塔利帕拉姆巴', 12.0416100, 75.3592700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76077, 'Tālīkota', 'Talikota', 'Talikota,Talikoti,Tālīkota', 16.4731100, 76.3108500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76078, 'Tālgrām', 'Talgram', 'Talgram,Tālgrām', 27.0475300, 79.6481100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76079, 'Talen', 'Talen', 'Talen', 23.5694900, 76.7282100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76080, 'Taleigao', 'Taleigao', '', 15.4691500, 73.8328500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76081, 'Talegaon Dābhāde', 'Talegaon Dabhade', 'Dabhade,Talegaon Dabhade,Talegaon Dābhāde,Talegaon-Dabhada', 18.7350200, 73.6756100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76082, 'Tālcher', 'Talcher', 'Talchar,Talcher,Tālcher', 20.9492700, 85.2335400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76083, 'Tālbahat', 'Talbahat', '', 25.0435700, 78.4344100, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76084, 'Talāja', 'Talaja', 'Talaja,Talāja', 21.3527000, 72.0352400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76085, 'Tāl', 'Tal', '', 23.7197900, 75.3851400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76086, 'Tāki', 'Taki', 'Taki,Takoj,Tāki,Такой', 22.5886700, 88.9325300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76087, 'Takhatpur', 'Takhatpur', 'Takhatpur', 22.1291500, 81.8695900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76088, 'Takhatgarh', 'Takhatgarh', 'Takhatgarh', 25.3223500, 73.0048700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76089, 'Tājpur', 'Tajpur', '', 29.1624200, 78.4845800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76090, 'Tādpatri', 'Tadpatri', 'Tadpatri,Tādpatri', 14.9083200, 78.0103100, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76091, 'Tādepallegūdem', 'Tadepallegudem', 'Tadepallegudem,Tadepalligudem,Tādepallegūdem,Tādepalligūdem', 16.8146700, 81.5271700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76092, 'Tādepalle', 'Tadepalle', '', 16.4833300, 80.6000000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76093, 'Swāmimalai', 'Swamimalai', 'Cuvaimalai,Swamimalai,Swāmimalai', 10.9574700, 79.3293100, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76094, 'Susner', 'Susner', 'Susner', 23.9466700, 76.0882500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76095, 'Suriāpet', 'Suriapet', 'Suriapet,Suriāpet,Suryapet', 17.1405400, 79.6204500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76096, 'Suriānwān', 'Surianwan', '', 25.4638700, 82.4192200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76097, 'Surgāna', 'Surgana', 'Surgana,Surgāna', 20.5595600, 73.6374700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76098, 'Surendranagar', 'Surendranagar', 'Civil Station,Surendranagar,Wadhwan,Wadhwan Camp,Wadhwan City,Wadhwan Civil Station,Wadhwān,Wadhwān Civil Station', 22.7270600, 71.6485600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76099, 'Sūratgarh', 'Suratgarh', 'Suratgarh,Suratgarkh,Sūratgarh,Суратгарх', 29.3215000, 73.8997900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76100, 'Sūrat', 'Surat', 'STV,Surat,Suratas,Surate,Sūrat,su la te,surata,surato,Сурат,सुरत,সুরাত,સુરત,スーラト,苏拉特', 21.1959400, 72.8302300, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76101, 'Sūrandai', 'Surandai', 'Surandai,Sūrandai', 8.9757400, 77.4192300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76102, 'Sūrajgarh', 'Surajgarh', 'Surajgarh,Sūrajgarh', 28.3100500, 75.7327100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76103, 'Supaul', 'Supaul', 'Supaul', 26.1150300, 86.5952700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76104, 'Suntikoppa', 'Suntikoppa', 'Suntikoppa', 12.4559400, 75.8297000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76105, 'Sunel', 'Sunel', '', 24.3706500, 75.9570800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76106, 'Sundarnagar', 'Sundarnagar', 'Sundarnagar', 31.5352300, 76.9050000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76107, 'Sundargarh', 'Sundargarh', 'Sundargarh,Sundergarh', 22.1166700, 84.0333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76108, 'Sunām', 'Sunam', 'Sunam,Sunām', 30.1288300, 75.7994300, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76109, 'Sumbal', 'Sumbal', 'Sumbal', 34.2307200, 74.6472000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76110, 'Sulya', 'Sulya', 'Sullia,Sulya,suliya,sulya,sulya taluka,सुळ्य तालुका,সুলিয়া,ಸುಳ್ಯ', 12.5610000, 75.3874100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76111, 'Sūlūru', 'Suluru', 'Sulurpet,Sulurpeta,Suluru,Sūlūrpet,Sūlūru', 13.7000000, 80.0166700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76112, 'Sulur', 'Sulur', 'Sulur,Sūlūr', 11.0242700, 77.1256500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76113, 'Sultanpur', 'Sultanpur', 'Sultanpur,Sultanpur Lodhi,Sultānpur,Sultānpur Lodhi', 31.2146800, 75.1960200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76114, 'Sultānpur', 'Sultanpur', 'Adampur,Sultanpur,Sultānpur,Ādampur', 29.7553400, 78.1103400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76115, 'Sultānpur', 'Sultanpur', 'Sultanpur,Sultānpur', 26.2578800, 82.0726900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76116, 'Sultānpur', 'Sultanpur', 'Sultanpur,Sultānpur', 23.1381200, 77.9340400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76117, 'Suket', 'Suket', 'Suke,Suket,Suket-Kotah', 24.6460900, 76.0417000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76118, 'Sūjāngarh', 'Sujangarh', 'Sujangarh,Sūjāngarh', 27.7000000, 74.4666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76119, 'Suchindram', 'Suchindram', 'Suchindram', 8.1531000, 77.4659600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76120, 'Suār', 'Suar', 'Suar,Suār,Суар', 29.0284100, 79.0565400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76121, 'Srivilliputhur', 'Srivilliputhur', 'si li wei li pu tu er,sribilliputhura,srivilli putturu,tiruvilliputtur,শ্রীবিল্লিপুথুর,ଶ୍ରୀବିଲ୍ଲିପୁଥୁର,திருவில்லிபுத்தூர்,శ్రీవిల్లి పుత్తూరు,斯里维利普图尔', 9.5127200, 77.6336900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76122, 'Srīvardhan', 'Srivardhan', 'Savardhan,Shriwardham,Srivardhan,Srīvardhan', 18.0459200, 73.0155200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76123, 'Srivaikuntam', 'Srivaikuntam', 'Srivaikuntam,Srīvaikuntam', 8.6293100, 77.9128100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76124, 'Srīsailain', 'Srisailain', 'Srisailain,Srisailam,Srīsailain,Srīsailam', 16.0721700, 78.8681600, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76125, 'Srīrāmnagar', 'Sriramnagar', 'Sri Rama Nagar,Sriramnagar,Srīrāmnagar', 17.2665200, 78.2554400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76126, 'Srīperumbūdūr', 'Sriperumbudur', 'Sriperumbubur,Sriperumbudur,Srīperumbūdūr', 12.9676300, 79.9419700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76127, 'Srīnivāspur', 'Srinivaspur', 'Srinivaspur,Srīnivāspur', 13.3391400, 78.2117500, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76128, 'Sringeri', 'Sringeri', 'Shringeri,Sringeri,cirunkeri,si lin ge ai li,sringeri,srngeri,Шрингери,शृंगेरी,शृङ्गेरी,শ্রীঙ্গেরী,சிருங்கேரி,శృంగేరి,ಶೃಂಗೇರಿ,斯林格埃里', 13.4169800, 75.2527100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76129, 'Srinagar', 'Srinagar', 'Caspira,Gorad Srynagar,SXR,Shrinagar,Srinagar,Srinagaras,Srinagaro,Srinankar,Srinigar,Srīnagar,Suryanagar,Szrinagar,cirinakar,seulinagaleu,shurinagaru,si li na jia,sirinagara,siry nagar,srinagar,srinagara,srinagaram,srinagari,srinkhr,sry ngr,srynaghar,sryngr,Śrinagar,Šrinagaras,Šrínagar,Σριναγκάρ,Горад Срынагар,Сринагар,Срінагар,Шринагар,Սրինագար,סרינגאר,جموں,سري نگر,سريناغار,سری نگر,سرینگر,سِری نَگَر,श्रीनगर,श्रीनगरम्,सिरीनगर,শ্রীনগর,ਸ੍ਰੀਨਗਰ,શ્રીનગર,ଶ୍ରୀନଗର,சிறிநகர்,శ్రీనగర్,ಶ್ರೀನಗರ,ശ്രീനഗർ,ศรีนคร,სრინაგარი,シュリーナガル,斯利那加,스리나가르', 34.0856500, 74.8055500, 'IN', '2015-09-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76130, 'Srīnagar', 'Srinagar', 'Shrinagar,Srinagar,Srinagar Garhwal,Srīnagar,Шринагар', 30.2224300, 78.7834100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75765, 'Santon', 'Santon', 'Saint Anne,Santon', 54.1166700, -4.5833300, 'IM', '2015-11-30', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75766, 'Ramsey', 'Ramsey', 'Ramsi,Ramsis,Rhumsaa,Рамси', 54.3227300, -4.3852600, 'IM', '2015-11-24', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75767, 'Port Saint Mary', 'Port Saint Mary', '', 54.0740500, -4.7385800, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75768, 'Port Erin', 'Port Erin', 'Port-Ehrin,Порт-Эрин', 54.0848700, -4.7509900, 'IM', '2015-11-24', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75769, 'Peel', 'Peel', 'Pil,Purt na hInse,Purt ny h-Inshey,Purt ny hInshey,Pylas,Пил', 54.2220900, -4.6909900, 'IM', '2015-11-27', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75770, 'Patrick', 'Patrick', 'Saint Patrick', 54.2044700, -4.6941700, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75771, 'Onchan', 'Onchan', 'Conchan,Kione Droghad,Onkan,Onkanas,Онкан', 54.1732900, -4.4532400, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75772, 'Maughold', 'Maughold', 'Saint Maughold', 54.2987700, -4.3184400, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75773, 'Lezayre', 'Lezayre', 'Lezayre', 54.3166700, -4.4166700, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75774, 'Laxey', 'Laxey', 'Laksaa,Laksi,Лакси', 54.2301700, -4.3998500, 'IM', '2015-11-24', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75775, 'Kirkmichael', 'Kirkmichael', '', 54.2856200, -4.5874800, 'IM', '2015-11-27', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75776, 'Kirk Braddan', 'Kirk Braddan', 'Kirk Braddan,Kirk Braddon,Saint Braddon', 54.1666700, -4.5166700, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75777, 'Jurby', 'Jurby', '', 54.3594100, -4.5219900, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75778, 'Douglas', 'Douglas', 'Daglas,Daglasa,Daglasas,Doolish,Douglas,Douglas pa Isle of Man,Douglas på Isle of Man,Douglas  Isle of Man,Dubh Lios,Duglas,Duqlas,Gorad Duglas,Ntanklas,Port Douglas,dagalasa,daglasa,dagurasu,daklas,dao ge la si,deogeulleoseu,duglasi,dwghlas,dwglas,taklacu,Ντάγκλας,Горад Дуглас,Даглас,Дуглас,Дъглас,דאגלס,دوغلاس,دوگلاس,ڈگلس,डग्लस,ਡਗਲਸ,டக்லசு,ดักลาส,დუგლასი,ダグラス,道格拉斯,더글러스', 54.1500000, -4.4833300, 'IM', '2014-10-30', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75779, 'Crosby', 'Crosby', 'Crosby', 54.1833300, -4.5666700, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75780, 'Castletown', 'Castletown', 'Baile Chaistil,Balley Chashtal,Castletoun,Kasltaun,Kasltaunas,Каслтаун', 54.0744500, -4.6536500, 'IM', '2015-11-24', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75781, 'Bride', 'Bride', '', 54.3825600, -4.3892100, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75782, 'Ballasalla', 'Ballasalla', '', 54.0959000, -4.6296200, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75783, 'Ballabeg', 'Ballabeg', 'Ballabeg', 54.1000000, -4.6833300, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75784, 'Andreas', 'Andreas', 'Andreas', 54.3666700, -4.4333300, 'IM', '2015-11-26', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75785, 'Ballaugh', 'Ballaugh', '', 54.3119300, -4.5445600, 'IM', '2015-11-27', 108);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75629, 'Shelomi', 'Shelomi', 'Chelomi,Shelomi,Shlomi,slwmy,שלומי', 33.0721600, 35.1445200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75630, 'Sederot', 'Sederot', 'Sderot,Sdérot,Sederot,Shederot,sdrwt,Şderot,Сдерот,שדרות', 31.5250000, 34.5969300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75631, 'Savyon', 'Savyon', 'Saviyon,Savyon,sbywn,סביון', 32.0496600, 34.8777000, 'IL', '2012-12-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75632, 'Sakhnīn', 'Sakhnin', 'Sahrin,Sakhnin,Sakhnīn,Saknin,Saknīn,Sikhnin,sh''nyn,sknyn,Сахнин,סח’נין,סכנין', 32.8642200, 35.2970700, 'IL', '2014-10-01', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75633, 'Sājūr', 'Sajur', 'Sajur,Sajūr,Shezor,Sājūr,sg''wr,סג’ור', 32.9426600, 35.3413600, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75634, 'Rosh Pinna', 'Rosh Pinna', 'El Ja`une,El Jā‘ūne,Ja`una,Ja`unah,Ja‘unah,Jā‘ūna,RPN,Rosh Pinah,Rosh Pinna,Rosh Pinnah,ראש פינה,ראש פנה', 32.9689400, 35.5425800, 'IL', '2013-05-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75635, 'Rosh Ha‘Ayin', 'Rosh Ha''Ayin', 'Ras al-`Ayn,Ras al-‘Ayn,Rosh Ha Ayin,Rosh Ha''Ayin,Rosh HaAyin,Rosh Ha‘Ayin,ראש העין', 32.0955600, 34.9566400, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75636, 'Rishon LeẔiyyon', 'Rishon LeZiyyon', 'Ayun Kara,Le Tsiyon,Le Tsīyōn,Richon le Sion,Rischon LeZion,Rishon Le Zion,Rishon LeTsiyyon,Rishon LeZion,Rishon LeZiyyon,Rishon Letsiyon,Rishon LeẔiyyon,Rishon Lsiyon,Rishon le Siyon,Rishon le Ziyon,Rishon-le-Cion,Risjon Letsion,Rison-Le-Ciono,Riszon le-Cijjon,Riŝon-Le-Ciono,`Uyun Qara,rʼswn lzywn,Ришон-ле-Цион,ראשון לציון,‘Uyūn Qāra', 31.9710200, 34.7893900, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75637, 'Rekhasim', 'Rekhasim', 'Rekhasim,rksym,רכסים', 32.7490700, 35.0990100, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75638, 'Reẖovot', 'Rehovot', 'Khirbet Deiran,Khirbet Deirān,Rechovot,Rechowot,Rehobot,Rehovot,Rehovoth,Rejovot,Reẖovot,Rhovot,Ruhaybah,rekhovot,rhwbwt,Реховот,רחובות', 31.8942100, 34.8119900, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75639, 'Ramla', 'Ramla', 'Er Ramle,Ramla,Ramle,Ramlo,alrmlt,la mu la,lameulla,ramla,ramura,rmlh,Рамла,רמלה,الرملة,رمله,رملہ، اسرائیل,ラムラ,拉姆拉,라믈라', 31.9292300, 34.8656300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75640, 'Ramat Yishay', 'Ramat Yishay', 'Jadah,Jeida,Ramat Yishai,Ramat Yishay,rmt ysy,רמת ישי', 32.7044400, 35.1707000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75641, 'Ramat HaSharon', 'Ramat HaSharon', '''Ir Shalom,Ramat Ha-Sharon,Ramat HaSharon,Ramat Hasaronas,Ramat Hash Sharon,Ramat Hasharon,Ramat Hasjaron,Ramat Hašaronas,Ramat ha-Saron,Ramat ha-Szaron,Ramat ha-Xaron,Ramat ha-Šaron,Ramat haScharon,Ramat-kha-Sharon,la ma te sha long,lamateuhasyalon,ramat hasharwn,ramat-hasharoni,rmt hsharwn,rmt hsrwn,Рамат-ха-Шарон,רמת השרון,رامات هاشارون,رمت هشارون,رمت ہشارون,რამათ-ჰაშარონი,‘Ir Shalom,拉马特沙龙,라마트하샤론', 32.1461300, 34.8394000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75642, 'Ramat Gan', 'Ramat Gan', 'Gan,Gorad Ramat-Gan,Ramat Gan,Ramat Ganas,Ramat Nkan,Ramat-Gan,Ramat-Qan,la ma gan,lamateugan,ramat-gani,rmat ghan,rmt ghan,rmt gn,Ραμάτ Γκαν,Горад Рамат-Ган,Рамат Ган,Рамат-Ган,רמת גן,رمات غان,رمت غان,رمت گن,რამათ-განი,ラマト・ガン,拉馬干,라마트간', 32.0822700, 34.8106500, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75643, 'Ra''anana', 'Ra''anana', 'Ra''anana,Ra''ananah,Ra''ananna,Raanana,Ra‘anana,Ra‘ananah,Ra‘ananna,rʻnnh,רעננה', 32.1836000, 34.8738600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75644, 'Qiryat Yam', 'Qiryat Yam', 'Kir''jat-Jam,Kirjat Jam,Kiryat Yam,Kiryat-Yam,Qiryat Yam,qryt ym,qryyt ym,Кирьят-Ям,קריית ים,קרית ים,קרית ימ', 32.8496600, 35.0697300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75645, 'Qiryat Shemona', 'Qiryat Shemona', 'Al Khalisa,El Khalisa,Halasa,Halsa,KSW,Khalasah,Kir''jat-Shmona,Kiryat Shemoneh,Kiryat Shmona,Qiryat Shemona,Qiryat Shemonah,Qiryat Shmona,Shemona Kiryat,qryt smwnh,qryyt smwnh,Кирьят-Шмона,קריית שמונה,קרית שמונה', 33.2073300, 35.5721200, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75646, 'Qiryat Moẕqin', 'Qiryat Mozqin', 'Kir''jat-Mockin,Kiryat Motzkin,Qiryat Motskin,Qiryat Motsqin,Qiryat Motzkin,Qiryat Mozqin,Qiryat Moẕqin,qryt mwzqwn,qryyt mwzqyn,Кирьят-Моцкин,קריית מוצקין,קרית מוצקון', 32.8370600, 35.0776000, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75647, 'Qiryat Gat', 'Qiryat Gat', 'Gat,Kir''jat-Gat,Kirjat Gat,Kiryat Gat,Qastina Alef,Qiryat Gat,qryt gt,qryyt gt,Кирьят-Гат,קריית גת,קרית גת', 31.6099800, 34.7642200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75648, 'Qiryat Bialik', 'Qiryat Bialik', 'Kir''jat-Bjalik,Kiryat Bialik,Qiryat Bialik,Qiryat Bialiq,Qiryat-Beyaliq,qryyt byʼlyq,Кирьят-Бялик,קריית ביאליק,קרית ביאליק', 32.8275000, 35.0858300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75649, 'Qiryat Ata', 'Qiryat Ata', 'Kefar `Atah,Kefar `Atta,Kefar ‘Atah,Kefar ‘Aṭṭa,Kefr Ata,Kir''jat-Ata,Kiryat Ata,Kiryat-Ata,Kufritta,Qiryat Ata,Qiryat Atta,qryyt ʼtʼ,Кирьят-Ата,קריית אתא,קרית אתא', 32.8114900, 35.1132300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75650, 'Qalansuwa', 'Qalansuwa', 'Kalansuva,Qalansuwa,Qalansuwah,Qallansawah,qlnswh,קלנסוה', 32.2849300, 34.9810600, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75651, 'Petaẖ Tiqwa', 'Petah Tiqwa', 'Mulebbis,Petach Tikva,Petah Tikva,Petah Tikwah,Petah Tiqwa,Petaẖ Tikva,Petaẖ Tiqwa,Pethah Tiqva,Pethah Tiqvā,Tigrah,pth tqwh,pth tqwwh,pth tyqwh,pth tyqwwh,פתח תיקוה,פתח תיקווה,פתח תקוה,פתח תקווה', 32.0870700, 34.8874700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75652, 'Pardesiyya', 'Pardesiyya', 'Pardesiya,Pardesiyah,Pardesiyya,prdsyh,prdsyyh,פרדסיה,פרדסייה', 32.3057700, 34.9091100, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75653, 'Or Yehuda', 'Or Yehuda', 'Or Jehuda,Or Yehuda,Or Yehudah,Or Yehudà,Or-Jekhuda,Saqiya,Saqiyyah,Sāqiya,awr yhwda,oleuyehuda,or-iehuda,ʼwr yhwdh,Ор-Йехуда,אור יהודה,أور یهودا,اور یهودا,اور یہودا,ორ-იეჰუდა,オル・イェフダ,오르예후다', 32.0292300, 34.8578800, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75654, 'Ofaqim', 'Ofaqim', 'Ofakim,Ofaqim,Ofiqim,ʼwpqym,אופקים,אפקים', 31.3141000, 34.6202500, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75655, 'Nordiyya', 'Nordiyya', 'Nordiya,Nordiyah,Nordiyya,nwrdyh,נורדיה', 32.3147000, 34.8961700, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75656, 'Netivot', 'Netivot', 'Azata,Azzata,Netivot,Netiwot,nei ti wo te,netivoti,ntybwt,ntyfwt,ntywt,ntywwt,Нетивот,Нетівот,נתיבות,نتيفوت,نتیوت,نتیووت,ნეთივოთი,內提沃特', 31.4230500, 34.5891100, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75657, 'Netanya', 'Netanya', 'Gorad Netanija,Lungsod ng Ntanya,Natania,Natanya,Nathanya,Netan''ja,Netania,Netanija,Netanja,Netanya,Netánja,Ntanya,na ta neiy,nattaniya,nei tan ya,netaniya,netanya,ntanya,ntnyh,Νετάνια,Горад Нетанія,Нетания,Нетанья,Нетаня,Нетанја,נתניה,نتانيا,نتانیا,நத்தானியா,นาตาเนีย,ネタニヤ,内坦亚,네타냐', 32.3329100, 34.8599200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75658, 'Ness Ziona', 'Ness Ziona', 'Nahalat Reuven,Nes Cijjona,Nes Cijona,Nes Ciona,Nes Siyona,Nes Tiona,Nes Tsiyona,Nes Tsiyonah,Nes Tziyona,Nes Ziona,Nes Ziyona,Nes Ziyyona,Nes Ționa,Nes Ẕiyyona,Nes-Ciona,Ness Siona,Ness Tziona,Ness Ziona,Neys-Siyona,Noss Ziona,Nēs Tsīyōnā,Nēs Zīyōnā,Wadi Hunayn,Wadi Hunein,Wady Hanin,Wādi Hunein,nai si ci ao na,ns zywna,ns zywnh,nys dywna,nys zywna,Нес-Циона,נס ציונה,نس زیونا,نيس زيونا,نیس ضیونا,耐斯茨奧納', 31.9293300, 34.7986800, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75659, 'Nesher', 'Nesher', 'Neixer,Nescher,Neser,Neseras,Nesher,Neszer,Nešer,Nešeras,nei xie er,nsr,nyshr,nyshyr,Нешер,נשר,نيشير,نیشر,内谢尔', 32.7662200, 35.0442500, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75660, 'Nein', 'Nein', 'Na`im,Nayn,Na‘im,Neim,Nein,nyn,נין,נעים', 32.6306300, 35.3488500, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75661, 'Neẖalim', 'Nehalim', 'Nehalim,Neẖalim,nhlym,נחלים', 32.0601200, 34.9106900, 'IL', '2012-12-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75662, 'Nazareth', 'Nazareth', 'En Nasira,En Nāsira,Lungsod ng Nazaret,Naatsaret,Nasaret,Nasira,Nasıra,Natserat,Natseret,Natsrat,Natséret,Natzaret,Nazara,Nazare,Nazaret,Nazaretas,Nazareth,Nazareto,Nazaré,Nazerat,Nazzerat,Naẕerat,Naẕẕerat,Nātsrat,alnasrt,na sa lei,nacarettu,nasales,nasrt,nazare,nsrt,nzrt,Ναζαρέτ,Назарет,נצרת,الناصرة,ناصرة,ܢܨܪܬ,நாசரேத்து,ナザレ,拿撒勒,나사렛', 32.6992500, 35.3048300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75663, 'Naḥf', 'Nahf', 'Nahaf,Nahef,Nahf,Naḥf,Naẖef,Naẖf,nhp,נחף', 32.9344400, 35.3167900, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75664, 'Nahariya', 'Nahariya', 'Nagarija,Naharia,Nahariia,Naharija,Naharijja,Nahariya,Nahariyah,Nahariyya,Nakharija,na ha li ya,naharia,nahariya,nharya,nhryh,Нагария,Нагарія,Нахария,Нахарија,נהריה,نهاريا,نهاریا,نہاریا,ნაჰარია,‏nhryh,‏נהריה,ナハリヤ,納哈里亞', 33.0113500, 35.0946700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75665, 'Mitzpe Ramon', 'Mitzpe Ramon', 'MIP,Mahane Ramon,Maḥane Ramon,Mitspe Ramon,Mitze Ramon,Mitzpe Ramon,Mizpe Ramon,Miẕpe Ramon', 30.6094400, 34.8011100, 'IL', '2013-05-09', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75666, 'Mi‘ilyā', 'Mi`ilya', 'Maaliya,Me`elya,Me‘elyā,Mi''elya,Mi''ilya,Mi`ilya,Mi‘ilyā,Mi’elya,Mi’ilyā,מעליא', 33.0278100, 35.2565800, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75667, 'Migdal Ha‘Emeq', 'Migdal Ha`Emeq', 'Magidal,Migdal Ha''Emek,Migdal Ha''Emeq,Migdal HaEmek,Migdal HaEmeq,Migdal Haemeqck,Migdal Hameq,Migdal Ha‘Emek,Migdal Ha‘Emeq,Migdal'' KhaEhmek,mgdl hʻmq,Мигдаль ХаЭмек,מגדל העמק', 32.6759700, 35.2398600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75668, 'Mevasseret Ẕiyyon', 'Mevasseret Ziyyon', 'Ma''oz Tsiyon,Ma’oz Tsiyon,Mevaseret Zion,Mevasseret Ziyyon,Mevasseret Ẕiyyon,MevasseretTsiyyon,mbsrt zywn,מבשרת ציון', 31.8018600, 35.1507200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75669, 'Metulla', 'Metulla', 'El Mutille,Metula,Metulah,Metulla,Metullah,Mitulla,mtlh,Метула,מטלה', 33.2791800, 35.5795000, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75670, 'Mazkeret Batya', 'Mazkeret Batya', '''Eqron,Ekron,Mazkeret Batya,Mazkeret Batyah,mzkrt btyh,מזכרת בתיה,‘Eqrōn', 31.8535700, 34.8464600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75671, 'Maghār', 'Maghar', 'El Mansura,Ma`ariyah,Maghar,Maghār,Ma‘ariyah,Mughar,מע’ר', 32.8898400, 35.4070300, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75672, 'Lod', 'Lod', 'Lida,Lidd,Lod,Lodas,Lont,Lud,Ludd,Lydda,Lūd,alld,lad,ld,lodeu,lodi,lu de,ludd,lwd,rodo,Λοντ,Лод,לד,לוד,اللد,لاد,لد,ലുദ്ദ്,ლოდი,ロード,卢德,로드', 31.9467000, 34.8903000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75673, 'Kefar Yona', 'Kefar Yona', 'Kefar Yona,Kefar Yonah,Kfar Yona,kpr ywnh,כפר יונה', 32.3166900, 34.9350700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75674, 'Kefar Tavor', 'Kefar Tavor', 'Kefar Tabor,Kefar Tavor,Kfar Tavor,Mas-ha,Mashah,kpr tbwr,כפר תבור', 32.6865500, 35.4211800, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75675, 'Kefar Shemaryahu', 'Kefar Shemaryahu', 'Kefar Shemaryahu,Kefar Shmaryahu,Kesar Shenaryahu,kpr smryhw,כפר שמריהו', 32.1852900, 34.8208200, 'IL', '2012-12-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75676, 'Kfar Saba', 'Kfar Saba', 'Kafr Saba,Kefar Saba,Kefar Sava,Kefar Sawa,Kefar-Sava,Kefár Saba,Kfar Saba,Kfar Sava,Kfar-Sava,ka fa sa ba,kfar saba,kfr sba,Кефар-Сава,Кфар Сава,Кфар-Сава,כפר סבא,كفار سابا,کفار سابا,کفر سبا,卡法薩巴', 32.1750000, 34.9069400, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75677, 'Kefar Rosh HaNiqra', 'Kefar Rosh HaNiqra', 'Kefar Rosh HaNiqra,Kfar Ras en Naqoura,Ras an-Naqurah,Ro''sh HaNikra,Rosh Haniqra,Rosh Haniqrah,Rosh-Khanikra,Ro’sh HaNikra,Sulam Tsor,Рош-Ханикра,כפר ראש הנקרה', 33.0860700, 35.1134800, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75678, 'Kefar H̱abad', 'Kefar Habad', 'Kefar Habad,Kefar Habbad,Kefar H̱abad,Kefar H̱abbad,Kfar Habad,kpr hb''''d,כפר חב’’ד', 31.9879300, 34.8516000, 'IL', '2015-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75679, 'Kaukab Abū el Hījā', 'Kaukab Abu el Hija', 'Kaukab,Kaukab Abu el Hija,Kaukab Abū el Hīja,Kaukab Abū el Hījā,Kawkab,Kawkab Abu el Hija,Kawkab Abu-al-Hij,Kawkab Abū el Hījā,Kokhva,כוכב אנו אל היג’א', 32.8315500, 35.2484800, 'IL', '2014-10-01', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75680, 'Karmi’el', 'Karmi''el', 'Carmiel,Karmi''el,Karmiehl'',Karmiel,Karmi’el,Qiryat Karmiel,krmyʼl,Кармиэль,כרמיאל', 32.9170800, 35.3050100, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75681, 'Kafir Yasif', 'Kafir Yasif', 'Kafir Yasif,Kafr Yasif,Kafr Yāsīf,Kefar-Yasif,Kfar Yasif,kpr ysyp,כפר יסיף', 32.9545100, 35.1623000, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75682, 'Kafr Qāsim', 'Kafr Qasim', 'Kafar Qasem,Kafar Qāsem,Kafer-Kassim,Kafr Qasim,Kafr Qāsim,Kasim,Kefar Qesem,Kufr Qasim,Kufr Qāsim,kpr qsm,כפר קסם', 32.1140600, 34.9762400, 'IL', '2012-12-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75683, 'Kafr Miṣr', 'Kafr Misr', 'Kafr Masr,Kafr Misr,Kafr Miṣr,kpr mzr,כפר מצר', 32.6452100, 35.4214700, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75684, 'Kafr Mandā', 'Kafr Manda', 'Kafar Manda,Kafer-Manda,Kafr Manda,Kafr Mandā,Kefar Mandi,כפר מנדא', 32.8103400, 35.2600900, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75685, 'Kafr Kannā', 'Kafr Kanna', 'Kafr Kanna,Kafr Kannā,Kafr Qanah,כפר כנא', 32.7466000, 35.3424200, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75686, 'Kafr Kammā', 'Kafr Kamma', 'Kafar Kama,Kafer-Kama,Kafr Kama,Kafr Kamma,Kafr Kammā,Kafr Kamā,Kafr Qamah,כפר כמא', 32.7212900, 35.4412200, 'IL', '2015-01-07', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75687, 'Kābūl', 'Kabul', 'Kabul,Kavul,Kābūl,kbwl,כבול', 32.8685600, 35.2117100, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75688, 'Judeida Makr', 'Judeida Makr', 'Al Judeida,Judaydah,Judeida,Judeida Makr,g''dydh mkr,ג’דידה מכר', 32.9282000, 35.1570500, 'IL', '2014-10-01', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75689, 'Jīsh', 'Jish', 'Giscala,Gishala,Gush Halab,Gush Halav,Gush H̱alav,Gush Ḥalav,Gush-Halaw,Habth,Jish,Jīsh,g''ys,ג’יש', 33.0221600, 35.4469400, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75690, 'Jaljūlya', 'Jaljulya', 'Gilgal,Gilgāl,Jaljuliya,Jaljulya,Jaljulyah,Jaljulye,Jaljūliya,Jaljūlya,Jaljūlye,Jiljulieh,g''lg''wlyh,glgl,גלגל,ג’לג’וליה', 32.1547000, 34.9537200, 'IL', '2012-12-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75691, 'Iksāl', 'Iksal', 'Iksal,Iksāl,Kessulot,Kesulot,Kislot Tavor,kslwt tbwr,אכסל,כסלות תבור', 32.6816400, 35.3236500, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75692, 'Ibṭīn', 'Ibtin', 'Beten,Ibtin,Ibṭin,Ibṭīn,אבטין', 32.7615000, 35.1140200, 'IL', '2015-02-07', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75693, 'Ḥurfeish', 'Hurfeish', 'Hourfeich,Hurfaysh,Hurfeish,H̱urfeish,hrpys,חרפיש,Ḥurfeish', 33.0171100, 35.3483500, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75694, 'H̱olon', 'Holon', 'Cholon,Holon,H̱olon,Jolon,Jolón,Kholon,hwlwn,Холон,חולון,حولون', 32.0103400, 34.7791800, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75695, 'Hod HaSharon', 'Hod HaSharon', 'God-ga-Sharon,Hada Ramatayim,Hadar Ramataim,Hadar Ramatayim,Hod HaSaron,Hod HaSharon,Hod Hasharon,Hod Hasjaron,Hod HaŞaron,Hod HaȘaron,Hod ha-Saron,Hod ha-Szaron,Hod ha-Šaron,Hod haScharon,Khod Khasharon,Khod-kha-Sharon,Ramatayim,huo de xia sha long,hwd hsharwn,hwd hsrwn,Год-га-Шарон,Ход Хашарон,Ход-ха-Шарон,הוד השרון,חוד השרון,هود هشارون,ہود ہشارون,霍德夏沙隆', 32.1593400, 34.8932000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75696, 'Herzliya', 'Herzliya', 'Gerclija,Herclijja,Herseliya,Hertseliyya,Hertsliyah,Hertsliyya,Hervlia,Hervlia B,Herzlia,Herzlia B,Herzliya,Herzliyah,Herzliyya,Herẕliyya,Lungsod ng Herzliyya,Lungsod ng Herẕliyya,hrzlyh,hrzlyyh,Герцлия,הרצליה,הרצלייה', 32.1662700, 34.8253600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75697, 'Haifa', 'Haifa', 'Aifa,Caiffa,Chaifa,Gorad Khajfa,HFA,Haifa,Hajfa,Hajfo,Hayfa,Haífa,Haïfa,Hefa,Heifa,Heifā,Hepha,Heyfa,H̱efa,Khajfa,Khajfae,Lungsod ng Hefa,Lungsod ng Ḥefa,ha''ipha,hai fa,haifa,haipa,haipha,hifa,hph,hyfa,hyph,kaihpa,khaipa,Ĥajfo,Χάιφα,Горад Хайфа,Хайфæ,Хайфа,Хајфа,Հայֆա,חיפה,חפה,حيفا,حیفا,حەیفا,ܚܝܦܐ,हाइफा,हैफ़ा,हैफा,கைஃபா,ಹೈಫ,ഹൈഫ,ไฮฟา,ხაიფა,Ḥeyfa,ハイファ,海法,하이파', 32.8184100, 34.9885000, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75698, 'Hadera', 'Hadera', 'Chadera,El Khudeira,Hadera,Haderah,Hadeyra,Hedora,Hudeira,H̱adera,Khadera,Khederah,hdrh,Хадера,חדרה', 32.4419200, 34.9039000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75699, 'Giv''at Shmuel', 'Giv''at Shmuel', 'Giv''at Shemu''el,Giv''at Shemuel,Giv''at Shmu''el,Giv''at Shmuel,Givat Shmu''el,Givat Shmu’el,Giv‘at Shemuel,Giv‘at Shemu’el,Giv‘at Shmuel,Giv‘at Shmu’el,gbʻt smwʼl,gybʻt smwʼl,גבעת שמואל,גיבעת שמואל', 32.0781700, 34.8485800, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75700, 'Givatayim', 'Givatayim', 'Gevataym,Giv''atayim,Givaatayim,Givataim,Giv‘atayim,gbʻtym,gbʻtyym,gybʻtyym,Гиватаим,גבעתיים,גבעתים,גיבעתיים', 32.0722500, 34.8125300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75701, 'Gedera', 'Gedera', 'Gedera,Gederah,Guedera,Guederà,gai dai la,gdra,gdrh,gedela,ghdyra,Гедера,גדרה,غديرا,گدرا,盖代拉,게데라', 31.8145600, 34.7799800, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75702, 'Gan Yavne', 'Gan Yavne', 'Gan Yavne,Gan Yavneh,gn ybnh,גן יבנה', 31.7873700, 34.7065900, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75703, 'Ganei Tikva', 'Ganei Tikva', 'Gane Tikva,Gane Tiqwa,Ganei Tikva,Ganne Tikva,Ganne Tiqwa,Ganné Tikva,Ganné Tiqwa,Gané Tiqwa,gny tqwh,gny tqwwh,gny tyqwwh,גני תיקווה,גני תקוה,גני תקווה', 32.0597100, 34.8732000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75704, 'Pasuta', 'Pasuta', 'Fassuta,Fassutah,Fassūṭā,Mafshatah,Mifshata,Pasuta,mpsth,pswth,מפשטה,פסוטה', 33.0489500, 35.3089300, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75705, 'Even Yehuda', 'Even Yehuda', 'Even Yahuda,Even Yehuda,Even Yehudah,ʼbn yhwdh,אבן יהודה', 32.2695900, 34.8875900, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75706, 'Tirah', 'Tirah', 'At Tira,Et Tira,Et Tire,Eṭ Ṭīra,Tira,Tirah,Tīra,א טירה', 32.2341000, 34.9502300, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75707, 'Eṭ Ṭaiyiba', 'Et Taiyiba', 'At Taiyiba,E-Tayibe,El Taiyiba,Et Taiyiba,Et Taiyibe,Et Tayyibeh,Eṭ Ṭaiyiba,Taibe,Taiyba,Taiyiba,Taiyibah,Taiyibe,Taiyibi,Taybah,Tayibe,Tayibeh,Tiva,Tīvā,א טיבה,Ṭaiyibe,Ṭayibe', 32.2661600, 35.0089300, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75708, 'Esh Sheikh Dannūn', 'Esh Sheikh Dannun', 'Dannun,Danun,Esh Sheikh Dannun,Esh Sheikh Dannūn,Esh Sheikh Daud,Esh Sheikh Dawud,Esh Sheikh Dāwūd,Esh Sheikh Dāūd,Shaykh Daud,Shaykh Dawud,Sheikh Danmov,Sheikh Dannun,Sheikh Dannūn,Sheikh Daud,Sheikh Dawud,Sheikh Dāwūd,ʼ syh'' dʼwd,א שיח’ דאוד,א שיח’ דנון', 32.9941000, 35.1480500, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75709, 'Er Reina', 'Er Reina', 'Ar Reina,Er Reina,Raynah,Reina,א רינה', 32.7233900, 35.3162200, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75710, '‘En Boqeq', '`En Boqeq', 'Ehjn-Bokek,En Bokek,EnBokeko,`En Boqeq,Эйн-Бокек,עין בוקק,‘En Boqeq', 31.1994100, 35.3625300, 'IL', '2012-08-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75711, 'Elyakhin', 'Elyakhin', 'Elyakhin,Khirbat Zalafa,Ma''abara Merkazit Emeq Hefer,Ma’abara Merkazit Emeq H̱efer,אליכין', 32.4079300, 34.9243300, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75712, 'El Mazra‘a', 'El Mazra`a', 'Al Mazra`a,Al Mazra‘a,El Mazra''a,El Mazra`a,El Mazra‘a,El Mazra’a,El Mezra,Mazra`a,Mazra`ah,Mazra‘a,Mazra‘ah,אל מזרעה', 32.9833800, 35.0983700, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75713, 'El Fureidīs', 'El Fureidis', 'Al Fureidis,El Fureidis,El Fureidīs,Freidis,Furaydis,Fureidis,Fureidīs,אל פרידיס', 32.5981200, 34.9515300, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75714, 'Eilat', 'Eilat', 'ETH,Ehjlat,Eilat,Ejlat,Ejlato,Elat,Elata,Elatas,Elath,Etzion Geber,Gorad Ehjlat,Lungsod ng Elat,Umm Rashrash,Umm Rashrāsh,Umrashash,ai la te,am alrshrash,aylat,eilati,eillateu,eirato,elat,ilata,Éilat,ʼylt,Εϊλάτ,Горад Эйлат,Еилат,Ейлат,Эйлат,Էյլաթ,אילת,أم الرشراش,إيلات,ایلات,ইলাত,ஏலாத்,ეილათი,エイラート,埃拉特,에일라트', 29.5580500, 34.9482100, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75715, '‘Eilabun', '`Eilabun', '`Ailabun,`Aylabun,`Eilabun,`Elabun,עילבון,‘Ailabun,‘Aylabun,‘Eilabun,‘Eilabūn,‘Elabun', 32.8369300, 35.4002900, 'IL', '2014-10-01', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75716, 'Dimona', 'Dimona', 'Dimona,Dimóna,Domona,di mo na,dimona,dymwna,dymwnh,Димона,Дімона,דימונה,ديمونا,دیمونا,دیمونہ,დიმონა,ディモナ,迪莫納,디모나', 31.0707900, 35.0326900, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75717, 'Deir Ḥannā', 'Deir Hanna', 'Dayr Hannah,Deir Hanna,Deir H̱anna,Deir Ḥannā,Kefar Yohanah,דיר חנא', 32.8619600, 35.3636500, 'IL', '2015-09-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75718, 'Daliyat al Karmel', 'Daliyat al Karmel', 'Carmel City,Daliat al karmel,Daliyah,Daliyat ad-Druz,Daliyat al Karmel,Daliyat al-Karmil,Daliyat at Karmil,Daliyat el Karmil,Dalyat el Karmel,Dāliyat el Karmil,Karmel'',dlyt ʼl krml,dlyyt ʼl krml,Кармель,דליית אל כרמל,דלית אל כרמל', 32.6938300, 35.0468600, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75719, 'Dabbūrīya', 'Dabburiya', 'Dabburiya,Dabburiyah,Dabburye,Dabbūrīya,Daburiyah,dbwryh,דבוריה', 32.6925600, 35.3712300, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75720, 'Buqei‘a', 'Buqei`a', 'Al Buqei`a,Al Buqei‘a,Beqe`ah,Beqe‘ah,Bukei''a,Bukei’a,Buqay`ah,Buqay‘ah,Buqei`a,Buqei‘a,El Bukeiah,El Buqei`a,El Buqei‘a,Peqi`in,Peqi‘in,pqyʻyn,בקיעה,פקיעין', 32.9774700, 35.3334500, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75721, 'Bu‘eina', 'Bu`eina', 'Bu`aynah,Bu`eina,Bu`eine,Bu‘aynah,Bu‘eina,Bu‘eine,בעינה', 32.8063600, 35.3648600, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75722, 'Bīr el Maksūr', 'Bir el Maksur', 'Bir el Maksur,Bīr el Maksūr,ביר אל מכסור', 32.7773200, 35.2206900, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75723, 'Bet Yiẕẖaq', 'Bet Yizhaq', 'Beit Yits-haq,Beit Yits-ḥaq,Beit Yitzak,Bet Yitshak,Bet Yitsẖak,Bet Yizhaq,Bet Yiẕẖaq,byt yzhq,בית יצחק', 32.3275100, 34.8887800, 'IL', '2012-01-18', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75724, 'Bet Shemesh', 'Bet Shemesh', 'Beit Semes,Beit Şemeș,Beit-Shemesh,Bejt-Shemesh,Bet Schemesch,Bet Shemesh,Betxemeix,Betxèmeix,Maabarat Hartuv,byt sms,Бейт-Шемеш,בית שמש', 31.7307200, 34.9929300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75725, 'Bet She’an', 'Bet She''an', 'Beisan,Beisān,Beit She''an,Beit Shean,Beit-Shean,Beith Shean,Beith Sheān,Bejt-Shean,Besan,Bet Sche''an,Bet Sche’an,Bet She''an,Bet Shean,Bet She’an,Bet Sze''an,Bet Sze’an,Bete-Sea,Bete-Seã,Beth Shan,Beth Shean,Beït Shéan,Beït-Shéan,Scythopolis,Skythopolis,bysan,byt sʼn,Бейт-Шеан,בית שאן,بيسان', 32.4972800, 35.4963200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75726, 'Bet Dagan', 'Bet Dagan', 'Bayt Dajan,Beit Dagon,Beit Dajan,Bet Dagan,bt dgn,byt dgn,בית דגן,בת דגן', 32.0019100, 34.8297700, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75727, 'Bnei Brak', 'Bnei Brak', 'Benai Beraq,Bene Berak,Bene Beraq,Benei Beraq,Beney Beraq,Bené Berak,Bené Beraq,Bne Beraq,Bnei Brak,Bné Beraq,bny brq,בני ברק', 32.0807400, 34.8338000, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75728, 'Bnei Ayish', 'Bnei Ayish', 'Bnei Ayish,Nahal Soreq,Naẖal Soreq,bny ʻy"s,bny ʻys,bny ʻyys,בני עי"ש,בני עייש,בני עיש', 31.7833300, 34.7500000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75729, 'Beit Jann', 'Beit Jann', 'Bayt Jann,Beit Jan,Beit Jann,Bet Dagan,byt g''n,בית ג’ן', 32.9646400, 35.3815200, 'IL', '2014-07-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75730, 'Beersheba', 'Beersheba', 'B''er Sheva'',B''eyr-Sheva'',BEV,Be''er Scheva,Be''er Sheva,Be''er Sheva`,Beehr-Sheva,Beer Scheva,Beer Seba,Beer Seva,Beer Sheba,Beer Sheva,Beer Sjeva,Beer Szewa,Beer Ŝeba,Beer Ševa,Beer Șeva,Beer-Seva,Beer-Sheva,Beer-Xeva,Beer-Şeva,Beerseba,Beerseva,Beersheba,Beerxeba,Beerşeba,Beerševa,Ber Seva,Bersabee,Bersabée,Berseba,Bersebá,Bersheva,Bersyeba,Berséba,Beér-Seva,Beër Sjeva,Beėršėva,Be’er Scheva,Bir el Saba,Bir es Sab`,Bir es Sabe,Birsheba,B’er Sheva‘,beer-sheva,beerusheba,bei er xie ba,beiyr chi ba,beleusyeba,bʼr sbʻ,pircepa,Μπερ Σεβά,Беер Шева,Беер-Шева,Бершева,Беэр-Шева,Биршеба,Բեեր Շևա,באר שבע,بئر السبع,بئرشبع,பீர்சேபா,เบียร์ชีบา,ბეერ-შევა,ቤርሳቤ,ベエルシェバ,贝尔谢巴,베르셰바', 31.2518100, 34.7913000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75731, 'Bat Yam', 'Bat Yam', 'Bat Jam,Bat Jamas,Bat Yam,Bat-Jam,ba te ya mu,bat yam,bat-iami,bateuyam,bt yam,bt ym,Бат Јам,Бат Ям,Бат-Ям,בת ים,بات يام,بات یام,بت یام,ბათ-იამი,バト・ヤム,巴特亚姆,바트얌', 32.0237900, 34.7518500, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75732, 'Basmat Ṭab‘ūn', 'Basmat Tab`un', 'Basmat Tab''un,Basmat Tab`un,Basmat Tab‘un,Basmat Ṭab‘ūn,Bismat Taba''un,Bismat Taba’un,Bosmat Tivon,בסמת טבעון', 32.7389800, 35.1571600, 'IL', '2015-02-07', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75733, 'Azor', 'Azor', 'Azor,Azur,Yazir,Yazor,Yazur,Yāzūr,ʼzwr,אזור', 32.0243000, 34.8063200, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75734, '‘Atlit', '`Atlit', 'Atlit,`Athlit,`Athlith,`Atlit,עתלית,‘Athlīt,‘Athlīth,‘Atlit', 32.6888900, 34.9423600, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75735, 'Ashqelon', 'Ashqelon', 'Al Majdal,Ashkelon,Ashqelon,Ashquelon,El Majdal,El Medjdel,Majdal,Majdal `Asqalan,Majdal ‘Asqalān,Migdal Ascalon,Migdal Ashqelon,Migdal Gad,ʼsqlwn,Ашкелон,אשקלון', 31.6692600, 34.5714900, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75736, 'Ashdod', 'Ashdod', 'Aschdod,Asdod,Asdodas,Asdode,Asdód,Ashdod,Ashdod Yam,Ashdod on the Sea,Asjdod,Asntont,Asot,Aszdod,Axdod,Azotus,Aŝdod,Aşdod,Ašdod,Ašdodas,Așdod,Ukreir,a shen du de,asdead,ashdodi,ashdwd,ashudoddo,astotu,asyudodeu,ʼsdwd,Ασντόντ,Ашдод,Աշդոդ,אשדוד,أشدود,اشدود,அஸ்தோது,അഷ്ദോദ്,აშდოდი,アシュドッド,阿什杜德,아슈도드', 31.7921300, 34.6496600, 'IL', '2017-07-05', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75737, 'Arad', 'Arad', 'Arad,ʻrd,ʼrd,Арад,ארד,ערד', 31.2588200, 35.2128200, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75738, 'Acre', 'Acre', '''Akko,Accho,Acre,Acri,Akka,Akkia,Akko,Akkon,Akra,Akre,Akrsborg,Ptolemais,Saint Jean d''Acre,Saint Jean d’Acre,San Giovanni d''Acri,`Akka,a ka,akko,ʻkw,Άκρα,Акко,עכו,عكا,‘Akka,‘Akko,アッコ,阿卡', 32.9281400, 35.0764700, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75739, 'Afula', 'Afula', '''Afula,Affula,Afula,Afule,Afuli,El ''Affule,El ‘Affūle,ʻpwlh,עפולה,‘Afula', 32.6090700, 35.2892000, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75740, 'Abū Ghaush', 'Abu Ghaush', 'Abu Ghaush,Abu Ghosh,Abu-Ghawsh,Abū Ghaush,Abū Ghōsh,Kuryet el Enab,Qaryat al `Inab,Qaryat al ‘Inab,Qaryat el `Inab,Qaryat el ‘Inab,Qaryet el `Inab,Qaryet el ‘Inab,`Inab,ʼbw gws,אבו גוש,אבו ע’וש,‘Inab', 31.8059200, 35.1093000, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75741, 'Shibli', 'Shibli', 'Shibli,sbly,שבלי', 32.6946400, 35.3925200, 'IL', '2012-01-19', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75742, 'Rumat Heib', 'Rumat Heib', 'Rumat Heib,Rūmat Heib,rwmt hyb,רומת היב', 32.7780200, 35.3057100, 'IL', '2012-05-06', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75743, 'Sallama', 'Sallama', 'Sallama,slmh,סלמה', 32.8944300, 35.3693100, 'IL', '2012-01-19', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75744, 'Kefar Weradim', 'Kefar Weradim', 'Kefar Veradim,Kefar Weradim,Kfar Vradim,kpr wrdym,כפר ורדים', 32.9938500, 35.2779300, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75745, 'Lehavim', 'Lehavim', 'Lehavim,lhbym,להבים', 31.3728400, 34.8161900, 'IL', '2017-07-02', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75746, 'Midreshet Ben-Gurion', 'Midreshet Ben-Gurion', '', 30.8515400, 34.7834000, 'IL', '2009-01-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75747, 'Cesarea', 'Cesarea', 'Caesarea,Kaysaria,Keisarya,Kesarija,Qesarya,Кесария', 32.5188800, 34.9045900, 'IL', '2017-04-23', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75748, 'West Jerusalem', 'West Jerusalem', 'Jerusalem West,Vaestra Jerusalem,Vest-Jerusalem,Vestjerusalem,Västra Jerusalem,West Jerusalem,Westjerusalem,מערב ירושלים', 31.7819900, 35.2196100, 'IL', '2012-03-01', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75749, 'Modiin Ilit', 'Modiin Ilit', 'מודיעין עילית', 31.9322100, 35.0441600, 'IL', '2017-07-04', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75750, 'Nof Ayalon', 'Nof Ayalon', 'נוף איילון', 31.8711100, 34.9908100, 'IL', '2016-09-13', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75751, 'Hashmonaim', 'Hashmonaim', 'חשמונאים', 31.9297300, 35.0215000, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75752, 'Lapid', 'Lapid', '', 31.9176400, 35.0322200, 'IL', '2016-09-13', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75753, 'Kfar NaOranim', 'Kfar NaOranim', 'כפר האורנים', 31.9198200, 35.0366900, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75754, 'Mevo horon', 'Mevo horon', 'מבוא חורון', 31.8487600, 35.0358300, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75755, 'Beit Horon', 'Beit Horon', 'byt hwrwn,בית חורון', 31.8758100, 35.1299900, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75756, 'Na''ale', 'Na''ale', 'Naale,נעלה', 31.9623600, 35.0655300, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75757, 'Giv''on HaHadasha', 'Giv''on HaHadasha', 'גבעון החדשה', 31.8492700, 35.1610600, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75758, 'Talmon', 'Talmon', 'tlmwn,טלמון', 31.9392700, 35.1353900, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75759, 'Dolev', 'Dolev', 'dwlb,דולב', 31.9260900, 35.1339300, 'IL', '2012-02-22', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75760, 'Ariel', 'Ariel', 'אריאל', 32.1065000, 35.1844900, 'IL', '2013-11-08', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75761, 'Nirit', 'Nirit', 'nyryt,נירית', 32.1467700, 34.9862200, 'IL', '2012-02-23', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75762, 'Revava', 'Revava', 'rbbh,רבבה', 32.1192600, 35.1289600, 'IL', '2012-02-23', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75763, 'Herzliya Pituah', 'Herzliya Pituah', 'Herzliya Pituach,Herzliya Pituah', 32.1740900, 34.8028000, 'IL', '2013-03-07', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(75764, 'Kiryat Ono', 'Kiryat Ono', 'Kiryat Ono,Qiryat Ono,qryt ʼwnw,qryyt ʼwnw,קריית אונו,קרית אונו', 32.0550300, 34.8578900, 'IL', '2017-07-03', 109);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76131, 'Srīmushnam', 'Srimushnam', 'Srimushnam,Srimushnum,Srīmushnam', 11.4011800, 79.4038400, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76132, 'Sri Mādhopur', 'Sri Madhopur', 'Sri Madhopur,Sri Mādhopur', 27.4659900, 75.5973600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76133, 'Karanpur', 'Karanpur', 'Karanpur,Karanpura,Sri Karanpur', 29.8404200, 73.4551900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76134, 'Chicacole', 'Chicacole', 'Chicacole,Srikakulam,Srīkākulam,srikakulam,శ్రీకాకుళం', 18.2989000, 83.8975100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76135, 'Sri Dūngargarh', 'Sri Dungargarh', 'Shri Dungargarh,Sri Dungargarh,Sri Dūngargarh', 28.0961700, 74.0086800, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76136, 'Soygaon', 'Soygaon', '', 20.5960600, 75.6176500, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76137, 'Soron', 'Soron', 'Soron,Сорон', 27.8905500, 78.7462100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76138, 'Soro', 'Soro', 'Soro', 21.2785100, 86.6883300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76139, 'Sorbhog', 'Sorbhog', '', 26.4861200, 90.8859000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76140, 'Sorada', 'Sorada', 'Sorada,Surada', 19.7608200, 84.4299700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76141, 'Sorab', 'Sorab', 'Sorab', 14.3814400, 75.0918300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76142, 'Sopur', 'Sopur', 'Sopor,Sopore,Sopur', 34.2867100, 74.4722800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76143, 'Sonīpat', 'Sonipat', 'Sonepat,Sonepat Punjab,Sonipat,Sonīpat', 28.9947800, 77.0193700, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76144, 'Songadh', 'Songadh', 'Songadh,Songarh', 21.1696600, 73.5635700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76145, 'Sonepur', 'Sonepur', 'Sonapur,Sonepur,Sonpur', 20.8333300, 83.9166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76146, 'Sonegaon', 'Sonegaon', '', 20.6291500, 78.6920700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76147, 'Sonāri', 'Sonari', 'Sonari,Sonāri', 27.0246200, 95.0162900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76148, 'Sonāmura', 'Sonamura', 'Sonamura,Sonāmura', 23.4754700, 91.2659000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76149, 'Sonāmukhi', 'Sonamukhi', 'Sonamukhi,Sonāmukhi', 23.3052100, 87.4133600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76150, 'Somvārpet', 'Somvarpet', 'Somvarpet,Somvārpet,Somwarpett', 12.5969800, 75.8495700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76151, 'Sompeta', 'Sompeta', 'Sompeta,sompeta,సోంపేట', 18.9441900, 84.5844900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76152, 'Someshwar', 'Someshwar', 'Somaishwar,Someshwar', 13.4911200, 75.0664600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76153, 'Solim', 'Solim', 'Siolim,Solim', 15.6152100, 73.7674000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76154, 'Solan', 'Solan', 'Solan,Solana,Solon,Солана', 30.9090800, 77.1086900, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76155, 'Sojītra', 'Sojitra', 'Sojitra,Sojītra', 22.5388400, 72.7198400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76156, 'Sojat', 'Sojat', 'Sojat', 25.9249300, 73.6663300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76157, 'Sohna', 'Sohna', 'Sohna', 28.2473700, 77.0654400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76158, 'Sohāgpur', 'Sohagpur', 'Sohagpur,Sohāgpur', 22.7005500, 78.1952200, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76159, 'Sohāgi', 'Sohagi', 'Sohagi,Sohāgi,Sohāgī', 24.9818100, 81.6955800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76160, 'Sodpur', 'Sodpur', 'Sodpur,Sudpur', 22.7042800, 88.3916600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76161, 'Soalkuchi', 'Soalkuchi', 'Soalkuchi,Sualkuchi,Suwalakuchi,Suwālakuchi', 26.1680600, 91.5711100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76162, 'Siwāna', 'Siwana', 'Siwana,Siwāna', 25.6515400, 72.4224300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76163, 'Siwān', 'Siwan', 'Savan,Sivan,Siwan,Siwān,Сиван', 26.2209600, 84.3560900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76164, 'Sivakasi', 'Sivakasi', 'Sivakasi,Sivakāsi,civakaci,sibakasi,sivakasi,xi wa ka xi,चिवकाचि,शिवकाशी,শিবকাশী,ਸਿਵਾਕਾਸੀ,ଶିବକାଶୀ,சிவகாசி,శివకాశి,ശിവകാശി,西瓦卡西,시바카시', 9.4499900, 77.7979700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76165, 'Sivagiri', 'Sivagiri', 'Sivagiri', 11.1202600, 77.7881100, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76166, 'Sivagiri', 'Sivagiri', 'Sivagiri', 9.3446100, 77.4291100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76167, 'Sivaganga', 'Sivaganga', 'Shivaganga,Sivaganga,civakankai,shivu~agangai,sibaganga,sivaganga,sivaganga''i,xi wa gang ge a,Шиваганга,शिवगङ्गा,শিবগঙ্গা,શિવગંગાઇ,ଶିବଗଙ୍ଗ,சிவகங்கை,シヴァガンガイ,西瓦冈格阿', 9.8470100, 78.4835800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76168, 'Siuri', 'Siuri', 'Siuri,Suri,Sūri', 23.9080600, 87.5277300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76169, 'Sitārganj', 'Sitarganj', 'Sitarganj,Sitārganj', 28.9293000, 79.7043600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76170, 'Sītāpur', 'Sitapur', 'Sitapur,Sītāpur', 27.5619200, 80.6826500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76171, 'Sītāmau', 'Sitamau', 'Sitamau,Sītāmau', 24.0147300, 75.3532400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76172, 'Sītāmarhi', 'Sitamarhi', 'Sitamarhi,Sītāmarhi', 26.5935700, 85.4906000, 'IN', '2016-06-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76173, 'Siswā Bāzār', 'Siswa Bazar', '', 27.1465200, 83.7580300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76174, 'Sisauli', 'Sisauli', 'Sisauli', 29.4138600, 77.4689000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76175, 'Sirūr', 'Sirur', 'Ghodnadi,Sirur,Sirūr', 18.8276000, 74.3747500, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76176, 'Sirumugai', 'Sirumugai', 'Sirumugai,Sirumugal,cirumukai,சிறுமுகை', 11.3213700, 77.0052100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76177, 'Siruguppa', 'Siruguppa', 'Siruguppa', 15.6300000, 76.8921700, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76178, 'Sirsilla', 'Sirsilla', 'Sirsilla,sirisilla,సిరిసిల్ల', 18.3886500, 78.8104800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76179, 'Sirsi', 'Sirsi', 'Sirsi', 28.6391600, 78.6430300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76180, 'Sirsi', 'Sirsi', 'Sirsi,sirasi,sirsi,xi er xi,शिरसि,सिरसी,ସିର୍ସି,ಶಿರಸಿ,西尔西', 14.6207200, 74.8355400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76181, 'Sirsāganj', 'Sirsaganj', 'Sirsaganj,Sirsāganj', 27.0571500, 78.6866100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76182, 'Sirsa', 'Sirsa', 'Sirsa,sirasa,sirsa,syrsa,xi er sa,Сирса,سیرسا,ضلع سرسہ,सिरसा,ସିର୍ସା,西尔萨', 29.5348900, 75.0289800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76183, 'Sirsā', 'Sirsa', 'Sirsa,Sirsā', 25.2634000, 82.0919000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76184, 'Sirpur', 'Sirpur', 'Sirpur,Sirpur-Tandura', 19.4795300, 79.5755800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76185, 'Sironj', 'Sironj', 'Sironj', 24.1031300, 77.6905500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76186, 'Sirohi', 'Sirohi', 'Sirohi,Sirokhi,shirohi,sirohi,xi luo xi,Сирохи,سروہی,सिरोही,সিরোহি,સિરોહી,ସିରୋହି,シローヒー,西罗希', 24.8883800, 72.8479400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76187, 'Sirmaur', 'Sirmaur', 'Sirmaur', 24.8364800, 81.3644800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76188, 'Sīrkāzhi', 'Sirkazhi', 'Cikal,Cīkāl,Shiyali,Shīyali,Sirkali,Sirkazhi,Sīrkāzhi', 11.2372500, 79.7358500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76189, 'Sirhind', 'Sirhind', 'Sirhind', 30.6432100, 76.3842100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76190, 'Sirāthu', 'Sirathu', 'Sirathu,Sirāthu,Sirāthū', 25.6429200, 81.3185500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76191, 'Sīra', 'Sira', 'Sira,Sīra', 13.7415500, 76.9043000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76192, 'Sinor', 'Sinor', 'Sinor', 21.9111700, 73.3397400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76193, 'Sinnar', 'Sinnar', 'Sinnar,Синнар', 19.8450500, 73.9986600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76194, 'Sini', 'Sini', 'Sini', 22.7919300, 85.9485000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76195, 'Singur', 'Singur', 'Singur', 22.8091700, 88.2294400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76196, 'Singtam', 'Singtam', 'Singtam,Singtam Bazar,Singtom', 27.2346700, 88.5016800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76197, 'Singoli', 'Singoli', 'Singoli', 24.9666700, 75.3000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76198, 'Singarāyakonda', 'Singarayakonda', 'Singaraya Konda Pagoda,Singarayakonda,Singarāyakonda', 15.2304600, 80.0279400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76199, 'Singapperumālkovil', 'Singapperumalkovil', 'Singaperumalkoil,Singaperumalkovil,Singaperumālkovil,Singapperumalkovil,Singapperumālkovil', 12.7594700, 80.0075000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76200, 'Singānallūr', 'Singanallur', '', 10.9989800, 77.0323800, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76201, 'Sindi', 'Sindi', 'Sindi', 20.8050900, 78.8875200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76202, 'Sindhnūr', 'Sindhnur', 'Sindhnur,Sindhnūr', 15.7698300, 76.7558100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76203, 'Sindgi', 'Sindgi', 'Sindgi', 16.9188300, 76.2336800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76204, 'Shimla', 'Shimla', 'SLV,Shimla,Simla,Simlá,cimla,shimla,shimura,shymla,simala,simla,sinla,symlh,xi mu la,Ŝimla,Şimla,Šimla,Шимла,Шімла,שימלה,شملہ,شيملا,شیملا,शिमला,শিমলা,ਸ਼ਿਮਲਾ,શિમલા,ଶିମଲା,சிம்லா,సిమ్లా,ಶಿಮ್ಲಾ,ഷിംല,შიმლა,シムラ,シムラー,西姆拉,심라', 31.1044200, 77.1666200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76205, 'Simga', 'Simga', 'Simga', 21.6281000, 81.7037600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76206, 'Simdega', 'Simdega', 'Simdega,simadega,symdga,xi mu de jia,Симдега,سیمدگا,सिमडेगा,সিমদেগা,સિમડેગા,ସିମଦେଗା,西姆德加', 22.6152300, 84.5020800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76207, 'Simaria', 'Simaria', 'Semaria,Simaria', 24.7949700, 81.1520000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76208, 'Silvassa', 'Silvassa', 'Selvasa,Selvāsa,Silvasa,Silvassa,cilvaca,selvasa,silabas''sa,silabhasa,silavasa,silbasa,silvasa,su~iruvu~asa,sylwasa,xi er wa sa,Силвасса,Сілвасса,سیلواسا,सिलवास,सिलवासा,सिल्वासा,সিলবাস্সা,ਸਿਲਵਾਸਾ,સેલ્વાસ,ସିଲଭାସା,சில்வாசா,സിൽവാസ്സ,სილვასა,スィルヴァーサー,锡尔瓦萨,실바사', 20.2738600, 72.9967300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76209, 'Sillod', 'Sillod', 'Sillod', 20.3030300, 75.6528400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76210, 'Silchar', 'Silchar', 'IXS,Silchar,silacara,silacara-nagaram,xi er qia er,Силчар,शिलचर-नगरम्,सिलचर,শিলচর,শিলচৰ,સિલચર,ସିଲ୍‌ଚର୍,西尔恰尔', 24.8273300, 92.7978700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76211, 'Silao', 'Silao', 'Silao,Vikramasila,Силао', 25.0835800, 85.4280400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76212, 'Sīkar', 'Sikar', 'Sikar,Sīkar', 27.6120600, 75.1399600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76213, 'Sikandra Rao', 'Sikandra Rao', 'Sikandra Rao', 27.6885900, 78.3798500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76214, 'Sikandra', 'Sikandra', '', 26.3672200, 79.6298000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76215, 'Sikandarpur', 'Sikandarpur', '', 26.0432700, 84.0529800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76216, 'Sikandarābād', 'Sikandarabad', 'Sikandarabad,Sikandarābād,Sikandrabad', 28.4522600, 77.7000400, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76217, 'Sikka', 'Sikka', 'Sika,Siki,Sikka', 22.4321800, 69.8415800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76218, 'Sijua', 'Sijua', 'Sijua', 23.7761700, 86.3302800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76219, 'Sihorā', 'Sihora', 'Sihora,Sihorā', 23.4871000, 80.1040400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76220, 'Sihor', 'Sihor', 'Shihor,Sihara,Sihor,sihora,xi huo er,سِہور,सिहोर,সিহোর,સિહોર,西霍尔', 21.7113400, 71.9617900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76221, 'Sidlaghatta', 'Sidlaghatta', 'Sidlaghatta', 13.3889600, 77.8644400, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76222, 'Sidhpura', 'Sidhpura', 'Sidhpura', 27.6331200, 78.8691800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76223, 'Sidhi', 'Sidhi', 'Sidhi,Sidi,Sidkhi,Сидхи', 24.4038000, 81.8795400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76224, 'Sidhaulī', 'Sidhauli', 'Sidhauli,Sidhaulī', 27.2820200, 80.8345000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76225, 'Siddipet', 'Siddipet', 'Siddipet,siddipeta,సిద్దిపేట', 18.1048300, 78.8485800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76226, 'Siddhapur', 'Siddhapur', 'Siddhapur,Sidhpur', 23.9178300, 72.3721200, 'IN', '2016-06-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76227, 'Siddāpur', 'Siddapur', 'Siddapur,Siddāpur', 14.3432200, 74.8940000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76228, 'Sibsāgar', 'Sibsagar', 'Sibsagar,Sibsagor Naga Bhumi,Sibsāgar,Сибсагар', 26.9842700, 94.6378400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76229, 'Shyamnagar', 'Shyamnagar', 'Shamnagar,Shamnagore,Shyamnagar,Syamnagar,Syāmnagar', 22.8333300, 88.3666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76230, 'Shupīyan', 'Shupiyan', 'Shupiyan,Shupiyon,Shupīyan', 33.7172300, 74.8341300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76231, 'Shujālpur', 'Shujalpur', 'Shujalpur,Shujālpur', 23.4067300, 76.7098000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76232, 'Shrīrangapattana', 'Shrirangapattana', 'Shrirangapattana,Shrīrangapattana,Srirangapatna', 12.4226400, 76.6843900, 'IN', '2015-01-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76233, 'Shrīrāmpur', 'Shrirampur', 'Serampore,Serampur,Shrirampur,Shrīrāmpur', 22.7527800, 88.3422200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76234, 'Shrīgonda', 'Shrigonda', 'Shrigonda,Shrīgonda', 18.6152700, 74.6989500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76235, 'Srāvana Belgola', 'Sravana Belgola', 'Shravan Belgola,Shravanabelagola,Sravana Belgola,Srāvana Belgola', 12.8573700, 76.4888600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76236, 'Shorāpur', 'Shorapur', 'Shorapur,Shoratur,Shorāpur,Surapur,Suratur,Sūrāpur', 16.5210000, 76.7573800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76237, 'Shōranūr', 'Shoranur', 'Shoranur,Shōranūr', 10.7618100, 76.2707800, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76238, 'Sholinghur', 'Sholinghur', 'Sholinghur', 13.1181000, 79.4202500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76239, 'Solāpur', 'Solapur', 'SSE,Sholapur,Sholāpur,Solapur,Solāpur,solapura,sollapura,sorapuru,Солапур,सोलापूर,ಸೊಲ್ಲಾಪುರ,ソーラープル', 17.6715200, 75.9104400, 'IN', '2017-03-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76240, 'Shivrājpur', 'Shivrajpur', '', 22.4231900, 73.6086500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76241, 'Shivpuri', 'Shivpuri', 'Shivpuri,Shivpurī,si xi wo pu li,sibapuri,sivapuri,Шивпури,शिवपुरी,শিবপুরি,શિવપુરી,ଶିବପୁରି,斯希沃普里', 25.4237800, 77.6622300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76242, 'Shīshgarh', 'Shishgarh', 'Shishgarh,Shīshgarh', 28.7292800, 79.3146900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76243, 'Shirwal', 'Shirwal', 'Shirval,Shirwal', 18.1505900, 73.9778800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76244, 'Shirpur', 'Shirpur', 'Shirpur,Shirpure,Ширпуре', 21.3482100, 74.8803500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76245, 'Shirhatti', 'Shirhatti', 'Shirhatti', 15.2335200, 75.5799600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76246, 'Shirgaon', 'Shirgaon', 'Shirgaon,Siri', 19.6958900, 72.7152700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76247, 'Shirdi', 'Shirdi', 'SAG,Shirdi,cirati,she de,shyrdy,siradi,sirdi,siriri,Ширди,شرڈی,شیردی,शिरडी,शिर्डी,শিরদি,શિરડી,ଶିରିଡ଼ି,சீரடி,షిర్డీ,ಶಿರ್ಡಿ,舍地', 19.7661600, 74.4773800, 'IN', '2017-06-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76248, 'Shimoga', 'Shimoga', 'Shimoga,Shimogga,Shivamogga,Shivamoggi,cimakka,shymwga,shywamwga,simeaga,simoga,sivamogga,xi mo jia,Шимога,شیموگا,شیواموگا,शिमोगा,শিমোগা,શિમોગા,சீமக்கா,శివమొగ్గ,ಶಿವಮೊಗ್ಗ,ഷിമോഗ,希莫加', 13.9315700, 75.5679100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76249, 'Shillong', 'Shillong', 'SHL,Shillong,Shilong,Silongas,cillan,shilongi,shiron,shylang,shylwngh,silam,silamga,silanga,sillang,silleann,sillong,silonga,xi long,Šilongas,Шиллонг,Шилонг,شيلونغ,شیلانگ,शिलाँग,शिलांग,शिलाङ्ग,शिलोंग,শিলং,ਸ਼ਿਲਾਂਗ,શિલોંગ,ଶିଲଂ,சில்லாங்,షిల్లాంగ్,ಶಿಲ್ಲಾಂಗ್,ഷില്ലോങ്ങ്,შილონგი,シロン,西隆,실롱', 25.5689200, 91.8831300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76250, 'Shiliguri', 'Shiliguri', 'Shiliguri,Silguri,Siligun,Siliguri,Silīguri,Silīgurí,siliguri,xi li gu li,Силигури,सिलीगुड़ी,শিলিগুড়ি,西里古里', 26.7100400, 88.4285100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76251, 'Shikohābād', 'Shikohabad', 'Shikohabad,Shikohābād', 27.1080000, 78.5866100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76252, 'Shikārpūr', 'Shikarpur', 'Shikarpur,Shikārpur,Shikārpūr', 28.2807200, 78.0141100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76253, 'Shikārpur', 'Shikarpur', '', 14.2698000, 75.3564300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76254, 'Shiggaon', 'Shiggaon', 'Shigaon,Shiggaon', 14.9905300, 75.2249900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76255, 'Shertallai', 'Shertallai', 'Shertalla,Shertallai,Shertally', 9.6858100, 76.3399600, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76256, 'Sherkot', 'Sherkot', 'Bijnor,Sherkot', 29.3270400, 78.5742900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76257, 'Sherghāti', 'Sherghati', 'Sherghati,Sherghāti', 24.5595000, 84.7916200, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76258, 'Shergarh', 'Shergarh', '', 28.6512800, 79.3681500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76259, 'Sheopur', 'Sheopur', 'Sheopur,Sheopur Kalan,se''opura,serapura,si he ao pu er,syopura,syopuram,श्योपुरम्,শেওপুর,শেৱপুর,શ્યોપુર,ଶେଓପୁର,斯赫奥普尔', 25.6647200, 76.6961600, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76260, 'Sheohar', 'Sheohar', 'Sheohar', 26.5139300, 85.2934100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76261, 'Sheoganj', 'Sheoganj', 'Sheoganj', 25.1391500, 73.0678400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76262, 'Shegaon', 'Shegaon', 'Shegaon,segamo,seganva,si he jia ao en,شے گاؤں,शेगांव,শেগাঁও,ଶେ‌‌ଗାଓଁ,斯赫加奥恩', 20.7932000, 76.6992100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76263, 'Shāntipur', 'Shantipur', 'Santipur,Shantipur,Shāntipur,Sāntipur', 23.2472300, 88.4330200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76264, 'Shankargarh', 'Shankargarh', 'Shankargarh', 25.1820000, 81.6176900, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76265, 'Shamsābād', 'Shamsabad', 'Shamsabad,Shamsābād', 27.5371000, 79.4379600, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76266, 'Shamsābād', 'Shamsabad', 'Shamsabad,Shamsābād', 27.0171800, 78.1235800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76267, 'Shāmli', 'Shamli', 'Shamli,Shāmli', 29.4497000, 77.3095900, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76268, 'Shāmgarh', 'Shamgarh', 'Shamgarh,Shāmgarh', 24.1881700, 75.6390300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76269, 'Shām Churāsi', 'Sham Churasi', '', 31.5002800, 75.7491700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76270, 'Shājāpur', 'Shajapur', 'Shajapur,Shājāpur', 23.4263700, 76.2777500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76271, 'Sheikhpura', 'Sheikhpura', 'Shaikhpura,Sheikhpura', 25.1399400, 85.8409600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76272, 'Shāhpura', 'Shahpura', '', 27.3912000, 75.9595600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76273, 'Shāhpura', 'Shahpura', 'Shahpura,Shāhpura', 25.6209400, 74.9248700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76274, 'Shāhpura', 'Shahpura', 'Shahpura,Shāhpura', 23.1366300, 79.6640200, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76275, 'Shāhpur', 'Shahpur', 'Shahpur,Shakhpura,Shāhpur,Шахпура', 29.3501000, 77.5516000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76276, 'Shāhpur', 'Shahpur', 'Shahpur,Shāhpur', 25.6029300, 84.4041200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76277, 'Shāhpur', 'Shahpur', '', 23.8937100, 79.0507400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76278, 'Shāhpur', 'Shahpur', '', 23.0244600, 81.0038000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76279, 'Shāhpur', 'Shahpur', '', 22.1952600, 77.9068200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76280, 'Shāhpur', 'Shahpur', '', 22.1561100, 70.7706800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76281, 'Shāhpur', 'Shahpur', 'Shahpur,Shāhpur', 21.2374200, 76.2255800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76282, 'Shāhpur', 'Shahpur', 'Shahpur,Shakhpura,Shāhpur,Шахпура', 16.6960500, 76.8422000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76283, 'Shāhkot', 'Shahkot', 'Jullundur,Shahkot,Shāhkot', 31.0817300, 75.3370800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76284, 'Shāhjānpur', 'Shahjanpur', 'Shahjahanpur,Shahjanpur,Shāhjahānpur,Shāhjānpur', 27.8816500, 79.9091800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76285, 'Shāhi', 'Shahi', 'Shahi,Shāhi', 28.5502300, 79.3176100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76286, 'Shāhgarh', 'Shahgarh', 'Shahgarh,Shāhgarh', 24.3136500, 79.1180600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76287, 'Shāhganj', 'Shahganj', 'Jaunpur,Shahganj,Shāhganj', 26.0496500, 82.6842300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76288, 'Shahdol', 'Shahdol', 'Sahdol,Shahdol,sahadola,saharola,satol,si ha he duo er,शहडोल,शहदोल,শাহদোল,શાહડોલ,ଶାହଡ଼ୋଲ,ஷடோல்,斯哈赫多尔', 23.2935600, 81.3619000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76289, 'Shāhāpur', 'Shahapur', 'Shahapur,Shāhāpur', 19.4523100, 73.3257200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76290, 'Shāhāda', 'Shahada', '', 21.5453800, 74.4710600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76291, 'Shāhābād', 'Shahabad', '', 30.1677600, 76.8704600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76292, 'Shāhābād', 'Shahabad', 'Sahabad,Shahabad,Shāhābād,Sāhābād', 28.5668100, 79.0095600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76293, 'Shāhābād', 'Shahabad', 'Hardoi,Shahabad,Shāhābād', 27.6431000, 79.9402000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76294, 'Shāhābād', 'Shahabad', 'Shahabad,Shahabad Deccan,Shāhābād', 17.1307000, 76.9436100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76295, 'Serula', 'Serula', '', 15.5477400, 73.8432900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76296, 'Serchhīp', 'Serchhip', 'Serchhip,Serchhīp', 23.2931200, 92.8467900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76297, 'Seram', 'Seram', 'Sedam,Seram,Серам', 17.1785900, 77.2899800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76298, 'Seorīnārāyan', 'Seorinarayan', 'Seorinarayan,Seorinaryan,Seorīnārāyan', 21.7205500, 82.5934400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76299, 'Seoni Mālwa', 'Seoni Malwa', 'Seoni Malwa,Seoni Marwa,Seoni Mālwa,Seonī Mālwā', 22.4504600, 77.4665000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76300, 'Seoni', 'Seoni', 'Seoni', 31.2418800, 77.1236200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76301, 'Seoni', 'Seoni', 'Seoni,Seonī', 22.0850300, 79.5503700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76302, 'Seondha', 'Seondha', 'Seondha,Seora', 26.1542200, 78.7812000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76303, 'Seohāra', 'Seohara', 'Seohara,Seohāra,Seohārā', 29.2090400, 78.5883700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76304, 'Sendhwa', 'Sendhwa', 'Sendhawa,Sendhwa', 21.6856200, 75.0962200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76305, 'Sehore', 'Sehore', 'Sehore', 23.2000000, 77.0833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76306, 'Secunderabad', 'Secunderabad', 'Sekunderabad,cikkantarapat,sai kang de la ba de,sekkandrabad,sekundarabada,sekundelabadeu,shikandarabado,sikandarabada,sikindrabad,skndr abad,Секундерабад,سکندر آباد,सिकंदराबाद,সেকুন্দারাবাদ,சிக்கந்தராபாத்,సికింద్రాబాద్,സെക്കന്ദ്രാബാദ്,シカンダラーバード,塞康德拉巴德,세쿤데라바드', 17.5042700, 78.5426300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76307, 'Sāyla', 'Sayla', 'Sayla,Sāyla', 22.5492500, 71.4832400, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76308, 'Sāyalkudi', 'Sayalkudi', 'Sayalgudi,Sayalkudi,Sāyalkudi', 9.1693100, 78.4470800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76309, 'Sawāi Mādhopur', 'Sawai Madhopur', 'Sawai Madhopur,Sawāi Mādhopur', 26.0230100, 76.3440800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76310, 'Sāvda', 'Savda', 'Savda,Sāvda', 21.1505400, 75.8893800, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76311, 'Savanūr', 'Savanur', 'Savanur,Savanūr', 14.9733500, 75.3372400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76312, 'Sāvantvādi', 'Savantvadi', 'Savantvadi,Sāvantvādi', 15.9041300, 73.8219100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76313, 'Sausar', 'Sausar', 'Sausar', 21.6557600, 78.7966900, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76314, 'Saurikh', 'Saurikh', 'Saurikh,Saurnikh', 27.0305100, 79.4881300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76315, 'Saundatti', 'Saundatti', 'Saundatti,Saundatti Yellamma,Soundatti', 15.7661500, 75.1177800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76316, 'Sathyamangalam', 'Sathyamangalam', 'cattimankalam,sa di ya mang ge a la mu,sathyamangalama,satyamangalama,styamnglm,ستیامنگلم,सत्यमंगलम,সথ্যামঙ্গলম,ସାଥ୍ୟମଙ୍ଗାଲମ,சத்திமங்கலம்,萨蒂亚芒格阿拉姆', 11.5052600, 77.2382600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76317, 'Satwās', 'Satwas', 'Satwas,Satwās', 22.5362800, 76.6845200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76318, 'Sattur', 'Sattur', 'Sattur,Sāttūr', 9.3559200, 77.9245700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76319, 'Sattenapalle', 'Sattenapalle', 'Sattenapalle', 16.3938100, 80.1522100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76320, 'Sathankulam', 'Sathankulam', 'Sattankulam,Sāttānkulam', 8.4416400, 77.9134900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76321, 'Satrikh', 'Satrikh', 'Satrikh', 26.8604500, 81.1956700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76322, 'Satna', 'Satna', 'Satna,TNI', 24.5772600, 80.8271900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76323, 'Satara', 'Satara', 'Satara,Sātāra,Сатара', 17.6858900, 73.9933300, 'IN', '2016-06-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76324, 'Satānā', 'Satana', 'Satana,Satāna,Satānā', 20.5948300, 74.2030100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76325, 'Sāsvad', 'Sasvad', 'Sasvad,Sāsvad', 18.3435100, 74.0310200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76326, 'Sāsni', 'Sasni', 'Sasni,Sāsni', 27.7028700, 78.0827800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76327, 'Sarwār', 'Sarwar', 'Sarvar,Sarvār,Sarwar,Sarwār', 26.0627200, 75.0110400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76328, 'Sāruberā', 'Sarubera', '', 23.8160900, 86.0104100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76329, 'Sarkhej', 'Sarkhej', 'Sarkhej', 22.9829700, 72.5019600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76330, 'Sarka Ghāt', 'Sarka Ghat', '', 31.6988700, 76.7352900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76331, 'Sarīla', 'Sarila', 'Sarila,Sarīla', 25.7757900, 79.6753500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76332, 'Sargūr', 'Sargur', 'Sargur,Sargūr', 11.9997100, 76.3961100, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76333, 'Sardulgarh', 'Sardulgarh', 'Sardulgarh', 29.6922400, 75.2360800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76334, 'Sardhana', 'Sardhana', 'Sardhana', 29.1455100, 77.6143300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76335, 'Sardārshahr', 'Sardarshahr', '', 28.4406200, 74.4910000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76336, 'Sarauli', 'Sarauli', 'Saranli,Sarauli', 28.4940400, 79.0917700, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76337, 'Sārangpur', 'Sarangpur', 'Sarangpur,Sārangpur', 23.5665100, 76.4730600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76338, 'Sārangarh', 'Sarangarh', 'Sarangarh,Sārangarh', 21.5861400, 83.0785000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76339, 'Saraipali', 'Saraipali', 'Saraipaili,Saraipali,Saraipāli', 21.3153000, 83.0062900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76340, 'Sarāi Mīr', 'Sarai Mir', 'Khud Kashta,Khud Kāshta,Sarai Mir,Sarāi Mīr', 26.0270500, 82.9184300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76341, 'Saraikela', 'Saraikela', 'Saraikela,Seraikella', 22.6990400, 85.9315400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76342, 'Sarai Ekdil', 'Sarai Ekdil', 'Sarai Ekdil,Sarāi Ekdil', 26.7444200, 79.0935300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76343, 'Sarāi Ākil', 'Sarai Akil', '', 25.3789000, 81.5103500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76344, 'Sarāhan', 'Sarahan', 'Sarahan,Sarāhan', 31.5098800, 77.7939500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76345, 'Sapatgrām', 'Sapatgram', 'Sapatgram,Sapatgrām', 26.3373200, 90.1236000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76346, 'Saoner', 'Saoner', 'Saoner', 21.3851000, 78.9215500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76347, 'Sānwer', 'Sanwer', '', 22.9741500, 75.8271000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76348, 'Sanvordem', 'Sanvordem', 'Sanvarden,Sanvordem', 15.2626900, 74.1196500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76349, 'Santoshpur', 'Santoshpur', 'Santashpur,Santoshpur', 22.5203800, 88.2697300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76350, 'Santokhgarh', 'Santokhgarh', 'Santokgarh,Santokhgarh', 31.3520500, 76.3177500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76351, 'Sanquelim', 'Sanquelim', 'Sanquelim', 15.5642200, 74.0079900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76352, 'Sānkrāil', 'Sankrail', 'Sankrail,Shankrail,Sānkrāil', 22.5499700, 88.2251500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76353, 'Sankheda', 'Sankheda', 'Sankheda', 22.1702100, 73.5782000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76354, 'Sankeshwar', 'Sankeshwar', 'Sankeshvar,Sankeshwar', 16.2564900, 74.4819500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76355, 'Sanivārsante', 'Sanivarsante', '', 12.7282400, 75.8866900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76356, 'Sanguem', 'Sanguem', 'Sanguem', 15.2290100, 74.1514900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76357, 'Sangrūr', 'Sangrur', 'Sangrur,Sangrūr', 30.2450600, 75.8448800, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76358, 'Sāngola', 'Sangola', '', 17.4394800, 75.1937900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76359, 'Sangod', 'Sangod', 'Sangod', 24.9270700, 76.2864900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76360, 'Sāngli', 'Sangli', 'Sangla,Sangli,Sāngli,Turmeric city', 16.8543800, 74.5641700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76361, 'Sangariā', 'Sangaria', 'Sangaria,Sangariā', 29.7988600, 74.4668300, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76362, 'Sangāreddi', 'Sangareddi', 'Sangareddi,Sangareddipet,Sangareddypeta,Sangāreddi,sangareddi,సంగారెడ్డి', 17.6247700, 78.0866900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76363, 'Sangamner', 'Sangamner', 'Sangamner,Sangamnor', 19.5678400, 74.2115400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76364, 'Sandūr', 'Sandur', 'Sandur,Sandūr', 15.0861300, 76.5469200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76365, 'Sandīla', 'Sandila', 'Sandila,Sandīla', 27.0698900, 80.5149700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76366, 'Sāndi', 'Sandi', 'Sandi,Sāndi', 27.2886700, 79.9519000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76367, 'Sancoale', 'Sancoale', 'Sancoale', 15.3779400, 73.9035200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76368, 'Sānchor', 'Sanchor', 'Sanchor,Sanchore,Sānchor', 24.7536100, 71.7728000, 'IN', '2016-08-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76369, 'Sānchi', 'Sanchi', 'Sanchi,Sānchi', 23.4864600, 77.7378000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76370, 'Sanāwad', 'Sanawad', 'Sanavad,Sanawad,Sanāwad,Sānāwad', 22.1739100, 76.0699300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76371, 'Sanaur', 'Sanaur', 'Sanaur', 30.3018200, 76.4578600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76372, 'Sānand', 'Sanand', 'Sanand,Sānand', 22.9922700, 72.3817700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76373, 'Samthar', 'Samthar', 'Samthar', 25.8434800, 78.9068300, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76374, 'Samrāla', 'Samrala', 'Samrala,Samrāla', 30.8360100, 76.1932400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76375, 'Samdari', 'Samdari', 'Samdari', 25.8129900, 72.5787900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76376, 'Sāmbhar', 'Sambhar', 'Sambhar,Sambhar Lake,Sambkhara,Sāmbhar,Самбхара', 26.9080600, 75.1913700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76377, 'Sambhal', 'Sambhal', 'Sambal,Sambhal,sambal,sambhala,Самбал,سامبال,سنبھل,संभल,সাম্ভাল,ସମ୍ଭାଲ', 28.5849800, 78.5695900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76378, 'Sambalpur', 'Sambalpur', 'Sambalpore,Sambalpur,sa mu ba er pu er,sambalapura,sambalpuleu,sanbarupuru,smblpwr,Самбалпур,سمبلپور,संबलपुर,संबलपूर,সাম্বালপুর,સંબલપુર,ସମ୍ବଲପୁର,సంబల్‌పుర్,サンバルプル,萨姆巴尔普尔,삼발푸르', 21.4652700, 83.9757300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76379, 'Sāmba', 'Samba', 'Samba,Sāmba', 32.5624500, 75.1199300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76380, 'Samāstipur', 'Samastipur', 'Samastipur,Samastīpur,Samāstipur', 25.8622200, 85.7795300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76381, 'Sāmalkot', 'Samalkot', '', 17.0567500, 82.1763900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76382, 'Samālkha', 'Samalkha', 'Samalkha,Samālkha', 29.2355200, 77.0127300, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76383, 'Sālūr', 'Salur', 'Salur,Sālūr,saluru,సాలూరు', 18.5171600, 83.2054800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76384, 'Sālūmbar', 'Salumbar', 'Salumbar,Sālūmbar', 24.1352400, 74.0444200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76385, 'Salon', 'Salon', 'Salon', 26.0285700, 81.4540300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76386, 'Saligao', 'Saligao', 'Saligao', 15.5535900, 73.7903600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76387, 'Salem', 'Salem', 'Gorad Salem,SXV,Salem,Selam,Szalem,Szálem,celam,sai lei mu,salema,sallem,salm,selam,selama,seramu,Горад Салем,Салем,سالم,سالم ،تامل ناڈو,سیلم، تامل ناڈو,सेलम,সালেম,સેલમ,ସେଲମ୍,சேலம்,సేలం,ಸೇಲಂ‌,സേലം,セーラム,塞勒姆,살렘', 11.6511700, 78.1586700, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76388, 'Salāya', 'Salaya', 'Salaya,Salāya', 22.3103800, 69.6037600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76389, 'Saktī', 'Sakti', 'Sakti,Saktī,Shakti,Шакти', 22.0266200, 82.9609100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76390, 'Sakleshpur', 'Sakleshpur', 'Saklaspur,Sakleshpur', 12.9411900, 75.7846700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76391, 'Sakīt', 'Sakit', 'Sakit,Sakīt', 27.4346300, 78.7790300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76392, 'Sāitlaw', 'Saitlaw', 'Saitlaw,Saitual,Sāitlaw', 23.9718700, 92.5745400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76393, 'Sairang', 'Sairang', 'Sairang', 23.8103400, 92.6522600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76394, 'Saint Thomas Mount', 'Saint Thomas Mount', 'Madras Saint Thomas Mount,Parangimalai,Paranginealai,Saint Thomas Mount,Saint Thomas''s Mount,Saint Thomas’s Mount', 13.0033400, 80.1961400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76395, 'Sainthia', 'Sainthia', 'Sainthia,sai en di ya,samithiya,sinthi''a,سینتھیا,সাঁইথিয়া,ସିନ୍ଥିଆ,赛恩蒂亚', 23.9482600, 87.6804500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76396, 'Selu', 'Selu', 'Sailu,Selu', 19.4551200, 76.4407300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76397, 'Sailāna', 'Sailana', 'Sailana,Sailāna', 23.4621900, 74.9231800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76398, 'Saiha', 'Saiha', 'Saiha', 22.4918300, 92.9814300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76399, 'Saidpur', 'Saidpur', '', 28.6108900, 77.9089600, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76400, 'Saidpur', 'Saidpur', 'Saidpur', 25.5374900, 83.2237800, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76401, 'Sāhibganj', 'Sahibganj', 'Sahibganj,Sāhibganj', 25.2442500, 87.6348100, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76402, 'Sahāwar', 'Sahawar', 'Sahawar,Sahāwar', 27.7960300, 78.8337300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76403, 'Sahaswān', 'Sahaswan', 'Sahaswan,Sahaswān', 28.0722700, 78.7508200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76404, 'Sahaspur', 'Sahaspur', 'Sahaspur', 29.1212500, 78.6227300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76405, 'Saharsa', 'Saharsa', 'Saharsa,Sakharsa,sa ha er sa,saharasa,saharsa,Сахарса,ساهارسا,سہرسہ,सहरसा,सहर्सा,সহর্ষ,সহর্ষা,સહરસા,ସାହାର୍ସା,సహర్సా,萨哈尔萨', 25.8749800, 86.5961100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76406, 'Sahāranpur', 'Saharanpur', 'Saharanpur,Sahāranpur', 29.9679000, 77.5452200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76407, 'Sagauli', 'Sagauli', 'Saganli,Sagauli,Saghauli,Sagowlee,Segowlee,Segowlie,Sugauli', 26.7639000, 84.7434100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76408, 'Saugor', 'Saugor', 'Sagar,Saugor,Sāgar,Сагар', 23.8387700, 78.7387400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76409, 'Sāgar', 'Sagar', 'Sagar,Sāgar', 14.1649800, 75.0290100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76410, 'Safīpur', 'Safipur', 'Safipur,Safīpur', 26.7378300, 80.3435000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76411, 'Safidon', 'Safidon', 'Safidon', 29.4059600, 76.6704200, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76412, 'Sādri', 'Sadri', 'Sadri,Sādri', 25.1855500, 73.4528800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76413, 'Sādāt', 'Sadat', 'Sadat,Sādāt', 25.6711700, 83.3026900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76414, 'Sadāseopet', 'Sadaseopet', 'Sadaseopet,Sadashivpet,Sadasivpet,Sadāseopet', 17.6192500, 77.9526300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76415, 'Sadalgi', 'Sadalgi', 'Sadalga,Sadalgi', 16.5587000, 74.5321100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76416, 'Sadābād', 'Sadabad', 'Sadabad,Sadābād', 27.4381800, 78.0375800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76417, 'Sachīn', 'Sachin', 'Sachim,Sachin,Sachir,Sachīn,Sachīr', 21.0871800, 72.8815300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76418, 'Sabrūm', 'Sabrum', 'Sabroom,Sabrum,Sabrūm', 23.0015300, 91.7242700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76419, 'Sabāthu', 'Sabathu', 'Sabathu,Sabāthu,Subathu', 30.9749400, 76.9913700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76420, 'Sabalgarh', 'Sabalgarh', 'Sabalgarh', 26.2491800, 77.4078600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76421, 'Rusera', 'Rusera', '', 25.7535500, 86.0259700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76422, 'Rura', 'Rura', 'Rura', 26.4900100, 79.9010800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76423, 'Ropar', 'Ropar', 'Ropar,Rupar,Rupnagar,Rūpar,Rūpnagar', 30.9689600, 76.5269500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76424, 'Rudraprayāg', 'Rudraprayag', 'Rudraprayag,Rudraprayāg', 30.2846700, 78.9835400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76425, 'Rūdarpur', 'Rudarpur', '', 26.4446700, 83.6130200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76426, 'Roorkee', 'Roorkee', 'Roorkee,Rurki,luo ao er kai ai,roraki,rraki,ruraki,rurki,rurkki,Рурки,Руркі,روڑکی,रुड़की,रूरकी,রোরকি,ଋଡ଼କୀ,ரூர்க்கி,రూర్కీ,罗奥尔凯埃', 29.8663200, 77.8911800, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76427, 'Ron', 'Ron', 'Ron,Rona,Рона', 15.6993500, 75.7340800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76428, 'Rohtak', 'Rohtak', 'Rohtak,Rokhtak,luo he ta ke,rohataka,rwhtak,rwtk,Рохтак,روتک,روهتاك,روہتک,रोहतक,রোহতক,રોહતક,ରୋହତକ,罗赫塔克', 28.8944700, 76.5891700, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76429, 'Rohru', 'Rohru', 'Rohru', 31.2026900, 77.7548400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76430, 'Roha', 'Roha', '', 23.1964600, 69.2707600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76431, 'Roha', 'Roha', 'Roha,Roha-Kolaba,rohe,روہا,रोहे', 18.4368700, 73.1196400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76432, 'Robertsonpet', 'Robertsonpet', 'Robertsonpet', 12.9562900, 78.2753900, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76433, 'Robertsganj', 'Robertsganj', 'Robertsgandzh,Robertsganj,Sonbhadra,luo bei er te si gan jie,rabartasaganja,rabartsganja,robartasaganja,Робертсгандж,روبرٹس گنج,राबर्ट्स्गञ्ज,রবার্টসগঞ্জ,રોબર્ટસગંજ,ରବର୍ଟସଗଞ୍ଜ,罗贝尔特斯甘杰', 24.6886000, 83.0678400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76434, 'Risod', 'Risod', 'Risod', 19.9767100, 76.7879900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76435, 'Rishra', 'Rishra', 'Rishra', 22.7239400, 88.3456300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76436, 'Rishīkesh', 'Rishikesh', 'Rikhikesh,Rishikesh,Rishīkesh,Ришикеш', 30.1077800, 78.2925500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76437, 'Rīngas', 'Ringas', 'Reengus,Ringas,Ringus,Rīngas', 27.3636000, 75.5683800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76438, 'Richha', 'Richha', 'Richha', 28.6946700, 79.5228400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76439, 'Riāsi', 'Riasi', 'Reasi,Riasi,Riāsi', 33.0811500, 74.8324200, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76440, 'Rewāri', 'Rewari', 'Rewari,Rewāri', 28.1990000, 76.6183000, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76441, 'Rewa', 'Rewa', 'REW,Reva,Rewa,Rewah,lei wa,reva sahara,rewa,riva,riwa,rywa,Рева,ریوا,रीवा,रेवा शहर,રીવા,ରେୱା,リーワー,雷瓦', 24.5325600, 81.2923400, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76442, 'Revelganj', 'Revelganj', 'Revelganj', 25.7897600, 84.6359600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76443, 'Revadanda', 'Revadanda', 'Revadanda,Revdanda', 18.5536300, 72.9255900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76444, 'Repalle', 'Repalle', 'Repalle,lei pa er lai,repalle,repalle mandala,ripalle,Репалле,रेपल्ले मण्डल,রিপাল্লে,ରେପାଲ୍ଲେ,రేపల్లె,雷帕尔莱', 16.0184000, 80.8295800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76445, 'Reoti', 'Reoti', 'Reoti', 25.8509100, 84.3778000, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76446, 'Renukūt', 'Renukut', 'Renukoot,Renukut,Renukūt', 24.2164100, 83.0358000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76447, 'Renigunta', 'Renigunta', 'Renigunta,lei ni gong ta,renigunta,renigunta mandala,renikunta,رینی گنٹا,रेणिगुंट मण्डल,রেনীগুন্তা,ରେନିଗୁନ୍ତା,ரேணிகுண்டா,రేణిగుంట,雷尼贡塔', 13.6514300, 79.5125600, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76448, 'Rengāli', 'Rengali', '', 21.6388500, 84.0443400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76449, 'Remuna', 'Remuna', 'Remuna', 21.5279800, 86.8715600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76450, 'Rehti', 'Rehti', 'Rehti,Rheti', 22.7378100, 77.4339900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76451, 'Rehli', 'Rehli', 'Rehli,Rehlī', 23.6372200, 79.0627500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76452, 'Rāzole', 'Razole', 'Razole,Rāzole', 16.4760800, 81.8391200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76453, 'Rāzām', 'Razam', 'Rajam,Razam,Rājām,Rāzām', 18.4490900, 83.6595700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76454, 'Rāybāg', 'Raybag', 'Raybag,Raybagh,Rāybāg', 16.4917800, 74.7739100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76455, 'Rāyadrug', 'Rayadrug', '', 14.6997100, 76.8524100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76456, 'Rāyachoti', 'Rayachoti', 'Rayachoti,Rāyachoti', 14.0572300, 78.7505600, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76457, 'Rāya', 'Raya', 'Raja,Raya,Rāya,Рая', 27.5560700, 77.7897200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76458, 'Rāy', 'Ray', '', 23.6846400, 85.0554500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76459, 'Raxaul', 'Raxaul', 'Raksaul,Rasaul,Raxaul,Raxaul Bazar,la ke ao er ba zha er,raja''ula bajara,raksaula,raksula bajara,Раксаул,रक्सौल,রক্সুল বাজার,রক্সৌল,ରାଜାଉଲ ବଜାର,拉克奥尔巴扎尔', 26.9798200, 84.8506500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76460, 'Rāwatsār', 'Rawatsar', 'Rawatsar,Rāwatsār', 29.2672400, 74.4028800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76461, 'Rāwatbhāta', 'Rawatbhata', 'Rawat Bhatta,Rawatbhaia,Rawatbhata,Rāwatbhāta', 24.9298100, 75.5920900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76462, 'Rāver', 'Raver', 'Raver,Rāver', 21.2475700, 76.0350900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76463, 'Ratnagiri', 'Ratnagiri', 'RTC,Ratnagiri,Ratnāgiri,Rutnagherry,irattinakiri,la te na ji li,ratnagiri,rtnagry,Ратнагири,رتناگری,रत्नगिरी,रत्नागिरि,रत्‍नागिरी,রত্নগিরি,રત્નાગિરી,ରତ୍ନଗିରି,இரத்தினகிரி,ರತ್ನಾಗಿರಿ,拉特纳吉里', 16.9915400, 73.3102200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76464, 'Ratlām', 'Ratlam', 'Hatlam,Ratlam,Ratlām', 23.3303300, 75.0403200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76465, 'Ratia', 'Ratia', 'Ratia,Ратиа', 29.6902900, 75.5768800, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76466, 'Rāth', 'Rath', 'Rata,Rath,Rāth,Рата', 25.5947400, 79.5666000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76467, 'Ratanpur', 'Ratanpur', 'Ratanpur', 22.2866000, 82.1682300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76468, 'Ratangarh', 'Ratangarh', '', 28.0813700, 74.6185400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76469, 'Ratangarh', 'Ratangarh', 'Ratangarh', 24.8166700, 75.1166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76470, 'Rasūlābād', 'Rasulabad', '', 26.7449100, 80.4901200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76471, 'Rasrā', 'Rasra', 'Rasra,Rasrā', 25.8576000, 83.8548700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76472, 'Rasipuram', 'Rasipuram', 'Rasipur,Rasipuram,Rāsipuram,Rāsīpur', 11.4600900, 78.1863500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76473, 'Rāpar', 'Rapar', 'Rapar,Rāpar', 23.5726700, 70.6471800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76474, 'Rānīr Bāzār', 'Ranir Bazar', '', 23.8346300, 91.3661400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76475, 'Rānīpur', 'Ranipur', 'Ranipur,Rānīpur', 25.2503400, 79.0620400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76476, 'Rānikhet', 'Ranikhet', 'Ranikhet,Rawikhet,Rānikhet,Rānīkhet,Rāwikhet', 29.6408200, 79.4322900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76477, 'Rānīganj', 'Raniganj', 'Ranigandzhe,Raniganj,Rānīganj,Ранигандже', 23.6164000, 87.1306100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76478, 'Rānībennur', 'Ranibennur', 'Ranibennur,Renibennur,Rānībennur', 14.6223900, 75.6295100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76479, 'Rānia', 'Rania', 'Rania,Ranija,Raniya,Rānia,Рания', 29.5245400, 74.8368900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76480, 'Rāni', 'Rani', 'Rani,Rāni', 25.3503100, 73.3088500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76481, 'Rangpo', 'Rangpo', 'Rangpo,Rongphu,Rungpo', 27.1773300, 88.5335800, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76482, 'Rangia', 'Rangia', 'Ranga Nadi,Rangia,Rangiya,Rangā Nadī', 26.4493100, 91.6135600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76483, 'Rangāpāra', 'Rangapara', 'Rangapara,Rangāpāra', 26.8377200, 92.6687600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76484, 'Ranchi', 'Ranchi', 'IXR,Ranchi,Ranci,Rancis,Rancsi,Ranĉi,Rančis,Ráncsí,Ráňčí,Rānchi,Rānchī,lan qi,lanchi,raci,ramci,ranchi,ranchy,ranci,ranci jilla,ranshy,rʼnzy,Ранчи,Ранчі,ראנצי,رانشي,رانچي,رانچی,राँची,रांची,रांची जिल्ला,রাঁচি,রাচি,ਰਾਂਚੀ,રાંચી,ରାଞ୍ଚି,ராஞ்சி,రాంచీ,ರಾಂಚಿ,റാഞ്ചി,რანჩი,ラーンチー,蘭契,란치', 23.3431600, 85.3094000, 'IN', '2016-02-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76485, 'Rānāvāv', 'Ranavav', 'Ranavav,Ranawao,Rānāvāv,Rānāwāo', 21.6873400, 69.7448500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76486, 'Rānāpur', 'Ranapur', 'Ranapur,Rānapur,Rānāpur', 22.6470400, 74.5211800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76487, 'Rānāghāt', 'Ranaghat', 'Ranaghat,Rānāghāt', 23.1762300, 88.5666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76488, 'Rāmtek', 'Ramtek', 'Ramtek,Rāmtek,Рамтек', 21.3956200, 79.3272500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76489, 'Rampur Hat', 'Rampur Hat', '', 24.1773700, 87.7827500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76490, 'Rāmpura', 'Rampura', '', 30.2560000, 75.2411600, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76491, 'Rāmpura', 'Rampura', 'Rampura,Rāmpura', 26.3496700, 79.1823400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76492, 'Rāmpura', 'Rampura', 'Rampura,Rāmpura', 24.4670000, 75.4399600, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76493, 'Rāmpur', 'Rampur', 'Rampur,Rampur Bushahr,Rāmpur,Рампур', 31.4494300, 77.6308700, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76494, 'Rāmpur', 'Rampur', '', 29.8062000, 77.4525100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76495, 'Rāmpur', 'Rampur', 'Rampur,Rāmpur', 28.8101400, 79.0269900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76496, 'Rāmnagar', 'Ramnagar', 'Ramnagar,Rāmnagar', 32.8072800, 75.3111900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76497, 'Rāmnagar', 'Ramnagar', 'Ramnagar,Rāmnagar', 29.3925000, 79.1283000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76498, 'Rāmnagar', 'Ramnagar', 'Ramnagar,Rāmnagar', 27.1637100, 84.3234200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76499, 'Rāmnagar', 'Ramnagar', '', 27.0849900, 81.4057500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76500, 'Rāmnagar', 'Ramnagar', 'Ramnagar,Rāmnagar', 25.2690700, 83.0297100, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76501, 'Rāmkola', 'Ramkola', 'Ramkola,Rāmkola', 26.9017200, 83.8375800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76502, 'Rāmjībanpur', 'Ramjibanpur', 'Ramjibanpur,Rāmjībanpur', 22.8281500, 87.6088800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76503, 'Rāmgundam', 'Ramgundam', 'Ramagundam,Ramgundam,Rāmgundam,ramagundam,రామగుండం', 18.8008400, 79.4520600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76504, 'Rāmgarh', 'Ramgarh', '', 33.4037900, 74.2238800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76505, 'Rāmgarh', 'Ramgarh', 'Ramgarh,Rāmgarh', 27.2509700, 75.1789300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76506, 'Rāmgarh', 'Ramgarh', 'Ramgarh,Rāmgarh', 23.6301800, 85.5192600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76507, 'Rāmganj Mandi', 'Ramganj Mandi', 'Ramganj Mandi,Rāmganj Mandi', 24.6464800, 75.9432500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76508, 'Rameswaram', 'Rameswaram', 'Rameshvaram,Ramesvaram,Rameswaram,Rámesvaram,Rāmeswaram,iramecuvaram,la mei si wa la mu,ramesbarama,rameshuwaramu,ramesvaram,ramesvarama,ramesvarama sahara,ramesvarama tirtha,ramesvaramu,rameswarama,Рамешварам,रामेश्वरम,रामेश्वरम तीर्थ,रामेश्वरम शहर,রামেশ্বরম,રામેશ્વરમ,ରାମେଶ୍ୱରମ,இராமேசுவரம்,రామేశ్వరము,ರಾಮೇಶ್ವರಮ್,രാമേശ്വരം,රාමේෂ්වරම්,ラーメーシュワラム,拉梅斯瓦拉姆', 9.2885000, 79.3127100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76509, 'Rām Dās', 'Ram Das', '', 31.9673900, 74.9087000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76510, 'Rambha', 'Rambha', 'Rambha', 19.5166700, 85.1000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76511, 'Rāmban', 'Ramban', 'Ramban,Rāmban', 33.2427800, 75.2351300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76512, 'Rāmāpuram', 'Ramapuram', 'Ramapuram,Ramāpuram,Rāmāpuram', 15.2874900, 77.8672200, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76513, 'Rāmāpuram', 'Ramapuram', '', 13.1009100, 79.1841000, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76514, 'Rāmānuj Ganj', 'Ramanuj Ganj', 'Ramanuj Ganj,Rāmānuj Ganj', 23.8063700, 83.6998100, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76515, 'Ramanathapuram', 'Ramanathapuram', 'Ramanathapuram,Ramanatkhapuram,Ramanatkhapurama,Ramanthapuram,Ramnad,Rāmanāthapuram,iramanatapuram,la ma na ta pu la mu,ramanatapuramu,ramanathapuram,ramanathapurama,ramanthapurama,Раманатхапурам,Раманатхапурама,रामनाथपुरम,रामनाथपुरम्,রমন্থাপুরম,રામનાથપુરમ,ରାମନାଥପୁରମ,இராமநாதபுரம்,ラーマナータプラム,拉马纳塔普拉姆', 9.3715800, 78.8307700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76516, 'Closepet', 'Closepet', 'Closepet,Ramanagaram,Rāmanagaram,Раманагарам', 12.7218100, 77.2814900, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76517, 'Rāmamangalam', 'Ramamangalam', 'Ramamangalam,Rāmamangalam', 9.9333300, 76.5000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76518, 'Rāmachandrapuram', 'Ramachandrapuram', 'Ramachandrapuram,Rāmachandrapuram', 16.8363600, 82.0287100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76519, 'Rājūra', 'Rajura', 'Rajura,Rājūra', 19.7794700, 79.3645900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76520, 'Rājur', 'Rajur', 'Rajur,Rājur', 20.1108700, 78.8931100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76521, 'Rājula', 'Rajula', 'Rajula,Rājula', 21.0385400, 71.4434500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76522, 'Rājsamand', 'Rajsamand', 'Rajsamand,Rājsamand', 25.0714500, 73.8798000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76523, 'Rājpura', 'Rajpura', 'Kajpura,Rajpura,Rājpura', 30.4785600, 76.5928400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76524, 'Rajpur', 'Rajpur', 'Alirajpur,Rajpur,Rājpur', 22.3039300, 74.3556800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76525, 'Rajpur', 'Rajpur', 'Rajpur,Rājpur', 21.9402200, 75.1360800, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76526, 'Rājpīpla', 'Rajpipla', '', 21.8666700, 73.5000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76527, 'Rāj-Nāndgaon', 'Raj-Nandgaon', 'Raj Nandga,Raj Nandgaon,Raj-Nandgaon,Rāj Nāndgaon,Rāj-Nāndgaon', 21.0968700, 81.0289000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76528, 'Rājnagar', 'Rajnagar', 'Rajnagar,Rājnagar', 24.8892900, 79.9117800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76529, 'Rājmahal', 'Rajmahal', 'Rajmahal,Rājmahal', 25.0530300, 87.8304800, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76530, 'Rājkot', 'Rajkot', 'RAJ,Radzhkot,Radzkot,Radzkotas,Radźkot,Radžkotas,Rajkot,Rājkot,rajikotto,Раджкот,ラージコット', 22.2916100, 70.7932200, 'IN', '2017-03-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76531, 'Rājgurunagar', 'Rajgurunagar', 'Rajgurunagar,Rājgurunagar', 18.8666700, 73.9000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76532, 'Rājgīr', 'Rajgir', 'Radzhgir,Rajagriha,Rajgir,Rajgriha,Rājagriha,Rājgīr,Раджгир', 25.0282800, 85.4207900, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76533, 'Rājgarh', 'Rajgarh', 'Rajgarh,Rājgarh', 30.8514200, 77.3006600, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76534, 'Rājgarh', 'Rajgarh', 'Sadulpur,rajagarha,राजगढ़', 28.6420100, 75.3861200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76535, 'Rājgarh', 'Rajgarh', 'Rajgarh,Rājgarh', 27.2373100, 76.6224300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76536, 'Rājgarh', 'Rajgarh', '', 24.0082600, 76.7325000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76537, 'Rājgarh', 'Rajgarh', 'Rajgarh,Rājgarh', 22.6782100, 74.9448300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76538, 'Rajaori', 'Rajaori', 'Rajaori,Rajauri,Rājaori,Rājauri', 33.3752600, 74.3092000, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76539, 'Rāja Sānsi', 'Raja Sansi', 'Raja Sansi,Rāja Sānsi', 31.7202100, 74.8008000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76540, 'Rājāpur', 'Rajapur', 'Majhgawan,Majhgawān,Rajapur,Rājāpur', 25.3872500, 81.1512500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76541, 'Rājāpur', 'Rajapur', 'Rajapur,Rājāpur', 16.6567900, 73.5170100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76542, 'Rajapalaiyam', 'Rajapalaiyam', 'Rajapalaiyam,Rajapalayam,Rājapālaiyam', 9.4529600, 77.5533500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76543, 'Rāzampeta', 'Razampeta', 'Rajampet,Razampeta,Rājampet,Rāzampeta', 14.1954400, 79.1589600, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76544, 'Rājaldesar', 'Rajaldesar', 'Rajaldesar,Rājaldesar', 28.0284900, 74.4744200, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76545, 'Rājākhera', 'Rajakhera', 'Rajakhera,Rājākhera', 26.8980200, 78.1710000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76546, 'Rājahmundry', 'Rajahmundry', 'RJA,Radzhamandri,Rajahmondry,Rajahmundry,Rajamahendravaram,Rajamahendri,Rajamandri,Rājahmundry,Rājamahendravaram,rajamandri,Раджамандри,రాజమండ్రి', 17.0051700, 81.7778400, 'IN', '2017-03-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76547, 'Rāīwāla Bara', 'Raiwala Bara', 'Raiwala,Raiwala Bara,Rāiwāla,Rāiwāla Bara,Rāīwāla Bara', 30.0186400, 78.2293000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76548, 'Rāisinghnagar', 'Raisinghnagar', 'Raisinghnagar,Rāisinghnagar', 29.5358300, 73.4491700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76549, 'Raisen', 'Raisen', 'Raisen', 23.3303300, 77.7811000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76550, 'Rāipur', 'Raipur', 'Raipur,Rāipur', 30.3109700, 78.0897900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76551, 'Raipur', 'Raipur', 'Raipur', 26.0425900, 74.0237300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76552, 'Raipur', 'Raipur', 'RPR,Raipur,Raipura,Raipuras,Rajpur,Rajpuro,Rayapura,Raypur,Rájpur,lai bu er,laipuleu,ra''ipura,raipuru,ray pwr,rayapura,raybwr,rayppur,raypur,Райпур,Рајпур,Ռայպուր,رائے پور,رايبور,رای پور,رای‌پور,راۓپور,रायपुर,रायपूर,রাইপুর,রায়পুর,ਰਾਇਪੁਰ,રાયપુર,ରାୟପୁର,ராய்ப்பூர்,రాయ్‌పుర్,ರಾಯ್ಪುರ್,റായ്‌പൂർ,რაიპური,ラーイプル,賴布爾,라이푸르', 21.2333300, 81.6333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76553, 'Rāikot', 'Raikot', 'Raikot,Rāikot', 30.6500000, 75.6000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76554, 'Raigarh', 'Raigarh', 'Raigarh,Raigârh,Rajgarkh,lai jia er,rayagadha,rayagara,rayjarh,Райгарх,رائے گڑھ,رايجاره,रायगढ,রায়গড়,રાયગઢ,ରାୟଗଢ,赖加尔', 21.8976400, 83.3966000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76555, 'Rāiganj', 'Raiganj', 'Raiganj,Rayganj,Rāiganj', 25.6128100, 88.1244900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76556, 'Rāichūr', 'Raichur', 'Raichur,Rajchur,Rāichūr,Райчур', 16.2054600, 77.3556700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76557, 'Raia', 'Raia', 'Raia', 15.3049900, 73.9709600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76558, 'Rāhuri', 'Rahuri', 'Rahuri,Rāhuri', 19.3906900, 74.6497900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76559, 'Rāhon', 'Rahon', 'Rabon,Rahon,Rāhon', 31.0527500, 76.1190700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76560, 'Rahimatpur', 'Rahimatpur', 'Rahimatpur,Rahunatpur', 17.5921000, 74.1996600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76561, 'Rāhatgarh', 'Rahatgarh', 'Rahatgarh,Rāhatgarh', 23.7896800, 78.3947300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76562, 'Rahā', 'Raha', '', 26.2333300, 92.5166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76563, 'Raghunāthpur', 'Raghunathpur', '', 25.6449200, 87.9176200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76564, 'Raghunathpur', 'Raghunathpur', 'Raghunathpur,Raghunāthpur', 23.5387800, 86.6735000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76565, 'Rāghogarh', 'Raghogarh', 'Raghogarh,Raghugarh,Rāghogarh,Rāghugarh', 24.4431800, 77.1976800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76566, 'Rafiganj', 'Rafiganj', 'Rafiganj', 24.8175700, 84.6344500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76567, 'Raebareli', 'Raebareli', 'Rae Bareli,Raebareli,Rāe Bareli', 26.2309000, 81.2331500, 'IN', '2015-08-15', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76568, 'Rādhanpur', 'Radhanpur', 'Radhanpur,Rādhanpur', 23.8323800, 71.6047000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76569, 'Rādhākund', 'Radhakund', 'Radha Kund,Radhakund,Rādha Kund,Rādhākund', 27.5243200, 77.4910100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76570, 'Radaur', 'Radaur', 'Radaur', 30.0270600, 77.1517700, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76571, 'Rabūpura', 'Rabupura', 'Rabupura,Rabūpura', 28.2515300, 77.6025300, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76572, 'Rabkavi', 'Rabkavi', '', 16.4756700, 75.1106000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76573, 'Kollam', 'Kollam', 'Coilum,Coulao,Coulão,Desinganadu,Kolam,Kolamo,Kollam,Kol·lam,Kullamalai,Kvilon,Quilon,keallam,kollam,kollama,korramu,kui long,kwlam,kwlm,Квилон,Колам,Коллам,کولام,کولم,कोल्लम,कोल्लम्,কোল্লম,কোল্লাম,કોલ્લમ,କୋଲ୍ଲାମ୍,கொல்லம்,കൊല്ലം,コッラム,奎隆,콜람', 8.8811300, 76.5846900, 'IN', '2016-06-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76574, 'Queula', 'Queula', 'Queula', 15.3901100, 73.9855700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76575, 'Quepem', 'Quepem', 'Quepem,Quepem Town', 15.2128000, 74.0772000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76576, 'Qāzigund', 'Qazigund', 'Qazigund,Qāzigund', 33.6382800, 75.1426100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76577, 'Kasba', 'Kasba', 'Kasba,Qasba', 25.8564300, 87.5383600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76578, 'Qādiān', 'Qadian', 'Kadian,Kādiān,Qadian,Qādiān', 31.8219800, 75.3766300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76579, 'Puttūr', 'Puttur', 'Puttur,Puttūr', 13.4418900, 79.5531400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76580, 'Puttūr', 'Puttur', 'Puttur,Puttūr', 12.7597500, 75.2016900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76581, 'Pushkar', 'Pushkar', 'Pouskar,Pushkar,Puskar,Puskár,Puszkar,Púshkar,pshkr,pu si he ka er,pusakara,puskar,puskara,puskaranagaram,pwsqr,Πουσκάρ,Пушкар,פושקר,پشکر,पुष्कर,पुष्करनगरम्,पुस्कर,পুষ্কর,ਪੁਸ਼ਕਰ,પુષ્કર,புஷ்கர்,పుష్కర్,普斯赫卡尔', 26.4902200, 74.5521100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76582, 'Pusad', 'Pusad', 'Pusad', 19.9127400, 77.5783800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76583, 'Purwā', 'Purwa', 'Purwa,Purwā', 26.4575600, 80.7740300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76584, 'Purushottampur', 'Purushottampur', 'Purushottampur,Purusottampur', 19.5202400, 84.8851400, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76585, 'Puruliya', 'Puruliya', 'Purulia,Puruliya', 23.3306200, 86.3630300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76586, 'Purnia', 'Purnia', 'Purnia,Purnija,Pūrnia,bwrnya,pu er ni ya,puraniya,purni''a,purniya,pwrnya,Пурния,Пурнија,بورنيا,پورنیا,پورنیہ,पुर्णिया,पूर्णिया,পুরনিয়া,পূর্ণিয়া,ପୁର୍ନିଆ,பூர்ணியா,普尔尼亚', 25.7789500, 87.4742200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76587, 'Pūrna', 'Purna', 'Purna,Pūrna,Пурна', 19.1817000, 77.0256600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76588, 'Puri', 'Puri', 'Jagannath,Jagannathpur,Jagannāth,Puri,Puri District,Purî,puri,pwry,Пури,פורי,পুরি,பூரி,プーリ', 19.7982500, 85.8249400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76589, 'Pūranpur', 'Puranpur', 'Puranpur,Pūranpur', 28.5128300, 80.1482900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76590, 'Pupri', 'Pupri', 'Janakpur Road,Pupri', 26.4707900, 85.7031100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76591, 'Punjai Puliyampatti', 'Punjai Puliyampatti', '', 11.3516300, 77.1667100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76592, 'Punganūru', 'Punganuru', '', 13.3667200, 78.5718600, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76593, 'Pune', 'Pune', 'PNQ,Pona,Poona,Poune,Pun,Puna,Pune,Puneo,Puno,Puné,Púna,bwnh,poona,pu na,puna,pune,pune sahara,punyapattanam,pwna,pwnh,pwny,pwnہ,Πούνε,Пуна,Пуне,Пуно,Պունա,פונה,بونه,پونا,پونه,پونہ,پونی,पुणे,पुणे शहर,पुण्यपट्टनम्,পুনে,ਪੂਨਾ,પુના,ପୁଣେ,புனே,పూణే,ಪುಣೆ,പൂണെ,პუნა,プネー,浦那,푸네', 18.5195700, 73.8553500, 'IN', '2015-06-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76594, 'Pūndri', 'Pundri', 'Pundri,Pūndri', 29.7609600, 76.5603400, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76595, 'Punāsa', 'Punasa', '', 22.2350700, 76.3933500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76596, 'Punalūr', 'Punalur', 'Punalur,Punalūr', 9.0195600, 76.9226100, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76597, 'Pūnāhāna', 'Punahana', 'Punahana,Punāhāna,Pūnāhāna', 27.8637100, 77.2043200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76598, 'Pulwama', 'Pulwama', 'Pulawom,Pulwama', 33.8740500, 74.8995500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76599, 'Pullambādi', 'Pullambadi', 'Pullambadi,Pullambādi,Pullampadi', 10.9410800, 78.9081600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76600, 'Puliyūr', 'Puliyur', 'Puliyur,Puliyūr', 10.6329200, 78.8410300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76601, 'Puliyangudi', 'Puliyangudi', 'Puliyangudi,Puliyankudi', 9.1748900, 77.3979900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76602, 'Pulivendla', 'Pulivendla', '', 14.4213900, 78.2250200, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76603, 'Pulgaon', 'Pulgaon', 'Pulgaon', 20.7220400, 78.3205600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76604, 'Pukhrāyān', 'Pukhrayan', 'Pukhrayan,Pukhrāyān', 26.2237500, 79.8373900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76605, 'Puduvāyal', 'Puduvayal', 'Puduvayal,Puduvāyal', 13.3301500, 80.1457700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76606, 'Pudūr', 'Pudur', '', 12.9980100, 79.1435200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76607, 'Pudūr', 'Pudur', '', 9.2914700, 78.1354500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76608, 'Puduppatti', 'Puduppatti', '', 11.1508300, 78.2119700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76609, 'Pudukkottai', 'Pudukkottai', 'Poodoocottah,Puducotai,Pudukattai,Pudukkottai,Pudukkottai-Trichinopoly,Pudukkottaj,Pudukotah,Pudukottai,pu du ke tai,pudo~ukottai,pudukkotta''i,purukkotta''i,putukkottai,Пудуккоттай,পুড়ুক্কোত্তাই,ପୁଡୁକ୍କୋଟ୍ଟାଇ,புதுக்கோட்டை,プドゥコーッタイ,普杜科泰', 10.3812800, 78.8214100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76610, 'Proddatūr', 'Proddatur', 'Proddatur,Proddatūr,prodduturu,ప్రొద్దుటూరు', 14.7502000, 78.5481300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76611, 'Pratāpgarh', 'Pratapgarh', 'Partabgarh City,Partapgarh,Pratapgarh,Pratāpgarh', 25.8950900, 81.9424000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76612, 'Pratāpgarh', 'Pratapgarh', 'Partabgarh,Partapgarh,Pratabgarh,Pratapgarh,Pratābgarh,Pratāpgarh', 24.0321500, 74.7816200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76613, 'Port Blair', 'Port Blair', 'Gorad Port-Blehr,IXZ,Port Blair,Port Bler,Port Bleras,Port-Blehr,Port-Bler,Portus Blairensis,bu lai er gang,porata bale''ara,port bler,port piler,porta blera,porta bleyara,portableyara,poteubeulleeo,potoburea,pwrt blr,pwrt blyyr,Горад Порт-Блэр,Порт Блер,Порт-Блер,Порт-Блэр,פורט בלייר,پورت بلر,پورٹ بلیئر,पोर्ट ब्लेयर,पोर्ट ब्लेर,पोर्टब्लेयर,পোর্ট ব্লেয়ার,ਪੋਰਟ ਬਲੇਅਰ,પોર્ટ બ્લૅર,ପୋର୍ଟ ବ୍ଲେୟର,போர்ட் பிளேர்,ಪೋರ್ಟ್ ಬ್ಲೇರ್,പോർട്ട് ബ്ലെയർ,พอร์ตแบลร์,პორტ-ბლერი,ポートブレア,布萊爾港,포트블레어', 11.6661300, 92.7463500, 'IN', '2017-05-24', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76614, 'Porsa', 'Porsa', 'Porsa,Порса', 26.6744400, 78.3708100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76615, 'Porbandar', 'Porbandar', 'PBD,Poorbunder,Porbandar,Porbandarom,Port Porbandar,Purbandar,bo er ben de er,bwrbndr,poleubandaleu,porabandara,porpantar,Порбандар,Порбандаром,بوربندر,पोरबंदर,पोरबन्दर,পোরবন্দর,પોરબંદર,ପୋରବନ୍ଦର,போர்பந்தர்,పోర్‌బందర్,പോർബന്തർ,博尔本德尔,포르반다르', 21.6421900, 69.6092900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76616, 'Poonamalle', 'Poonamalle', 'Poonamallee', 13.0488800, 80.1148800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76617, 'Ponnūru', 'Ponnuru', '', 16.0654700, 80.5520300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76618, 'Ponneri', 'Ponneri', 'Ponneri,bo nei li,ponneri,পোন্নেরি,ପୋନ୍ନେରି,பொன்னேரி,波内里', 13.3386800, 80.1948700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76619, 'Ponnāni', 'Ponnani', 'Ponani,Ponnani,Ponnāni', 10.7669500, 75.9252300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76620, 'Ponnampet', 'Ponnampet', 'Ponnampet', 12.1447300, 75.9451400, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76621, 'Ponnamarāvati', 'Ponnamaravati', 'Ponnamaravathy,Ponnamaravati,Ponnamarāvati', 10.2817800, 78.5355400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76622, 'Puducherry', 'Puducherry', 'PNY,Pondicero,Pondicheri,Pondicherri,Pondicherry,Pondichery,Pondichéri,Pondichéry,Pondiseri,Pondisheri,Pondiĉero,Ponducherry,Pondy,Poudhucherry,Puduchcheri,Puducherri,Puducherry,Puduvai,Territoire de Pondichery,Territoire de Pondichéry,ben de zhi li,ben de zhi li shi,pandiceri,panticceri,pondiceri,pondisheri,Пондишери,Пондішері,पॉण्डिचेरी,পন্ডিচেরী,પૉંડિચેરી,பாண்டிச்சேரி,პონდიშერი,ポンディシェリ,本地治里,本地治里市', 11.9338100, 79.8297900, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76623, 'Ponda', 'Ponda', 'Cassabe de Ponda,Cassabé de Pondá,Ponda', 15.4034100, 74.0151900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76624, 'Polūr', 'Polur', 'Polur,Polūr', 12.5121700, 79.1240500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76625, 'Pollachi', 'Pollachi', 'Pollachi,Pollāchi,bo la qi,peallacci,pollacci,pollaci,pwlachy,پولاچی,पोल्लाची,পোল্লাচি,ପୋଲ୍ଲାଚି,பொள்ளாச்சி,పొల్లాచి,പൊള്ളാച്ചി,波拉奇', 10.6582500, 77.0085000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76626, 'Polavaram', 'Polavaram', 'Polarvaram,Polavaram', 17.2475400, 81.6437200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76627, 'Polasara', 'Polasara', 'Polasara', 19.6938600, 84.8140100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76628, 'Pokaran', 'Pokaran', 'Pokaran,Pokhran', 26.9200700, 71.9163100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76629, 'Pithorāgarh', 'Pithoragarh', 'Pathorgarh,Pithoragarh,Pithoragari,Pithorāgarh', 29.5834900, 80.2094700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76630, 'Pithora', 'Pithora', 'Pithora', 21.2502100, 82.5170700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76631, 'Pithāpuram', 'Pithapuram', 'Pithapuram,Pithāpuram', 17.1168000, 82.2528400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76632, 'Piro', 'Piro', 'Piro', 25.3321800, 84.4045400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76633, 'Piriyāpatna', 'Piriyapatna', 'Piriyapatna,Piriyāpatna', 12.3349700, 76.1007300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76634, 'Pirāwa', 'Pirawa', 'Pirawa,Pirāwa', 24.1550600, 76.0272800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76635, 'Piravam', 'Piravam', 'Piravam,Piravom', 9.8666700, 76.5000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76636, 'Pīpri', 'Pipri', 'Peepri,Pipri,Pīpri', 19.7937100, 75.5351900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76637, 'Pipraich', 'Pipraich', 'Pipraich', 26.8274500, 83.5263200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76638, 'Pippara', 'Pippara', 'Pippara', 16.7166700, 81.5500000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76639, 'Piploda', 'Piploda', 'Piploda', 23.3500000, 75.4333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76640, 'Pipili', 'Pipili', 'Pipili,Pipli', 20.1135700, 85.8314700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76641, 'Pīpār', 'Pipar', '', 26.3844100, 73.5439400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76642, 'Pīpalkoti', 'Pipalkoti', '', 30.4255300, 79.4306600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76643, 'Pinjaur', 'Pinjaur', 'Pinjaur', 30.7987300, 76.9182200, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76644, 'Pindwāra', 'Pindwara', 'Pindwara,Pindwāra', 24.7974900, 73.0550500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76645, 'Pināhat', 'Pinahat', 'Pinahat,Pināhat', 26.8848700, 78.3764700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76646, 'Pimpri', 'Pimpri', 'Pimpri', 18.6229200, 73.8069600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76647, 'Pilkhua', 'Pilkhua', 'Pilkhua,Pilkhuwa', 28.7127100, 77.6560000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76648, 'Pīlibhīt', 'Pilibhit', 'Pilibhhit,Pilibhit,Pilibkhit,Pīlibhīt,Pīlībhīt,Пилибхит', 28.6312400, 79.8043600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76649, 'Pilibangan', 'Pilibangan', 'Pilibanga,Pilibangan', 29.4496400, 74.1009300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76650, 'Pilāni', 'Pilani', 'Pilani,Pilāni', 28.3672500, 75.6035200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76651, 'Pihānī', 'Pihani', 'Pihani,Pihāni,Pihānī', 27.6198700, 80.2034300, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76652, 'Phūlpur', 'Phulpur', '', 26.0777900, 82.8760800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76653, 'Phulpur', 'Phulpur', 'Phulpur,Phūlpur', 25.5489500, 82.0895000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76654, 'Phulera', 'Phulera', 'Phalera,Phulera', 26.8740100, 75.2417100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76655, 'Phulabāni', 'Phulabani', 'Phulabani,Phulabāni,Phulbam,Phulbani,Phulbāni', 20.4791600, 84.2316200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76656, 'Phirangipuram', 'Phirangipuram', 'Phirangipuram', 16.2907800, 80.2623300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76657, 'Phillaur', 'Phillaur', 'Phillaur', 31.0188700, 75.7911100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76658, 'Phek', 'Phek', 'Phek', 25.6666700, 94.5000000, 'IN', '2012-05-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76659, 'Pharihā', 'Phariha', 'Phariha,Pharihā', 27.3216600, 78.4726700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76660, 'Phaphūnd', 'Phaphund', 'Phaphund,Phaphūnd', 26.5988800, 79.4643700, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76661, 'Phaltan', 'Phaltan', 'Phaltan,pa er tan,phalatana,پھلتان,फलटण,ফালটান,ફલટણ,ଫଲଟନ,帕尔坦', 17.9911300, 74.4317700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76662, 'Phalodi', 'Phalodi', 'Phalodi', 27.1310200, 72.3682600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76663, 'Phalauda', 'Phalauda', 'Phalauda', 29.1882400, 77.8299600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76664, 'Phagwāra', 'Phagwara', 'Phagwara,Phagwāra', 31.2245200, 75.7738700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76665, 'Petlāwad', 'Petlawad', 'Petlawad,Petlāwad', 23.0110200, 74.7977200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76666, 'Petlād', 'Petlad', 'Petlad,Petlād', 22.4768100, 72.7999500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76667, 'Perūr', 'Perur', 'Melai Citamparam,Perur,Perūr', 10.9751900, 76.9129200, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76668, 'Perundurai', 'Perundurai', 'Perundurai,Perundural', 11.2756400, 77.5879400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76669, 'Perumpāvūr', 'Perumpavur', '', 10.1154400, 76.4761100, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76670, 'Pernem', 'Pernem', 'Cassabe-de-Pernem,Cassabé-de-Pernem,Pernem', 15.7230000, 73.7951100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76671, 'Periyapatti', 'Periyapatti', 'Periyapatti', 10.7581200, 77.2708700, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76672, 'Periyanegamam', 'Periyanegamam', '', 10.7431700, 77.1029600, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76673, 'Periyanayakkanpalaiyam', 'Periyanayakkanpalaiyam', 'Periyanaikanpalayam,Periyanayakkanpalaiyam,Periyanāyakkanpālaiyam,periyanayakkanpalaiyam,பெரியநாயக்கன்பாளையம்', 11.1525500, 76.9515900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76674, 'Periyakulam', 'Periyakulam', 'Periyakulam', 10.1212700, 77.5439200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76675, 'Perya', 'Perya', 'Periya,Perya', 11.8333400, 75.8540800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76676, 'Peravurani', 'Peravurani', 'Peravurani,Peravurni,Perāvūrani', 10.2903500, 79.2015600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76677, 'Peranāmpattu', 'Peranampattu', 'Peranambattu,Peranampattu,Peranāmbattu,Peranāmpattu,Pernambut', 12.9343000, 78.7189000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76678, 'Peranamallūr', 'Peranamallur', 'Peranamallur,Peranamallūr', 12.5705200, 79.4333200, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76679, 'Perambalur', 'Perambalur', 'Perambalur,Perambalūr,byrmbalwr,pei la mu ba lu er,peramabalura,perambalura,perambaluru,perampalur,peranbaruru,Перамбалур,بيرمبالور,पेरम्बलूरु,পেরামবালুর,ପେରାମ୍ବାଲୁର,பெரம்பலூர்,ペランバルール,佩拉姆巴卢尔', 11.2333300, 78.8833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76680, 'Peraiyur', 'Peraiyur', 'Paryur,Peraiyur,Peraiyūr', 9.7357900, 77.7895500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76681, 'Penukonda', 'Penukonda', 'Penukonda', 14.0828600, 77.5947300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76682, 'Penugonda', 'Penugonda', 'Penugonda', 16.6536300, 81.7455000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76683, 'Pennāthur', 'Pennathur', 'Pennathur,Pennattur,Pennāthur,Pennāttūr', 12.2468100, 79.2259200, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76684, 'Pennāgaram', 'Pennagaram', 'Pennagaram,Pennāgaram', 12.1343300, 77.8952500, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76685, 'Pennādam', 'Pennadam', 'Pennadam,Pennādam', 11.4031600, 79.2410300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76686, 'Pendra', 'Pendra', 'Pendra', 22.7754800, 81.9596800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76687, 'Pen', 'Pen', 'Pen', 18.7373400, 73.0960300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76688, 'Pehowa', 'Pehowa', 'Pehowa', 29.9789700, 76.5824900, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76689, 'Peddāpuram', 'Peddapuram', 'Peddapuram,Peddapuram Town,Peddāpuram', 17.0770100, 82.1383600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76690, 'Peddapalli', 'Peddapalli', '', 18.6135700, 79.3744200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76691, 'Pedana', 'Pedana', 'Pedana', 16.2558200, 81.1437800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76692, 'Payyannūr', 'Payyannur', 'Payyannur,Payyannūr,Payyanur', 12.0935000, 75.2024900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76693, 'Pawāyan', 'Pawayan', 'Pawayan,Pawāyan', 28.0662600, 80.1030500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76694, 'Pawai', 'Pawai', 'Pawai', 24.2663500, 80.1619600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76695, 'Pāvugada', 'Pavugada', 'Pavagada,Pavugada,Pāvagada,Pāvugada', 14.0995300, 77.2801800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76696, 'Pauri', 'Pauri', 'Pauri,bao li,pa''uri,paudi,pauri,Паури,Паурі,पौड़ी,पौडी,পাউরি,પૌડી,ପାଉରି,保里', 30.1528600, 78.7771000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76697, 'Pawni', 'Pawni', 'Pauni,Pawni', 20.7922900, 79.6364400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76698, 'Pātūr', 'Patur', 'Patur,Pātūr', 20.4609300, 76.9372500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76699, 'Pātuli', 'Patuli', 'Patuli,Pātuli', 23.5528600, 88.2647300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76700, 'Pattukkottai', 'Pattukkottai', 'Pattukkottai,pa tu ke tai,pattukkotta''i,pattukkottai,pattukotta''i,পাত্তুক্কোত্তাই,ପାତ୍ତୁକୋଟ୍ଟାଇ,பட்டுக்கோட்டை,帕图科泰', 10.4235800, 79.3194900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76701, 'Patti', 'Patti', 'Patti', 31.2809200, 74.8584900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76702, 'Patti', 'Patti', 'Patti,Патти', 25.9215000, 82.2004800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76703, 'Pattan', 'Pattan', 'Patan,Pattan', 34.1612500, 74.5563400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76704, 'Pātrasāer', 'Patrasaer', 'Patrasaer,Patrassyar,Pātrasāer', 23.1969700, 87.5331900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76705, 'Patnāgarh', 'Patnagarh', 'Patnagarh,Patnāgarh', 20.7083300, 83.1326300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76706, 'Patna', 'Patna', 'New Patna,PAT,Patna,Patna New City,Patnao,ba te na,batna,pat na,patana,pateuna,patna,patona,ptnh,Πάτνα,Патна,Պատնա,פטנה,باتنا,پتنه,پٹنہ,پټنا,पटना,पाटणा,पाट्ना,পাটনা,ਪਟਨਾ,પટના,ପାଟଣା,பட்னா,பாட்னா,పాట్నా,ಪಟ್ನಾ,പട്ന,ปัฏนา,პატნა,パトナ,パトナー,巴特那,파트나', 25.5940800, 85.1356300, 'IN', '2016-02-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76707, 'Patiāli', 'Patiali', '', 27.6908600, 78.9982300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76708, 'Patiāla', 'Patiala', 'Pat''jala,Patiala,Patiāla,Патьяла', 30.3362500, 76.3922000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76709, 'Pāthri', 'Pathri', 'Pathri,Patri,Pāthri,Патри', 19.2588000, 76.4341200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76710, 'Patharia', 'Patharia', 'Patharia', 23.8992100, 79.1939300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76711, 'Pāthardih', 'Pathardih', 'Pathardih,Pathardihi,Pāthardih', 23.6658000, 86.4316600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76712, 'Pāthardi', 'Pathardi', 'Pathardi,Pāthardi', 19.1727900, 75.1742500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76713, 'Pathānkot', 'Pathankot', 'IXP,Pathankot,Pathānkot,Patkhankot,Rathankot,pa tan ke te,pathanakota,Патханкот,پٹھان کوٹ,पठानकोट,পাঠানকোট,পাথানকোট,帕坦科特', 32.2748400, 75.6528700, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76714, 'Pathanāmthitta', 'Pathanamthitta', 'Pathanamthitta,Pathanāmthitta,Pattanamtitta', 9.2666700, 76.7833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76715, 'Pathalgaon', 'Pathalgaon', 'Pathalgaon,Pathargaon', 22.5565600, 83.4635500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76716, 'Pataudi', 'Pataudi', 'Pataudi,pa tao di,pataudi,pattoti,पटौदी,পতৌদি,பட்டோடி,帕陶迪', 28.3254700, 76.7785800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76717, 'Patancheru', 'Patancheru', 'Patancheroo,Patancheru', 17.5333400, 78.2645000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76718, 'Pātan', 'Patan', 'Patan,Pātan,Патан', 23.8507000, 72.1296300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76719, 'Pātan', 'Patan', 'Patan,Pātan', 23.2863600, 79.6896200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76720, 'Pātan', 'Patan', 'Patan,Pātan,Патан', 21.0333300, 81.5333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76721, 'Pātan', 'Patan', 'Patan,Pātan', 17.3751300, 73.9014300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76722, 'Patāmundai', 'Patamundai', 'Patamudai,Patamundai,Patāmundai', 20.5780600, 86.5606300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76723, 'Pāsighāt', 'Pasighat', 'IXT,Pasighat,Pāsighāt', 28.0663100, 95.3267800, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76724, 'Pasān', 'Pasan', 'Pasan,Pasān', 22.8441200, 82.1982300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76725, 'Parvatsar', 'Parvatsar', 'Parbatsar,Parvatsar', 26.8860400, 74.7660200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76726, 'Pārvatipuram', 'Parvatipuram', 'Parvatipuram,Pārvatipuram,Pārvatīpuram,parvatipuram,పార్వతీపురం', 18.7839200, 83.4256900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76727, 'Partūr', 'Partur', 'Partur,Partūr', 19.5992500, 76.2154100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76728, 'Partāpur', 'Partapur', 'Partapor,Partapur,Partāpur', 23.5927600, 74.1739600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76729, 'Parshādepur', 'Parshadepur', '', 26.0735400, 81.4920700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76730, 'Parola', 'Parola', 'Parola,Pārola', 20.8809800, 75.1193700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76731, 'Parol', 'Parol', 'Nagri,Parol,Parole', 32.3459800, 75.4344100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76732, 'Parnera', 'Parnera', 'Parnera', 20.5610100, 72.9484600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76733, 'Parli Vaijnāth', 'Parli Vaijnath', 'Parli,Parli Vaijnath,Parli Vaijnāth,Purli,Purli Vaijnath', 18.8505700, 76.5316300, 'IN', '2016-07-29', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76734, 'Parlākimidi', 'Parlakimidi', 'Paria Kimedi,Parlakimidi,Parlākimidi,PurlaKimedy,parlakimidi,పర్లాకిమిడి', 18.7811300, 84.0883600, 'IN', '2013-11-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76735, 'Pariyāpuram', 'Pariyapuram', 'Pariyapuram,Pariyāpuram', 11.0166700, 75.8666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76736, 'Parīchhatgarh', 'Parichhatgarh', '', 28.9784100, 77.9342200, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76737, 'Pārīchha', 'Parichha', 'Parichha,Parīchhā,Pārīchha', 25.5078900, 78.7595400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76738, 'Pārdi', 'Pardi', 'Pardi,Pārdi', 20.5087000, 72.9456900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76739, 'Parbhani', 'Parbhani', 'Parbaini,Parbani,Parbhani,Parbkhani,pa er ba ni,parabhani,parbhani,prbany,Парбани,Парбхани,پربانی,پربھنی,परभणी,পারভানি,ପାର୍ଭାନି,帕尔巴尼', 19.2685500, 76.7708100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76740, 'Paravūr Tekkumbhāgam', 'Paravur Tekkumbhagam', 'Paravar,Paravoor,Paravur,Paravur Tekkumbhagam,Paravūr,Paravūr Tekkumbhāgam', 8.7947000, 76.6679800, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76741, 'Parāsia', 'Parasia', 'Dongar Parasia,Dongar Parāsia,Parasia,Parāsia', 22.1913000, 78.7590400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76742, 'Paramagudi', 'Paramagudi', '', 9.5463300, 78.5907000, 'IN', '2016-06-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76743, 'Parādīp Garh', 'Paradip Garh', 'Paradeep,Paradip,Paradip Garh,Paradipur,Paradwip,Parādīp Garh,Pārādwīp', 20.3164100, 86.6085000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76744, 'Pāppinisshēri', 'Pappinissheri', 'Pappinisseri,Pappinissheri,Pāppinisseri,Pāppinissheri,Pāppinisshēri', 11.9565500, 75.3403400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76745, 'Pāppārappatti', 'Papparappatti', 'Papparapatti,Papparappatti,Pāppārappatti', 12.2208600, 78.0592000, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76746, 'Pāpireddippatti', 'Papireddippatti', 'Papireddipatti,Papireddippatti,Pāpireddippatti', 11.9177400, 78.3686500, 'IN', '2016-06-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76747, 'Papanasam', 'Papanasam', 'Papanasam,Papanāsam,Pavanasi,pa pa na sa mu,papanacam,பாபநாசம்,帕帕纳萨姆', 10.9268700, 79.2705600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76748, 'Pāonta Sāhib', 'Paonta Sahib', 'Paonta,Paonta Sahib,Pāonta Sāhib', 30.4366600, 77.6246200, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76749, 'Panvel', 'Panvel', 'Panvel,Panwel,pan wei er,pana''oyela,panabela,panaraela,panavela,panvel,panwl,pnwyl,پانول,پنویل,पनवेल,পানওয়েল,পানৱেল,ପାନବେଲ,பன்வேல்,潘韦尔', 18.9887800, 73.1101300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76750, 'Pānsemāl', 'Pansemal', 'Pansemal,Pānsemal,Pānsemāl', 21.6598100, 74.6993700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76751, 'Panruti', 'Panruti', 'Panruti,pan lu di,panaruti,pannurutti,পানরুটি,ପାନରୁତି,பண்ணுருட்டி,潘鲁蒂', 11.7766200, 79.5526900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76752, 'Panna', 'Panna', 'Panna', 24.7209400, 80.1877200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76753, 'Ponmana', 'Ponmana', 'Panmana,Ponmana', 9.0079800, 76.5202300, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76754, 'Pānīpat', 'Panipat', 'Panipat,Panipata,Pānīpat,Панипата', 29.3874700, 76.9682500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76755, 'Pānihāti', 'Panihati', 'Panihati,Pānihāti', 22.6908900, 88.3740400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76756, 'Panhāla', 'Panhala', 'Panhala,Panhāla', 16.8121000, 74.1100700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76757, 'Pāngāla', 'Pangala', 'Pangala,Pāngāla', 13.2500000, 74.7500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76758, 'Pandua', 'Pandua', 'Pandua', 23.0749200, 88.2863700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76759, 'Pāndoh', 'Pandoh', '', 31.6690200, 77.0535900, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76760, 'Pāndhurnā', 'Pandhurna', 'Pandhurna,Pāndhurna,Pāndhurnā', 21.5955600, 78.5262800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76761, 'Pandharpur', 'Pandharpur', 'Pandharpur,Pandkharpur,padharapura,pan da er pu er,pandaripuramu,pandharapura,pantaripuram,Пандхарпур,پانڈھراپور,पंढरपुर,पंढरपूर,পাধরপুর,ପାଣ୍ଢାରପୁର,பண்டரிபுரம்,పండరీపురము,ಪಂಢರಪುರ,潘达尔普尔', 17.6792400, 75.3309800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76762, 'Pandhāna', 'Pandhana', 'Pandhana,Pandhāna', 21.6981600, 76.2248700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76763, 'French Rocks', 'French Rocks', 'French Rocks,Hirod,Pandavapura,Pāndavapura', 12.5009400, 76.6741600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76764, 'Pāndātarai', 'Pandatarai', 'Pandatarai,Pāndātarai', 22.1871400, 81.3281500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76765, 'Pandaria', 'Pandaria', '', 22.2249500, 81.4099400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76766, 'Pānchgani', 'Panchgani', 'Panchagani,Panchgani,Pānchgani', 17.9244900, 73.8008000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76767, 'Panara', 'Panara', 'Panara,Panāra', 22.2056800, 78.5509300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76768, 'Panamaram', 'Panamaram', 'Panamaram', 11.7401400, 76.0736900, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76769, 'Panaji', 'Panaji', 'Nova Goa,Panadzhi,Panadzi,Panadzis,Panadzsi,Panadžis,Panadží,Panaji,Pangim,Panjim,pa na ji,panaji,panjy,pn chi,pnjy,Панаджи,پانجی,پنجی,पणजी,পানাজি,ਪਣਜੀ,ପାଣାଜୀ,பணஜி,பானஜி,పనజీ,ಪಣಜಿ,പനജി,ปณชี,პანაჯი,パナジ,帕纳吉,파나지', 15.4957400, 73.8262400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76770, 'Panāgar', 'Panagar', 'Panagar,Panagar Bazar,Panagara,Panāgar,Pānāgar', 23.2853900, 79.9950900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76771, 'Palwal', 'Palwal', 'Palval,Palwal,balwal,pa er wa er,pala''oyala,palaraala,palavala,palawala,Палвал,بالوال,पलवल,পালওয়াল,পালৱাল,ପଲୱାଲ,帕尔瓦尔', 28.1446900, 77.3254600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76772, 'Pāloncha', 'Paloncha', '', 17.6018400, 80.7050900, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76773, 'Palani', 'Palani', 'Palani,Palni,pa la ni,palani,Палани,पलनी,पळणी,पळनी,পালানি,ପାଲାନି,பழனி,പഴനി,帕拉尼', 10.4503400, 77.5209000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76774, 'Palmaner', 'Palmaner', 'Palmaner', 13.2000000, 78.7472500, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76775, 'Pallippatti', 'Pallippatti', '', 11.9395600, 78.4015200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76776, 'Pallipattu', 'Pallipattu', 'Pallipat,Pallipattu', 13.3386000, 79.4448900, 'IN', '2012-02-29', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76777, 'Pallikondai', 'Pallikondai', 'Pallikonda,Pallikondai', 12.9051800, 78.9427000, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76778, 'Pallevāda', 'Pallevada', 'Pallevada,Pallevāda', 16.5779000, 81.2946300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76779, 'Palle', 'Palle', 'Pale,Palle', 15.4666700, 74.0833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76780, 'Pallāvaram', 'Pallavaram', 'Pallavaram,Pallāvaram', 12.9679600, 80.1502500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76781, 'Pallattūr', 'Pallattur', 'Pallattur,Pallattūr,Pallatur', 10.1456000, 78.8026300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76782, 'Pallappatti', 'Pallappatti', 'Pallapatti,Pallappatti', 10.7205700, 77.8795100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76783, 'Palladam', 'Palladam', 'Palladam', 10.9917500, 77.2863300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76784, 'Pālkonda', 'Palkonda', 'Palakonda,Palkonda,Pālkonda,palakonda,పాలకొండ', 18.6037400, 83.7556800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76785, 'Pāliyād', 'Paliyad', 'Paliad,Paliyad,Pāliyād', 22.2575700, 71.5602400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76786, 'Pālitāna', 'Palitana', 'Palitana,Pālitāna,Палитана', 21.5251900, 71.8230900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76787, 'Paliā Kalān', 'Palia Kalan', 'Palia,Palia Kalan,Paliā Kalān', 28.4320500, 80.5813700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76788, 'Pāli', 'Pali', 'Pali,Pali-Marwar,Pāli,Пали', 25.7727600, 73.3233500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76789, 'Pāli', 'Pali', 'Pali,Pāli', 24.4918800, 78.4161700, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76790, 'Pāli', 'Pali', 'Birsinghapur,Pali,Pāli,Пали', 23.3645300, 81.0437400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76791, 'Pālghāt', 'Palghat', 'Palakkad,Palghat,Palgkhat,Pālghāt,pa la ke ka de,palakkad,palakkada,palakkara,palakkat,palakkatu,Палгхат,پالگھاٹ,पालक्काड,पालक्काड़,পালক্কাদ,પલક્કડ,ପାଲାକ୍କଡ଼,பாலக்காடு,పాలక్కాడ్,പാലക്കാട്,帕拉克卡德', 10.7731900, 76.6536600, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76792, 'Pālghar', 'Palghar', 'Palghar,Pālghar', 19.6969300, 72.7654300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76793, 'Palera', 'Palera', 'Palera', 25.0201300, 79.2281800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76794, 'Palāsbāri', 'Palasbari', 'Mirza Pahar,Palasbari,Palāsbāri', 26.1238800, 91.5397400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76795, 'Palāsa', 'Palasa', 'Palasa,Palāsa,palasa,పలాస', 18.7725700, 84.4101200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76796, 'Pālanpur', 'Palanpur', 'Palanpur,Pālanpur', 24.1712800, 72.4382700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76797, 'Pālampur', 'Palampur', 'Palampur,Patampar,Pālampur', 32.1145300, 76.5568100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76798, 'Pālamedu', 'Palamedu', 'Palamedu,Pālamedu', 10.1049200, 78.1134800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76799, 'Pālakollu', 'Palakollu', 'Palacole,Palakollu,Pālakollu', 16.5167000, 81.7300000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76800, 'Pālakkodu', 'Palakkodu', 'Palakkodu,Palakod,Pālakkodu', 12.3069600, 78.0702200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76801, 'Pākaur', 'Pakaur', 'Pakaur,Pākaur', 24.6392500, 87.8423900, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76802, 'Pākāla', 'Pakala', 'Pakal,Pakala,Pākāla', 13.4490300, 79.1149300, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76803, 'Paithan', 'Paithan', 'Paithan,pa''ithana,pai tan,paithana,پئے ٹھن,पैठण,পাইথান,ପାଇଥାନ,派坦', 19.4750600, 75.3855800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76804, 'Pahāsu', 'Pahasu', 'Pahasu,Pahāsu', 28.1722000, 78.0637600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76805, 'Pahlgām', 'Pahlgam', 'Pahalgam,Pahalgām,Pahlgam,Pahlgām', 34.0159200, 75.3189900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76806, 'Padrauna', 'Padrauna', 'Padrauna', 26.9040300, 83.9808700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76807, 'Padra', 'Padra', 'Padra', 22.2398000, 73.0845100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76808, 'Padmanābhapuram', 'Padmanabhapuram', 'Padmanabhapuram,Padmanābhapuram,patmanapapuram,பத்மனாபபுரம்', 8.2446200, 77.3258100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76809, 'Paddhari', 'Paddhari', 'Paddhari', 22.4365400, 70.6016200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76810, 'Padampur', 'Padampur', 'Padampur', 29.7088500, 73.6253900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76811, 'Padampur', 'Padampur', 'Padampur,Podampur', 20.9993200, 83.0632500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76812, 'Padam', 'Padam', 'Padam', 33.4665900, 76.8848800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76813, 'Pachperwa', 'Pachperwa', 'Pachperwa', 27.5123400, 82.6429700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76814, 'Pāchora', 'Pachora', 'Pachora,Pāchora', 20.6672700, 75.3530500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76815, 'Pachmarhi', 'Pachmarhi', 'Pachmarhi,Pachmarhi Cantonment,Pachmarhi Cantt,Pachmarhī,pa qi ma er xi qia en te te,pacamadhi,pacamarhi,pacamari,pacamari senanibasa,pacmar''hi,pancamadhi,पचमढ़ी,पचमढी,পাচমাড়ি সেনানিবাস,ਪਚਮੜੀ,પંચમઢી,ಪಚ್ಮರ್ಹಿ,帕奇马尔希恰恩特特', 22.4679100, 78.4331200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76816, 'Ottappālam', 'Ottappalam', 'Ottapalam,Ottappalam,Ottappālam', 10.7735000, 76.3775800, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76817, 'Osmanabad', 'Osmanabad', 'OMN,Osmanabad,Osmānābād,Usmanabad,ao si ma na ba de,osamanabada,osmanabada,usamanabada,usmanabada,usumanabado,Османабад,عثمان آباد,उस्मानाबाद,ওসমানাবাদ,ਉਸਮਾਨਾਬਾਦ,ઉસ્માનાબાદ,ଓସ୍ମାନାବାଦ,ウスマーナーバード,奥斯马纳巴德', 18.1815800, 76.0388900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76818, 'Orchha', 'Orchha', 'Orachha,Orcha,Orchga,Orchha,Orchhâ,Orchkha,Orcsha,ao la qi ha,oracha,orucha,Órcsha,Órčha,Орчга,Орчха,ओरछा,ওড়ছা,ਓਰਛਾ,ઓરછા,オールチャー,奥拉奇哈', 25.3519200, 78.6403300, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76819, 'Oran', 'Oran', 'Oran', 25.3688200, 80.7423000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76820, 'Orai', 'Orai', 'Orai', 25.9902300, 79.4533400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76821, 'Ongole', 'Ongole', 'Ongole,anagole,awngl,awngwl,ongol-nagaram,ongola,ongole,ongolu,onkol,weng guo er,Онголе,اونگل,اونگول,ओंगोल,ओङ्गोल्-नगरम्,অনগোলে,ઓંગોલે,ଓଙ୍ଗୋଲେ,ஒங்கோல்,ఒంగోలు,翁果爾', 15.5035700, 80.0445400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76822, 'Omalur', 'Omalur', 'Omalur,Omalūr', 11.7409900, 78.0455900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76823, 'Olpād', 'Olpad', 'Olpad,Olpād', 21.3364900, 72.7516100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76824, 'Okha', 'Okha', 'Okha,Okha Port,Port Okha,Оха', 22.4675600, 69.0700200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76825, 'Ozar', 'Ozar', 'ISK,Ojhai,Ojhar,Ozar,ao zha er,ojara,ওজার,奥扎尔', 20.0947300, 73.9281600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76826, 'Odugattūr', 'Odugattur', 'Odugathur,Odugattur,Odugattūr,Udugattur,Udugattūr', 12.7679300, 78.8830400, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76827, 'Odlābāri', 'Odlabari', 'Odlabari,Odlābāri,Oldabari,Oldābāri', 26.8364400, 88.6294300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76828, 'Obra', 'Obra', 'Obra', 24.4186300, 82.9879700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76829, 'Nyāmti', 'Nyamti', 'Nyamati,Nyamti,Nyāmati,Nyāmti', 14.1486900, 75.5764100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76830, 'Nūzvīd', 'Nuzvid', 'Nuzvid,Nūzvīd', 16.7885400, 80.8459300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76831, 'Nūrpur Kalān', 'Nurpur Kalan', 'Nurpur,Nurpur Kalan,Nūrpur,Nūrpur Kalān', 31.1666700, 76.4833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76832, 'Nūrpur', 'Nurpur', '', 29.1495600, 78.4084000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76833, 'Nūrmahal', 'Nurmahal', 'Nurmahal,Nūrmahal', 31.0966200, 75.5938600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76834, 'Numāligarh', 'Numaligarh', 'Numaligarh,Numāligarh', 26.6224900, 93.7222500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76835, 'Nūh', 'Nuh', 'Nuh,Nūh', 28.1029600, 77.0014400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76836, 'Nowrangapur', 'Nowrangapur', 'Nabarangapur,Nabarangpur,Nowrangpur', 19.2311400, 82.5482600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76837, 'North Vanlaiphai', 'North Vanlaiphai', 'North Vanlaiphai,Vanlaiphai', 23.1322700, 93.0653200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76838, 'North Lakhimpur', 'North Lakhimpur', 'IXI,Lakhimpur,North Lakhimpur,auyam laksipura,lakhimapura,nuo er te la ji mu pu er,uttara lakhimapura,uttara laksmipura,uttara-lakhimapuram,uttari lakhimapura,شمالی لیکھمپور,उत्तर लखिमपुर,उत्तर-लखिमपुरम्,उत्तरी लखीमपुर,लखीमपुर,উত্তর লখিমপুর,উত্তৰ লখিমপুৰ,ঔয়াং লক্ষিপুর,લખિમપુર,ଉତ୍ତର ଲକ୍ଷ୍ମୀପୁର,诺尔特拉基姆普尔', 27.2351700, 94.1035700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76839, 'North Guwāhāti', 'North Guwahati', 'North Gauhati,North Gauhāti,North Guwahati,North Guwāhāti', 26.1974900, 91.7202000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76840, 'Nongstoin', 'Nongstoin', 'Nongstoin', 25.5170400, 91.2648400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76841, 'Nongpoh', 'Nongpoh', 'Nongpoh', 25.9023000, 91.8769400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76842, 'Nokha', 'Nokha', 'Noka,Nokha,Nokha mani,Nokhamandi', 27.5615500, 73.4714100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76843, 'Nohar', 'Nohar', 'Nohar,Nohor Tehsils', 29.1829200, 74.7706400, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76844, 'Noāmundi', 'Noamundi', 'Noamundi,Noāmundi', 22.1609400, 85.5041600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76845, 'Nizāmābād', 'Nizamabad', 'Nizamabad,Nizāmābād', 26.0529500, 83.0578700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76846, 'Nizāmābād', 'Nizamabad', 'Nizamabad,Nizāmābād,nijamabad,నిజామాబాద్', 18.6715400, 78.0988000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76847, 'Niwāri', 'Niwari', 'Niwari,Niwāri', 28.8761100, 77.5382000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76848, 'Nirsā', 'Nirsa', 'Nirsa,Nirsā', 23.7843800, 86.7069200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76849, 'Nirmāli', 'Nirmali', 'Nirmali,Nirmāli', 26.3139700, 86.5853700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76850, 'Nirmal', 'Nirmal', 'Nirmal,Nirmala,ni er ma er,nirmal,nirmala,nrml,Нирмала,نرمل,निर्मल,নির্মল,ନିର୍ମଲ,నిర్మల్,尼尔马尔', 19.0968500, 78.3440700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76851, 'Nipāni', 'Nipani', 'Nimpani,Nipani,Nipāni', 16.3990000, 74.3828500, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76852, 'Neem ka Thana', 'Neem ka Thana', '', 27.7397600, 75.7865200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76853, 'Nīmbāhera', 'Nimbahera', 'Nimbahera,Nīmbāhera', 24.6216600, 74.6799900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76854, 'Nimāparha', 'Nimaparha', 'Nimapara,Nimaparha,Nimapāra,Nimāparha', 20.0575600, 86.0043600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76855, 'Nīmāj', 'Nimaj', 'Nimaj,Nimbaj,Nimbāj,Nīmāj', 26.1499500, 74.0009400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76856, 'Nīlokheri', 'Nilokheri', 'Nilokeri,Nilokhera,Nilokheri,Nilu Kheri,Nīlokheri,Nīlū Kheri', 29.8367100, 76.9319100, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76857, 'Nīlēshwar', 'Nileshwar', 'Nileshwar,Nīleshwar,Nīlēshwar', 12.2595300, 75.1352000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76858, 'Nilanga', 'Nilanga', 'Nilanga', 18.1167500, 76.7527900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76859, 'Nilakottai', 'Nilakottai', 'Nilakkottai,Nilakkottai-Madura', 10.1650000, 77.8502400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76860, 'Nīlgiri', 'Nilgiri', 'Nilagiri,Nilgiri,Nīlgiri,Raj Nilgiri', 21.4623500, 86.7679400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76861, 'Nihtaur', 'Nihtaur', 'Nehtaur,Nihtaur', 29.3241600, 78.3872400, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76862, 'Needamangalam', 'Needamangalam', 'Nidamangalam,Nīdāmāngalam', 10.7737800, 79.4187500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76863, 'Nidadavole', 'Nidadavole', 'Nidadavol,Nidadavole', 16.9057200, 81.6722200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76864, 'Nichlaul', 'Nichlaul', 'Nichlaul', 27.3124700, 83.7253000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76865, 'Neyyāttinkara', 'Neyyattinkara', 'Neyattinkara,Neyyattinkara,Neyyāttinkara', 8.3985400, 77.0858600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76866, 'New Delhi', 'New Delhi', 'Dellium Novum,Dilli,Dillí,N''ju-Deli,Neo Delchi,Neu-Delhi,Nev Deli,New Delhi,New Dilli,Nju Delkhi,Nov-Delhio,Nova Delhi,Nova Deli,Nova Deli - na''i dilli,Nova Deli - नई दिल्ली,Nova-Delhi,Nove Dilli,Nové Dillí,Nueba Deli,Nueva Delhi,Nuova Delhi,Nyja Deli,Nyu Deli,Nòva Delhi,Nýja Delí,Yeni Delhi,na''i dilli,naya dilli,niu-deli,niwde li,nyudelli,nyuderi,nyw dlhy,nywdlhy,putu tilli,xin de li,Νέο Δελχί,Њу Делхи,Нев Дели,Нью-Дели,Նյու Դելի,ניו דלהי,نيودلهي,नई दिल्ली,নয়া দিল্লী,புது தில்லி,นิวเดลี,ནེའུ་དིལ་ལིའི,ნიუ-დელი,ኒው ዴሊ,ニューデリー,新德里,뉴델리', 28.6357600, 77.2244500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76867, 'Netarhāt', 'Netarhat', 'Netarhat,Netarhāt,Neturhat,Neturhāt', 23.4686400, 84.2700500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76868, 'Neral', 'Neral', 'Neral', 19.0247500, 73.3168800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76869, 'Nepānagar', 'Nepanagar', 'Nepa Nagar,Nepanagar,Nepānagar', 21.4538000, 76.3933500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76870, 'Nellore', 'Nellore', 'Nellore,Nellur,Nelluru,Nelor,nei luo er,nellare,nellaura,nellora,nellur,nelluru,nelluru-nagaram,neruru,nlwr,nylwr,nylwry,sinhapuri,Неллуру,Нелор,نلور,نيلور,نيلوری,نیلور,नेल्लूरु-नगरम्,नेल्लोर,नेल्लौर,নেল্লরে,ନେଲ୍ଲୋର,நெல்லூர்,నెల్లూరు,సింహపురి,ネルール,內洛爾', 14.4499200, 79.9869700, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76871, 'Nellikkuppam', 'Nellikkuppam', 'Nellikkuppam,Nellikuppami', 11.7757700, 79.6678900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76872, 'Nelamangala', 'Nelamangala', 'Nelamangala', 13.0997800, 77.3936400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76873, 'Nedumangād', 'Nedumangad', 'Nedumangad,Nedumangād', 8.6026700, 77.0013900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76874, 'Nāzirā', 'Nazira', 'Nazira,Nāzirā', 26.9164900, 94.7361100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76875, 'Nāyudupet', 'Nayudupet', 'Nayudupet,Nayudupeta,Nāyudupet,Nāyudupeta', 13.9074200, 79.8946500, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76876, 'Nayāgarh', 'Nayagarh', 'Nayagarh,Nayāgarh', 20.1285600, 85.0956300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76877, 'Naya Bāzār', 'Naya Bazar', 'Naya Bazar,Naya Bāzār', 27.1308200, 88.2397200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76878, 'Nawanshahr', 'Nawanshahr', 'Nawanshahr,QNW,na wan si ha he er,na''oyanasahara,naraanasahara,navana sahara,navanasahara,navansahara,navansahara-nagaram,navansahira,nawanasahara,नवनशहर,नवांशहर,नवांशहर-नगरम्,नवान शहर,নওয়ানশাহর,নৱানশাহর,ਨਵਾਂਸ਼ਹਿਰ,ନୱାନଶାହର,纳万斯哈赫尔', 31.1245000, 76.1161300, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76879, 'Nawānshahr', 'Nawanshahr', '', 32.7650500, 74.5277200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76880, 'Nawalgarh', 'Nawalgarh', 'Nawalgarh,na wa er jia er,navalagadha,नवलगढ,纳瓦尔加尔', 27.8516100, 75.2738400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76881, 'Niwai', 'Niwai', 'Newai', 26.3607300, 75.9183600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76882, 'Nawāda', 'Nawada', 'Nawada,Nawāda', 24.8867000, 85.5436400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76883, 'Nawābganj', 'Nawabganj', 'Kanpur Nawabganj,Nawabganj,Nawābganj', 26.4971600, 80.3093400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76884, 'Nawābganj', 'Nawabganj', 'Nawabganj,Nawābganj', 28.5410300, 79.6346200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76885, 'Nawābganj', 'Nawabganj', 'Nawabgang,Nawabganj,Nawābganj', 26.9312900, 81.1984100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76886, 'Nawābganj', 'Nawabganj', 'Nawabganj,Nawābganj', 26.8639600, 82.1410300, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76887, 'Nāwa', 'Nawa', 'Nawa,Nāwa', 27.0195000, 75.0022600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76888, 'Navelim', 'Navelim', '', 15.5333300, 73.9833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76889, 'Navalgund', 'Navalgund', 'Navalgund', 15.5587700, 75.3530500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76890, 'Navadwīp', 'Navadwip', 'Nabadurip,Nabadwip,Nadia,Navadvip,Navadwip,Navadwīp,Навадвип', 23.4067000, 88.3686100, 'IN', '2016-06-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76891, 'Nautanwa', 'Nautanwa', 'Nautanwa,Nautanwa Bazar', 27.4275200, 83.4178900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76892, 'Naugachhia', 'Naugachhia', 'Naugachhia,Naugachia', 25.3880700, 87.0990600, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76893, 'Nāttarasankottai', 'Nattarasankottai', 'Nattarasankotal,Nattarasankottai,Nāttarasankottai', 9.8714400, 78.5521100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76894, 'Nattam', 'Nattam', 'Nattam,Nuttam', 10.2277600, 78.2296900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76895, 'Nāthdwāra', 'Nathdwara', 'Nathdwara,Nathwara,Nāthdwāra', 24.9380500, 73.8239200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76896, 'Nasrullāhganj', 'Nasrullahganj', 'Nasrullaganj,Nasrullahganj,Nasrullāhganj', 22.6837000, 77.2706900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76897, 'Nāsriganj', 'Nasriganj', 'Nasriganj,Nasriganji,Nāsriganj', 25.0514000, 84.3283900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76898, 'Nāspur', 'Naspur', 'Naspur,Nāspur', 18.8457700, 79.4616500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76899, 'Nasīrābād', 'Nasirabad', 'Nasirabad,Nasīrābād', 26.3047300, 74.7336400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76900, 'Nashik', 'Nashik', 'ISK,Nashik,Nasik,Nasikas,Nasiko,Naszik,Našikas,Nászik,na xi ke,nacik,nashiku,nashk,nasik,nasika,nasikeu,nask,nasyk,Насик,Нашик,Нашік,ناسک,ناسیک,ناشک,नाशिक,नाशीक,नासिक,নাশিক,ਨਾਸ਼ਿਕ,નાસિક,ନାଶିକ,நாசிக்,నాసిక్,ನಾಸಿಕ್,ნაშიკი,ナーシク,纳西克,나시크', 19.9972700, 73.7909600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76901, 'Narwar', 'Narwar', 'Narwar', 25.6439000, 77.9129000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76902, 'Narwāna', 'Narwana', 'Narwana,Narwanal,Narwāna', 29.5990300, 76.1192700, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76903, 'Narsīpatnam', 'Narsipatnam', 'Narsipatnam,Narsīpatnam', 17.6670900, 82.6124500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76904, 'Nārsingi', 'Narsingi', 'Narsingi,Nārsingi', 18.0446800, 78.4251600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76905, 'Narsinghgarh', 'Narsinghgarh', 'Narsinghgarh', 23.7075800, 77.0931900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76906, 'Narsimhapur', 'Narsimhapur', 'Narsimahpur,Narsimhapur,Narsinghpur', 22.9493600, 79.1835700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76907, 'Naroda', 'Naroda', 'Naroda,Narora', 23.0704100, 72.6570200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76908, 'Nārnaund', 'Narnaund', 'Narnaund,Nārnaund', 29.2204700, 76.1427800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76909, 'Nārnaul', 'Narnaul', 'Narnaul,Nārnaul', 28.0444400, 76.1083300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76910, 'Narharpur', 'Narharpur', 'Narharpur', 20.4489200, 81.6200400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76911, 'Nargund', 'Nargund', 'Nargund', 15.7229900, 75.3866600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76912, 'Narendranagar', 'Narendranagar', 'Narendranagar', 30.1617300, 78.2871200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76913, 'Naregal', 'Naregal', 'Naregal', 15.5731600, 75.8080500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76914, 'Nārāyanpet', 'Narayanpet', 'Narayanpet,Nārāyanpet', 16.7479900, 77.4954000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76915, 'Narāyangarh', 'Narayangarh', 'Naraingarh,Narayangarh,Narāyangarh,Nārāyangarh', 30.4779800, 77.1280400, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76916, 'Nārāyangarh', 'Narayangarh', 'Narayangarh,Nārāyangarh', 24.2708300, 75.0500700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76917, 'Nārāyanavanam', 'Narayanavanam', 'Narayanavanam,Nārāyanavanam', 13.4256500, 79.5888100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76918, 'Nāravārikuppam', 'Naravarikuppam', 'Naravanikuppam,Naravarikuppam,Naravānikuppam,Nāravārikuppam', 13.1913300, 80.1847300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76919, 'Naraura', 'Naraura', 'Naraura', 28.2014700, 78.3872300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76920, 'Narauli', 'Narauli', 'Narauli', 28.4854700, 78.7148400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76921, 'Narasingāpuram', 'Narasingapuram', '', 13.6075900, 79.3165200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76922, 'Narasimharājapura', 'Narasimharajapura', 'Narasimharajapura,Narasimharājapura', 13.6107500, 75.5120000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76923, 'Narasaraopet', 'Narasaraopet', 'Narasaraopet,na la sa la ao pei te,narasara''opet,narasara''opeta,narasaravupeta,نراساراو پیٹ,नरसरावुपेट,নারাসারাওপেত,ନାରସାରାଓପେଟ୍,నరసరావుపేట,纳拉萨拉奥佩特', 16.2348800, 80.0492700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76924, 'Narasapur', 'Narasapur', 'Narasapur,Narasapuram,Narsapur,na er sa pu er,naracapuram mantalam,narasapuram,narasapuram mandala,نراساپور، مغربی گوداوری ضلع,नरसापुरं मण्डल,ନାରସାପୁରମ୍,நரசாபுரம் மண்டலம்,నరసాపురం,纳尔萨普尔', 16.4342500, 81.6984500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76925, 'Narasannapeta', 'Narasannapeta', 'Narasannapeta,Narsannapet', 18.4142800, 84.0446300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76926, 'Naraini', 'Naraini', 'Naraini', 25.1903300, 80.4750000, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76927, 'Naraina', 'Naraina', '', 26.7906900, 75.2060800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76928, 'Napāsar', 'Napasar', 'Napasar,Napāsar', 27.9605900, 73.5591300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76929, 'Nānpāra', 'Nanpara', 'Nanpara,Nānpāra', 27.8645900, 81.5003600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76930, 'Nannilam', 'Nannilam', 'Nannilam', 10.8793300, 79.6106200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76931, 'Nanjangūd', 'Nanjangud', 'Nanjangud,Nanjangud Town,Nanjangūd', 12.1176400, 76.6839700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76932, 'Nanguneri', 'Nanguneri', 'Nanguneri,Nānguneri', 8.4932600, 77.6580600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76933, 'Nāngloi Jāt', 'Nangloi Jat', 'Nangloi,Nangloi Jat,Nāngloi Jāt', 28.6795700, 77.0679900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76934, 'Nangavalli', 'Nangavalli', 'Nangavalli,Nangavelli', 11.7618900, 77.8909300, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76935, 'Nāngal Township', 'Nangal Township', 'Nangal,Nangal Township,Nāngal,Nāngal Township,Нангал', 31.3896600, 76.3757400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76936, 'Nandyāl', 'Nandyal', 'Nandial,Nandyal,Nandyala,Nandyāl,Nandyāla,nandyala,నంద్యాల', 15.4779900, 78.4836000, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76937, 'Nandurbar', 'Nandurbar', 'Nandurbar,Nandurbār', 21.3667100, 74.2405100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76938, 'Nāndūra Buzurg', 'Nandura Buzurg', 'Nandur Buzruk,Nandura,Nandura Buzruk,Nandura Buzurg,Nāndūr Buzruk,Nāndūra,Nāndūra Buzruk,Nāndūra Buzurg', 20.8341700, 76.4592400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76939, 'Nandikotkūr', 'Nandikotkur', 'Nandikotkur,Nandikotkūr', 15.8566800, 78.2656900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76940, 'Nandigāma', 'Nandigama', 'Nandigama,Nandigāma', 16.7717000, 80.2859600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76941, 'Nandgaon', 'Nandgaon', 'Nandgaon', 27.7110200, 77.3865300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76942, 'Nāndgaon', 'Nandgaon', 'Nandgaon,Nāndgaon', 20.3068000, 74.6550100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76943, 'Nanded', 'Nanded', 'NDC,Nandair,Nanded,Nander,Nānded,Nānder,nadera,nan dai de,nan ded,nan theth,nandd,nandeda,nandedeu,nandedo,nandera,nandyd,nantet,nantetu,nndyd,Нандед,Нандер,ناندد,ناندید,ناندیڑ,ننديد,नांदेड,नांदेड़,नान्देड,ਨੰਦੇੜ,நாந்தேடு,நான்தேட்,นันเดด,นันเทฑ,ナーンデード,楠代德,난데드', 19.1602300, 77.3149700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76944, 'Nanauta', 'Nanauta', 'Nanauta,Phuta Shahr', 29.7121500, 77.4172800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76945, 'Nāmrup', 'Namrup', 'Namrup,Nāmrup', 27.1939500, 95.3192900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76946, 'Namli', 'Namli', 'Namli', 23.4611500, 75.0603600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76947, 'Namchi', 'Namchi', 'Namchi', 27.1649400, 88.3638000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76948, 'Nambutalai', 'Nambutalai', '', 9.7276600, 79.0070700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76949, 'Nambiyūr', 'Nambiyur', 'Nambiyur,Nambiyūr', 11.3581100, 77.3211500, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76950, 'Nāmakkal', 'Namakkal', 'Namakkal', 11.2212600, 78.1652400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76951, 'Nāmagiripettai', 'Namagiripettai', 'Namagiripetai,Namagiripettai,Nāmagiripettai', 11.4550000, 78.2690000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76952, 'Naliya', 'Naliya', 'Naliya', 23.2605800, 68.8265500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76953, 'Nalhāti', 'Nalhati', 'Nalhati,Nalhāti', 24.2970400, 87.8289900, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76954, 'Nalgonda', 'Nalgonda', 'Nalgonda,na er ge en da,nalaganada,nalagonda,nalgonda,nalgonda-nagaram,naljwnda,nalkonta,Налгонда,نالجوندا,नलगोंडा,नल्गोण्डा-नगरम्,नल्गोन्डा,नालगोंडा,নলগনদা,ନାଲଗୋଣ୍ଡା,நல்கொண்டா,నల్గొండ,纳尔戈恩达', 17.0543900, 79.2670700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76955, 'Naldurg', 'Naldurg', 'Naldrug,Naldurg', 17.8166700, 76.2818200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76956, 'Nālāgarh', 'Nalagarh', 'Nalagarh,Nālāgarh', 31.0416800, 76.7228500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76957, 'Nakūr', 'Nakur', 'Nakur,Nakūr', 29.9196400, 77.3043800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76958, 'Naksalbāri', 'Naksalbari', 'Nakalbari,Nakalbāri,Naksalbari,Naksalbāri,Naxalbari', 26.6827000, 88.2200100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76959, 'Nakodar', 'Nakodar', 'Nakodar,na ke da er,nakodar,nakodara,nkwdr,نكودر,नकोदार,নাকোদার,ਨਕੋਦਰ,ନାକୋଦାର୍,纳科达尔', 31.1258600, 75.4750800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76960, 'Najībābād', 'Najibabad', 'Najibabab,Najibabad,Najībābāb,Najībābād', 29.6119400, 78.3427400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76961, 'Nainwa', 'Nainwa', 'Naenwa,Nainwa', 25.7714500, 75.8497800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76962, 'Nainpur', 'Nainpur', 'Nainpur', 22.4299600, 80.1056100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76963, 'Naini Tāl', 'Naini Tal', 'Nainital', 29.3974300, 79.4468600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76964, 'Naihāti', 'Naihati', 'Naihati,Naihāti', 22.8939600, 88.4152100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76965, 'Naīgarhi', 'Naigarhi', 'Naigarhi,Naigarhī,Naīgarhi,Niagurhi', 24.7868600, 81.7786800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76966, 'Nahorkatiya', 'Nahorkatiya', 'Naharkativa,Naharkatiya,Nahorkatiya', 27.2891200, 95.3418000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76967, 'Nāhan', 'Nahan', 'Nahan,Nāhan', 30.5602900, 77.2942600, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76968, 'Nagrota', 'Nagrota', '', 32.0571000, 76.0913900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76969, 'Nagrām', 'Nagram', 'Nagram,Nagrām', 26.6187200, 81.1404300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76970, 'Nagpur', 'Nagpur', 'Ajni,Gorad Nagpur,NAG,Nagpore,Nagpur,Nagpura,Nagpuras,Nankpour,Nágpur,Nāgpur,Nāgpura,na ge pu er,nagapur,nagapura,nagapuram,nageupuleu,naghbwr,nagpwr,nagupuru,nakpur,Ναγκπούρ,Горад Нагпур,Нагпур,Наґпур,נאגפור,ناغبور,ناگپور,नागपुर,नागपुरम्,नागपूर,নাগপুর,ਨਾਗਪੁਰ,નાગપુર,ନାଗପୁର,நாக்பூர்,నాగపూర్,ನಾಗಪುರ,നാഗ്‌പൂർ,ნაგპური,ナーグプル,那格浦尔,나그푸르', 21.1463100, 79.0849100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76971, 'Nāgothana', 'Nagothana', 'Nagothana,Nagothna,Nāgothana', 18.5422500, 73.1349300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76972, 'Nāgod', 'Nagod', 'Nagod,Nāgod', 24.5692400, 80.5880900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76973, 'Nāgireddipalli', 'Nagireddipalli', 'Nagireddipalle,Nagireddipalli,Nāgireddipalli', 14.2700500, 79.1013100, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76974, 'Nagīna', 'Nagina', 'Nagina,Nagīna', 29.4443300, 78.4364600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76975, 'Nāgercoil', 'Nagercoil', 'Nagarkoil,Nagarkovil,Nagercoil,Nāgercoil,nakarkovil,நாகர்கோவில்', 8.1773100, 77.4343700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76976, 'Nagda', 'Nagda', 'Nagda,Nagda-Dhar', 23.4583400, 75.4175900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76977, 'Nāgaur', 'Nagaur', 'Nagaur,Nagaur Marwar,Nāgaur', 27.2020100, 73.7339400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76978, 'Nāgar Karnūl', 'Nagar Karnul', 'Karnul,Karnūl,Nagar Karnul,Nāgar Karnūl', 16.4821000, 78.3247100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76979, 'Nagari', 'Nagari', 'Nagari', 13.3213900, 79.5855700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76980, 'Nagar', 'Nagar', 'Magar,Nagar,Naggar,Наггар', 32.1380800, 77.1739300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76981, 'Nagar', 'Nagar', '', 27.4239700, 77.0992200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76982, 'Nāgappattinam', 'Nagappattinam', 'Nagapatinam,Nagapattinam,Nagappattinam,Negapainttam City,Negapatam,Negapattinam,Nāgappattinam,nagapattinamu,nagappattinamu,nakappattinam,நாகப்பட்டினம்,ナーガッパッティナム,ナーガパッティナム', 10.7639300, 79.8445400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76983, 'Nāgamangala', 'Nagamangala', 'Nagamangala,Nāgamangala', 12.8193900, 76.7545600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76984, 'Naduvattam', 'Naduvattam', 'Naduvattam', 11.4807500, 76.5436500, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76985, 'Naduvannūr', 'Naduvannur', 'Naduvannur,Naduvannūr', 11.4877200, 75.7751100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76986, 'Nadīgaon', 'Nadigaon', 'Nadigaon,Nadīgaon', 26.1078400, 79.0228300, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76987, 'Nadiād', 'Nadiad', 'Hadiad,Nadiad,Nadiād,Naidad', 22.6938500, 72.8615700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76988, 'Nādbai', 'Nadbai', 'Nadbai,Nādbai', 27.2228800, 77.1956900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76989, 'Nādaun', 'Nadaun', 'Nadaun,Nādaun', 31.7830300, 76.3431000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76990, 'Nādāpuram', 'Nadapuram', 'Kummankod,Nadapuram,Nādāpuram', 11.6846500, 75.6549300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76991, 'Nabīnagar', 'Nabinagar', 'Nabinagar,Nabīnagar', 24.6068100, 84.1262400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76992, 'Nābha', 'Nabha', 'Nabha,Nābha', 30.3757700, 76.1529200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76993, 'Mysore', 'Mysore', 'MYQ,Mahisur,Mahisūr,Maisur,Maisuru,Maisúr,Maisūr,Maisūru,Majsor,Majsur,Majszur,Mysooru,Mysore,Mysuru,Mysūru,Májszúr,ma''isora,mahisura,mai suo er,maicur,maisoleu,maisoru,maisura,maisuru,mayswr,mhaisura,myswr,Майсур,Мајсор,مايسور,میسور,मैसूर,मैसूरु,म्हैसूर,মহীশূর,মাইসোর,ਮੈਸੂਰ,મૈસૂર,ମହୀଶୂର,மைசூர்,మైసూరు,ಮೈಸೂರು,മൈസൂരു,මයිසූර්,マイソール,迈索尔,마이소르', 12.2979100, 76.6392500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76994, 'Muzaffarpur', 'Muzaffarpur', 'MZU,Muzaffarpur,Tirhoot', 26.1225900, 85.3905500, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76995, 'Muzaffarnagar', 'Muzaffarnagar', 'Muzafarnagar,Muzaffarnagar,mu zha fa er na jia er,mujapharanagara,mujaphpharanagara,mujaphpharanagaram,mujhaphpharanagara,muzaffara nagara,muzaffarunagaru,mzfr ngr,mzfrngr,Музафарнагар,مظفر نگر,مظفرنگر,मुजफ्फरनगरम्,मुज़फ़्फ़र नगर,मुझफ्फरनगर,મુજફ્ફરનગર,ମୁଜଫରନଗର,ムザッファルナガル,穆扎法尔纳加尔', 29.4709100, 77.7033200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76996, 'Mūvattupula', 'Muvattupula', 'Muvattupula,Muvatupusha,Muvatupuzha,Mūvattupula', 9.9849300, 76.5772800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76997, 'Muttupet', 'Muttupet', 'Muttapet,Muttupet,Mutupet', 10.3950500, 79.4935300, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76998, 'Mustafābād', 'Mustafabad', 'Mustafabad,Mustafābād', 30.2022000, 77.1487300, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(76999, 'Mussoorie', 'Mussoorie', 'Massuri,Masuri,Musoori,Mussooree,Mussoori,Mussoorie,Mussuri,masori,masuri,mu suo li,mucori,mus''sauri,Массури,Масурі,Муссури,مسوری، اتراکھنڈ,मसुरी,मसूरी,মুস্সৌরি,ਮਸੂਰੀ,મસૂરી,ମଶୋରୀ,முசோரி,മസൂറി,穆索里', 30.4549800, 78.0706800, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77000, 'Musiri', 'Musiri', 'Musiri', 10.9529900, 78.4442700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77001, 'Mushābani', 'Mushabani', 'Mosaboni,Mosaboni Mines,Musabani,Mushabani,Mushābani', 22.5113500, 86.4571300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77002, 'Musāfir-Khāna', 'Musafir-Khana', 'Musafir-Khana,Musafirkhana,Musāfir-Khāna,Musāfirkhāna', 26.3783700, 81.7960700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77003, 'Murwāra', 'Murwara', 'Katni,Murwara,Murwāra', 23.8377600, 80.3940500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77004, 'Murud', 'Murud', 'Janjira,Marad,Murad,Murud', 18.3281700, 72.9621000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77005, 'Murtajāpur', 'Murtajapur', 'Murtajapur,Murtajāpur,Murtazapur,Murtazāpur', 20.7329900, 77.3669400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77006, 'Murshidābād', 'Murshidabad', 'Murshidabad,Murshidābād,Муршидабад', 24.1839000, 88.2717100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77007, 'Mursān', 'Mursan', 'Mursan,Mursān', 27.5778800, 77.9409100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77008, 'Murlīganj', 'Murliganj', 'Murliganj,Murlīganj', 25.8969000, 86.9957700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77009, 'Morinda', 'Morinda', 'Morinda,Murinda,Mūrinda,Моринда', 30.7901400, 76.4988300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77010, 'Muri', 'Muri', 'Muri', 23.3707400, 85.8623600, 'IN', '2012-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77011, 'Murgūd', 'Murgud', 'Murgud,Murgūd', 16.3960400, 74.1914200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77012, 'Murbād', 'Murbad', 'Murbad,Murbād', 19.2539500, 73.3899300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77013, 'Muragācha', 'Muragacha', 'Muragacha,Muragachha,Muragācha', 23.5363100, 88.3942500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77014, 'Murādnagar', 'Muradnagar', 'Muradnagar,Muravnagar,Murādnagar', 28.7806900, 77.4986500, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77015, 'Munnar', 'Munnar', 'Munnar,munar,munara,munnar,munnara,mwnar,Муннар,مونار,मुन्नार,मुन्नार्,મુનાર,மூணார்,మున్నార్,മൂന്നാർ', 10.0881800, 77.0623900, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77016, 'Munirābād', 'Munirabad', 'Munirabad,Munirābād', 15.3092800, 76.3383000, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77017, 'Monghyr', 'Monghyr', 'Manger,Monghyr,Munger,Мангер', 25.3745900, 86.4745500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77018, 'Mungeli', 'Mungeli', 'Mungeli', 22.0656600, 81.6854300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77019, 'Mungaoli', 'Mungaoli', 'Mungaoli,Mungaolī', 24.4083700, 78.0958800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77020, 'Mūndwa', 'Mundwa', 'Mundwa,Mūndwa', 27.0631000, 73.8230400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77021, 'Mundra', 'Mundra', 'Mundra', 22.8391800, 69.7219000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77022, 'Mundi', 'Mundi', 'Mundi', 22.0669300, 76.4932600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77023, 'Mundgod', 'Mundgod', 'Mundgod', 14.9714400, 75.0365800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77024, 'Mundargi', 'Mundargi', 'Mundargi,mndrgy,mu en da er ji,mundaragi,mundargi,مندرگی,मुन्दर्गी,মুন্ডারগি,ମୁନ୍ଦାର୍ଗି,ಮುಂಡರಗಿ,穆恩达尔吉', 15.2067700, 75.8839000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77025, 'Multai', 'Multai', 'Multai', 21.7746300, 78.2575600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77026, 'Mūlki', 'Mulki', 'Mulki,Mūlki', 13.0910100, 74.7935300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77027, 'Mulgund', 'Mulgund', 'Mulgund', 15.2807000, 75.5213200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77028, 'Mulbāgal', 'Mulbagal', 'Mulbagal,Mulbāgal', 13.1635200, 78.3934600, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77029, 'Muluppilagadu', 'Muluppilagadu', 'Mulappilangad,Mulappilangal,Mulappilangād,Muluppilagadu,Muzhappilangad', 11.7978800, 75.4511100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77030, 'Mūlanūr', 'Mulanur', 'Mulanur,Mūlanūr', 10.7943600, 77.7117500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77031, 'Mūl', 'Mul', 'Mul,Mūl', 20.0698700, 79.6782600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77032, 'Muktsar', 'Muktsar', 'Muktsar', 30.4742600, 74.5166000, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77033, 'Mukher', 'Mukher', '', 18.7063600, 77.3679500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77034, 'Mukeriān', 'Mukerian', 'Mukerian,Mukeriān', 31.9539400, 75.6171600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77035, 'Muhammadābād', 'Muhammadabad', '', 27.3089500, 79.4325200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77036, 'Muhammadābād', 'Muhammadabad', '', 26.0340400, 83.3811400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77037, 'Muhammadābād', 'Muhammadabad', 'Muhammadabad,Muhammadābād', 25.6190700, 83.7557600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77038, 'Mugma', 'Mugma', 'Mugma', 23.7701500, 86.7274600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77039, 'Mughal Sarāi', 'Mughal Sarai', 'Moghal Sarai,Moghulserdai,Mughal Sarai,Mughal Sarāi', 25.2830700, 83.1196800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77040, 'Mudukulattūr', 'Mudukulattur', 'Mudukulathur,Mudukulattur', 9.3416900, 78.5138800, 'IN', '2016-06-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77041, 'Mudkhed', 'Mudkhed', 'Mudkhed', 19.1565700, 77.5030400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77042, 'Mudgere', 'Mudgere', 'Mudgere,Mudigere', 13.1335300, 75.6416000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77043, 'Mudhol', 'Mudhol', 'Mudhol,mu duo er,mudahala,mudhol,mudhola,mudoru,مودھول,मुधोल,মুদহল,মুধোল,ମୁଧୋଲ୍,ಮುಧೋಳ,ムドール,穆多尔', 16.3335400, 75.2830500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77044, 'Mudgal', 'Mudgal', 'Mudgal,midgala,mu de jia er,mudagal,mudagala,mudogaru,मिद्गल,মুদগাল,ಮುದಗಲ್,ムドガル,穆德加尔', 16.0119100, 76.4420300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77045, 'Muddebihāl', 'Muddebihal', 'Muddebihal,Muddebihāl', 16.3378200, 76.1317300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77046, 'Mūdbidri', 'Mudbidri', 'Mudabidri,Mudbidri,Mūdbidri', 13.0665300, 74.9952500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77047, 'Mubārakpur', 'Mubarakpur', 'Azamgarh,Mubarakpur,Mubārakpur', 26.0886600, 83.2908800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77048, 'Mowād', 'Mowad', 'Mowad,Mowar,Mowād,Mowār', 21.4647500, 78.4510300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77049, 'Mothīhāri', 'Mothihari', 'Mothihari,Mothīhāri,Motihan,Motihari,Motīhāri,motihari,मोतिहारी', 26.6486200, 84.9165600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77050, 'Moth', 'Moth', 'Moth', 25.7259500, 78.9502900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77051, 'Morwa', 'Morwa', 'Morva,Morwa', 22.9046900, 73.8391200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77052, 'Morsi', 'Morsi', '', 21.3403000, 78.0125800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77053, 'Morjim', 'Morjim', 'Mordzhim,Морджим', 15.6309700, 73.7390300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77054, 'Morena', 'Morena', 'Morena,Pech Morena,mo lei na,morena,muraina,mwryna,Морена,مورینا,मुरैना,मोरेना,মোরেনা,મુરૈના,ମୋରେନା,莫雷纳', 26.4989200, 77.9953400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77055, 'Morbi', 'Morbi', 'Morbi,Morvi', 22.8173100, 70.8377000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77056, 'Morār', 'Morar', '', 26.2264000, 78.2248200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77057, 'Morānha', 'Moranha', 'Moran,Moranha,Moranhat,Morān,Morānha', 27.1873500, 94.9155700, 'IN', '2016-06-26', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77058, 'Moram', 'Moram', '', 17.7881200, 76.4707700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77059, 'Morādābād', 'Moradabad', 'Moradabad,Morādābād,Muradabad,Murādābād,Морадабад', 28.8389300, 78.7768400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77060, 'Mon', 'Mon', 'Mon', 26.7358300, 95.0584100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77061, 'Mokokchūng', 'Mokokchung', 'Mkokchung,Mokokchung,Mokokchūng,Mokokshung', 26.3248000, 94.5183400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77062, 'Mokameh', 'Mokameh', 'Mokama,Mokamah,Mokameh,Mokāma', 25.3966200, 85.9219000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77063, 'Moirāng', 'Moirang', 'Moirang,Moirāng', 24.4975000, 93.7779100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77064, 'Mohpa', 'Mohpa', 'Mohpa', 21.3101200, 78.8296900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77065, 'Mohiuddinnagar', 'Mohiuddinnagar', 'Mohiuddinagar,Mohiuddinnagar', 25.5737400, 85.6694400, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77066, 'Mohgaon', 'Mohgaon', 'Mohgaon', 21.6394100, 78.7363800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77067, 'Mohanūr', 'Mohanur', 'Mohanur,Mohanūr', 11.0589600, 78.1399200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77068, 'Mohanpur', 'Mohanpur', 'Mohanpur', 28.2526100, 80.2449800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77069, 'Mohān', 'Mohan', 'Mohan,Mohān', 26.7800800, 80.6749700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77070, 'Moga', 'Moga', 'Moga,Mogu,moga,moka,mwga,mwga  pnjab,Мога,Могу,موگا,موگا، پنجاب,मोगा,ਮੋਗਾ,મોગા,ମୋଗା,மோகா', 30.8138300, 75.1687800, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77071, 'Modāsa', 'Modasa', 'Modasa,Modassa,Modāsa', 23.4625300, 73.2985700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77072, 'Meethari Marwar', 'Meethari Marwar', 'mithari maravara,मीठड़ी मारवाड़', 27.5761500, 74.6866100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77073, 'Misrikh', 'Misrikh', '', 27.4313700, 80.5315700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77074, 'Mirzāpur', 'Mirzapur', 'Mirzapur,Mirzapur-cum-Vindhyachal,Mirzarpur,Mirzāpur,Мирзапур', 25.1449000, 82.5653400, 'IN', '2016-06-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77075, 'Mirik', 'Mirik', 'Mirik', 26.8881700, 88.1900700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77076, 'Miriālgūda', 'Mirialguda', 'Mirialguda,Miriyalguda,Miriālgūda,Miryalguda', 16.8722000, 79.5624700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77077, 'Mīrganj', 'Mirganj', 'Mirganj,Mīrganj', 28.5401200, 79.2081700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77078, 'Mīrānpur Katra', 'Miranpur Katra', '', 28.0296300, 79.6677800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77079, 'Mīrānpur', 'Miranpur', 'Miranpur,Mīrānpur', 29.2902600, 77.9493900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77080, 'Mīnjūr', 'Minjur', 'Minjur,Mīnjūr', 13.2795100, 80.2581500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77081, 'Milak', 'Milak', 'Milak,Милак', 28.6103100, 79.1699700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77082, 'Mihona', 'Mihona', 'Mehona,Mihona', 26.2837300, 78.9804800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77083, 'Mhāsvād', 'Mhasvad', 'Mhasvad,Mhaswad,Mhāsvād', 17.6335900, 74.7877300, 'IN', '2016-07-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77084, 'Mhasla', 'Mhasla', 'Mhasla,Mhusla', 18.1334000, 73.1116200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77085, 'Mettur', 'Mettur', 'Mettur,Mettūr', 11.7879600, 77.8008000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77086, 'Mettupalayam', 'Mettupalayam', 'Mettupalaiyam,Mettupalayam-Coimbatore,Mettuppalaiyam,Mettuppālaiyam,Mettupālaiyam,mettupalayam koyambatturu,mettupalayama,mettuppalaiyam,मेट्टुपालयम,மேட்டுப்பாளையம்,మెట్టుపాలయం కోయంబత్తూరు', 11.2997100, 76.9348500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77087, 'Mettuppālaiyam', 'Mettuppalaiyam', 'Mettupalayam,Mettuppalaiyam,Mettuppālaiyam', 11.1681200, 78.4523200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77088, 'Merta', 'Merta', '', 26.6485900, 74.0341400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77089, 'Mendarda', 'Mendarda', 'Mendarda', 21.3211200, 70.4407800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77090, 'Memāri', 'Memari', 'Memari,Memāri', 23.1764700, 88.0974900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77091, 'Melur', 'Melur', 'Mailore,Melur,Melūr', 10.0324100, 78.3393000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77092, 'Melukote', 'Melukote', 'Melkote,Melukote', 12.6625800, 76.6486100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77093, 'Mehndāwal', 'Mehndawal', 'Mahdawal,Mehdawal,Mehndawal,Mehndāwal', 26.9757900, 83.1099500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77094, 'Mehnagar', 'Mehnagar', 'Mehnagar', 25.8788900, 83.1161100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77095, 'Mehekar', 'Mehekar', 'Mehekar,Mehkar', 20.1505000, 76.5684100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77096, 'Meghraj', 'Meghraj', 'Meghraj,Meghrāj', 23.4980500, 73.5135200, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77097, 'Meerut', 'Meerut', 'Meerut,Meerut City,Merath,Meratkh,Mirat,Miratas,Mirut,Mirát,meluteu,meratha,merato,mi la te,mirarr,mirat,mirat nagaram,mirata,miruta,myrwt,Меерут,Мератх,Мирут,Мірут,מיראט,ميروت,ميروټ,میروت,میرٹھ,मीरत,मेरठ,মীরুট,ਮੇਰਠ,મેરઠ,ମିରଟ,மீரட்,మీరట్ నగరం,മീററ്റ്,メーラト,密拉特,메루트', 28.9800200, 77.7063600, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77098, 'Medinīpur', 'Medinipur', 'Medinipur,Medinīpur,Midnapor,Midnapore,Midnapur,Миднапор', 22.4211400, 87.3225700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77099, 'Medak', 'Medak', 'Medak,medak,medaka,mei da ke,mendaka,metak,mydak,Медак,ميداك,میڈک,मेंडक,मेडक,মেদক,ମେଦାକ୍,மேதக்,మెదక్,梅达克', 18.0453100, 78.2607800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77100, 'Mayiladuthurai', 'Mayiladuthurai', 'Mayavaram,Mayaveram,Mayuram,Māyavaram,Māyuram,Māyūram,ma yi la du tu lai,mailadutturai,mayalanduthura''i,mayiladuthuraya,mayiladuturai,mayilatuturai,میئیلاڈوتھورائے,मयिलदुथुराय,मयीलाडूतुरै,মায়লান্দুথুরাই,மயிலாடுதுறை,మైలాదుత్తురై,马伊拉杜图赖', 11.1035400, 79.6550000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77101, 'Mayāng Imphāl', 'Mayang Imphal', 'Mayang Imphal,Mayāng Imphāl', 24.6099800, 93.8887300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77102, 'Māyakonda', 'Mayakonda', 'Mayakonda,Māyakonda', 14.2889400, 76.0830500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77103, 'Mawāna', 'Mawana', 'Mawana,Mawāna', 29.1028800, 77.9219900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77104, 'Mavoor', 'Mavoor', '', 11.2666700, 75.9166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77105, 'Māvelikara', 'Mavelikara', 'Mavalikara,Mavelikara,Māvelikara', 9.2592900, 76.5564200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77106, 'Maurānwān', 'Mauranwan', 'Mauranwan,Maurawan,Maurānwān,Maurāwān', 26.4287600, 80.8800800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77107, 'Maur', 'Maur', 'Maur', 30.0833300, 75.2500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77108, 'Mauganj', 'Mauganj', 'Mauganj', 24.6672100, 81.8733900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77109, 'Maudaha', 'Maudaha', 'Maudaha', 25.6831200, 80.1141900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77110, 'Mau Aimma', 'Mau Aimma', 'Mau Aima,Mau Aimma', 25.6951500, 81.9233600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77111, 'Mau', 'Mau', 'Mau', 26.2658400, 78.6710800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77112, 'Mau', 'Mau', 'Mau,Mau Nath Bhanjan,Mau Nathbhanjan,Maunath Bhanjan,Maunāth Bhanjan,ma''u,ma''unatha bhanjana,mao na te ban zhan,mau,mavu,maw,myw,Мау,مئو,ماؤ,ماؤ ناتھ بھنجن,ماو,मऊ,मऊनाथ भंजन,मवु,मौ,মৌ,મઊ,毛纳特班詹', 25.9416700, 83.5611100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77113, 'Māttūr', 'Mattur', 'Mattur,Māttūr', 11.3188100, 79.2072400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77114, 'Mattanūr', 'Mattanur', 'Mattanur,Mattanūr', 11.9301800, 75.5715200, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77115, 'Mathura', 'Mathura', 'Madhura,Mandura,Mathura,Matkhura,Matura,Muttra,ma tu la,mathura,mato~ura,matula,matura,matwra,Матура,Матхура,Մաթհուրա,ماتورا,متھرا,मथुरा,মথুরা,મથુરા,ମଥୁରା,மதுரா,మథుర,ಮಥುರಾ,മഥുര,マトゥラー,马图拉,마투라', 27.5035000, 77.6721500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77116, 'Mātherān', 'Matheran', 'Matheran,Mātherān', 18.9828100, 73.2652000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77117, 'Mataundh', 'Mataundh', 'Mataundh', 25.4359400, 80.1565300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77118, 'Mātābhānga', 'Matabhanga', 'Matabhanga,Mathabhanga,Mātābhānga', 26.3419700, 89.2155500, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77119, 'Masinigudi', 'Masinigudi', 'Masinigudi,Masnigudi', 11.5683100, 76.6408700, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77120, 'Masaurhi Buzurg', 'Masaurhi Buzurg', 'Masaurhi,Masaurhi Buzurg,Masaurki', 25.3541700, 85.0319500, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77121, 'Mormugao', 'Mormugao', 'Goa,Marmagao,Marmagoa,Marmugao,Mermugao,Mormugao,Porio,Мармагао', 15.3891400, 73.8149100, 'IN', '2017-05-24', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77122, 'Mārkāpur', 'Markapur', 'Markapur,Mārkāpur', 15.7353400, 79.2684800, 'IN', '2016-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77123, 'Mariāni', 'Mariani', 'Mariani,Mariāni,Мариани', 26.6572500, 94.3152900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77124, 'Mariāhu', 'Mariahu', 'Mariahu,Mariāhu', 25.6040400, 82.6037900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77125, 'Marhaura', 'Marhaura', 'Marhaura', 25.9734900, 84.8679600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77126, 'Margherita', 'Margherita', 'Margherita', 27.2848200, 95.6679600, 'IN', '2012-10-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77127, 'Mārāndahalli', 'Marandahalli', 'Marandahalli,Marandahally,Mārāndahalli', 12.3882600, 78.0031600, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77128, 'Marakkanam', 'Marakkanam', 'Marakkanam,Marakkānam,Markanum,Merkanam,Merkānam', 12.1921400, 79.9419300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77129, 'Marayur', 'Marayur', 'Maraiyoor,Maraiyur,Maraiyūr,Marayoor,Marayur', 10.2764100, 77.1620500, 'IN', '2016-03-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77130, 'Mārahra', 'Marahra', '', 27.7368000, 78.5689100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77131, 'Māpuca', 'Mapuca', 'Mapuca,Mapusa,Mapuçá,Мапуса', 15.5915400, 73.8089800, 'IN', '2016-11-25', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77132, 'Mānwat', 'Manwat', 'Manwat,Manwath,Mānwat', 19.3013300, 76.4973500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77133, 'Mānvi', 'Manvi', 'Manvi,Mānvi', 15.9912600, 77.0503400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77134, 'Manthani', 'Manthani', 'Manthani', 18.6508700, 79.6650100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77135, 'Mansar', 'Mansar', 'Mansar', 21.3960200, 79.2635000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77136, 'Mānsa', 'Mansa', 'Mansa,Mānsa', 29.9884400, 75.4016700, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77137, 'Mānsa', 'Mansa', '', 23.4256400, 72.6573900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77138, 'Mānpur', 'Manpur', 'Manpur,Mānpur', 22.4315100, 75.6210700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77139, 'Manor', 'Manor', 'Manor,Manori,Munnar', 19.7244000, 72.9096600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77140, 'Manohar Thāna', 'Manohar Thana', 'Manohar Thana,Manohar Thāna', 24.2400000, 76.8018200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77141, 'Manoharpur', 'Manoharpur', '', 27.2976900, 75.9495000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77142, 'Manoharpur', 'Manoharpur', '', 22.3745600, 85.1923400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77143, 'Mannargudi', 'Mannargudi', 'Mannargudi,Mannārgudi,ma na er gu di,mannaraguri,mannargudi,mannarkuti,मन्नर्गुडी,মান্নারগুড়ি,மன்னார்குடி,马纳尔古迪', 10.6662600, 79.4506400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77144, 'Mannārakkāt', 'Mannarakkat', '', 10.9922300, 76.4641800, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77145, 'Manmād', 'Manmad', 'Manmad,Manmād', 20.2533400, 74.4375500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77146, 'Mankāpur', 'Mankapur', 'Mankapur,Mankāpur', 27.0518900, 82.2296100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77147, 'Mankāchar', 'Mankachar', 'Manikarchar,Mankachar,Mankāchar', 25.5334700, 89.8637300, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77148, 'Mājalgaon', 'Majalgaon', 'Majalgaon,Manjlegaon,Mājalgaon', 19.1598800, 76.2083200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77149, 'Manjhanpur', 'Manjhanpur', 'Manjhanpur', 25.5304600, 81.3756600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77150, 'Manjēshvar', 'Manjeshvar', 'Bungar Munjeshwar,Manjeshvar,Manjeshwar,Manjeshwara,Manjēshvar', 12.7128700, 74.8885700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77151, 'Manjeri', 'Manjeri', 'Manjeri,man jie li,manceri,manjeri,mnjyry,منجیری,मंजेरी,মঞ্জেরী,மஞ்சேரி,മഞ്ചേരി,曼杰里', 11.1201800, 76.1199600, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77152, 'Manipala', 'Manipala', 'Manipal,Manipala', 13.3500000, 74.7833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77153, 'Mānikpur', 'Manikpur', 'Manikpur,Mānikpur', 25.0608300, 81.0996100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77154, 'Manihāri', 'Manihari', 'Manihari,Manihāri', 25.3389100, 87.6199800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77155, 'Maniar', 'Maniar', '', 25.9854600, 84.1723300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77156, 'Mangrūl Pīr', 'Mangrul Pir', '', 20.3137900, 77.3417800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77157, 'Māngrol', 'Mangrol', 'Kaiztori,Kazitori,Kāiztori,Kāzitori,Mangrol,Māngrol', 25.3306100, 76.5097300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77158, 'Māngrol', 'Mangrol', 'Mangral,Mangrol,Mungrol,Māngral,Māngrol,Mūngrol', 21.1226800, 70.1148400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77159, 'Manglaur', 'Manglaur', 'Manglaur,Manglaur Town', 29.7909400, 77.8783600, 'IN', '2016-02-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77160, 'Mangawān', 'Mangawan', 'Mangawan,Mangawān', 24.6675400, 81.5464400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77161, 'Mangan', 'Mangan', 'Mangan,Mangan Bazar,Mangang,Mangen,Mongon', 27.5096500, 88.5220600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77162, 'Mangalore', 'Mangalore', 'IXE,Kodial,Kudla,Maikala,Mangalooru,Mangalor,Mangalore,Mangaloro,Mangalur,Mangaluru,Mangalúru,Mangalūru,Manglapuram,Tulu Nadu,kodiyal,maingalura,mang kha l xr,mang-galloleu,mangalora,mangalore,mangalura,mangaluru,mangaroru,manghlwr,manglwr,mankalur,men ge luo er,mengalora,mnglwr,myangalora,Мангалор,Мангалур,Мангалуру,مانغلور,مانگلور,منگلور,मंगळूर,मङ्गलूरु,मङ्गळूरु,मैंगलूर,মাঙ্গালোর,ম্যাঙ্গালোর,મેંગલોર,ମାଙ୍ଗାଲୋରେ,மங்களூர்,మంగళూరు,ಕೊಡಿಯಾಲ್,ಮಂಗಳೂರು,മംഗളൂരു,มังคาลอร์,マンガロール,门格洛尔,망갈로르', 12.9172300, 74.8560300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77163, 'Mangaldai', 'Mangaldai', 'Mangaldai', 26.4421200, 92.0304700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77164, 'Mangalam', 'Mangalam', 'Mangalam,Mungalum', 9.7657200, 78.6396900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77165, 'Mangalagiri', 'Mangalagiri', 'Mangalagiri,mang ge a la ji li,mangalagiri,mankalakiri,मंगलगिरी,মঙ্গলাগিরি,மங்களகிரி,మంగళగిరి,芒格阿拉吉里', 16.4308300, 80.5681500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77166, 'Maner', 'Maner', 'Maner,Maner Sharif,Manera,Манера', 25.6460200, 84.8729100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77167, 'Mandya', 'Mandya', 'Mand''ja,Mandya,man di ya,mandaya,mandya,mantiya,Мандья,مانڈیا,मंड्या,मांड्या,মান্দায়া,માંડ્યા,ମାନ୍ଦ୍ୟ,மண்டியா,మండ్య,ಮಂಡ್ಯ,曼迪亚', 12.5223000, 76.8974600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77168, 'Māndvi', 'Mandvi', 'Cutch Mandi,Cutch-Mandvi,Mandvi,Māndvi,Мандви', 22.8328200, 69.3523700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77169, 'Māndvi', 'Mandvi', '', 21.2552600, 73.3041200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77170, 'Māndu', 'Mandu', 'Mandu,Māndu', 22.3666700, 75.3833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77171, 'Mandsaur', 'Mandsaur', 'Mandasor,Mandsaur,man de shao er,mandasaura,mandosauru,mandsa''ur,mndswr,مندسور,मंदसौर,मन्दसौर,মান্দসৌর,મંદસૌર,ମାନ୍ଦ୍ସାଉର୍,マンドサウル,曼德绍尔', 24.0718400, 75.0698600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77172, 'Māndleshwar', 'Mandleshwar', 'Mandleshwar,Māndleshwar', 22.1759800, 75.6599500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77173, 'Mandlā', 'Mandla', 'Mandla,Mandlā,Мандла', 22.5987900, 80.3711500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77174, 'Mandi', 'Mandi', 'Mandi,ma en di,mandi,Манди,منڈی، ہماچل پردیش,मंडी,मण्डी,মান্ডী,মান্দী,મંડી,ମଣ୍ଡି,马恩迪', 31.7119400, 76.9327300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77175, 'Mandholi Kalān', 'Mandholi Kalan', 'Mandholi,Mandholi Kalan,Mandholi Kalān,Mandholi Sheoran ki,Mandholi badi', 28.7085000, 75.6829600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77176, 'Mandāwar', 'Mandawar', 'Mandawar,Mandāwar', 29.4865500, 78.1273200, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77177, 'Mandāwar', 'Mandawar', '', 27.8637400, 76.5499900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77178, 'Mandasa', 'Mandasa', 'Mandasa,mandasa,మందస', 18.8683000, 84.4629600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77179, 'Mandapeta', 'Mandapeta', 'Mandapeta', 16.8625400, 81.9292100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77180, 'Mandapam', 'Mandapam', 'Mandapam', 9.2757100, 79.1236200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77181, 'Māndalgarh', 'Mandalgarh', 'Mandalgarh,Māndalgarh', 25.1940700, 75.0721500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77182, 'Māndal', 'Mandal', '', 25.4412600, 74.5697900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77183, 'Māndal', 'Mandal', '', 23.2886500, 71.9185400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77184, 'Mancherāl', 'Mancheral', 'Mancheral,Mancherial,Mancherāl,manciryala,మంచిర్యాల', 18.8707400, 79.4286300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77185, 'Manchar', 'Manchar', 'Manchar', 19.0043600, 73.9434600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77186, 'Manāwar', 'Manawar', 'Manawar,Manāwar', 22.2356600, 75.0891700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77187, 'Manavalakurichi', 'Manavalakurichi', 'Manavalakurichi', 8.1481200, 77.3063400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77188, 'Mānāvadar', 'Manavadar', 'Manavadar,Manawadar,Mānāvadar', 21.4981300, 70.1377500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77189, 'Manāsa', 'Manasa', '', 24.4837100, 75.2687100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77190, 'Manapparai', 'Manapparai', 'Manaparai,Manapparai,Manappārai', 10.6077200, 78.4258200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77191, 'Manamadurai', 'Manamadurai', 'Manamadura,Manamadurai,Mānāmadurai,ma na ma du lai,manamadura''i,manamaduraya,manamaturai,मनमदुराय,মনমদুরাই,மானாமதுரை,马纳马杜赖', 9.6731800, 78.4709600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77192, 'Manalūrpettai', 'Manalurpettai', 'Manalurpet,Manalurpettai,Manalūrpettai', 12.0078800, 79.0918400, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77193, 'Manāli', 'Manali', 'Manali,Manāli', 32.2574000, 77.1748100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77194, 'Manali', 'Manali', 'Manali,manali,மணலி', 13.1666700, 80.2666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77195, 'Mamit', 'Mamit', 'Mamit', 23.9270300, 92.4896800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77196, 'Seven Pagodas', 'Seven Pagodas', 'Mahabalipur,Mahabalipuram,Mahaballipuram,Mahapalipuram,Mahâballipuram,Mahābalipūr,Makhabalipuram,Mamallapuram,Māmallapuram,Seven Pagodas,mamallapuram,Махабалипурам,மாமல்லபுரம்', 12.6209100, 80.1933100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77197, 'Mālvan', 'Malvan', 'Malvan,Malwan,Mālvan', 16.0598100, 73.4629000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77198, 'Mālūr', 'Malur', 'Malur,Mālūr', 13.0032200, 77.9379800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77199, 'Mālpura', 'Malpura', 'Malpura,Mālpura', 26.2838000, 75.3645800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77200, 'Mālpur', 'Malpur', 'Malpur,Mālpur', 23.3603500, 73.4659500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77201, 'Malpe', 'Malpe', 'Malpe', 13.3496200, 74.7039400, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77202, 'Māllur', 'Mallur', 'Mallur,Māllur', 11.5429900, 78.1401700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77203, 'Mallasamudram', 'Mallasamudram', 'Mallasamudram', 11.4892000, 78.0327700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77204, 'Mallāpuram', 'Mallapuram', 'Mallapuram,Mallāpuram,Manapuram', 11.9812300, 78.2482900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77205, 'Malkera', 'Malkera', 'Malkera', 23.7821300, 86.2876700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77206, 'Malkāpur', 'Malkapur', 'Malkapur,Malkāpur', 20.8855500, 76.1993200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77207, 'Malkāpur', 'Malkapur', '', 16.9199900, 73.9347000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77208, 'Malakanagiri', 'Malakanagiri', 'Malakanagiri,Malakangairi,Malkanagiri,Malkangiri,Mālkāngiri', 18.3642800, 81.8880000, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77209, 'Malīhābād', 'Malihabad', 'Malihabad,Malīhābād', 26.9222300, 80.7107800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77210, 'Malhārgarh', 'Malhargarh', 'Malhargarh,Malhārgarh', 24.2828600, 74.9902400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77211, 'Māler Kotla', 'Maler Kotla', 'Maler Kotla,Māler Kotla', 30.5309000, 75.8794900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77212, 'Mālegaon', 'Malegaon', 'Malegaon,Mālegaon,Малегаон', 20.5496600, 74.5346200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77213, 'Malavalli', 'Malavalli', 'Malavalli', 12.3855600, 77.0604500, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77214, 'Malaut', 'Malaut', '', 30.2112100, 74.4818000, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77215, 'Malappuram', 'Malappuram', 'Malappuram,ma la pu nan,ma la pu pu la mu,malabwram,malappuram,malappurama,mlapwrm,Малаппурам,مالابورام,ملاپورم,मलप्पुरम,মালাপ্পুরম,மலப்புறம்,മലപ്പുറം,马拉普普拉姆,马拉浦南', 11.0419900, 76.0815400, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77216, 'Mākum', 'Makum', 'Makum,Makum-Junction,Mākum', 27.4865200, 95.4364600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77217, 'Maksi', 'Maksi', 'Maksi,Макси', 23.2599900, 76.1456700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77218, 'Makrāna', 'Makrana', 'Makrana,Makrāna', 27.0436100, 74.7244500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77219, 'Makhu', 'Makhu', 'Makhu', 31.1033500, 74.9963100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77220, 'Mākhjan', 'Makhjan', '', 17.2698000, 73.5003100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77221, 'Majītha', 'Majitha', 'Majitha,Majītha', 31.7571100, 74.9589100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77222, 'Majholi', 'Majholi', 'Majholi,Majholī', 23.5011400, 79.9239600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77223, 'Mairwa', 'Mairwa', 'Mairwa', 26.2321800, 84.1634900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77224, 'Mairang', 'Mairang', 'Mairang', 25.5616500, 91.6360200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77225, 'Mainpuri', 'Mainpuri', 'Mainpuri', 27.2285700, 79.0288200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77226, 'Maindargi', 'Maindargi', 'Maindargi', 17.4573900, 76.2932000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77227, 'Maināguri', 'Mainaguri', 'Mainaguri,Maināguri', 26.5626300, 88.8204000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77228, 'Mailāni', 'Mailani', 'Mailani,Mailani Junction,Mailāni,Mailāni Junction', 28.2908800, 80.3438000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77229, 'Maihar', 'Maihar', 'Maihar', 24.2659400, 80.7606300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77230, 'Maibong', 'Maibong', 'Maibang,Maibong', 25.3012500, 93.1381100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77231, 'Mahwah', 'Mahwah', 'Mahwa,Mahwah', 27.0459400, 76.9315200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77232, 'Mahur', 'Mahur', 'Mahur', 25.1830500, 93.1134200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77233, 'Mahudha', 'Mahudha', 'Mahudha', 22.8208200, 72.9403200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77234, 'Mahroni', 'Mahroni', 'Mahrauni,Mahroni', 24.5862400, 78.7277100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77235, 'Maholi', 'Maholi', 'Maholi', 27.6636800, 80.4737100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77236, 'Mahobā', 'Mahoba', 'Mahoba,Mahobā', 25.2905000, 79.8753300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77237, 'Mahmudābād', 'Mahmudabad', 'Mahmudabad,Mahmudābād,Mahmūdābād', 27.2919100, 81.1177500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77238, 'Mahīshādal', 'Mahishadal', 'Mahishadal,Mahīshādal', 22.1861600, 87.9807200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77239, 'Mahgawān', 'Mahgawan', '', 26.4947100, 78.6159300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77240, 'Maheshwar', 'Maheshwar', 'Maheshwar,Makheshvar,ma he si he wa er,mahesbara,maheshuwaru,mahesvar,mahesvara,Махешвар,महेश्वर,মহেশ্বর,மஹேஷ்வர்,マヘーシュワル,马赫斯赫瓦尔', 22.1759200, 75.5871500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77241, 'Mahendragarh', 'Mahendragarh', 'Kanaud,Kānaud,Mahendragarh,Mohindargarh', 28.2693500, 76.1525300, 'IN', '2016-07-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77242, 'Mahemdāvād', 'Mahemdavad', 'Mahemdavad,Mahemdāvād,Mehmadabad,Mehmadābād', 22.8235900, 72.7555100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77243, 'Mahē', 'Mahe', 'Mahe,Mahē,Makh,Mayyazhi,Мах', 11.7017200, 75.5347400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77244, 'Mahbūbnagar', 'Mahbubnagar', 'Mahboobnagar,Mahbubnagar,Mahbūbnagar', 16.7438500, 77.9859700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77245, 'Mahbūbābād', 'Mahbubabad', 'Mahboobabad,Mahbubabad,Mahbūbābād', 17.5972800, 80.0020700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77246, 'Mahāsamund', 'Mahasamund', 'Mahasamund,Mahāsamund', 21.1074300, 82.0948000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77247, 'Mahārāganj', 'Maharaganj', 'Maharaganj,Maharajganj,Mahārāganj,Mahārājganj', 27.1445600, 83.5621400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77248, 'Mahārājganj', 'Maharajganj', 'Maharajganj,Mahārājganj', 26.3812600, 81.2743600, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77249, 'Bishunpur Urf Mahārājganj', 'Bishunpur Urf Maharajganj', 'Bishunpur Urf Maharajganj,Bishunpur Urf Mahārājganj,Maharajganj,Mahārājganj', 26.2591400, 83.1164300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77250, 'Mahārājgani', 'Maharajgani', 'Maharajgani,Maharajganj,Mahārājgani,Mahārājganj', 26.1101700, 84.5036500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77251, 'Maham', 'Maham', 'Maham', 28.9691200, 76.2949500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77252, 'Mahālingpur', 'Mahalingpur', 'Mahalingpur,Mahālingpur', 16.3888000, 75.1087300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77253, 'Mahād', 'Mahad', 'Mahad,Mahād,Makhad,Махад', 18.0833300, 73.4166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77254, 'Mahāban', 'Mahaban', 'Mahaban,Mahāban', 27.4326200, 77.7433800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77255, 'Mahābaleshwar', 'Mahabaleshwar', 'Mahabaleshvar,Mahabaleshwar,Mahābaleshwar,Malcolm Peth', 17.9236900, 73.6585700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77256, 'Maghar', 'Maghar', 'Maghar', 26.7558600, 83.1277300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77257, 'Māgām', 'Magam', 'Magam,Māgām', 34.0925600, 74.5901600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77258, 'Māgadi', 'Magadi', 'Magadi,Māgadi,Магади', 12.9570600, 77.2237400, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77259, 'Madurāntakam', 'Madurantakam', 'Madurantakam,Madurāntakam', 12.5116700, 79.8848500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77260, 'Madurai', 'Madurai', 'IXM,Madura,Madurai,Maduraj,Madurajus,Maduráj,Mathurai,m thu ri,ma du lai,madhura,madhurai,mado~urai,madulai,madura''i,madurai,madwray,maturai,mdwray,mdwrayy,Мадурай,Мадурај,مادورائ,مادوراي,مادورای,مدورائی,مدورای,मदुरई,मदुराई,मदुरै,मधुरै,মদুরাই,ਮਦੁਰਈ,મદુરાઇ,ମଦୁରାଇ,மதுரை,మదురై,ಮಧುರೈ,മധുര,มทุไร,მადურაი,マドゥライ,马杜赖,마두라이', 9.9173500, 78.1196200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77261, 'Madukkūr', 'Madukkur', 'Madukkur,Madukkūr', 10.4809800, 79.3993900, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77262, 'Madukkarai', 'Madukkarai', 'Madukarai,Madukkarai,Mudukarai', 10.9056800, 76.9634400, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77263, 'Mādugula', 'Madugula', 'Madugula,Mādugula', 17.9158900, 82.8157800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77264, 'Chennai', 'Chennai', 'Cenaj,Cenajo,Cenajus,Cenay,Cennai,Cennaj,Chenaj,Chennai,Chennai - cennai,Chennai - சென்னை,Chennaj,Csennai,Gorad Chehnai,MAA,Maderaspatanum,Madras,Madrás,Tamizhagam,Tamulinadu,Tsennai,cen ni,cena''i,cenna''i,cennai,chen''nai,chenai,chennai,chnay,chnayy,chynay,chynayy,jin nai,qing nai,tshynay,znʼy,Çenay,Çennai,Ćennaj,Ĉenajo,Čenaj,Čenajus,Čennai,Čennaí,Τσεννάι,Горад Чэнаі,Ченай,Ченај,Ченнаи,Ченнай,Ченнаї,Չեննայ,צנאי,تشيناي,چنائی,چنای,چينای,چینائی,चेन्नई,चेन्नै,চেন্নাই,ਚੇਨਈ,ચેન્નઈ,ଚେନ୍ନାଇ,சென்னை,చెన్నై,ಚೆನ್ನೈ,ചെന്നൈ,චෙන්නායි,เจนไน,ချန်နိုင်းမြို့,ჩენაი,チェンナイ,清奈,金奈,첸나이', 13.0878400, 80.2784700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77265, 'Madikeri', 'Madikeri', 'Madikeri,Mercara,Mercāra,Merkara', 12.4260200, 75.7382000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77266, 'Madhyamgram', 'Madhyamgram', 'Maddham Gram,Madhyamgram,ma di ya mu ge la mu,madhyagrama,madhyamagrama,مدھیامگرام,मध्यमग्राम,মধ্যগ্রাম,মধ্যমগ্রাম,马迪亚姆格拉姆', 22.6894400, 88.4459400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77267, 'Madhupur', 'Madhupur', 'Madhupur', 24.2741900, 86.6392900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77268, 'Maddagiri', 'Maddagiri', 'Maddagiri,Madhugiri', 13.6603500, 77.2123900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77269, 'Madhubani', 'Madhubani', 'Madhubani,Madkhubani,Мадхубани', 26.3536700, 86.0716900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77270, 'Mādhogarh', 'Madhogarh', 'Madhogarh,Mādhogarh', 26.2752200, 79.1859000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77271, 'Madhogarh', 'Madhogarh', 'Madhagarh,Madhogarh,Mādhogarh', 24.5640100, 80.9112600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77272, 'Mādhoganj', 'Madhoganj', 'Hardoi,Madhoganj,Mādhoganj', 27.1180700, 80.1405800, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77273, 'Madhipura', 'Madhipura', 'Madhipura,Madhupura', 25.9212700, 86.7927100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77274, 'Madgaon', 'Madgaon', 'Madgaon,Margao,Margão,Маргао', 15.2750100, 73.9578600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77275, 'Maddūr', 'Maddur', 'Maddur,Maddūr', 12.5828300, 77.0429400, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77276, 'Madanpur', 'Madanpur', 'Madanpur', 23.0058900, 88.4916800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77277, 'Madanapalle', 'Madanapalle', 'Madanapalle,ma da na pa er lai,ma da na pa li,madanapalle,madanapalle mandala,madanapalli,matanappalli,mdnply,Маданапалле,مدنپلی,मदनपल्ली,मदनपल्ले मण्डल,মদনাপাল্লে,ମାଦାନାପାଲ୍ଲେ,மதனப்பள்ளி,మదనపల్లె,མ་ད་ནཱ་པལ་ལི།,馬達納帕利,马达纳帕尔莱', 13.5503000, 78.5028800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77278, 'Machilīpatnam', 'Machilipatnam', 'Bandar,Kistna,Krishna,Machilipatnam,Machilīpatnam,Masulipatam,Masulipatao,Masulipatnam,Masulipatão,macilipatnam,మచిలీపట్నం', 16.1874700, 81.1388800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77279, 'Machhlīshahr', 'Machhlishahr', 'Machhlishahr,Machhlīshahr', 25.6856400, 82.4110600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77280, 'Māchhīwāra', 'Machhiwara', 'Machhiwara,Māchhīwāra', 30.9155700, 76.2001600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77281, 'Mācherla', 'Macherla', 'Macherla,Mācherla', 16.4763500, 79.4353300, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77282, 'Māchalpur', 'Machalpur', 'Machalpur,Maohalpur,Māchalpur,Māohalpur', 24.1276700, 76.3167200, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77283, 'Lunglei', 'Lunglei', 'Lungleh,Lunglei,Lungliah,lnglyy,long ge lai yi,lun''gale''i,lungalai,lungle''i,lunle''i,lunley,lwngly,Лунглеи,لنگلئی,لونگلی,लुंग्लेइ,लुंग्लेई,लुङ्गलै,লুংলেই,લુન્ગલેઇ,ଲୁଙ୍ଗ୍ଲେଇ,லுங்லேய்,隆格莱伊', 22.8924700, 92.7421800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77284, 'Lūnāvāda', 'Lunavada', 'Lunavada,Lūnāvāda', 23.1284100, 73.6104300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77285, 'Ludhiāna', 'Ludhiana', 'LUH,Ludhiana,Ludhijana,Ludhiāna,Ludkhijana,ludhi''ana,ludhiyana,lutiyana,rudiana,rudiyana,Лудхияна,लुधियाना,ਲੁਧਿਆਣਾ,லூதியானா,ルディアーナ,ルディヤーナー', 30.9120400, 75.8537900, 'IN', '2017-03-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77286, 'Lucknow', 'Lucknow', 'LKO,Lakhnau,Lakkhnau,Lakkhnau shaary,Laknaou,Laknau,Laknauo,Laknava,Laknaú,Laknaŭo,Lucknow,Lucknow City,Luknow,ilakno,lakh nea,lakhana''u,lakhanau,laknau,lakno,laksnau,lei ke nao,leokeunau,lkhnw,lknaw,rakunau,Λάκναου,Лакнау,Лакхнау,Лакхнау шаары,לאקנאו,لكهنؤ,لكهنو,لکناو,لکهنو,لکھنؤ,लखनऊ,लखनौ,লক্ষ্ণৌ,লখনৌ,ਲਖਨਊ,લખનૌ,ଲକ୍ଷ୍ନୌ,இலக்னோ,లక్నో,ಲಕ್ನೋ,ലഖ്‌നൗ,ลัคเนา,ლაქნაუ,ラクナウ,ラクナウー,勒克瑙,러크나우', 26.8392800, 80.9231300, 'IN', '2015-11-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77287, 'Luckeesarai', 'Luckeesarai', 'Lakhisarai,Luckeesarai,Luckesserai', 25.1765000, 86.0947000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77288, 'Losal', 'Losal', 'Losal', 27.4000000, 74.9166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77289, 'Lormi', 'Lormi', 'Lormi', 22.2743400, 81.7018100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77290, 'Loni', 'Loni', 'Lone,Loni,Лоне', 28.7514300, 77.2902300, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77291, 'Londa', 'Londa', 'Landa,Londa', 15.4690700, 74.5190600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77292, 'Lonavla', 'Lonavla', 'Lonauli,Lonavala,Lonavla', 18.7527500, 73.4057500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77293, 'Lonār', 'Lonar', '', 19.9853300, 76.5204600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77294, 'Lohogaon', 'Lohogaon', '', 18.5992100, 73.9270100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77295, 'Lohāru', 'Loharu', 'Loharu,Lohāru', 28.4299300, 75.8077900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77296, 'Lohārdaga', 'Lohardaga', 'Lohardaga,Lohārdaga', 23.4331300, 84.6798200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77297, 'Lohaghāt', 'Lohaghat', 'Lohaghat,Lohaghāt', 29.4035600, 80.0896500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77298, 'Lodhīkheda', 'Lodhikheda', 'Lodhikheda,Lodhikhera,Lodhīkheda,Lodhīkhedā,Lodhīkhera', 21.5823500, 78.8591100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77299, 'Lingsugūr', 'Lingsugur', 'Lingsugur,Lingsugūr', 16.1587600, 76.5217400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77300, 'Limbdi', 'Limbdi', 'Limbdi,Limri', 22.5650700, 71.8107600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77301, 'Leteri', 'Leteri', '', 24.0597900, 77.4085800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77302, 'Leh', 'Leh', 'IXL,Leh,Lehas,Lekh,Len,Léh,le,leha,lh,lie cheng,lyah,lyہہ,re,Лех,לה,له,لياه,لیہہ,लेह,লেহ,ਲੇਹ,લેહ,லே,ലേ,レー,列城,레', 34.1650400, 77.5840200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77303, 'Lāwar Khās', 'Lawar Khas', 'Lawar,Lawar Khas,Lāwar,Lāwar Khās', 29.1109100, 77.7776700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77304, 'Laungowāl', 'Laungowal', 'Lalgarh,Laungowal,Laungowāl,Lālgarh', 30.1939300, 75.6808900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77305, 'Latur', 'Latur', 'LTU,Latur,la du er,latr,latur,latura,latwr,rato~uru,Латур,لاتر,لاتور,लातूर,লাতুর,લાતૂર,ଲାତୁର୍,ラートゥール,拉杜爾', 18.3972100, 76.5678400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77306, 'Lāthi', 'Lathi', 'Lathi,Lati,Lāthi', 21.7231000, 71.3884300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77307, 'Lātehār', 'Latehar', 'Latehar,Lātehār', 23.7439500, 84.4990000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77308, 'Lāsalgaon', 'Lasalgaon', 'Lasalgaon,Lāsalgaon', 20.1427000, 74.2394600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77309, 'Lar', 'Lar', 'Lar,Lār', 26.2039400, 83.9690600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77310, 'Lansdowne', 'Lansdowne', 'Lansdowne', 29.8418300, 78.6801400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77311, 'Lānja', 'Lanja', 'Lanja,Lānja', 16.8608600, 73.5499300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77312, 'Lālsot', 'Lalsot', 'Lalsot,Lālsot', 26.5595100, 76.3291500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77313, 'Lālpur', 'Lalpur', '', 22.1907300, 69.9635100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77314, 'Lalitpur', 'Lalitpur', 'Lalitpur,lalipura,lalitapura,lalitapuram,lalitpur,lallispuleu,Лалитпур,للت پور، بھارت,ललितपुर,ललितपुरम्,ललितपूर,ললিতপুর,લલિતપુર,ଲାଲିପୁର,லலித்பூர்,랄릿푸르', 24.6900700, 78.4191500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77315, 'Lalgudi', 'Lalgudi', 'Lalgudi,Lālgudi,ilalkuti,la er gu di,lalagudi,lalaguri,لالگوڈی,लालगुडी,লালগুড়ি,ଲାଲଗୁଡି,இலால்குடி,拉尔古迪', 10.8741900, 78.8193500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77316, 'Lālgola', 'Lalgola', 'Lalgola,Lalgola Ghat,Lālgola', 24.4224400, 88.2523800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77317, 'Lālganj', 'Lalganj', '', 25.9318200, 81.7047800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77318, 'Lālganj', 'Lalganj', 'Lalganj,Lālganj', 25.8689400, 85.1739400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77319, 'Lālam', 'Lalam', 'Lalam,Lālam', 9.7166700, 76.7000000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77320, 'Lāla', 'Lala', 'Lala,Lāla', 24.5541800, 92.6159200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77321, 'Lakshmeshwar', 'Lakshmeshwar', 'Lakshmeshvar,Lakshmeshwar', 15.1268900, 75.4693500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77322, 'Lakshettipet', 'Lakshettipet', 'Lakhsetipet,Lakshettipet', 18.8666700, 79.2166700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77323, 'Laksar', 'Laksar', 'Laksar', 29.7587000, 78.0414800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77324, 'Lakhyabad', 'Lakhyabad', 'Lakhyabad,Lakhyābād,Layabad,Loyabad', 23.6666700, 86.6666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77325, 'Lakhtar', 'Lakhtar', 'Lakhtar,Luctor', 22.8568300, 71.7884400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77326, 'Lakhnādon', 'Lakhnadon', 'Lakhnadon,Lakhnādon', 22.6004900, 79.6009400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77327, 'Lakhnā', 'Lakhna', 'Dakhna,Dakhnā,Lakhna,Lakhnā', 26.6482200, 79.1477000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77328, 'Lakhipur', 'Lakhipur', '', 26.0300100, 90.3061100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77329, 'Lakhipur', 'Lakhipur', 'Lakhipur', 24.7928100, 93.0091000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77330, 'Lakhīmpur', 'Lakhimpur', 'Lakhimpur,Lakhīmpur', 27.9482200, 80.7793500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77331, 'Lākheri', 'Lakheri', 'Lakheri,Lākheri', 25.6723700, 76.1769200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77332, 'Lāharpur', 'Laharpur', 'Laharpur,Lāharpur', 27.7082700, 80.9025600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77333, 'Lahār', 'Lahar', '', 26.1940100, 78.9413700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77334, 'Lādwa', 'Ladwa', 'Ladwa,Lādwa', 29.9935000, 77.0456300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77335, 'Lādnūn', 'Ladnun', '', 27.6531200, 74.3999300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77336, 'Lachhmangarh Sīkar', 'Lachhmangarh Sikar', 'Lachhmangarh,Lachhmangarh Sikar,Lachhmangarh Sīkar,Lachmangarh', 27.8229400, 75.0275400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77337, 'Kyelang', 'Kyelang', 'Kejlong,Kyeang,Kyelang,Kyelong,Кейлонг', 32.5717000, 77.0244800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77338, 'Kuzhithurai', 'Kuzhithurai', 'Kuzhithurai,Kuzhittura', 8.3179200, 77.1919200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77339, 'Koothanallur', 'Koothanallur', 'Koothanallur,Kuttanallur,Kūttānallūr', 10.7199000, 79.5157000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77340, 'Kuttampuzha', 'Kuttampuzha', 'Kuttampuzha', 10.1503300, 76.7354400, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77341, 'Kuttālam', 'Kuttalam', 'Courtalam,Courtallam,Kurralam,Kuttalam,Kuttālam', 8.9303000, 77.2695100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77342, 'Kutiyāna', 'Kutiyana', 'Kuntiyana,Kuntiyāna,Kurtiyana,Kutiyana,Kutiyāna', 21.6241000, 69.9849400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77343, 'Kutiatodu', 'Kutiatodu', 'Kuthiathode,Kutiatodu', 9.8000000, 76.3333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77344, 'Kushtagi', 'Kushtagi', 'Kushtagi', 15.7562300, 76.1911200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77345, 'Kushālnagar', 'Kushalnagar', 'Fraserpet', 12.4579500, 75.9590400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77346, 'Kushālgarh', 'Kushalgarh', '', 23.1989900, 74.4507400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77347, 'Kurud', 'Kurud', 'Kurud', 20.8307300, 81.7221200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77348, 'Kurinjippādi', 'Kurinjippadi', 'Kurinjipadi,Kurinjippadi,Kurinjippādi', 11.5502800, 79.5906600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77349, 'Kurgunta', 'Kurgunta', 'Kurgunta', 17.1932100, 77.3577200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77350, 'Kurduvādi', 'Kurduvadi', 'Kurduvadi,Kurduvādi', 18.0933900, 75.4156700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77351, 'Kurāra', 'Kurara', 'Kurara,Kurāra', 25.9804600, 79.9898400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77352, 'Kurandvād', 'Kurandvad', '', 16.6831700, 74.5889200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77353, 'Kuppam', 'Kuppam', 'Kuppam', 12.7493100, 78.3418900, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77354, 'Kunnattūr', 'Kunnattur', 'Kunnattur,Kunnattūr,Kunnatur', 12.3478200, 78.5104600, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77355, 'Kunnamkulam', 'Kunnamkulam', 'Kunamkulam,Kunnamkulam,kun na mu ku lan,kunnamakulama,kunnamkulam,kunnankulam,kwnamkwlm,کونامکولم,कुन्नम्कुलम्,কুন্নামকুলম,କୁନ୍ନାମକୁଲାମ,குன்னங்குளம்,കുന്നംകുളം,昆纳姆库兰', 10.6466700, 76.0669500, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77356, 'Kunnamangalam', 'Kunnamangalam', '', 11.3045900, 75.8777200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77357, 'Kunigal', 'Kunigal', 'Kunigal', 13.0231900, 77.0251800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77358, 'Kundla', 'Kundla', '', 21.3422200, 71.3063300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77359, 'Kundgol', 'Kundgol', 'Kundgol,ku en de ge er,kundagola,कुन्दगोल,কুন্ডগোল,ಕುಂದಗೋಳ,库恩德戈尔', 15.2561200, 75.2473500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77360, 'Kundarkhi', 'Kundarkhi', 'Kundarkhi,Kundarki', 28.6830400, 78.7855900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77361, 'Kunda', 'Kunda', 'Kunda', 25.7170200, 81.5139600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77362, 'Kumta', 'Kumta', 'Coompta,Kumpta,Kumta,ku mu ta,kumata,kumta,कुम्ता,কুমতা,ಕುಮಟಾ,库姆塔', 14.4285300, 74.4189000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77363, 'Kumsi', 'Kumsi', 'Kumsi', 14.0545500, 75.3999200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77364, 'Kūmher', 'Kumher', 'Kumher,Kūmher', 27.3165700, 77.3707900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77365, 'Kumhāri', 'Kumhari', 'Kumhari,Kumhāri', 21.2666700, 81.5166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77366, 'Kumbhrāj', 'Kumbhraj', 'Kumbhraj,Kumbhrāj', 24.3733800, 77.0484100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77367, 'Kumbakonam', 'Kumbakonam', 'Kumbakonam,ku mu ba ke na mu,kumbakonama,kumbhakeanam,kumbhakonam,kumbhakonama,kumpakonam,Кумбаконам,कुंभकोणम,कुम्बकोनाम,কুম্ভকোনম,கும்பகோணம்,కుంభకోణం,കുംഭകോണം,库姆巴科纳姆', 10.9620900, 79.3912400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77368, 'Kumaralingam', 'Kumaralingam', '', 10.4893600, 77.3499000, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77369, 'Kulu', 'Kulu', 'KUU,Kullu,Kulu,Sultanpur,Sultānpur', 31.9583500, 77.1082300, 'IN', '2016-07-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77370, 'Kulti', 'Kulti', 'Kulti,Култи', 23.7316600, 86.8437200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77371, 'Kulpahār', 'Kulpahar', 'Kulpahar,Kulpahār', 25.3200700, 79.6393100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77372, 'Kulittalai', 'Kulittalai', 'Kulittalai', 10.9348700, 78.4125100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77373, 'Kulgam', 'Kulgam', 'Kulgam,Kulgām', 33.6445600, 75.0192300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77374, 'Kulattūr', 'Kulattur', 'Kulathur,Kulattur,Kulattūr', 9.0023400, 78.1925000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77375, 'Kukshi', 'Kukshi', 'Kukshi', 22.2067700, 74.7578800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77376, 'Kūkatpalli', 'Kukatpalli', 'Kukatpalli,Kukatpally,Kūkatpalli', 17.4848600, 78.4137600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77377, 'Kuju', 'Kuju', 'Kuju', 23.7275700, 85.5061600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77378, 'Kūdligi', 'Kudligi', 'Kudligi,Kūdligi', 14.9050000, 76.3852700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77379, 'Kudāl', 'Kudal', 'Kudal,Kudāl', 16.0114800, 73.6886700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77380, 'Kudachi', 'Kudachi', 'Kudachi,Kudchi', 16.6278400, 74.8540800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77381, 'Kūd', 'Kud', 'Kud,Kūd', 33.0724600, 75.2872700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77382, 'Kuchera', 'Kuchera', 'Kucher,Kuchera,Кучер', 26.9874700, 73.9710800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77383, 'Kuchāman', 'Kuchaman', 'Kuchaman,Kuchawan,Kuchāman,Kuchāwan', 27.1474500, 74.8565500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77384, 'Kuchaiburi', 'Kuchaiburi', 'Kuchaiburi,Rairangpur', 22.2667500, 86.1738500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77385, 'Krishnarājpet', 'Krishnarajpet', 'Krishnarajpet,Krishnarājpet', 12.6662100, 76.4877000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77386, 'Krishnanagar', 'Krishnanagar', 'Krishnagar,Krishnagar City,Krishnagiri,Krishnanagar,Krishnigar,ke li si he na na jia er,kirusnanakar,krsnanagara,Кришнанагар,Крішнанаґар,कृष्णनगर,कृष्णानगर,কৃষ্ণনগর,கிருஷ்ணாநகர்,克里斯赫纳纳加尔', 23.4057600, 88.4907300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77387, 'Krishnagiri', 'Krishnagiri', 'Krishnagiri,ke li si he na ji li,kiruttinakiri,krshnagry,krsnagiri,kurishunagiri,Кришнагири,کرشناگری,कृष्णगिरि,कृष्णगिरी,কৃষ্ণগিরি,કૃષ્ણાગિરિ,கிருட்டினகிரி,クリシュナギリ,克里斯赫纳吉里', 12.5192100, 78.2138200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77388, 'Kozhikode', 'Kozhikode', 'CCJ,Calecute,Calicut,Calicutium,City of Spices,Kal''kutta,Kalicut,Kalikuto,Kojikode,Kolikod,Kozhikkot,Kozhikod,Kozhikode,Kozikkot,Kozikode,Kozsikode,Kozsíkóde,Kožikodė,Kóžikkót,kajahikode,kajhikada,kalikotu,kalykwt,karikatto,ke ze ke de,kealikkeat,kealikkeat jilla,kho chi khod,kojhikora,kojikodeu,kolikkot,kolikkota,kolikkotu,kolikod,kolikoda,kolikora,qwzyqwd,Калькутта,Кожикод,Кожикоде,Կոժիկոդե,קוזיקוד,كاليكوت,کالیکوت,کالیکٹ,کوزیکوڈ,ކާލީކޯޓު,कोलिक्कोट,कोळिकोड,कोष़िक्कोड,কজহিকোদে,কঝিকড,কোঝিকোড়,કોળિક્કોટ્,କୋଳିକୋଡ଼,கோழிக்கோடு,కోళికోడ్,കോഴിക്കോട്,കോഴിക്കോട് ജില്ല,കോഴിക്കോട്‌,โคชิโคด,カリカット,科泽科德,코지코드', 11.2480200, 75.7804000, 'IN', '2016-10-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77389, 'Koynanagar', 'Koynanagar', 'Koynanagar', 17.4000000, 73.7666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77390, 'Kovvūr', 'Kovvur', 'Kovur,Kovvur,Kovvūr', 17.0162000, 81.7293400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77391, 'Kovūr', 'Kovur', 'Kovur,Kovūr', 14.5005000, 79.9851800, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77392, 'Kovilpatti', 'Kovilpatti', 'Koilpatti,Kovilpatti,ke wei er pa di,kobhilapatti,kobilapatti,kovilpatti,कोभिलपट्टी,কোবিলপাত্তি,கோவில்பட்டி,科维尔帕蒂', 9.1716700, 77.8698900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77393, 'Kovalam', 'Kovalam', 'Kovalam,Kovilam,Ковалам', 8.3666700, 76.9966700, 'IN', '2012-01-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77394, 'Kotwa', 'Kotwa', 'Kotwa', 25.0308000, 81.3190800, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77395, 'Kottūru', 'Kotturu', 'Kothur,Kottur,Kotturu,Kottūru', 14.8244200, 76.2200500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77396, 'Kottayam', 'Kottayam', 'Kotayam,Kottajam,Kottayam,kattayama,ke te ta ye mu,keattayam,kotayam,kottayam,kottayama,Коттаям,کوٹایم,कोट्टयम्,कोट्टायम,কত্তায়াম,কোট্টায়ম,કોટ્ટયમ,କୋତ୍ତାୟମ,கோட்டயம்,కోట్టాయం,കോട്ടയം,科特塔耶姆,코타얌', 9.5869200, 76.5213200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77397, 'Kottapalli', 'Kottapalli', '', 18.4954300, 79.0943000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77398, 'Kottaiyūr', 'Kottaiyur', 'Kottaiyur,Kottaiyūr', 10.1100700, 78.7955500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77399, 'Kottagūdem', 'Kottagudem', 'Kothagudem,Kottagudem,Kottagūdem', 17.5510600, 80.6177900, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77400, 'Kotra', 'Kotra', 'Kotra', 25.8077000, 79.3090900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77401, 'Kotputli', 'Kotputli', '', 27.7020700, 76.1991100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77402, 'Kotma', 'Kotma', 'Kotma', 23.2038300, 81.9790400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77403, 'Kotla', 'Kotla', 'Kotla', 32.2500000, 76.0333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77404, 'Kotkhai', 'Kotkhai', 'Kot Khai,Kot Khāi,Kotkhai', 31.1172800, 77.5393600, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77405, 'Kot Īsa Khān', 'Kot Isa Khan', 'Kot Isa Khan,Kot Ïsa Khān,Kot Īsa Khān,Kot-Ise-Khan', 30.9465900, 75.1378000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77406, 'Kothi', 'Kothi', 'Kothi', 24.7526000, 80.7775100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77407, 'Kothāpet', 'Kothapet', 'Kagaznagar,Kothapet,Kothāpet', 19.3517600, 79.4832300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77408, 'Kotdwāra', 'Kotdwara', 'Kotdwara,Kotdwāra', 29.7461200, 78.5221900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77409, 'Kotār', 'Kotar', 'Kotar,Kotār', 24.6980200, 80.9807300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77410, 'Kotapārh', 'Kotaparh', 'Kotapad,Kotaparh,Kotapād,Kotapārh', 19.1425600, 82.3253600, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77411, 'Kotamangalam', 'Kotamangalam', '', 10.0643500, 76.6284300, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77412, 'Kotagiri', 'Kotagiri', 'Kotagiri,ke ta ji li,keattagiri,kotagiri,kottakiri,कोटागिरी,কোটাগিরি,কোতাগিরি,கோத்தகிரி,കോട്ടഗിരി,科塔吉里', 11.4207200, 76.8603500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77413, 'Kota', 'Kota', 'KTU,Kota,Kotah,Kotah City,ke ta,kota,kotta,kwta,Кота,کوتا,کوٹا,कोटा,ਕੋਟਾ,કોટા,கோட்டா,コーター,科塔,코타', 25.1825400, 75.8390700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77414, 'Kota', 'Kota', 'Kota,Кота', 24.4464300, 83.1306300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77415, 'Kotā', 'Kota', 'Kota,Kotā', 22.2950700, 82.0236600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77416, 'Kosigi', 'Kosigi', 'Kesigi,Kosgi,Kosigi', 15.8551000, 77.2446300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77417, 'Kosi', 'Kosi', '', 27.7944900, 77.4368000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77418, 'Kosamba', 'Kosamba', 'Kosamba', 21.4620200, 72.9584200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77419, 'Korwai', 'Korwai', '', 24.1177400, 78.0400700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77420, 'Korukollu', 'Korukollu', 'Korukollu', 16.5000000, 81.2500000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77421, 'Koregaon', 'Koregaon', 'Koregaon,Koregaon-Bhima', 18.6457300, 74.0590900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77422, 'Korba', 'Korba', 'Korba,koraba jila,Корба,कोरबा जिला', 22.3458000, 82.6963300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77423, 'Koratla', 'Koratla', 'Koratla', 18.8215400, 78.7118600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77424, 'Koratagere', 'Koratagere', 'Koratagere', 13.5220000, 77.2373000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77425, 'Korāput', 'Koraput', 'Koraput,Korāput,Корапут', 18.8119900, 82.7104800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77426, 'Korampallam', 'Korampallam', '', 8.7750600, 78.0915800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77427, 'Korādi', 'Koradi', 'Koradi,Koradih,Korādi,Korādih', 21.2475800, 79.1057500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77428, 'Koradāchcheri', 'Koradachcheri', 'Koradachcheri,Koradacheri,Koradāchcheri', 10.7701900, 79.4915800, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77429, 'Koppal', 'Koppal', 'Kappal,Kopbal,Koppal,ke pu pa er,koppal,koppala,Коппал,कोप्पल,कोप्पळ,কোপ্পাল,કોપ્પલ,கொப்பள்,科普帕尔', 15.3452200, 76.1547800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77430, 'Koppa', 'Koppa', 'Koppa', 13.5304400, 75.3632900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77431, 'Kopargaon', 'Kopargaon', 'Kopargaon', 19.8823900, 74.4760500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77432, 'Kopāganj', 'Kopaganj', 'Kopaganj,Kopāganj', 26.0192300, 83.5663000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77433, 'Konnūr', 'Konnur', 'Konnur,Konnūr', 16.2013800, 74.7488600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77434, 'Konnagar', 'Konnagar', 'Konnagar', 22.7050800, 88.3444600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77435, 'Konganāpuram', 'Konganapuram', 'Konganapuram,Konganāpuram', 11.5710500, 77.9004000, 'IN', '2017-05-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77436, 'Kondapalle', 'Kondapalle', 'Kondapalle,Kondapalli', 16.6198900, 80.5424400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77437, 'Kondalwādi', 'Kondalwadi', '', 18.8072700, 77.7703100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77438, 'Kondagaon', 'Kondagaon', 'Kondagaon,Kondegaon', 19.5908300, 81.6640000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77439, 'Konch', 'Konch', 'Konch,Kunch,Kūnch', 25.9945100, 79.1512700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77440, 'Konārka', 'Konarka', 'Kanarak,Konarak,Konark,Konarka,Konârak,Konārak,Konārka,Swiatynia Surji w Konarak,ke na er ke,konark,Świątynia Surji w Konarak,ಕೊನಾರ್ಕ್,科纳尔克', 19.8975800, 86.1141300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77441, 'Konanūr', 'Konanur', 'Konanur,Konanūr', 12.6301600, 76.0503700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77442, 'Kombai', 'Kombai', 'Kombai,Komebai', 9.8467200, 77.2957700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77443, 'Kolasib', 'Kolasib', '', 24.2238800, 92.6786900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77444, 'Kollegāl', 'Kollegal', 'Collegal,Kollegal,Kollegalam,Kollegāl,Kollegālam', 12.1544900, 77.1105100, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77445, 'Kolhāpur', 'Kolhapur', 'KLH,Kolhapur,Kolhāpur', 16.6956300, 74.2316700, 'IN', '2017-03-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77446, 'Kolāras', 'Kolaras', 'Kolaras,Kolāras', 25.2192800, 77.6116700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77447, 'Kolār', 'Kolar', 'Kolar,Kolār,Колар', 13.1376800, 78.1299900, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77448, 'Kolanukonda', 'Kolanukonda', 'Kolanukonda', 16.4539200, 80.6104600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77449, 'Colachel', 'Colachel', '', 8.1793800, 77.2581800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77450, 'Kokrajhar', 'Kokrajhar', 'Kokradzhar,Kokrajhar,Кокраджар', 26.4010700, 90.2728600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77451, 'Kohima', 'Kohima', 'Kohima,Kohīma,Kokhima,ke xi ma,keahima,kohima,kokima,Кохима,Кохіма,کوہیما,कोहिमा,কোহিমা,ਕੋਹਿਮਾ,કોહિમા,କୋହିମା,கோகிமா,കൊഹിമ,კოჰიმა,コヒマ,科希马,코히마', 25.6746700, 94.1109900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77452, 'Koelwār', 'Koelwar', '', 25.5805500, 84.7975100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77453, 'Kodungallūr', 'Kodungallur', 'Cranganore,Cranganur,Crānganūr,Kodungallur,Kodungallūr,Methala,Muchiri,Muchiripattinam,Muyirikkodu,Muziris,Shinkli', 10.2326300, 76.1951300, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77454, 'Kodumudi', 'Kodumudi', 'Kodumudi', 11.0775100, 77.8836300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77455, 'Kodoli', 'Kodoli', 'Kodoli', 16.8763900, 74.1909000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77456, 'Kodlipet', 'Kodlipet', '', 12.8008700, 75.8866200, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77457, 'Kodīnar', 'Kodinar', 'Kodina,Kodinar,Kodīnar,Korinar', 20.7939300, 70.7021600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77458, 'Kodigenahalli', 'Kodigenahalli', 'Kodiganballi,Kodigenahalli', 13.7213600, 77.3862900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77459, 'Kodarmā', 'Kodarma', 'Kodarma,Kodarmā', 24.4675300, 85.5939700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77460, 'Kodār', 'Kodar', '', 16.9985000, 79.9656000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77461, 'Kodala', 'Kodala', 'Kodala', 19.6242500, 84.9407500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77462, 'Kodaikānāl', 'Kodaikanal', 'Kodaikan,Kodaikanal,Kodaikān,Kodaikānāl,Kodajkanal,Кодайканал', 10.2392500, 77.4893200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77463, 'Kochinda', 'Kochinda', 'Kochinda,Kuchinda', 21.7457000, 84.3510500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77464, 'Koch Bihār', 'Koch Bihar', 'COH,Cooch Behar,Koch Bihar,Koch Bihār,Kuch Bihar,Kuch Bihār', 26.3253900, 89.4450800, 'IN', '2017-02-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77465, 'Koāth', 'Koath', 'Koath,Koāth', 25.3264300, 84.2598300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77466, 'Kizhake Chālakudi', 'Kizhake Chalakudi', 'Chalakudi,Chālakudi,Kizhake Chalakudi,Kizhake Chālakudi', 10.3006700, 76.3376300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77467, 'Kithor', 'Kithor', '', 28.8668400, 77.9386100, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77468, 'Kishtwār', 'Kishtwar', 'Kishtvare,Kishtwar,Kishtwer,Kishtwār,Киштваре', 33.3134600, 75.7672600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77469, 'Kishni', 'Kishni', 'Kishni', 27.0248700, 79.2620000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77470, 'Kishanpur', 'Kishanpur', '', 25.6423200, 81.0227000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77471, 'Kishangarh', 'Kishangarh', '', 27.8188900, 76.7297200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77472, 'Kishangarh', 'Kishangarh', 'Kishangarh,Kishangarkh,Кишангарх', 26.5741000, 74.8668500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77473, 'Kishanganj', 'Kishanganj', 'Kishanganj,Kishanganj Bazar', 26.1022400, 87.9553400, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77474, 'Kiri Buru', 'Kiri Buru', '', 22.0833300, 85.3500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77475, 'Kīratpur', 'Kiratpur', 'Kiratpur,Kīratpur', 29.5067100, 78.2061300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77476, 'Kiraoli', 'Kiraoli', 'Kiraoli', 27.1376800, 77.7851600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77477, 'Kīranūr', 'Kiranur', '', 10.5935800, 77.5028000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77478, 'Kīranūr', 'Kiranur', '', 10.5698800, 78.7868200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77479, 'Kirākat', 'Kirakat', '', 25.6374500, 82.9159600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77480, 'Kinwat', 'Kinwat', 'Kinvat,Kinwat', 19.6255700, 78.1987000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77481, 'Kilvelur', 'Kilvelur', 'Kil Valur,Kilvelur,Kilvelure,Kīl Vālur', 10.7672100, 79.7418600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77482, 'Kichha', 'Kichha', 'Kichha', 28.9115400, 79.5200900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77483, 'Khūtār', 'Khutar', 'Khutar,Khūtār', 28.2030700, 80.2704600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77484, 'Khusropur', 'Khusropur', '', 25.4817400, 85.3849200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77485, 'Khurja', 'Khurja', 'Khurja', 28.2538200, 77.8553500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77486, 'Khurda', 'Khurda', 'Khordha,Khurda', 20.1826800, 85.6162900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77487, 'Khurai', 'Khurai', 'Khurai', 24.0437200, 78.3301400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77488, 'Khunti', 'Khunti', 'Khunti', 23.0753300, 85.2790300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77489, 'Khuldābād', 'Khuldabad', 'Khuldabad,Khuldābād,Rauza', 20.0067100, 75.1924500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77490, 'Khujner', 'Khujner', 'Khujner', 23.7859700, 76.6177300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77491, 'Khudāganj', 'Khudaganj', '', 28.1460700, 79.7147200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77492, 'Khowai', 'Khowai', 'IXN,Khowai', 24.0796400, 91.5997200, 'IN', '2013-10-30', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77493, 'Khopoli', 'Khopoli', 'Khopoli,ke bo li,khopoli,کھوپولی,खोपोली,খোপোলি,科波利', 18.7856200, 73.3458900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77494, 'Khonsa', 'Khonsa', 'Horu Khunma,Khela,Khonsa', 27.0166700, 95.5666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77495, 'Khirkiyān', 'Khirkiyan', 'Khirkian,Khirkiya,Khirkiyan,Khirkiyān,Khirkiān', 22.1673200, 76.8613700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77496, 'Khilchipur', 'Khilchipur', 'Khilchipur', 24.0394300, 76.5780000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77497, 'Khetri', 'Khetri', 'Khetri,kai te li,kherti,khetari,khetri,खेतड़ी,खेर्ती,খেত্রি,凯特里', 28.0006900, 75.7864400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77498, 'Khetia', 'Khetia', 'Khetia', 21.6712400, 74.5853500, 'IN', '2012-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77499, 'Kheri', 'Kheri', 'Kheri', 27.9035400, 80.7975400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77500, 'Kherālu', 'Kheralu', 'Kheralu,Kherālu', 23.8853400, 72.6186900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77501, 'Khem Karan', 'Khem Karan', 'Khem Karan', 31.1444300, 74.5593800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77502, 'Khekra', 'Khekra', '', 28.8658600, 77.2841000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77503, 'Khedbrahma', 'Khedbrahma', '', 24.0299000, 73.0463200, 'IN', '2017-03-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77504, 'Kheda', 'Kheda', 'Kaira,Kheda,Хеда', 22.7521800, 72.6853300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77505, 'Khed', 'Khed', '', 18.3381100, 73.8467700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77506, 'Khed', 'Khed', 'Khed', 17.7188800, 73.3969300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77507, 'Khawhai', 'Khawhai', 'Khawhai', 23.3780700, 93.1279700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77508, 'Khaur', 'Khaur', 'Khaur,Khour', 32.6027000, 74.8091800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77509, 'Khātra', 'Khatra', 'Khatra,Khātra', 22.9761700, 86.8546200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77510, 'Khatīma', 'Khatima', 'Khatima,Khatīma', 28.9213400, 79.9707500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77511, 'Khātegaon', 'Khategaon', 'Khategaon,Khātegaon', 22.5957300, 76.9133000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77512, 'Khatauli', 'Khatauli', 'Khatauli', 29.2784400, 77.7330200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77513, 'Khārupatia', 'Kharupatia', 'Kharupatia,Kharupatia Ghat,Khārupatia', 26.5183900, 92.1472200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77514, 'Kharsia', 'Kharsia', 'Kharsia', 21.9895300, 83.1047600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77515, 'Kharsāwān', 'Kharsawan', 'Kharsawan,Kharsawangarh,Kharsāwān', 22.7904100, 85.8313200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77516, 'Kharod', 'Kharod', 'Kharod', 21.7442000, 82.5788000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77517, 'Kharkhauda', 'Kharkhauda', '', 28.8787000, 76.9106900, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77518, 'Kharkhauda', 'Kharkhauda', '', 28.8364400, 77.7415900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77519, 'Kharhiāl', 'Kharhial', 'Kharhial,Kharhiāl,Khariar,Khariār', 20.2884500, 82.7606000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77520, 'Khargupur', 'Khargupur', 'Khargupur', 27.3761100, 81.9882000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77521, 'Khargone', 'Khargone', 'Khargon,Khargone', 21.8229200, 75.6139400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77522, 'Khargāpur', 'Khargapur', 'Khargapur,Khargāpur', 24.8230000, 79.1440000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77523, 'Kharela', 'Kharela', 'Kharela,Kharelā', 25.5427700, 79.8123500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77524, 'Khardah', 'Khardah', 'Khardah,Khardaha', 22.7186100, 88.3780600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77525, 'Kharar', 'Kharar', 'Kharar', 30.7463200, 76.6468900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77526, 'Kharar', 'Kharar', 'Kharar', 22.7221100, 87.6782400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77527, 'Kharakvasla', 'Kharakvasla', 'Khadakvaslal,Khadakwasla,Khandakwalsa,Kharakvasla', 18.4399700, 73.7754500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77528, 'Kharagpur', 'Kharagpur', 'Kharagpur,Харагпур', 25.1244600, 86.5557800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77529, 'Kharagpur', 'Kharagpur', 'Kharagpur,Khargpur,karakpur,ke lei ge bu er,kharagapura,khargapura,khragpwr,Харагпур,خراگپور,खरगपुर,खरगपूर,খড়্গপুর,ଖଡ଼ଗପୁର,கரக்பூர்,ಖರಗ್‌ಪುರ,克勒格布爾', 22.3397100, 87.3250100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77530, 'Khāpa', 'Khapa', '', 21.4224300, 78.9816800, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77531, 'Khānpur', 'Khanpur', 'Khanpur,Khānpur', 28.5344600, 78.0654600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77532, 'Khānpur', 'Khanpur', '', 24.7324100, 76.3960100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77533, 'Khanna', 'Khanna', 'Khanna,Ханна', 30.7054700, 76.2219600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77534, 'Khandwa', 'Khandwa', 'Kandva,Khandwa,kan de wa,khandava,khando''oya,khandoraa,khandva,Кандва,खंडवा,खण्डवा,खन्द्वा,खांडवा,খান্দোওয়া,খান্দোৱা,ખંડવા,坎德瓦', 21.8242700, 76.3508600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77535, 'Khandela', 'Khandela', 'Khandela', 27.6049900, 75.5020000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77536, 'Khānāpur', 'Khanapur', 'Khanapur,Khānāpur', 15.6396900, 74.5084700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77537, 'Khammam', 'Khammam', 'Khammam,Khammamett,Khammamette,Kkhammam,ka mu ma mu,kam''mam,kham''mam,kham''mama,khamam,Кхаммам,خامام,کھمم,खम्मम,खम्माम,খাম্মাম,ଖମ୍ମମ,கம்மம்,ఖమ్మం,卡姆马姆', 17.2476700, 80.1436800, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77538, 'Khamharia', 'Khamharia', 'Khamharia', 20.9760000, 82.2511600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77539, 'Khāmgaon', 'Khamgaon', 'Khamgaon,Khāmgaon', 20.7073800, 76.5682700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77540, 'Khambhāt', 'Khambhat', 'Cambay,Kambay,Khambayat,Khambhat,Khambhāt,Khambāyat', 22.3174400, 72.6191600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77541, 'Khambhāliya', 'Khambhaliya', 'Khambhalia,Khambhaliva,Khambhaliya,Khambhāliya', 22.2068500, 69.6503100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77542, 'Khamaria', 'Khamaria', '', 23.2255800, 79.8800700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77543, 'Khamānon Kalān', 'Khamanon Kalan', 'Khamanon,Khamanon Kalan,Khamānon,Khamānon Kalān', 30.8172500, 76.3547800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77544, 'Khallikot', 'Khallikot', 'Kallikota,Khallikot,Khallikote,Kullikota', 19.6090800, 85.0860900, 'IN', '2016-06-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77545, 'Khalīlābād', 'Khalilabad', 'Khalilabad,Khalīlābād', 26.7726800, 83.0717900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77546, 'Khajuraho Group of Monuments', 'Khajuraho Group of Monuments', 'Conjunto de Templos de Khajuraho,HJR,Khadzuraho,Khadżuraho,Khajraho,Khajrāho,Khajuraho,Khajuraho Group of Monuments,Khajurâho,Khajurāho,Kkhadzhurakho,kajuraho,khajuraha,khajuraho,Кхаджурахо,खजुराहो,খাজুরাহ,ಖಜುರಾಹೊ,カジュラーホー', 24.8480900, 79.9335100, 'IN', '2016-10-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77547, 'Khairāgarh', 'Khairagarh', 'Khairagarh,Khairāgarh,Kheragarh', 26.9426900, 77.8189000, 'IN', '2016-07-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77548, 'Khairāgarh', 'Khairagarh', 'Khairagarh,Khairagarh Raj,Khairāgarh', 21.4185900, 80.9794200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77549, 'Khairābād', 'Khairabad', 'Khairabad,Khairābād', 27.5269800, 80.7546100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77550, 'Khair', 'Khair', 'Khair,kha''ira,khaira,khaira prakhanda,kher,کھیر,खैर,खैर प्रखण्ड,খাইর,ଖେର୍', 27.9419500, 77.8424300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77551, 'Khailār', 'Khailar', 'Khailar,Khailor,Khailār', 25.3412700, 78.5313300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77552, 'Khagaul', 'Khagaul', 'Khagaul', 25.5789800, 85.0456400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77553, 'Khagaria', 'Khagaria', 'Khagaria', 25.5022000, 86.4670800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77554, 'Khāga', 'Khaga', 'Khaga,Khāga', 25.7721500, 81.1039300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77555, 'Khadki', 'Khadki', 'Khadki,Kirkee', 18.5635000, 73.8520500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77556, 'Khada', 'Khada', '', 27.1833300, 83.8833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77557, 'Khāchrod', 'Khachrod', 'Khachrod,Khāchrod', 23.4232200, 75.2818500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77558, 'Kesinga', 'Kesinga', 'Kesinga', 20.1877800, 83.2194900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77559, 'Keshorai Pātan', 'Keshorai Patan', '', 25.2927500, 75.9394800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77560, 'Keshod', 'Keshod', 'IXK,Keshod,Kesod', 21.3032800, 70.2486100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77561, 'Kerūr', 'Kerur', 'Kerur,Kerūr', 16.0138400, 75.5463100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77562, 'Kenduadīh', 'Kenduadih', 'Kenduadih,Kenduadīh', 23.7757400, 86.3760900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77563, 'Kendrāparha', 'Kendraparha', 'Kendrapara,Kendraparha,Kendrāparha,Kendrāpāra', 20.5016600, 86.4222700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77564, 'Kenda', 'Kenda', 'Kenda', 23.1959000, 86.5149900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77565, 'Kemrī', 'Kemri', 'Kemri,Kemrī', 28.8067300, 79.2048000, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77566, 'Kelamangalam', 'Kelamangalam', 'Kelamangalam,Kelamnagalam', 12.6030700, 77.8519300, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77567, 'Kekri', 'Kekri', 'Kekri', 25.9713200, 75.1499200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77568, 'Kayattār', 'Kayattar', 'Kayatar,Kayattar,Kayattār', 8.9470800, 77.7720600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77569, 'Kāyankulam', 'Kayankulam', 'Kayamkulam,Kayangulam,Kayankulam,Kāyankulam', 9.1817300, 76.5009300, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77570, 'Kayalpattinam', 'Kayalpattinam', 'Aramaganori,Coilnapatam,Kayalpatnam,Kayalpattinam,Kayalpatuam,Kāyalpatnam,Kāyalpattinam', 8.5714300, 78.1199200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77571, 'Kawardha', 'Kawardha', 'Kawardha', 22.0085300, 81.2314800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77572, 'Kawānt', 'Kawant', 'Kavant,Kawant,Kawānt', 22.0928200, 74.0507800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77573, 'Kāveripatnam', 'Kaveripatnam', 'Kaveripatnam,Kaveripattinam,Kaverippattanam,Kāveripatnam,Kāverippattanam', 12.4218600, 78.2188000, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77574, 'Kavaratti', 'Kavaratti', 'Atol Kavaraci,Kavaratis,Kavaratti,ka wa la di,kabalati,kabarati,kabaratti,kabharetti,kavarati,kavaratti,kw ratti,kwaraty,Атол Кавараці,Каваратти,Каваратті,کواراتی,ކަވަރައްދޫ,कवरत्ती,काभारेट्टी,কাবারাত্তি,ਕਵਰੱਤੀ,କବରତ୍ତୀ,கவரத்தி,ಕವರಟ್ಟಿ,കവരത്തി,กวรัตติ,კავარატი,カバラティ,卡瓦拉蒂,카바라티', 10.5668800, 72.6420300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77575, 'Kavalūr', 'Kavalur', 'Kavalur,Kavalūr', 15.2882900, 75.9433000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77576, 'Kāvali', 'Kavali', 'Kavali,Kāvali', 14.9163000, 79.9944900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77577, 'Kāttuputtūr', 'Kattuputtur', 'Kattupputtur,Kattuputtur,Katuputur,Kāttupputtūr,Kāttuputtūr', 10.9936700, 78.2192900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77578, 'Kattivākkam', 'Kattivakkam', 'Kattivakkam,Kattivākkam', 13.2166700, 80.3166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77579, 'Kattanam', 'Kattanam', 'Kattanam', 9.1761400, 76.5632500, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77580, 'Kātrās', 'Katras', 'Katras,Kātrās', 23.7975200, 86.2983400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77581, 'Katra', 'Katra', 'Katra', 32.9916700, 74.9319500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77582, 'Katra', 'Katra', '', 27.5087100, 82.0263600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77583, 'Katpur', 'Katpur', 'Jegri,Kadpur,Katpur,Kutpur', 21.0586900, 71.7945700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77584, 'Kātpādi', 'Katpadi', 'Katpadi,Kātpādi', 12.9695100, 79.1455200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77585, 'Kātoya', 'Katoya', 'Katoya,Katwa,Kātoya', 23.6455800, 88.1325800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77586, 'Kātol', 'Katol', 'Katol,Kātol', 21.2738800, 78.5858000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77587, 'Katihar', 'Katihar', 'Hafiz Saifganj,Katihar,Katihār', 25.5385200, 87.5704400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77588, 'Kāti', 'Kati', '', 17.9613700, 75.8889500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77589, 'Kathua', 'Kathua', 'Kathua,Katkhua,ka tu a,kathu''a,kathura,kathuraa,kathuva,kathwa,Катхуа,كاثوا,کتھوا,कठुआ,कठुवा,कथुआ,कथुरा,কথুৱা,કઠુઆ,କାଠୁଆ,卡图阿', 32.3694100, 75.5253900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77590, 'Kāthor', 'Kathor', 'Kathor,Kāthor', 21.2885400, 72.9407000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77591, 'Katghora', 'Katghora', 'Katghora', 22.5024700, 82.5427900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77592, 'Katangi', 'Katangi', 'Katangi,Nagra Katangi', 23.4412400, 79.7962100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77593, 'Katangi', 'Katangi', 'Katangi,Katāngi', 21.7736900, 79.8051300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77594, 'Kasrāwad', 'Kasrawad', 'Kasrawad,Kasrāwad', 22.1274500, 75.6110100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77595, 'Kashipur', 'Kashipur', 'Kashipur,Kāshīpur,ka si xi pu er,kashypwr,kasipura,Кашипур,Кашіпур,کاشی پور، اتراکھنڈ,کاشیپور,काशीपुर,काशीपूर,কাশিপুর,କାଶିପୁର,卡斯希普尔', 29.2139900, 78.9569300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77596, 'Kāsganj', 'Kasganj', 'Kasganj,Kāsganj', 27.8088200, 78.6457900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77597, 'Kasauli', 'Kasauli', 'Ambala,Ambāla,Kasauli,Kosauli', 30.8985600, 76.9658700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77598, 'Kāsaragod', 'Kasaragod', 'Kasaragod,Kasaragod Fort,Kāsaragod', 12.4983800, 74.9895900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77599, 'Karwar', 'Karwar', 'Karvar,Karwar,Kawar,Kárvár,Kārwār,ka er wa er,kara''oyara,kararaara,karavara,karavaram,karvar,karwar,krwar,Карвар,کاروار,کروار,कारवार,कारवारम्,কারওয়ার,কারৱার,કારવાર,କାର୍ୱାର୍,கார்வார்,ಕಾರವಾರ,卡尔瓦尔', 14.8136100, 74.1297200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77600, 'Karur', 'Karur', 'Karur,Karūr,ka lu er,kaluleu,karur,karura,karuru,karwr,krwr,Карур,كرور,کارور,करुर,करूर,करूरु,কারুর,કરુર,କାରୁର୍,கரூர்,ಕರೂರ್,കരൂർ,カルール,卡鲁尔,카루르', 10.9577100, 78.0809500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77601, 'Karumbākkam', 'Karumbakkam', 'Karumbakham,Karumbakkam,Karumbākkam', 12.7020300, 80.0911000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77602, 'Kartārpur', 'Kartarpur', 'Kartarpur,Kartārpur', 31.4426800, 75.4984700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77603, 'Kārsiyāng', 'Karsiyang', 'Karsiyang,Kharasana,Kurseong,Kārsiyāng', 26.8825100, 88.2772900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77604, 'Karrāpur', 'Karrapur', 'Karrapur,Karrāpur', 23.9489100, 78.8658400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77605, 'Karol Bāgh', 'Karol Bagh', 'Karol Bagh,Karol Bāgh', 28.6513600, 77.1907200, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77606, 'Karnāl', 'Karnal', 'Karnal,Karnāl,Карнал', 29.6919700, 76.9844800, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77607, 'Karmāla', 'Karmala', 'Karmala,Karmāla', 18.4077000, 75.1938600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77608, 'Kārkala', 'Karkala', 'Karaka,Karkal,Karkala,Kārkala,Kārkāl', 13.2142800, 74.9923400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77609, 'Karjat', 'Karjat', 'Karjat,ka er gu te,karajata,karjat,karjata,krjt,کرجت,कर्जत,কারজাত,କାର୍ଜାତ,கர்ஜத்,卡尔贾特', 18.9107000, 73.3235400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77610, 'Kariapatti', 'Kariapatti', 'Kariapatti,Kariyapatti,Kariyapattinam,Kāriyāpatti', 9.6750500, 78.0999200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77611, 'Karīmpur', 'Karimpur', 'Karimpur,Karīmpur', 23.9759400, 88.6191700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77612, 'Karīmnagar', 'Karimnagar', 'Karimnagar,Karīmnagar,karinnagar,కరీంనగర్', 18.4391500, 79.1285600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77613, 'Karīmganj', 'Karimganj', 'Karimganj,Karīmganj,karimaganja,করিমগঞ্জ', 24.8691900, 92.3554300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77614, 'Karhal', 'Karhal', 'Karhal', 27.0008900, 78.9393500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77615, 'Kargil', 'Kargil', 'Kargil,ka er ji er,karagila,kargilanagaram,kargl,karkil,krghyl,Каргил,كرغيل,کارګېل,کارگل,करगिल,कारगिल,कार्गिलनगरम्,ਕਾਰਗਿਲ,કારગિલ,கார்கில்,കാർഗിൽ,卡尔吉尔', 34.5576500, 76.1262200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77616, 'Karera', 'Karera', 'Karera,Karery,Кареры', 25.4581500, 78.1358300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77617, 'Kareli', 'Kareli', 'Kareli,Karelī,Карели', 22.9153300, 79.0637800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77618, 'Karauli', 'Karauli', 'Karauli,ka lao li,karauli,Караули,करौली,কারৌলি,કરૌલી,卡劳利', 26.4983100, 77.0275500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77619, 'Karārī', 'Karari', 'Karari,Karārī', 25.4524100, 81.4267500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77620, 'Kāranja', 'Karanja', 'Karandzha,Karanja,Karanja Bibi,Kāranja,Kāranja Bibi,Каранджа', 20.4827300, 77.4885700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77621, 'Karamsad', 'Karamsad', 'Karamsad', 22.5424300, 72.9039200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77622, 'Karambakkudi', 'Karambakkudi', 'Karambakkudi,Karambakuduy', 10.4578700, 79.1397100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77623, 'Kāramadai', 'Karamadai', 'Karamadai,Kāramadai,karamatai,காரமடை', 11.2405800, 76.9600900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77624, 'Kāraikkudi', 'Karaikkudi', 'Karaikkudi,Karaikudi,Kāraikkudi', 10.0661000, 78.7678700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77625, 'Kāraikāl', 'Karaikal', 'Karaikal,Karikal,Kārikāl,karaikal,kāraikāl', 10.9166700, 79.8333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77626, 'Karād', 'Karad', 'Karad,Karād', 17.2893700, 74.1818300, 'IN', '2016-06-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77627, 'Kapūrthala', 'Kapurthala', 'Kapurtala,Kapurthala,Kapurthala Town,Kapūrthala', 31.3801100, 75.3810500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77628, 'Captainganj', 'Captainganj', 'Captainganj,Kaptanganj,Kaptānganj', 26.9264000, 83.7133400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77629, 'Kāpren', 'Kapren', '', 25.4052900, 76.0743100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77630, 'Kapadvanj', 'Kapadvanj', 'Kapadranj,Kapadvanj', 23.0230200, 73.0711300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77631, 'Kantilo', 'Kantilo', 'Kantilo', 20.3643600, 85.1963400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77632, 'Kānth', 'Kanth', 'Kanth,Kānth,Mannagar,Mānnagar', 29.0593900, 78.6295100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77633, 'Kantābānji', 'Kantabanji', 'Kantabanji,Kantābānji', 20.4670900, 82.9204200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77634, 'Kānt', 'Kant', 'Kant,Kānt', 27.8104900, 79.7918500, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77635, 'Kanpur', 'Kanpur', 'Cawnpore,KNU,Kanpur,Kanpuras,Kanpwr,Kānpur,Kānpwr,kanapura,kanpur,kanpuru,Канпур,קאנפור,कानपुर,कानपूर,কানপুর,கான்பூர்,カーンプル', 26.4652300, 80.3497500, 'IN', '2015-08-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77636, 'Kānor', 'Kanor', 'Kanor,Kānor', 24.4343700, 74.2654600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77637, 'Kānodar', 'Kanodar', 'Kanodar,Kānodar', 24.0893200, 72.3935400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77638, 'Kannod', 'Kannod', 'Kannod', 22.6676400, 76.7428600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77639, 'Kanniyākumāri', 'Kanniyakumari', 'Cap Comorin,Cape Comorin,Comorin,Kan''jakumari,Kanniakumari,Kanniyakumar,Kanniyakumari,Kanniyākumar,Kanniyākumāri,Kanyakumari,Каньякумари', 8.0900800, 77.5384100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77640, 'Kannavam', 'Kannavam', 'Kannavam', 11.8445000, 75.6626600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77641, 'Kannauj', 'Kannauj', 'Kanaudzh,Kanauj,Kannaudzh,Kannauj,Kânnauj,ka nao jie,kanauja,kanauji,kannauja,kannoci,kannoja,qnwj,Канаудж,Каннаудж,قنوج,कनौज,कन्नौज,কন্নৌজ,ਕੰਨੌਜ,કન્નોજ,கன்னோசி,კანაუჯი,カナウジ,卡瑙杰,카나우지', 27.0552400, 79.9188000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77642, 'Kānnangād', 'Kannangad', 'Kanhangad,Kannangad,Kānnangād', 12.3081400, 75.1063200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77643, 'Kannad', 'Kannad', 'Kannad', 20.2568400, 75.1378600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77644, 'Kānkon', 'Kankon', 'Advota,Canacona,Chauri,Chauri Town,Kankon,Kānkon', 15.0269800, 74.0461700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77645, 'Kankipādu', 'Kankipadu', 'Kankipad,Kankipadu,Kankipādu', 16.4353000, 80.7671500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77646, 'Kānker', 'Kanker', 'Kanker,Kānker', 20.2719300, 81.4917700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77647, 'Kānke', 'Kanke', 'Kanke,Kānke', 23.4336200, 85.3211000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77648, 'Kankauli', 'Kankauli', 'Kankauli,Kankavali,Kankavli', 16.2660900, 73.7121700, 'IN', '2016-07-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77649, 'Kanigiri', 'Kanigiri', 'Kanigiri', 15.4055500, 79.5069400, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77650, 'Kāngar', 'Kangar', 'Kangar,Kangra,Kāngar,Kāngra', 32.0913500, 76.2626700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77651, 'Kangayam', 'Kangayam', '', 11.0059900, 77.5609000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77652, 'Kandukūr', 'Kandukur', 'Kandukur,Kandukūr', 15.2154200, 79.9039000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77653, 'Kāndri', 'Kandri', 'Kandri,Kāndri', 21.4203000, 79.2766300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77654, 'Kāndra', 'Kandra', 'Kandra,Kāndra', 22.8517000, 86.0519200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77655, 'Kāndla', 'Kandla', 'IXY,Kandla,Kundla,Kāndla,Кандла', 23.0333300, 70.2166700, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77656, 'Kāndi', 'Kandi', 'Kandi,Kāndi', 23.9594600, 88.0401800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77657, 'Kāndhla', 'Kandhla', 'Kandhla,Kāndhla', 29.3210400, 77.2710100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77658, 'Kānchipuram', 'Kanchipuram', 'Conjeeveram,Conjevaram,Conjeveram,Kancheepuram,Kanchipuram,Kancipuram,Kanjippuram,Kańćipuram,Kānchipuram,gan ji bu lei mu,kanchipuramu,kancipuram,kancipurama,Канчипурам,কাঞ্চিপুরম,காஞ்சிபுரம்,カーンチープラム,甘吉布勒姆', 12.8351500, 79.7000600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77659, 'Kānkānhalli', 'Kankanhalli', 'Kanakapura,Kanakpura,Kankanhalli,Kānkānhalli', 12.5465400, 77.4200500, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77660, 'Kanadukattan', 'Kanadukattan', 'Kanadukathan,Kanadukattan,Kanatu,Kanatukattan,Kānādukāttān,Kānātu,Kānātukāttān', 10.1720900, 78.7793500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77661, 'Kamuthi', 'Kamuthi', 'Kamudi,Kamuti,Kaumuri', 9.4073200, 78.3733700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77662, 'Kāmthi', 'Kamthi', 'Kamptee,Kamtha,Kamthi,Kāmtha,Kāmthi,kampti', 21.2161500, 79.1973000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77663, 'Kampli', 'Kampli', 'Kampli', 15.4062600, 76.6001300, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77664, 'Kampil', 'Kampil', 'Kampil,ka mu pi er,kampila,kmply,کمپلی,कम्पिल,কাম্পিল,卡姆皮尔', 27.6126800, 79.2768700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77665, 'Cumbum', 'Cumbum', 'Kambam', 9.7364700, 77.2847000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77666, 'Kāmārhāti', 'Kamarhati', 'Kamarhati,Kamarhatty,Kāmārhāti', 22.6711100, 88.3747200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77667, 'Kāmāreddi', 'Kamareddi', 'Kamareddi,Kamareddipet,Kamaredi,Kāmāreddi', 18.3200100, 78.3417700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77668, 'Kāman', 'Kaman', 'Kaman,Kāman,Каман', 27.6579100, 77.2690800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77669, 'Kamalpur', 'Kamalpur', 'IXQ,Kamalpur', 24.1959300, 91.8343800, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77670, 'Kamalganj', 'Kamalganj', 'Kamalganj', 27.2618100, 79.6313400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77671, 'Kāmalāpuram', 'Kamalapuram', '', 14.5983000, 78.6694800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77672, 'Kāmākhyānagar', 'Kamakhyanagar', 'Kamakhyanagar,Kāmākhyānagar,Murhi', 20.9338500, 85.5448900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77673, 'Kalyani', 'Kalyani', 'Kalyani,ka li ya ni,kalyani,কল্যাণী,கல்யாணி,卡利亚尼', 22.9833300, 88.4833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77674, 'Kalyān', 'Kalyan', 'Kal''jan,Kalyan,Kalyān,Кальян', 19.2437000, 73.1355400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77675, 'Kālundri', 'Kalundri', '', 18.9802000, 73.1270800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77676, 'Kalugumalai', 'Kalugumalai', 'Kalugumalai,Kalugumali', 9.1472600, 77.7042400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77677, 'Kālpi', 'Kalpi', 'Kalpi,Kālpi,Калпи', 26.1166700, 79.7333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77678, 'Kalpatta', 'Kalpatta', 'Kalpatta,Kalpetta,ka er pei te ta,kalapetta,kalparra,kalpetta,Калпетта,کلپیٹا,कल्पेट्टा,कालपेट्टा,কালপেত্ত,কালপেত্তা,கல்பற்றா,കൽപറ്റ,卡尔佩特塔', 11.6087100, 76.0834300, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77679, 'Kālol', 'Kalol', 'Kalol,Kālol', 22.6077700, 73.4627200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77680, 'Kālna', 'Kalna', 'Kalna,Kālna,Кална', 23.2194400, 88.3629500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77681, 'Kalmeshwar', 'Kalmeshwar', '', 21.2321900, 78.9198800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77682, 'Kallupatti', 'Kallupatti', '', 9.7166700, 77.8666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77683, 'Kallidaikurichchi', 'Kallidaikurichchi', 'Kailidaikorichchi,Kallidaikurichchi', 8.6830100, 77.4645500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77684, 'Kallakkurichchi', 'Kallakkurichchi', 'Kallakirichi', 11.7404000, 78.9590000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77685, 'Kālka', 'Kalka', 'Kalka,Kalki,Kālka,kalaka,Калки,कालका', 30.8398200, 76.9406500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77686, 'Kāliyāganj', 'Kaliyaganj', 'Kaliaganj,Kaliyagan,Kaliyaganj,Kāliyāgan,Kāliyāganj', 25.6344200, 88.3266500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77687, 'Kanīna Khās', 'Kanina Khas', 'Kalina Khas,Kalīna Khās,Kanina,Kanina Khas,Kanīna Khās', 28.3309300, 76.3109900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77688, 'Kālīnagar', 'Kalinagar', 'Kalinagar,Kālīnagar', 28.6201900, 80.0815200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77689, 'Kālimpong', 'Kalimpong', 'Kalimpang,Kalimpong,Kālimpang,Kālimpong,Калимпонг', 27.0705900, 88.4752900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77690, 'Kālikāpur', 'Kalikapur', 'Kalikapur,Kālikāpur', 22.6166200, 86.2881000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77691, 'Kalghatgi', 'Kalghatgi', 'Kalghatgi', 15.1831500, 74.9709900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77692, 'Kalavai', 'Kalavai', 'Kalavai,Kalaval', 12.7702900, 79.4199900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77693, 'Kālāvad', 'Kalavad', 'Kalavad,Kālāvad', 22.2078900, 70.3834300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77694, 'Kalas', 'Kalas', '', 18.1724100, 74.7904500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77695, 'Kālānwāli', 'Kalanwali', 'Kalanwali,Kālānwāli', 29.8357300, 74.9717000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77696, 'Kalanaur', 'Kalanaur', 'Kalanaur,Kalānaur', 32.0122700, 75.1506300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77697, 'Kalānaur', 'Kalanaur', 'Kalanaur,Kalānaur', 28.8282300, 76.3955000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77698, 'Kalamnūri', 'Kalamnuri', 'Kalamnuri,Kalamnūri', 19.6738600, 77.3114900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77699, 'Kalamb', 'Kalamb', 'Kalamb', 19.0443700, 73.9555400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77700, 'Kalakkādu', 'Kalakkadu', 'Kalakad,Kalakkadu,Kalakkādu', 8.5122800, 77.5535000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77701, 'Kalaīkunda', 'Kalaikunda', '', 22.3393000, 87.2263700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77702, 'Kālāgarh Project Colony', 'Kalagarh Project Colony', 'Kalagarh,Kalagarh Project Colony,Kālāgarh,Kālāgarh Project Colony', 29.4778000, 78.7844900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77703, 'Kālādhūngi', 'Kaladhungi', 'Kaladhungi,Kālādhūngi', 29.2835100, 79.3510000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77704, 'Kakrāla', 'Kakrala', 'Kakrala,Kakrāla', 27.8926900, 79.1945000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77705, 'Kākori', 'Kakori', 'Kakori,Kākori', 26.8680000, 80.7857000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77706, 'Kākināda', 'Kakinada', 'Cocanada,Coconada,East Godavari,Godavari,Kakinada,Kākināda,kakinada,Какинада,కాకినాడ', 16.9603600, 82.2380900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77707, 'Kakching', 'Kakching', 'Kakching', 24.4982000, 93.9812600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77708, 'Kaithal', 'Kaithal', 'Kaithal,Kajtkhal,ka''ithala,kai ta er,kaithala,kythal,Кайтхал,كيتهال,کیتھل,कैथल,কাইথাল,ਕੈਥਲ,କୈଥଲ,凯塔尔', 29.8015300, 76.3995900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77709, 'Kairāna', 'Kairana', 'Kairana,Kairāna', 29.3954100, 77.2054000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77710, 'Kaintarāgarh', 'Kaintaragarh', 'Athmalik,Athmallik,Kaintaragarh,Kaintarāgarh', 20.7210200, 84.5350500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77711, 'Kaimori', 'Kaimori', 'Kaimori,Kaimur,Kymore', 23.3846500, 79.7442000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77712, 'Kaimganj', 'Kaimganj', 'Kaimganj', 27.5544100, 79.3352500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77713, 'Kailāshahar', 'Kailashahar', 'IXH,Kailasahar,Kailashahar,Kailāshahar', 24.3319900, 92.0039100, 'IN', '2017-03-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77714, 'Kailāras', 'Kailaras', 'Kailaras,Kailāras', 26.3049800, 77.6160000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77715, 'Kaikalūr', 'Kaikalur', '', 16.5515400, 81.2140000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77716, 'Kāgal', 'Kagal', 'Kagal,Kāgal', 16.5770200, 74.3154400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77717, 'Kadūr', 'Kadur', 'Kadur,Kadūr', 13.5528500, 76.0116400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77718, 'Kadod', 'Kadod', 'Kadod', 21.2171700, 73.2197200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77719, 'Kadiri', 'Kadiri', 'Kadiri,Кадири', 14.1116800, 78.1598200, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77720, 'Kādīpur', 'Kadipur', 'Kadipur,Kādīpur', 26.1677900, 82.3702800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77721, 'Kadi', 'Kadi', 'Kadi', 23.2990800, 72.3336200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77722, 'Kadaura', 'Kadaura', 'Baoni Kadawa,Kadaura', 25.9853700, 79.8384200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77723, 'Kadambūr', 'Kadambur', 'Kadambur,Kadambūr', 8.9969400, 77.8621800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77724, 'Kadayanallur', 'Kadayanallur', 'Kadaiyanallur,Kadaiyanallūr,Kadayanallur', 9.0727700, 77.3415200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77725, 'Kānchrāpāra', 'Kanchrapara', 'Kachrapara,Kancharapara,Kanchrapara,Kāchrāpāra,Kānchrāpāra', 22.9599800, 88.4284900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77726, 'Kachhwa', 'Kachhwa', 'Kachhwa,Kachhwā', 25.2061500, 82.7144200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77727, 'Kabrāi', 'Kabrai', 'Kabrai,Kabral,Kabrāi', 25.4028100, 79.9997000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77728, 'Jutogh', 'Jutogh', 'Jutogh,Simla', 31.1000000, 77.1166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77729, 'Junnar', 'Junnar', 'Junnar,Shivner,jiu na er,jnar,junnar,junnara,Юннар,جنار,जुन्नर,জুন্নার,ஜூன்னார்,久纳尔', 19.2081500, 73.8752000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77730, 'Jūnāgarh', 'Junagarh', 'Junagarh,Jūnāgarh', 19.8599300, 82.9338500, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77731, 'Jūnāgadh', 'Junagadh', 'Junagad,Junagadh,Junagarh,Junaghur,Jūnāgadh', 21.5196600, 70.4598100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77732, 'Jumri Tilaiyā', 'Jumri Tilaiya', 'Jhumri Telaiya,Jhumri Tellaya,Jumri Tilaiya,Jumri Tilaiyā,Kodarma', 24.4349000, 85.5295100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77733, 'Jalandhar', 'Jalandhar', 'Dzalandar,Dzalandhar,Dzhalandkhar,Dzsalandhar,Dzsálandhár,Dźalandhar,Galangar,Jalandar,Jalandhar,Jullundur,Jullundur City,QJU,gu lang da er,jaladhara,jalandhar,jalandhara,jalandhari,jalantar,jallandaleu,jarandaru,jlndr,Ĝalanĝar,Џаландар,Джаландхар,جالندھر,جلندر,جەلەندەر,जलंधर,जलन्धर,জলন্ধর,ਜਲੰਧਰ,જલંધર,ଜଳନ୍ଧର,ஜலந்தர்,ಜಲಂಧರ್,ജലന്ധർ,ჯალანდჰარი,ジャランダル,賈朗達爾,잘란다르', 31.3255600, 75.5791700, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77734, 'Shādīpur Julāna', 'Shadipur Julana', 'Julana,Julana Shadipur,Julāna,Julāna Shādipur,Shadipur Julana,Shādīpur Julāna', 29.1236800, 76.4051600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77735, 'Jugsālai', 'Jugsalai', 'Jugsalai,Jugsālai,Tatanagar', 22.7766800, 86.1835100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77736, 'Jubbal', 'Jubbal', 'Deorha,Jubbal,Jubbl', 31.1092300, 77.6508500, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77737, 'Jua', 'Jua', '', 15.5307000, 73.9504700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77738, 'Joshīmath', 'Joshimath', 'Joshimath,Joshinath,Joshīmath', 30.5554300, 79.5643600, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77739, 'Jorhāt', 'Jorhat', 'Dzhorkhat,JRH,Jorhat,Jorhāt,Sibsagar,Sibságar,Джорхат', 26.7575100, 94.2030600, 'IN', '2017-03-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77740, 'Jora', 'Jora', 'Jora,Joura,Zhora,Жора', 26.3420900, 77.8092000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77741, 'Jalārpet', 'Jalarpet', 'Jalarpet,Jalārpet,Jolarpettai,Jolārpettai', 12.5702500, 78.5731800, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77742, 'Jogindarnagar', 'Jogindarnagar', 'Jogindarnagar,Joginder Nagar', 31.9872700, 76.7890600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77743, 'Jogīghopa', 'Jogighopa', 'Jogighopa,Jogīghopa', 26.2264600, 90.5724700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77744, 'Jogbani', 'Jogbani', 'Jogbani', 26.3990500, 87.2652500, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77745, 'Jodiya Bandar', 'Jodiya Bandar', 'Jodiya,Jodiya Bandar', 22.7166700, 70.2833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77746, 'Jodhpur', 'Jodhpur', 'Codpur,Dzhodkhpur,Dzodhpur,Dzodhpura,Dzodhpuras,Dzodpur,Dzsodhpur,Dzsódhpur,Dźodhpur,Džodhpura,Džodhpuras,Džódpur,Godhpur,JDH,Jodhpur,Jodhpur City,Tzontchpour,cotpur,gwdpwr,jiao te bu er,jodeupuleu,jodhapura,jodhapuram,jodopuru,jwdapwr,jwdbwr,jwdpwr,jwdھpwr,yodapura,yodhapura,Ĝodhpur,Τζοντχπούρ,Џодпур,Джодхпур,גודפור,جوداپور,جودبور,جودپور,جودھ پور,جودھپور,जोधपुर,जोधपुरम्,जोधपूर,যোদপুর,যোধপুর,ਜੋਧਪੁਰ,જોધપુર,ଯୋଧପୁର,சோத்பூர்,ჯოდპური,ジョドプル,ジョードプル,焦特布尔,조드푸르', 26.2684100, 73.0059400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77747, 'Jodhpur', 'Jodhpur', 'Jodhpur', 21.9017400, 70.0327000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77748, 'Jobner', 'Jobner', 'Jobner', 26.9725700, 75.3875200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77749, 'Jobat', 'Jobat', 'Jobat', 22.4159900, 74.5682800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77750, 'Jīran', 'Jiran', 'Jiran,Jīran', 24.3087100, 74.8908700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77751, 'Jintūr', 'Jintur', 'Jintur,Jintūr', 19.6118600, 76.6874000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77752, 'Jīnd', 'Jind', 'Jind,Jīnd', 29.3157700, 76.3150200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77753, 'Jhūsi', 'Jhusi', 'Jhusi,Jhūsi,Pratishthanpur', 25.4374500, 81.9055000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77754, 'Jhunjhunūn', 'Jhunjhunun', 'Jhunjhunu,Jhunjhunun,Jhunjhunūn,Jhūnjhunu', 28.1255900, 75.3979700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77755, 'Jhinjhāna', 'Jhinjhana', 'Jhinjhana,Jhinjhāna', 29.5211800, 77.2247000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77756, 'Jhīnjhak', 'Jhinjhak', 'Jhinjhak,Jhīnjhak', 26.5609300, 79.7342300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77757, 'Jhārsuguda', 'Jharsuguda', 'Jharsaguda,Jharsguda,Jharsogra,Jharsugra,Jharsuguda,Jharsugude,Jhārsugra,Jhārsuguda', 21.8615900, 84.0178800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77758, 'Jharia', 'Jharia', 'Jharia,gu li ya,jhariya,झरिया,贾里亚', 23.7407900, 86.4145600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77759, 'Jhārgrām', 'Jhargram', 'Jharagram,Jhargram,Jhāragrām,Jhārgrām', 22.4538400, 86.9949700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77760, 'Jhānsi', 'Jhansi', 'Jhansi,Jhānsi', 25.4588700, 78.5799400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77761, 'Jhanjhārpur', 'Jhanjharpur', 'Jhanjharpur,Jhanjhārpur', 26.2646700, 86.2799300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77762, 'Jhālu', 'Jhalu', 'Jhalu,Jhālu,Jhālū', 29.3360900, 78.2260800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77763, 'Jhālrapātan', 'Jhalrapatan', 'Jhalrapatan,Jhalrapatan Chhroni,Jhalrapatan City,Jhalrapatna City,Jhālrapātan,Jhālrapātan Chhroni,Patan,Pātan', 24.5420500, 76.1724200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77764, 'Jhalida', 'Jhalida', '', 23.3654100, 85.9758100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77765, 'Jhālāwār', 'Jhalawar', 'Brijnagar,Jhalawar,Jhālāwār', 24.5963300, 76.1649900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77766, 'Jhajjar', 'Jhajjar', 'Dzhadzhar,Jhajjar,gu jie gu er,jahjar,jhajjara,Джаджар,جاهجار,झज्जर,ঝজ্জর,贾杰贾尔', 28.6063000, 76.6565000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77767, 'Jhā Jhā', 'Jha Jha', '', 24.7741800, 86.3800500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77768, 'Jhābua', 'Jhabua', 'Dkhabua,Jhabua,Jhābua,Дхабуа', 22.7677200, 74.5908700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77769, 'Jewar', 'Jewar', 'Jewar', 28.1220000, 77.5573400, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77770, 'Jevargi', 'Jevargi', 'Jalvergi,Jevargi', 17.0139400, 76.7731700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77771, 'Jetpur', 'Jetpur', '', 22.3447200, 73.8409300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77772, 'Jetpur', 'Jetpur', 'Jetpur', 21.7548200, 70.6234700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77773, 'Jetalsar', 'Jetalsar', '', 21.7089100, 70.5769500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77774, 'Jejūri', 'Jejuri', 'Jejuri,Jejūri', 18.2765800, 74.1600800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77775, 'Jeypore', 'Jeypore', 'Jaypur,Jeyepore,Jeypore,PYB', 18.8563000, 82.5716000, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77776, 'Jaynagar', 'Jaynagar', 'Jayanagar,Jaynagar', 26.5904800, 86.1379100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77777, 'Jaynagar-Majilpur', 'Jaynagar-Majilpur', 'Jaynagar,Jaynagar-Majilpur', 22.1758300, 88.4177800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77778, 'Jayamkondacholapuram', 'Jayamkondacholapuram', 'Jayamkondacholapuram,Jayankondacholpuram', 11.2126600, 79.3636900, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77779, 'Jawhār', 'Jawhar', 'Jawhar,Jawhār', 19.9121300, 73.2267900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77780, 'Iāwar', 'Iawar', 'Iawar,Iāwar,Jawar,Jāwar', 23.0094300, 76.5007000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77781, 'Jawāla Mukhi', 'Jawala Mukhi', 'Jawala Mukhi,Jawalanukhi,Jawāla Mukhi,Jwalamukhi', 31.8745600, 76.3201300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77782, 'Jāwad', 'Jawad', 'Jawad,Jāwad,javada,जावद', 24.5991600, 74.8626100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77783, 'Jaunpur', 'Jaunpur', 'Caunpur,Dzhaunpur,Jaunpur,Jawnpur,jaunapura,jaunapuram,jaunpuru,jauyanapura,jwn pwr,jwnfwr,jwnpwr,jwnpwr  atrprdysh,qiao en pu er,Джаунпур,جون پور,جونفور,جونپور,جونپور، اترپردیش,जौनपुर,जौनपुरम्,জৌয়ানপুর,જૌનપુર,ジャウンプル,乔恩普尔', 25.7535600, 82.6868900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77784, 'Jatāra', 'Jatara', 'Jatara,Jatāra', 25.0096400, 79.0486900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77785, 'Jatani', 'Jatani', 'Jatani,Jatni,Jātni', 20.1597500, 85.7074200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77786, 'Jaswantnagar', 'Jaswantnagar', 'Jaswantnagar', 26.8827100, 78.9025600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77787, 'Jasrāna', 'Jasrana', 'Jasrana,Jasrāna', 27.2358700, 78.6524400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77788, 'Jaspur', 'Jaspur', 'Jaspur', 29.2791900, 78.8279800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77789, 'Jasidih', 'Jasidih', 'Jasidih', 24.5137900, 86.6457600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77790, 'Jashpurnagar', 'Jashpurnagar', 'Jashpur,Jashpurnagar', 22.8877200, 84.1392500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77791, 'Jasdan', 'Jasdan', 'Jasdan', 22.0370900, 71.2079400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77792, 'Jarwal', 'Jarwal', 'Jarwal', 27.1629000, 81.5417900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77793, 'Jaorā', 'Jaora', 'Jaora,Jaorā', 23.6378300, 75.1271100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77794, 'Jānsath', 'Jansath', 'Jansath,Jānsath', 29.3250200, 77.8504400, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77795, 'Jānjgīr', 'Janjgir', 'Janjgir,Jānjgīr', 22.0092200, 82.5778000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77796, 'Jangipur', 'Jangipur', '', 24.4700100, 88.0765900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77797, 'Jangaon', 'Jangaon', 'Jangaon,Jangoon', 17.7260200, 79.1523600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77798, 'Jandiāla Gurū', 'Jandiala Guru', 'Jandiala Guru,Jandiāla Guru,Jandiāla Gurū', 31.5619800, 75.0277000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77799, 'Jandiāla', 'Jandiala', 'Jandiala,Jandiali,Jandiāla', 31.1593000, 75.6175500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77800, 'Jāmuria', 'Jamuria', 'Jamuria,Jaykayanagar,Jaykaynagar,Jāmuria', 23.7046800, 87.0787200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77801, 'Jamūī', 'Jamui', 'Jamui,Jamūi,Jamūī', 24.9260600, 86.2253100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77802, 'Jāmtāra', 'Jamtara', 'Jamtara,Jāmtāra', 23.9630000, 86.8028500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77803, 'Jamshedpur', 'Jamshedpur', 'Cemsidpur,Cemşidpur,Dzamshedpur,Dzhamshedpur,Dzsamsedpur,Gamsedpur,IXW,Jamshedpur,Jarnshedpur,Tatanagar,chamseth pu ra,gu mu xie de bu er,jamasedapura,jamcetpur,jamsedapura,jamsyedeupuleu,jamushedopuru,jia mu xie de bu er,jmshdpwr,jmshyd pwr,jmshydbwr,jmshydpwr,Ĝamŝedpur,Џамшедпур,Джамшедпур,جمشدپور,جمشيد پور,جمشيدبور,جمشیدپور,जमशेदपुर,जमशेदपूर,जम्शेदपुर,জমশেদপুর,জামশেদপুর,જમશેદપુર,ଜାମସେଦପୁର,ஜம்சேத்பூர்,జంషెడ్‌పూర్,ಜಮ್ಶೆಡ್‌ಪುರ,ชัมเศทปุระ,ჯამშედპური,ジャムシェドプル,ジャムシェードプル,賈姆謝德布爾,贾姆谢德布尔,잠셰드푸르', 22.8027800, 86.1854500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77804, 'Jamnagar', 'Jamnagar', 'Dzhamnagarom,JGA,Jamnagar,Jamnogar,Jāmnagar,Navanagar,Navangar,Nawanagar,Nowanagar,Nowanuggur,Джамнагаром', 22.4729200, 70.0667300, 'IN', '2016-12-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77805, 'Jammu', 'Jammu', 'Dzammu,Dzamu,Dzhammu,Džammú,Džamu,Gamu,Gorad Dzhamu,IXJ,Jammu,Jammu City,cam''mu,gu mu mu,jam''mu,jammu,jamu,janmu,Ĝamu,Џаму,Горад Джаму,Джамму,جموں,जम्मू,জম্মু,ਜੰਮੂ,சம்மு,ജമ്മു,ジャンムー,贾姆穆,잠무', 32.7356900, 74.8691100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77806, 'Jammalamadugu', 'Jammalamadugu', 'Jammalamadugu', 14.8467700, 78.3831400, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77807, 'Jamkhandi', 'Jamkhandi', 'Jamkhandi', 16.5046100, 75.2914600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77808, 'Jambusar', 'Jambusar', 'Jambusar', 22.0523600, 72.8007400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77809, 'Jamālpur', 'Jamalpur', 'Jamalpur,Jamālpur', 25.3125800, 86.4888800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77810, 'Jāmai', 'Jamai', 'Jamai,Jumiardev,Jumiārdev,Jāmai', 22.1964400, 78.5919100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77811, 'Jāmadoba', 'Jamadoba', 'Jamadoba,Jāmadoba', 23.7166700, 86.4000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77812, 'Jalpāiguri', 'Jalpaiguri', 'Jalpaiguri,Jalpāiguri,Paiguri', 26.5166700, 88.7333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77813, 'Jalor', 'Jalor', '', 25.3455800, 72.6155900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77814, 'Jālna', 'Jalna', 'Jalna,Jālna', 19.8410200, 75.8863600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77815, 'Jalgaon Jamod', 'Jalgaon Jamod', 'Dzhalgaone,Jaigaon,Jalgaon,Jāigaon,Jālgaon,Джалгаоне', 21.0519400, 76.5346400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77816, 'Jalgaon', 'Jalgaon', 'Dzalgaon,Dzhalgaon,Dzhalgaone,Galgaon,Jalgaon,Jālgaon,jalagamo,jalagamva,jalaganva,jalagava,jalgaw,jalgawn,jalkav,jia er gang,jlgawn,Ĝalgaon,Џалгаон,Джалгаон,Джалгаоне,جالگاو,جالگاون,جلگاؤن,جلگاؤں,जलगाँव,जलगाव,जळगाव,জালগাঁও,જલગાંવ,ஜள்காவ்,加爾岡', 21.0029200, 75.5660200, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77817, 'Jalgaon', 'Jalgaon', 'Jalgaon', 17.7402600, 73.1908700, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77818, 'Jaleshwar', 'Jaleshwar', 'Jaleshwar,Jaleswar', 21.8017600, 87.2225000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77819, 'Jalesar', 'Jalesar', 'Jalesar,Jalesar Town', 27.4731500, 78.3031000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77820, 'Jālaun', 'Jalaun', 'Jalaun,Jālaun', 26.1451000, 79.3366000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77821, 'Jalālpur', 'Jalalpur', 'Jalalpur,Jalālpur', 26.3116200, 82.7385900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77822, 'Jalālpur', 'Jalalpur', 'Jalalpore,Jalalpur,Jalālpur,Surat', 20.9489600, 72.8982900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77823, 'Jalālī', 'Jalali', 'Jalali,Jalāli,Jalālī', 27.8668000, 78.2526700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77824, 'Jalālābād', 'Jalalabad', 'Jalalabad,Jalālābād', 30.6062200, 74.2572700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77825, 'Jalālābad', 'Jalalabad', 'Jalalabad,Jalālābad,Jalālābād', 29.6185300, 77.4390800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77826, 'Jalālābād', 'Jalalabad', '', 27.7262500, 79.6552300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77827, 'Jalakandapuram', 'Jalakandapuram', 'Jalakandapuram,Jalakandāpuram,Jalakantapuram', 11.6977900, 77.8729800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77828, 'Jākhal', 'Jakhal', 'Jakhal,Jakhal Mandi,Jākhal', 29.7962700, 75.8239200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77829, 'Jājpur', 'Jajpur', 'Gaypur,Jajpur,Jājpur', 20.8485200, 86.3372900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77830, 'Jaito', 'Jaito', '', 30.4512600, 74.8918900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77831, 'Jaithāri', 'Jaithari', 'Jaithari,Jaithāri', 23.2085600, 78.6148700, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77832, 'Jaitāran', 'Jaitaran', 'Jaitaran,Jaitāran', 26.2044600, 73.9367600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77833, 'Jaisingpur', 'Jaisingpur', 'Jaisingpur,Jayasingpar,Jaysingpur', 16.7763900, 74.5536100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77834, 'Jaisinghnagar', 'Jaisinghnagar', 'Jaisinghnagar', 23.6858200, 81.3908500, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77835, 'Jaisalmer', 'Jaisalmer', 'Dzaisalmer,Dzhajsalmer,Dzsaiszalmer,Džaisalmér,Gorad Dzhajsalmer,JSA,Jailsamer,Jaisalmer,Tzaisalmer,gu sha mei er,jaisalamera,jaisalmeleu,jaisarumeru,jayasalamera,jesalamera,jeycalmer,jyslmyr,Τζαϊσαλμέρ,Горад Джайсалмер,Джайсалмер,جیسلمیر,जेसलमेर,जैसलमेर,জয়সলমের,জয়সালমের,ਜੈਸਲਮੇਰ,જેસલમેર,ଜୈସଲମେର,ஜெய்சல்மேர்,ജയ്സാൽമീർ,ジャイサルメール,贾沙梅尔,자이살메르', 26.9176300, 70.9038700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77836, 'Jais', 'Jais', 'Jais,Jāis', 26.2649000, 81.5485500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77837, 'Jaipur', 'Jaipur', 'Caypur,Dzaipur,Dzaipuras,Dzajpur,Dzajpura,Dzhajpur,Dzsaipur,Dźajpur,Džaipur,Džaipuras,Džajpur,Džajpura,Gajpuro,Gorad Dzhajpur,Iaipura,JAI,Jainagar,Jaipur,Jaipur City,Jayapur,Jaypur,Jeypore,Tzaipour,Zhajpur,ceyppur,chay pu ra,gʼypwr,jaipuleu,jaipura,jaipuru,jayapura,jayapuram,jaybwr,jaypwr,jypwr,zhai pu er,zhai pu ya,Ĝajpuro,Τζαϊπούρ,Џајпур,Горад Джайпур,Джайпур,Жайпур,Ջայպուր,גאיפור,جايبور,جایپور,جيپور,جے پور,जयपुर,जयपुरम्,जयपूर,জয়পুর,জয়পুৰ,ਜੈਪੁਰ,જયપુર,ଜୟପୁର,செய்ப்பூர்,ജയ്‌പൂർ,ชัยปุระ,ჯაიპური,ジャイプル,齋浦爾,齋葡亞,자이푸르', 26.9196200, 75.7878100, 'IN', '2015-06-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77838, 'Jainpur', 'Jainpur', 'Jainpur,Jianpur,Jiyanpur,Jīanpur', 26.1538900, 83.3350500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77839, 'Jahāzpur', 'Jahazpur', 'Jahazpur,Jahāzpur', 25.6199400, 75.2760900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77840, 'Jahāngīrpur', 'Jahangirpur', 'Jahangirpur,Jahāngīrpur', 28.1791900, 77.7050100, 'IN', '2016-06-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77841, 'Jahāngīrābād', 'Jahangirabad', '', 28.4054900, 78.1058800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77842, 'Jahānābād', 'Jahanabad', 'Jahanabad,Jahānābād', 28.6302500, 79.7181800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77843, 'Jahānābād', 'Jahanabad', '', 25.2136800, 84.9871000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77844, 'Jagtiāl', 'Jagtial', 'Jagtial,Jagtiāl,jagityala,జగిత్యాల', 18.7947300, 78.9166100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77845, 'Jagraon', 'Jagraon', 'Jagraon,gu ge la ao en,jagara''um,jagararana,jagra''om,jagravam,جگروں,जग्रावं,জাগরাৱন,ਜਗਰਾਉਂ,ଜାଗ୍ରାଓଁ,贾格拉奥恩', 30.7878300, 75.4739100, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77846, 'Jagnair', 'Jagnair', '', 26.8636000, 77.6023100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77847, 'Jaggayyapeta', 'Jaggayyapeta', 'Jaggayyapeta', 16.8938000, 80.0980700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77848, 'Jagdīspur', 'Jagdispur', 'Jagdispur,Jagdīspur', 25.4681100, 84.4193900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77849, 'Jagdīshpur', 'Jagdishpur', 'Jagdishpur,Jagdīshpur', 26.7496700, 80.5451000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77850, 'Jagdalpur', 'Jagdalpur', 'Dzhagdalpur,JGB,Jagdalpur,gu ge da er pu er,jagadalapura,jagadalpura,jgdlpwr,Джагдалпур,جگدلپور,जगदलपुर,जगदलपूर,जगदल्पुर,জগদলপুর,જગદાલપુર,ଜଗଦଲପୁର,జగదల్‌పుర్,贾格达尔普尔', 19.0813600, 82.0213100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77851, 'Jagatsinghapur', 'Jagatsinghapur', 'Jagatsinghapur,Jagatsinghpur,Jagatsingpur', 20.2557000, 86.1711200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77852, 'Jagannāthpur', 'Jagannathpur', '', 22.2217200, 85.6380100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77853, 'Jagalūr', 'Jagalur', 'Jagalur,Jagalūr', 14.5195700, 76.3391500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77854, 'Jagādhri', 'Jagadhri', 'Jagadhri,Jagādhri', 30.1671900, 77.3036700, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77855, 'Jabalpur', 'Jabalpur', 'Dzabalpur,Dzabalpuras,Dzhabalpur,Dzsabalpur,Dżabalpur,Džabalpur,Džabalpuras,Gabalpur,JLR,Jabalpur,Jubbulpore,gu ba er pu er,jabalapura,jabalapuram,jabalpuleu,jabalpur,jabarupuru,japalpur,jbl pwr,jblbwr,Ĝabalpur,Џабалпур,Джабалпур,Ջաբալպուր,جبال‌پور,جبل پور,جبلبور,जबलपुर,जबलपुरम्,জবলপুর,જબલપુર,ଜାବାଲପୁର,ஜபல்பூர்,జబల్పూర్,ജബൽ‌പൂർ,ჯაბალპური,ジャバルプル,贾巴尔普尔,자발푸르', 23.1669700, 79.9500600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77856, 'Itimādpur', 'Itimadpur', '', 27.2354100, 78.1982900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77857, 'Itaunja', 'Itaunja', 'Itaunja', 27.0834700, 80.8967200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77858, 'Itārsi', 'Itarsi', 'Itarsi,Itārsi', 22.6147700, 77.7622200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77859, 'Itānagar', 'Itanagar', 'Itanagar,Itānagar,Kalyanpur,itanagara,itanagaram,itanagaru,ittanakar,Итанагар,इटानगरम्,ईटानगर,ইটানগর,இட்டாநகர்,イタナガル,イーターナガル', 27.0869400, 93.6098700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77860, 'Islāmpur', 'Islampur', 'Islampur,Islāmpur', 26.2654100, 88.1898200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77861, 'Islāmpur', 'Islampur', 'Islampur,Islāmpur', 25.1407500, 85.2058700, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77862, 'Islāmnagar', 'Islamnagar', 'Aryanagar,Aryānagar,Islamnagar,Islāmnagar', 28.3289600, 78.7252400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77863, 'Isāgarh', 'Isagarh', 'Isagarh,Isāgarh', 24.8390600, 77.8827400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77864, 'Irugūr', 'Irugur', 'Irugur,Irugūr', 11.0178200, 77.0628500, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77865, 'Irinjālakuda', 'Irinjalakuda', 'Irinjalakuda,Irinjālakuda', 10.3423800, 76.2112400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77866, 'Iringal', 'Iringal', 'Iringal', 11.5592900, 75.6166300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77867, 'Ingrāj Bāzār', 'Ingraj Bazar', 'English Bazar,English Bāzār,Ingraj Bazar,Ingrāj Bāzār', 25.0044700, 88.1457300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77868, 'Indri', 'Indri', 'Indri,Ramgarh,Rāmgarh', 29.8799900, 77.0597200, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77869, 'Indore', 'Indore', 'IDR,Indaur,Indor,Indore,Indore Madhya Pradesh,Induras,andwr,ayndwr,idaura,indaura,indoleu,indor,indora,indori,indoru,indura,intor,yin duo er,Індаур,Индаур,Индор,إندور,اندور,ایندور,इंदूर,इन्दोर,इन्दौर,ইন্দোর,ਇੰਦੌਰ,ઈંદોર,ଇନ୍ଦୋର,இந்தோர்,ఇండోర్,ಇಂದೋರ್,ഇൻ‌ഡോർ,ინდორი,インドール,印多尔,인도르', 22.7179200, 75.8333000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77870, 'Indi', 'Indi', 'Indi', 17.1773500, 75.9526000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77871, 'Indergarh', 'Indergarh', 'Indergarh', 26.9352100, 79.6712000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77872, 'Indāpur', 'Indapur', 'Indapur,Indapuri,Indāpur', 18.3000000, 73.2500000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77873, 'Imphal', 'Imphal', 'IMF,Imphal,Imphāl,Impkhal,impal,imphala,inparu,Импхал,इंफाल,इम्फाल,ইম্ফল,இம்பால்,インパール', 24.8080500, 93.9442000, 'IN', '2016-02-20', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77874, 'Iluppūr', 'Iluppur', 'Illuppur,Iluppur,Iluppūr', 10.5134700, 78.6235700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77875, 'Ilkal', 'Ilkal', 'Ilkal', 15.9592300, 76.1135100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77876, 'Ilampillai', 'Ilampillai', 'Ilampillai', 11.6055300, 78.0066500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77877, 'Iklehra', 'Iklehra', 'Iklehra', 23.1466700, 76.3904400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77878, 'Ikauna', 'Ikauna', 'Ikauna', 27.5309700, 81.9691700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77879, 'Iglās', 'Iglas', 'Iglas,Iglās', 27.7110000, 77.9396700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77880, 'Igatpuri', 'Igatpuri', 'Igatpuri,Vigatpuri,Wigatpura,aygatpwry,aygt pwry,igatapuri,igatpuri,yi jia te pu li,ایگاتپوری,ایگت پوری,इगतपुरी,ইগাটপুরি,ઇગતપુરી,ഇഗത്പുരി,伊加特普里', 19.6952200, 73.5626000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77881, 'Idukki', 'Idukki', 'Idiaki,Idikki,Idukki', 9.8500000, 76.9666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77882, 'Idappadi', 'Idappadi', 'Edapadi,Edappadi,Idappadi,Idāppādi', 11.5862400, 77.8389100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77883, 'Ichhāwar', 'Ichhawar', 'Ichhawar,Ichhāwar', 23.0281600, 77.0172900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77884, 'Ichchāpuram', 'Ichchapuram', 'Ichapuram,Ichchapur,Ichchapuram,Ichchāpuram,Ichekapuram,iccapuram,ఇచ్చాపురం', 19.1139300, 84.6872100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77885, 'Ichalkaranji', 'Ichalkaranji', 'Icalkarandzi,Ichalkaranji,aychalkaranjy,aychl krnjy,aychlkyrnjy,icalakaranaji,icalakaranji,icalkaranji,yi qie er ge lun ji,Ицалкаранџи,ایچالکارانجی,ایچل کرنجی,ایچلکیرنجی,इचलकरंजी,ईचल्करंजी,ইচালকরনজি,ଇଚାଲକରଞ୍ଜି,伊切尔格伦吉', 16.6911700, 74.4605400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77886, 'Hyderabad', 'Hyderabad', 'Bhaganagar,HYD,Haidarabadas,Haiderabad,Hajdarabad,Hajdarábád,Hyderabad,Hyderabad-Deccan,Hyderābād,Khajdarabad,Khajderabad,hai de la ba,haidarabada,haidarabadu,haiderabado,haitarapat,hayadarabada ema. karporesana,hayadrabada,hydr abad,hydr abad dkn,hydrabad,Хайдарабад,Хајдерабад,حیدر آباد,حیدر آباد دکن,حیدرآباد,हैदराबाद,হায়দরাবাদ এম. কর্পোরেশন,হায়দ্রাবাদ,ஹைதராபாத்,హైదరాబాదు,ハイデラバード,海得拉巴', 17.3840500, 78.4563600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77887, 'Hadagalli', 'Hadagalli', 'Hadagalli,Huvinabadgalli,Huvvmahadagalli', 15.0204800, 75.9318500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77888, 'Husainābād', 'Husainabad', 'Husainabad,Husainābād,Jopla', 24.5284900, 84.0000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77889, 'Hunsūr', 'Hunsur', 'Hunsur,Hunsūr,Khunsur,Хунсур', 12.3035900, 76.2927500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77890, 'Hungund', 'Hungund', 'Hungund', 16.0621300, 76.0586000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77891, 'Hukeri', 'Hukeri', 'Hukeri,hu kai li,hukeri,hukkeri,hukkeri taluka,हुकेरी,हुक्केरी,हुक्केरी तालुका,হুকেরী,ಹುಕ್ಕೇರಿ,胡凯里', 16.2308200, 74.6024400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77892, 'Hugli', 'Hugli', 'Hooghly,Hooghly-Chinsura,Hooghly-Chinsurah,Hugli,Khugli,Хугли', 22.9087700, 88.3967400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77893, 'Hubli', 'Hubli', 'HBX,Hubballi,Hubli,Hubli City,hubballi,ಹುಬ್ಬಳ್ಳಿ', 15.3477600, 75.1337800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77894, 'Howli', 'Howli', 'Howli', 26.4223700, 90.9800400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77895, 'Hosūr', 'Hosur', 'Hosur,Hosūr,Oossoor', 12.7364700, 77.8326400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77896, 'Hospet', 'Hospet', 'Hosapete,Hospet,Hoszpet,Khospet,hosapeta,hosapete,hospeta,hospete,huo si pei te,hwspt,Хоспет,هوسپت,ہوسپٹ,होसपेटे,होस्पेट,হোসপেত,ಹೊಸಪೇಟೆ,ಹೊಸ್ಪೇಟೆ,霍斯佩特', 15.2695400, 76.3871000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77897, 'Hoskote', 'Hoskote', 'Hoskote', 13.0707000, 77.7981400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77898, 'Hoshangābād', 'Hoshangabad', 'Hoshangabad,Hoshangābād', 22.7474700, 77.7273600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77899, 'Hosdurga', 'Hosdurga', 'Hosadurga,Hosdurga', 13.7963100, 76.2840800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77900, 'Hosangadi', 'Hosangadi', '', 13.6975600, 74.9542700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77901, 'Hosanagara', 'Hosanagara', 'Hosanagara', 13.9138700, 75.0650300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77902, 'Hosakote', 'Hosakote', 'Hoskote', 14.2760300, 77.1682700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77903, 'Honnāli', 'Honnali', 'Honnali,Honnāli', 14.2397600, 75.6450700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77904, 'Honāvar', 'Honavar', 'Honavar,Honawar,Honore,Honāvar,Onore', 14.2808800, 74.4449700, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77905, 'Homnābād', 'Homnabad', 'Hominabad,Homnabad,Homnābād', 17.7707400, 77.1251900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77906, 'Hole Narsipur', 'Hole Narsipur', '', 12.7863500, 76.2433100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77907, 'Holalkere', 'Holalkere', 'Holalkere', 14.0429500, 76.1849600, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77908, 'Hojāi', 'Hojai', 'Hojai,Hojal,Hojāi,Hōjāl', 26.0028100, 92.8560500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77909, 'Hodal', 'Hodal', 'Hodal', 27.8919600, 77.3674400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77910, 'Hisuā', 'Hisua', 'Hisua,Hisuā', 24.8336000, 85.4172900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77911, 'Hisar', 'Hisar', 'HSS,Hisar,Hissar,Hissār,Hisār,Khisar,hisara,hsar,xi sa er,Хисар,حصار,ہسار,ہیسار,हिसार,હિસાર,ହିସାର,希萨尔', 29.1539400, 75.7229400, 'IN', '2015-06-01', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77912, 'Hiriyūr', 'Hiriyur', 'Hiriyur,Hiriyūr', 13.9445500, 76.6172300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77913, 'Hirekerūr', 'Hirekerur', 'Hirekerur,Hirekerūr', 14.4550600, 75.3952000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77914, 'Hīrāpur Hamesha', 'Hirapur Hamesha', 'Hirapur,Hirapur Hamesha,Hīrāpur,Hīrāpur Hamesha', 21.5554600, 79.7858100, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77915, 'Hirānagar', 'Hiranagar', 'Hiranagar,Hirānagar,Hīrānagar', 32.4549300, 75.2718700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77916, 'Hīrākud', 'Hirakud', 'Hirakud,Hīrākud,Hīrākūd', 21.5250200, 83.8727500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77917, 'Hinjilikatu', 'Hinjilikatu', 'Hinjili,Hinjilicut,Hinjilikatu', 19.4816600, 84.7448900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77918, 'Hingoli', 'Hingoli', 'Hingoli,Khingoli,hingoli,xing ge ao li,Хинголи,ہنگولی,हिंगोली,हिङ्गोली,হিঙ্গোলি,હિંગોલી,兴格奥利', 19.7146400, 77.1423800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77919, 'Hinganghāt', 'Hinganghat', 'Hinganghat,Hinganghāt', 20.5487500, 78.8397800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77920, 'Hindupur', 'Hindupur', 'Hindupur', 13.8280700, 77.4914300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77921, 'Hindoria', 'Hindoria', 'Hindoria,Hindoriā', 23.9034500, 79.5686100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77922, 'Hindaun', 'Hindaun', 'Hindaun,Hindaun City,hinda''una,hindauna,hindauna siti,hindaunanagaram,hindona,xin dao en,हिंडोन,हिण्डौन,हिण्डौन सिटी,हिण्डौननगरम्,হিন্দাউন,欣道恩', 26.7341100, 77.0351900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77923, 'Himatnagar', 'Himatnagar', 'Ahmadnagar,Ahmednagar,Himatnagar', 23.5989300, 72.9660200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77924, 'Hilsa', 'Hilsa', 'Hilsa', 25.3164200, 85.2823400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77925, 'Hesla', 'Hesla', 'Hesla', 24.0631800, 85.8791500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77926, 'Harbatpur', 'Harbatpur', 'Harbatpur,Herbertpur', 30.4386300, 77.7405800, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77927, 'Heggadadevankote', 'Heggadadevankote', 'Heggadadevankote,Heggaddevankote', 12.0880900, 76.3295700, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77928, 'Hazārībāg', 'Hazaribag', 'Hazaribag,Hazaribagh,Hazarybaugh,Hazāribāgh,Hazārībāg,Khazaribag,hajaribaga,Хазарибаг,हजारीबाग', 23.9950700, 85.3610900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77929, 'Hayuliang', 'Hayuliang', 'Hayuliang,Hayutang', 28.0730100, 96.5430500, 'IN', '2016-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77930, 'Hāveri', 'Haveri', 'Haveri,Hāveri', 14.7935400, 75.4044800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77931, 'Hatta', 'Hatta', 'Hatla,Hatta,Khatta,Хатта', 24.1340600, 79.6011900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77932, 'Hātod', 'Hatod', 'Hatod,Hātod', 22.7937800, 75.7392800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77933, 'Hāthras', 'Hathras', 'Hathras,Hāthras', 27.5955100, 78.0520100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77934, 'Hātā', 'Hata', 'Hata,Hāta,Hātā', 26.7412000, 83.7452600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77935, 'Hastināpur', 'Hastinapur', 'Hastinapur,Hastināpur', 29.1604200, 78.0076200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77936, 'Hassan', 'Hassan', 'Hassan,Khasan,ha sang,hasana,Хасан,ಹಾಸನ,哈桑', 13.0071500, 76.0962000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77937, 'Hāsimāra', 'Hasimara', 'Hashimara,Hasimara,Hāsimāra', 26.7469000, 89.3538500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77938, 'Hasanpur', 'Hasanpur', 'Hasanpur', 28.7224900, 78.2843600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77939, 'Hasanpur', 'Hasanpur', '', 27.9694400, 77.4954400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77940, 'Harūr', 'Harur', 'Harur,Harūr', 12.0526700, 78.4802300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77941, 'Harsūd', 'Harsud', 'Harsud,Harsūd', 22.0994700, 76.7342300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77942, 'Harrai', 'Harrai', 'Harrai', 22.6142800, 79.2220700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77943, 'Harpanahalli', 'Harpanahalli', 'Harpanahalli', 14.7876600, 75.9886300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77944, 'Harpālpur', 'Harpalpur', 'Harpalpur,Harpālpur', 25.2877300, 79.3327900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77945, 'Harnai', 'Harnai', 'Harnai,Herni', 17.8134000, 73.0966800, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77946, 'Haringhāta', 'Haringhata', 'Haringhata,Haringhāta,Harringhatta', 22.9647400, 88.5745100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77947, 'Hārij', 'Harij', 'Harij,Hārij', 23.6935600, 71.9070000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77948, 'Harihar', 'Harihar', 'Harihar,ha li ha er,harihara,हरिहर,হরিহর,ಹರಿಹರ,哈里哈尔', 14.5128800, 75.8071600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77949, 'Haridwar', 'Haridwar', 'Hardwar,Hardwār,Haridvar,Haridvár,Haridwar,Haridwār,Khardvar,Kharidvar,arittuvar,haraduraara,haradvara,haridowaru,haridu''ara,haridvar,haridvara,haridvaram,he er de wa er,Хардвар,Харидвар,Харідвар,ہریدوار,हरिद्वार,हरिद्वारम्,হরদুৱার,ਹਰਿਦੁਆਰ,હરદ્વાર,ହରିଦ୍ଵାର,அரித்துவார்,హరిద్వార్,ಹರಿದ್ವಾರ,ഹരിദ്വാർ,ハリドワール,赫尔德瓦尔', 29.9479100, 78.1602500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77950, 'Hariāna', 'Hariana', 'Hariana,Hariāna', 31.6351200, 75.8388700, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77951, 'Harduāganj', 'Harduaganj', 'Harduaganj,Harduganj,Harduāganj', 27.9436100, 78.1578900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77952, 'Hardoī', 'Hardoi', 'Hardoi,Hardoī', 27.3949100, 80.1316500, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77953, 'Harda Khās', 'Harda Khas', 'Harda,Harda Khas,Harda Khās', 22.3441400, 77.0953600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77954, 'Haraiya', 'Haraiya', '', 26.7947700, 82.4643600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77955, 'Hāpur', 'Hapur', 'Hapur,Hāpur', 28.7298500, 77.7806800, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77956, 'Hāora', 'Haora', 'Haora,Haura,Hawrah,Howrah,Hāora,ha''ora,haura,হাওড়া,ハウラー,ハーウラー', 22.5768800, 88.3185700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77957, 'Hanumāngarh', 'Hanumangarh', 'Hanumangarh,Hanumāngarh,Sadulgarh', 29.5818200, 74.3293800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77958, 'Hansot', 'Hansot', 'Hansot,Hansut', 21.5849600, 72.8076400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77959, 'Hānsi', 'Hansi', 'Hansi,Hānsi,Khansi,Ханси', 29.1023900, 75.9625300, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77960, 'Hāngal', 'Hangal', 'Hangal,Hāngal', 14.7646500, 75.1246000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77961, 'Handiā', 'Handia', 'Handia,Handiā', 25.3637900, 82.1865500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77962, 'Hampi', 'Hampi', 'Conjunto Monumental de Hampi,Hampe,Hampi,Hampis,Khampi,hamby,hampe,hampi,hampy,hanpi,heng bi,Хампи,Хампі,هامبي,هامپی,हंपी,हम्पी,হাম্পি,હમ્પી,ହାମ୍ପି,ஹம்பி,హంపి,ಹಂಪೆ,ഹംപി,ჰამპი,ハンピ,亨比,함피', 15.3352000, 76.4603000, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77963, 'Hamīrpur', 'Hamirpur', 'Hamirpur,Hamīrpur', 31.6841100, 76.5250600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77964, 'Hamīrpur', 'Hamirpur', 'Hamirpur,Hamīrpur', 25.9553000, 80.1484200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77965, 'Halvad', 'Halvad', 'Halvad,Halwad', 23.0151600, 71.1802900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77966, 'Hālol', 'Halol', 'Halol,Hālol', 22.5032100, 73.4724200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77967, 'Haliyal', 'Haliyal', 'Haliyal,Haliyāl', 15.3286400, 74.7563800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77968, 'Hālīsahar', 'Halisahar', 'Halisahar,Halishahar,Hālīsahar', 22.9321800, 88.4185900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77969, 'Haldwani', 'Haldwani', 'Haldwani,Haldwani-cum-Kathgodam,Haldwāni,Khaldvani,ha er de wa ni-qiu mu-ka te ge da mu,haladuraani-tilakara-kathagodama,haladwani,haldvani,haldvani-va-kathagodama,Халдвани,Халдвані,ہلدوانی,हल्द्वानी,हल्द्वानी-व-काठगोदाम,হলদুৱানি-তিলকরা-কাঠগোদাম,ହାଲଦ୍ୱାନି,哈尔德瓦尼-丘姆-卡特戈达姆', 29.2225400, 79.5286000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77970, 'Haldībāri', 'Haldibari', 'Haldibabi,Haldibari,Haldībāri', 26.3388700, 88.7822000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77971, 'Haldaur', 'Haldaur', 'Haldaur', 29.2898800, 78.2843700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77972, 'Hājo', 'Hajo', 'Hajo,Hājo,Nij Hajo,Nij Hājo', 26.2452000, 91.5252500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77973, 'Hājipur', 'Hajipur', 'Hajipur,Hajjipur,Hājipur,Hājjīpur,Hājīpur,Khadzhipur,Хаджипур', 31.9771400, 75.7543800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77974, 'Hājīpur', 'Hajipur', 'Hajipur,Hājīpur,Khadzhipur,Хаджипур', 25.6854400, 85.2098100, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77975, 'Hājan', 'Hajan', 'Hajan,Hājan', 34.2989500, 74.6168100, 'IN', '2014-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77976, 'Hailākāndi', 'Hailakandi', 'Hailakandi,Hailikandi,Hailākāndi,Hylakandi,ha''ilakandi,হাইলাকান্দি', 24.6839400, 92.5609700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77977, 'Hāflong', 'Haflong', 'Haflang,Haflong,Hāflong', 25.1647800, 93.0174400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77978, 'Hadgāon', 'Hadgaon', 'Hadgaon,Hadgāon', 19.4955200, 77.6586300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77979, 'Hābra', 'Habra', 'Habra,Hābra', 22.8420200, 88.6560600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77980, 'Gyānpur', 'Gyanpur', 'Gyanpur,Gyānpur', 25.3326800, 82.4663700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77981, 'Gwalior', 'Gwalior', 'GWL,Gvalior,Gwalior,Гвалиор', 26.2298300, 78.1733700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77982, 'Guskhara', 'Guskhara', 'Gushkara,Guskhara', 23.4927600, 87.7348400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77983, 'Guruvāyūr', 'Guruvayur', 'Gurupavanapuri,Guruvayoor,Guruvayur,Guruvāyūr', 10.5943000, 76.0411000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77984, 'Guru Har Sahāi', 'Guru Har Sahai', 'Guru Har Sahai,Guru Har Sahāi', 30.7086200, 74.4040700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77985, 'Gursarāi', 'Gursarai', 'Gursarai,Gursarāi', 25.6167700, 79.1805300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77986, 'Gursahāiganj', 'Gursahaiganj', 'Gursahaiganj,Gursahāiganj', 27.1151800, 79.7317400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77987, 'Gurmatkāl', 'Gurmatkal', 'Gurmatkal,Gurmatkol,Gurmatkāl', 16.8677300, 77.3908800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77988, 'Gurh', 'Gurh', 'Goorha,Gurh', 24.5026500, 81.5003700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77989, 'Gurgaon', 'Gurgaon', 'Gurgaon,Gurgáon,gu er gang,gudaganva,guleugaon,guraga''om,guragamo,guraganv,guraganva,guragavam,gurugaon,gwrgan,gwrgaw,jwrjawn,khur khean,kurkan,Гургаон,Ґурґаон,جورجاون,گرگاؤں,گورگان,گورگاو,گڑگاؤں,गुडगांव,गुरगांव,গুরগাঁও,ਗੁੜਗਾਵਾਂ,ଗୁଡ଼ଗାଓଁ,குர்கான்,ಗುರಗಾಂವ್,ഗുഡ്‌ഗാവ്,คุร์เคาน์,グルガーオン,古爾岡,구르가온', 28.4601000, 77.0263500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77990, 'Gunupur', 'Gunupur', 'Gunupur,gu nu pu er,gunapura,gunupura,গুনুপুর,ଗୁଣପୁର,古努普尔', 19.0804000, 83.8087900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77991, 'Guntur', 'Guntur', 'Guntur,Guntura,Guntūr,guntur,gunturu,Гунтура,గుంటూరు,గుంటూర్', 16.2997400, 80.4572900, 'IN', '2016-03-31', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77992, 'Guntakal Junction', 'Guntakal Junction', 'Guntakai,Guntakal,Guntakal Junction,Guntakul,gantalaka,gong ta ka er,guntakala,guntakallu,kuntakkal,गंतलक,गुंटकल,গুন্তকাল,குண்டக்கல்,గుంతకల్లు,贡塔卡尔', 15.1711200, 77.3624400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77993, 'Gunnaur', 'Gunnaur', 'Gunnaur', 28.2399500, 78.4399400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77994, 'Gundlupēt', 'Gundlupet', 'Gundalpet,Gundlupet,Gundlupēt', 11.8100400, 76.6902700, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77995, 'Guna', 'Guna', 'GUX,Guna', 24.6469100, 77.3113000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77996, 'Gummidipundi', 'Gummidipundi', 'Gumidipoondi,Gummidipundi,Gummidipūndi,Gummudipundi,Gummudipūndi', 13.4076500, 80.1087900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77997, 'Gumla', 'Gumla', 'Gumla', 23.0415600, 84.5439700, 'IN', '2012-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77998, 'Gumia', 'Gumia', 'Gumia', 23.7989600, 85.8238300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(77999, 'Guledagudda', 'Guledagudda', 'Guledagudda,Guledgarh,Guledgud,Guledgudd', 16.0502500, 75.7899700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78000, 'Gulbarga', 'Gulbarga', 'Gul''barga,Gulbarga,Gulburga,Kalaburgi,Kalburgi,Kulbarga,glbrgh,gu er bo jia,gulabarga,gulbaleuga,gulbarga,gurubaruga,kalaburagi,kalaburgi,klbrkt,kulparka,Гулбарга,Гульбарга,كلبركة,گلبرگه,گلبرگہ,गुलबर्ग,गुलबर्गा,गुल्बर्गा,গুলবার্গ,ગુલબર્ગ,குல்பர்கா,గుల్బర్గా,ಕಲಬುರಗಿ,ಕಾಲಬೂರ್ಗಿ,ഗുൽബർഗ,გულბარგა,グルバルガ,古尔伯加,굴바르가', 17.3358300, 76.8375700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78001, 'Gulāothi', 'Gulaothi', 'Gulaothi,Gulāothi', 28.5893800, 77.7931800, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78002, 'Gulābpura', 'Gulabpura', 'Gulabpura,Gulābpura', 25.9044800, 74.6602500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78003, 'Guirim', 'Guirim', 'Guirim', 15.5755200, 73.8072200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78004, 'Guhāgar', 'Guhagar', 'Guhagar,Guhāgar', 17.4841500, 73.1928900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78005, 'Gūduvāncheri', 'Guduvancheri', 'Guduvancheri,Gūduvāncheri', 12.8451900, 80.0605500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78006, 'Gūdūr', 'Gudur', '', 17.4917400, 78.8230200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78007, 'Gūdūr', 'Gudur', 'Gudur,Gūdūr', 14.1509300, 79.8521000, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78008, 'Gudlavalleru', 'Gudlavalleru', 'Gudlavalleru', 16.3500000, 81.0500000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78009, 'Gudiyatham', 'Gudiyatham', '', 12.9460100, 78.8737700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78010, 'Gudivāda', 'Gudivada', 'Gudivada,Gudivāda', 16.4354700, 80.9955500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78011, 'Gudibanda', 'Gudibanda', 'Gudibanda', 13.6709900, 77.7041400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78012, 'Gudāri', 'Gudari', 'Gudari,Gudāri', 19.3476200, 83.7812800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78013, 'Gudalur', 'Gudalur', 'Gudalur,Gūdalūr', 9.6782600, 77.2495100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78014, 'Gubbi', 'Gubbi', 'Gubbi', 13.3121600, 76.9410200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78015, 'Gua', 'Gua', 'Gua', 22.2136100, 85.3877400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78016, 'Goyerkāta', 'Goyerkata', '', 26.6998400, 89.0256500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78017, 'Govindgarh', 'Govindgarh', 'Govindgarh', 27.5042300, 76.9993800, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78018, 'Govindgarh', 'Govindgarh', 'Govindgarh', 24.3784500, 81.2964400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78019, 'Govardhan', 'Govardhan', 'Gobardhan,Govardhan,Govardkhan,Говардхан', 27.4965800, 77.4626300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78020, 'Goshaingaon', 'Goshaingaon', 'Goshaingaon,Gossaigaon', 26.4394600, 89.9630700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78021, 'Goshāīnganj', 'Goshainganj', 'Gosainganj,Goshainganj,Goshāīnganj', 26.7679300, 81.1075200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78022, 'Goshāinganj', 'Goshainganj', 'Gosainganj,Goshainganj,Goshāinganj', 26.5711500, 82.3809100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78023, 'Gosāba', 'Gosaba', 'Gosaba,Gosaha,Gosāba', 22.1654700, 88.8007000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78024, 'Gorūr', 'Gorur', '', 12.8229700, 76.0646300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78025, 'Goregaon', 'Goregaon', 'Goregaon', 18.1548300, 73.2914700, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78026, 'Gorakhpur', 'Gorakhpur', 'Gorakhpur,Gorakpura,Горакпура', 29.4476800, 75.6720600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78027, 'Gorakhpur', 'Gorakhpur', 'GOP,Gorakhpur,Gorakkhpur,Gorakpur,Gorakpura,Goruckpur,Korakhpur,ge lei ke bu er,golakeupuleu,gorakhapura,gorakhapuram,gorakupuru,gwrakpwr,kho rakh pu ra,korakpur,Горакпур,Горакпура,Горакхпур,گوراکپور,گورکھپور,गोरखपुर,गोरखपुरम्,गोरखपूर,গোরখপুর,ਗੋਰਖਪੁਰ,ગોરખપુર,கோரக்பூர்,ಗೋರಖಪುರ,ഗോരഖ്പൂർ,โคราฆปุระ,ゴーラクプル,戈勒克布爾,고라크푸르', 26.7662800, 83.3688900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78028, 'Gopināthpur', 'Gopinathpur', '', 22.6630100, 86.0750000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78029, 'Gobichettipalayam', 'Gobichettipalayam', 'Gobichettipalaiyam,Gobichettipalayam,Gobichettipalyam,Gopichettipalaiyam,Gopichettipālaiyam,ge bi qie di pa la ye mu,gobicettipalayama,kopiccettippalaiyam,گوبیچیٹیپلیام,गोबिचेट्टिपलयम,গোবিচেত্তিপালায়াম,ଗୋବିଚେତ୍ତିପାଲୟମ,கோபிச்செட்டிப்பாளையம்,戈比切蒂帕拉耶姆', 11.4549600, 77.4422000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78030, 'Gopāmau', 'Gopamau', 'Gopamau,Gopāmau', 27.5346800, 80.2850700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78031, 'Gopālur', 'Gopalur', 'Gopalour,Gopalur,Gopālur', 16.6122000, 77.8072800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78032, 'Gopālpur', 'Gopalpur', 'Gopalpur,Gopalpur-on-Sea,Gopālpur,Gopālpur-on-Sea', 19.2586100, 84.9051700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78033, 'Gopālganj', 'Gopalganj', 'Gopalganj,Gopālganj', 26.4673400, 84.4404100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78034, 'Gondiā', 'Gondia', 'Gondia,Gondija,Gondiya,Gondiā,gonadiya,gondiya,gondiya jila,gondiya jille,gong di ye,Гондия,गोंदिया,गोंदिया जिला,गोण्डिया,গোনদিয়া,ಗೊಂದಿಯಾ ಜಿಲ್ಲೆ,贡迪耶', 21.4602600, 80.1920500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78035, 'Gondal', 'Gondal', 'Gondal', 21.9607400, 70.8025500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78036, 'Gondā City', 'Gonda City', 'Gonda,Gonda City,Gonda Oudh,Gondā City,Гонда', 27.1318100, 81.9533200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78037, 'Gomoh', 'Gomoh', 'Gomoh', 23.8735500, 86.1516000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78038, 'Golakganj', 'Golakganj', 'Golakganj,Golakgans', 26.1021600, 89.8227500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78039, 'Gola Gokarannāth', 'Gola Gokarannath', 'Gola,Gola Gokarannath,Gola Gokarannāth', 28.0783700, 80.4705400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78040, 'Golāghāt', 'Golaghat', 'Golaghat,Golāghāt', 26.5116700, 93.9595100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78041, 'Gola Bāzār', 'Gola Bazar', 'Gola Bazar,Gola Bāzār', 26.3446000, 83.3530300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78042, 'Gokul', 'Gokul', 'Gokul', 27.4392600, 77.7201900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78043, 'Gokarna', 'Gokarna', 'Gokarn,Gokarna,Gorad Gokarna,gokarna,kokarnam,Гокарн,Гокарна,Горад Гокарна,गोकर्ण,கோகர்ணம்,గోకర్ణ,ಗೋಕರ್ಣ,ഗോകർണ്ണം', 14.5500000, 74.3166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78044, 'Gokak', 'Gokak', 'Gokak,Gokāk,Гокак', 16.1690100, 74.8239300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78045, 'Gohpur', 'Gohpur', 'Gohpur', 26.8818400, 93.6156000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78046, 'Gohānd', 'Gohand', 'Gohand,Gohānd', 25.6987100, 79.5456700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78047, 'Gohāna', 'Gohana', 'Gohana,Gohāna', 29.1377700, 76.7024700, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78048, 'Gohadi', 'Gohadi', 'Gohad,Gohadi', 26.4327800, 78.4420500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78049, 'Gogāpur', 'Gogapur', 'Gogapur,Gogāpur', 23.5574600, 75.5166500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78050, 'Godhra', 'Godhra', 'Godhr,Godhra,Godkhra,Godkhre,ge de la,godhara,godhra,Годхра,Годхре,گودھرا,गोधरा,গোধরা,ગોધરા,ଗୋଧ୍ରା,戈德拉', 22.7754700, 73.6148800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78051, 'Godda', 'Godda', 'Godda,Goddā', 24.8270000, 87.2125000, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78052, 'Gobindpur', 'Gobindpur', 'Gobindpur', 23.8355600, 86.5185300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78053, 'Gobindpur', 'Gobindpur', 'Gobindpur', 22.6339300, 86.0716200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78054, 'Gobārdānga', 'Gobardanga', 'Gobardanga,Gobārdānga', 22.8774000, 88.7547900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78055, 'Goa Velha', 'Goa Velha', 'Antiga Goa,Gamle Goa,Goa Velha,Goa Vieja,Khrami i monastiri Goa,O-Goa,Old Goa,Oud Goa,Senoji Goa,Stara Goa,Stare Goa,Velha Goa,dzveli goa,go''a vel''ha,kaw kea,olda goya,palaiya kova,praacina goraa,pracinagova,purano gova,purano goya,shhr qdym gwa,Ó-Goa,Храми і монастирі Гоа,גואה העתיקה,شهر قدیم گوا,ओल्ड गोय,गोआ वेल्हा,पुरानो गोवा,प्राचीनगोवा,পুরনো গোয়া,প্ৰাচীন গোৱা,பழைய கோவா,ಬಾಮ್ ಜೀಸಸ್ ಬೆಸಿಲಿಕಾ ಮತ್ತಿತರ ಚರ್ಚ್‌ಗಳು,ഓൾഡ‍് ഗോവ,กัวเก่า,ძველი გოა', 15.4438400, 73.8857200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78056, 'Goālpāra', 'Goalpara', 'Goalpara,Goālpāra', 26.1766800, 90.6263400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78057, 'Old Goa', 'Old Goa', 'GOI,Staryj Goa,Velha Goa,Старый Гоа', 15.5019500, 73.9100900, 'IN', '2017-07-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78058, 'Girīdīh', 'Giridih', 'Giridih,Girīdīh,girid''iha,girid''iha jila,giridi,gryڈyہ,گریڈیہ,गिरीडीह,गिरीडीह जिला,গিরিডি', 24.1856100, 86.3077200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78059, 'Gingee', 'Gingee', 'Gingee,Gingi,cenci,ginji,jing ge ai ai,jingi,jinji,shenji,गिन्जी,जिंजी,জিঙ্গী,செஞ்சி,シェンジ,京格埃埃', 12.2528200, 79.4172700, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78060, 'Giddarbāha', 'Giddarbaha', 'Giddarbaha,Giddarbāha', 30.1995300, 74.6662700, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78061, 'Giddalūr', 'Giddalur', '', 15.3743900, 78.9260900, 'IN', '2016-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78062, 'Gīdam', 'Gidam', 'Gidam,Gidum,Gīdam', 18.9743100, 81.3989400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78063, 'Ghugus', 'Ghugus', 'Ghugus,Ghūgus', 19.9381000, 79.1119200, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78064, 'Ghoti Budrukh', 'Ghoti Budrukh', 'Ghoti,Ghoti Budrukh', 19.7164100, 73.6282100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78065, 'Ghosī', 'Ghosi', 'Ghosi,Ghosī', 26.1058700, 83.5393000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78066, 'Ghorāwal', 'Ghorawal', 'Ghorawal,Ghorawul,Ghorwal,Ghorāwal', 24.7545900, 82.7796500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78067, 'Ghogha', 'Ghogha', 'Cogna,Ghogha,Gogha', 21.6881300, 72.2763000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78068, 'Ghoga', 'Ghoga', 'Ghoga', 25.2173800, 87.1571000, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78069, 'Ghiror', 'Ghiror', '', 27.1891200, 78.7931200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78070, 'Ghazīpur', 'Ghazipur', 'Ghazipur,Ghazīpur,Ghāzīpur', 25.5833300, 83.5852600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78071, 'Ghāziābād', 'Ghaziabad', 'Gaziabad,Ghaziabad,Ghazibad,Ghāziābād,Газиабад', 28.6653500, 77.4391500, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78072, 'Ghātsīla', 'Ghatsila', 'Ghatshila,Ghatsila,Ghātsīla', 22.5853100, 86.4768200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78073, 'Ghātanji', 'Ghatanji', 'Ghatanji,Ghātanji', 20.1418300, 78.3133300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78074, 'Ghātampur', 'Ghatampur', 'Ghatampur,Ghātampur', 26.1527200, 80.1680300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78075, 'Ghātāl', 'Ghatal', 'Ghatal,Ghātāl', 22.6624400, 87.7339900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78076, 'Gharghoda', 'Gharghoda', 'Gharghoda', 22.1742700, 83.3517000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78077, 'Gharaunda', 'Gharaunda', 'Gharaunda', 29.5369200, 76.9714200, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78078, 'Ghansor', 'Ghansor', 'Ghansor', 22.6597600, 79.9501300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78079, 'Ghanaur', 'Ghanaur', 'Ghanaur', 30.3309200, 76.6120300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78080, 'Ghumārwīn', 'Ghumarwin', 'Ghamarwin,Ghamārwin,Ghumarwin,Ghumārwīn', 31.4416600, 76.7150900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78081, 'Gevrai', 'Gevrai', 'Gevrai', 19.2637200, 75.7500700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78082, 'George Town', 'George Town', 'George Town', 13.0926000, 80.2801000, 'IN', '2015-03-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78083, 'Gaya', 'Gaya', 'GAY,Gaya', 24.7968600, 85.0038500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78084, 'Gawān', 'Gawan', 'Gawan,Gawān', 28.4196900, 78.3518600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78085, 'Gautampura', 'Gautampura', 'Gautampura,Runaj', 22.9866400, 75.5192100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78086, 'Gauripur', 'Gauripur', 'Gauripur', 26.0833400, 89.9611800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78087, 'Goribidnūr', 'Goribidnur', 'Gauibidanur,Gauribidanur,Gauribidanūr,Goribidnur,Goribidnūr', 13.6107200, 77.5173800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78088, 'Gaurela', 'Gaurela', '', 22.7544900, 81.9010700, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78089, 'Guwahati', 'Guwahati', 'GAU,Gauhati,Gauháti,Gauhāti,Gaukhati,Guvahati,Guvahatis,Guvakhati,Guwahati,gauhati,gu wa ha ti,gu''ahati,guhati,guraahati,guvahati,guvahatti,guwahati,guyahati,gwahty,gwaty,gwwaہaty,jwahaty,kuvahatti,kuvakatti,Гаухати,Гувахати,Ґувахаті,جواهاتي,گواتی,گواهتي,گوواہاتی,گوہاٹی,गुवहाटी,गुवाहाटी,গুয়াহাটি,গুৱাহাটি,গুৱাহাটী,ਗੁਹਾਟੀ,ગુવાહાટી,ଗୁଆହାଟୀ,குவகாத்தி,குவஹாத்தி,గౌహతి,ಗುವಾಹಾಟಿ,ഗുവഹാത്തി,グワハティ,グワーハーティー,古瓦哈提,구와하티', 26.1844000, 91.7458000, 'IN', '2015-06-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78090, 'Garhwa', 'Garhwa', 'Garhwa,Garwa', 24.1600200, 83.8075500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78091, 'Garui', 'Garui', '', 22.6333300, 88.4000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78092, 'Gariadhar', 'Gariadhar', 'Gariadhar,Gariyadhar', 21.5388900, 71.5773700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78093, 'Gariāband', 'Gariaband', 'Gariaband,Gariāband', 20.6332300, 82.0622100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78094, 'Garhshankar', 'Garhshankar', 'Garhshankar,Garshankar', 31.2153700, 76.1414900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78095, 'Garhmuktesar', 'Garhmuktesar', '', 28.7873200, 78.1021400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78096, 'Garhi Pūkhta', 'Garhi Pukhta', 'Garhi,Garhi Pukhta,Garhi Pūkhta,Garhī,Garhī Pūkhta', 29.5498000, 77.3088100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78097, 'Garhākota', 'Garhakota', 'Garhakota,Garhākota,Garhākotā', 23.7791000, 79.1432100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78098, 'Garhdiwāla', 'Garhdiwala', 'Gardhiwala,Gardhīwāla,Garhdiwala,Garhdiwāla,Garhdīwāla', 31.7414700, 75.7556700, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78099, 'Garautha', 'Garautha', 'Garautha', 25.5719000, 79.2976400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78100, 'Gannavaram', 'Gannavaram', 'Gannavaram,VGA', 16.5409200, 80.8021300, 'IN', '2016-04-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78101, 'Ganj Murādābād', 'Ganj Muradabad', 'Ganj Muradabad,Ganj Murādābād,Muradabad Patti,Murādābad Patti', 26.9573300, 80.1840000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78102, 'Ganjām', 'Ganjam', 'Canjam,Ganjam,Ganjām', 19.3870500, 85.0507900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78103, 'Ganguvāda', 'Ganguvada', 'Ganguvada,Ganguvāda,ganguvada,గంగువాడ', 18.6666700, 84.1166700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78104, 'Gangtok', 'Gangtok', 'Gangtok,Gangtoka,Gangtokas,gagatoka,gan tuo ke,ganatoka,gangataka,gangatok,gangatoka,gangtokeu,gannteakk,gantoka,gantoku,gngtwk,gyantaka,kentak,Гангток,Ґанґток,گنگتوک,گینگٹاک,गंगटोक,गङ्गटोक्,गाङतोक,गान्तोक,গ্যাংটক,ਗੰਗਟੋਕ,ગંગટોક,ଗାଙ୍ଗଟକ,கேங்டாக்,ഗങ്ങ്ടോക്ക്,སྒང་ཐོག,განგტოკი,ガントク,甘托克,강토크', 27.3257400, 88.6121600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78105, 'Gangolli', 'Gangolli', 'Gangolli,Ganguli', 13.6502400, 74.6707200, 'IN', '2012-03-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78106, 'Gangoh', 'Gangoh', 'Gangoh', 29.7800400, 77.2634600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78107, 'Gangāwati', 'Gangawati', 'Gangavati,Gangawati,Gangāwati', 15.4313000, 76.5293300, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78108, 'Gangavalli', 'Gangavalli', 'Gangavalli', 11.4982800, 78.6496600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78109, 'Gangārāmpur', 'Gangarampur', 'Gangarampur,Gangārāmpur', 25.4013800, 88.5297800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78110, 'Gangāpur', 'Gangapur', '', 26.4724900, 76.7174400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78111, 'Gangāpur', 'Gangapur', '', 25.2195400, 74.2602800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78112, 'Gangāpur', 'Gangapur', 'Gangapur,Gangāpur', 19.6971800, 75.0104500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78113, 'Gangānagar', 'Ganganagar', 'Ganganagar,Gangānagar,Sri Ganganagar,Sri Gangānagar,Sriganga Najar', 29.9200900, 73.8749600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78114, 'Gangākher', 'Gangakher', '', 18.9696200, 76.7494600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78115, 'Gangaikondān', 'Gangaikondan', 'Gaingundaun,Gangaikondan,Gangaikondān,Gangalkondan', 8.8559700, 77.7795100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78116, 'Gāndhī Nagar', 'Gandhi Nagar', 'Gandhi Nagar,Gandhinagao,Gāndhī Nagar', 13.0063900, 80.2541700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78117, 'Ghandinagar', 'Ghandinagar', 'Gandhinagar,Gandinagar,Ghandinagar,Gāndhīnagar,gandhinagara,gandhinagaram,gandinagaru,ganjinagaru,kantinakar,Гандинагар,गान्धीनगरम्,গান্ধিনগর,গান্ধীনগর,ગાંધીનગર,காந்திநகர்,ガンジナガル,ガンディーナガル', 23.2166700, 72.6833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78118, 'Gāndhīdhām', 'Gandhidham', 'Gandhidham,Gandi Dham,Gāndhīdhām', 23.0833300, 70.1333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78119, 'Gandevi', 'Gandevi', 'Ganadevi,Gandevi', 20.8121400, 72.9981100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78120, 'Gāndarbal', 'Gandarbal', 'Gandarbal,Ganderbal,Gāndarbal', 34.2261900, 74.7747800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78121, 'Gandai', 'Gandai', 'Gandai,Gandai-Pandaria', 21.6666700, 81.1001300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78122, 'Galiākot', 'Galiakot', 'Galiakot,Galiākot', 23.5199500, 74.0202800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78123, 'Gajraula', 'Gajraula', 'Gajraula', 28.8457000, 78.2396000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78124, 'Gajendragarh', 'Gajendragarh', 'Gajendragad,Gajendragarh', 15.7362800, 75.9697600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78125, 'Gagret', 'Gagret', 'Gagret', 31.6584600, 76.0614400, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78126, 'Gadwāl', 'Gadwal', 'Gadwal,Gadwāl', 16.2350400, 77.7955600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78127, 'Gadhinglaj', 'Gadhinglaj', 'Gadhinglaj,gadahinglaja,gadhingalaja,gadhinlaja,garahinlaja,jia ding ge la jie,گدھنگ لاج,गडहिंग्लज,गधिंगलज,গড়হিংলাজ,গাধিংলাজ,加丁格拉杰', 16.2229100, 74.3501000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78128, 'Gadhada', 'Gadhada', 'Gadhada', 21.9695700, 71.5782800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78129, 'Gādarwāra', 'Gadarwara', 'Gadarwara,Gādarwāra', 22.9235000, 78.7849000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78130, 'Gadag', 'Gadag', 'Gadag', 15.4297700, 75.6297100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78131, 'Fort Gloster', 'Fort Gloster', '', 22.5044400, 88.1833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78132, 'Forbesganj', 'Forbesganj', 'Forbesganj', 26.3025300, 87.2655600, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78133, 'Fīrozpur Jhirka', 'Firozpur Jhirka', 'Ferozepur,Ferozepur-Jhirka,Ferozpur Jhirka,Firozpur Jhirka,Fērozpur Jhirka,Fīrozpur Jhirka', 27.7885300, 76.9449600, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78134, 'Ferozepore', 'Ferozepore', 'Ferozepore,Ferozepur,Feruzpur,Firozpur,Fērūzpur,Fīrozpur', 30.9257400, 74.6131100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78135, 'Fīrozābād', 'Firozabad', 'Firozabad,Fīrozābād', 27.1509200, 78.3978100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78136, 'Ferokh', 'Ferokh', 'Ferok,Feroke,Ferokh', 11.1798900, 75.8414100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78137, 'Fāzilka', 'Fazilka', 'Fazika,Fazilka,Fāzilka', 30.4020700, 74.0283600, 'IN', '2014-10-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78138, 'Fatwa', 'Fatwa', '', 25.5095800, 85.3050400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78139, 'Fatehpur Sīkri', 'Fatehpur Sikri', 'Fatehpur Sikri,Fatehpur Sīkri,Fatehpur-Sikri,Fatekhpur Sikri,fatehapura sikari,fth pwr sykry,phatepur sikri,Фатехпур Сикри,فتح پور سیکری,फ़तेहपुर सीकरी,ಫತೇಪುರ್ ಸಿಕ್ರಿ', 27.0937000, 77.6600300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78140, 'Fatehpur Chaurāsi', 'Fatehpur Chaurasi', 'Fatehpur,Fatehpur Chaurasi,Fatehpur Chaurāsi', 26.7892500, 80.2654700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78141, 'Fatehpur', 'Fatehpur', '', 27.9948600, 74.9562800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78142, 'Fatehpur', 'Fatehpur', 'Fatehpur,tahasila fatehapura,तहसील फ़तेहपुर', 27.1728100, 81.2106100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78143, 'Fatehpur', 'Fatehpur', 'Fatehpur,Fatehpur City,Fatekhpur,Фатехпур', 25.9277400, 80.8126600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78144, 'Fatehgarh Chūriān', 'Fatehgarh Churian', 'Chaurian Fatehgarh,Fatehgarh Churian,Fatehgarh Chūriān', 31.8643100, 74.9566500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78145, 'Fatehgarh', 'Fatehgarh', 'Fatehgarh', 27.3640900, 79.6311100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78146, 'Fatehganj West', 'Fatehganj West', '', 28.4662000, 79.3065700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78147, 'Fatehābād', 'Fatehabad', 'Fatahabad,Fatehabad,Fatehābād', 29.5152500, 75.4555400, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78148, 'Fatehābād', 'Fatehabad', '', 27.0264500, 78.3027000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78149, 'Farrukhnagar', 'Farrukhnagar', 'Farrukhnagar', 28.4474500, 76.8239100, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78150, 'Farrukhnagar', 'Farrukhnagar', '', 17.0778700, 78.2033900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78151, 'Farrukhābād', 'Farrukhabad', 'Farrukhabad,Farrukhābād', 27.3913400, 79.5793000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78152, 'Farīdpur', 'Faridpur', 'Bharatpur,Faridpur,Farīdpur', 28.2099700, 79.5414900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78153, 'Farīdnagar', 'Faridnagar', 'Faridnagar,Farīdnagar', 28.7692300, 77.6293400, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78154, 'Farīdkot', 'Faridkot', 'Faridkot,Farīdkot', 30.6739900, 74.7557900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78155, 'Faridabad', 'Faridabad', 'Faridabad,Faridabadas,Farīdābād,QNF,faridabado,pharidabada,Фаридабад,फरीदाबाद,ファリダバード,ファリーダーバード', 28.4112400, 77.3131600, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78156, 'Farakka', 'Farakka', '', 24.8166700, 87.9000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78157, 'Farah', 'Farah', 'Farah', 27.3208100, 77.7618500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78158, 'Fālākāta', 'Falakata', 'Falakata,Fālākāta', 26.5196300, 89.2042300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78159, 'Faizpur', 'Faizpur', 'Faizpur', 21.1676600, 75.8600600, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78160, 'Fyzābād', 'Fyzabad', 'Faizabad,Faizābād,Fajzabad,Fyzabad,Fyzābād,Файзабад', 26.7754900, 82.1501800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78161, 'Ettaiyapuram', 'Ettaiyapuram', '', 9.1440500, 77.9906600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78162, 'Etikoppāka', 'Etikoppaka', 'Etikoppaka,Etikoppāka', 17.5000000, 82.7333300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78163, 'Etāwah', 'Etawah', 'Etawah,Etāwah', 26.7761500, 79.0213300, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78164, 'Erumaippatti', 'Erumaippatti', '', 11.1455500, 78.2909500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78165, 'Erraguntla', 'Erraguntla', 'Erraguntla,Yerraguntla', 14.6385300, 78.5397400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78166, 'Erode', 'Erode', 'Brod,Erode,Irodu,Periyar,Periyār,ai luo de,elodeu,eroda,erode,iread,iroda,irodo~u,irotu,Брод,Ироду,اروڑ,इरोड,ईरोड,एरोड,এরোডে,ઇરોડ,ଇରୋଡ,ஈரோடு,ഈറോഡ്,イーロードゥ,埃罗德,에로드', 11.3428000, 77.7274100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78167, 'Erāttupetta', 'Erattupetta', 'Erattupetta,Eratupeta,Erāttupetta', 9.6874700, 76.7789100, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78168, 'Eraniel', 'Eraniel', 'Eraniel', 8.2025000, 77.3153800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78169, 'Erandol', 'Erandol', 'Erandol', 20.9220600, 75.3264100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78170, 'Eral', 'Eral', 'Eral', 8.6239200, 78.0219100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78171, 'Emmiganūr', 'Emmiganur', 'Emmiganur,Emmiganuru,Emmiganūr,Emmiganūru,Yemmiganur', 15.7720300, 77.4834500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78172, 'Ellore', 'Ellore', 'Ellore,Eluru,Elūru,West Godavari,West Godāvari', 16.7131100, 81.1043700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78173, 'Elūr', 'Elur', '', 10.0666700, 76.2833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78174, 'Elumalai', 'Elumalai', 'Elumalai', 9.8637600, 77.6993900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78175, 'Ellenabad', 'Ellenabad', 'Ellenabad,Ellenābād,Kharyal', 29.4528200, 74.6612200, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78176, 'Elāyirampannai', 'Elayirampannai', 'Elayirampannai,Elāyirampannai', 9.2703300, 77.8249400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78177, 'Elamanchili', 'Elamanchili', 'Elamanchili,Yellamanchili,Yellamanchilli', 17.5490700, 82.8574900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78178, 'Egra', 'Egra', 'Egra', 21.8994700, 87.5379400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78179, 'Dwārka', 'Dwarka', 'Dvarka,Dwarka,Dwārka,Дварка', 22.2394400, 68.9677800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78180, 'Dwārāhāt', 'Dwarahat', 'Dwarahat,Dwārāhāt', 29.7778500, 79.4273100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78181, 'Dūsi', 'Dusi', 'Dusi,Dūsi', 12.7757400, 79.6789200, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78182, 'Durgapur', 'Durgapur', 'Durgapur,RDP,do~urugapuru,drgapwr,du er jia bu er,duleugapuleu,durgapura,duർgapuർ  pascima bangaൾ,dwrgapwr,turkapur,turkapur  merku vankalam,Дургапур,درگاپور,دورگاپور,दुर्गापुर,दुर्गापूर,দুর্গাপুর,துர்காபூர்,துர்காபூர்  மேற்கு வங்காளம்,ദുർഗാപൂർ,ദുർഗാപൂർ  പശ്ചിമ ബംഗാൾ,ドゥルガプル,杜爾加布爾,두르가푸르', 23.5158300, 87.3080100, 'IN', '2015-11-29', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78183, 'Durgāpur', 'Durgapur', 'Durgapur,Durgāpur', 20.0054000, 79.3027300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78184, 'Durg', 'Durg', 'Drug,Durg,Durga,drg,du er ge,durga,dwrg,dwrj,Дург,درگ,دورج,دورگ,ڈرگ,दुर्ग,দুর্গ,ଦୁର୍ଗ,杜爾格', 21.1914700, 81.2761900, 'IN', '2015-08-30', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78185, 'Dūngarpur', 'Dungarpur', 'Dungarpur,Dūngarpur', 23.8430600, 73.7146600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78186, 'Dungarpur', 'Dungarpur', '', 21.2877700, 71.7556000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78187, 'Ganj Dundwāra', 'Ganj Dundwara', 'Dundwaraganj,Dundwārāganj,Ganj Dundwara,Ganj Dundwāra', 27.7330800, 78.9411900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78188, 'Dumraon', 'Dumraon', 'Dumraon', 25.5526500, 84.1514900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78189, 'Dumra', 'Dumra', 'Dumra', 26.5670800, 85.5204000, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78190, 'Dumka', 'Dumka', 'Dumka,dmka,du mu ka,dumaka,dumaka jila,dumaka jilla,dumka,dwmka,Думка,دمکا,دومكا,डुमका,दुमका,दुमका जिला,दुमका जिल्ला,दुम्का,দুমকা,ଡୁମକା,杜姆卡', 24.2677800, 87.2485500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78191, 'Dum Duma', 'Dum Duma', 'Doom-Dooma,Dum Duma,Sookerating', 27.5688400, 95.5566400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78192, 'Dam Dam', 'Dam Dam', 'Dam Dam,Dum Dum', 22.6334100, 88.4228600, 'IN', '2017-07-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78193, 'Duliāgaon', 'Duliagaon', 'Duliagaon,Duliāgaon', 27.3722700, 95.3075400, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78194, 'Dugda', 'Dugda', 'Dugda', 23.7451600, 86.1717500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78195, 'Dūdhi', 'Dudhi', 'Dudhi,Dūdhi', 24.2135700, 83.2406700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78196, 'Dudhani', 'Dudhani', 'Dudhani,Dudhni', 17.3579200, 76.3668800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78197, 'Dubrājpur', 'Dubrajpur', 'Dubrajpur,Dubrājpur', 23.7902000, 87.3764800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78198, 'Dostpur', 'Dostpur', 'Dostpur', 26.2748600, 82.4709100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78199, 'Dornakal', 'Dornakal', '', 17.4447500, 80.1490500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78200, 'Dorāha', 'Doraha', 'Doraha,Dorāha', 30.7995300, 76.0235500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78201, 'Dongargarh', 'Dongargarh', 'Dongargarh', 21.1889300, 80.7545900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78202, 'Dongargaon', 'Dongargaon', 'Dongargaon', 20.9717200, 80.8507700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78203, 'Dondaicha', 'Dondaicha', '', 21.3236000, 74.5680400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78204, 'Dombivli', 'Dombivli', 'Dombivali', 19.2166700, 73.0833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78205, 'Doiwāla', 'Doiwala', 'Doiwala,Doiwāla', 30.1766700, 78.1165900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78206, 'Dohrighāt', 'Dohrighat', 'Dohrighat,Dohrighāt,Dohrīghāt', 26.2721700, 83.5091600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78207, 'Dugadda', 'Dugadda', 'Dogadda,Dugadda,Garhwal', 29.8067300, 78.6110900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78208, 'Dod Ballāpur', 'Dod Ballapur', 'Dod Ballapur,Dod Ballāpur', 13.2945200, 77.5377700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78209, 'Doda', 'Doda', 'Doda,Doda District (India)', 33.1491600, 75.5474600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78210, 'Diu', 'Diu', 'DIU,Diu,Div,Diva,Ntiou,Vostrau Dyu,di wu,di''u,diu,diva,dyu,Ντιού,Востраў Дыу,Диу,Діу,दिउ,दीव,দিউ,ഡ്യു,ディーウ,第烏,迪乌,디우', 20.7140500, 70.9822400, 'IN', '2016-06-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78211, 'Dispur', 'Dispur', 'Dishpur,Dispur,Dispuras,di si pu er,dichapura,disapura,diseupuleu,dispur,disupuru,tispur,Диспур,Діспур,दिसपुर,दिसपूर,দিছপুৰ,দিশপুৰ,দিসপুর,ਦਿਸਪੁਰ,દિસપુર,ଦିସପୁର,திஸ்பூர்,ದಿಸ್ಪುರ್,ദിസ്‌പൂർ,დისპური,ディスプル,第斯普尔,디스푸르', 26.1356400, 91.8006900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78212, 'Dīsa', 'Disa', 'Deesa,Dis,Disa,Dīsa,Дис', 24.2561200, 72.1792800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78213, 'Dirba', 'Dirba', 'Dirba', 30.0722200, 75.9960700, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78214, 'Diphu', 'Diphu', 'Diphn,Diphu', 25.8434100, 93.4311600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78215, 'Dīnhāta', 'Dinhata', 'Dinhata,Dīnhāta', 26.1352600, 89.4612900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78216, 'Dindori', 'Dindori', 'Dindori', 22.9414100, 81.0797500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78217, 'Dindigul', 'Dindigul', 'Dhundgal,Dindigul,Dindukkal,Dundigal,dindigul,dindigula,dindukkala,ding di gu er,dyndygwl,tindo~ukkaru,tindo~ukkaru xian,tintukkal,Диндигул,Диндуккал,دیندیگول,दिंडुक्कल,दिण्डुक्कल,दिन्दिगुल,দিন্দিগুল,திண்டுக்கல்,ദിണ്ടിഗൽ,ティンドゥッカル,ティンドゥッカル県,丁迪古爾,딘디굴', 10.3689600, 77.9803600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78218, 'Dīnānagar', 'Dinanagar', 'Dinanagar,Dīnānagar', 32.1366400, 75.4729100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78219, 'Dimāpur', 'Dimapur', 'DMU,Dampur,Dimapur,Dimāpur,Димапур', 25.9117400, 93.7217000, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78220, 'Diguvametta', 'Diguvametta', 'Diguvametta', 15.3950700, 78.8293000, 'IN', '2016-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78221, 'Digras', 'Digras', '', 20.1035000, 77.7184600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78222, 'Dīglūr', 'Diglur', 'Deglur,Diglur,Dīglūr', 18.5482900, 77.5769500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78223, 'Dighwāra', 'Dighwara', 'Digha,Dighwara,Dighwāra', 25.7443400, 85.0100300, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78224, 'Digha', 'Digha', 'Digha,digha,দীঘা', 21.6277600, 87.5196500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78225, 'Digboi', 'Digboi', 'Digboi,Digbol,Digbor', 27.3932100, 95.6183900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78226, 'Digapahandi', 'Digapahandi', 'Digapahandi,Digapanahdi', 19.3727500, 84.5718400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78227, 'Dīg', 'Dig', 'Deeg,Dig,Dīg', 27.4718800, 77.3256400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78228, 'Dīdwāna', 'Didwana', 'Didwana,Dīdwāna', 27.4009600, 74.5753700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78229, 'Dicholi', 'Dicholi', 'Bicholim,Bicholim Town,Cassabe de Bicholim,Cassabé de Bicholim,Dicholi', 15.5931900, 73.9457100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78230, 'Dibrugarh', 'Dibrugarh', 'DIB,Dibrugarh,Dibrugarkh,Lakhinpur,di bu lu jia er,dibraugara,dibrgara,dibrugadh,dibrugadha,dibrugara,dibrugara-nagaram,dibrugarha,dybrwjarh,tiprukar,Дибругарх,ديبروجاره,ڈبروگڑھ,डिब्रुगर-नगरम्,डिब्रूगढ़,दिब्रुगढ,ডিব্রুগড়,ডিব্ৰুগড়,દિબ્રુગઢ,ଦିବୃଗଡ଼,திப்ருகார்,ദിബ്രുഗഢ്,迪布鲁加尔', 27.4798900, 94.9083700, 'IN', '2016-07-02', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78231, 'Dibai', 'Dibai', 'Dibai', 28.2084900, 78.2617300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78232, 'Diamond Harbour', 'Diamond Harbour', 'Diamond Harbor,Diamond Harbour,dayamanda harabara,dayamanda harbara,di ya meng de ha er bo wu er,डायमंड हार्बर,डायमण्ड हार्बर,ডায়মণ্ড হারবার,ডায়মন্ড হারবার,迪亚蒙德哈尔博乌尔', 22.1930300, 88.1846600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78233, 'Dhuwaran', 'Dhuwaran', 'Dhuvaran,Dhuwaran', 22.2377900, 72.7591000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78234, 'Dhūri', 'Dhuri', 'Dhuri,Dhūri', 30.3684600, 75.8679100, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78235, 'Dhupgāri', 'Dhupgari', 'Dhupgari,Dhupguri,Dhupgāri', 26.5890400, 89.0073200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78236, 'Dhuliān', 'Dhulian', 'Dhulian,Dhuliān', 24.6812700, 87.9535000, 'IN', '2016-06-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78237, 'Dhūlia', 'Dhulia', 'Dhule,Dhulia,Dhūlia,Dkhule,Dule,dhule,dwlh,tu lai,Дуле,Дхуле,دوله,دھول,धुले,धुळे,ধুলে,圖萊', 20.9013000, 74.7773700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78238, 'Dhuburi', 'Dhuburi', 'Dhubri,Dhuburi,Dubri,dhubari,धुबरी', 26.0185600, 89.9856400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78239, 'Dhrol', 'Dhrol', 'Dhrol', 22.5670000, 70.4176900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78240, 'Dhrāngadhra', 'Dhrangadhra', 'Dhrangadhra,Dhrangadra,Dhrāngadhra,Dhrāngadra', 22.9916700, 71.4679300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78241, 'Dhorāji', 'Dhoraji', 'Dhorail,Dhoraji,Dhorāji', 21.7335900, 70.4500400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78242, 'Dhone', 'Dhone', 'Dhone', 15.3952000, 77.8715000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78243, 'Dholka', 'Dholka', 'Dholka', 22.7273200, 72.4412800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78244, 'Dhola', 'Dhola', 'Dhola', 21.8812900, 71.7726900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78245, 'Dhing', 'Dhing', 'Dhing', 26.4679300, 92.4733600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78246, 'Dhilwan', 'Dhilwan', 'Dhilwan,Dhilwān', 31.5143200, 75.3457400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78247, 'Dhenkānāl', 'Dhenkanal', 'Dhenkanal,Dhenkānāl', 20.6574400, 85.5969300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78248, 'Dhemāji', 'Dhemaji', 'Dhemaji,Dhemāji', 27.4833300, 94.5833300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78249, 'Dhekiajuli', 'Dhekiajuli', 'Dhekiajuli', 26.7036700, 92.4780800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78250, 'Dhaurahra', 'Dhaurahra', '', 27.9981400, 81.0897500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78251, 'Dhaulpur', 'Dhaulpur', 'Dhaulpur,Dholpur', 26.6928600, 77.8796800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78252, 'Dhārūr', 'Dharur', 'Dharur,Dhārūr,Fatehabad,Fatehabād,Fatheabad', 18.8201700, 76.1093700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78253, 'Dhāruhera', 'Dharuhera', 'Dharuhera,Dhāruhera', 28.2055300, 76.7969100, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78254, 'Dharamsala', 'Dharamsala', 'Bhagsu,DHM,Darmsala,Dharamsala,Dharamshala,Dharmsala,Dharmshala,Dharmsāla,Dharmšála,da lan sa la,dalamsalla,daramusara,daramushara,dharmasala,Дармсала,धर्मशाला,ধর্মশালা,ダラムサラ,ダラムシャーラー,达兰萨拉,다람살라', 32.2200600, 76.3201300, 'IN', '2016-12-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78255, 'Dharmavaram', 'Dharmavaram', 'Dharmavaram', 14.4143500, 77.7203500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78256, 'Dharmapuri', 'Dharmapuri', 'Dharmapuri,Dkharmapuri,da er ma pu li,darumapuri,dharmapuri,tarmapuri,Дхармапури,धर्मपुरी,ধর্মাপুরি,தர்மபுரி,ダルマプリ,达尔马普里', 12.1277000, 78.1579400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78257, 'Dharmanagar', 'Dharmanagar', 'Dharmanagar', 24.3666700, 92.1666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78258, 'Dharmadam', 'Dharmadam', 'Dharmadam', 11.7753800, 75.4645900, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78259, 'Dharmābād', 'Dharmabad', 'Dharmabad,Dharmābād', 18.8911600, 77.8494000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78260, 'Dhāriwāl', 'Dhariwal', 'Dhariwal,Dhāriwāl', 31.9561600, 75.3238600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78261, 'Dhāri', 'Dhari', 'Dhari,Dhāri', 21.3285500, 71.0264500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78262, 'Dhārchula', 'Dharchula', 'Dharchula,Dhārchula', 29.8470700, 80.5195100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78263, 'Dharapuram', 'Dharapuram', 'Dharapuram,Dhārāpuram,da la pu la mu,dharapurama,tarapuram,धारापुरम,ধারাপুরম,தாராபுரம்,达拉普拉姆', 10.7382800, 77.5322300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78264, 'Dharangaon', 'Dharangaon', 'Darangaon,Dharangaon', 21.0118700, 75.2740700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78265, 'Dharampuri', 'Dharampuri', 'Dharampuri', 22.1495100, 75.3443900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78266, 'Dharampur', 'Dharampur', 'Dharampore,Dharampur,Dhurrumpur,Dilarampur', 20.5369300, 73.1736800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78267, 'Dhār', 'Dhar', 'Dhar,Dhār,Dkhar,Дхар', 22.5937300, 75.2977400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78268, 'Dhanwār', 'Dhanwar', 'Dhanwar,Dhanwār', 24.4109900, 85.9818900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78269, 'Dhanera', 'Dhanera', 'Dhanera', 24.5096700, 72.0234300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78270, 'Dhandhuka', 'Dhandhuka', 'Dhandhuka', 22.3818500, 71.9866400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78271, 'Dhanbād', 'Dhanbad', 'DBD,Dhanabad,Dhanbad,Dhanbaid,Dhanbād,Dkhanbad,danbado,dhanabada,Дханбад,धनबाद,ধানাবাদ,ダンバード', 23.8019900, 86.4432400, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78272, 'Dhanaura', 'Dhanaura', 'Dhanaura', 28.9591200, 78.2562900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78273, 'Dhanaula', 'Dhanaula', 'Dhanaula', 30.2821600, 75.5734100, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78274, 'Dhāna', 'Dhana', 'Dhana,Dhāna', 23.7469700, 78.8623400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78275, 'Dhamtari', 'Dhamtari', 'Dhamtari', 20.7071800, 81.5487400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78276, 'Dhāmpur', 'Dhampur', 'Dhampur,Dhāmpur', 29.3088300, 78.5108300, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78277, 'Dhāmnod', 'Dhamnod', 'Dhamnod,Dhāmnod', 22.2092800, 75.4705700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78278, 'Dhali', 'Dhali', 'Dhali', 10.5104900, 77.1880600, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78279, 'Dhāka', 'Dhaka', 'Dhaka,Dhāka', 26.6747900, 85.1669800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78280, 'Dewas', 'Dewas', 'Devas,Dewas,Dewās,de wa si,de''oyasa,deraasa,devasa,dewasu,dwas,dywas,Девас,دواس,دیواس,देवस,देवास,দেওয়াস,দেৱাস,દેવાસ,デーワース,德瓦斯', 22.9658500, 76.0552600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78281, 'Dewā', 'Dewa', 'Dewa,Dewā', 27.0362100, 81.1669200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78282, 'Deoli', 'Deoli', 'Deoli,Devli,Dioli', 25.7572800, 75.3799100, 'IN', '2016-06-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78283, 'Devgarh', 'Devgarh', 'Deogarh,Devgarh', 25.5253300, 73.9081200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78284, 'Devgadh Bāriya', 'Devgadh Bariya', 'Baria,Bariya,Bāria,Devgad Baria,Devgad Bāria,Devgadh Bariya,Devgadh Bāriya', 22.7051700, 73.9088200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78285, 'Devarkonda', 'Devarkonda', '', 16.6918600, 78.9207300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78286, 'Devaprayāg', 'Devaprayag', 'Devaprayag,Devaprayāg', 30.1460300, 78.6027200, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78287, 'Devanhalli', 'Devanhalli', 'Devanahalli,Devanhalli,de wa en ha er li,debanahalli,devanahalli,devanhalli,devu~anaharri,देवनहल्ली,देवन्हल्ली,দেবানহাল্লি,ದೇವನಹಳ್ಳಿ,デーヴァナハッリ,德瓦恩哈尔利', 13.2465500, 77.7118300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78288, 'Devakottai', 'Devakottai', 'Devakottai', 9.9470400, 78.8233000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78289, 'Devadānappatti', 'Devadanappatti', 'Devadanapatti,Devadanappatti,Devadānappatti', 10.1462500, 77.6437100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78290, 'Deūlgaon Rāja', 'Deulgaon Raja', 'Deulgaon Raja,Deūlgaon Rāja', 20.0175700, 76.0375500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78291, 'Desūr', 'Desur', 'Desur,Desūr', 12.4372700, 79.4814500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78292, 'Deshnoke', 'Deshnoke', 'Deshnok,Deshnoke', 27.7983600, 73.3429700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78293, 'Dergaon', 'Dergaon', 'Dergaon', 26.7000000, 93.9666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78294, 'Dera Gopipur', 'Dera Gopipur', 'Dera Gopipur,Dera-Gepipur', 31.8791900, 76.2187100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78295, 'Derā Nānak', 'Dera Nanak', 'Dera Baba Nanak,Dera Nanak,Derā Nānak', 32.0373300, 75.0278700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78296, 'Depālpur', 'Depalpur', 'Depalpur,Depālpur', 22.8509500, 75.5422400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78297, 'Deori Khās', 'Deori Khas', 'Deore,Deori,Deori Khas,Deori Khās,Deorī Khās', 23.3901700, 79.0163000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78298, 'Deoria', 'Deoria', 'Deoria,Deorija,de ao li ya,de''uriya,devariya,dywrya,dywrya  atrprdysh,Деория,دیوریا,دیوریا، اترپردیش,देवरिया,দেউরিয়া,德奥里亚', 26.5016700, 83.7793600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78299, 'Deori', 'Deori', '', 21.4500000, 82.6166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78300, 'Deoraniān', 'Deoranian', 'Deorania,Deoranian,Deoraniān', 28.6298900, 79.4764800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78301, 'Deoli', 'Deoli', 'Deoli', 20.6492000, 78.4802300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78302, 'Deolāli', 'Deolali', 'Deolali,Deolāli', 19.9440400, 73.8344100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78303, 'Deogarh', 'Deogarh', 'Deogarh', 21.5376800, 84.7337200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78304, 'Deoband', 'Deoband', 'Deoband,Deobande,Деобанде', 29.6950500, 77.6796400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78305, 'Denkanikota', 'Denkanikota', '', 12.5301000, 77.7888700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78306, 'Delvāda', 'Delvada', 'Delvada,Delvāda', 20.7754400, 71.0464600, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78307, 'Delhi', 'Delhi', 'DEL,Daehli,Dehli,Dehlī,Delchi,Delhi,Delhio,Delhí,Delhî,Deli,Delis,Delkhi,Dellium,Delí,Dilhi,Dilli,Dillí,Dillī,Dähli,Déhli,Faritani Delhi,Gorad Dehli,New Delhi,Old Delhi,Sahdzahanabad,Stare Deli,de li,dehali,deli,delli,deri,dhilli,dhly,dhly qdym,dil''hi,dili,dilli,dlhy,dly,dlھy,dylhy,na''i dilli,prany dہly,tilli,Šáhdžahanabád,Δελχί,Горад Дэлі,Дели,Делхи,Делі,Деҳли,Старе Делі,Դելի,דלהי,דעלהי,دلهي,دلھی,دلی,دهلي,دهلی قدیم,ديلهى,دہلی,دێھلی,پرانی دہلی,ډېلي,ދިއްލީ,दिल्ली,देहली,नई दिल्ली,দিল্লি,দিল্লী,ਦਿੱਲੀ,દિલ્હી,ଦିଲ୍ଲୀ,தில்லி,ఢిల్లీ,ದೆಹಲಿ,ഡെൽഹി,เดลี,დელი,デリー,德里,델리', 28.6519500, 77.2314900, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78308, 'Dehu', 'Dehu', 'Dehu', 18.7185100, 73.7663500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78309, 'Dehri', 'Dehri', 'Dehm,Dehri', 24.9024700, 84.1821700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78310, 'Dehra Dūn', 'Dehra Dun', 'Dehra,Dehra Dun,Dehra Dūn,Dehradun,Dekhradune,Дехрадуне', 30.3244300, 78.0339200, 'IN', '2015-10-15', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78311, 'Debīpur', 'Debipur', '', 24.2502900, 88.6182400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78312, 'Dayāl Bāgh', 'Dayal Bagh', '', 27.2212200, 78.0109500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78313, 'Davorlim', 'Davorlim', 'Davorlim', 15.2722100, 73.9924200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78314, 'Dausa', 'Dausa', 'Daosa,Dausa,da''usa,dao sa,dausa,Дауса,دوسہ,दौसा,দাউসা,દૌસા,道萨', 26.8900000, 76.3358400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78315, 'Daurāla', 'Daurala', 'Daurala,Daurāla', 29.1134400, 77.7046700, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78316, 'Daund', 'Daund', 'Daund,Dhond,dao en de,daunda,Даунд,ڈونڈ,दौंड,দৌন্দ,道恩德', 18.4651500, 74.5837500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78317, 'Daulatpur', 'Daulatpur', '', 32.0562200, 76.2610100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78318, 'Daulatpur', 'Daulatpur', 'Daulatpur', 31.7887100, 75.9915400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78319, 'Daulatpur', 'Daulatpur', 'Daulatpur,Muhanundp', 25.3260500, 88.3298900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78320, 'Daulatābād', 'Daulatabad', 'Daulatabad,Daulatābād,Даулатабад', 19.9361100, 75.2214800, 'IN', '2017-07-24', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78321, 'Daudnagar', 'Daudnagar', 'Daudnagar', 25.0347300, 84.4009500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78322, 'Dattāpur', 'Dattapur', '', 20.7807500, 78.1407000, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78323, 'Datia', 'Datia', 'Datia', 25.6731200, 78.4590800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78324, 'Dātāganj', 'Dataganj', 'Dataganj,Dātāganj', 28.0253000, 79.4081900, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78325, 'Dasūya', 'Dasuya', 'Dasua,Dasuya,Dasūa,Dasūya', 31.8167900, 75.6531000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78326, 'Dāsna', 'Dasna', 'Dasna,Dāsna', 28.6773600, 77.5225200, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78327, 'Daryāpur', 'Daryapur', 'Daryapur,Daryāpur', 20.9248900, 77.3264400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78328, 'Dārwha', 'Darwha', 'Darwha,Dārwha,Dārwhā', 20.3101700, 77.7725700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78329, 'Darlawn', 'Darlawn', 'Darlawn', 24.0133600, 92.9243900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78330, 'Dārjiling', 'Darjiling', 'Dardzhiling,Dardzilingas,Dardžilingas,Dargiling,Darjeeling,Darjiling,Darĝiling,Dārjiling,Rdorje gling,da ji ling,daleujilling,dar jylng,darjilim,drgylyng,Дарджилинг,דרגילינג,دار جیلنگ,দার্জিলিং,大吉嶺,다르질링', 27.0333300, 88.2666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78331, 'Dariba', 'Dariba', 'Dariba', 24.9486500, 74.1342000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78332, 'Darbhanga', 'Darbhanga', 'Darbanga,Darbhanga,Darbkhanga,Gorad Darbkhanga,da er bang ge a,darabhaga,darabhanga,darbanga,darbhanga,darbhanja,drbnga,Горад Дарбханга,Дарбанга,Дарбханга,داربهانجا,دربنگا,دربھنگا,دربھنگہ,दरभंगा,दरभङ्गा,দারভাঙ্গা,ਦਰਭੰਗਾ,ଦାରଭଙ୍ଗା,దర్భాంగా,ದರ್ಬಂಗ,达尔邦格阿', 26.1521600, 85.8970700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78333, 'Dankaur', 'Dankaur', 'Dankaur', 28.3512100, 77.5550800, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78334, 'Dandeli', 'Dandeli', 'Dandeli', 15.2666700, 74.6166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78335, 'Dinapore', 'Dinapore', 'Danapur,Dinapore,Dānāpur', 25.6370500, 85.0479400, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78336, 'Damoh', 'Damoh', 'Damoh,da mo,dameah,damoha,दमोह,दामोह,দামোহ,દામોહ,ദമോഹ്,达莫', 23.8331200, 79.4419000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78337, 'Dāmnagar', 'Damnagar', 'Damnagar,Dāmnagar', 21.6923200, 71.5174700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78338, 'Daman', 'Daman', 'Daman,Damanas,Damanum,Damao,Damaun,Damán,Damão,Damān,Gorad Daman,NMB,da man,daman,damana,damani,taman,Горад Даман,Даман,دامان,दमण,दमन,ਦਮਨ,દમણ,ଡାମନ,தமன்,ദമൻ,დამანი,ダマン,达曼,達曼,다만', 20.4143100, 72.8323600, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78339, 'Daltonganj', 'Daltonganj', 'Daltenganj,Daltongandzh,Daltonganj,Daltongganj,Dāltenganj,Medininagar,Medninagar,da er tong ge a en jie,daltanaganja,daltanaganjanagaram,Далтонгандж,डाल्टनगंज,डाल्टनगञ्ज,डाल्टनगञ्जनगरम्,দাল্টনগঞ্জ,ଡାଲଟନ୍‌ଗଞ୍ଜ,达尔通格阿恩杰', 24.0397100, 84.0658000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78340, 'Dalsingh Sarai', 'Dalsingh Sarai', 'Dalsingh Sarai,Dalsingh-Sari', 25.6679500, 85.8363600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78341, 'Dalmau', 'Dalmau', 'Dalmau', 26.0647700, 81.0298000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78342, 'Dalkola', 'Dalkola', '', 25.8757700, 87.8400900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78343, 'Dalhousie', 'Dalhousie', 'Dalhousie,da er huo wu xi ye,dalahauji,dalahausi,delaha''ujhi,tal''havuci,डलहौजी,डलहौसी,ডালহৌসি,দালহৌসি,ડેલહાઉઝી,டல்ஹவுசி,ഡൽഹൗസി,达尔霍乌西耶', 32.5521900, 75.9466300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78344, 'Dākor', 'Dakor', 'Dakor,Dākor,Дакор', 22.7526800, 73.1496700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78345, 'Daitari', 'Daitari', 'Daitari', 21.1000000, 85.7500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78346, 'Dohad', 'Dohad', 'Dahod,Dohad,Dāhod', 22.8328300, 74.2598600, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78347, 'Dahegām', 'Dahegam', 'Dahegam,Dahegām,Dehgam,Dehgām', 23.1690300, 72.8216100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78348, 'Dāhānu', 'Dahanu', 'Dahanu,Dāhānu', 19.9677800, 72.7126300, 'IN', '2013-02-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78349, 'Dagshai', 'Dagshai', 'Dagahai,Dagshai,Simla', 30.8843100, 77.0522800, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78350, 'Dādri', 'Dadri', 'Dadri,Dādri', 28.5525700, 77.5540300, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78351, 'Dadra', 'Dadra', 'Dadara,Dadará,Dadra,Dādra,Дадра', 20.3250400, 72.9661800, 'IN', '2017-07-30', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78352, 'Dabwāli', 'Dabwali', '', 29.9490600, 74.7383200, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78353, 'Dabra', 'Dabra', 'Dabra', 25.8857200, 78.3322100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78354, 'Daboh', 'Daboh', 'Daboh', 26.0023900, 78.8765800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78355, 'Dābhol', 'Dabhol', 'Dabhol,Dābhol', 17.5897100, 73.1800100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78356, 'Dabhoi', 'Dabhoi', 'Dabhoi', 22.1833300, 73.4333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78357, 'Cuttack', 'Cuttack', 'Katak,Kataka,Kattak,Kattake,katak,kataka,katakam,katakku,katk,kattak,ke ta ke,kutakeu,kuttaka,Катак,Каттак,Каттаке,کاتک,کوٹاک,کٹک,کټاک,कटक,कटकम्,কটক,কুত্তক,ਕਟਕ,કટક,କଟକ,கட்டக்,కటక్,കട്ടക്,カタック,克塔克,쿠타크', 20.4649700, 85.8792700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78358, 'Curti', 'Curti', 'Curti', 15.4166700, 74.0166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78359, 'Curchorem', 'Curchorem', 'Curchorem,Curchurem', 15.2634900, 74.1087500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78360, 'Cuncolim', 'Cuncolim', 'Cuncolim', 15.1773000, 73.9939200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78361, 'Cumbum', 'Cumbum', 'Cumbum,Kambhamu', 15.5817100, 79.1105900, 'IN', '2016-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78362, 'Cuddapah', 'Cuddapah', 'CDP,Cuddapah,Kadapa,Kurpah,kadapa,katappa,கடப்பா,కడప', 14.4799500, 78.8234600, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78363, 'Cuddalore', 'Cuddalore', 'Cuddalore,Gondelour,Gudalur,Kudalur,Kuddalor,Kuddalore,Kūdalūr,gu da luo er,kadalura,kadaluru,kadaruru,kaddalora,katalur,kudalloleu,kuddalore,Куддалор,Куддалоре,कडलूर,कडलूरु,कड्डालोर,কুদ্দালোরে,કડલૂર,கடலூர்,കടലൂർ,カダルール,古达罗尔,쿠달로르', 11.7462900, 79.7643600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78364, 'Cortalim', 'Cortalim', 'Cortalim,Cortolim', 15.4024700, 73.9088100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78365, 'Coondapoor', 'Coondapoor', 'Coondapoor,Coondapur,Kundapur', 13.6312600, 74.6902000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78366, 'Colva', 'Colva', 'Colva,Kolva,Колва', 15.2797600, 73.9228500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78367, 'Colovale', 'Colovale', 'Colovale,Colvale', 15.6352200, 73.8242600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78368, 'Colonelganj', 'Colonelganj', 'Colonelganj', 27.1343200, 81.6986800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78369, 'Colgong', 'Colgong', 'Colgong', 25.2632800, 87.2326400, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78370, 'Calangute', 'Calangute', 'Calangute,Kalangut,Калангут', 15.5439000, 73.7553000, 'IN', '2008-10-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78371, 'Coimbatore', 'Coimbatore', 'CJB,Coimbatore,Koimbator,Koimbatore,Koimbatur,Kojambuttur,Kojambuttúr,Kovai,Koyambattur,Koyambattūr,Koyamuttur,Koyamuttūr,ge yin bai tuo,keayampattuർ,ko''ibatura,ko''imabatore,ko''imbatora,ko''imbatura,koimbatoleu,kovai,koyambattura,koyambatturu,koyambatura,koyampattur,koyamputtur,koyanbutto~uru,kwymbatwr,kwymbtwr,Коимбатор,Коимбатур,Коїмбатор,كويمباتور,کوئمباتور,کويمبتور,کویمباتور,کویمبٹور,कोइंबतूर,कोयंबतूर,कोयम्बत्तूर,कोयम्बत्तूरु,কোইমবাতোরে,ਕੋਇੰਬਟੂਰ,કોઇમ્બતુર,କୋଇମ୍ବାଟୋର,கோயம்பத்தூர்,கோயம்புத்தூர்,கோவை,కోయంబత్తూరు,ಕೊಯಂಬತ್ತೂರು,കോയമ്പത്തൂർ,ကိုအင်ဘတောမြို့,კოიამპუტური,コーヤンブットゥール,哥印拜陀,코임바토르', 11.0055500, 76.9661200, 'IN', '2015-07-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78372, 'Cochin', 'Cochin', 'British Cochin,COK,Cochim,Cochin,Cochín,Fort Cochin,Kochi,Kochin,Koczin,Kuchi Bandar,Malabar,ke zhi,keacci,kocci,kochi,koci,qwzy,Кочин,קוצי,कोच्चि,কোচি,கொச்சி,കൊച്ചി,コーチ,柯枝', 9.9398800, 76.2602200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78373, 'Clement Town', 'Clement Town', 'Clement Town', 30.2636100, 78.0086200, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78374, 'Chūru', 'Churu', 'Churu,Chūru', 28.3041500, 74.9671800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78375, 'Churāchāndpur', 'Churachandpur', 'Churachandpur,Churāchāndpur', 24.3335300, 93.6699900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78376, 'Chunār', 'Chunar', 'Chunar,Chunār', 25.1277600, 82.8821000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78377, 'Vikāsnagar', 'Vikasnagar', 'Chuharpur,Chūharpur,Vikasnagar,Vikāsnagar', 30.4694400, 77.7727500, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78378, 'Chuāri Khās', 'Chuari Khas', 'Chuari Khas,Chuāri Khās', 32.4305800, 76.0142800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78379, 'Chotila', 'Chotila', 'Chotila', 22.4234700, 71.1964100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78380, 'Chorhat', 'Chorhat', 'Chorhat,Chorhāt,Churhat', 24.4274300, 81.6694800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78381, 'Chopda', 'Chopda', 'Chopda', 21.2457800, 75.2994600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78382, 'Chopan', 'Chopan', 'Chopan', 24.5195400, 83.0228700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78383, 'Cholapuram', 'Cholapuram', 'Cholapuram', 9.3519300, 77.5683900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78384, 'Chodavaram', 'Chodavaram', 'Chodavaram', 17.8288400, 82.9352600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78385, 'Rampachodavaram', 'Rampachodavaram', '', 17.4408800, 81.7755800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78386, 'Chittūr', 'Chittur', 'Chittur,Chittur-Cochin,Chittūr', 10.6996700, 76.7471000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78387, 'Chittoor', 'Chittoor', 'Chittoor,Chittor,Chittur,Chitturu,Chittūru,chtwr,cittara,cittur,cittura,citturu,citura,qi te tuo ao er,shytwr,Читтур,شيتور,چتور,चितूर,चित्तूर,চিত্তর,ଚିତ୍ତୂର,சித்தூர்,చిత్తూరు,奇特托奥尔', 13.2105500, 79.0956000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78388, 'Chittaurgarh', 'Chittaurgarh', 'Chitor,Chitorgarh,Chittaurgarh,Chittor,Chittorgarh', 24.8896300, 74.6240300, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78389, 'Chittaranjan', 'Chittaranjan', 'Chittarandzhan,Chittaranjan,Mihijam,Mihijan,Mihijām,Читтаранджан', 23.8568100, 86.9032400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78390, 'Chittarkonda', 'Chittarkonda', 'Chitrakonda,Chittarkonda', 18.1253300, 82.1089000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78391, 'Chitradurga', 'Chitradurga', 'Chitaldroog,Chitaldrug,Chitaldurg,Chitradurg,Chitradurga,Chitrakaldurga,Chitteldrug,citradurga,citradurga nagara,citradurgam,citraturka,Читрадурга,चित्रदुर्ग,चित्रदुर्गम्,চিত্রদুর্গ,சித்ரதுர்கா,ಚಿತ್ರದುರ್ಗ ನಗರ', 14.2226200, 76.4003800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78392, 'Chītāpur', 'Chitapur', 'Chitapur,Chītāpur', 17.1235700, 77.0824000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78393, 'Chiria', 'Chiria', 'Chiria', 22.3114400, 85.2755600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78394, 'Chirgaon', 'Chirgaon', 'Chirgaon,Chīrgaon', 25.5719800, 78.8143200, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78395, 'Chidawa', 'Chidawa', 'Chirawa,Chirāwa', 28.2393700, 75.6403500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78396, 'Chīrāla', 'Chirala', 'Chirala,Chīrāla', 15.8238500, 80.3521900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78397, 'Chīpurupalle', 'Chipurupalle', '', 18.3114200, 83.5684600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78398, 'Chiplūn', 'Chiplun', 'Chiplun,Chiplūn', 17.5333900, 73.5093500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78399, 'Chintāmani', 'Chintamani', 'Chintamani,Chintāmani,Чинтамани', 13.4005100, 78.0517200, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78400, 'Chinna Salem', 'Chinna Salem', 'Chinna Salem,Chinnasalem', 11.6332500, 78.8722300, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78401, 'Chinnamanūr', 'Chinnamanur', 'Chinnamanur,Chinnamanūr,Chinnammanur', 9.8399900, 77.3810900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78402, 'Chincholi', 'Chincholi', 'Chincholi', 17.4650800, 77.4187400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78403, 'Chinchinim', 'Chinchinim', 'Chinchinim', 15.2144700, 73.9755500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78404, 'Chinchani', 'Chinchani', 'Chinchani,Chinchni', 19.8745800, 72.6851000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78405, 'Chillupār', 'Chillupar', 'Barhalganj,Chillupar,Chillupār,Chillūpār', 26.2822100, 83.5064000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78406, 'Chilakalūrupet', 'Chilakalurupet', '', 16.0898700, 80.1670500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78407, 'Chikodi', 'Chikodi', 'Chikodi,cikkodi,cikodi,cikodi taluka,qi ke di,चिकोडी,चिकोडी तालुका,चिक्कोडी,চিকোদি,ಚಿಕ್ಕೋಡಿ,奇科迪', 16.4289800, 74.5859100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78408, 'Chiknāyakanhalli', 'Chiknayakanhalli', 'Chiknayakanhalli,Chiknāyakanhalli', 13.4160900, 76.6206300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78409, 'Chikmagalūr', 'Chikmagalur', 'Chickmagalur,Chikkamagaluru,Chikkamagalūru,Chikmagalur,Chikmagalūr,Chikmanglur,Chikmugalur,Chikmugalūr,cikkamagaluru,ಚಿಕ್ಕಮಗಳೂರು', 13.3223100, 75.7740000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78410, 'Chikitigarh', 'Chikitigarh', 'Chikati,Chikiti,Chikitigarh,Chīkati', 19.2023300, 84.6145000, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78411, 'Chikhli', 'Chikhli', 'Chikhli', 20.7575100, 73.0626800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78412, 'Chikhli', 'Chikhli', 'Chikhli', 20.3504600, 76.2577400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78413, 'Chik Ballāpur', 'Chik Ballapur', 'Chik Ballapur,Chik Ballāpur', 13.4351200, 77.7278700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78414, 'Chidambaram', 'Chidambaram', 'Chidambaram,Chitdambaram,Cidambaram,cidambaram,cidambarama,citamparam,ji deng bo lei mu,Ćidambaram,Чидамбарам,चिदाम्बरम,চিদাম্বরম,சிதம்பரம்,చిదంబరం,ചിദംബരം,吉登伯勒姆', 11.3990700, 79.6911300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78415, 'Chicholi', 'Chicholi', 'Chicholi,Chīcholi', 21.4692600, 79.7015100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78416, 'Chichli', 'Chichli', 'Chichli', 22.8336300, 78.8261100, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78417, 'Chicalim', 'Chicalim', 'Chicalim,Chiquilim', 15.3983500, 73.8421600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78418, 'Chhuīkhadān', 'Chhuikhadan', 'Chhuikhadan,Chhuīkhadān', 21.5231600, 80.9978800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78419, 'Chhoti Sādri', 'Chhoti Sadri', 'Chhoti Sadri,Chhoti Sādri', 24.3814500, 74.7012000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78420, 'Chhota Udepur', 'Chhota Udepur', 'Chhota Udepur,Chota Udaipur', 22.3040100, 74.0158000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78421, 'Chhindwāra', 'Chhindwara', 'Chhindwara,Chhindwāra,Chindwara,Sindwara', 22.0569700, 78.9395800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78422, 'Chhibrāmau', 'Chhibramau', 'Chhibramau,Chhibrāmau', 27.1487200, 79.5007800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78423, 'Chhatarpur', 'Chhatarpur', 'Chantarpur,Chhatarpur,Chkatarpur', 24.9177000, 79.5887100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78424, 'Chhātāpur', 'Chhatapur', 'Chhatapur,Chhātāpur', 26.2196500, 87.0047900, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78425, 'Chhāta', 'Chhata', 'Chhata,Chhāta', 27.7237400, 77.5081000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78426, 'Chharra', 'Chharra', '', 27.9247000, 78.4010200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78427, 'Chhaprauli', 'Chhaprauli', 'Chhaprauli', 29.2098900, 77.1745400, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78428, 'Chāpra', 'Chapra', 'Chapra,Chhapra,Chkhapra,Chupra,Chāpra,capara,capra,chapara,chapra,qia pu la,Чапра,Чхапра,چاپرا,चप्रा,छपरा,छप्रा,চাপরা,恰普拉', 25.7803100, 84.7470900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78429, 'Chhāpar', 'Chhapar', 'Chhapar,Chhāpar', 27.8190000, 74.4393600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78430, 'Chhala', 'Chhala', '', 23.3077900, 72.7740400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78431, 'Chhachhrauli', 'Chhachhrauli', 'Chhachhrauli', 30.2449200, 77.3602700, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78432, 'Chhabra', 'Chhabra', 'Chhabra', 24.6647200, 76.8437900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78433, 'Cheyyur', 'Cheyyur', 'Chaeur,Cheyur,Cheyyur,Cheyyūr,Cheyūr', 12.3494800, 80.0030400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78434, 'Chettipālaiyam', 'Chettipalaiyam', 'Chettipalaiyam,Chettipalayam,Chettipālaiyam', 10.9124800, 77.0369900, 'IN', '2017-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78435, 'Chetput', 'Chetput', 'Chetpat,Chetpet,Chetput,Madras Chetput', 13.0700000, 80.2408300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78436, 'Cherrapunji', 'Cherrapunji', 'Cerapunci,Cerapundzi,Cerapundzis,Cherapundzhi,Cherapundzi,Cherapunjee,Cherapunji,Cherrapundzhi,Cherrapunjee,Cherrapunji,Cherripunji,Czerapundzi,Czerapuńdżi,cerapumji,cerapunji,che la pan zhi,chelapunji,cherapunji,cirapunci,cirapunji,cora,qi la peng qi,tshyrabwnjy,Çerapunci,Čerapundžis,Čérápuňdží,Черапунджи,Черапунџи,Черрапунджі,Չերապունջի,تشيرابونجي,चेरापुंजी,चेरापूँजी,चेरापूंजी,चेरापूञ्जी,চেরাপুঞ্জি,ચેરાપુંજી,சோரா,చిరపుంజీ,ಚಿರಾಪುಂಜಿ,ചിറാപുഞ്ചി,ჩერაპუნჯი,チェラプンジ,乞拉朋齐,車剌潘治,체라푼지', 25.3008900, 91.6961900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78437, 'Chennimalai', 'Chennimalai', 'Chennimalai', 11.1637800, 77.6038800, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78438, 'Chengannūr', 'Chengannur', 'Chengannur,Chengannūr', 9.3157500, 76.6151300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78439, 'Chengam', 'Chengam', 'Chengam', 12.3088900, 78.7913700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78440, 'Chingleput', 'Chingleput', 'Chengalpat,Chengalpattu,Chingleput,cengalapattu,cenkalpattu,qin ge a er pa tu,चेंगलपट्टु,चेंगलपट्टू,চেঙ্গালপাত্তু,செங்கல்பட்டு,琴格阿尔帕图', 12.6918400, 79.9766100, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78441, 'Chēlakara', 'Chelakara', '', 10.6928900, 76.3438700, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78442, 'Chechat', 'Chechat', 'Chechat', 24.7666700, 75.8833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78443, 'Chetwayi', 'Chetwayi', 'Chaughat,Chavakkad,Chetwagi,Chetwayi,Chitwye,Chowghat,Chāvakkād', 10.5288500, 76.0479300, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78444, 'Chaupāl', 'Chaupal', 'Chaupal,Chaupāl', 30.9464700, 77.5884000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78445, 'Chaksu', 'Chaksu', 'Chaksu,Chatsu,Chāksu,Chātsu', 26.6051000, 75.9481400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78446, 'Chatrapur', 'Chatrapur', 'Chatrapur,Chhatrapur', 19.3557400, 84.9835900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78447, 'Chatra', 'Chatra', 'Chatra', 24.2037600, 84.8703200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78448, 'Chātakonda', 'Chatakonda', 'Chatakonda,Chātakonda', 17.5530300, 80.6477000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78449, 'Chās', 'Chas', 'Chas,Chās,Час', 23.6355600, 86.1671200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78450, 'Charthāwal', 'Charthawal', 'Charthawal,Charthāwal,Charthāwāl', 29.5468700, 77.5943800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78451, 'Charkhi Dādri', 'Charkhi Dadri', 'Charkhi Dadri,Charkhi Dādri,Charki Dadrai,Charki Dadri,Dadri,Dādri', 28.5916600, 76.2716100, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78452, 'Charkhāri', 'Charkhari', 'Charkhari,Charkhāri,Maharajnagar,Māhārājnagar', 25.4030400, 79.7487700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78453, 'Chāpar', 'Chapar', 'Chapar,Chāpar,Ghapar,Ghāpar', 26.2726600, 90.4455600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78454, 'Channarāyapatna', 'Channarayapatna', 'Channarayapatna,Channarāyapatna,Chanzarayapatna', 12.9064200, 76.3877500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78455, 'Channapatna', 'Channapatna', 'Channapatan,Channapatna', 12.6514300, 77.2067200, 'IN', '2016-09-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78456, 'Channagiri', 'Channagiri', 'Channagiri', 14.0239900, 75.9257700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78457, 'Changanācheri', 'Changanacheri', 'Changanacheri,Changanacherry,Changanācheri', 9.4420300, 76.5360400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78458, 'Chāndor', 'Chandor', 'Chandor,Chandvad,Chandwar,Chāndor,Chāndvad,Chāndwar', 20.3306000, 74.2446700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78459, 'Chāndūr Bāzār', 'Chandur Bazar', '', 21.2385300, 77.7471300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78460, 'Chāndūr', 'Chandur', 'Chandur,Chāndur,Chāndūr', 20.8140800, 77.9801500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78461, 'Chāndur', 'Chandur', 'Chandur,Chāndur', 19.7344400, 79.1716700, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78462, 'Chānda', 'Chanda', 'Candrapur,Chanda,Chandrapur,Chānda,candrapur,candrapura,candrapura jille,candrapuram,chandrapwr,chndrapwr,chndrpwr,qian de la pu er,Ćandrapur,Чандрапур,چاندراپور,چندراپور,چندرپور,चंद्रपूर,चन्द्रपुर,चन्द्रपुरम्,চন্দ্রপুর,ચંદ્રપૂર,చంద్రపూర్,ಚಂದ್ರಪುರ ಜಿಲ್ಲೆ,钱德拉普尔', 19.9507600, 79.2952300, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78463, 'Chandrakona', 'Chandrakona', 'Chandrakona,Chandshona', 22.7333300, 87.5166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78464, 'Chāndpur', 'Chandpur', 'Bijnor,Chandpur,Chāndpur', 29.1348900, 78.2718700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78465, 'Chandla', 'Chandla', 'Chandla', 25.0714800, 80.1929400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78466, 'Chāndil', 'Chandil', 'Chandil,Chāndil', 22.9574500, 86.0533100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78467, 'Chandigarh', 'Chandigarh', 'Candigarchas,Candigarh,Chandigar,Chandigarh,Chandigarkh,Chandīgarh,Czandigarh,IXC,cadigarha,candhigad,candigadh,candigadha,candigara,candigarha,cantikar,chandigadh,chandigarhi,chandigaru,chang di jia er,Čandigarchas,Čandígarh,Чандигар,Чандигарх,צ''אנדיגאר,चंडीगढ़,চন্ডিগড়,চন্ডীগড়,ਚੰਡੀਗੜ੍ਹ,ચંડીગઢ,சண்டிகர்,చండీగఢ్,ఛండీగఢ్,ചണ്ഢീഗഡ്,ჩანდიგარჰი,チャンディーガル,昌迪加尔', 30.7362900, 76.7884000, 'IN', '2016-02-20', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78468, 'Chandia', 'Chandia', 'Chandia', 23.6564700, 80.7091100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78469, 'Chanderi', 'Chanderi', 'Chanderi,caderi,canderi,chanderi,qian de li,Чандери,चंदेरी,चन्देरी,চান্দেরী,ਚੰਦੇਰੀ,チャンデーリー,钱德里', 24.7131200, 78.1380900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78470, 'Chāndbāli', 'Chandbali', '', 20.7751900, 86.7413900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78471, 'Chanduasi', 'Chanduasi', 'Chandausi,Chanduasi', 28.4517800, 78.7827700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78472, 'Chandauli', 'Chandauli', 'Chandauli', 25.2580300, 83.2682500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78473, 'Chandannagar', 'Chandannagar', 'Candanagaro,Chandan Nagar,Chandannagar,Chandernagor,Chandernagore,candananagara,cantannakar,chandanagaleu,chandanagari,chndngr,jin de ne ge er,shanderunagoru,Ĉandanagaro,Чанданнагар,Чанданнаґар,چندنگر,चन्दननगर,চন্দননগর,சந்தன்நகர்,ჩანდანაგარი,シャンデルナゴル,金德訥格爾,찬다나가르', 22.8622500, 88.3679600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78474, 'Chānasma', 'Chanasma', 'Chanasma,Chānasma', 23.7147200, 72.1127900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78475, 'Chamrajnagar', 'Chamrajnagar', '', 11.9231200, 76.9394900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78476, 'Chāmpua', 'Champua', 'Champua,Chāmpua', 22.0673400, 85.6646300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78477, 'Champawat', 'Champawat', 'Champawat', 29.3350100, 80.0778300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78478, 'Chāmpāhāti', 'Champahati', 'Champahati,Chāmpāhāti', 22.4002600, 88.4920900, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78479, 'Chāmpa', 'Champa', '', 22.0353200, 82.6423400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78480, 'Chamba', 'Chamba', 'Chamba,Chambâ,caba,camba,campa,qia mu ba,چمبہ,चंबा,चम्बा,ਚੰਬਾ,ચંબા,ചമ്പ,恰姆巴', 32.5553100, 76.1264700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78481, 'Challapalle', 'Challapalle', 'Challapalle,Challapalli', 16.1175600, 80.9313900, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78482, 'Challakere', 'Challakere', 'Challakere', 14.3180000, 76.6516500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78483, 'Chālisgaon', 'Chalisgaon', 'Chalisgaon,Chālisgaon', 20.4578100, 75.0159600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78484, 'Chalāla', 'Chalala', 'Chalala,Chalāla', 21.4107300, 71.1662100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78485, 'Chākuliā', 'Chakulia', 'Chakuha,Chakulia,Chākuha,Chākuliā', 22.4830100, 86.7179300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78486, 'Chakrāta', 'Chakrata', 'Chakrata,Chakrāta', 30.7036900, 77.8638600, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78487, 'Chakradharpur', 'Chakradharpur', 'Chakardharpore,Chakradharpur,cakradharapura,cakratarpur,qia ke la da er pu er,चक्रधरपुर,चक्रधरपूर,চক্রধরপুর,சக்ரதர்பூர்,恰克拉达尔普尔', 22.6762600, 85.6290600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78488, 'Chaklāsi', 'Chaklasi', 'Chaklasi,Chaklāsi', 22.6532000, 72.9449700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78489, 'Chākia', 'Chakia', 'Chakia,Chākia', 26.4159800, 85.0466500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78490, 'Chakia', 'Chakia', 'Chakia', 25.0489100, 83.2215500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78491, 'Chākan', 'Chakan', 'Chakan,Chākan', 18.7605900, 73.8635100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78492, 'Chail', 'Chail', 'Chail', 25.4265400, 81.6319800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78493, 'Chāībāsa', 'Chaibasa', 'Chaibasa,Chāībāsa', 22.5482500, 85.8045800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78494, 'Chābua', 'Chabua', 'Chabua,Chābua', 27.4825300, 95.1745100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78495, 'Cavelossim', 'Cavelossim', 'Caveloesim,Kavelossim,Кавелоссим', 15.1725500, 73.9419400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78496, 'Carapur', 'Carapur', 'Carapur', 15.5658800, 73.9871300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78497, 'Canning', 'Canning', 'Canning,Canning Town,Port Canning', 22.3145300, 88.6624800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78498, 'Cannanore', 'Cannanore', 'Cananor,Kananorskom,Kannanur,Kannur,Kanoor,Кананорском', 11.8675200, 75.3576300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78499, 'Candolim', 'Candolim', '', 15.5180700, 73.7625900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78500, 'Kolkata', 'Kolkata', 'CCU,Calcuta,Calcutta,Calcutá,Calcúta,Caligardamana,Kaelkuettae,Kal''kuta,Kal''kutta,Kal''kuttae,Kalikata,Kalikātā,Kalkata,Kalkota,Kalkouta,Kalkueta,Kalkuta,Kalkutta,Kalkútta,Kalküta,Kolkat,Kolkata,Kolkate,Kolkato,Kälküttä,Kəlkətə,Sealdah,jia er ge da,jia li ji da,kalakata,kalakatta,kalikata,kalkata,keaൽkkatta,klkta,klkth,klkwth,ko l ka ta,kolakata,kolkata,kolkatta,kol‌kata,korukata,kwlkata,kʼolkʼatʼa,qwlqth,Καλκούτα,Калькута,Калькуттæ,Калькутта,Колката,Колкате,Կալկաթա,כלכותה,קאלקאטא,קולקטה,كلكتا,كولكاتا,کلکته,کلکتہ,کولکاتہ,کَلٕکَتا,کەلکەتە,कलकत्ता,कोलकाता,কলকাতা,ਕੋਲਕਾਤਾ,કોલકાતા,କଲିକତା,கொல்கத்தா,కోల్‌కాతా,ಕೊಲ್ಕತ್ತ,കൊൽക്കത്ത,โกลกาตา,ཀ་ལི་ཀུ་ཏ,ကာလကတ္တားမြို့,კოლკატა,ኮልካታ,コルカタ,加尔各答,架利吉打,콜카타', 22.5626300, 88.3630400, 'IN', '2016-03-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78501, 'Byādgi', 'Byadgi', 'Byadgi,Byādgi', 14.6732500, 75.4868000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78502, 'Buxar', 'Buxar', 'Buxar', 25.5754800, 83.9804300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78503, 'Burla', 'Burla', 'Burla', 21.5097600, 83.8725900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78504, 'Būriya', 'Buriya', '', 30.1591100, 77.3581400, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78505, 'Burhar', 'Burhar', 'Burhar', 23.2149400, 81.5320400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78506, 'Burhānpur', 'Burhanpur', 'Burhanpur,Burhānpur', 21.3086800, 76.2302600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78507, 'Būndu', 'Bundu', 'Bundu,Būndu', 23.1613900, 85.5892500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78508, 'Būndi', 'Bundi', 'Bundi,Bundi City,Būndi,Бунди', 25.4385500, 75.6373500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78509, 'Buldāna', 'Buldana', '', 20.5293300, 76.1845700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78510, 'Bulandshahr', 'Bulandshahr', 'Buelendsehr,Bulandshahr,Bulandshakhr,Bulandshakhre,Bulandshar,Bülendşehr,blndshhr,bu lan de si ha he er,bulandasahara,pulantacakar,Буландшар,Буландшахр,Буландшахре,بلند شہر,بلندشهر,बुलन्दशहर,बुलन्दसहर,বুলান্দশহর,புலந்தசகர்,布兰德斯哈赫尔', 28.4039200, 77.8577300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78511, 'Buguda', 'Buguda', 'Buguda', 19.8080600, 84.7908400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78512, 'Budhlāda', 'Budhlada', 'Budhlada,Budhlāda', 29.9279900, 75.5620500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78513, 'Budhāna', 'Budhana', 'Budhana,Budhāna,budhana,बुधना', 29.2880500, 77.4753400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78514, 'Budaun', 'Budaun', 'Badajun,Badaun,Budaun,badanyu,badauna,badayum,bu dao en,budauna,patavun,Бадаюн,بدایوں,बदांयू,बदायूँ,बुडौन,বুদৌন,બદૌન,பதாவுன்,布道恩', 28.0381100, 79.1266800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78515, 'Brājarājnagar', 'Brajarajnagar', 'Brajarajnagar,Brajrajnagar,Brājarājnagar', 21.8166700, 83.9166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78516, 'Brahmapur', 'Brahmapur', 'Berhampore,Berhampur,Berkhampur,Brahmapur,Brahmapuramu,Brahmapuras,Bramapur,Ganjam,barampuram,brahmapura,brahmapuram,brhmapwr,bu la he ma pu er,Берхампур,Брамапур,برهماپور,برہماپور، اڑیسہ,برہمپور,ब्रह्मपुर,ব্রহ্মপুর,ব্রহ্মাপুর,ବ୍ରହ୍ମପୁର,బరంపురం,బ్రహ్మపురం,布拉赫马普尔', 19.3115100, 84.7929000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78517, 'Botād', 'Botad', 'Botad,Botād', 22.1691700, 71.6667100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78518, 'Borsad', 'Borsad', 'Borsad', 22.4078800, 72.8981700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78519, 'Borivli', 'Borivli', 'Borivali,Borivli', 19.2349600, 72.8597600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78520, 'Bongaigaon', 'Bongaigaon', 'Bongaigaon', 26.4770300, 90.5581500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78521, 'Bomdila', 'Bomdila', 'Bomdila,Bomdilla', 27.2647500, 92.4247200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78522, 'Mumbai', 'Mumbai', 'Asumumbay,BOM,Bombai,Bombaim,Bombaj,Bombay,Bombaya,Bombej,Bombejus,Bombėjus,Bumbaj,Bůmbaj,Dakbayan sa Bombay,Gorad Mumbai,Lungsod ng Mumbai,Moembaai,Mumbai,Mumbai - मुम़बई,Mumbaj,Mumbaja,Mumbajo,Mumbajus,Mumbay,Mumbaî,Numbai,Vomvai,bamba''i,bmbyy,gretara mumba''i,meng mai,mmbay,mmbyy,mu0bai,muba''i,mum bi,mumba''i,mumbai,mumpai,munbai,mwmbay,mwmbyy,mymbais,pullapa mumba''i,Βομβάη,Бомбай,Бомбей,Горад Мумбаі,Мумбаи,Мумбай,Мумбаі,Мумбаї,Мумбај,Մումբայ,מומבאי,מומביי,بمبئی,بَمبَے,ممبئي,ممبئی,ممبای,مومباى,مومباي,مومبای,މުންބާއީ,ग्रेटर मुम्बई,बम्बई,मुंबई,मुम्बई,পুল্লাপ মুম্বাই,মুম্বই,মুম্বাই,ਮੁੰਬਈ,મુંબઈ,ମୁମ୍ବାଇ,மும்பை,ముంబై,ಮುಂಬೈ,ಮು೦ಬೈ,മുംബൈ,มุมไบ,འབོམ་སྦེ,မွမ်ဘိုင်းမြို့,მუმბაი,ムンバイ,孟买,뭄바이', 19.0728300, 72.8826100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78523, 'Bolpur', 'Bolpur', 'Bolpur,bo er pu er,bolapura,bolapura pascima bangala,बोलपुर,बोलपुर पश्चिम बंगाल,বোলপুর,博尔普尔', 23.6627800, 87.6969500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78524, 'Bolānīkhodān', 'Bolanikhodan', 'Bolani,Bolanikhodan,Bolāni,Bolānīkhodān', 22.1131200, 85.3364500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78525, 'Bokāro', 'Bokaro', 'Bokaro,Bokaro Steel City,Bokāro,Бокаро', 23.7873200, 85.9562200, 'IN', '2016-05-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78526, 'Bokākhāt', 'Bokakhat', 'Bokakhat,Bokākhāt', 26.6401800, 93.6005200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78527, 'Bokajān', 'Bokajan', 'Bokajan,Bokajan O. Noajan,Bokajān', 26.0213100, 93.7794500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78528, 'Boisar', 'Boisar', 'Boisar', 19.8036200, 72.7559800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78529, 'Bodri', 'Bodri', 'Bodri', 23.1652400, 81.4326200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78530, 'Bodināyakkanūr', 'Bodinayakkanur', 'Bodinayakanur,Bodinayakkanur,Bodināyakkanūr', 10.0117100, 77.3497600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78531, 'Buddh Gaya', 'Buddh Gaya', 'Bodh Gaja,Bodh Gaya,Bodh-Gaja,Bodhgaja,Bodhgaya,Buddh Gaya,Buddha Gaya,Bódhgaja,bod''dha gaya,bodh gaya,bodha gaya,bodhagaya,bodkh-gaja,bud''dha gaya,budagaya,buddagaya,bwdh gaya,phuthth kh ya,pu ti jia ye,puttakaya,Бодх-Гая,بوده گایا,बोद्ध गया,बोधगया,বুদ্ধ গয়া,বোধ গয়া,புத்தகயா,ಬೋಧ್ ಗಯಾ,බුද්ධගයා,พุทธคยา,ဗုဒ္ဓဂါယာ,ブッダガヤ,菩提伽耶,부다가야', 24.6980800, 84.9869000, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78532, 'Bodhan', 'Bodhan', 'Bodhan,bodhan,బోధన్', 18.6620800, 77.8858100, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78533, 'Bobbili', 'Bobbili', 'Bobbili,babbili,bo bu bi li,bobbili,bobbiri,bwbly,poppili,بوبلی,बोब्बिलि,বব্বিলি,ବୋବ୍ବିଲି,பொப்பிலி,బొబ్బిలి,ボッビリ,博布比利', 18.5736600, 83.3592500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78534, 'Bithūr', 'Bithur', '', 26.6066400, 80.2709800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78535, 'Biswān', 'Biswan', 'Biswan,Biswān', 27.4958100, 80.9961800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78536, 'Bissāu', 'Bissau', 'Bisau,Bissau,Bissāu,Бисау', 28.2473700, 75.0766600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78537, 'Bishnupur', 'Bishnupur', 'Bishnupur,Vishnupur,Бишнупур', 23.0738000, 87.3199100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78538, 'Bishnupur', 'Bishnupur', 'Bishnupur,Бишнупур', 22.3777700, 88.2741100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78539, 'Bishnāh', 'Bishnah', 'Bishna,Bishnah,Bishnāh', 32.6106000, 74.8555700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78540, 'Bisenda Buzurg', 'Bisenda Buzurg', 'Bisanda,Bisenda,Bisenda Buzurg', 25.4035000, 80.6188900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78541, 'Bisauli', 'Bisauli', 'Bisauli', 28.3077200, 78.9367800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78542, 'Bīsalpur', 'Bisalpur', 'Bisalpur,Bīsalpur', 28.2925300, 79.8047200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78543, 'Birūr', 'Birur', 'Birur,Birūr', 13.5972300, 75.9716700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78544, 'Bīrpur', 'Birpur', 'Birpur,Bīrpur', 26.5082300, 87.0119400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78545, 'Birmitrapur', 'Birmitrapur', '', 22.4000000, 84.7666700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78546, 'Birbhaddar', 'Birbhaddar', 'Birbhaddar,Virbhadra', 30.0712000, 78.2818900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78547, 'Beed', 'Beed', 'Beed,Bhir,Bid,Bidh,Bir,Bīr,Mahboobganj,Mahbubganj,bida,bira,Бид,بیڑ,बीड,બીડ,ବୀଡ଼', 18.9892100, 75.7563400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78548, 'Binka', 'Binka', 'Binika,Binka', 21.0262600, 83.8119700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78549, 'Bindki', 'Bindki', 'Bindki', 26.0361300, 80.5761700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78550, 'Etāwa', 'Etawa', 'Bina-Etawa,Bīna-Etāwa,Etawa,Etawah,Etāwa', 24.1835100, 78.2028900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78551, 'Bilthra', 'Bilthra', 'Belthara,Bilthar,Bilthra', 26.1270500, 83.8914800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78552, 'Bilsi', 'Bilsi', 'Bilsi', 28.1294100, 78.9109000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78553, 'Bilsanda', 'Bilsanda', 'Bilsanda', 28.2434100, 79.9513500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78554, 'Biloli', 'Biloli', 'Biloli', 18.7738500, 77.7246300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78555, 'Bilkha', 'Bilkha', 'Bhilka,Bilkha', 21.4415000, 70.6006300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78556, 'Bilimora', 'Bilimora', 'Bilimor,Bilimora,Mora', 20.7695700, 72.9613400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78557, 'Bilhaur', 'Bilhaur', 'Bilhaur', 26.8434500, 80.0638800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78558, 'Bilgrām', 'Bilgram', 'Bilgram,Bilgrām', 27.1750900, 80.0320100, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78559, 'Bilgi', 'Bilgi', 'Bilg,Bilgi', 16.3471400, 75.6180400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78560, 'Bilaspur', 'Bilaspur', 'Bilaspur,Bilāspur', 31.3302700, 76.7566300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78561, 'Bilāspur', 'Bilaspur', 'Bilaspur,Bilāspur', 30.3045000, 77.3042400, 'IN', '2015-03-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78562, 'Bīlāspur', 'Bilaspur', 'Bilaspur,Bilāspur,Bīlāspur', 28.8865500, 79.2703000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78563, 'Bīlāspur', 'Bilaspur', 'Bilaspur,Bilāspur,Bīlāspur', 28.3912800, 77.6242100, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78564, 'Bilāspur', 'Bilaspur', 'Bilaspur,Bilaspura,Bilāspur,PAB,Биласпура', 22.0800500, 82.1554300, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78565, 'Bilāsipāra', 'Bilasipara', 'Bilasipara,Bilāsipāra', 26.2328500, 90.2341000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78566, 'Bilariāganj', 'Bilariaganj', 'Bilariaganj,Bilariāganj,Bilrayaganj,Bilrayāganj', 26.1959300, 83.2269000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78567, 'Bilāri', 'Bilari', 'Bilari,Bilāri', 28.6214600, 78.8036100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78568, 'Bilāra', 'Bilara', 'Bilara,Bilāra', 26.1806700, 73.7055000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78569, 'Bikramganj', 'Bikramganj', 'Bikramganj', 25.2107300, 84.2550800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78570, 'Bīkāpur', 'Bikapur', 'Bikapur,Bīkāpur', 26.5953400, 82.1327200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78571, 'Bīkaner', 'Bikaner', 'BKB,Bikaner,Bîkâner,Bīkaner,Bīkāner,bikanera,Биканер,बीकानेर', 28.0176200, 73.3149500, 'IN', '2017-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78572, 'Bijrauni', 'Bijrauni', 'Bijrauni,Bijroni', 24.9329600, 77.6435200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78573, 'Bijnor', 'Bijnor', 'Bidzhnor,Bijnor,bi jie nuo er,bijanaura,bijanora,bijnora,bjnwr,pijnor,Биджнор,بجنور,बिजनोर,बिजनौर,बिज्नोर,বিজনোর,બિજનૌર,பிஜ்னோர்,比杰诺尔', 29.3730000, 78.1363600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78574, 'Bijni', 'Bijni', 'Bijni', 26.4958800, 90.7029800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78575, 'Bijbehara', 'Bijbehara', 'Bijbehara,Bijbiara,Bijbiāra,Vejibyor,Vejibyour,Vejibyōr,Vijeshwara', 33.7937800, 75.1070000, 'IN', '2016-06-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78576, 'Bijāwar', 'Bijawar', 'Bijawar,Bijāwar', 24.6235100, 79.4899400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78577, 'Bijapur', 'Bijapur', 'Bidzapur,Bidzapuras,Bidzhapur,Bidzsapur,Bidźapur,Bidžapuras,Bijapur,Bijāpur,Bídzsápur,Bîjâpur,Districte de Bijapur,Vijapura,Vijayapur,Vijayapura,Visiapur,bi gu bu er,bi jia bu er,bijapuleu,bijapura,bijapuram,bijapuru,byjapwr,pijappur,vijapura,Биджапур,Биџапур,بیجاپور,बिजापुरम्,बीजापुर,विजापूर,ਬੀਜਾਪੁਰ,பிஜாப்பூர்,ಬಿಜಾಪುರ,ബിജാപ്പൂർ,ビジャープル,比贾布尔,비자푸르', 16.8244200, 75.7153700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78578, 'Bihpuriāgaon', 'Bihpuriagaon', '', 27.0171800, 93.9167300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78579, 'Bihār Sharīf', 'Bihar Sharif', 'Behar,Bihar,Bihar Sharif,Bihār,Bihār Sharīf', 25.2008400, 85.5238900, 'IN', '2016-05-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78580, 'Bihārīganj', 'Bihariganj', 'Bihariganj,Bihārīganj', 25.7341500, 86.9883700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78581, 'Bīghāpur Khurd', 'Bighapur Khurd', 'Bighapur,Bighapur Khurd,Bighāpur,Bīghāpur Khurd', 26.3473400, 80.6569800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78582, 'Bidhūna', 'Bidhuna', 'Bidhuna,Bidhūna', 26.8017200, 79.5082900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78583, 'Bīdar', 'Bidar', 'Bidar,Bīdar,Бидар', 17.9133100, 77.5301100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78584, 'Biaora', 'Biaora', 'Biaora', 23.8666700, 76.9166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78585, 'Bhuvanagiri', 'Bhuvanagiri', 'Bhavanagiri,Bhuvanagiri,Bliuvanagiri', 11.4415400, 79.6456800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78586, 'Bhusāval', 'Bhusaval', 'Bhusaval,Bhusawal,Bhusāval,Bhusāwal', 21.0436500, 75.7850600, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78587, 'Bhuma', 'Bhuma', 'Bhuma', 27.7833300, 74.9333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78588, 'Bhūm', 'Bhum', 'Bhoom,Bhum,Bhūm', 18.4590800, 75.6587700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78589, 'Bhuj', 'Bhuj', 'BHJ,Bhooj,Bhuj,Bkhudzh,bhoja,bhuja,bwj,puj,Бхудж,بوج,بھوج,ڀڄ,भुज,भूज,ভোজ,ભુજ,ଭୁଜ,புஜ்', 23.2539700, 69.6692800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78590, 'Bhudgaon', 'Bhudgaon', 'Bhudgaon,Budhgaon', 16.9074200, 74.5995400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78591, 'Bhubaneshwar', 'Bhubaneshwar', 'BBI,BBSR,Bhubaneshwar,Bhubaneswar,Bhubaneśwar,Bkhubaneshvar,Temple City of India,bhubanesbara,bhuvanesvara,bubaneshuwaru,puvanecuvaram,Бхубанешвар,בובנשוואר,भुवनेश्वर,ভুবনেশ্বর,புவனேசுவரம்,ブバネーシュワル', 20.2724100, 85.8338500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78592, 'Bhuban', 'Bhuban', 'Bhuban', 20.8819700, 85.8333400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78593, 'Bhowali', 'Bhowali', 'Bhowali,Bhowāli', 29.3898500, 79.5048100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78594, 'Bhor', 'Bhor', 'Bhor', 18.1486100, 73.8433600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78595, 'Bhopal', 'Bhopal', 'BHO,Bhojpal,Bhopal,Bhopala,Bhopalas,Bhopalo,Bhopál,Bhopāl,Bhopāla,Bhópál,Bkhopal,Bopal,Bópal,Gorad Bkhapal,bhopal,bhopala,bo pa er,bopal,boparu,bwbal,bwpal,popal,Μποπάλ,Бопал,Бхопал,Горад Бхапал,בופאל,بوبال,بوپال,بھوپال,بہوپال,भोपाल,भोपाळ,ভোপাল,ਭੋਪਾਲ,ભોપાલ,ଭୋପାଳ,போபால்,భోపాల్,ಭೊಪಾಲ್,ഭോപ്പാൽ,ბჰოპალი,ボパール,ボーパール,博帕尔,보팔', 23.2546900, 77.4028900, 'IN', '2015-06-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78596, 'Bhongīr', 'Bhongir', 'Bhongir,Bhongīr', 17.5154400, 78.8856300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78597, 'Bhongaon', 'Bhongaon', 'Bhongaon', 27.2551500, 79.1811800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78598, 'Bhulath Gharbi', 'Bhulath Gharbi', 'Bholath,Bhulath Gharbi', 31.5427900, 75.5075500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78599, 'Bhojudih', 'Bhojudih', 'Bhojudih', 23.6396200, 86.4410500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78600, 'Bhogpur', 'Bhogpur', 'Bhogpur,Bhogpur Sirwal', 31.5544200, 75.6427100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78601, 'Bhiwāni', 'Bhiwani', 'Bhiwani,Bhiwāni', 28.7930400, 76.1396800, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78602, 'Bhiwandi', 'Bhiwandi', 'Bhivandi,Bhivándi,Bhiwandi,Bhiwndi,Bivandi,Bkhivandi,bhi''oyadi,bhivandi,bhiwandi,biwandi,bywandy,pi wen di,Биванди,Бхиванди,بيوانډي,بھیواندی,بھیونڈی,بیواندی,भिवंडी,भिवन्दी,ভিওয়াদি,ભિવંડી,ଭିୱାନ୍ଦି,ビワンディー,皮文迪,비완디', 19.3002300, 73.0588100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78603, 'Bhitarwār', 'Bhitarwar', 'Bhitarwar,Bhitarwār', 25.7921600, 78.1108500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78604, 'Bhīnmāl', 'Bhinmal', 'Bhinmal,Bhīnmāl', 24.9994400, 72.2714100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78605, 'Bhinga', 'Bhinga', 'Bhinga', 27.7028300, 81.9343000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78606, 'Bhindār', 'Bhindar', 'Bhindar,Bhindār,Bhīndar', 24.5023500, 74.1855100, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78607, 'Bhind', 'Bhind', 'Bhind', 26.5667100, 78.7872800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78608, 'Bhīmunipatnam', 'Bhimunipatnam', 'Bheemunipatnam,Bhimunipatnam,Bhīmunipatnam,Bimlipatam', 17.8901700, 83.4520300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78609, 'Bhīm Tāl', 'Bhim Tal', '', 29.3444700, 79.5633600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78610, 'Bhīmavaram', 'Bhimavaram', 'Bhimavaram,Bhīmavaram', 16.5407800, 81.5232200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78611, 'Bhīlwāra', 'Bhilwara', 'Bhilwara,Bhīlwāra', 25.3470700, 74.6408100, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78612, 'Bhilai', 'Bhilai', 'Bhilai,Bhilai Nagar,Bhilaj Nagar,Bhilajus,Bhilāī,Bilaj,Bkhilai,balay,bhila''i,bhila''i nagara,bhilai nagara,bi lai,billai,birai,pilay,Билај,Бхилаи,بالای,بھلائی,بھیلائ,भिलाई,भिलै नगर,ভিলাই নগর,ଭିଲାଇ,பிலாய்,ビラーイー,比萊,빌라이', 21.2091900, 81.4285000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78613, 'Bhīkhi', 'Bhikhi', 'Bhikhi,Bhīkhi', 30.0591800, 75.5350000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78614, 'Bhikangaon', 'Bhikangaon', 'Bhikangaon', 21.8676400, 75.9639100, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78615, 'Bhigvan', 'Bhigvan', '', 18.3007000, 74.7670100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78616, 'Bhāyāvadar', 'Bhayavadar', 'Bhaya nadar,Bhayaradar,Bhayavadar,Bhayawadar,Bhāyāradar,Bhāyāvadar', 21.8552300, 70.2479100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78617, 'Bhayandar', 'Bhayandar', 'Bhayandar,Bhayndar,Bhayundar', 19.3015700, 72.8510700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78618, 'Bhawānipatna', 'Bhawanipatna', 'Bhawanipatna,Bhawānipatna', 19.9071700, 83.1669700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78619, 'Bhawānīgarh', 'Bhawanigarh', 'Bhawanigarh,Bhawānīgarh', 30.2668500, 76.0385400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78620, 'Bhawāniganj', 'Bhawaniganj', '', 24.4158200, 75.8355200, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78621, 'Bhavnagar', 'Bhavnagar', 'BHU,Baunagar,Bharnagar,Bhaunagar,Bhavnagar,Bhunagar,Bhāvnagar,Bkhavnagarom,ba fu na jia er,babeunagaleu,bavunagaru,bawngr,bhavanagara,bhav‌nagar,bھawngr,pavanakar,Бхавнагаром,باونگر,بھاونگر,भावनगर,ભાવનગર,பவநகர்,భావ్‌నగర్,バーヴナガル,巴夫那加尔,바브나가르', 21.7628700, 72.1533100, 'IN', '2016-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78622, 'Bhavāni', 'Bhavani', 'Bhavani,Bhavāni', 11.4455300, 77.6821500, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78623, 'Bhattiprolu', 'Bhattiprolu', 'Bhattiprolu', 16.1026000, 80.7807400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78624, 'Bhātpāra', 'Bhatpara', 'Bhatpara,Bhātpāra', 22.8664300, 88.4011300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78625, 'Bhatkal', 'Bhatkal', 'Bhatkal', 13.9853400, 74.5553100, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78626, 'Bathinda', 'Bathinda', 'BUP,Bathinda,Bkhatinda,ba ting da,bathida,bathinda,batynda,bhatinda,pattinta,Бхатинда,باتیندا,बठिंडा,बठिण्डा,বাথিন্দা,ভাটিণ্ডা,ਬਠਿੰਡਾ,ଭଟିଣ୍ଡା,பட்டிண்டா,ബഠിംഡാ,巴廷達', 30.2074700, 74.9389300, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78627, 'Bhatgaon', 'Bhatgaon', 'Bhatgaon', 21.1500000, 81.7000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78628, 'Bhātāpāra', 'Bhatapara', 'Bhatapara,Bhātāpāra', 21.7350000, 81.9471100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78629, 'Bhasāwar', 'Bhasawar', 'Bhusawar', 27.0389500, 77.0484900, 'IN', '2016-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78630, 'Bharwāri', 'Bharwari', 'Bharwari,Bharwāri', 25.5607800, 81.4916400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78631, 'Bharūch', 'Bharuch', 'Baroach,Bharoch,Bharuch,Bharūch,Broach', 21.6948200, 72.9805000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78632, 'Bharthana', 'Bharthana', 'Bharthana', 26.7523100, 79.2218000, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78633, 'Bharatpur', 'Bharatpur', 'Batarpur,Bharatpur,Bkharatpur,baratopuru,bharatapura,bharatapuram,po lei de bu er,Батарпур,Бхаратпур,بھارتپور,भरतपुर,भरतपुरम्,भरतपूर,ভরতপুর,ਭਰਤਪੁਰ,ભરતપુર,ଭରତପୁର,ഭരത്പൂർ,バラトプル,珀勒德布爾', 27.2173100, 77.4900900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78634, 'Bhānvad', 'Bhanvad', 'Bhanvad,Bhanwar,Bhauwar,Bhānvad', 21.9305300, 69.7808100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78635, 'Bhānpurī', 'Bhanpuri', 'Bhanpuri,Bhānpuri,Bhānpurī', 21.0919000, 80.9321800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78636, 'Bhānpura', 'Bhanpura', 'Bhanpura,Bhānpura', 24.5130000, 75.7469000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78637, 'Bhanjanagar', 'Bhanjanagar', 'Bhanjanagar,Russelkonda,Russellkonda', 19.9271900, 84.5820100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78638, 'Bhānder', 'Bhander', 'Bhander,Bhānder', 25.7358100, 78.7455500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78639, 'Bhandāra', 'Bhandara', 'Bhandara,Bhandāra,Bkhandara,Бхандара', 21.1681700, 79.6488500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78640, 'Bhālki', 'Bhalki', 'Bhalki,Bhālki', 18.0434800, 77.2060000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78641, 'Bhaisa', 'Bhaisa', 'Bhainsa,Bhaisa,bhainsa,భైంసా', 19.1128500, 77.9633600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78642, 'Bhainsdehi', 'Bhainsdehi', 'Bhainsdehi', 21.6449100, 77.6302300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78643, 'Bhagwantnagar', 'Bhagwantnagar', '', 26.2238300, 80.7575000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78644, 'Bhāgalpur', 'Bhagalpur', 'Bhagalpur,Bhāgalpur', 25.2444600, 86.9718300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78645, 'Bhadreswar', 'Bhadreswar', 'Bhadreswar', 22.8244900, 88.3384100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78646, 'Bhadrāvati', 'Bhadravati', 'Bhadravati,Bhadrāvati', 13.8484600, 75.7050200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78647, 'Bhadrakh', 'Bhadrakh', 'Bhadrak,Bhadrakh', 21.0544700, 86.5156000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78648, 'Bhadrāchalam', 'Bhadrachalam', 'Bhadrachalam,Bhadrachellam Road,Bhadrāchalam', 17.6684600, 80.8888700, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78649, 'Bhādra', 'Bhadra', 'Bhadra,Bhādra,Bkhadra,Бхадра', 29.1029800, 75.1713800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78650, 'Bhadohi', 'Bhadohi', 'Bhadohi,Bhadohī,XXB,ba duo xi,bhadohi,bhanadohi,بھدوہی,भदोही,ভানদোহি,巴多希', 25.3952600, 82.5703000, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78651, 'Bhadaur', 'Bhadaur', 'Bhadaur', 30.4765100, 75.3304900, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78652, 'Bhādāsar', 'Bhadasar', 'Adarsh Bas,Bhadasar,Bhādāsar,Ādarsh Bās', 28.3145700, 74.2895200, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78653, 'Bhadarwāh', 'Bhadarwah', 'Bhadarwab,Bhadarwah,Bhadarwāh,Bhaderwah,Bhadrawah', 32.9794100, 75.7172300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78654, 'Bhachāu', 'Bhachau', 'Bachau,Bhachau,Bhachāu,Buchow', 23.2985800, 70.3427900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78655, 'Bhabhua', 'Bhabhua', 'Bhabhua,Bhabua', 25.0404900, 83.6074900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78656, 'Bhābhra', 'Bhabhra', 'Bhabhra,Bhabra,Bhābhra,Bhābra', 22.5304800, 74.3284600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78657, 'Beypore', 'Beypore', 'Beipur,Beppur,Beypore,Beypur,bei yi bo lei,bepura,beyapare,peppur,बेपुर,বেয়পারে,பேப்பூர்,ബേപ്പൂർ,贝伊波雷', 11.1715100, 75.8061100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78658, 'Bewar', 'Bewar', '', 27.2186900, 79.2976100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78659, 'Betūl Bazār', 'Betul Bazar', 'Betul,Betul Bazar,Betūl Bazār,Betūl Bāzār', 21.8557200, 77.9291300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78660, 'Betūl', 'Betul', 'Badnur,Badnúr,Betul,Betūl', 21.9005600, 77.9022900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78661, 'Bettiah', 'Bettiah', 'Bettiah,Bettiakh,bei te di ya,betiya,betti''ah,bettiya,Беттиах,بیتیاہ,बेतिया,बेत्तिया,বেত্তিয়া,ବେଟ୍ଟିଆଃ,贝特蒂亚', 26.8022900, 84.5031100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78662, 'Betma', 'Betma', 'Betma', 22.6865300, 75.6145600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78663, 'Betamcherla', 'Betamcherla', '', 15.4514400, 78.1479700, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78664, 'Beswān', 'Beswan', 'Beswan,Beswān', 27.6379200, 77.8801900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78665, 'Beri Khās', 'Beri Khas', 'Beri,Beri Khas,Beri Khās', 28.7014600, 76.5770800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78666, 'Berasia', 'Berasia', 'Berasia,bei la xia,berasiya,बेरासिया,বেরাসিয়া,贝拉夏', 23.6313400, 77.4335100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78667, 'Beohāri', 'Beohari', 'Beohari,Beohāri', 24.0242300, 81.3783100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78668, 'Benīganj', 'Beniganj', 'Beniganj,Benīganj', 27.2929300, 80.4436400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78669, 'Benaulim', 'Benaulim', 'Benaulim,Бенаулим', 15.2643500, 73.9281200, 'IN', '2015-11-20', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78670, 'Bemetāra', 'Bemetara', 'Bemetara,Bemetāra', 21.7155600, 81.5342300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78671, 'Belūr', 'Belur', 'Belur,Belūr,Белур', 13.1655800, 75.8651900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78672, 'Belūr', 'Belur', '', 11.7069100, 78.4157000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78673, 'Beltangadi', 'Beltangadi', 'Beltangadi,Beltangady', 13.9833300, 75.3000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78674, 'Belsand', 'Belsand', 'Belsand', 26.4436500, 85.4007600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78675, 'Belonia', 'Belonia', 'Belonia,Beloniya', 23.2517800, 91.4540700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78676, 'Bellūru', 'Belluru', 'Bellur,Belluru,Bellūru', 12.9814000, 76.7330800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78677, 'Bellary', 'Bellary', 'BEP,Ballari,Ballāri,Belari,Belaris,Bellari,Bellary,Bellāri,ballari,bei la li,bellari,blary,bllary,bylary,pellari,Белари,Беллари,بلاری,بللاری,بیلاری,बळ्ळारी,बेल्लारी,বেল্লারী,ବଲ୍ଲାରୀ,பெல்லாரி,బళ్లారి,ಬಳ್ಳಾರಿ,贝拉里', 15.1420500, 76.9239800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78678, 'Beliātor', 'Beliator', 'Beliator,Beliatore,Beliātor', 23.3205200, 87.2208100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78679, 'Belgaum', 'Belgaum', 'Belagaavi,Belagavi,Belagoavi,Belagāvi,Belgaavi,Belgaon,Belgaum,Belgaumas,Gorad Belgaan,IXG,bei er gao mu,belaga''uma,belagam,belagamva,belaganva,belagavi,belgam,belgaum,berugaumu,blgam,blgaywm,bylgawm,bylgwm,pelkam,Белгаум,Горад Белгаан,بلگام,بلگایوم,بيلگوم,بیلگاؤم,बेलगाँव,बेलगांव,बेळगांव,बेळगावी,বেলগাউম,ବେଲଗାଁ,பெல்காம்,బెల్గాం,ಬೆಳಗಾವಿ,ബെൽഗാം,ベルガウム,贝尔高姆,벨가움', 15.8521200, 74.5044700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78680, 'Beldānga', 'Beldanga', 'Beldanga,Beldānga', 23.9342800, 88.2601800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78681, 'Belaguntha', 'Belaguntha', 'Belaguntha', 19.8824900, 84.6380100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78682, 'Bela', 'Bela', 'Bela,Bela Partabgarh,Partapgarh,Pratapgarh,Бела', 25.9205800, 81.9962900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78683, 'Behror', 'Behror', 'Behror,beharora,behrora,bei he luo er,बेह्रोर,বেহরোর,贝赫罗尔', 27.8883200, 76.2810800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78684, 'Behat', 'Behat', 'Behat', 30.1718000, 77.6139000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78685, 'Begusarai', 'Begusarai', 'Begusarai,Begusaraj,begusara''i,begusaraya,bei gu sa lai,bjsaray,pekucaray,Бегусарай,Бегусарај,بجساراي,بیگوسرائے,बेगुसराई,बेगुसराय,बेगूसराय,বেগুসারাই,ବେଗୁସରାଇ,பேகூசராய்,贝古萨赖', 25.4185300, 86.1338900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78686, 'Begūn', 'Begun', 'Begun,Begūn,Бегун', 24.9833300, 75.0000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78687, 'Begowāl', 'Begowal', 'Begowal,Begowala,Begowāl', 31.6115200, 75.5213500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78688, 'Begamganj', 'Begamganj', 'Begamganj', 23.5991700, 78.3406400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78689, 'Bedi', 'Bedi', 'Beda,Bedi,Bedi Bandar,Беда', 22.5014300, 70.0436300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78690, 'Beāwar', 'Beawar', 'Beawar,Beāwar', 26.1011900, 74.3202800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78691, 'Bāzpur', 'Bazpur', '', 29.1529900, 79.1081400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78692, 'Bayāna', 'Bayana', 'Bajan,Bayaha,Bayana,Bayāna,Баян', 26.9079100, 77.2898500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78693, 'Bawāna', 'Bawana', 'Bawana,Bawana Delhi,Bawāna', 28.7982000, 77.0343100, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78694, 'Bāwal', 'Bawal', 'Bawal,Bāwal', 28.0718400, 76.5831200, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78695, 'Bauda', 'Bauda', 'Bauda,Baudh,Baudh Raj,Baudh Rāj,Baudh-Ral', 20.8333300, 84.3166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78696, 'Batoti', 'Batoti', 'Batote,Batoti', 33.1182600, 75.3088900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78697, 'Batāla', 'Batala', 'Batala,Batāla,Butala', 31.8092100, 75.2029400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78698, 'Baswa', 'Baswa', '', 27.1495500, 76.5834500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78699, 'Bāsugaon', 'Basugaon', 'Basugaon,Bāsugaon', 26.4674200, 90.4195100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78700, 'Bāsudebpur', 'Basudebpur', 'Basudebpur,Bāsudebpur', 21.1197400, 86.7289600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78701, 'Bastī', 'Basti', 'Basti,Bastī,Басти', 26.7881700, 82.7161700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78702, 'Bāsoda', 'Basoda', 'Basoda,Bāsoda', 23.8515300, 77.9365200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78703, 'Basni', 'Basni', 'Basni,Basni Bailima,Басни', 27.1723200, 73.6451900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78704, 'Basna', 'Basna', 'Basna', 21.2788500, 82.8267000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78705, 'Basmat', 'Basmat', 'Basmat,Basmath', 19.3287200, 77.1574600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78706, 'Basi', 'Basi', '', 30.6885000, 76.4011100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78707, 'Basi', 'Basi', 'Basi,Dera Basi,Dera Bassi', 30.5881300, 76.8449800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78708, 'Basi', 'Basi', '', 26.8315000, 76.0485600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78709, 'Basavana Bāgevādi', 'Basavana Bagevadi', 'Bagevadi,Basavana Bagevadi,Basavana Bāgevādi,Bāgevādi', 16.5727800, 75.9725200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78710, 'Basavakalyān', 'Basavakalyan', 'Basavakalyan,Basavakalyān,Kalyani,Kalyāni', 17.8744500, 76.9497200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78711, 'Bāsār', 'Basar', 'Basar,Bāsār', 27.9900800, 94.6945100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78712, 'Barwāni', 'Barwani', 'Barwani,Barwāni', 22.0323200, 74.8998200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78713, 'Barwāla', 'Barwala', 'Barwala,Barwāla', 29.3674700, 75.9080900, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78714, 'Barwādih', 'Barwadih', 'Barwadih,Barwādih', 23.8475300, 84.1112200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78715, 'Bāruni', 'Baruni', 'Barani,Baruni,Bāruni,Баруни', 25.4750900, 85.9681300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78716, 'Bāruipur', 'Baruipur', 'Baruipur,Bāruipur', 22.3525300, 88.4388200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78717, 'Bārsi', 'Barsi', 'Barshi,Barsi,Bārsi', 18.2345400, 75.6927500, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78718, 'Barsāna', 'Barsana', 'Barsana,Barsāna', 27.6480200, 77.3764000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78719, 'Barpeta', 'Barpeta', 'Barpeta', 26.3229300, 91.0063200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78720, 'Barpathār', 'Barpathar', 'Barpathar,Barpathār', 26.2870900, 93.8884400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78721, 'Barpāli', 'Barpali', 'Barpali,Barpāli', 21.1900500, 83.5872100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78722, 'Barnāla', 'Barnala', 'Anahadgarh,Anāhadgarh,Barnala,Barnāla,Барнала', 30.3745100, 75.5487000, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78723, 'Bārmer', 'Barmer', 'Barmer,Bārmer', 25.7457200, 71.3921100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78724, 'Barkot', 'Barkot', 'Barkot', 30.8086100, 78.2059600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78725, 'Barki Saria', 'Barki Saria', '', 24.1754300, 85.8907700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78726, 'Barkhera Kalān', 'Barkhera Kalan', 'Barkhera,Barkhera Kala,Barkhera Kalan,Barkhera Kalān', 28.4520900, 79.8065500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78727, 'Barka Kāna', 'Barka Kana', '', 23.6219900, 85.4671400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78728, 'Barjora', 'Barjora', 'Barjora', 23.4275400, 87.2903700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78729, 'Barjala', 'Barjala', '', 23.6182000, 91.3559600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78730, 'Bari Sādri', 'Bari Sadri', 'Bari Sadri,Bari Sādri', 24.4133900, 74.4733100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78731, 'Bariārpur', 'Bariarpur', '', 25.2884800, 86.5757800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78732, 'Bāri', 'Bari', 'Bari,Bāri', 26.6466100, 77.6163400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78733, 'Barhiya', 'Barhiya', '', 25.2881400, 86.0205500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78734, 'patamda', 'patamda', '', 24.3000000, 85.4166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78735, 'Barhi', 'Barhi', 'Barhi', 23.9032600, 80.8151600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78736, 'Bārh', 'Barh', 'Barh,Barkh,Bārh,Барх', 25.4833900, 85.7092800, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78737, 'Bargi', 'Bargi', '', 22.9913800, 79.8755000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78738, 'Barghāt', 'Barghat', 'Barghat,Barghāt', 22.0306500, 79.7328000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78739, 'Bargarh', 'Bargarh', 'Baragarh,Bargarh,Bargarkh,ba er jia er,baragadha,baragara,bargadh,parkaht,Баргарх,برگرہ,बरगढ,বারগড়,બરગઢ,ବରଗଡ଼,பர்கஃட்,బర్గఢ్,巴尔加尔', 21.3334800, 83.6190500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78740, 'Barela', 'Barela', 'Barela,Barelā', 23.0967800, 80.0508400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78741, 'Bareilly', 'Bareilly', 'BEK,Bareilly,Barejli,Bareli,Barelī,ba lei li,baleilli,baraili,bareli,bareri,bereli,bryly,pareli,Барейли,Барели,Барејли,بريلي,بریلی,बरेली,बरैली,বেরেলি,બરેલી,பரேலி,ಬರೇಲಿ,ബറേലി,バレーリー,巴雷利,바레일리', 28.3667800, 79.4316700, 'IN', '2017-05-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78742, 'Bārdoli', 'Bardoli', 'Bardoli,Bardoti,Bārdoli,Бардоли', 21.1229700, 73.1115100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78743, 'Barddhamān', 'Barddhaman', 'Barddhaman,Barddhamān,Bardhaman,Bardhamān,Bordhoman,Burdwan,Burdwān,bardhamana,বর্ধমান', 23.2557200, 87.8569100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78744, 'Bar Bigha', 'Bar Bigha', '', 25.2185500, 85.7332000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78745, 'Baraut', 'Baraut', 'Baraut', 29.1019900, 77.2633400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78746, 'Barauli', 'Barauli', 'Barauli', 26.3810900, 84.5864800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78747, 'Bārāsat', 'Barasat', 'Barasat,Bārāsat', 22.7215400, 88.4819800, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78748, 'Bārāsat', 'Barasat', 'Barasat,Bārāsat', 22.2251600, 88.4508600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78749, 'Baranagar', 'Baranagar', 'Baranagar,Baranagaras,Baranagore,ba la na jia er,barahanagara,baranagara,barangr,Баранагар,بارانگر,बारानगर,বড়ানগর,বরাহনগর,巴拉纳加尔', 22.6413200, 88.3772700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78750, 'Bārān', 'Baran', 'Baran,Bārān,Баран', 25.1000000, 76.5166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78751, 'Bāramūla', 'Baramula', '', 34.2090000, 74.3428500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78752, 'Bārāmati', 'Baramati', 'Baramati,Bārāmati,Барамати', 18.1517400, 74.5776700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78753, 'Bārākpur', 'Barakpur', 'Barakpur,Barrackpore,Bārākpur,Chanak', 22.7660200, 88.3633600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78754, 'Barāgaon', 'Baragaon', 'Baragaon,Barāgaon', 25.4755400, 78.7122400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78755, 'Barāgaon', 'Baragaon', 'Baragaon,Barāgaon', 25.4293600, 82.8170900, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78756, 'Bara Bazar', 'Bara Bazar', 'Bara Bazar,Barabazar,Calcutta Bara Bazar', 22.5666700, 88.3500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78757, 'Bāpatla', 'Bapatla', 'Bapatla,Bāpatla', 15.9042200, 80.4674300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78758, 'Banūr', 'Banur', '', 30.5540700, 76.7194800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78759, 'Bantvāl', 'Bantval', 'Bantval,Bantvāl,Bantwall,Bantyal,Bartval', 12.8905000, 75.0348900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78760, 'Bāntva', 'Bantva', 'Bantva,Bantwa,Bāntva', 21.4881500, 70.0757600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78761, 'Bānswāra', 'Banswara', 'Banswara,Bānswāra', 23.5410900, 74.4425000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78762, 'Bānswāda', 'Banswada', 'Banswada,Bānswāda', 18.3772500, 77.8800700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78763, 'Bānsi', 'Bansi', 'Bansi,Bānsi', 27.1774900, 82.9344200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78764, 'Bānsgāon', 'Bansgaon', 'Bansgaon,Bānsgaon,Bānsgāon', 26.5503200, 83.3450300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78765, 'Bānsdīh', 'Bansdih', 'Bansdih,Bānsdīh', 25.8837700, 84.2182700, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78766, 'Bānsbāria', 'Bansbaria', 'Bansbaria,Bansberia,Bānsbāria', 22.9538700, 88.4009800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78767, 'Bānposh', 'Banposh', 'Banposh,Banposi,Bānposh,Bānposi,Panposh', 22.2483400, 84.8104400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78768, 'Bannūr', 'Bannur', 'Bannur,Bannūr', 12.3329500, 76.8620100, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78769, 'Banmankhi', 'Banmankhi', 'Banmankhi,Banmanki', 25.8885700, 87.1942100, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78770, 'Bānkura', 'Bankura', 'Bankura,Bānkura,Банкура', 23.2324100, 87.0716000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78771, 'Bānki', 'Banki', 'Banki,Bankigarh,Bānki,Bānkīgarh', 20.3791200, 85.5295300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78772, 'Bānka', 'Banka', 'Banka,Bhagalpur,Bānka', 24.8809100, 86.9225700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78773, 'Banjār', 'Banjar', 'Banjar,Banjār', 31.6390000, 77.3405500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78774, 'Banihāl', 'Banihal', 'Banihal,Banihāl', 33.4364700, 75.1968400, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78775, 'Bāngarmau', 'Bangarmau', 'Bangarmau,Bāngarmau', 26.8912000, 80.2114900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78776, 'Bowringpet', 'Bowringpet', 'Bangarapet,Bangārapet,Bowringpet', 12.9911600, 78.1780400, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78777, 'Bangaon', 'Bangaon', 'Bangaon', 25.8672800, 86.5115200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78778, 'Bangaon', 'Bangaon', 'Bangaon,Bongaon,banagam,banagamo,banagavam,bang ge a ao en,Бангаон,बानगावं,বনগাঁ,বনগাঁও,邦格阿奥恩', 23.0455300, 88.8308400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78779, 'Banganapalle', 'Banganapalle', 'Banaganapalli,Banganapalle,Banganapilly,banaganapalli,బనగానపల్లి', 15.3177100, 78.2266900, 'IN', '2016-10-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78780, 'Bengaluru', 'Bengaluru', 'BLR,Ban''nkalor,Bangalor,Bangalora,Bangalore,Bangalore - bengaluru,Bangalore - ಬೆಂಗಳೂರು,Bangalore City,Bangalur,Bangaluri,Bangalúr,Bengalour,Bengaluras,Bengaluro,Bengaluru,Bengalurus,Bengalúru,Bengalūras,Bengalūru,Gorad Bangalor,baeng-geollo,bagalaura,ban jia luo er,bang kha l xr,bang-galloleu,bangalaura,bangalora,bangalura,bangaroru,beng-gallulu,bengalora,bengaluru,benguluru,bnghalwr,bnglwr,bynglwr,penkalur,Μπανγκαλόρ,Бангалор,Бенгалуру,Бенґалуру,Горад Бангалор,בנגלור,بنغالور,بنگلور,بینگلور,बंगलौर,बंगळूर,बेङ्गलूरु,बेङ्गलोर,बेङ्गळूरु,বাঙ্গালোর,বেঙ্গালুরু,ਬੰਗਲੌਰ,બેંગલોર,ବେଙ୍ଗାଳୁରୁ,பெங்களூர்,బెంగుళూరు,ಬೆಂಗಳೂರು,ബെംഗളൂരു,බැංගලෝර්,บังคาลอร์,ဘန်ဂလိုမြို့,ბენგალურუ,バンガロール,班加罗尔,班加羅爾,방갈로르,뱅걸로,벵갈루루', 12.9719400, 77.5936900, 'IN', '2017-06-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78781, 'Banga', 'Banga', 'Banga', 31.1887400, 75.9949500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78782, 'Bandora', 'Bandora', 'Bandora', 15.4082300, 73.9812900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78783, 'Bandipura', 'Bandipura', 'Bandapur,Bandipur,Bandipura', 34.4172800, 74.6430800, 'IN', '2014-12-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78784, 'Bāndīkūi', 'Bandikui', 'Bandikui,Bāndīkūi', 27.0508700, 76.5732500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78785, 'Bānda', 'Banda', 'Banda,Bānda', 25.4775800, 80.3349100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78786, 'Banda', 'Banda', '', 24.0448800, 78.9609400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78787, 'Bānāvar', 'Banavar', 'Banavar,Banavara,Bānāvar', 13.4102900, 76.1631400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78788, 'Banat', 'Banat', 'Banat,Банат', 29.4635500, 77.3547800, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78789, 'Bānapur', 'Banapur', 'Banapur,Banpur,Bānapur,Bānpur', 19.7788900, 85.1703300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78790, 'Bāmor Kalān', 'Bamor Kalan', 'Bamor,Bamor Kalan,Bāmor,Bāmor Kalān', 24.8929800, 78.1510500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78791, 'Bamora', 'Bamora', 'Bamora', 24.0553900, 78.0892500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78792, 'Bamna', 'Bamna', 'Bamna,Bamnia,Bāmnia', 23.0945400, 74.7616400, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78793, 'Bamboo Flat', 'Bamboo Flat', '', 11.7000000, 92.7166700, 'IN', '2006-01-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78794, 'Bambolim', 'Bambolim', 'Bambolim', 15.4636100, 73.8531000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78795, 'Bālurghāt', 'Balurghat', 'Balurghat,Bālurghāt,RGH', 25.2209900, 88.7773200, 'IN', '2017-03-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78796, 'Bālugaon', 'Balugaon', 'Balugaon,Bālugaon', 20.1781100, 85.1122500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78797, 'Balrāmpur', 'Balrampur', 'Balrampur,Balrāmpur', 27.4294900, 82.1854500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78798, 'Bālotra', 'Balotra', 'Balotra,Bālotra', 25.8324200, 72.2400000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78799, 'Baloda Bāzār', 'Baloda Bazar', 'Baloda Bazar,Baloda Bāzār', 21.6567800, 82.1606200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78800, 'Baloda', 'Baloda', 'Baloda', 22.1389000, 82.4817100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78801, 'Balod', 'Balod', 'Balod', 20.7308100, 81.2057800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78802, 'Bāli', 'Bali', 'Bali,Bally,Bāli,Бали', 22.6485900, 88.3411500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78803, 'Ballālpur', 'Ballalpur', 'Ballalpur,Ballarpur,Ballālpur', 19.8469600, 79.3457800, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78804, 'Balimila', 'Balimila', 'Balimela,Balimila,Bālimela', 18.2516700, 82.1065900, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78805, 'Bāli Chak', 'Bali Chak', '', 22.3648200, 87.5530400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78806, 'Bāli', 'Bali', '', 25.1972500, 73.2911700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78807, 'Balasore', 'Balasore', 'Balasor,Balasore,Baleshwar,Baleswar,Bāleshwar,ba la suo er,balasor,balaswr,balesbara,balesvara,bareshuwaru,palesvar,Баласор,بالاسور,बालेश्वर,বালেশ্বর,બાલેશ્વર,ବାଲେଶ୍ଵର,பாலேஸ்வர்,బాలాసోర్,ಬಾಲಸೊರ್,バーレーシュワル,巴拉索尔', 21.4926600, 86.9334800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78808, 'Baldeogarh', 'Baldeogarh', 'Baldeogarh', 24.7561900, 79.0671500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78809, 'Baldev', 'Baldev', 'Baldeo,Baldev,Dauji,Dāūji', 27.4068400, 77.8221400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78810, 'Balarāmpur', 'Balarampur', 'Balarampur,Balarāmpur', 23.0971400, 86.2229200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78811, 'Bālāpur', 'Balapur', 'Balapur,Bālāpur', 20.6661200, 76.7738600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78812, 'Balāngīr', 'Balangir', 'Balangir,Balāngīr,Bolangir,Bolāngir', 20.7041900, 83.4902900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78813, 'Bālāghāt', 'Balaghat', 'Balaghat,Burha,Bālāghāt', 21.8156000, 80.1884500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78814, 'Bālāchor', 'Balachor', 'Balachaur,Balachor,Bālāchor', 31.0606200, 76.3016600, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78815, 'Bakshwāho', 'Bakshwaho', 'Bakshwaho,Bakshwāho,Bakswaho,Bakswāho,Buxwaha', 24.2510600, 79.2861800, 'IN', '2016-06-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78816, 'Bakreswar', 'Bakreswar', 'Bakresvare,Bakreswar', 23.8832000, 87.3726500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78817, 'Bakloh', 'Bakloh', 'Bakloh,Bukloh,ba ke luo,bakaloha,balko,बल्को,বাকলোহ,巴克洛', 32.4793900, 75.9187400, 'IN', '2012-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78818, 'Bakhtiyārpur', 'Bakhtiyarpur', '', 25.4617900, 85.5317900, 'IN', '2016-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78819, 'Bakewar', 'Bakewar', 'Bakewar', 26.6622600, 79.1762500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78820, 'Bakāni', 'Bakani', 'Bakani,Bakāni', 24.2862400, 76.2370900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78821, 'Bājna', 'Bajna', 'Bajna,Bājna', 27.8979300, 77.6783600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78822, 'Baj Baj', 'Baj Baj', 'Baj Baj,Budge Budge', 22.4751400, 88.1776700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78823, 'Baisi', 'Baisi', 'Baisi', 25.8630200, 87.7448700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78824, 'Bairāgnia', 'Bairagnia', 'Bairagnia,Bairgania,Bairāgnia', 26.7406300, 85.2732300, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78825, 'Byndoor', 'Byndoor', 'Baindur,Bainduri,Baindūr,Baindūri,Byndoor', 13.8666700, 74.6333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78826, 'Bail-Hongal', 'Bail-Hongal', 'Bail Hongal,Bail-Hongal', 15.8137000, 74.8589500, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78827, 'Baikunthpur', 'Baikunthpur', 'Baikunthapur,Baikunthpur', 23.2620600, 82.5605100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78828, 'Baikunthpur', 'Baikunthpur', 'Baikanthpur,Baikunthpur', 24.7276800, 81.4097500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78829, 'Baihar', 'Baihar', 'Baihar', 22.1013300, 80.5496700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78830, 'Baidyabāti', 'Baidyabati', 'Baidyabati,Baidyabāti', 22.7849800, 88.3258600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78831, 'Bahua', 'Bahua', '', 25.8394200, 80.6225500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78832, 'Bahsūma', 'Bahsuma', 'Bahsuma,Bahsūma', 29.2006300, 77.9722100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78833, 'Bahraigh', 'Bahraigh', 'Bahraich,Bahraigh', 27.5742900, 81.5947400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78834, 'Bahjoi', 'Bahjoi', 'Bahjoi,Bhajoi', 28.3950200, 78.6265900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78835, 'Baheri', 'Baheri', 'Baheri', 28.7741600, 79.4974000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78836, 'Baharampur', 'Baharampur', 'Baharampur,Bahrampur,Bahrāmpur,Bakharampur,Berhampore,ba ha la mu pu er,baharamapura,Бахарампур,بهرام‌پور,بہرام پور,बहरमपुर,बहरामपुर,बहरामपूर,বহরমপুর,বাহারামপুর,ବହରମ୍‌ପୁର୍,巴哈拉姆普尔', 24.1047300, 88.2515500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78837, 'Bahādurgarh', 'Bahadurgarh', 'Bahadurgarh,Bahādurgarh', 28.6928700, 76.9355500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78838, 'Bahādurganj', 'Bahadurganj', 'Bahadurganj,Bahādurganj', 26.2617200, 87.8244300, 'IN', '2015-12-05', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78839, 'Bāh', 'Bah', 'Bah,Bāh', 26.8691200, 78.5938500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78840, 'Bagulā', 'Bagula', 'Bagula,Bagulā', 23.3366400, 88.6410900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78841, 'Bagra', 'Bagra', '', 23.7333300, 86.3166700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78842, 'Bāgli', 'Bagli', 'Bagli,Bāgli', 22.6412400, 76.3487700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78843, 'Bāghpat', 'Baghpat', 'Baghpat,Bagpat,Bāghpat', 28.9448500, 77.2186500, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78844, 'Bagdogra', 'Bagdogra', 'Bagdogra,Baghdogra,Bāghdogra,IXB', 26.6992900, 88.3117700, 'IN', '2016-10-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78845, 'Bāgha Purāna', 'Bagha Purana', 'Bagha Purana,Baghaparana,Bāgha Purāna', 30.6880900, 75.0983800, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78846, 'Bāg', 'Bag', 'Bag,Bagh,Bāg,Bāgh', 22.3590500, 74.7905200, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78847, 'Bāgeshwar', 'Bageshwar', 'Bageshwar,Bāgeshwar', 29.8373800, 79.7716100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78848, 'Bāgepalli', 'Bagepalli', 'Bagepalli,Bāgepalli', 13.7833800, 77.7966700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78849, 'Bagasra', 'Bagasra', 'Bagasara,Bagasra', 21.4871900, 70.9551600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78850, 'Bagar', 'Bagar', 'Bagar', 28.1878400, 75.5001200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78851, 'Bagalkot', 'Bagalkot', 'Bagalakote,Bagalkot,Bāgalkot,ba jia er ke te,bagalakota,pakalkot,Багалкот,बागलकोट,বাগলকোট,பாகல்கோட்,బాగల్‌కోట్,巴加尔科特', 16.1867300, 75.6961400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78852, 'Bagaha', 'Bagaha', 'Bagaha', 27.0991800, 84.0900300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78853, 'Bagaha', 'Bagaha', 'Bagaha,Bagaha Division', 24.5289800, 85.0601900, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78854, 'Badvel', 'Badvel', 'Badvel', 14.7451000, 79.0628800, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78855, 'Badūria', 'Baduria', 'Baduria,Badurii,Badūria,Бадурии', 22.7443100, 88.7865500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78856, 'Badnāwar', 'Badnawar', 'Badnawar,Badnāwar', 23.0218100, 75.2326800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78857, 'Badlapur', 'Badlapur', 'Badlapur,ba de la pu er,badalapura,bdlapwr,بدلاپور,बदलापूर,बादलपुर,বাদলাপুর,巴德拉普尔', 19.1551600, 73.2655300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78858, 'Badhni Kalān', 'Badhni Kalan', 'Badhni Kalan,Badhni Kalān', 30.6813000, 75.2908700, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78859, 'Badarwās', 'Badarwas', 'Badarwas,Badarwās', 24.9751600, 77.5649000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78860, 'Badarpur', 'Badarpur', 'Badarpur', 24.8685200, 92.5960600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78861, 'Bādāmi', 'Badami', 'Badami,Бадами', 15.9149500, 75.6768300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78862, 'Badagara', 'Badagara', 'Badagara,Vatakara', 11.5977600, 75.5814200, 'IN', '2016-05-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78863, 'Bada Barabīl', 'Bada Barabil', 'Bada Barabil,Bada Barabīl,Barabil', 22.1118600, 85.3868400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78864, 'Bachhrāwān', 'Bachhrawan', 'Bachhrawan,Bachhrāwān', 26.4709000, 81.1158000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78865, 'Bachhraon', 'Bachhraon', 'Bachhraon', 28.9269400, 78.2345600, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78866, 'Babugarh', 'Babugarh', 'Babugarh,Bābūgarh', 28.7235300, 77.8467700, 'IN', '2015-07-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78867, 'Babrāla', 'Babrala', 'Babrala,Babrāla', 28.2641900, 78.4056000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78868, 'Bābra', 'Babra', 'Babra,Babra (India : Taluka),Bābra', 21.8457700, 71.3054400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78869, 'Babīna', 'Babina', 'Babina,Babīna,Бабина', 25.2394700, 78.4702800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78870, 'Baberu', 'Baberu', 'Baberu', 25.5471100, 80.7044300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78871, 'Bābai', 'Babai', 'Babai,Bābai', 22.7025600, 77.9349400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78872, 'Azamgarh', 'Azamgarh', 'Azamgarh,Azamgarkh,a zha mu jia er,ajamagadha,ajamagadha jilla,ajamagadha-nagaram,ajamagara,ajhamagadha,azamagarha,azamugaru,Āzamgarh,Азамгарх,اعظم گڑھ,आजमगढ,आजमगढ जिल्ला,आजमगढ-नगरम्,आज़मगढ़,आझमगढ,আজমগড়,આઝમગઢ,ଆଜମ୍‌ଗଡ଼,アーザムガル,阿扎姆加尔', 26.0683200, 83.1835800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78873, 'Ayyampettāi', 'Ayyampettai', 'Ayyampettai,Ayyampettāi', 10.9014100, 79.1798400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78874, 'Ajodhya', 'Ajodhya', 'Ajodhija,Ajodhjo,Ajodhya,Ajodkh''e,Ajodkh''ja,Ajodkhja,Ayodhya,Oudh,a yue ti ya,ayead''dhya,ayod''dha,ayodhi''a,ayodhya,ayodhye,ayodia,ayodiya,ayotti,aywdya,x yoth ya,Айодхье,Айодхья,Айодхя,أيوديا,ایودھیا,ایودیا,अयोद्धा,अयोध्या,অযোধ্যা,ਅਯੋਧਿਆ,અયોધ્યા,ଅଯୋଧ୍ୟା,அயோத்தி,అయోధ్య,ಅಯೋಧ್ಯೆ,അയോദ്ധ്യ,อโยธยา,ཨ་ཡོ་དྷི་ཡ།,アヨーディヤー,阿约提亚,아요디아', 26.7990900, 82.2047000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78875, 'Ayakudi', 'Ayakudi', 'Ayakkudi,Ayakudi,Palaiya Ayakkudi', 10.4499200, 77.5519800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78876, 'Awantipur', 'Awantipur', 'Awantipur,Awantipura,Awantīpur,Awantīpura,Wantipor,Wantipur,Wantipōr', 33.9197800, 75.0151500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78877, 'Avanigadda', 'Avanigadda', '', 16.0214800, 80.9180800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78878, 'Avinashi', 'Avinashi', 'Avanashi,Avanāshi', 11.1929700, 77.2686500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78879, 'Āvadi', 'Avadi', 'Avadi,Āvadi,Авади', 13.1147000, 80.1098100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78880, 'Ausa', 'Ausa', 'Ausa', 18.2472800, 76.4993000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78881, 'Aurās', 'Auras', 'Auras,Aurās', 26.9141400, 80.5079200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78882, 'Aurangābād', 'Aurangabad', 'Aurangabad,Aurangābād', 24.7520400, 84.3742000, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78883, 'Aurangabad', 'Aurangabad', 'Aurangabad,Aurangabad - aurangabada,Aurangabad - औरंगाबाद,Aurangabadas,Aurangâbâd,Aurangābād,IXU,a''orangabada,a''urangabada,aurangabada,aurangabada sahara,aurangabado,Аурангабад,औरंगाबाद,औरंगाबाद शहर,আউরঙ্গাবাদ,আওরঙ্গাবাদ,アウランガーバード', 19.8775700, 75.3422600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78884, 'Auraiya', 'Auraiya', 'Auraiya,Aurajja,Etawah,a''ura''iya,ao lai ye,aura''iya,auraiya,awrya,Аурайя,اورایہ,اوریا,औराइया,औरैया,আউরাইয়া,ઔરૈયા,奥赖耶', 26.4651700, 79.5091800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78885, 'Aurād', 'Aurad', 'Aurad,Aurād', 18.2539700, 77.4176100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78886, 'Attur', 'Attur', 'Attur,Atur-Salem,attur,attura,Āttūr,अत्तुर,আত্তুর,ஆத்தூர்', 11.5941400, 78.6014300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78887, 'Attingal', 'Attingal', 'Attingal,Attungal,a te ting ge a er,arrinkal,attinagala,attingal,attingala,آٹنگل,अत्तिनगल,অত্তিঙ্গল,আত্তিঙ্গল,ଆଟ୍ଟିଙ୍ଗାଲ୍,ஆற்றிங்கல்,ആറ്റിങ്ങൽ,阿特廷格阿尔', 8.6960900, 76.8150700, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78888, 'Attili', 'Attili', 'Attili', 16.7000000, 81.6000000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78889, 'Āttayyāmpatti', 'Attayyampatti', 'Attayampatti,Attayyampatti,Āttayyāmpatti', 11.5318700, 78.0541600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78890, 'Atraulia', 'Atraulia', 'Atraulia,Atrauliya,Atrauliā', 26.3333000, 82.9472700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78891, 'Atraulī', 'Atrauli', 'Aligarh,Atrauli,Atraulī', 28.0296400, 78.2857100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78892, 'Atmakūr', 'Atmakur', '', 15.8810900, 78.5870400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78893, 'Adirampattinam', 'Adirampattinam', 'Adirampatnam,Adirampattinam,Adirāmpatnam,Atirampattinam,Atirāmpattinam,Attirampattinam', 10.3405900, 79.3790500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78894, 'Athni', 'Athni', 'Athani,Athni,a te ni,athani,athani taluka,athni,اتھانی، کرناٹک,अथणी,अथणी तालुका,अथ्नी,আথনি,ଆଥ୍‌ନି,ಅಥಣಿ,阿特尼', 16.7261300, 75.0642100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78895, 'Āthagarh', 'Athagarh', 'Athagarh,Athgarh,Āthagarh', 20.5199900, 85.6296500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78896, 'Ateli Mandi', 'Ateli Mandi', 'Ateli,Ateli Mandi', 28.1008000, 76.2598000, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78897, 'Atarra', 'Atarra', 'Atarra,Atarra Buzurg', 25.2861800, 80.5715500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78898, 'Āsind', 'Asind', 'Asind,Āsind', 25.7342000, 74.3327800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78899, 'Āsika', 'Asika', 'Asika,Aska,Āsika', 19.6111400, 84.6599800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78900, 'Asifābād', 'Asifabad', 'Asafabad,Asifabad,Asifābād,Jangaon', 19.3585100, 79.2841500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78901, 'Ashti', 'Ashti', 'Ashti,Āshti', 19.3767100, 76.2252000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78902, 'Ashta', 'Ashta', 'Ashta,Ашта', 23.0175400, 76.7220800, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78903, 'Ashta', 'Ashta', 'Ashta,Satara,Ашта', 16.9494300, 74.4093600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78904, 'Ashoknagar', 'Ashoknagar', 'Ashok Nagar,Ashoknagar,Pachhar,Pachhār,a si huo ke na jia er,acok nakar,ashwk ngr,asokanagara,asokanagara jilla,asokanagaram,اشوک نگر,अशोकनगर,अशोकनगर जिल्ला,अशोकनगरम्,অশোকনগর,ଅଶୋକନଗର,அசோக் நகர்,阿斯霍克纳加尔', 24.5757800, 77.7312300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78905, 'Asarganj', 'Asarganj', 'Asarganj', 25.1504600, 86.6863900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78906, 'Āsansol', 'Asansol', 'Asanol,Asansol,asanasola,asansoru,Āsansol,Асансол,आसनसोल,আসানসোল,アサンソル', 23.6833300, 86.9833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78907, 'Āsandh', 'Asandh', 'Asandh,Āsandh', 29.5211900, 76.6055200, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78908, 'Ārvi', 'Arvi', 'Arvi,Ārvi', 20.9958500, 78.2291400, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78909, 'Aruppukkottai', 'Aruppukkottai', 'Aruppukkottai', 9.5084200, 78.0944900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78910, 'Arumuganeri', 'Arumuganeri', 'Arumuganeri', 8.5688000, 78.0909100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78911, 'Arumbāvūr', 'Arumbavur', 'Arumbavur,Arumbvur,Arumbāvūr', 11.3816700, 78.7288500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78912, 'Arukutti', 'Arukutti', '', 9.8666700, 76.3500000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78913, 'Arsikere', 'Arsikere', 'Arsikere', 13.3144600, 76.2570400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78914, 'Āron', 'Aron', 'Aron,Āron', 24.3810900, 77.4173900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78915, 'Norīa', 'Noria', 'Arnia,Arnīa,Noria,Norīa', 32.5209500, 74.7984500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78916, 'Arki', 'Arki', 'Arki', 31.1519600, 76.9667500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78917, 'Arkalgūd', 'Arkalgud', 'Arkalgud,Arkalgūd', 12.7617100, 76.0603500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78918, 'Ariyalūr', 'Ariyalur', '', 11.1384900, 79.0755600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78919, 'Arimalam', 'Arimalam', 'Arimalam', 10.2563900, 78.8871200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78920, 'Arcot', 'Arcot', 'Arcot,Arkota,Аркота', 12.9056900, 79.3189700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78921, 'Aruvankad', 'Aruvankad', 'Aravandadu,Aravanghat,Aravankadu,Aravankādu,Aruvankad,Aruvankadu', 11.3631500, 76.7579000, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78922, 'Arāria', 'Araria', 'Araria,Ararija,Arāria,arariya,Арария,अररिया', 26.1493400, 87.5132300, 'IN', '2016-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78923, 'Arantāngi', 'Arantangi', 'Arantangi,Arantāngi,Arrantangy', 10.1723500, 78.9911800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78924, 'Arni', 'Arni', 'Arani,Arni,Ārani', 12.6677100, 79.2852900, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78925, 'Ārangaon', 'Arangaon', 'Arangaon,Jamkhed,Ārangaon', 18.6745800, 75.1797600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78926, 'Arang', 'Arang', 'Arang', 21.1963900, 81.9691200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78927, 'Arambol', 'Arambol', 'Arambol,Arambol'',Арамболь', 15.6868100, 73.7044900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78928, 'Arāmbāgh', 'Arambagh', 'Arambagh,Arāmbāgh', 22.8833300, 87.7833300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78929, 'Arakkonam', 'Arakkonam', 'Arakkonam,Arkonam', 13.0844900, 79.6705300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78930, 'Arrah', 'Arrah', 'Ara,Arrah,Arrakh,Shahabad,a la,ara,araraha,arrah,Ара,Аррах,آرا,آراہ,اراہ,आरा,আররাহ,ਆਰਾ,આરા,ଆର୍ରାହ୍,阿拉', 25.5562900, 84.6633500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78931, 'Aonla', 'Aonla', 'Aonla,Aonla Kila', 28.2740200, 79.1652100, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78932, 'Anūpshahr', 'Anupshahr', 'Anupshahr,Anūpshahr', 28.3574800, 78.2691400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78933, 'Anūppur', 'Anuppur', 'Anuppur,Anūppur', 23.1034400, 81.6908300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78934, 'Anūpgarh', 'Anupgarh', 'Anupgarh,Anūpgarh', 29.1911100, 73.2086100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78935, 'Antu', 'Antu', 'Antu', 26.0565400, 81.9026700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78936, 'Antri', 'Antri', 'Antri', 26.0580400, 78.2102700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78937, 'Anta', 'Anta', '', 25.1500000, 76.3000000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78938, 'Anshing', 'Anshing', 'Anshing,Ansing,Ansing (Shrungarushi Maharaj)', 20.0409000, 77.3150100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78939, 'Annur', 'Annur', 'Annur,Annūr', 11.2361600, 77.1051400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78940, 'Annigeri', 'Annigeri', 'Annigeri', 15.4251300, 75.4335000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78941, 'Annavāsal', 'Annavasal', 'Annavasal,Annavāsal', 10.4605700, 78.7000200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78942, 'Annāmalainagar', 'Annamalainagar', 'Anamalainagar,Annamalai,Annamalainagar,Annāmalainagar', 11.4000000, 79.7333300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78943, 'Ankola', 'Ankola', 'Ankola,an ke la,ankola,ankwla,انکولا,अंकोल,अंकोला,অঙ্কোলা,আঙ্কোল,ಅಂಕೋಲಾ,安科拉', 14.6604900, 74.3047000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78944, 'Ankleshwar', 'Ankleshwar', 'Ankleshwar,Anklesvar', 21.6323600, 72.9900100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78945, 'Anjār', 'Anjar', 'Andzharom,Anjar,Anjār,Анджаром', 23.1131600, 70.0267100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78946, 'Anjangaon', 'Anjangaon', 'Anjangaon', 21.1651600, 77.3091000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78947, 'Anjad', 'Anjad', 'Anjad', 22.0417100, 75.0551900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78948, 'Angul', 'Angul', 'Angul,Anugul,Ungul,a nu gu er,angul,angula,angwl,anugola,anugula,anukol,anwgl,Ангул,انوگل,انگول,अंगुल,अनुगुल,अनुगोल,অনুগুল,ଅନୁଗୋଳ,அனுகோள்,అంగుల్,ಅಂಗುಲ್,阿努古尔', 20.8408900, 85.1019200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78949, 'Angamāli', 'Angamali', 'Angamali,Angamally,Angamāli', 10.1905500, 76.3878900, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78950, 'Anekal', 'Anekal', 'Anekal,a nei ka er,anekal,anekala,आनॆकल,आनॆकल्,আনেকাল,ಆನೇಕಲ್,阿内卡尔', 12.7111000, 77.6955700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78951, 'Andol', 'Andol', '', 17.8145800, 78.0771300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78952, 'Anthiyur', 'Anthiyur', 'Andiyur,Andiyūr', 11.5750600, 77.5904300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78953, 'Āndippatti', 'Andippatti', '', 9.9985400, 77.6212200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78954, 'Anantnag', 'Anantnag', 'Anantnag,Anantnāg,Islamabad,Islāmābād,a na en te na ge,anantanaga,anantanak,anantnag,anantnaj,anatanaga,annt nag,anntnag,Анантнаг,أنانتناج,انانتناگ,اننت ناگ,اننتناگ,अनंतनाग,अनन्तनाग,ਅਨੰਤਨਾਗ,અનંતનાગ,ଅନନ୍ତନାଗ,அனந்தநாக்,അനന്ത്നാഗ്,阿纳恩特纳格', 33.7306800, 75.1541800, 'IN', '2015-10-01', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78955, 'Anantapur', 'Anantapur', 'Anantapour,Anantapur,Anantapuramu,Anantapure,a na en ta pu er,anantapur,anantapura,anantapuram,anantapwr,annt pwr,Ανάνταπουρ,Анантапур,Анантапуре,آنانتاپور,اننت پور,اننتپور، آندھرا پردیش,अनंतपूर,अनन्तपुर,अनन्तपुरम्,অনন্তপুর,ଅନନ୍ତପୁର,அனந்தபூர்,అనంతపురం,అనంతపూర్,ಅನಂತಪುರ,阿纳恩塔普尔', 14.6778400, 77.6081300, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78956, 'Anandpur', 'Anandpur', 'Anandpur,Anandpur Sahib,Anandpur Sāhib', 31.2392600, 76.5025300, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78957, 'Anandnagar', 'Anandnagar', 'Anandnagar,Pharenda', 27.1006200, 83.2715600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78958, 'Anand', 'Anand', 'Aimand,Anand,Anaud,QNB,Ānand,Ананд', 22.5525100, 72.9552000, 'IN', '2017-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78959, 'Anakāpalle', 'Anakapalle', 'Anakapalle,Anakāpalle,anakapalli,అనకాపల్లి', 17.6913400, 83.0039500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78960, 'Anamalais', 'Anamalais', 'Anaimalai,Anaimalais,Anamalai,Anamalais', 10.5830300, 76.9344100, 'IN', '2017-03-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78961, 'Amudālavalasa', 'Amudalavalasa', 'Amudalavalasa,Amudālavalasa,amudalavalasa,ఆముదాలవలస', 18.4102500, 83.9029500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78962, 'Āmta', 'Amta', 'Amta,Āmta', 22.5834400, 88.0103900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78963, 'Amroli', 'Amroli', 'Amroli', 21.2508400, 72.8387800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78964, 'Amroha', 'Amroha', 'Amroha', 28.9031400, 78.4698400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78965, 'Amritsar', 'Amritsar', 'ATQ,Amricar,Amritsar,Amritsar - amritasara,Amritsar - ਅੰਮ੍ਰਿਤਸਰ,Amritsara,Amritsaras,Amritszar,Amritszár,a mu li ze,amlichaleu,amritasara,amritcar,amrtasara,amrtasarah,amrtsr,amrytsar,amrytsr,amuritosaru,xm vt sar,yamrytsar,ʼmrytsr,Амритсар,Амрицар,Амрітсар,Ամրիթսար,אמריטסר,أمريتسار,ئامریتسار,امرتسر,امريتسر,امریتسار,अमृतसर,अमृतसरः,অমৃতসর,ਅੰਮ੍ਰਿਤਸਰ,અમૃતસર,ଅମୃତସର,அம்ரித்சர்,అమృత్‌సర్,ಅಮೃತಸರ,അമൃത്‌സർ,อมฤตสาร์,ამრიტსარი,アムリトサル,阿姆利则,암리차르', 31.6223400, 74.8753400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78966, 'Amreli', 'Amreli', 'Amreli,Amrelis,amareli,amreli,amrly,amryly,an lei li,Амрели,امرلی,امریلی,अमरेली,অমরেলী,ਅਮਰੇਲੀ,અમરેલી,ଆମ୍ରେଲି,அம்ரேலி,ಅಮ್ರೇಲಿ,安雷利', 21.5998300, 71.2116900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78967, 'Amrāvati', 'Amravati', 'Amaravati,Amraoti,Amraotī,Amravati,Amrāvati', 20.9333300, 77.7500000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78968, 'Amod', 'Amod', 'Amod,Broach', 21.9931700, 72.8704700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78969, 'Ammāpettai', 'Ammapettai', 'Ammapettai,Ammāpettai', 11.6197500, 77.7426400, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78970, 'Ammāpettai', 'Ammapettai', 'Ammapet,Ammapettai,Ammāpettai', 10.7947600, 79.3198600, 'IN', '2017-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78971, 'Amloh', 'Amloh', 'Amloh', 30.6083700, 76.2319900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78972, 'Āmli', 'Amli', 'Amli,Āmli', 20.2833300, 73.0166700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78973, 'Āmlāgora', 'Amlagora', '', 22.8461600, 87.3355900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78974, 'Amla', 'Amla', 'Amla', 21.9248500, 78.1278600, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78975, 'Amguri', 'Amguri', 'Amguri', 26.8148200, 94.5261400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78976, 'Amethi', 'Amethi', '', 28.0166700, 81.0500000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78977, 'Amethī', 'Amethi', 'Amethi,Amethī', 26.1569600, 81.8051900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78978, 'Amet', 'Amet', 'Amet', 25.3060900, 73.9258000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78979, 'Ambur', 'Ambur', 'Ambur,a mu bu er,ambura,amburu,ambwr,ampur,Āmbūr,آمبور,امبور,अम्बुर,আম্বুর,ஆம்பூர்,ಆಂಬೂರು,阿姆布尔', 12.7916300, 78.7164400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78980, 'Ambikāpur', 'Ambikapur', 'Ambikapur,Ambikāpur,Surguja,Surquja', 23.1189200, 83.1953700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78981, 'Ambattūr', 'Ambattur', 'Ambattur,Ambattūr', 13.0981800, 80.1615200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78982, 'Ambasamudram', 'Ambasamudram', 'Ambasamudram,Ambassamudram,Ambāsamudram,a mu ba sa mu de la mu,ambasamudram,ambasamudrama,ambasamwdram,ampacamuttiram,امباسامودرام,अम्बसमुद्राम,আম্বাসমুদ্রম,அம்பாசமுத்திரம்,അംബാസമുദ്രം,阿姆巴萨穆德拉姆', 8.7106800, 77.4519000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78983, 'Āmbāsa', 'Ambasa', 'Ambasa,Ambassa,Āmbāsa', 23.9360000, 91.8543600, 'IN', '2016-07-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78984, 'Ambāla', 'Ambala', 'Ambala,Ambata,Ambāla', 30.3609900, 76.7978200, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78985, 'Ambājogāi', 'Ambajogai', 'Ambajogai,Ambe,Ambejogai,Ambājogāi,Mominabad,Mominābād', 18.7331200, 76.3861600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78986, 'Ambahta', 'Ambahta', '', 29.8570600, 77.3358300, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78987, 'Ambāh', 'Ambah', 'Ambah,Ambāh', 26.7042300, 78.2267800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78988, 'Ambāgarh Chauki', 'Ambagarh Chauki', 'Ambagarh Chauki,Ambagarh-Chowki,Ambāgarh Chauki', 20.7764400, 80.7460800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78989, 'Ambad', 'Ambad', '', 19.6130100, 75.7890600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78990, 'Amarwāra', 'Amarwara', 'Amarwara,Amarwāra', 22.2978000, 79.1694300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78991, 'Amarpur', 'Amarpur', 'Amarpur', 25.0396700, 86.9024700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78992, 'Amarpur', 'Amarpur', 'Amarpur', 23.5257000, 91.6587900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78993, 'Amarpātan', 'Amarpatan', 'Amarpatan,Amarpātan', 24.3137100, 80.9770300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78994, 'Amarnāth', 'Amarnath', 'Amarnath,Amarnatkh,Amarnāth,Ambarnath,Амарнатх', 19.2000000, 73.1666700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78995, 'Amarkantak', 'Amarkantak', 'Amarkantak,a ma er ka en ta ke,amarakantaka,amarakanthaka,Амаркантак,अमरकंटक,अमरकन्ठक,অমরকণ্টক,অমরকন্টকা,അമർകാണ്ടക്,阿马尔卡恩塔克', 22.6748600, 81.7590800, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78996, 'Amānpur', 'Amanpur', 'Amanpur,Amānpur', 27.7122200, 78.7378800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78997, 'Amānganj', 'Amanganj', 'Amanganj,Amānganj', 24.4266400, 80.0357900, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78998, 'Amalner', 'Amalner', 'Amalner,a ma er nei er,amalanera,amalner,amalnera,amalnr,aml nyr,آمل نیر,امالنر,अमल्नेर,अमळनेर,আমালনের,અમલનેર,ଅମଳନେର,ಅಮಲ್ನೇರ್,阿马尔内尔', 21.0398300, 75.0588700, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(78999, 'Amalāpuram', 'Amalapuram', 'Amalapuram,Amalāpuram', 16.5786800, 82.0060900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79000, 'Alwaye', 'Alwaye', 'Aluva,Alwaye,aluva,ആലുവ', 10.1064900, 76.3548400, 'IN', '2017-02-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79001, 'Ālwār Tirunagari', 'Alwar Tirunagari', 'Alvar Tirunagari,Alwar Tirunagari,Ālwār Tirunagari', 8.6051100, 77.9375400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79002, 'Alwar', 'Alwar', 'Alvar,Alvaras,Alvaro,Alwar,Alwar City,District d''Alwar,a er wa er,ala''oyara,alaraara,alavara,alawara,alvar,alvara,alvari,alwar,aruwaru,Álvaro,Алвар,الوار,अलवर,अल्वर,আলওয়ার,আলৱার,ਅਲਵਰ,અલવર,ଅଲୱର,அல்வார்,ಅಳ್ವಾರ್,ალვარი,アルワル,阿尔瓦尔', 27.5624600, 76.6250000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79003, 'Alūr', 'Alur', 'Alur,Alūr', 12.9780500, 75.9909400, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79004, 'Alot', 'Alot', 'Alot', 23.7633600, 75.5566200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79005, 'Along', 'Along', 'Along,IXV', 28.1695100, 94.8006000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79006, 'Alnāvar', 'Alnavar', 'Alnavar,Alnāvar', 15.4272700, 74.7411100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79007, 'Almora', 'Almora', 'Al''mora,Almora,a er mo la,alamoda,alamora,almoda,almora,arumora,Алмора,Альмора,المورہ,अलमोडा,अल्मोड़ा,अल्मोडा,আলমোরা,ਅਲਮੋੜਾ,અલમોડા,ఆల్మోరా,ಅಲ್ಮೋರ,അൽമോറ,アルモーラー,阿尔莫拉', 29.5971300, 79.6591100, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79008, 'Alleppey', 'Alleppey', 'Alapalli,Alapolai,Alappula,Alappuzha,Alapulai,Aleppi,Allapuza,Alleppey,Alleppi,Aulapolai,alappula,Алаппужа,ആലപ്പുഴ', 9.4900400, 76.3264000, 'IN', '2017-01-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79009, 'Allāpalli', 'Allapalli', 'Alapillai,Allapalli,Allāpalli,Alāpillai', 19.4317200, 80.0637700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79010, 'Allāhganj', 'Allahganj', 'Allahganj,Allāhganj', 27.5454000, 79.6871500, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79011, 'Allahābād', 'Allahabad', 'Alahabadas,Alla Abba Habab,Allahabad,Allahabad - ilahabada,Allahabad - इलाहाबाद,Allahābād,Allakhabad,Allāhābād,IXD,Ilahabad,Ilāhābād,Prayag,Prayāg,alakapat,an la a ba de,arahabado,elahabada,ilahabada,irahabado,Аллахабад,إلٰه‌آباد,الہ آباد,इलाहाबाद,এলাহাবাদ,அலகாபாத்,アラハバード,イラーハーバード,安拉阿巴德', 25.4447800, 81.8432200, 'IN', '2017-03-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79012, 'Alīpur', 'Alipur', '', 28.7986200, 77.1331400, 'IN', '2015-05-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79013, 'Alīgarh', 'Aligarh', 'Aligarh,Aligarkh,Alīgarh,Koil,aligara,aligarha,Алигарх,علی گڑھ,अलीगढ़,আলিগড়', 27.8814500, 78.0746400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79014, 'Alīganj', 'Aliganj', 'Aliganj,Alīganj', 27.4935800, 79.1712700, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79015, 'Alībāg', 'Alibag', 'Alibag,Alibagh,Alibágh,Alībāg', 18.6481300, 72.8757900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79016, 'Aldona', 'Aldona', 'Aldona', 15.5933700, 73.8748200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79017, 'Alāwalpur', 'Alawalpur', 'Alawalpur,Alāwalpur', 31.4316100, 75.6561400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79018, 'Ālappākkam', 'Alappakkam', 'Alapakam,Alappakkam,Ālappākkam', 11.5989500, 79.7189300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79019, 'Ālangulam', 'Alangulam', 'Alangulam,Atangulam,Ālangulam,Ātangulam', 8.8640400, 77.4993700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79020, 'Ālangudi', 'Alangudi', 'Alangudi,Ālangudi', 10.3606000, 78.9849200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79021, 'Alangāyam', 'Alangayam', 'Alangayam,Alangāyam,Ālangāyam', 12.6223500, 78.7520700, 'IN', '2016-11-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79022, 'Alangānallūr', 'Alanganallur', 'Alanganallur,Alangānallūr', 10.0469000, 78.0906100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79023, 'Alandur', 'Alandur', 'Alandoor,Alandur', 13.0025000, 80.2061100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79024, 'Alandi', 'Alandi', 'Alandi,Alandi-Devachi', 18.6775600, 73.8986800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79025, 'Aland', 'Aland', 'Aland,Alland', 17.5642500, 76.5685400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79026, 'Alampur', 'Alampur', 'Alampur', 26.0251400, 78.7969700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79027, 'Ālampur', 'Alampur', '', 15.8798700, 78.1335200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79028, 'Alagāpuram', 'Alagapuram', '', 11.8870500, 78.9175800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79029, 'Akot', 'Akot', 'Akot,a ke te,akat,akota,آکوٹ,اکات,अकोट,अकोत,অকোট,ଆକୋଟ,阿科特', 21.0963000, 77.0588000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79030, 'Akola', 'Akola', 'AKD,Akola,Akolá,a ke la,akola,akolla,akwla,Акола,اکولا,اکولہ,अकोला,অকোলা,আকোলা,ਅਕੋਲਾ,અકોલા,ଅକୋଲା,அகோலா,ಅಕೋಲಾ,阿科拉,아콜라', 20.7095700, 76.9981000, 'IN', '2017-03-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79031, 'Akodia', 'Akodia', 'Akodia', 23.3802700, 76.5987500, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79032, 'Aklera', 'Aklera', 'Akera,Aklera', 24.4128800, 76.5671900, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79033, 'Akivīdu', 'Akividu', 'Akividu,Akivīdu,Ākivīdu', 16.5822500, 81.3811200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79034, 'Akhnūr', 'Akhnur', '', 32.8666700, 74.7333300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79035, 'Akbarpur', 'Akbarpur', 'Akbarpur,Miranpur Akbarpur,Mīrānpur Akbarpur,akabarapura,akbarapuram,akbrpwr  ambdkar ngar,Акбарпур,اکبر پور، امبیڈکر نگر,اکبرپور، امبدکار نگار,अक्बरपुरम्,ਅਕਬਰਪੁਰ', 26.4295300, 82.5343100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79036, 'Akbarpur', 'Akbarpur', 'Akbarpur', 26.3837100, 79.9492600, 'IN', '2016-03-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79037, 'Akaltara', 'Akaltara', 'Akaltara', 22.0246300, 82.4264100, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79038, 'Akalkot', 'Akalkot', 'Akalkot', 17.5253200, 76.2061100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79039, 'Akālgarh', 'Akalgarh', 'Akalgarh,Akālgarh', 29.8207400, 75.8907800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79040, 'Ajra', 'Ajra', 'Ajra', 16.1160100, 74.2109700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79041, 'Ajnāla', 'Ajnala', 'Ajnala,Ajnāla', 31.8447300, 74.7629500, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79042, 'Ajmer', 'Ajmer', 'Acmer,Adzhmer,Adzmer,Adzmera,Adzmeras,Adzsmir,Adźmer,Adžmera,Adžmeras,Adžmér,Agmer,Ajmer,Ajmer City,Aĝmer,a jie mei er,ajamera,ajamira,ajimeleu,ajmer,ajmeri,ajmir,ajmyr,ajumeru,Ádzsmír,Аджмер,Аџмер,أجمير,اجمیر,اجمېر,अजमेर,অজমের,আজমির,ਅਜਮੇਰ,અજમેર,ଆଜମେର,அஜ்மீர்,అజ్మీర్,ಅಜ್ಮೇರ್,അജ്മീർ,აჯმერი,アジュメール,阿杰梅尔,아지메르', 26.4521000, 74.6386700, 'IN', '2015-10-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79043, 'Ajjampur', 'Ajjampur', '', 13.7279400, 76.0068000, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79044, 'Ajaigarh', 'Ajaigarh', 'Ajaigarh', 24.8987900, 80.2592100, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79045, 'Aizawl', 'Aizawl', 'AJL,Ai jal,Aidzhal,Aijal,Aizal,Aizavlis,Aizawl,Aizol,Aizwal,Ajzol,a''ijala,a''ijola,a''izola,ai zao er,aijali,aijaul,aijavla,aijhavala,aijhola,aijola,aizauru,aycal,ayyzwl,ayzal,ayzwal,Āīzawl,Аиджал,Аїджал,Ајзол,آئزال,آئیزول,ایزوال,आइज़ोल,आइजोल,ऐजव्ल,ऐजोल,ऐझॉल,আইজল,ਆਈਜ਼ੋਲ,ઐઝવાલ,ଆଇଜୋଲ,அய்சால்,ఐజ్‌వాల్,ഐസോൾ,აიჯალი,アイザウル,艾藻尔,아이자울', 23.7289400, 92.7179100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79046, 'Ahwa', 'Ahwa', 'Ahwa', 20.7571800, 73.6862600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79047, 'Ahraura', 'Ahraura', 'Ahraura,Ahraurā', 25.0157900, 83.0329400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79048, 'Ahmadpur', 'Ahmadpur', 'Ahmadpur', 23.8300900, 87.6866100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79049, 'Ahmadpur', 'Ahmadpur', 'Ahmadpur,Ahmedpur,Rajura,Rājūra', 18.7062200, 76.9373100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79050, 'Ahmadnagar', 'Ahmadnagar', 'Ahmadnagar,Ahmadnâgar,Ahmednagar,ahamadanagara,ahamedanagara,ahmd ngr,akamatnakar,احمد نگر,अहमदनगर,আহমেদনগর,அகமத்நகர்', 19.0945700, 74.7384300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79051, 'Ahmedabad', 'Ahmedabad', 'AMD,Achmentampant,Ahmadabad,Ahmadabadas,Ahmadabado,Ahmadobod,Ahmadábád,Ahmadābād,Ahmedabad,Ahmedabad - amadavada,Ahmedabad - અમદાવાદ,Akhmadabad,Akhmadabad shaary,Akhmedabad,Amadavad,Amdavada,Amdāvāda,Amedebatum,Exmetabad,Gorad Akhmedabad,a mei da ba de,afumadabado,aham''madabad,ahamadabada,ahamedabada,ahimadabada,ahmadabad,ahmadabadi,ahmd abad,ahmdabad,ahmdabad - hyndystan,ai ha mai da ba de,ai ha mai de bao,akamatapat,amadabadeu,amadaraada,amadavada,xah mda bad,Αχμενταμπάντ,Ахмадабад,Ахмадабад шаары,Ахмедабад,Аҳмадобод,Горад Ахмедабад,אחמדאבאד,أحمد آباد,احمد آباد,احمدآباد,احمدآباد - هیندیستان,احمداباد,अमदावाद,अहमदाबाद,অমদাৱাদ,আহমেদাবাদ,ਅਹਿਮਦਾਬਾਦ,અમદાવાદ,ଅହମଦାବାଦ,அகமதாபாத்,అహ్మదాబాద్,ಅಹ್ಮದಾಬಾದ್,അഹമ്മദാബാദ്,อัห์มดาบาด,အမယ်ဒါဘတ်မြို့,აჰმადაბადი,アフマダーバード,艾哈迈德堡,艾哈迈达巴德,阿美達巴德,아마다바드', 23.0257900, 72.5872700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79052, 'Ahiri', 'Ahiri', '', 19.4138600, 80.0035900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79053, 'Agra', 'Agra', 'AGR,Agra,Agra - agara,Agra - आगरा,Lungsod ng Agra,a ge la,agara,ageula,agra,agura,akra,Āgra,Āgrā,Агра,Аґра,אגרה,آگرہ,आगरा,আগ্রা,ஆக்ரா,ಆಗ್ರಾ,アーグラ,アーグラー,阿格拉,아그라', 27.1833300, 78.0166700, 'IN', '2016-10-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79054, 'Agartala', 'Agartala', 'Agartala,Agratala,Ajarthala,Ankartala,Aqartala,IXA,a jia er ta la,agaleutalla,agaratala,agartala,agarutara,agrtla,akartala,Αγκαρτάλα,Агартала,اگارتالا,اگرتلا,अगरतला,अगरताल,अगरताला,अगर्तला,আগরতলা,ਅਗਰਤਲਾ,અગરતલા,ଅଗରତାଲା,அகர்தலா,అగర్తలా,ಅಗರ್ತಲ,അഗർത്തല,აგარტალა,アガルタラ,阿加尔塔拉,아가르탈라', 23.8360500, 91.2793900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79055, 'Agar', 'Agar', 'Agar,Agar-agar,Агар-агар', 23.7117700, 76.0157100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79056, 'Afzalpur', 'Afzalpur', 'Afzalpur', 17.1998600, 76.3601800, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79057, 'Afzalgarh', 'Afzalgarh', 'Afzalgarh', 29.3937000, 78.6739300, 'IN', '2015-06-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79058, 'Aduthurai', 'Aduthurai', '', 11.0154200, 79.4809300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79059, 'Adūr', 'Adur', '', 9.1559500, 76.7319200, 'IN', '2017-04-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79060, 'Adra', 'Adra', 'Adra,Ādra,Адра', 23.4966800, 86.6836300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79061, 'Ādoni', 'Adoni', 'Adoni,Ādoni,Адони', 15.6278800, 77.2749500, 'IN', '2015-11-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79062, 'Ādilābād', 'Adilabad', 'Adilabad,Edlabad,Edlābād,adilabad,adilabadu,atilapat,Ādilābād,ஆதிலாபாத்,ఆదిలాబాదు,ఆదిలాబాద్', 19.6720300, 78.5359000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79063, 'Addanki', 'Addanki', 'Addanki', 15.8106100, 79.9733800, 'IN', '2017-01-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79064, 'Adalaj', 'Adalaj', 'Adalaj', 23.1645300, 72.5810700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79065, 'Achhnera', 'Achhnera', 'Achhnera,Achnera', 27.1782600, 77.7567400, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79066, 'Achalpur', 'Achalpur', 'Achalpur,Ellichpur,a qia er pu er,acalapura,accalpur,acharupuru,achlpwr,akalpwr,alacapura,اچلپور,اکالپور,अचलपूर,अलचपुर,অচলপুর,আচলপুর,ଅଚଳପୁର,அச்சல்பூர்,アチャルプル,阿恰尔普尔', 21.2566500, 77.5100600, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79067, 'Ābu Road', 'Abu Road', 'Abu Road,Ābu Road', 24.4801200, 72.7818600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79068, 'Ābu', 'Abu', 'Abu,Mount Abu,Ābu,Абу', 24.5936500, 72.7175600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79069, 'Abohar', 'Abohar', 'Abohar,a bo he er,abohara,abwhar,apohar,آبوهار,ابوہر,अबोहर,আবোহার,ਅਬੋਹਰ,அபோஹர்,阿博赫尔', 30.1445300, 74.1955200, 'IN', '2015-02-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79070, 'Abirāmam', 'Abiramam', 'Abiramam,Abirāmam', 9.4412500, 78.4406500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79071, 'Abhayāpuri', 'Abhayapuri', 'Abhayapuri,Abhayāpuri', 26.3225500, 90.6852600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79072, 'Contai', 'Contai', 'Contai', 21.7798500, 87.7489200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79073, 'Haldia', 'Haldia', 'Haldia', 22.0604600, 88.1097500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79074, 'Srirāmpur', 'Srirampur', 'Srirampur,Srirāmpur', 22.9484900, 88.0195400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79075, 'Haripur', 'Haripur', '', 22.9361100, 88.2319400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79076, 'Kesabpur', 'Kesabpur', 'Kesabpur', 22.9683300, 88.2627800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79077, 'Rāmchandrapur', 'Ramchandrapur', 'Ramchandrapur,Rāmchandrapur', 22.8963900, 88.4752800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79078, 'Bāgnān', 'Bagnan', '', 22.9333800, 88.1385600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79079, 'Rāmnagar', 'Ramnagar', '', 22.7777800, 88.2463900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79080, 'Sankarpur', 'Sankarpur', 'Sankarpur', 22.8483900, 88.4512600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79081, 'Begampur', 'Begampur', 'Begampur', 22.7307000, 88.2576400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79082, 'Parbatipur', 'Parbatipur', '', 22.6625000, 88.2222200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79083, 'Bhandārdaha', 'Bhandardaha', 'Bhandardaha,Bhandārdaha', 22.6147600, 88.1919000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79084, 'Dumjor', 'Dumjor', 'Domjur,Dumjor', 22.6199300, 88.2456600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79085, 'Krishnapur', 'Krishnapur', 'Krishnapur', 22.6702800, 88.2694400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79086, 'Bankra', 'Bankra', 'Bankra', 22.6029100, 88.2775100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79087, 'Chakapara', 'Chakapara', 'Chakapara,Chakpara', 22.6322200, 88.3486100, 'IN', '2016-07-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79088, 'Mahiari', 'Mahiari', 'Mahiari', 22.5882600, 88.2354400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79089, 'Masila', 'Masila', '', 22.5808300, 88.2327800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79090, 'Dhulagari', 'Dhulagari', '', 22.5821300, 88.1710000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79091, 'Pānchla', 'Panchla', 'Panchla,Pānchla', 22.5366500, 88.1378500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79092, 'Sāhāpur', 'Sahapur', 'Sahapur,Sāhāpur', 22.5244400, 88.1669400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79093, 'Raghudebbati', 'Raghudebbati', 'Raghudebbati', 22.5255600, 88.1958300, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79094, 'Gobindapur', 'Gobindapur', '', 22.5930600, 88.0913900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79095, 'Nangi', 'Nangi', '', 22.5083300, 88.2152800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79096, 'Pujali', 'Pujali', 'Pujali', 22.4711000, 88.1453000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79097, 'Amtala', 'Amtala', 'Amtala', 22.3704600, 88.2786400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79098, 'Bāwāli', 'Bawali', '', 22.4256300, 88.1933600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79099, 'Balarāmpur', 'Balarampur', '', 22.3341700, 88.2977800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79100, 'Jāfarpur', 'Jafarpur', 'Jafarpur,Jāfarpur', 22.3187800, 88.2305000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79101, 'Serpur', 'Serpur', 'Serpur', 22.3234400, 88.3077500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79102, 'Monoharpur', 'Monoharpur', 'Monoharpur', 22.1083300, 88.0788900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79103, 'Solap', 'Solap', '', 22.1277800, 88.1586100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79104, 'Harindānga', 'Harindanga', 'Harindanga,Harindānga', 22.0383300, 88.3213900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79105, 'Gurdaha', 'Gurdaha', '', 22.7347200, 88.7594400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79106, 'Ula', 'Ula', '', 22.7225000, 88.5555600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79107, 'Gopālpur', 'Gopalpur', '', 22.6184500, 88.7511900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79108, 'Raypur', 'Raypur', '', 22.4108300, 88.5094400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79109, 'Nabagrām', 'Nabagram', 'Nabagram,Nabagrām', 22.2880600, 88.5091700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79110, 'Soyībug', 'Soyibug', '', 34.0767700, 74.7057000, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79111, 'Jauriān', 'Jaurian', '', 32.8325500, 74.5761200, 'IN', '2015-09-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79112, 'Chīma', 'Chima', '', 30.6854000, 76.0864300, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79113, 'Kheri Sāmpla', 'Kheri Sampla', '', 28.7781000, 76.7756000, 'IN', '2015-01-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79114, 'Gho Brāhmanān de', 'Gho Brahmanan de', 'Gho Brahmanan,Gho Brahmanan de,Gho Brāhmanān,Gho Brāhmanān de,Gho Manhasan,Gho Manhāsān', 32.5559000, 74.9539000, 'IN', '2015-08-07', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79115, 'Chhutmalpur', 'Chhutmalpur', 'Chhutmalpur', 30.0320900, 77.7532900, 'IN', '2015-04-08', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79116, 'Borkhera', 'Borkhera', '', 25.5211500, 75.6402800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79117, 'Singāpur', 'Singapur', 'Singapur,Singāpur', 17.4698200, 78.1257400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79118, 'Bālāpur', 'Balapur', '', 17.3101800, 78.4996900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79119, 'Ghatkesar', 'Ghatkesar', 'Ghatkesar', 17.4508100, 78.6836600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79120, 'Chandūr', 'Chandur', 'Chandur,Chandūr', 17.8745500, 78.1001700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79121, 'Vadigenhalli', 'Vadigenhalli', 'Vadigenhalli,Vijayapura', 13.2972400, 77.8018400, 'IN', '2016-09-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79122, 'Ādampur', 'Adampur', 'Adampur,Ādampur', 31.4322400, 75.7148400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79123, 'Chinnasekkadu', 'Chinnasekkadu', 'Chinnasekkadu', 13.1608900, 80.2572700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79124, 'Porur', 'Porur', 'Porur,bo lu er,porur,porura,পোরুর,போரூர்,波鲁尔', 13.0356500, 80.1582100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79125, 'Manappakkam', 'Manappakkam', '', 13.0108300, 80.1686100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79126, 'Madipakkam', 'Madipakkam', 'Madipakkam', 12.9622600, 80.1986400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79127, 'Perungudi', 'Perungudi', 'Perungudi', 12.9609500, 80.2409400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79128, 'Vengavasal', 'Vengavasal', '', 12.8991100, 80.1690000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79129, 'Nandambakkam', 'Nandambakkam', '', 12.9779500, 80.0678100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79130, 'Madambakkam', 'Madambakkam', 'Madambakkam', 12.8525000, 80.0466700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79131, 'Vellānūr', 'Vellanur', 'Vellanur,Vellānūr', 13.1580400, 80.1063400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79132, 'Kupwāra', 'Kupwara', 'Kopawor,Kupwara,Kupwāra', 34.0305600, 74.2641700, 'IN', '2012-01-20', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79133, 'Powai', 'Powai', 'pancakutira,pava''i,पंचकुटिर,पवई', 19.1164000, 72.9047100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79134, 'Navi Mumbai', 'Navi Mumbai', 'Marathi  Maharashtra,Navi Moembaai,Navi Mumbai,Navi Mumbaj,Nova Bombaim,Novmumbajo,bmbyy nw,na''oyi mumba''i,nabi mumba''i,nabimumbai,nabimunbai,narai mumba''i,navi mumba''i,navi mumbai,navi mumbayi,navi mumpai,nawy mwmbay,nwy mmbyy,xin meng mai,Нави Мумбаи,Нави Мумбај,נבי מומבאי,بمبئی نو,ناوي مومبای,نوی ممبئی,नवि मुम्बई,नवी मुंबई,নাওয়ি মুম্বাই,নৱি মুম্বাই,નવી મુંબઈ,ନବି ମୁମ୍ବାଇ,நவி மும்பை,ನವೀ ಮುಂಬಯಿ,നവി മുംബൈ,ナビムンバイ,新孟買,나비뭄바이', 19.0368100, 73.0158200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79135, 'Auroville', 'Auroville', 'Aurorurbo,Aurovil,Aurovil'',Auroville,Aŭrorurbo,arovil,arovile,li ming zhi cun,orovila,orovu~iru,Ауровил,Ауровиль,Ауровіль,אורוויל,अरोविले,ओरोविल,ஆரோவில்,ఆరోవిల్,ഓറോവിൽ,オーロヴィル,黎明之村', 12.0054900, 79.8088500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79136, 'Puttaparthi', 'Puttaparthi', 'PUT,Puttaparthi,Puttaparti,putapaleuti,puttaparthi,puttaparti,puttaparti mandala,puttapartti,puttaparuti,Путтапарти,پوٹاپرتی,पुट्टपर्ति मण्डल,पुट्टपर्ती,पुट्टपर्थी,पुट्टपार्थी,புட்டபர்த்தி,పుట్టపర్తి,ಪುಟ್ಟಪರ್ತಿ,പുട്ടപർത്തി,プッタパルティ,푸타파르티', 14.1652000, 77.8117000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79137, 'Panchkula', 'Panchkula', 'Panchkula,Panchkula Urban Estate,Pusat Bandar Panchkula,bantshkwla,pancakula,pancakula upa sahara,Панчкула,بانتشكولا,پنج‌کولا,पंचकुला,पञ्चकुला,পঞ্চকুলা উপ শহর,ପଞ୍ଚକୁଲା,ಪಂಚಕುಲ', 30.6946100, 76.8504000, 'IN', '2017-05-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79138, 'Canacona', 'Canacona', 'Kanakona,Канакона', 14.9959000, 74.0505600, 'IN', '2010-06-23', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79139, 'Abhaneri', 'Abhaneri', '', 27.0074300, 76.6076000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79140, 'Chowari', 'Chowari', '', 32.4319000, 76.0120000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79141, 'Murudeshwara', 'Murudeshwara', 'Murudeshvara,Мурудешвара', 14.0943000, 74.4845000, 'IN', '2010-07-26', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79142, 'Shivaji Nagar', 'Shivaji Nagar', '', 18.5301700, 73.8526300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79143, 'Greater Noida', 'Greater Noida', 'Didzioji Noida,Didžioji Noida,Velika Nojda,gretara no''eda,noyta perunakar,Велика Нойда,گریٹر نوئیڈا,ग्रेटर नोएडा,நொய்டா பெருநகர்', 28.4961500, 77.5360100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79144, 'Mohali', 'Mohali', '', 30.6799500, 76.7221100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79145, 'Banbasa', 'Banbasa', 'Banbasa,Банбаса', 28.9913200, 80.0760800, 'IN', '2010-01-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79146, 'vadlamuru', 'vadlamuru', '', 17.0954500, 82.1656500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79147, 'Pithampur', 'Pithampur', '', 22.6019700, 75.6964900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79148, 'Barbil', 'Barbil', '', 21.6568500, 85.6434900, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79149, 'Airoli', 'Airoli', '', 19.1509600, 72.9962500, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79150, 'Aluva', 'Aluva', 'alubha,alura,aluva,alwa,آلوا,अलुवा,आलुव,আলুভা,আলুৱ,ஆலுவா,ಅಲುವ,ആലുവ', 10.1076400, 76.3515800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79151, 'Kotkapura', 'Kotkapura', '', 30.5819000, 74.8329800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79152, 'Muvattupuzha', 'Muvattupuzha', 'mu wa te tu pu zha,mubattupujha,mubattupuyha,muvarruppulai,muvarrupula,muvattupujha,muvattupusa,موواٹوپوژا,मुवात्तुपुझा,मूवाट्टुपुषा,মুবাত্তুপুয্হ,ମୁବାତ୍ତୁପୁଝା,மூவாற்றுப்புழை,മൂവാറ്റുപുഴ,穆瓦特图普扎', 9.9798500, 76.5738100, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79153, 'Perumbavoor', 'Perumbavoor', 'pei lu mu ba wo ao er,perumbabhura,perumbaraura,perumpavur,pyrwmbawwr,پیرومباوور,পেরুম্বৱূর,ପେରୁମ୍ବାଭୁର,பெரும்பாவூர்,പെരുമ്പാവൂർ,佩鲁姆巴沃奥尔', 10.1069500, 76.4736600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79154, 'Vapi', 'Vapi', 'Wapi,Wāpi,bapi,vapi,vappi,wapy,wpy,واپی,وپی,वापि,वापी,বাপি,વાપી,வாப்பி', 20.3717500, 72.9049300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79155, 'Baddi', 'Baddi', '', 30.9578300, 76.7913600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79156, 'Noida', 'Noida', 'Naveen,New Okhla Industrial Development Authority,Noida,Nojda,neayda,no''eda,no''era,no''ida,noyada,noyida,noyta,nuo yi da,nwyda,Ноида,Нойда,نوئدا,نوئیڈا,نويډا,نویدا,नोइडा,नोएडा,नोयडा,নোইদা,ਨੋਇਡਾ,નોઇડા,ନୋଏଡ଼ା,நொய்டா,నోయిడా,നോയ്ഡ,诺伊达', 28.5800000, 77.3300000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79157, 'Bhiwadi', 'Bhiwadi', '', 28.2102400, 76.8605600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79158, 'Parwanoo', 'Parwanoo', '', 30.8371600, 76.9614300, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79159, 'Jorethang', 'Jorethang', '', 27.1069600, 88.3233200, 'IN', '2010-02-22', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79160, 'Mandideep', 'Mandideep', 'Manideep', 23.0816600, 77.5332800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79161, 'Singrauli', 'Singrauli', 'Singrauli,singara''uli,singarauli,sinra''uli,sngrawly,syngrawly,xin ge lao li,Синграули,سنگراؤلی,سینگراولی,सिंगरौली,সিংরাউলি,ସିଙ୍ଗରାଉଲି,辛格劳利', 24.1997300, 82.6753500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79162, 'Edakkulam', 'Edakkulam', 'etakkulam,എടക്കുളം', 10.6102000, 76.1835200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79163, 'Avanoor', 'Avanoor', '', 10.6082600, 76.1762000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79164, 'Baga', 'Baga', '', 15.5651700, 73.7551700, 'IN', '2017-07-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79165, 'Birpara', 'Birpara', '', 26.7042100, 89.1454700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79166, 'Jaigaon', 'Jaigaon', '', 26.8476600, 89.3755800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79167, 'Palackattumala', 'Palackattumala', '', 9.7435600, 76.6294000, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79168, 'Periyapattinam', 'Periyapattinam', 'periyapattinam,பெரியபட்டினம்', 9.2726300, 78.9023200, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79169, 'Pitampura', 'Pitampura', 'Pitam Pura,Pitampura,Pītāmpura', 28.6896400, 77.1312600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79170, 'Vagator', 'Vagator', 'Vagator,Вагатор', 15.5976600, 73.7449600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79171, 'Akkarampalle', 'Akkarampalle', '', 13.6500000, 79.4200000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79172, 'Bellampalli', 'Bellampalli', 'Bellampalle,bellampalli,బెల్లంపల్లి', 19.0557700, 79.4930000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79173, 'Chemmumiahpet', 'Chemmumiahpet', '', 15.8979400, 79.3212900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79174, 'Gaddi Annaram', 'Gaddi Annaram', 'Gaddi Annaram,Gaddiannaram', 17.3668700, 78.5242000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79175, 'Dasnapur', 'Dasnapur', '', 19.6539900, 78.5121300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79176, 'Kanuru', 'Kanuru', '', 16.2858400, 81.2546400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79177, 'Lal Bahadur Nagar', 'Lal Bahadur Nagar', 'L.B.Nagar,Lal Bahadur Nagar,Lalbahadur Nagar', 17.3476900, 78.5575700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79178, 'Malkajgiri', 'Malkajgiri', 'ma er ka jie ji li,makajgyry,malakajagiri,malkajaganja,mlkajgyry,ماکاجگیری,ملکاجگیری,मल्कजगञ्ज,মালকাজগিরি,మల్కాజ్‌గిరి,马尔卡杰吉里', 17.4478100, 78.5263300, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79179, 'Mandamarri', 'Mandamarri', 'mandamarri,మందమర్రి', 18.9650600, 79.4747500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79180, 'Chinnachowk', 'Chinnachowk', 'Chinna Chowk,Chinnachowk', 14.4751600, 78.8354000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79181, 'Kyathampalle', 'Kyathampalle', '', 19.6678100, 78.5289000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79182, 'Gajuwaka', 'Gajuwaka', 'gajuvaka,గాజువాక', 17.7000000, 83.2166700, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79183, 'Manuguru', 'Manuguru', 'Manugur,Manuguru', 17.9810200, 80.7547000, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79184, 'Kalyandurg', 'Kalyandurg', 'Kalyandrug,Kalyandurg,Kalyāndrug,kalyandurg,kalyāndurg', 14.5451900, 77.1055200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79185, 'Ponnur', 'Ponnur', '', 16.0711400, 80.5494400, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79186, 'Quthbullapur', 'Quthbullapur', 'Quthbullapur,Qutubullapur', 17.5010700, 78.4581800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79187, 'Ramanayyapeta', 'Ramanayyapeta', '', 16.9451600, 82.2385000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79188, 'Palwancha', 'Palwancha', 'Paloncha,Palwancha', 17.5815200, 80.6765100, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79189, 'Barpeta Road', 'Barpeta Road', '', 26.5028400, 90.9693700, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79190, 'Sathupalli', 'Sathupalli', '', 17.2496800, 80.8689900, 'IN', '2014-10-12', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79191, 'Yanamalakuduru', 'Yanamalakuduru', 'Yanamalakuduru,Yenamalakuduru', 16.4853100, 80.6674600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79192, 'Morigaon', 'Morigaon', 'Marigaon,Morigaon', 26.2490800, 92.3476400, 'IN', '2016-06-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79193, 'Naharlagun', 'Naharlagun', '', 27.1046700, 93.6951800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79194, 'Serilingampalle', 'Serilingampalle', 'Serilingampalle,Serilingampally', 17.4931300, 78.3019600, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79195, 'Silapathar', 'Silapathar', 'Silapather', 27.5944100, 94.7240200, 'IN', '2016-12-09', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79196, 'Sarupathar', 'Sarupathar', '', 26.2060000, 96.8100000, 'IN', '2016-12-01', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79197, 'Lumding Railway Colony', 'Lumding Railway Colony', 'Kumding,Lumding,Lumding Railway Colony', 25.7490300, 93.1699800, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79198, 'Aistala', 'Aistala', '', 23.1800000, 88.5800000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79199, 'Ashoknagar Kalyangarh', 'Ashoknagar Kalyangarh', '', 22.8641600, 88.6370100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79200, 'Bahula', 'Bahula', '', 23.6517600, 87.1647500, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79201, 'Pavuluru', 'Pavuluru', '', 15.8529200, 80.1646800, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79202, 'pedda nakkalapalem', 'pedda nakkalapalem', '', 15.8668000, 80.1620200, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79203, 'Jhulasan', 'Jhulasan', '', 23.3286000, 72.4731400, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79204, 'Bhawanipur', 'Bhawanipur', '', 26.4535200, 87.0274400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79205, 'Zira', 'Zira', 'qi la,زیرا، بھارت,齐拉', 30.9685300, 74.9910600, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79206, 'Nangilickondan', 'Nangilickondan', '', 12.2553900, 79.4750800, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79207, 'Artist Village', 'Artist Village', '', 19.0322700, 73.0427600, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79208, 'Ramagundam', 'Ramagundam', 'RMD,Ramagundam,la ma gu en da mu,ramagndm,ramagundam,ramagundam mandala,ramagundama,ramagwndam,ramakuntam,Рамагундам,راماگندم,راماگوندام,راماگڈم,रामगुंडं मण्डल,রামগুন্দম,ରାମଗୁଣ୍ଡମ,ராமகுண்டம்,రామగుండం,拉马古恩达姆', 18.7550000, 79.4740000, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79209, 'Govindapuram,Chilakaluripet,Guntur', 'Govindapuram,Chilakaluripet,Guntur', '', 16.1547700, 80.1027900, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79210, 'Cherpulassery', 'Cherpulassery', '', 10.8765500, 76.3093200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79211, 'Kagaznāgār', 'Kagaznagar', 'Kagaznagar,Kagaznāgār', 19.3315900, 79.4660500, 'IN', '2014-10-10', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79212, 'Kirandul', 'Kirandul', '', 18.6364900, 81.2582700, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79213, 'Dayapar', 'Dayapar', '', 23.6337100, 68.9019200, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79214, 'Paikpara', 'Paikpara', '', 24.7712100, 87.9225100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79215, 'Shiraguppi', 'Shiraguppi', '', 16.6187500, 74.7090700, 'IN', '2014-03-03', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79216, 'Bishnupur', 'Bishnupur', '', 24.6284500, 93.7617900, 'IN', '2014-10-13', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79217, 'V.S.K.Valasai (Dindigul-Dist.)', 'V.S.K.Valasai (Dindigul-Dist.)', 'V.S.K.Valasai,V.S.K.Valasai (Dindigul-Dist.),В.С.К.Валасаи', 10.3154900, 78.1514100, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79218, 'Gangadharpur', 'Gangadharpur', 'Gangadharpur,gangadharapura,গঙ্গাধরপুর', 22.7600000, 88.2200000, 'IN', '2017-03-28', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79219, 'Neemuch', 'Neemuch', 'Nimach,nei ai mu qi,nimac,nimaca,nimuca,nymwch,نیموچ,नीमच,নীমুচ,ନୀମଚ,நீமச்,内埃穆奇', 24.4763900, 74.8624100, 'IN', '2014-05-01', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79220, 'Dasarahalli', 'Dasarahalli', '', 13.0990400, 77.8320400, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79221, 'Neelankarai', 'Neelankarai', '', 12.9495000, 80.2592000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79222, 'Injambakkam', 'Injambakkam', '', 12.9162000, 80.2488000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79223, 'Palavakkam', 'Palavakkam', '', 12.9535000, 80.2572000, 'IN', '2014-10-14', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79224, 'Kultali', 'Kultali', '', 21.9000000, 88.4000000, 'IN', '2014-10-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79225, 'Mushalpur', 'Mushalpur', '', 26.5792000, 91.4261000, 'IN', '2014-10-24', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79226, 'Shahbazpur', 'Shahbazpur', 'Shahbazpur,sahabajapura,shaہbazpwr,شاہبازپور,शाहबाजपुर', 26.3051100, 87.2886500, 'IN', '2016-04-20', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79227, 'Bhagirathpur', 'Bhagirathpur', '', 26.2695000, 86.0634600, 'IN', '2014-12-01', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79228, 'Kumbalam', 'Kumbalam', '', 9.9063000, 76.3112700, 'IN', '2015-08-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79229, 'Aroor', 'Aroor', '', 9.8694000, 76.3049800, 'IN', '2015-08-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79230, 'Kadakkavoor', 'Kadakkavoor', '', 8.6792100, 76.7671400, 'IN', '2015-08-19', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79231, 'Kalavoor', 'Kalavoor', '', 9.5704600, 76.3275600, 'IN', '2015-08-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79232, 'Kalamassery', 'Kalamassery', '', 10.0614000, 76.3263100, 'IN', '2015-09-04', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79233, 'Akasahebpet', 'Akasahebpet', '', 17.5045500, 82.5659700, 'IN', '2016-02-11', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79234, 'Cherthala', 'Cherthala', '', 9.6844400, 76.3355800, 'IN', '2015-09-16', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79235, 'Kunnumma', 'Kunnumma', '', 9.3567200, 76.4134300, 'IN', '2015-09-18', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79236, 'Abrama', 'Abrama', '', 20.8586500, 72.9064800, 'IN', '2016-03-25', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79237, 'Hawai', 'Hawai', '', 27.8867700, 96.8017000, 'IN', '2016-06-06', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79238, 'Longleng', 'Longleng', '', 26.4898900, 94.8177200, 'IN', '2016-06-24', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79239, 'Malkapur', 'Malkapur', '', 17.2621400, 74.1757400, 'IN', '2016-06-21', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79240, 'Garha Brahman', 'Garha Brahman', '', 23.8687300, 77.3573100, 'IN', '2016-10-17', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79241, 'Sector', 'Sector', '', 28.5708000, 77.3261000, 'IN', '2017-03-27', 103);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79376, 'Shahrak', 'Shahrak', 'Shahrak,Shahrak-e Taleqan,Shahrak-e Ţāleqān,Taleqan,Tāleqān,shhrk,shhrk talqan,taliqan,talqan,Ţāleqān,تالِقان,شهرك,شهرک طالقان,طالقان', 36.1744900, 50.7690800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79242, 'Zāwītah', 'Zawitah', 'Zawete,Zawita,Zawita-i Zheri,Zawitah,Zawite,Zawête,Zawîte,Zāwīta,Zāwīta-i Zhērī,Zāwītah,zawytt,zawytە,زاويتة,زاويتە,زاوێتە', 36.9056800, 43.1432400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79243, 'Zaxo', 'Zaxo', 'Qada'' Zakhu,Qaḑā’ Zākhū,Zakhaw,Zakho,Zakhu,Zakhu Qadha'',Zaxo,Zaxu,Zākhaw,Zākhū,Zākhū Qadhā’,qdaʾ zakhw,zakhw,Заху,زاخو,زاخۆ,قضاء زاخو', 37.1487100, 42.6859100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79244, 'Umm Qaşr', 'Umm Qasr', 'Omolgasr,Um Kasr,Umm Qasr,Umm Qaşr,am qsr,ام قصر', 30.0362000, 47.9195100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79245, 'Tozkhurmato', 'Tozkhurmato', 'Khurmati,Touz Hourmato,Tozkhurmato,Tozkhurmatu,Tuz,Tuz Kermatli,Tuz Khurmatli,Tuz Khurmatu,Tuz Khurmatu District,Tuz Xurmatu,Tuzkhurmatu,twz,twz khwrmatw,twzkhwrmatw,Ţūz,Ţūz Khūrmātū,Ţūzkhūrmātū,توزخورماتو,طوز,طوز خورماتو,طوزخورماتو', 34.8880800, 44.6325600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79246, 'Tikrīt', 'Tikrit', 'Tekrit,Tikret,Tikrit,Tikritas,Tikrīt,Tıkrit,ti ke li te,tikurito,tkryt,tykryt,Тикрит,תיכרית,تكريت,تکریت,ティクリート,提克里特', 34.6158100, 43.6786100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79247, 'Dāqūq', 'Daquq', 'Daquq,Dāqūq,Tauk,Tauq,Tawud,Tawuq,daqwq,Ţāwūd,Ţāwūq,داقوق', 35.1392300, 44.4490700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79248, 'Tallkayf', 'Tallkayf', 'Qada'' Talkif,Qada'' Tallkayf,Qaḑā’ Talkīf,Qaḑā’ Tallkayf,Tall Kaif,Tall Kayf,Tall''-Kajf,Tallkayf,Tel Kaif,Tilkayf,tlkyf,Талль-Кайф,تلكيف,قضاء تلكيف', 36.4911800, 43.1211400, 'IQ', '2017-07-04', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79249, 'Tall ‘Afar', 'Tall ''Afar', 'Tal Afar,Tal `Afar,Tal ‘Afar,Tala''afar,Tall `Afar,Tall ‘Afar,Tall`afar,Tall‘afar,Tel Afar,Tele`fer,Tele‘fer,tl ʿfr,تل عفر,تلعفر,تەلەعفەر', 36.3791300, 42.4480600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79250, 'Sūq ash Shuyūkh', 'Suq ash Shuyukh', 'Shuyukh,Shuyūkh,Suq al-Shyukh,Suq ash Shaykh,Suq ash Shuyukh,Sūq ash Shaykh,Sūq ash Shuyūkh,swq alshywkh,سوق الشيوخ', 30.8908600, 46.4542500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79251, 'Saymayl', 'Saymayl', 'Samil,Samīl,Saymayl,Semel,Simayl,Simel,Sumayl,Sumel,Summail,Summayl,Summel,Summēl,Sumêl,Sêmêl,Sīmayl,smyl,symyl,sێmێl,سميل,سومێل,سيميل,سێمێل', 36.8582300, 42.8482000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79252, 'Sīnah', 'Sinah', 'Sina,Sinah,Sine,Sîne,Sīnah,Sīnā,synt,سينة,سينە', 36.8075200, 43.0383100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79253, '‘Ayn Tamr', '''Ayn Tamr', 'Shetata,Shetateh,Shifatha,Shifathah,Shifatheh,Shitata,Shitathah,Shithatha,Shithathah,Shithātha,Shithāthah,`Ayn Tamr,`Ayn at Tamr,shthatht,ʿyn altmr,شثاثة,عين التمر,عين تمر,‘Ayn Tamr,‘Ayn at Tamr', 32.5668700, 43.4881500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79254, 'Ash Sharqāt', 'Ash Sharqat', 'Ash Sharqat,Ash Sharqāt,Sharqat,Sharqāt,alshrqat,الشرقاط', 35.5172200, 43.2280600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79255, 'Shaqlāwah', 'Shaqlawah', 'Shaglawa,Shaglāwa,Shaklawa,Shaqlawa,Shaqlawah,Shaqlāwa,Shaqlāwah,Sheqlawe,Sheqławe,shqlawt,شقلاوة,شەقڵاوە', 36.4042200, 44.3256300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79256, 'Seyid Sadiq', 'Seyid Sadiq', 'Said Sadiq,Saiyid Sadiq,Sayyid Sadiq,Sayyid Şādiq,Seyd Sadiq,Seyd Şadiq,Seyid Sadiq,Seyid Şadiq,Seyyed Sadeq,Seyyed Şādeq,syd sadq,سيد صادق,سیّد صادق,سەيد سادق,سەيد صادق', 35.3527800, 45.8668200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79257, 'Sāmarrā’', 'Samarra''', 'Saimarreh,Samara,Samarra,Samarra'',Samarrah,Sāmarrah,Sāmarrā’,سامراء', 34.1959000, 43.8856800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79258, 'Nāḩīyat Saddat al Hindīyah', 'Nahiyat Saddat al Hindiyah', 'Al Hindiyah,Al Hindīyah,Hindiya,Hindīya,Nahiyat Saddat al Hindiyah,Nāḩiyat Saddat al Hindīyah,Nāḩīyat Saddat al Hindīyah,Qaryat Saddat al Hindiyah,Qaryat Saddat al Hindīyah,Saddat al Hindiyah,Saddat al Hindīyah,nahyt sdt alhndyt,sdt alhndyt,سدة الهندية,ناحية سدة الهندية', 32.7155700, 44.2785700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79259, 'Ruwāndiz', 'Ruwandiz', 'Ravanduz,Rawandiz,Rawandoz,Rawanduz,Rawanduze,Rawndoz,Rawāndiz,Revandis,Rewandus,Rewanduz,Roandiz,Roanduz,Rowanduz,Rowandūz,Ruwan Duz,Ruwandiz,Ruwanduz,Ruwāndiz,Ruwāndūz,Rāwandūz,rawndwz,rwandz,Равандуз,راوندوز,رواندز,ڕwandz,ڕواندز,ڕەwandwz,ڕەواندوز,Ṟewanduz,Ṟuwandiz', 36.6120700, 44.5237200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79260, 'Rāwah', 'Rawah', 'Rawa,Rawah,Rāwah,rawt,راوة', 34.4822900, 41.9189800, 'IQ', '2016-06-27', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79261, 'Ṟaniye', 'Raniye', 'Rania,Raniya,Raniyah,Raniye,Raniyeh,Ranya,Ranyah,Ranye,Rānia,Rāniyah,Rānya,Rānyah,Rānīyah,ranyt,رانية,ڕانيە,Ṟaniye,Ṟanye', 36.2551100, 44.8823900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79262, 'Al Qā’im', 'Al Qa''im', 'Al Qa''im,Al Qā’im,Al-Qaim,Dulaym al Husaybah,Dulaym al Ḩusaybah,El Kaim,El Qa''im,El Qa’im,Hsaiba,Husaybah,Kasibah,Kaşībah,Kseba,Markaz Qada` al Qa`im,Markaz Qaḑā‘ al Qā‘im,Qsiba,Qsībā,Qusaybah,Quşaybah,alqaym,hsybt,القائم,حصيبة,مركز قضاء القائم,Ḩuşaybah', 34.3925100, 40.9894500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79263, 'Al-Hamdaniya', 'Al-Hamdaniya', 'Al Hamdaniya,Al Hamdaniyah,Al-Hamdaniya District,Qada'' al Hamdaniyah,Qarah Qosh,Qarah Qush,Qarah Qōsh,Qarah Qūsh,Qaraqosh,Qaraqush,Qaḑā’ al Ḩamdānīyah,قضاء الحمدانية', 36.2709300, 43.3775800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79264, 'Qeredagh', 'Qeredagh', 'Qara Dagh,Qaradagh,Qaradgh,Qaradāgh,Qarah Dagh,Qarah Dāgh,Qere Dagh,Qeredagh,qrdagh,qrh dagh,qrt dagh,qەrەdagh,قرة داغ,قرداغ,قره داغ,قەرەداغ', 35.3071000, 45.3906000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79265, 'Qal‘at Şāliḩ', 'Qal''at Salih', 'Kala Salih,Kalaat Saleh,Kale Sale,Qal`at Salih,Qala Salih,Qalat Saleh,Qal‘at Şāliḩ,Shatra el Amara,Shatrat al `Amara,Shatrat al ‘Amāra,Shatret el `Amareh,Shatret el ‘Amareh,قلعة صالح', 31.5280200, 47.2936200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79266, 'Qeładizê', 'Qeladize', 'Dizah,Qal`at Dizah,Qala Diza,Qala Dizeh,Qala Dīzeh,Qaladiz,Qaladiza,Qaladizay,Qaladizi,Qaladza,Qalā Diza,Qalādizay,Qalādizī,Qal‘at Dizah,Qeladize,Qeładize,Qeładizê,qladzy,qەڵadzێ,qەڵadzە,قلادزي,قلعة دزة,قەڵادزێ,قەڵادزە', 36.1853600, 45.1273500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79267, 'Mêrgasur', 'Mergasur', 'Mayrkah Sur,Mayrkah Sūr,Mayrkasur,Mayrkasūr,Merga Soor,Merga Sor,Merga Sor-i-Zhori,Mergasur,Mergasur Upper,Mergasur-i Zheri,Merge Sur,Mirga Sur,Mirkah Sur,Mirkah Sūr,Mêrgasur,Mêrge Sur,Mêrge Sûr,Mērgasūr-i Zhērī,myrkh swr,myrkswr,mێrgە swr,mێrgە swwr,mێrgەswr,ميركسور,ميركه سور,مێرگە سور,مێرگە سوور,مێرگەسور', 36.8430800, 44.3009400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79268, 'Mawet', 'Mawet', 'Mawat,Mawet,Māwat,mawt,mawەt,ماوت,ماوەت', 35.9012000, 45.4130100, 'IQ', '2016-06-27', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79269, 'Mandalī', 'Mandali', 'Mandali,Mandalī,Mendali,Mendeli,Mendéli,mndly,Мандали,مندلي', 33.7481000, 45.5550300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79270, 'Mexmur', 'Mexmur', 'Makhmur,Makhmūr,Mexmur,Mexmûr,Mokhmur,mkhmwr,mەkhmwr,مخمور,مەخمور,مەخموور', 35.7762200, 43.5797400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79271, 'Koysinceq', 'Koysinceq', 'Kawiyah,Kawīyah,Koi Sanjaq,Koisnjaq,Kou Senaq,Kou Senjaq,Koy Senjaq,Koye,Koysinceq,Koysinjaq,Kuwaysinjaq,Kuyah,Kuysinjaq,Kūyah,Kūysinjaq,kwysnjq,kwyt,كوية,كويسنجق,كۆيسنجەق,كۆيە', 36.0828900, 44.6287300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79272, 'Kifrī', 'Kifri', 'Kiffri,Kiffrī,Kifri,Kifrî,Kifrī,Kufri,Kufrī,Salahie,Salahiya,Salahiyeh,Sallahiya,Sallahiyah,Salāhīya,Zeng Abad,Zeng Ābād,kfry,Кифри,كفرى,كفري', 34.6896300, 44.9605700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79273, 'Khānaqīn', 'Khanaqin', 'Kanaqin,Khanaqeen,Khanaqin,Khaneqeyn,Khaneqin,Khanikin,Khaniqin,Khānaqīn,Khāneqeyn,Khāneqīn,Xaneqin,Xaneqîn,khanqyn,khanەqyn,خانقين,خانەقين', 34.3482000, 45.3906500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79274, 'Kirkuk', 'Kirkuk', 'KIK,Karkh Slukh,Karkuk,Karkúk,Karkūk,Kerkouk,Kerkuek,Kerkuk,Kerkûk,Kerkük,Kirkoek,Kirkouk,Kirkuk,Kirkukas,Kirkúk,Kirkūk,Kərkük,ji er ku ke,khir khuk,kileukukeu,kirukuku,krk slwk,krkwk,kyrkwk,Κιρκούκ,Киркук,Кіркук,Кәркүк,Քիրքուք,כירכוכ,كركوك,كه‌ركووك,كەركوك,کرکوک,کەرکووک,ܟܪܟ ܣܠܘܟ,കിർകുക്ക്,คีร์คูก,კირკუკი,キルクーク,基爾庫克,키르쿠크', 35.4680600, 44.3922200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79275, 'Karbala', 'Karbala', 'Gorad Kerbela,Karbala,Karbala'',Karbalaa,Karbalo,Karbalá,Karbalā’,Karbila,Karmpala,Kerbala,Kerbela,Kərbəla,Meshed Hussain,Meshed Hussein,Nainawa,Qerbelaja,Shathi''ul-Furat,Vilojati Karbalo,al-Ghadiriya,ka er ba la,kaleuballa,karabala,karbala,karpala,karubara,karubara xian,krbla,ktrbala,Καρμπάλα,Вилояти Карбало,Горад Кербела,Карбала,Кербала,Кербела,Քերբելա,כרבלא,מחוז כרבלא,كةربالا,كربلاء,محافظة كربلاء,کربلا,کەربەلا,ڪربلا,करबला,কারবালা,ਕਰਬਲਾ,கர்பலா,കർബല,ქარბალა,カルバラー,カルバラー県,卡爾巴拉,카르발라', 32.6160300, 44.0248800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79276, 'Kelar', 'Kelar', 'Kalar,Kallar,Kallār,Kalār,Kelar,Klar,klar,كلار,كەلار', 34.6280500, 45.3185200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79277, 'Erbil', 'Erbil', 'Arbeel,Arbela,Arbil,Arbēla,Arbīl,EBL,Erbil,Hawler,Hawlēr,Hewler,Hewlêr,Irbil,Irbīl,Viloati Arbil,ai er bi lei sheng,arbyl,arubiru xian,hەwlێr,mhafzt arbyl,Арбил,Вилояти Арбӣл,מחוז ארביל,أربيل,إربيل,اربیل,محافظة أربيل,هەولێر,アルビール県,埃爾比勒省', 36.1925700, 44.0106200, 'IQ', '2016-11-20', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79278, 'Hīt', 'Hit', 'Hit,Hīt,hyt,هيت', 33.6366400, 42.8276800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79279, 'Al Ḩaqlānīyah', 'Al Haqlaniyah', 'Al Haqlaniyah,Al Ḩaqlānīyah,Hawija Arban,Hawijan Arban,Hawijat Arban,Hawīja Arban,alhqlanyt,الحقلانية,Ḩawījat Arbān', 34.0859900, 42.3617400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79280, 'Ḩalabjah', 'Halabjah', 'Alabja,Halabdscha,Halabia,Halabja,Halabjah,Halebdja,Halebja,Halebjeh,Halepce,Halepçe,Helebce,Helepce,Helepçe,Khalabdzha,hlbchh,hlbjt,Халабджа,حلبجة,حلبچه', 35.1777800, 45.9861100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79281, 'Ḩadīthah', 'Hadithah', 'Al Hadithah,Al Ḩadīthah,Haditha,Hadithah,Khadita,hdytht,Хадита,حديثة,Ḩadīthah', 34.1366100, 42.3772700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79282, 'Xebat', 'Xebat', 'Aski Kalak,Askī Kalak,Eski Kalak,Eski Kellek,Kalak,Kelek,Kelleck,Kellek,Khabat,Khabāt,Qalak,Qalaq,Xebat,khbat,klk,خبات,خەبات,كلك,كەلەك', 36.2779800, 43.6706500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79283, 'Dukan', 'Dukan', 'Dokan,Dukan,Dukhan,Dukhān,Dūkān,dwkan,دوكان', 35.9292200, 44.9628200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79284, 'Soran', 'Soran', 'Diana,Diyana,Diyane,Diyānā,Qaryat Diyana,Qaryat Diyānā,Sawran,Sawrān,Soran,dyana,dyanە,qryt dyana,swran,sۆran,ديانا,ديانە,سوران,سۆران,قرية ديانا', 36.6532000, 44.5440700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79285, 'Dihok', 'Dihok', 'Dahuk,Dahūk,Dakhuk,Dihok,Dihuk,Dihōk,Dihūk,Dohuk,Duhok,Duhuk,Dûhok,dahuk,dhwk,dhۆk,Дахук,دهوك,دهوک,دهۆك,دهۆک,دووهۆک,دَهُکْ,ܢܘܗܕܪܐ', 36.8670900, 42.9884500, 'IQ', '2016-11-20', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79286, 'Dibis', 'Dibis', 'Dibis,Dibiz,Dibs,dbs,dbz,دبز,دبس', 35.6748200, 44.0706700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79287, 'Chwarta', 'Chwarta', 'Choarta,Chuwarta,Chuwartah,Chuwārtah,Chuwārtā,Chwarta,Juwarta,Juwartah,Juwārtah,Juwārtā,chwarta,chwartt,jwarta,jwartt,جوارتا,جوارتة,چوارتا,چوارتة', 35.7265900, 45.5723200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79288, 'Jamjamāl', 'Jamjamal', 'Chamchamal,Chamchamāl,Chemchemal,Chemchemał,Chemchemāl,Jamjamal,Jamjamāl,Shamshamal,Shamshamāl,chmchmal,chەmchەmaڵ,jmjmal,جمجمال,چمچمال,چەمچەماڵ', 35.5335600, 44.8343000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79289, 'Al Jabāyish', 'Al Jabayish', 'Al Chabaish,Al Chabayish,Al Chabaysh,Al Chabāyish,Al Chabāysh,Al Jaba''ish,Al Jabayish,Al Jabāyish,Al Jabā’ish,Al Kaba''ish,Al Kabā’ish,Ash Shebaish,Chabaish,Chubeish,Kabaish,Kabayish,Kibaish,alchbaysh,aljbaysh,الجبايش,الچبايش', 30.9658800, 47.0019600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79290, 'Bayjī', 'Bayji', 'Baiji,Bajdzhi,Bayji,Bayjī,byjy,Байджи,بيجي', 34.9291500, 43.4887800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79291, 'Baqubah', 'Baqubah', 'Ba''quba,Ba''qubah,Bakouba,Bakuba,Baquba,Baqubah,Baqubeh,Ba‘qūbah,Ba’qūba,XQV,ba gu bai,Бакуба,بعقوبة,巴古拜', 33.7540300, 44.6051800, 'IQ', '2016-02-28', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79292, 'Baynjiwayn', 'Baynjiwayn', 'Banjiwayn,Banjwin,Banjwīn,Baynjiwayn,Pandjvin,Panjvin,Panjwin,Panjwīn,Paynjiwayn,Penciwen,Pencwen,Pendjevin,Pendjevine,Pendsevine,Penjevin,Penjvin,Penjvīn,Penjwen,Penjwin,Pênciwên,Pêncwên,bnjwyn,bynjwyn,pnjwyn,pynjwyn,بنجوين,بينجوين,پنجوین,پينجوین,پێنجوێن', 35.6232900, 45.9471400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79293, 'Bāmarnī', 'Bamarni', 'BMN,Bamami,Bamarne,Bamarni,Bamarny,Bamerne,Bamerni,Bameṟnê,Bameṟnî,Bamirni,Bāmami,Bāmarnī,bamrny,بامرني,بامەڕنى,بامەڕنێ', 37.1216300, 43.2709000, 'IQ', '2017-02-09', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79294, 'Baladrūz', 'Baladruz', 'Baladruz,Baladrūz,bldrwz,بلدروز', 33.6963100, 45.0778200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79295, 'Balad', 'Balad', 'Balad,Balada,Belad,Beled,XQC,bld,Балада,بلد', 34.0148500, 44.1457400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79296, 'Baḩirkah', 'Bahirkah', 'Bahirka,Bahirkah,Barkah,Baḩirkah,Behirke,Beḧirke,Markaz Bahirkah,Markaz Baḩirkah,bhrkh,bhrkt,brkh,mrkz bhrkt,بحركه,بركه,بهركة,بەحركە,مركز بحركة', 36.3155600, 44.0353300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79297, 'Baghdad', 'Baghdad', 'BGW,Bagda,Bagdad,Bagdadas,Bagdado,Bagdat,Bagdate,Bagdatum,Bagdod,Bagdá,Bagdád,Baghdad,Baghdād,Bağdad,Bağdat,Beghdad,Bexda,Lungsod ng Baghdad,ba ge da,bagadada,bageudadeu,bagudado,bghdad,bەghdad,paktat,Βαγδάτη,Багдад,Бағдод,Բաղդադ,בגדאד,بغداد,بەغداد,ܒܓܕܐܕ,बगदाद,பக்தாத்,པ་ག་ཏ,ባግዳድ,バグダード,巴格达,바그다드', 33.3405800, 44.4008800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79298, 'Badrah', 'Badrah', 'Badra,Badrah,Badrai,Bedrah,Bedrai,bdrt,بدرة', 33.1150800, 45.9334400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79299, 'Az Zubayr', 'Az Zubayr', 'Az Zubair,Az Zubayr,Az Zuhair,El Zubair,Zobier,Zubair,alzbyr,الزبير', 30.3921300, 47.7017500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79300, 'Ash Shaykhān', 'Ash Shaykhan', 'Ain Sifni,Ain Sufni,Ash Shaykhan,Ash Shaykhān,Isifne,Shexan,Shikhan,Shêxan,`Ayn Sifni,`Eyn Sifni,alshykhan,yysfnێ,Îsifnê,ئيسفنێ,الشيخان,شێخان,عين سفني,عەين سفنى,‘Ayn Sifnī,‘Eyn Sifnî', 36.6959500, 43.3520200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79301, '‘Aynkāwah', '''Aynkawah', 'Ainkawa,Ankawa,Markaz `Aynkawah,Markaz ‘Aynkāwah,`Aynkawah,`Eynkawa,عينكاوة,عەينكاوا,مركز عينكاوة,‘Aynkāwah,‘Eynkawa', 36.2306000, 43.9944200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79302, 'Aţ Ţārmīyah', 'At Tarmiyah', 'At Tarmiyah,Aţ Ţārmīyah,Tarmiya,Tarmiyah,Tārmīya,Tārmīyah,altarmyt,الطارمية', 33.6744400, 44.3958300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79303, 'Aş Şuwayrah', 'As Suwayrah', 'As Suwayrah,Aş Şuwayrah,Jazira,Jazīra,Jumeiseh,Juweimiseh,Sewairah,Suvajra,Suwaira,Suweireh,Suweiri,alswyrt,Сувайра,الصويرة', 32.9255600, 44.7758300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79304, 'As Sulaymānīyah', 'As Sulaymaniyah', 'Al-Sulaimaniya,As Sulaymaniyah,As Sulaymānīyah,As-Sulajmanijja,ISU,Silemani,Silêmanî,Sleimani,Sleimāni,Slemani,Slêmanî,Slēmānī,Solimania,Souleimaniye,Sueleymaniye,Sulaimania,Sulaimanieh,Sulaimaniya,Sulaimaniyya,Sulaimany,Sulaymaniyah,Sulaymaniyya,Sulaymānīyah,Suleimania,Suleimaniya,Sulejmanija,Süleymaniye,alslymanyt,slymanyh,Сулеймания,السليمانية,سلیمانیه,سلێمانى,سلێمانی', 35.5649600, 45.4329000, 'IQ', '2017-02-09', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79305, 'As Samawah', 'As Samawah', 'As Samawah,As Samāwah,SAMAWA,Samava,Samawa,Samawah,Samāwah,alsmawh,Самава,السماوه', 31.3319800, 45.2944000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79306, 'As Salmān', 'As Salman', 'Al-Saliman,As Salman,As Salmān,alslman,السلمان', 30.5046400, 44.5394300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79307, 'Nāḩiyat ash Shināfīyah', 'Nahiyat ash Shinafiyah', 'Ash Shinafiyah,Ash Shināfīyah,Chinafiyah,Nahiyat ash Shinafiyah,Nāḩiyat ash Shināfīyah,Shannafiuah,Shenafiya,Shenāfiya,Shinafie,Shinafiya,Shinafiyeh,Shināfiya,alshnafyt,nahyt alshnafyt,الشنافية,ناحية الشنافية', 31.5837600, 44.6467500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79308, 'Ash Shaţrah', 'Ash Shatrah', 'Ash Shatrah,Ash Shaţrah,Shatra,Shatrat al Muntafiq,Shatreh,Shatret el Muntefiq,Shattra,Shattrah el Muntifik,alshtrt,الشطرة', 31.4090600, 46.1727000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79309, 'Ash Shāmīyah', 'Ash Shamiyah', 'Ash Shamiya,Ash Shamiyah,Ash Shāmīya,Ash Shāmīyah,Shamiya,Ummal Barur,alshamyt,الشامية', 31.9625700, 44.6007500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79310, 'Ar Ruţbah', 'Ar Rutbah', 'Al Rutbah,Ar Rutbah,Ar Ruţbah,Rutba,Rutbah,alrtbt,الرطبة', 33.0371800, 40.2858600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79311, 'Ar Rumaythah', 'Ar Rumaythah', 'Al-Rumitha,Ar Rumaythah,Rumaith,Rumaitha,Rumaithah,Rumeitheh,Rumetha,Ubaiyidh,alrmytht,الرميثة', 31.5284500, 45.2037700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79312, 'Ar Rifā‘ī', 'Ar Rifa''i', 'Al Karradi,Al Karrādī,Al-Refai,Ar Rifa`i,Ar Rifā‘ī,Karradi,Refai,الرفاعي', 31.7207900, 46.1077800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79313, 'Ramadi', 'Ramadi', 'Al-Ramadi,Al-Rumadi,Ar Ramadi,Ar Ramādī,Ar-Ramadi,Ar-Ramādī,Ehr-Ramadi,Er-Ramadi,Ramadi,Ramadie,Ramadieh,Ramadiyah,Ramanti,Ramádi,Ramádí,Rumadiya,Rumadiyeh,Rumādīya,Rumādīyeh,XTM,alrmady,la ma di,lamadi,ramadi,ramady,rmady,Ραμάντι,Ер-Рамаді,Рамади,Эр-Рамади,רמאדי,الرمادى,الرمادي,رامادی,رمادی,ਰਮਾਦੀ,റമാദി,რამადი,ラマーディー,拉馬迪,라마디', 33.4205600, 43.3077800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79314, '‘Aqrah', '''Aqrah', 'Akra,Akre,Akrê,Aora,`Aqirah,`Aqrah,Ākrē,ئاكرێ,عقرة,‘Aqirah,‘Aqrah', 36.7332200, 43.8796400, 'IQ', '2014-11-05', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79315, 'An Nu‘mānīyah', 'An Nu''maniyah', 'Al Bughaylah,An Nu`maniyah,An Nu‘mānīyah,Baghailah,Baghela,Bghailah,Bogheileh,Bogheili,Bughaila,Bughaylah,N`amaniya,Na''amiya,Na’amiya,N‘amānīya,النعمانية', 32.5562100, 45.4129300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79316, 'Nasiriyah', 'Nasiriyah', 'Al-Nasiriya,An Nasiriya,An Nasiriyah,An Nāsirīya,An Nāşirīyah,An-Nasiriya,Muntafik,Muntifik,Nasirija,Nasirijja,Nasiriya,Nasiriyah,Nasiriyeh,Nasiriyya,Nasrie,Nasriye,Nāsirīyah,XNH,alnasryh,alnasryt,nashiriya,Насирия,الناصرية,الناصريه,ナーシリーヤ', 31.0579900, 46.2572600, 'IQ', '2017-06-15', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79317, 'Najaf', 'Najaf', 'Al Najaf al Ashraf,An Najaf,An Najaf al Ashraf,An-Nadzaf,An-Nadzhaf,An-Nadżaf,An-Najaf,Ehn-Nadzhaf,Meshed ''Ali,Meshed ’Ali,NJF,Nachaf,Nadjaf,Nadschaf,Nadzaf,Nadzafas,Nadzhaf,Nadžaf,Nadžafas,Nagafo,Najaf,Najaf - njf,Najaf - نجف,Natzaf,Nayaf,Naĝafo,Necef,Nedjef,Nedzsef,Neshed Ali,Nəcəf,alnjf,alnjf alashrf,na jie fu,najafa,najafu,najap,najapeu,najapi,ngp,njf,Νατζάφ,Ан-Наджаф,Наджаф,Наџаф,Эн-Наджаф,נגף,النجف,النجف الاشرف,نجف,नजफ़,நஜாப்,നജഫ്‌,ნაჯაფი,ナジャフ,納杰夫,나자프', 32.0259400, 44.3462500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79318, '‘Anat al Qadīmah', '''Anat al Qadimah', 'Ana,Anah,`Anah,`Anat al Qadimah,عنة القديمة,‘Anat al Qadīmah,‘Ānah', 34.4693400, 41.9422300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79319, 'Al Qurnah', 'Al Qurnah', 'Al Qurna,Al Qurnah,Qurnah,alqrnt,القرنة', 31.0154700, 47.4336200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79320, 'Al Qayyārah', 'Al Qayyarah', 'Al Kayyarah,Al Kayyārah,Al Qaiyara,Al Qaiyāra,Al Qayyarah,Al Qayyārah,Al-Qaiyara,Gayara,Kaiyara,Nahiyat al Qayyarah,Nāḩiyat al Qayyārah,Qaiyara,Qaiyāra,Qayyarah,Qayyārah,RQW,alqyart,nahyt alqyart,القيارة,ناحية القيارة', 35.7993300, 43.2944700, 'IQ', '2017-02-09', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79321, 'Imam Qasim', 'Imam Qasim', 'Al Qasim,Al Qāsim,Al''-Kasim,Imam Qasim,Nahiyat al Qasim,Nāḩiyat al Qāsim,Qasim,Qāsim,alqasm,nahyt alqasm,Аль-Касим,القاسم,ناحية القاسم', 32.2979900, 44.6828200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79322, 'Al Musayyib', 'Al Musayyib', 'Al Musaiyib,Al Musayyib,Al''-Ehl''-Musajibe,Mosayab,Musaiyib,Musayyib,Musaīyib,Museyib,almsyb,Аль-Эль-Мусайибе,المسيب', 32.7787200, 44.2900500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79323, 'Al Mishkhāb', 'Al Mishkhab', 'Al Faysaliyah,Al Fayşalīyah,Al Mishkhab,Al Mishkhāb,Faisailiya,almshkhab,المشخاب', 31.8043700, 44.4893000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79324, 'Al Miqdādīyah', 'Al Miqdadiyah', 'Al Miqdadiyah,Al Miqdādīyah,Muqdadiyah,Shahraban,Shahroban,Shahrābān,almqdadyt,المقدادية', 33.9786100, 44.9369400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79325, 'Al Maymūnah', 'Al Maymunah', 'Al Maymunah,Al Maymūnah,Maimunah,Maimūnah,Maymuna,almymwnt,الميمونة', 31.6790000, 46.9694800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79326, 'Al Mawşil al Jadīdah', 'Al Mawsil al Jadidah', 'Al Mawsil al Jadidah,Al Mawşil al Jadīdah,almwsl aljdydt,الموصل الجديدة', 36.3327100, 43.1055500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79327, 'Mosul', 'Mosul', 'Al Mawsil,Al Mawşil,Al Mosul,Al Musil,Al Mūşil,Mosel,Mosoel,Mosouli,Mossoul,Mossul,Mosul,Mosul khot,Mosula,Mosulas,Mosulo,Moszul,Mousl,Moussoul,Musil,Musił,Musul,Musıl,Mûsil,OSM,almwsl,mo su er,mo sul,mocul,mosala,mosul,mosula,mosuli,mosuru,mwsl,mwswl,mwsڵ,Μοσούλη,Мосeл,Мосул,Мосул хот,Մոսուլ,מאסול,מוסול,الموصل,موسڵ,موصل,موصول,مووسڵ,ܡܘܨܠ,मोसुल,ਮੋਸਲ,மோசுல்,മൊസൂൾ,โมซูล,მოსული,モースル,摩苏尔,摩蘇爾,모술', 36.3350000, 43.1188900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79328, 'Al Maḩmūdīyah', 'Al Mahmudiyah', 'Al Mahmudiya,Al Mahmudiyah,Al Mahmūdīya,Al Maḩmūdīyah,Mahmudie,Mahmudiya,Mahmudiyeh,Mahmūdīya,almhmwdyt,المحمودية', 33.0622100, 44.3656400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79329, 'Al Maḩāwīl', 'Al Mahawil', 'Al Mahawil,Al Maḩāwīl,Khan al Mahawil,Khān al Mahawīl,Mahawil,Qada'' al Mahawil,Qaḑā’ al Maḩāwīl,almhawyl,المحاويل', 32.6613800, 44.4085400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79330, 'Al Madīnah', 'Al Madinah', 'Al Madina,Al Madinah,Al Madīnah,Medina,Medineh,almdynt,المدينة', 30.9632400, 47.2699800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79331, 'Al Kūt', 'Al Kut', 'Al Koet,Al Kut,Al Kūt,Al-Kut,Kut,Kut al Amara,Kut al Amarah,Kut al Imara,Kut al Imāra,Kut al `Amarah,Kut-al-Almarah,Kut-al-Almārah,Kut-al-Imarah,Kūt,Kūt al ‘Amārah,Kūt-al-Imārah,alkwt,kwt,Кут,الكوت,كوت', 32.5128000, 45.8181700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79332, 'Kufa', 'Kufa', 'Al Kufa,Al Kūfa,Al-Kufa,Al-Kufah,Al-Kūfah,Cufa,Ehl''-Kufa,Gorad Ehl''-Kufa,Koefa,Koufa,Kufa,Kufah,Kufe,Kufə,Kúfa,Kūfa,Qada'' al Kufah,Qaḑā’ al Kūfah,alkwfh,alkwft,ku fei,kufa,kupa,kupha,kwfh,kwph,Κούφα,Горад Эль-Куфа,Куфа,Эль-Куфа,כופה,الكوفة,الكوفه,كوفه,کوفه,کوفہ,کووفە,ކޫފާ,कूफ़ा,কুফা,ਕੂਫ਼ਾ,കൂഫ,კუფა,クーファ,库费,쿠파', 32.0511400, 44.4401700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79333, 'Al Khāliş', 'Al Khalis', 'Al Khalis,Al Khāliş,Daltawah,Daltāwah,Diltawa,Diltawah,Diltāwah,Dīltāwah,alkhals,dyltawt,الخالص,ديلتاوة', 33.8511800, 44.5204700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79334, 'Khāliş', 'Khalis', 'Al Khalis,Al Khāliş,Al''-Khalisa,Diltawah,Diltāwah,Khalis,Khāliş,khals,Аль-Халиса,خالص', 33.8080900, 44.5334300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79335, 'Al Kaḩlā’', 'Al Kahla''', 'Al Kahla'',Al Kaḩlā’,Kahla,Musa`idah,Musaidda,Musay`idah,Musay‘īdah,Musāidda,Musā‘idah,الكحلاء', 31.6678900, 47.2945000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79336, '‘Alī al Gharbī', '''Ali al Gharbi', 'Ali Gharbi,Ali el Gharbi,Imam Ali Gherbi,Imām Ali Gherbi,`Ali al Gharbi,علي الغربي,‘Alī al Gharbī', 32.4618600, 46.6879400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79337, 'Al Hindīyah', 'Al Hindiyah', 'Al Hindiyah,Al Hindīyah,Hindiya,Hindīya,Qada'' al Hindiyah,Qaḑā’ al Hindīyah,Tuwairij,Tuwairji,Tuwairīj,Tuwayrij,alhndyt,Ţuwayrīj,الهندية', 32.5467100, 44.2276500, 'IQ', '2014-11-05', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79338, 'Al Ḩillah', 'Al Hillah', 'Al Hilla,Al Hillah,Al Ḩillah,Al''-Khilla,Al-Hella,Hilah,Hilla,Hille,Hillé,alhlt,Аль-Хилла,الحلة', 32.4636700, 44.4196300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79339, 'Al Ḩayy', 'Al Hayy', 'Al Hai,Al Hay,Al Hayy,Al Ḩayy,Al''-Khaja,Kut al Hai,alhy,Аль-Хая,الحي', 32.1741900, 46.0434500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79340, 'Al Hāshimīyah', 'Al Hashimiyah', 'Al Hashimiyah,Al Hāshimīyah,Al-Hashimiya,Hashimiya,Hashimiyah,Hāshimīya,Jarbu`iya,Jarbuiyah,Jarbuīyah,Jarbū‘īya,alhashmyt,الهاشمية', 32.3635100, 44.6601100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79341, 'Al Hārithah', 'Al Harithah', 'Al Harithah,Al Harthah,Al Hārithah,Al Hārthah,Al''-Kharrisa,Hartha,Harthah,alhartht,Аль-Харриса,الهارثة', 30.5848100, 47.7611400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79342, 'Al Ḩamzah', 'Al Hamzah', 'Al Hamzah,Al Ḩamzah,Hamzah,Qawam al Hamzah,Qawām al Ḩamzah,Quwam al Hamza,Quwām al Hamza,alhmzt,الحمزة,Ḩamzah', 31.7244400, 44.9769400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79343, 'Al Ḩaḑar', 'Al Hadar', 'Al Hadar,Al Hadhar,Al Hadhr,Al Hadr,Al Ḩaḑar,Al Ḩaḑr,Hadhar,Hadhr,Hatra,Rijm al Hadr,Rijm al Ḩaḑr,alhdr,الحضر', 35.5729000, 42.7339500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79344, 'Nahiyat Ghammas', 'Nahiyat Ghammas', 'Al Ghammas,Al Ghammās,Ghammas,Ghammās,Nahiyat Ghammas,Nāḩiyat Ghammās,ghmas,nahyt ghmas,غماس,ناحية غماس', 31.7431100, 44.6196000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79345, 'Nāḩiyat al Fuhūd', 'Nahiyat al Fuhud', 'Al Fuhud,Al Fuhūd,Fuhud,Fuhūd', 30.9697200, 46.7227800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79346, 'Al Fāw', 'Al Faw', 'Al Faw,Al Fāw,Al''-Fau,Fao,Fao Terminal,Fava,alfaw,Аль-Фау,الفاو', 29.9742100, 48.4730900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79347, 'Al Fallūjah', 'Al Fallujah', 'Al Falluja,Al Fallujah,Al Fallūja,Al Fallūjah,Al Falooja,Al-Falludza,Al-Falludża,Al-Falluja,Falloujah,Falludscha,Falluja,Fallujah,Fallūjah,Faludza,Faludzha,Faluga,Faluja,Faluya,Faluĝa,Feludja,Feluja,TQD,alflwjt,faruja,fei lu jie,Фалуджа,Фалуџа,الفلوجة,ファルージャ,费卢杰', 33.3491300, 43.7859900, 'IQ', '2017-02-09', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79348, 'Al Ba‘āj', 'Al Ba''aj', 'Al Ba`aj,Al Ba‘āj,Al Bi`aj,Al Bi‘āj,Baaj,Bajar,Bajār,البعاج', 36.0426000, 41.7163200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79349, 'Basrah', 'Basrah', 'Al Basrah,Al Başrah,Al-Basra,BSR,Bacora,Basora,Basra,Basrah,Bassora,Bassorah,Bassra,Baçorá,Busra,Busrah,Bussora,Bàssora,albsrt,ba shi la,ba si la,basura,bsrh,bsrt,bzrh,Басра,בצרה,البصرة,بصرة,بصره,ܒܨܪܐ,バスラ,巴士拉,巴斯拉', 30.5085200, 47.7804000, 'IQ', '2015-11-29', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79350, 'Al ‘Azīzīyah', 'Al ''Aziziyah', 'Al `Aziziya,Al `Aziziyah,Al ‘Aziziya,Al ‘Azīzīyah,Al-Azizya,Al-Azīzya,Azizie,Aziziya,Aziziyah,Azizīya,Azīzīyah,`Aziziyeh,العزيزية,‘Aziziyeh', 32.9094100, 45.0635900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79351, 'Al ‘Awjah', 'Al ''Awjah', 'Al `Awja'',Al `Awjah,Al ‘Awjah,Al ‘Awjā’,Nahiyat al `Awjah,Nāḩiyat al ‘Awjah,Owja,alʿwjt,nahyt alʿwjt,العوجة,ناحية العوجة', 34.5333300, 43.7333300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79352, 'Al ‘Amārah', 'Al ''Amarah', 'Al `Amarah,Al ‘Amārah,Amara,Amarah,Amare,Amaré,`Amara,alʿmart,العمارة,العماره,‘Amāra', 31.8356100, 47.1448300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79353, 'Al ‘Amādīyah', 'Al ''Amadiyah', 'Al Amadiya,Al `Amadiyah,Al ‘Amādīyah,Amadia,Amadiyeh,Amedi,Amedy,Amidi,Amêdî,Amîdî,Amādia,Amādīyeh,Amēdī,`Amadiya,`Amadiyah,yamydy,ئاميدى,ئامێدى,العمادية,‘Amādīya,‘Amādīyah', 37.0921400, 43.4876900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79354, '‘Afak', '''Afak', 'Afag,Afak,Afaq,Sok el Afej,`Afak,Афак,عفك,‘Afak', 32.0643000, 45.2474300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79355, 'Ad Dujayl', 'Ad Dujayl', 'Ad Dujayl,Al Ibrahimiyah,Al Ibrāhīmīyah,Doujail,Doujaïl,Dudschail,Dudzail,Dudžail,Dujail,Dujayl,Nahiya Sumaika,Nahiya Sumaīka,Nahiyat ad Dujayl,Nāḩiyat ad Dujayl,Sumaicha,Sumaichah,Sumaika,Sumaikcheh,Sumaykah,Sumaīka,Sumeicha,Sumeikeh,Sumekche,Summeicha,Suneiki,do~ujairu,ドゥジャイル', 33.8466700, 44.2344400, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79356, 'Ad Dīwānīyah', 'Ad Diwaniyah', 'Ad Diwania,Ad Diwaniya,Ad Diwaniyah,Ad Dīwānīya,Ad Dīwānīyah,Al-Diwaniya,Divanija,Diwanie,Diwaniya,Diwaniyan,Diwaniyeh,Dīwanīya,Hiska,aldywanyt,Дивания,الديوانية', 31.9928900, 44.9255200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79357, 'Ad Dawr', 'Ad Dawr', 'Ad Dawr,Ad Dur,Ad Dūr,Daur,Dawr,Dur,aldwr,الدور', 34.4559700, 43.7934100, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79358, 'Al Manādhirah', 'Al Manadhirah', 'Abu Sukhair,Abu Sukhayir,Abu Sukhayr,Abu Sūkhair,Abū Şukhayir,Abū Şukhayr,Al Manadhirah,Al Manādhirah,abw skhyr,almnadhrt,ابو صخير,المناذرة', 31.9069200, 44.4864900, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79359, 'Abī al Khaşīb', 'Abi al Khasib', 'Abi al Khasib,Abi al Khusayb,Abu al Khasib,Abul Khasib,Abī al Khaşīb,Abī al Khuşayb,Abū al Khaşīb,abw alkhsyb,aby alkhsyb,أبي الخصيب,ابو الخصيب', 30.4463600, 47.9781300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79360, 'Abū Ghurayb', 'Abu Ghurayb', 'Abou Ghraib,Abu Ghraib,Abu Ghraib - abw ghryb,Abu Ghraib - أبو غريب,Abu Ghraib Farms,Abu Ghuraib,Abu Ghurayb,Abu-Grejb,Abū Ghraib Farms,Abū Ghurayb,Mazari` Abi Gharib,Mazari` Abi Ghurayb,Mazāri‘ Abī Ghurayb,Mazārı‘ Abī Gharīb,abw ghryb,Абу-Грейб,אבו גרייב,أبو غريب,ابو غریب', 33.3056300, 44.1847700, 'IQ', '2015-01-07', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79361, 'Derbendîxan', 'Derbendixan', 'Darbandekhan,Darbandikhan,Darbandikhān,Darbandīkhān,Debendi Khan,Derbend Khan,Derbendixan,Derbendîxan,drbndkhan,drbndykhan,دربندخان,دربنديخان,دەربەنديخان', 35.1120700, 45.6866300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79362, 'Al Başrah al Qadīmah', 'Al Basrah al Qadimah', 'Al Basrah al Qadimah,Al Basrat al Qadimah,Al Başrah al Qadīmah,Al Başrat al Qadīmah,albsrt alqdymt,البصرة القديمة', 30.5031600, 47.8150700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79363, 'Al Ḩawījah', 'Al Hawijah', 'Al Hawijah,Al Huwayjah,Al Ḩawījah,Al Ḩuwayjah,alhwyjt,الحويجة', 35.3259200, 43.7726700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79364, 'Qūshtabah', 'Qushtabah', 'Markaz Qushtabah,Markaz Qūshtabah,Qush Tabbah,Qush Tappah,Qushtabah,Qushtapa,Qushtepe,Qūsh Tabbah,Qūsh Tappah,Qūshtabah,mrkz qwshtbt,qwsh tbt,qwshtbt,قوش تبة,قوشتبة,قوشتەپە,مركز قوشتبة', 36.0019300, 44.0382700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79365, 'Dāratū', 'Daratu', 'Dara Tw,Daratu,Dare Tu,Dare Tû,Dāratū,Dārātū,Markaz Daratu,Markaz Dāratū,daratw,dartw,mrkz dartw,داراتو,دارتو,دارە توو,مركز دارتو', 36.1206200, 44.0597200, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79366, 'Kasnazān', 'Kasnazan', 'Kasnazan,Kasnazan Asmaail,Kasnazan Isma`il,Kasnazan Sin Isma`il,Kasnazan Tahsin,Kasnazān,Kasnazān Ismā‘īl,Kasnazān Sīn Ismā‘īl,Kastran Siti Isma`il,Kastrān Sitī Ismā‘īl,Kesnezan Tehsin,Kesnezan Teḧsîn,Kesnezani Isma`il,Kesnezanî Îsma‘îl,Markaz Kasnazan,Markaz Kasnazān,ksnzan,mrkz ksnzan,كستران ستي اسماعيل,كسنزان,كسنزان اسماعيل,كسنزان سين اسماعيل,كەسنەزان تەحسين,كەسنەزانى اسماعيل,مركز كسنزان', 36.2006700, 44.1326300, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79367, 'Choman', 'Choman', 'Choman,Choman Mustafa Agha,Chōmān,Chōmān Muşţafa Āghā,Jawman,Jawmān,Mustafa Agha,Muşţafa Āghā,jwman,jwman mstfy agha,جومان,جومان مصطفى اغا,چۆمان', 36.6366500, 44.8882000, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79368, 'Sinjār', 'Sinjar', 'Shengal,Shingal,Sincar,Sinjar,Sinjār,Sncar,shەngal,snjar,سنجار,شەنگال', 36.3209000, 41.8765600, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79369, '‘Anah', '''Anah', 'Ar Rayhanah,Ar Rayḩānah,Ar Rihanah,Ar Rīḩānah,Madinat `Anah al Jadidah,Madinat `Annat al Jadidah,Madīnat ‘Anah al Jadīdah,Madīnat ‘Annat al Jadīdah,Rayhanah,Rayḩānah,`Anah,`Anah al Jadidah,`Annah,`Annah al Jadidah,alryhant,ryhant,ʿnh aljdydt,ʿnt,الريحانة,ريحانة,عنة,عنه الجديدة,مدينة عنة الجديدة,‘Anah,‘Anah al Jadīdah,‘Annah,‘Annah al Jadīdah', 34.3685700, 41.9819400, 'IQ', '2016-06-27', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79370, 'Nāḩiyat Hīrān', 'Nahiyat Hiran', 'Nahiyat Hiran,Nāḩiyat Hīrān,nahyt hyran,ناحية هيران', 36.2789900, 44.4881500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79371, 'Nāḩiyat Baḩār', 'Nahiyat Bahar', 'Nahiyat Bahar,Nāḩiyat Baḩār,nahyt bhar,ناحية بحار', 30.1764900, 48.3977500, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79372, 'Nāḩiyat ‘Atbah', 'Nahiyat `Atbah', 'Nahiyat `Atbah,Nāḩiyat ‘Atbah,ناحية عتبة', 30.4811700, 48.0142400, 'IQ', '2012-05-06', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79373, 'Nāḩiyat Alī ash Sharqī', 'Nahiyat Ali ash Sharqi', 'Ali ash Sharqi,Alī ash Sharqī,Nahiyat Ali ash Sharqi,Nāḩiyat Alī ash Sharqī,علي الشرقي,ناحية علي الشرقي', 32.1228700, 46.7492800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79374, 'Zaxu', 'Zaxu', 'Qada'' Zakhu,Qaḑā’ Zākhū,Zakho,Zakhu,Zakhu Qadha'',Zaxo,Zaxu,Zākhū,Zākhū Qadhā’,qdaʾ zakhw,zakhw,zakhۆ,زاخو,زاخۆ,قضاء زاخو', 37.1424600, 42.6818700, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79375, 'Ḩalabjah al Jadīdah', 'Halabjah al Jadidah', 'Halabjah al Jadidah,Helebcey Taze,Hełebcey Taze,hlbjt aljdydt,حلبجة الجديدة,ھەڵەbjەy tazە,ھەڵەبجەى تازە,Ḩalabjah al Jadīdah', 35.3197500, 45.6894800, 'IQ', '2016-06-22', 106);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79377, 'Alvand', 'Alvand', 'Alborz,Alvand,albrz,alwnd,البرز,الوند', 36.1893000, 50.0643000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79378, 'Āzādshahr', 'Azadshahr', 'Azad Shahr,Azadshahr,azadshhr,Āzādshahr,آزادشهر', 34.7904900, 48.5701100, 'IR', '2016-08-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79379, 'Nīr', 'Nir', 'Nir,Nīr,Shahrestan-e Nir,Shahrestān-e Nīr,nyr,shhrstan nyr,شهرستان نير,نير', 38.0346000, 47.9986000, 'IR', '2015-07-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79380, 'Qarah Āghāj', 'Qarah Aghaj', 'Qarah Aghaj,Qarah Āghāj,Qareh Aghaj,Qareh Āghāj,qrh aghaj,قره آغاج', 37.2187000, 47.2167000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79381, 'Bostānābād', 'Bostanabad', 'Bostanabad,Bostānābād,bstan abad,بستان آباد', 37.8463300, 46.8354200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79382, 'Kahrīz', 'Kahriz', 'Kahriz,Kahrīz,khryz,کهریز', 34.3838000, 47.0553000, 'IR', '2012-01-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79383, 'Nūrābād', 'Nurabad', 'Nurabad,Nūrābād,nwr abad,Нурабад,نور آباد', 34.0734000, 47.9725000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79384, 'Javānrūd', 'Javanrud', 'Javanrud,Javānrūd,Juanru,Jūānrū,Qal`a Juanrud,Qal`eh Juanrud,Qal`eh-ye Javanrud,Qal‘a Jūanrūd,Qal‘eh Jūānrūd,Qal‘eh-ye Javānrūd,jwanrwd,جوانرود', 34.8067000, 46.4913000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79385, 'Bozghān', 'Bozghan', 'Barghan,Barghān,Bozghan,Bozghān,Firuzeh,Fīrūzeh,bzghan,fyrwzh,بزغان,فيروزه', 36.2863900, 58.5858600, 'IR', '2016-09-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79386, 'Kalāt-e Nāderī', 'Kalat-e Naderi', 'Kalat,Kalat-e Naderi,Kalāt,Kalāt-e Nāderī,klat,klat nadry,کلات,کلات نادری', 36.9953200, 59.7647200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79387, 'Īstgāh-e Rāh Āhan-e Garmsār', 'Istgah-e Rah Ahan-e Garmsar', 'Istgah-e Garmsar,Istgah-e Rah Ahan Garmsar,Istgah-e Rah Ahan-e Garmsar,aystgah grmsar,aystgah rahahn garmsar,ystgahi garmsar,ystgahi rah ahan garmsar,ystgahi rahahani garmsar,Īstgāh-e Garmsār,Īstgāh-e Rāh Āhan Garmsār,Īstgāh-e Rāh Āhan-e Garmsār,ايستگاه راهاهن گَرمسار,ايستگاه گرمسار,يستگاهِ راه آهَن گَرمسار,يستگاهِ راهاهَنِ گَرمسار,يستگاهِ گَرمسار', 35.2345500, 52.3094200, 'IR', '2013-01-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79388, 'Qarchak', 'Qarchak', 'Qarchak,qrchk,قرچك', 35.4286700, 51.5754400, 'IR', '2012-12-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79389, 'Shahrak-e Emām Ḩasan', 'Shahrak-e Emam Hasan', 'Shahrak-e Emam Hasan,Shahrak-e Emam Hasan-e Mojtaba,Shahrak-e Emām Ḩasan,Shahrak-e Emām Ḩasan-e Mojtabá,shhrk amam hsn,shhrk amam hsn mjtby,شهرک امام حسن,شهرک امام حسن مجتبی', 35.4884600, 51.3456700, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79390, 'Shahre Jadide Andisheh', 'Shahre Jadide Andisheh', 'Shahrak-e Andisheh,Shahrak-e Andīsheh,shhr jdyd andyshh,شهر جدید اندیشه', 35.6803000, 51.0193000, 'IR', '2012-08-22', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79391, 'Omīdcheh', 'Omidcheh', 'Omidcheh,Omīdcheh,aumydchih,اُميدچِه', 38.2866700, 48.1413900, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79392, 'Āq Qāyeh', 'Aq Qayeh', 'Aq Qayeh,aq qayih,Āq Qāyeh,آق قايِه', 37.2747200, 55.1588900, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79393, 'Gomīshān', 'Gomishan', 'Gish Dafeh,Gomesh Tappeh,Gomish Tappeh,Gomish Tappeh Jik,Gomishan,Gomīsh Tappeh,Gomīsh Tappeh Jīk,Gomīshān,Gumish Tepe,Gumshan,Gumshān,Gīsh Dafeh,gmysh tph,gmyshan,گميش تپه,گميشان', 37.0718000, 54.0765400, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79394, 'Pā’īn-e Bāzār-e Rūdbār', 'Pa''in-e Bazar-e Rudbar', 'Pa''in-e Bazar-e Rudbar,Pā’īn-e Bāzār-e Rūdbār,Rudbar,Rudbar-e Kuhpayeh-ye Pa''in,Rūdbār,Rūdbār-e Kūhpāyeh-ye Pā’īn,payyn bazar rwdbar,rwdbar,rwdbar kwhpayh payyn,رودبار,رودبار کوهپایه پائین,پائین بازار رودبار', 36.8211000, 49.4264000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79395, 'Khorramdarreh', 'Khorramdarreh', 'Khorramdareh,Khorramdarreh,Khurramdarreh,Khurramdarrekh,khrmdrh,خرمدره', 36.2089800, 49.1915200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79396, 'Kavār', 'Kavar', 'Kaval,Kavar,Kavār,kwar,کوار', 29.2050000, 52.6899000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79397, 'Yasuj', 'Yasuj', 'Jasudz,Jasudzh,Jasudż,Jasudž,Jásúdž,YES,Yasooj,Yasuc,Yasudsch,Yasuj,Yasûc,Yesuj,Yesūj,Yāsūj,ya su ji,yasuj,yasuja,yasujeu,yasuju,yaswj,yiswj,yswj,Ёсӯҷ,Ясудж,Յասուջ,ياسوج,يَسُّج,يِسوج,یاسوج,یسوج,यासूज,ヤースージュ,亞蘇季,야수즈', 30.6682400, 51.5879600, 'IR', '2013-11-10', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79398, 'Āzādshahr', 'Azadshahr', 'Azadshahr,Shah Pasand,Shāh Pasand,azad shhr,shah psnd,Āzādshahr,آزاد شهر,شاه پسند', 37.0864100, 55.1722200, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79399, 'Ziabar (Gaskar)', 'Ziabar (Gaskar)', 'Gaskar,Zeyabar,Zeyābar,Zia'' Bar,Ziabar,Ziabera,Ziya'' Bar,Zīyā’ Bar,dyabr,ضیابر,Ẕīābar,Ẕīā’ Bar', 37.4261000, 49.2459000, 'IR', '2013-08-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79400, 'Zarrīnābād', 'Zarrinabad', 'Zarinabad,Zarrinabad,Zarrīnābād,zryn abad,زرین آباد', 36.4262200, 48.2815800, 'IR', '2016-12-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79401, 'Zarand', 'Zarand', 'Zarand,zrnd,زرند', 30.8127100, 56.5639900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79402, 'Zanjān', 'Zanjan', 'JWN,Zanjan,Zanjān,Zendzhan,Zenjan,Zenjān,znjan,Зенджан,زنجان', 36.6764200, 48.4962800, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79403, 'Yazd', 'Yazd', 'AZD,Dakbayan sa Yazd,Giaznt,Jazd,Jazdo,Jezd,Jezdas,Yasd,Yazd,Yezd,Yəzd,iezdi,ya ci de,yajeudeu,yazda,yazudo,yzd,Γιαζντ,Јазд,Йезд,Язд,Յազդ,יזד,يزد,یزد,यज़्द,იეზდი,ヤズド,亚兹德,야즈드', 31.8972200, 54.3675000, 'IR', '2013-11-27', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79404, 'Vasīān', 'Vasian', 'Cham Bagh-e Veysian,Cham Bāgh-e Veysīān,Vaisiyan,Vaisyan,Vasian,Vasīān,Veseyan,Veseyān,Veysian,Veysiyan,Veysīyān,Veysīān,Voisiyan,cham baghi wisyan,wasyan,wisian,wisyan,وَسيان,وِسِيان,وِيسيان,وِيسيّان,چَم باغِ وِيسيان', 33.4908300, 48.0491700, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79405, 'Varazqān', 'Varazqan', 'Varazqan,Varazqān,Varezqan,Varezqān,Varzagan,Varzaghan Dezmar,Varzagān,Varzaqan,Varzaqān,Verazgan,Verazqan,Verazqān,warzagan,warzaghan dizmar,wirazgan,wrzqan,ورزقان,وَرزَغَن دِزمَر,وَرزَگان,وِرَزگَن', 38.6754900, 46.1120500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79406, 'Varāmīn', 'Varamin', 'Esfandabad,Esfandābād,Varamin,Varāmīn,Veramin,Verāmin,varamin,wramyn,Варамин,ورامين', 35.3242000, 51.6457000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79407, 'Tūyserkān', 'Tuyserkan', 'Tooyserkan,Tuisarkan,Tuysarkan,Tuyserkan,Tūysarkān,Tūyserkān,Tūīsarkān,tuysirkan,twysrkan,تویسرکان,تُّيسِركَن', 34.5510000, 48.4435300, 'IR', '2016-09-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79408, 'Ţorqabeh', 'Torqabeh', 'Targhobeh,Toroqbeh,Torqabeh,Torqebeh,trqbh,Ţoroqbeh,Ţorqabeh,طرقبه', 36.3104000, 59.3735000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79409, 'Torbat-e Ḩeydarīyeh', 'Torbat-e Heydariyeh', 'Torbat-e Heydariyeh,Torbat-e Ḩeydarīyeh,Torbat-e-Heydari,Turbat-i-Haidari,Turbet-i-Haidari,trbt hydryh,تربت حیدریه', 35.2740100, 59.2194900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79410, 'Tonekābon', 'Tonekabon', 'Shahsavar,Shahsavār,Shahsawar,Shahsawār,Tonekabon,Tonekābon,tnkabn,Тонекабон,تنکابن', 36.8162600, 50.8737600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79411, 'Tehran', 'Tehran', 'THR,Taekhran,Tahran,Techerane,Teera,Teerao,Teerã,Teerão,Tegeran,Teheran,Teherana,Teheranas,Teherano,Teherán,Teherāna,Tehran,Tehrano,Tekheran,Téhéran,de hei lan,teharan,teharana,tehelan,teheran,tehran,teirani,thran,thrn,thrwn,tihiran,tihran,Τεχεράνη,Тæхран,Тегеран,Техеран,Теҳрон,Թեհրան,טהראן,טהרן,تهران,تهرون,تِهران,تِهِرَن,تہران,طهران,ܛܗܪܐܢ,तेहरान,তেহরান,தெஹ்ரான்,เตหะราน,ཏེ་ཧི་རན​།,თეირანი,ቴህራን,テヘラン,德黑兰,테헤란', 35.6943900, 51.4215100, 'IR', '2015-10-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79412, 'Hashtpar', 'Hashtpar', 'Gashpar,Hashtpar,Hashtpar-e Tavalesh,Hashtpar-e Tavālesh,Otak Saray,Otaq Sarai,Otaq Saray,Otāq Sarai,Oţāq Sarāy,Talesh,Tālesh,hshtpr,hshtpr twalsh,هشتپر,هشتپر توالش', 37.7965800, 48.9052100, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79413, 'Ţāleb ābād', 'Taleb abad', 'Taleb Abad,talb abad,طالب آباد', 35.5013000, 51.5314700, 'IR', '2014-10-01', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79414, 'Tākestān', 'Takestan', 'Seyadahan,Seyādahan,Siadehan,Siahdehan,Siakh-Degen,Siakhdekhan,Sīahdehān,Sīādehan,Takestan,Takistan,Tākestān,Tākistān,syadihan,syahdihan,takstan,تاكستان,سيادِهَن,سيَهدِهان', 36.0696000, 49.6959000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79415, 'Takāb', 'Takab', 'Takab,Takan Tepe,Takāb,tkab,تکاب', 36.4009000, 47.1133000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79416, 'Tajrīsh', 'Tajrish', 'Tajrish,Tajrīsh,tjrysh,تجريش', 35.8044000, 51.4256000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79417, 'Shahr-e Herāt', 'Shahr-e Herat', 'Burd Harat,Burd Herat,Būrd Harāt,Būrd Herāt,Harat Khowreh,Harāt Khowreh,Herat,Herat-i-Khurreh,Herāt,Herāt-i-Khurreh,Shahr-e Herat,Shahr-e Herāt,Tajabad,Tajabad-e Harat,Tājābād,Tājābād-e Harāt,hrat,shhr hrat,شهر هرات,هرات', 30.0540700, 54.3729400, 'IR', '2014-12-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79418, 'Taft', 'Taft', 'Taft,tft,Тафт,تفت', 31.7438400, 54.2027800, 'IR', '2013-10-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79419, 'Tafresh', 'Tafresh', 'Tafresh,tfrsh,Тафреш,تفرش', 34.6930700, 50.0160100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79420, 'Tabriz', 'Tabriz', 'Gorad Tehbryz,TBZ,Tabrez,Tabris,Tabriz,Tabrizo,Tabríz,Tabrīz,Taebris,Taebriz,Tampriz,Tauris,Tebriz,Tebriza,Tebrizas,Tebrīza,Tewrez,Tewrêz,Toewriz,Täbris,Täbriz,Töwriz,Təbriz,da bu li shi,ta bris,tabareza,tabariza,tabeulijeu,tabris,taburizu,tavrizi,tbryz,Ταμπρίζ,Горад Тэбрыз,Табрез,Табриз,Тебриз,Тәбриз,Թավրիզ,טאבריז,תבריז,تبريز,تبریز,تەورێز,तबरेज़,ਤਬਰੀਜ਼,ടാബ്രിസ്,ตาบริซ,ཊ་བི་རི་ཛ།,თავრიზი,タブリーズ,大不里士,타브리즈', 38.0800000, 46.2919000, 'IR', '2015-10-25', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79421, 'Tabas', 'Tabas', 'Golshan,Gulshan,TCX,Tabas,Tabas Gilaki,Tebes,Təbəs,ta ba si,tbs,Ţabas,Табас,Тебес,شہرستان طبس,طبس,塔巴斯', 33.5958600, 56.9243700, 'IR', '2013-10-23', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79422, 'Sūrīān', 'Surian', 'Sureyan,Surian,Suriyan,Sūreyān,Sūrīyān,Sūrīān,swryan,سوریان', 30.4551000, 53.6510000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79423, 'Sūrak', 'Surak', 'Surak,Sūrak,swrk,سورک', 36.5948800, 53.2076200, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79424, 'Nūr', 'Nur', 'Nur,Nūr,Suldeh,Sulehdeh,Sūldeh,Sūlehdeh,nwr,swldih,swlihdih,سولدِه,سولِهدِه,نور', 36.5716800, 52.0153000, 'IR', '2017-01-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79425, 'Şowme‘eh Sarā', 'Sowme`eh Sara', 'Somee Sara,Sowma`eh Sara,Sowme`eh Sara,Sume`eh Sara,Sumehsara,Sumesera,Şowma‘eh Sarā,Şowme‘eh Sarā,Şūme‘eh Sarā,صومعه سرا', 37.3013400, 49.3150400, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79426, 'Sorkheh', 'Sorkheh', 'Sorkheh,Surkheh,srkhh,سرخه', 35.4633000, 53.2140000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79427, 'Sonqor', 'Sonqor', 'Sanghur,Sanghūr,Sonqor,Sunqur,Sūnqūr,snqr,سنقر', 34.7818700, 47.5994500, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79428, 'Solţānābād', 'Soltanabad', 'Kashmar,Soltanabad,Solţānābād,Sultanabad,Sultānābād,Turshiz,sltan abad,سلطان آباد', 36.4035200, 58.0389400, 'IR', '2016-10-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79429, 'Sirjan', 'Sirjan', 'SYJ,Sa''idabad,Sa‘īdābād,Sircan,Sirdschan,Sirdzan,Sirdzhan,Sirdżan,Sirdžan,Sirjan,Sīrjān,sirajana,syrjan,xi er zhan,Серҷон,Сирджан,سيرجان,سیرجان,सीरजान,錫爾詹', 29.4513700, 55.6809000, 'IR', '2014-05-28', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79430, 'Sīāhkal', 'Siahkal', 'Seyah Kal,Seyāh Kal,Siah Kal,Siahkal,Siahkal Mahalleh,Siyah Kal,Sīyāh Kal,Sīāh Kal,Sīāhkal,Sīāhkal Maḩalleh,syahkl,سیاهکل', 37.1532800, 49.8713600, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79431, 'Shūshtar', 'Shushtar', 'Shooshtar,Shushtar,Shushtehr,Shustar,Shūshtar,Shūstar,shwshtr,Шуштэр,شوشتر', 32.0497200, 48.8484300, 'IR', '2015-11-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79432, 'Shūsh', 'Shush', 'Shoosh,Shush,Shūsh,Susa,Suse,Susy,Suza,Suzo,Suzy,Súsy,Sūsa,shwsh,susa,Сузы,شوش,スーサ', 32.1942000, 48.2436000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79433, 'Shīrvān', 'Shirvan', 'Shirvan,Shīrvān,shyrwan,شیروان', 37.3966900, 57.9295200, 'IR', '2015-07-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79434, 'Shiraz', 'Shiraz', 'Chimaz,Chiraz,Gorad Shyraz,SYZ,Schiras,Sheroz,Shiraz,Shīrāz,Siraz,Siraza,Sirazas,Sirazo,Siráz,Sjiraz,Sziraz,Xiraz,chi ras,she la zi,shirazi,shirazu,shyraz,silajeu,Ŝirazo,Şiraz,Şîraz,Širaz,Širazas,Šíráz,Šīrāz,Šīrāza,Σιράζ,Горад Шыраз,Шероз,Шираз,Շիրազ,שיראז,شيراز,شیراز,ชีราซ,შირაზი,シーラーズ,設拉子,시라즈', 29.6103100, 52.5311300, 'IR', '2014-07-21', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79435, 'Sharīfābād', 'Sharifabad', 'Sharifabad,Sharīfābād,sharyf abad,shryf abad,شريف آباد,شَريف آباد', 35.4275000, 51.7852800, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79436, 'Shalamzār', 'Shalamzar', 'Shalamzar,Shalamzār,shlmzar,شلمزار', 32.0453900, 50.8171400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79437, 'Shahr-e Kord', 'Shahr-e Kord', 'CQD,QHK,Shahr Kord,Shahr Kurd,Shahr-e Kord,Shahrekord,Shakhre-Kord,shhr krd,Шахре-Корд,شهر كرد', 32.3255600, 50.8644400, 'IR', '2016-07-11', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79438, 'Shahr-e Bābak', 'Shahr-e Babak', 'Shahr Babak,Shahr Bābak,Shahr-e Babak,Shahr-e Bābak,Shahr-i-Babak,Shahr-i-Bābak,shhr babk,شهر بابک', 30.1165000, 55.1186000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79439, 'Shaft', 'Shaft', 'Bazar Shaft,Bāzār Shaft,Shaft,shft,شفت', 37.1702000, 49.3998000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79440, 'Shādegān', 'Shadegan', 'Fallabiyeh,Fallahiyeh,Fallehiyeh,Fallābīyeh,Fallāḩīyeh,Shadegan,Shadeganskie,Shadgan,Shādegān,Shādgān,shadgan,Шадеганские,شادگان', 30.6492400, 48.6649700, 'IR', '2016-09-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79441, 'Shabestar', 'Shabestar', 'Chabiastar,Shabestar,Shabiastar,Shabistar,shbstr,Шабестар,شبستر', 38.1804000, 45.7028000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79442, 'Seyah Cheshmeh', 'Seyah Cheshmeh', 'Kara Aineh,Qareh Eyni,Qareh Eynī,Seyah Cheshmeh,Siah Chashmeh,Siah Cheshmeh,Siyah Cheshmeh,Siāh Chashmeh,Sīyah Cheshmeh,Sīāh Cheshmeh,qarih ainy,syah chishmih,syh chshmh,سياه چِشمِه,سيه چشمه,قَرِه اِينی', 39.0650800, 44.3841600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79443, 'Semnān', 'Semnan', 'Samnan,Samnān,Semnan,Semnān,smnan,Семнан,سمنان', 35.5769100, 53.3920500, 'IR', '2013-09-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79444, 'Semīrom', 'Semirom', '', 31.4166700, 51.5666700, 'IR', '2006-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79445, 'Semīrom', 'Semirom', 'Samirum,Semirom,Semīrom,Simrom,Sīmrom,smyrm,سمیرم', 31.4141800, 51.5694400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79446, 'Sāveh', 'Saveh', 'Sava,Saveh,Sāveh,sawh,Сава,ساوه', 35.0213000, 50.3566000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79447, 'Sarvestān', 'Sarvestan', 'Sarvestan,Sarvestān,Sarvistan,Sarvistān,srwstan,سروستان', 29.2735000, 53.2203000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79448, 'Sarvābād', 'Sarvabad', 'Sarrabad,Sarrābād,Sarvabad,Sarvābād,Saulawa,Saulāwa,Sulaveh,Sūlāveh,srw abad,سرو آباد', 35.3126000, 46.3669000, 'IR', '2017-01-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79449, 'Sari', 'Sari', 'SRY,Sari,Sari i Iran,Saris,Sariyo,Sarí,Sarî,Shahr-i-Tajan,Shari-i-Tajan,Sori,Szari,Szári,Sárí,Sārī,sa li shi,sali,sari,sary,sary  ayran,Σάρι,Сари,Сарі,Сорӣ,Սարի,سارى,ساري,ساری,ساری، ایران,सारी,სარი,サーリー,薩里市,사리', 36.5633200, 53.0600900, 'IR', '2013-05-12', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79450, 'Sardasht', 'Sardasht', 'Sardasht,srdsht,سردشت', 36.1552000, 45.4788000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79451, 'Sardasht', 'Sardasht', 'Sardasht,Sardasht-e Bashakerd,Sardasht-e Bashākerd,srdsht,srdsht bshakrd,سردشت,سردشت بشاکرد', 26.4559000, 57.9028000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79452, 'Sarbīsheh', 'Sarbisheh', 'Sar-bice,Sarbisheh,Sarbīsheh,srbyshh,سربیشه', 32.5756600, 59.7982100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79453, 'Sarāyān', 'Sarayan', 'Sara''ian,Sarayan,Sarāyān,Sarā’īān,Siryan,Sīryān,srayan,سرایان', 33.8601700, 58.5216600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79454, 'Sarābleh', 'Sarableh', 'Sarableh,Sarābleh,srablh,سرابله', 33.7677200, 46.5657800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79455, 'Sarāb-e Dowreh', 'Sarab-e Dowreh', 'Sarab Darreh,Sarab Doreh,Sarab Dowrah,Sarab Dowreh,Sarab-e Do Rah,Sarab-e Dowreh,Sarabdowreh,Sarāb Darreh,Sarāb Doreh,Sarāb Dowrah,Sarāb Dowreh,Sarāb-e Do Rah,Sarāb-e Dowreh,Sarābdowreh,srab dwrh,سراب دوره', 33.5639000, 48.0221000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79456, 'Sarāb', 'Sarab', 'Sarab,Sarāb,srab,سراب', 37.9408000, 47.5367000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79457, 'Saqqez', 'Saqqez', 'Saggiz,Saggız,Saghez,Saghghez,Sakez,Sakezo,Sakiz,Sakkiz,Sakīz,Saqez,Saqqez,Saqqez (2),Saqqiz,Saqqız,Sekkez,Seqiz,sa gai zi,saghiz,sakkeja,sakyz,saqiz,sqz,sqz (1),sqz (2),Саққиз,Секкез,سقز,سقّز (1),سقّز (٢),سَغِز,سَقِّز,سَكيز,سەقز,सक्केज,薩蓋茲', 36.2499200, 46.2735000, 'IR', '2009-03-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79458, 'Sanandaj', 'Sanandaj', 'Gorad Senendehdzh,SDG,Sanandadsch,Sanandadz,Sanandadż,Sanandadž,Sanandago,Sanandaj,Sanandaĝo,Sanandij,Senendec,Senendedzas,Senendedzh,Senendedžas,Senna,Senneh,Sinandij,Sine,Sinneh,Sənəndəc,sa nan da ji,sanandaja,sanandaji,sina,sinih,snndj,Горад Сенендэдж,Санандаџ,Санандаҷ,Сенендедж,Сәнәндәҗ,Սանանդաջ,سنندج,سنە,سِنَّ,سِنِّه,सनंदज,सनंदाज,萨南达季,사난다지', 35.3149500, 46.9988300, 'IR', '2012-08-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79459, 'Salmās', 'Salmas', 'Dilmagan,Dilman,Dīlmagān,Dīlman,Salmas,Salmās,Shahpoor,Shahpur,Shapur,Shāhpūr,slmas,Салмас,سلماس', 38.1973000, 44.7653000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79460, 'Soleh Bon', 'Soleh Bon', 'Soleh Bon,slh bn,سله بن', 35.7684100, 52.5609100, 'IR', '2016-08-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79461, 'Rāmsar', 'Ramsar', 'RZR,Ramsar,Ransar,Rāmsar,Rānsar,Sakht Sar,ramsr,ramusaru,رامسر,ラームサル', 36.9179600, 50.6480200, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79462, 'Shāhīn Dezh', 'Shahin Dezh', 'Sa''in Dezh,Sa''in Qal`eh,Sahin Dazh,Sain Kaleh,Shahin Dezh,Shāhīn Dezh,Sāīn Kaleh,shahyn dzh,Şā’īn Dezh,Şā’īn Qal‘eh,شاهین دژ', 36.6793000, 46.5669000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79463, 'Şaḩneh', 'Sahneh', 'Sahna,Sahneh,Sehneh,shnh,Şaḩneh,صحنه', 34.4813000, 47.6908000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79464, 'Sabzevar', 'Sabzevar', 'AFZ,Sabzawar,Sabzawār,Sabzevar,Sabzevār,Sabzewar,Sabzivor,Sebzevar,Səbzivar,sa bo ze wa er,sab si war,sabzevara,sbzwar,Сабзевар,Сабзивор,Себзевар,سبزوار,सब्ज़ेवार,ซับซีวาร์,薩卜澤瓦爾', 36.2126000, 57.6819100, 'IR', '2014-05-28', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79465, 'Sa‘ādat Shahr', 'Sa`adat Shahr', 'Sa''adat Abad,Sa`adat Shahr,Sa`adatabad,Sa‘ādat Shahr,Sa‘ādatābād,Sa’ādat Ābād,سعادت شهر', 30.0792100, 53.1346400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79466, 'Rūdsar', 'Rudsar', 'Rud-i-Sar,Rudsar,Rūd-i-Sar,Rūdsar,rwdsr,رودسر', 37.1376100, 50.2880000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79467, 'Narmāshīr', 'Narmashir', 'Narmashir,Narmāshīr,Rostamabad,Rostamābād,nrmashyr,rstm abad,رستم آباد,نرماشير', 28.9521600, 58.6977300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79468, 'Roshtkhvār', 'Roshtkhvar', 'Rash Khar,Rashkhvan,Rashkhvān,Rashtkhvar,Rashtkhvār,Roshkhvar,Roshkhvār,Roshtehkhvar,Roshtehkhvār,Roshtkhar,Roshtkhvar,Roshtkhvār,Roshtkhār,Rushkar,Rūshkār,rshtkhwar,رشتخوار', 34.9751200, 59.6248200, 'IR', '2016-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79469, 'Robāţ Karīm', 'Robat Karim', 'Robat Karim,Robāţ Karīm,Shahriar,Shahryar,Shahryār,rbat krym,رباط كريم', 35.4846000, 51.0829000, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79470, 'Reẕvānshahr', 'Rezvanshahr', 'Razvand,Rezvandeh,Rezvanshahr,Rezvāndeh,Rezvānshahr,Reẕvāndeh,Reẕvānshahr,Rizvand,Rizwand,rdwandh,rdwanshhr,رضوانده,رضوانشهر', 37.5497600, 49.1370300, 'IR', '2016-01-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79471, 'Razan', 'Razan', 'Razan,rzn,رزن', 35.3866000, 49.0338000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79472, 'Rāvar', 'Ravar', 'Ravar,Rāvar,rawr,راور', 31.2656200, 56.8054500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79473, 'Ravānsar', 'Ravansar', 'Ravansar,Ravānsar,Rawansir,Rawānsīr,rwansr,روانسر', 34.7153000, 46.6533000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79474, 'Rasht', 'Rasht', 'RAS,Raixt,Rascht,Rasht,Rasjt,Rast,Rasto,Raszt,Raŝto,Rašt,Reshh,Resht,Rest,Restas,Reşt,Reštas,Rəşt,la shen te,lasyuteu,rashuto,rasta,reshti,rsht,Рашт,Решт,Рещ,Рәшт,Ռեշտ,ראשת,رشت,ڕەشت,रश्त,แรชต์,რეშთი,ラシュト,拉什特,라슈트', 37.2761100, 49.5886200, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79475, 'Rāmshīr', 'Ramshir', 'Khalafabad,Khalafābād,Khalas Abad,Ram Shahr,Ramshir,Rāmshīr,khlf abad,ramshyr,خلف آباد,رامشیر', 30.8931500, 49.4078700, 'IR', '2016-11-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79476, 'Rāmīān', 'Ramian', 'Rameyan,Ramian,Ramiyan,Rāmeyān,Rāmīyān,Rāmīān,ramyan,راميان', 37.0159800, 55.1412300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79477, 'Rāmhormoz', 'Ramhormoz', 'Ram Hormuz,Ramhormoz,Ramuz,Rām Hormuz,Rāmhormoz,Rāmuz,ramhrmz,رامهرمز', 31.2799700, 49.6035100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79478, 'Rafsanjān', 'Rafsanjan', 'Bahramabad,Bahrāmābād,RJN,Rafsandzhane,Rafsanjan,Rafsanjān,Rafsinjan,Rafsinjān,rfsnjan,Рафсанджане,رفسنجان', 30.4067000, 55.9939000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79479, 'Rābor', 'Rabor', 'Raber,Rabor,Rabur,Rahbur,Rābor,Rābur,Rāhbur,rabr,رابر', 29.2912000, 56.9131000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79480, 'Qūchān', 'Quchan', 'Gochan,Quchan,Qūchān,qwchan,قوچان', 37.1060000, 58.5095500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79481, 'Qorveh', 'Qorveh', 'Qorveh,Qurve,Qurveh,qrwh,قروه', 35.1664000, 47.8056400, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79482, 'Qom', 'Qom', 'Dakbayan sa Qom,Ghom,Gorad Kum,Homo,Kom,Kum,Kum shaary,Kumas,QUM,Qom,Qum,Qûm,gomu,koma,ku mu,kum,kuvom,qm,qwm,Ĥomo,Горад Кум,Ком,Кум,Кум шаары,Қум,קום,قم,قوم,कोम,குவோம்,ゴム,库姆,쿰', 34.6401000, 50.8764000, 'IR', '2016-02-12', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79483, 'Qohūrd-e ‘Olyā', 'Qohurd-e `Olya', 'Ghohorde Olya,Ghohordé Olya,Khokhurd Bala,Khokhūrd Bāla,Qohord,Qohord-e Bala,Qohord-e Bālā,Qohord-e `Olya,Qohord-e ‘Olyā,Qohurd-e `Olya,Qohūrd-e ‘Olyā,qhrd bala,قهرد بالا,قهورد علیا', 35.4397900, 48.0736200, 'IR', '2016-11-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79484, 'Qīr', 'Qir', 'Qir,Qir va Karzin,Qīr,Qīr va Kārzīn,qyr,qyr w karzyn,قیر,قیر و کارزین', 28.4825000, 53.0346000, 'IR', '2017-01-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79485, 'Qeshm', 'Qeshm', 'Bandar-e Qeshm,Gheshm,Keshm,Qeshm,Qishm,qshm,Кешм,قشم', 26.9492000, 56.2691000, 'IR', '2013-11-27', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79486, 'Qazvin', 'Qazvin', 'Dakbayan sa Qazvin,GZW,Gazvin,Kazvin,Kazvinas,Kazvín,Kazwin,Kuazvin,Qazvin,Qazvín,Qazvīn,Qazwen,Qazwên,Qəzvin,gazuvu~in,jia ci wen,kajeubin,kazvina,kxs win,qzwyn,Казвин,Казвін,Къазвин,Қазвин,Ղազվին,قزوين,قزوین,قەزوین,कज़्वीन,กอซวีน,ყაზვინი,ガズヴィーン,加兹温,카즈빈', 36.2687700, 50.0041000, 'IR', '2013-05-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79487, 'Qaşr-e Shīrīn', 'Qasr-e Shirin', 'Ghasr-i-shirin,Ghasr-shirin,Ghasr-shīrīn,Ghasr-ī-shīrīn,Qasr-e Shirin,Qasr-i-Shirin,Qasr-ī-Shīrīn,Qaşr-e Shīrīn,qsr shyryn,قصر شيرين', 34.5156000, 45.5791000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79488, 'Qarnābād', 'Qarnabad', 'Qarnabad,Qarnābād,qrn abad,قرن آباد', 36.8220300, 54.5922200, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79489, 'Qarah Ẕīā’ od Dīn', 'Qarah Zia'' od Din', 'Ghareh Ziya'' Oddin,Ghareh Ziya’ Oddin,Qara Zia ud Din,Qara Zīa ud Dīn,Qarah Zia'' od Din,Qarah Ẕīā’ od Dīn,Qaraziadin,Qareh Zeya ed Din,Qareh Zeyā ed Dīn,Qareh Zia'' od Din,Qareh Ziya ''Eddin,Qareh Zīyā ’Eddīn,Qareh Ẕīā’ od Dīn,قره ضیاء الدین', 38.8915000, 45.0255000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79490, 'Shahr-e Qods', 'Shahr-e Qods', 'Karaj,Qal`eh Hasan,Qal`eh-ye Hasan Khan,Qal‘eh Hasan,Qal‘eh-ye Ḩasan Khān,Qods,Shahr-e Qods,Shahrak-e Qods,karaj,qds,shhr qds,shhrk qds,شهر قدس,شهرك قدس,قدس,قلعه حسن خان,قَلعِه هَسَن,كَرَج', 35.7214000, 51.1090000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79491, 'Qal‘eh Ganj', 'Qal`eh Ganj', 'Ghal`eh Ganj,Ghal‘eh Ganj,Kalat-i-Ganj,Kalateh-ye Ganj,Kalāt-i-Ganj,Kalāteh-ye Ganj,Mohammadabad,Moḩammadābād,Qal`eh Ganj,Qal`eh-ye Ganj,Qal‘eh Ganj,Qal‘eh-ye Ganj,قلعه گنج', 27.5236000, 57.8811000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79492, 'Rūdān', 'Rudan', 'Bala Shahr,Bala Shahr-e Deh Barez,Bālā Shahr,Bālā Shahr-e Deh Bārez,Deh Barez,Deh Bariz,Deh Bārez,Deh Bāriz,Deh Dariz,Deh Dāriz,Dehbarez,Dehbārez,Qal`eh-ye Deh Barez,Qal`eh-ye Deh-e Barez,Qal‘eh-ye Deh Bārez,Qal‘eh-ye Deh-e Bārez,Rudan,Rugan,Rūdān,Rūgan,bala shahr,bala shahri dih bariz,dhbarz,rwdan,rwgan,بالا شَهر,بالا شَهرِ دِه بارِز,دهبارز,رودان,روگَن,قَلعِۀ دِهِ بارِز', 27.4419400, 57.1919800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79493, 'Qal‘eh-ye Khvājeh', 'Qal`eh-ye Khvajeh', 'Qal''eh Khajeh,Qal`eh Khvajeh,Qal`eh-ye Khvajeh,Qal`eh-ye Khvajeh Bala,Qal‘eh Khvājeh,Qal‘eh-ye Khvājeh,Qal‘eh-ye Khvājeh Bālā,Qal’eh Khājeh,qlʿh khwajh,قلعه خواجه,قلعه خواجه بالا', 32.2064000, 49.4437000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79494, 'Arakvāz-e Malekshāhī', 'Arakvaz-e Malekshahi', 'Arakvaz,Arakvaz-e Malekshahi,Arakvāz,Arakvāz-e Malekshāhī,Arkavazi,Arkavāzī,Arkvaz,Arkvāz,Arkwaz,Arkwāz,Qal`eh Darreh,Qal‘eh Darreh,arkwaz,arkwaz mlkshahy,ارکواز,ارکواز ملکشاهی,قَلعِه دَرِّه', 33.3828000, 46.5983000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79495, 'Farrokh Shahr', 'Farrokh Shahr', 'Farrokh Shahr,Qahferokh,Qahofrokh,Qatarokh,Qehfarukh,frkh shhr,qahfirukh,qahufrukh,qatarukh,فرّخ شهر,قَتَرُخ,قَهفِرُخ,قَهُفرُخ', 32.2717400, 50.9800800, 'IR', '2012-01-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79496, 'Qā’en', 'Qa''en', 'Qa''en,Qain,Qayen,Qaīn,Qāyen,Qā’en,Shahr-e Qayen,Shahr-e Qāyen,qayn,قائن,قاین', 33.7265400, 59.1843900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79497, 'Sarpol-e Z̄ahāb', 'Sarpol-e Zahab', 'Pol-e Zahab,Pol-e Zohab,Pol-e Z̄ahāb,Pol-e Z̄ohāb,Sar-e Pol-e Zahab,Sar-e Pol-e Z̄ahāb,Sar-i-Pul Zuhab,Sar-ī-Pūl Zūhāb,Sari-Pul,Sarpol,Sarpol-e Zahab,Sarpol-e Z̄ahāb,Sarī-Pūl,sr pl dhhab,سر پل ذهاب', 34.4610900, 45.8626400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79498, 'Pol-e Sefīd', 'Pol-e Sefid', 'Pol Sefid,Pol-e Sefid,Pol-e Sefīd,pl sfyd,پل سفيد', 36.1178700, 53.0553100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79499, 'Poldokhtar', 'Poldokhtar', 'Pol Dokhtar,Pol-e Dokhtar,Poldokhtar,Pul-i-Dukhtar,pl dkhtr,pldkhtr,پل دختر,پلدختر', 33.1524900, 47.7101400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79500, 'Poldasht', 'Poldasht', 'Araplar,Pol Dasht,Pol''desht,Pol-e Dasht,Poldasht,Pol’desht,Pul Dasht,aaraplar,pldsht,اَرَپلَر,پلدشت', 39.3480000, 45.0710000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79501, 'Pīshvā', 'Pishva', 'Pichva,Pishva,Pishyan,Pīchvā,Pīshvā,Pīshyān,pychwa,pyshwa,pyshyan,پيشوا,پيشيان,پيچوا', 35.3080000, 51.7267000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79502, 'Piranshahr', 'Piranshahr', 'KHA,Khaneh,Khāneh,Okrug Peronsahr,Okrug Peronšahr,Piran Shahr,Piransaher,Piransahr,Piransar,Piransara,Piranschahr,Piransehr,Piranshahr,Piranshekhr,Piransherkh,Piransjahr,Piranszahr,Piranxahr,Piranşehr,Piranşəhr,Piranšaher,Piranšahr,Piranšāra,Pîranşar,Pīrān Shahr,Pīrānshahr,byranshhr,pi lan sha he er,piranshafuru,pyranshar,pyranshhr,Пероншаҳр,Пираншехр,Піраншерх,بیرانشهر,پیرانشار,پیرانشهر,پیرانشھر,پیرانشہر,ピーラーンシャフル,皮兰沙赫尔', 36.7010000, 45.1413000, 'IR', '2013-10-22', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79503, 'Pāveh', 'Paveh', 'Paveh,Pawah,Paweh,Pāveh,Pāweh,pawh,پاوه', 35.0434000, 46.3565000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79504, 'Pārsābād', 'Parsabad', 'Farsabad,Fārsābād,PFQ,Parsabad,Pārsābād,fars abad,pars abad,Парсабад,فارس آباد,پارس آباد', 39.6482000, 47.9174000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79505, 'Oskū', 'Osku', 'Osku,Oskū,Uzku,Yuzki,askw,اسکو', 37.9150400, 46.1225800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79506, 'Oshnavīyeh', 'Oshnaviyeh', 'Ashnooyeh,Oshnaviyeh,Oshnavīyeh,Oshnovieh,Oshnoviyeh,Oshnovīeh,Oshnovīyeh,Oshnuje,Ushnu,Ushnuiyeh,Ushnū,Ushnūīyeh,ashnwyh,Ошнуйе,اشنويه', 37.0397000, 45.0983000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79507, 'Orūmīyeh', 'Orumiyeh', 'OMH,Orumiyeh,Orūmīyeh,Ourmia,Reza''iyeh,Rezaeyeh,Rezaiyye,Rezâiyye,Rezā’īyeh,Rizaiyeh,Rizāiyeh,Urmia,Urmija,Urmiya,Urmiye,Urmía,Urumija,Urumiyeh,Urūmiyeh,arwmyh,arwmyt,shhrstan arwmyh,Úrmia,Ûrmiye,Урмия,Урумия,אורמיה,أرومية,ارومیه,ارومیّه,شهرستان ارومیه,ܐܘܪܡܝܐ', 37.5527400, 45.0760500, 'IR', '2016-12-21', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79508, 'Omīdīyeh', 'Omidiyeh', 'Omidiyeh,Omidiyeh Sherkat-e Naft,Omīdīyeh,Omīdīyeh Sherkat-e Naft,Sherkat-e Naft,amydyh,امیدیه', 30.7597200, 49.7050000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79509, 'Nūrābād', 'Nurabad', 'Nurabad,Nūrābād,nwr abad,نور آباد', 30.1140500, 51.5217400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79510, 'Nowshahr', 'Nowshahr', 'Bandar-e Now Shahr,NSH,Nau Shahr,Nowshahr,nwshhr,نوشهر', 36.6485200, 51.4962100, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79511, 'Noşratābād', 'Nosratabad', 'Nasratabad Sipi,Nasratābād Sipi,Nosratabad,Nosratabad-e Bala,Nosratabad-e Pa''in,Noşratābād,Noşratābād-e Bālā,Noşratābād-e Pā’īn', 29.9000000, 59.9833300, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79512, 'Nīshābūr', 'Nishabur', 'Nejsaburo,Nejŝaburo,Neyshabur,Neyshābūr,Nichapur,Nisabur,Nischapur,Nishabur,Nishapur,Nishopur,Nişabur,Nīshābūr,Nīshāpūr,nishapu,nysabwr,nyshabwr,nyshapwr,Нишапур,Нишопур,نيسابور,نیشابور,نیشاپور,ニシャプー', 36.2132900, 58.7957500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79513, 'Neyrīz', 'Neyriz', 'Neyriz,Neyrīz,Niriz,Nīrīz,nyryz,نیریز', 29.1988000, 54.3278000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79514, 'Neqāb', 'Neqab', 'Neqab,Neqāb,nqab,نقاب', 36.7079200, 57.4214600, 'IR', '2016-04-10', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79515, 'Nekā', 'Neka', 'Naranj Bagh,Neka,Neka'',Nekā,Nekā’,Nika,Nāranj Bāgh,Nīkā,naranj bagh,nka,nyka,Нека,نارَنج باغ,نكا,نكاء,نيكا', 36.6507900, 53.2990500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79516, 'Naz̧arābād', 'Nazarabad', 'Nazarabad,Nazarabad-e Bozorg,Naz̧arābād,Naz̧arābād-e Bozorg,nazarabadi buzurg,nzr abad,نظر آباد,نَظَرابادِ بُزُرگ', 35.9541100, 50.6060700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79517, 'Naţanz', 'Natanz', 'Natanz,Naţanz,ntnz,نطنز', 33.5111800, 51.9180800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79518, 'Nashtārūd', 'Nashtarud', 'Nashta Rud,Nashtarood,Nashtarud,Nashtā Rūd,Nashtārūd,Neshta Rud,Neshtā Rūd,nshtarwd,نشتارود', 36.7509000, 51.0236200, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79519, 'Naqadeh', 'Naqadeh', 'Nagadeh,Naghadeh,Naghdeh,Nakhuda,Naqadeh,Nākhuda,nqdh,نقده', 36.9553000, 45.3880000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79520, 'Namīn', 'Namin', 'Namin,Namīn,nmyn,نمين', 38.4269000, 48.4839000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79521, 'Nā’īn', 'Na''in', 'Na''in,Naeyn,Nāeyn,Nā’īn,nayyn,نائین', 32.8600600, 53.0874900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79522, 'Nahāvand', 'Nahavand', 'Nachavant,Nagavande,Nahavand,Nahāvand,Nehavend,Nehāvend,Nihavand,Nīhāvand,nhawnd,nihavu~ando,Ναχαβάντ,Нагаванде,نهاوند,ニハーヴァンド', 34.1908800, 48.3744600, 'IR', '2016-08-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79523, 'Marāveh Tappeh', 'Maraveh Tappeh', 'Maraveh,Maraveh Tappeh,Maravehtepe,Marveh Tappeh,Marāveh,Marāveh Tappeh,Moraveh Tappeh,Morāveh Tappeh,mrawh tph,مراوه تپه', 37.9041000, 55.9559600, 'IR', '2015-02-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79524, 'Mollās̄ānī', 'Mollasani', 'Molla Sany,Mollasani,Mollā Sāny,Mollās̄ānī,Mulla Sani,Mulla Sāni,Ramin,Rāmīn,mla thany,ramyn,رامین,ملا ثانی', 31.5847000, 48.8858700, 'IR', '2017-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79525, 'Mohr', 'Mohr', 'Mehr,Mohr,Mohur,Mohur-i- Saiyidan,Mohur-i- Saiyidān,Mur,Mūr,mhr,muhr,shhrstan muhr,شهرستان مُهر,مهر,مُهر', 27.5552000, 52.8836000, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79526, 'Moḩammadābād', 'Mohammadabad', 'Mohammadabad,Mohammadabad-e Rigan,Moḩammadābād,Moḩammadābād-e Rīgān,Muhammadabad,Muhammadābād,mhmd abad,محمد آباد', 28.6687700, 59.0734100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79527, 'Mīnūdasht', 'Minudasht', 'Minudasht,Mīnūdasht,mynwdsht,مينودشت', 37.2301500, 55.3721100, 'IR', '2016-01-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79528, 'Mīnāb', 'Minab', 'Minab,Mīnāb,mynab,Минаб,ميناب', 27.1310400, 57.0871600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79529, 'Mīāneh', 'Mianeh', 'Meyaneh,Meyāneh,Miane,Mianeh,Miyaneh,Mīyaneh,Mīāneh,myanh,میانه', 37.4210000, 47.7150000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79530, 'Mīāndoāb', 'Miandoab', 'Meyandoab,Meyāndoāb,Miandoab,Miandow Ab,Miandowab,Mianduab,Miyandoab,Miyanduab,Miyāndūāb,Mīyāndoāb,Mīāndow Āb,Mīāndowāb,Mīāndoāb,Mīāndūāb,myandwab,Миандоаб,میاندوآب', 36.9666700, 46.1096100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79531, 'Meybod', 'Meybod', 'Maibud,Meybod,mybd,ميبد', 32.2501400, 54.0165800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79532, 'Meshgīn Shahr', 'Meshgin Shahr', 'Kheyav,Kheyāv,Khiav,Khiov,Khiyav,Khiyov,Khīyāv,Khīāv,Meshgin Shahr,Meshgīn Shahr,Meshkin Shahr,Meshkīn Shahr,Mishgin,mshgyn shhr,مشگين شهر', 38.3990000, 47.6820000, 'IR', '2015-07-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79533, 'Mahrīz', 'Mahriz', 'Mahriz,Mahrīz,Mehriz,Mehrīz,mhryz,mihryz,مهريز,مِهريز', 31.5842800, 54.4428000, 'IR', '2013-10-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79534, 'Mehrān', 'Mehran', 'Mansurabad,Mansūrābād,Mehran,Mehrān,manswr abad,mhran,مهران,مَنسور آباد', 33.1222000, 46.1646000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79535, 'Masjed Soleymān', 'Masjed Soleyman', 'Masjed Soleiman,Masjed Soleyman,Masjed Soleymān,Masjed-e Soleyman,Masjed-e Soleymān,Masjid-i-Sulaiman,msjd slyman,مسجد سلیمان', 31.9364000, 49.3039000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79536, 'Maşīrī', 'Masiri', 'Masiri,Masīrī,Maşīrī,msyry,مصیری', 30.2458400, 51.5223300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79537, 'Bardsīr', 'Bardsir', 'Bardesir,Bardesīr,Bardsir,Bardsīr,Deh-e Now-e Mashiz,Deh-e Now-e Mashīz,Mashiz,Mashīz,Mshiz,Qal`eh-ye Mashiz,Qal‘eh-ye Mashīz,brdsyr,بردسیر', 29.9226600, 56.5743300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79538, 'Mashhad', 'Mashhad', 'Gorad Meshkhed,MHD,Masant,Masat,Maschhad,Mashad,Mashado,Mashhad,Mashkhad,Masyhad,Maxhad,Maŝhado,Maşat,Mašhad,Mașhad,Meixad,Meshed,Mesheda,Meshedas,Meshkhed,MeshkhӀed,Meszhed,Mexed,Meşhed,Mešheda,Mešhedas,Məshəd,Məşhəd,ma shen ha de,mach had,macukat,masahada,mashuhado,masyuhadeu,meshhedi,mshd,mshhd,Μασάντ,Горад Мешхед,Машхад,Машҳад,Мешхед,МешхӀед,Мешһед,Мәшһәд,Մաշհադ,משהד,مشهد,مشہد,مەشھەد,मशहद,মাশহাদ,ਮਸ਼ਹਦ,மசுகாத்,മശ്‌ഹദ്,มัชฮัด,მეშჰედი,マシュハド,馬什哈德,마슈하드', 36.3155900, 59.5679600, 'IR', '2012-09-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79539, 'Marvdasht', 'Marvdasht', 'Marvdasht,mrwdsht,مرودشت', 29.8742000, 52.8025000, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79540, 'Marīvān', 'Marivan', 'Dezh Shahpur,Dezh Shapoor,Dezh Shāhpūr,Marivan,Marīvān,Qal`eh-ye Marivan,Qal‘eh-ye Marīvān,dizh shahpwr,mrywan,دِژ شاهپور,قَلعِۀ مَريوان,مریوان', 35.5182900, 46.1829800, 'IR', '2017-01-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79541, 'Marand', 'Marand', 'Marand,Morand,mrnd,Маранд,مرند', 38.4329000, 45.7749000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79542, 'Marāgheh', 'Maragheh', 'ACP,Maragheh,Maraghen,Marāgheh,Marāghen,mraghh,مراغه', 37.3920600, 46.2390900, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79543, 'Manūjān', 'Manujan', 'Jarian,Jārīān,Manujan,Manūjān,Posht Qalat,Posht Qalāt,Qal`eh-ye Manujan,Qal‘eh-ye Manūjān,jaryan,mnwjan,جاریان,منوجان', 27.4069800, 57.5012800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79544, 'Malekān', 'Malekan', 'Malek Kandi,Malek Kandī,Malekan,Malekān,Malik Kandi,Malikkand,malik kandy,mlkan,ملکان,مَلِك كَندی', 37.1425800, 46.1034500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79545, 'Malāyer', 'Malayer', 'Daulatabad,Daūlatābād,Dowlatabad,Dowlatābād,Malayer,Malāyer,mlayr,ملایر', 34.3015800, 48.8216600, 'IR', '2016-10-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79546, 'Malārd', 'Malard', 'Malar,Malard,Malār,Malārd,Melard,Melārd,malar,mlard,ملارد,مَلار', 35.6659000, 50.9767000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79547, 'Mākū', 'Maku', 'Maku,Mākū,makw,ماکو', 39.2951300, 44.4982200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79548, 'Māhneshān', 'Mahneshan', 'Mah Neshan,Mahneshan,Māh Neshān,Māhneshān,mah nshan,mahnshan,ماه نشان,ماهنشان', 36.7444000, 47.6725000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79549, 'Maḩmūdābād', 'Mahmudabad', 'Mahmudabad,Maḩmūdābād,mhmwd abad,محمود آباد', 36.6319100, 52.2628600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79550, 'Maḩallāt', 'Mahallat', 'Mahallat,Mahallat Bala,Mahallat-e Bala,Mahallāt Bāla,Maḩallāt,Maḩallāt-e Bālā,mahalat bala,mahalati bala,mhlat,محلات,مَحَلّاتِ بالا,مَهَلّات بالَ', 33.9110800, 50.4531700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79551, 'Mahābād', 'Mahabad', 'Mahabad,Mahābād,Makhabad,Mehabad,Mehābād,Saujbulagh,Sāūjbulāgh,mah abad,mhabad,mih abad,Махабад,مهاباد,مَه آباد,مِه آباد', 36.7631000, 45.7222000, 'IR', '2012-01-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79552, 'Lordegān', 'Lordegan', 'Lord Jan,Lordagan,Lordagān,Lordajan,Lordajān,Lordakan,Lordakān,Lordegan,Lordegān,Lordgan,Lordgān,Lurdagan,Lurdagān,lrdgan,lurd jan,لردگان,لُرد جَن', 31.5133800, 50.8267200, 'IR', '2016-12-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79553, 'Līkak', 'Likak', 'Lak Lak,Lakak,Likak,Likak-e Bahmani,Lirkak,Līkak,Līkak-e Bahmanī,Līrkak,Qal`eh-i-Likak,Qal`eh-ye Likak,Qal‘eh-i-Likak,Qal‘eh-ye Līkak,Seh Laklak,lak lak,lakak,lykk,lykk bhmny,lyrkak,sih laklak,سِه لَكلَك,قَلعِۀ ليكَك,ليركَك,ليکک,لَك لَك,لَكَك,لیکک بهمنی', 30.8949000, 50.0931000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79554, 'Shahr-e Qadīm-e Lār', 'Shahr-e Qadim-e Lar', 'LRR,Lar,Larestan,Lār,Shahr-e Qadim-e Lar,Shahr-e Qadīm-e Lār,lar,shhr qdym lar,شهر قدیم لار,لار', 27.6833600, 54.3417200, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79555, 'Langarūd', 'Langarud', 'Langarood,Langarud,Langarūd,Langerud,Langerūd,Shahr-e Langarud,Shahr-e Langarūd,lngrwd,لنگرود', 37.1970100, 50.1535100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79556, 'Lāmerd', 'Lamerd', 'LFM,Lamard,Lamerd,Lāmard,Lāmerd,lamrd,لامرد', 27.3340000, 53.1790000, 'IR', '2017-01-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79557, 'Dasht-e Lati', 'Dasht-e Lati', 'Dasht-e Lali,Dasht-e Lati,Dasht-e Lālī,Lali,Lali Pelayen,Lālī,Lālī Pelāyen,dsht laly,laly,دشت لالی,لالی', 32.3290000, 49.0936000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79558, 'Lāhījān', 'Lahijan', 'Lahijan,Lāhījān,lahyjan,لاهیجان', 37.2073200, 50.0039700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79559, 'Kūhdasht', 'Kuhdasht', 'Kuh-i-Dasht,Kuhdasht,Kūh-ī-Dasht,Kūhdasht,kwhdsht,کوهدشت', 33.5333500, 47.6099900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79560, 'Kūhbanān', 'Kuhbanan', 'Koobanan,Kuh Banan,Kuh Baneh,Kuhbanan,Kuhbonan,Kūh Baneh,Kūh Banān,Kūhbanān,Kūhbonān,kwhbnan,کوهبنان', 31.4102900, 56.2825500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79561, 'Kord Kūy', 'Kord Kuy', 'Kord Ku,Kord Kuy,Kord Kū,Kord Kūy,Kurd Kui,Kurd Kūi,krd kwy,krdkwy,kurd kw,كردكوی,كُرد كو,کرد کوی', 36.7930700, 54.1121400, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79562, 'Komījān', 'Komijan', 'Khumajan,Khūmajān,Komazan,Komejan,Komejān,Komeyjan,Komeyjān,Komijan,Komizan,Komāzān,Komījān,Komīzān,Kumizan,Kūmīzān,kmyjan,كميجان', 34.7214200, 49.3265300, 'IR', '2017-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79563, 'Kīsh', 'Kish', 'Kish,Kīsh,kysh,Киш,كيش', 26.5577800, 54.0194400, 'IR', '2012-01-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79564, 'Khvoy', 'Khvoy', 'KHY,Khoi,Khowy,Khoy,Khvoy,khwy,خوی', 38.5503000, 44.9521000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79565, 'Khowrmūj', 'Khowrmuj', 'Khormoj,Khormuj,Khormūj,Khowr Muj,Khowr Mūj,Khowrmuj,Khowrmūj,Khurmoj,Khurmudj,Khurmuj,Khūrmūj,khwrmwj,خورموج', 28.6543000, 51.3800000, 'IR', '2016-01-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79566, 'Khūr', 'Khur', 'Khowr,Khur,Khvor,Khūr,khwr,خور', 33.7751200, 55.0832900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79567, 'Khvānsār', 'Khvansar', 'Khansar,Khavansar,Khonsar,Khunsar,Khvansar,Khvonsar,Khvonsār,Khvānsār,Khūnsār,Shahr-e Khvonsar,Shahr-e Khvonsār,khwansar,خوانسار', 33.2205200, 50.3149700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79568, 'Khorramshahr', 'Khorramshahr', 'Al-Muhammarah,Choremsehras,Choremšehras,Chorramsahr,Chorramschahr,Chorramszahr,Chorramšahr,Horamsaher,Horamšaher,Huerremsehr,Hürremşehr,Jorramchar,Khoramshahr,Khorram Shahr Abadan,Khorram Shahr Ābādān,Khorramchahre,Khorramshahr,Khorramxahr,Khorremshekhr,Khunin Shahr,Khurramshahr,Khūnīn Shahr,Koramshar,Koramsjar,Mohammerah,Muhammerah,Xürrəmşəhr,almhmrt,bndr khrmshhr,horramushafuru,huo la mu sha he er,khrmshhr,khurramasahara,Корамшар,Хорремшехр,Хуррамшаҳр,المحمرة,بندر خرمشهر,خرمشهر,خرمشھر,खुर्रमशहर,ホッラムシャフル,霍拉姆沙赫尔', 30.4407900, 48.1842800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79569, 'Khorramabad', 'Khorramabad', 'KHD,Khorramabad,Khorramābād,Khur Ramabad,Khur Ramābād,Khurramobod,khrm abad,Хуррамобод,خرم آباد', 33.4877800, 48.3558300, 'IR', '2016-01-23', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79570, 'Khonj', 'Khonj', 'Khonj,Khunj,Khunji,khnj,خنج', 27.8913000, 53.4344000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79571, 'Khondāb', 'Khondab', 'Khandab,Khondab,Khondāb,Khāndāb,khandab,khndab,خانداب,خنداب', 34.3928000, 49.1841000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79572, 'Khomeyn', 'Khomeyn', 'Khomein,Khomeyn,Khomeīn,Khowmeyn,Khumain,Khūmaīn,khmyn,khumin,خمين,خُومِين', 33.6422500, 50.0789000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79573, 'Khomārlū', 'Khomarlu', 'Khomarlu,Khomārlū,khmarlw,خمارلو', 39.1489000, 47.0347000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79574, 'Kherāmeh', 'Kherameh', 'Karameh,Kharameh,Kharāmeh,Kherameh,Kherāmeh,khramh,خرامه', 29.4989600, 53.3119900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79575, 'Khānī Yek', 'Khani Yek', 'Khani Yek,Khānī Yek', 29.8916700, 51.6866700, 'IR', '2012-01-16', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79576, 'Bandar-e Khamīr', 'Bandar-e Khamir', 'Bandar-e Khamir,Bandar-e Khamīr,Khamir,Khamīr,Xamir,bandari khamyr,bndr khmyr,bndrkhmyr,khamyr,بندر خمير,بندرخمير,بَندَرِ خَمير,خَمير', 26.9521000, 55.5851000, 'IR', '2015-08-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79577, 'Khalkhāl', 'Khalkhal', 'Harau,Harowabad,Herau,Herauabad,Heroabad,Herow,Herowabad,Herowābād,Heroābād,Hirabad,Hirābād,Khalkhal,Khalkhāl,hrw abad,khlkhal,خلخال,هرو آباد', 37.6183700, 48.5292800, 'IR', '2017-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79578, 'Khalīlābād', 'Khalilabad', 'Khalilabad,Khalīlābād,khlyl abad,خلیل آباد', 35.2539500, 58.2856600, 'IR', '2016-08-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79579, 'Kermanshah', 'Kermanshah', 'Bahtaran,Bakhtaran,Bākhtarān,KSH,Kermansah,Kermansaho,Kermanschah,Kermanshah,Kermanshahan,Kermanshakh,Kermanŝaho,Kermânsâh,Kermānschāh,Kermānshāh,Kermānshāhān,Kirmansah,Kirmanşah,Kirmasan,Kirmaşan,Province de Kermanshah,Provincia de Kermanshah,Provinco Kermansah,Provinco Kermanŝah,Província de Kermanshah,Qahremanshahr,Qahremānshahr,astan krmanshah,ke er man sha he,kerumansha,krmanshah,Керманшах,Кирмоншоҳ,Устони Кирмоншоҳ,استان کرمانشاه,كرمانشاه,کرمانشاه,ケルマーンシャー,克尔曼沙赫', 34.3141700, 47.0650000, 'IR', '2016-11-01', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79580, 'Kerman', 'Kerman', 'Carmana,Dakbayan sa Kerman,Dakbayan sa Kermān,Gorad Kerman,KER,Kerman,Kermanas,Kermano,Kermon,Kermán,Kermān,Kirman,Kirmon,karmana,ke er man,keleuman,kermani,keruman,krman,Горад Керман,Керман,Кирмон,Կերման,כרמאן,كرمان,کرمان,कर्मान,ქერმანი,ケルマーン,克尔曼,케르만', 30.2832100, 57.0787900, 'IR', '2015-10-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79581, 'Kerend-e Gharb', 'Kerend-e Gharb', 'Karand,Karind,Karīnd,Kerend,Kerend-e Gharb,krnd ghrb,کرند غرب', 34.2842000, 46.2423000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79582, 'Kāzerūn', 'Kazerun', 'Kasrun,Kazarun,Kazeroun,Kazerun,Kazeruna,Kāzarūn,Kāzerūn,kazrwn,Казеруна,كازرون', 29.6194900, 51.6541500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79583, 'Kāshmar', 'Kashmar', 'Kashmar,Khashmar,Kāshmar,Soultanabad,Torshiz,Torshīz,Turshiz,Turshīz,kashmr,کاشمر', 35.2383100, 58.4655800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79584, 'Karaj', 'Karaj', 'Heredi,Karadj,Karadje,Karadsch,Karadz,Karadzs,Karadż,Karadž,Karag,Karaj,Karatz,Karaĝ,Karej,Kerec,Keredi,Keredzas,Keredzh,Keredžas,Kerezh,Kərəc,Leredi,PYK,QKC,Qasabeh-e Karaj,Qaşabeh-e Karaj,ka la ji,kairaija,kalaji,karaj,karaji,kha rac,krj,kyaraji,qasabihi karaj,Καράτζ,Карай,Караџ,Караҷ,Кередж,Кереж,כאראג,قَصَبِهِ كَرَج,كرج,کرج,کەرەج,कैरैज,கராஜ்,คาราจ,ქარაჯი,キャラジ,卡拉季,카라지', 35.8326600, 50.9915500, 'IR', '2013-06-15', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79585, 'Kangāvar', 'Kangavar', 'Kangavar,Kangāvar,kngawr,کنگاور', 34.5043000, 47.9653000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79586, 'Kangān', 'Kangan', 'Bandar-e Kangan,Bandar-e Kangān,KNR,Kangan,Kangun,Kangān,bndri kngan,kngan,بندرِ كنگان,كنگان', 27.8340000, 52.0628000, 'IR', '2017-02-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79587, 'Kāmyārān', 'Kamyaran', 'Kamyaran,Kāmyārān,kamyaran,کامیاران', 34.7956000, 46.9355000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79588, 'Kaleybar', 'Kaleybar', 'Kaleybar,Kalibar,Kalipar,Kalībar,Keleibar,Keleivar,klybr,کليبر', 38.8650900, 47.0390900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79589, 'Kalāleh', 'Kalaleh', 'KLM,Kalalah,Kalaleh,Kalālah,Kalāleh,klalh,كلاله', 37.3789900, 55.4930000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79590, 'Kabūdarāhang', 'Kabudarahang', 'Kaboodrahang,Kabud Rahang,Kabudarahang,Kabutarahang,Kabūd Rāhang,Kabūdarāhang,Kabūtarāhang,kbwdr ahng,کبودر آهنگ', 35.2092400, 48.7234100, 'IR', '2017-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79591, 'Eyvān', 'Eyvan', 'Aiwan,Aīwān,Bagh-e Shah,Bagh-i-Shah,Bāgh-e Shāh,Bāgh-ī-Shāh,Eyvan,Eyvan-e Gharb,Eyvān,Eyvān-e Gharb,Juy Zar,Jūy Zar,aywan,aywan ghrb,baghi shah,jwy zar,ايوان,ایوان غرب,باغِ شاه,جوی زَر', 33.8272000, 46.3097000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79592, 'Jūybār', 'Juybar', 'Baghlu,Bāghlū,Juybar,Jūybār,baghlw,jwybar,باغلو,جويبار', 36.6411500, 52.9124400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79593, 'Joghtāy', 'Joghtay', 'Jaghatai,Jaghatāi,Joghatay,Joghatāy,Joghtay,Joghtāy,jghtay,جغتای', 36.6361900, 57.0728400, 'IR', '2016-04-10', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79594, 'Khārk', 'Khark', 'Jazireh Khark,Jazireh-ye Khark,Jazīreh-ye Khārk,Khark,Khārk,khark,Харк,جَزيرِۀ خارك,خارك', 29.2613900, 50.3305600, 'IR', '2013-02-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79595, 'Javānrūd', 'Javanrud', 'Juanru,Jūānrū,Qal`a Juanrud,Qal`a Jūanrūd,Qal`eh Juanrud,Qal`eh Jūānrūd,Qal`eh-ye Javanrud,Qal`eh-ye Javānrūd', 34.7961100, 46.5172200, 'IR', '2006-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79596, 'Jāsk', 'Jask', 'Bandar-e Jask,Bandar-e Jāsk,Jask,Jāsk,bndri jask,jask,بندرِ جاسک,جاسک', 25.6453300, 57.7755200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79597, 'Jongīyeh', 'Jongiyeh', 'Jangeyeh,Jangiyeh,Jangīyeh,Jongiyeh,Jongīyeh', 31.2558300, 48.6166700, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79598, 'Jam', 'Jam', 'Jam,Jam-e Jam,Jamm,Jām-e Jam,Velayat,Velāyat,jami jam,jm,wlayt,جامِ جَم,جم,ولایت', 27.8281700, 52.3253600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79599, 'Jājarm', 'Jajarm', 'Jajarm,Jājarm,jajrm,جاجرم', 36.9501200, 56.3800500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79600, 'Jahrom', 'Jahrom', 'Do,JAR,Jahrom,Jahrum,Jahrūm,dw,jhrm,جهرم,دو', 28.5000000, 53.5605000, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79601, 'Īz̄eh', 'Izeh', 'Izeh,Malamir,Malāmir,aydhh,Īz̄eh,ایذه', 31.8340800, 49.8672500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79602, 'Īlām', 'Ilam', 'Elam,Elām,IIL,Ilam,ailam,aylam,ylam,Īlām,Илам,اِلام,ایلام,يلام', 33.6374000, 46.4227000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79603, 'Hoveyzeh', 'Hoveyzeh', 'Havizeh,Hawiza,Hawizeh,Hawīzeh,Hovayze,Hovayzeh,Hoveyzeh,Huzgan,Hūzgān,hwyzh,هویزه', 31.4619000, 48.0740000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79604, 'Herīs', 'Heris', 'Haris,Harīs,Heris,Herīs,Hiriz,hrys,هريس', 38.2481600, 47.1167800, 'IR', '2015-04-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79605, 'Hendījān', 'Hendijan', 'Hendeyan,Hendeyān,Hendian,Hendijan,Hendijan Kuchek,Hendijar,Hendījān,Hendījān Kūchek,Hendījār,Hendīān,Hindian,Hindijan,Hindīān,hndyjan,هندیجان', 30.2363000, 49.7119000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79606, 'Hashtgerd', 'Hashtgerd', 'Ashjird,Hashtgerd,Hashtjerd,Hashtjird,hashtjird,hshtgrd,هشتگرد,هَشتجِرد', 35.9620000, 50.6799000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79607, 'Harsīn', 'Harsin', 'Harsin,Harsīn,hrsyn,هرسین', 34.2721000, 47.5861000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79608, 'Hamadān', 'Hamadan', 'Ecbatana,HDM,Hamadan,Hamadān,Hamedan,Hamedān,Khamadan,hmdan,Хамадан,همدان', 34.7992200, 48.5145600, 'IR', '2017-02-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79609, 'Ḩājjīābād', 'Hajjiabad', 'Hajiabad,Hajjiabad,Hājīābād,hajy abad,حاجی آباد,Ḩājjīābād', 28.3573500, 54.4233500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79610, 'Ḩājjīābād', 'Hajjiabad', 'Hajjiabad,hajy abad,حاجی آباد,Ḩājjīābād', 28.3091000, 55.9017000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79611, 'Haftkel', 'Haftkel', 'Haftgel,Haftkel,hftgl,hftkl,هفتکل,هفتگل', 31.4468600, 49.5295100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79612, 'Gorgān', 'Gorgan', 'Asterabad,Asterābād,GBT,Gorgan,Gorgān,Gurgan,Gurgon,Gūrgān,Hirkanio,aastir abad,grgan,gwrgan,Горган,Гургон,اَستِر آباد,گرگان,گورگان', 36.8427000, 54.4439100, 'IR', '2017-02-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79613, 'Gonbad-e Kāvūs', 'Gonbad-e Kavus', 'Dashte Gorgan,Gonbad Qabus,Gonbad Qavoos,Gonbad Qābūs,Gonbad-e Kavus,Gonbad-e Kāvūs,Gonbad-e Qabus,Gonbad-e Qābūs,Gunbad-i-Kawas,Gunbad-i-Kawus,Gunbad-i-Kāwās,Gunbad-i-Kāwūs,Gunbad-i-Qabus,Gunbad-i-Qābūs,gnbd kawws,gnbd qabws,گنبد قابوس,گنبد کاووس', 37.2500400, 55.1672100, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79614, 'Gonābād', 'Gonabad', 'Gonabad,Gonābād,Gunabad,Gūnābād,Juymand,Jūymand,gnabad,گناباد', 34.3528700, 58.6836500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79615, 'Golpāyegān', 'Golpayegan', 'Golpayagan,Golpayegan,Golpāyagān,Golpāyegān,Gulpaigan,Gulpāīgān,Shahr-e Golpayegan,Shahr-e Golpāyegān,glpaygan,گلپایگان', 33.4537000, 50.2883600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79616, 'Gīlān-e Gharb', 'Gilan-e Gharb', 'Gilan,Gilan-e Gharb,Gīlān,Gīlān-e Gharb,gylan ghrb,گیلان غرب', 34.1421000, 45.9203000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79617, 'Gerāsh', 'Gerash', 'Gerash,Gerāsh,Girash,Girāsh,grash,گراش', 27.6696600, 54.1358600, 'IR', '2016-10-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79618, 'Gāvbandī', 'Gavbandi', 'Gabandi,Gavbandi,Gāvbandī,gawbndy,گاوبندی', 27.2083000, 53.0361000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79619, 'Garmsār', 'Garmsar', 'Garmsar,Garmsār,Qeshlaq,Qeshlāq,Qishlaq,Shahr-e Qeshlaq,Shahr-e Qeshlāq,grmsar,qishlaq,shahri qishlaq,شَهرِ قِشلاق,قِشلاق,گرمسار', 35.2182400, 52.3408500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79620, 'Germī', 'Germi', 'Garmi,Garmi Ejarood,Garmī,Germi,Germī,grmy,گرمی', 39.0215000, 48.0801000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79621, 'Garmeh', 'Garmeh', 'Garmeh,grmh,گرمه', 36.9870000, 56.2894200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79622, 'Bandar-e Ganāveh', 'Bandar-e Ganaveh', 'Bandar Ganaveh,Bandar Ganāveh,Bandar-e Ganaveh,Bandar-e Ganāveh,Bandar-e Genaveh,Bandar-e Genāveh,Bandar-e-Gonaveh,Bandar-e-Gonāveh,Ganaveh,Ganāveh,Genaveh,Genāveh,Gonaveh,Gonāveh,Kenareh,Kenâreh,bndri gnawh,ganawih,بندرِ گناوه,گَناوِه', 29.5791000, 50.5170000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79623, 'Galūgāh', 'Galugah', 'Galugah,Galūgāh,glwgah,گلوگاه', 36.7273400, 53.8088800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79624, 'Gālīkesh', 'Galikesh', 'Galikash,Galikesh,Galīkesh,Gālīkash,Gālīkesh,galyksh,گاليكش', 37.2725900, 55.4339400, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79625, 'Fūman', 'Fuman', 'Fowman,Fowmen,Fuman,Fumen,Fūman,fwmn,فومن', 37.2240000, 49.3125000, 'IR', '2016-01-28', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79626, 'Fīrūzkūh', 'Firuzkuh', 'Firuzkuh,Fīrūzkūh,Qasabeh-ye Firuz Kuh,Qaşabeh-ye Fīrūz Kūh,fyrwzkwh,فيروزكوه', 35.7567400, 52.7706200, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79627, 'Fīrūzābād', 'Firuzabad', 'Firuzabad,Fīrūzābād,fyrwz abad,فیروز آباد', 28.8438000, 52.5707000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79628, 'Feyẕābād', 'Feyzabad', 'Faizabad,Faizābād,Feyzabad,Feyzābād,Feyẕābād,fyd abad,فیض آباد', 35.0189100, 58.7834300, 'IR', '2016-06-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79629, 'Fareydūnshahr', 'Fareydunshahr', 'Fareydunshahr,Fareydūnshahr,Fereydunshahr,Fereydūnshahr,frydwnshhr,فریدونشهر', 32.9409800, 50.1210000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79630, 'Fereydūnkenār', 'Fereydunkenar', 'Faridun Kinar,Fereidun Kenar,Fereydunkenar,Fereydūnkenār,Fāridūn Kinār,Qasabeh,Qaşabeh,frydwnknar,qasabih,فريدونكنار,قَصَبِه', 36.6864200, 52.5225500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79631, 'Ferdows', 'Ferdows', 'Ferdous,Ferdows,Firdaus,Firdavs,Firdevs,Firdovs,Tun,Tūn,fei er dao si,ferudo~usu,frdws,Фердоус,Фирдавс,فردوس,フェルドゥース,費爾道斯', 34.0185000, 58.1722200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79632, 'Fasā', 'Fasa', 'FAZ,Fasa,Fassa,Fasā,fsa,فسا', 28.9383000, 53.6482000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79633, 'Fāryāb', 'Faryab', 'Fariab,Fariyab,Faryab,Fāryāb,Fārīāb,Pariab,Paryab,Paryāb,Pay Ab,Pārīāb,Pāy Āb,Shahmoradi-ye Faryab,Shahmorādi-ye Fāryāb,faryab,فاریاب', 28.0987000, 57.2318100, 'IR', '2015-04-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79634, 'Fārūj', 'Faruj', 'Farij,Faruj,Fārij,Fārūj,farwj,فاروج', 37.2312100, 58.2190000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79635, 'Fārsān', 'Farsan', 'Farsa,Farsan,Farsian,Farsun,Farsūn,Fārsā,Fārsān,Fārsīān,farsa,farsan,farswn,farsyan,فارسا,فارسان,فارسيان,فَرسون', 32.2569400, 50.5609500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79636, 'Farāshband', 'Farashband', 'Farash,Farashband,Farrash,Farrashband,Farrāsh,Farrāshband,Farāsh,Farāshband,frashbnd,فراشبند', 28.8713000, 52.0916000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79637, 'Farmahīn', 'Farmahin', 'Farmahin,Farmahīn,frmhyn,فرمهين', 34.5038300, 49.6843700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79638, 'Farīmān', 'Fariman', 'Fariman,Farimun,Farīmān,Farīmūn,fryman,فریمان', 35.7068500, 59.8500600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79639, 'pamas', 'pamas', 'Famast,Fāmāst,Gamasb,Gamasp,Gāmāsb,Gāmāsp,Pamas,famast,gamasb,gamasp,pamas,فاماست,پَمَس,گاماسب,گاماسپ', 34.0379100, 48.4620000, 'IR', '2009-11-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79640, 'Fāmenīn', 'Famenin', 'Famanin,Famenin,Faminin,Famīnīn,Fāmanīn,Fāmenīn,famnyn,فامنین', 35.1159300, 48.9733600, 'IR', '2017-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79641, 'Fahraj', 'Fahraj', 'Fahraj,Fahrej,Iranshahr,Irānshahr,Narmashir,Narmāshīr,fhrj,فهرج', 28.9502000, 58.8850000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79642, 'Estahbān', 'Estahban', 'Estahban,Estahbanat,Estahbān,Estehbanat,Eşţahbān,Eşţahbānāt,Istehbanat,Istehbānāt,Savanat,Savānāt,Shahr-e Estahbanat,Shahr-e Eşţahbānāt,asthban,استهبان', 29.1266000, 54.0421000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79643, 'Eslāmābād-e Gharb', 'Eslamabad-e Gharb', 'Eslamabad,Eslamabad-e Gharb,Eslāmābād,Eslāmābād-e Gharb,Harunabad,Hārūnābād,Shahabad,Shahabad-e Gharb,Shāhābād,Shāhābād-e Gharb,aslam abad ghrb,اسلام آباد غرب', 34.1094000, 46.5275000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79644, 'Eshtehārd', 'Eshtehard', 'Eshtehard,Eshtehārd,Ishtahabad,Ishtahard,ashthard,Īshtahard,Īshtahābād,اشتهارد', 35.7255000, 50.3662000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79645, 'Esfarāyen', 'Esfarayen', 'Esfarayen,Esfarāyen,Meyanabad,Meyanābād,Mianabad,Miyanabad,Mīyānābād,Mīānābād,asfrayn,اسفراین', 37.0764500, 57.5100900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79646, 'Eqlīd', 'Eqlid', 'Eklid,Eklīd,Eqlid,Eqlīd,Iqlid,Iqlīd,Shahrestan-e Eqlid,Shahrestān-e Eqlīd,aqlyd,اقلید', 30.8988500, 52.6970100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79647, 'Shahrud', 'Shahrud', 'Emamshahr,Emāmshahr,RUD,Shahrud,Sharud,Shāhrūd,Shārūd,aimamshahr,shahrwd,sharwd,اِمامشَهر,شارود,شاهرود', 36.4181900, 54.9762800, 'IR', '2014-02-01', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79648, 'Dowlatābād', 'Dowlatabad', 'Daulatabad,Daulatābad,Dowlatabad,Dowlatābād,dwlt abad,دولت آباد', 35.2821900, 59.5197200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79649, 'Dorūd', 'Dorud', 'Dorood Garan,Dorud,Dorūd,Dow Rud,Dow Rūd,Durud,Dūrūd,durud garan,durwd,dwrwd,دورود,دُرود,دُرُّد گَرَن', 33.4971400, 49.0577700, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79650, 'Dogonbadan', 'Dogonbadan', 'Do Gonbadan,Do Gonbadān,Dogonbadan,Dow Gonbadan,Dow Gonbadān,Du Gunbadan,Du Gunbadān,GCH,Gachsaran,Gachsārān,du gunbadan,gchsaran,دُو گُنبَدان,گچساران', 30.3586000, 50.7981000, 'IR', '2013-10-22', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79651, 'Dīvāndarreh', 'Divandarreh', 'Divan Darra,Divandarreh,Diwan Darreh,Dīvan Darra,Dīvāndarreh,Dīwān Darreh,dywandrh,ديواندره', 35.9139000, 47.0239000, 'IR', '2016-12-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79652, 'Dezful', 'Dezful', 'DEF,Dezfoul,Dezful,Dezfūl,Dizful,Dizful'',Dīzfūl,des ful,dezaphula,di zi fu lei,dyzfwl,dzfwl,Дизфуль,دزفول,ديزفول,देज़फूल,เดซฟูล,迪茲富勒', 32.3811400, 48.4058100, 'IR', '2015-10-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79653, 'Deyr', 'Deyr', 'Bandar-e Deyyer,Daiyir,Dayer,Dayir,Dayyer,Deyr,Qal''eh Dir,Qal’eh Dīr,bndr dyr,dyr,qalyih dyr,بندر دیر,دير,قَلئِه دير', 27.8399000, 51.9378000, 'IR', '2014-10-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79654, 'Delījān', 'Delijan', 'Dalijan,Dalijān,Delijan,Delījān,Dilijan,Dilījān,dlyjan,دليجان', 33.9905000, 50.6838000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79655, 'Dehlorān', 'Dehloran', 'Deh Lovan,Deh Lovān,Deh Luran,Deh Lūrān,Dehloran,Dehlorān,Dekhlorana,dhlran,dih luan,dih lwran,Дехлорана,دهلران,دِه لوران,دِه لُوان', 32.6941000, 47.2679000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79656, 'Dehgolān', 'Dehgolan', 'Deh Gulan,Deh-i-Gulan,Deh-ī-Gūlān,Dehgolan,Dehgolān,dhglan,دهگلان', 35.2780000, 47.4184000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79657, 'Dehdasht', 'Dehdasht', 'Dehdasht,Dehdast,Kuhgiluyeh,dhdsht,dihdast,دهدشت,دِهدَست', 30.7949000, 50.5645700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79658, 'Sīsakht', 'Sisakht', 'Deh Bozorg-e Sisakht,Deh Bozorg-e Sīsakht,Deh Bozorg-e Sīsākht,Deh-e Bozorg Sisakht,Deh-e Bozorg Sīsakht,Sisakht,Sīsakht,dih buzurgi sysakht,sy skht,دِه بُزُرگِ سيساخت,دِه بُزُرگِ سيسَخت,سی سخت', 30.8639300, 51.4559000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79659, 'Şafāshahr', 'Safashahr', 'Deh Bid,Deh Bīd,Safashahr,dh byd,sfashhr,Şafāshahr,ده بید,صفاشهر', 30.6131000, 53.1954000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79660, 'Dehāqān', 'Dehaqan', 'Dehaqan,Dehāqān,dhaqan,دهاقان', 31.9400400, 51.6478600, 'IR', '2015-10-15', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79661, 'Sūsangerd', 'Susangerd', 'Dasht-e Azadegan,Dasht-e Āzādegān,Dasht-i-Mishan,Dasht-i-Mishān,Dashte'' Mishan,Dashte’ Mishan,Khafajiyah,Khafajiyaz,Khafajiyeh,Susangerd,Susangird,Susangurd,Sūsangerd,Sūsangird,Sūsangurd,swsngrd,سوسنگرد', 31.5635000, 48.1895800, 'IR', '2016-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79662, 'Darreh Shahr', 'Darreh Shahr', 'Dareh sahr,Darre Szahr,Darreh Shahr,Darreh-ye Shahr,Darrehshahr,Darreshekhr,Deresehr,Dereşehr,Dərəşəhr,Madakto,drh shhr,Даррашаҳр,Даррешехр,Դարեհ շահր,دره شهر,دره‌شهر,دەڕەشار,شهرستان دره‌شهر', 33.1444700, 47.3799000, 'IR', '2016-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79663, 'Dargaz', 'Dargaz', 'Dargaz,Darreh Gaz,Mohammadabad,Mohammadabad Arbab,Moḩammadābād,Moḩammadābād Arbāb,Muhammadabad,Muhammadābād,drgz,drh gz,دره گز,درگز', 37.4444700, 59.1080900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79664, 'Dārān', 'Daran', 'Daran,Darun,Dārān,Dārūn,Faridan,Farīdān,daran,داران', 32.9887100, 50.4126700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79665, 'Dārāb', 'Darab', 'Darab,Darab-e 2,Dārāb,Dārāb-e 2,Yek,darab,darab 2,yk,داراب,داراب ٢,يک', 28.7519400, 54.5444400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79666, 'Dāmghān', 'Damghan', 'Damghan,Dāmghān,damghan,دامغان', 36.1679000, 54.3429200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79667, 'Damāvand', 'Damavand', 'Damavand,Damāvand,Demavend,Demāvend,Qasabeh-e Damavand,Qaşabeh-e Damāvand,dmawnd,qasabihi damawand,Дамаванд,دماوند,قَصَبِهِ دَماوَند', 35.7184200, 52.0695800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79668, 'Chenārān', 'Chenaran', 'Chanaran,Chanārān,Chenaran,Chenārān,Chinaran,Chinārān,chnaran,چناران', 36.6454600, 59.1212300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79669, 'Chelgard', 'Chelgard', 'Chelgard,Chelgerd,chlgrd,چلگرد', 32.4666800, 50.1230800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79670, 'Chālūs', 'Chalus', 'Chalus,Chālūs,chalws,Чалус,چالوس', 36.6550000, 51.4204000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79671, 'Chādegān', 'Chadegan', 'Chadegan,Chadgan,Chadgun,Chadgūn,Chadugan,Chadūgān,Chādegān,Chādgān,chadgan,چادگان', 32.7682500, 50.6287300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79672, 'Bandar-e Būshehr', 'Bandar-e Bushehr', 'Abu Shehr,Abuschehr,BUZ,Bandar Abu Shehr,Bandar Bushehr,Bandar Būshehr,Bandar-e Bushehr,Bandar-e Būshehr,Bouchehr,Buschehr,Buschir,Busehr,Bushehr,Busher,Bushir,Bushire,Būshehr,Būšehr,bndr bwshhr,bwshhr,bwshihr,Бушер,Бушир,Бӯшеҳр,Бӯшиҳр,بندر بوشهر,بوشهر,بوشِهر', 28.9684000, 50.8385000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79673, 'Būkān', 'Bukan', 'Bokan,Bowkan,Bowkān,Bukan,Būkān,bwkan,Букан,بوکان', 36.5210000, 46.2089000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79674, 'Bū’īn Zahrā', 'Bu''in Zahra', 'Bu''in,Bu''in Zahra,Buyin,Būyīn,Bū’īn,Bū’īn Zahrā,bwyyn zhra,بوئین زهرا', 35.7669000, 50.0578000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79675, 'Borūjerd', 'Borujerd', 'Borudzherd,Borujerd,Borūjerd,Burujird,Būrūjīrd,brwjrd,bwrwjyrd,Боруджерд,بروجرد,بوروجيرد', 33.8973000, 48.7516000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79676, 'Borūjen', 'Borujen', 'Amrujan,Amrūjān,Beroojen,Borujan,Borujen,Borūjen,Borūjān,Burujan,Burūjān,Urujan,Urūjān,aamrwjan,birujin,brwjn,burwjan,اَمروجان,بروجن,بُروجان,بِرُّجِن', 31.9652300, 51.2873000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79677, 'Borāzjān', 'Borazjan', 'Borazdjan,Borazjan,Borazjun,Borāzjān,Borāzjūn,brazjan,burazdjan,برازجان,بُرَزدجَن', 29.2699000, 51.2188000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79678, 'Shahrak-e Kūlūrī', 'Shahrak-e Kuluri', 'Boneh Hoseinkalooli,Boneh Hoseyn Koluli,Boneh Ḩoseyn Kolūlī,Boneh-ye Hoseyn Kaluli,Boneh-ye Ḩoseyn Kalūlī,Shahrak-e Kaluli,Shahrak-e Kalūlī,Shahrak-e Kuluri,Shahrak-e Kūlūrī,bnh hsyn klwly,shhrk klwly,shhrk kwlwry,بنه حسين کلولی,شهرک کلولی,شهرک کولوری', 32.3527600, 48.4705900, 'IR', '2016-01-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79679, 'Bojnūrd', 'Bojnurd', 'BJB,Bodzhnurd,Bojnord,Bojnourd,Bojnurd,Bojnūrd,Bujnurd,Bujnūrd,bjnwrd,Боджнурд,بجنورد', 37.4747300, 57.3290300, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79680, 'Bīrjand', 'Birjand', 'Birdjand,Birdschand,Birdzhend,Birjand,Bīrjand,XBJ,byrjnd,Бирдженд,Бӣрҷанд,بيرجند,بیرجند', 32.8662800, 59.2211400, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79681, 'Bīleh Savār', 'Bileh Savar', 'Bileh Savar,Bīleh Savār,bylh swar,بيله سوار', 39.3796100, 48.3546300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79682, 'Bījār', 'Bijar', 'Bidzhar,Bijar,Bījār,byjar,Биджар,بيجار', 35.8668000, 47.6050600, 'IR', '2010-08-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79683, 'Bonāb', 'Bonab', 'Benab,Benāb,Binab,Bināb,Bonab,Bonāb,Bunab,bnab,Бонаб,بناب', 37.3404000, 46.0561000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79684, 'Behshahr', 'Behshahr', 'Ashraf,Behshahr,Bekhshekhr,aashraf,bhshhr,Бехшехр,اَشرَف,بهشهر', 36.6923500, 53.5526200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79685, 'Behbahān', 'Behbahan', 'Behbahan,Behbahān,Behbehan,Behbehān,bhbhan,بهبهان', 30.5959000, 50.2417000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79686, 'Māsāl', 'Masal', 'Bazar-e Masal,Bāzār-e Māsāl,Masal,Masal-Bazar,Māsāl,Sar-i-Bazar,Sar-i-Bāzar,Sari Bazar Musar,Sārī Bāzār Mūsār,bazar masal,masal,بازار ماسال,ماسال', 37.3631000, 49.1329000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79687, 'Bastak', 'Bastak', 'Bastak,Lastak,bstk,lastak,Бастак,بستک,لَستَك', 27.1990800, 54.3667600, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79688, 'Bāsht', 'Basht', 'Basht,Bāsht,basht,باشت,بَشت', 30.3610000, 51.1573500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79689, 'Bardaskan', 'Bardaskan', 'Badar Askan,Badar Askān,Badr Eshkand,Bardaskan,Bardaskand,Bardeshkand,Bardeskan,Bardāskan,Bardāskand,Berdesken,Budraskan,Būdraskān,Bərdəskən,ba er da si kan,baradaskana,brdaskn,brdskn,Бардаскан,Բարդասքան,برداسکن,بردسكن,بردسکن,বারদাস্কান,巴爾達斯坎', 35.2621800, 57.9707500, 'IR', '2016-05-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79690, 'Bāneh', 'Baneh', 'Bane,Baneh,Bani,Bāneh,banh,bani,Бани,بانه,بَنِ', 35.9975000, 45.8853000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79691, 'Bandar-e Torkaman', 'Bandar-e Torkaman', 'Bandar Shah,Bandar Shāh,Bandar-e Shah,Bandar-e Shāh,Bandar-e Torkaman,Bandar-e Torkeman,Bandar-e Torkman,bandari shah,bandari turkman,bndr trkmn,بندر تركمن,بَندَرِ تُركمَن,بَندَرِ شاه', 36.9012400, 54.0719500, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79692, 'Bandar-e Māhshahr', 'Bandar-e Mahshahr', 'Bandar Ma`sbur,Bandar Ma`shur,Bandar Mah Shahr Terminal,Bandar Mah Sharh,Bandar Mah-Shahr,Bandar Mashur,Bandar Ma‘sbur,Bandar Ma‘shūr,Bandar-Mashour,Bandar-e Ma`shur,Bandar-e Mahshahr,Bandar-e Ma‘shūr,Bandar-e Māhshahr,Bandar-mashoor,Bar Andaz,Bār Andāz,MRX,Mah Shahr,Mahshahr,Markaz-e Bargiri-ye Bandar-e Mah Shahr,Markaz-e Bārgīrī-ye Bandar-e Māh Shahr,Mashur,Māhshahr,bndr mahshhr,بندر ماهشهر', 30.5565500, 49.1885200, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79693, 'Bandar-e Lengeh', 'Bandar-e Lengeh', 'BDH,Bandar Langeh,Bandar-e Lengeh,Bandar-e-Langeh,Linja,Linjah,bndr lngh,بندر لنگه', 26.5579200, 54.8806700, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79694, 'Bandar-e Gaz', 'Bandar-e Gaz', 'Bandar Gaz,Bandar-e Gaz,Bandar-i-Gaz,Bandar-i-Jaz,Bander Gaz,bndr gz,بندر گز', 36.7740900, 53.9479800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79695, 'Bandar-e Deylam', 'Bandar-e Deylam', 'Bandar Deylam,Bandar Dilam,Bandar Dīlam,Bandar-e Delam,Bandar-e Deylam,Dilam,Dīlam,bandari dilam,bndr dylm,dylam,بندر ديلم,بَندَرِ دِلَم,ديلَم', 30.0542000, 50.1590000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79696, 'Bandar-e Anzalī', 'Bandar-e Anzali', 'Bandar Anzali,Bandar Pahlavi,Bandar Pahlevi,Bandar-e Anzali,Bandar-e Anzalī,Bandar-e Pahlavi,Bandar-e Pahlavī,Enceli,Enzeli,Pahlavi,Pahlavī,Pahlevi,Pahlevī,Pehlevi,bndr anzly,بندر انزلی', 37.4731800, 49.4578500, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79697, 'Bandar Abbas', 'Bandar Abbas', 'BND,Bandar Abas,Bandar Abbas,Bandar Abbas - بندر عباس,Bandar Abbás,Bandar `Abbas,Bandar `Abbasi,Bandar ‘Abbās,Bandar ‘Abbāsī,Bandar-Abbas,Bandar-Abbasz,Bandar-Abbos,Bandar-Abbász,Bandar-e Abbas,Bandar-e `Abbas,Bandar-e ‘Abbās,Bandare Abasas,Bander Abbas,Bantar Ampas,Bender Abas,Bender Abbas,Bender Ebbas,Bender-Abbas,Bəndər Abbas,Cambarao,Cambarão,Gombroon,Gorad Bendehr-Abas,Gumrun,Port Comorao,Port Comorão,a ba si gang,ban dar xab bas,bandaleuabaseu,bandara abbasa,bandara-e-abbasa,bender-abasi,bndr ʻbʼs,bndr ʿbas,gumbrun,Μπαντάρ Αμπάς,Бандар-Аббос,Бендер Абас,Бендер-Аббас,Горад Бендэр-Абас,Բանդեր Աբբաս,בנדר עבאס,بندر عباس,بندرعباس,بَندَر عَبّاسی,بَندَرِ عَبّاس,بەندەر عەباس,گُمبرُّن,बंदर-ए-अब्बास,বন্দর আব্বাস,บันดาร์อับบาส,ბენდერ-აბასი,バンダレ・アッバース,阿巴斯港,반다르아바스', 27.1865000, 56.2808000, 'IR', '2016-02-27', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79698, 'Bam', 'Bam', 'BXR,Bam,bamu,bm,Бам,بم,バム', 29.1060000, 58.3570000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79699, 'Bajestān', 'Bajestan', 'Bajestan,Bajestān,Bejestan,Bejestān,Bijestan,Bijistan,Bījestān,Bījistān,bjstan,بجستان', 34.5163900, 58.1845000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79700, 'Bahār', 'Bahar', 'Bahar,Bahār,Bakhar,bhar,Бахар,بهار', 34.9072000, 48.4414000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79701, 'Bāgh-e Malek', 'Bagh-e Malek', 'Bagh Malek,Bagh-e Malek,Bagh-i-Malik,Bāgh-e Malek,bagh mlk,باغ ملک', 31.5231300, 49.8862400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79702, 'Bāft', 'Baft', 'Baft,Bāft,baft,بافت', 29.2331000, 56.6022000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79703, 'Bāfq', 'Bafq', 'Bafk,Bafq,Bāfq,bafq,Бафк,بافق', 31.6035000, 55.4024900, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79704, 'Bābolsar', 'Babolsar', 'Babolsar,Babul Sar,Bābolsar,Bābul Sar,Mashhad-i-Sar,Mashhadsar,Meshed-i-Sar,bablsr,mashhadsar,بابلسر,مَشهَدسَر', 36.7025100, 52.6576000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79705, 'Bābol', 'Babol', 'Babol,Babol'',Babul,Balfrush,Barfarush,Barfrush,Barfurush,Bābol,Bābul,Bārfurush,babl,Баболь,بابل', 36.5513200, 52.6789500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79706, 'Aznā', 'Azna', 'Azna,Aznā,azna,ازنا', 33.6095000, 48.9307000, 'IR', '2012-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79707, 'Aznā', 'Azna', 'Azna,Aznā,Ezna,Eznā,azna,ازنا', 33.4557000, 49.4555000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79708, 'Hashtrūd', 'Hashtrud', 'Azaran,Hashtrud,Hashtrūd,Sar Eskand,Sar Eskand Khan,Sar Eskand Khān,Sar Eskandar,Saraskand,Sarāskand,hshtrwd,Āz̄arān,هشترود', 37.4779000, 47.0508000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79709, 'Shāzand', 'Shazand', 'Azadshahr,Shah Zand,Shazand,Shāzand,azadshahr,shah zand,shaznd,Āzādshahr,آزادشَهر,شازند,شَه زَند', 33.9276000, 49.4116000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79710, 'Āstārā', 'Astara', 'Astara,astara,Āstārā,Астара,آستارا', 38.4291000, 48.8720000, 'IR', '2013-03-31', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79711, 'Āstāneh-ye Ashrafīyeh', 'Astaneh-ye Ashrafiyeh', 'Astane,Astaneh,Astaneh-ye Ashrafiyeh,astanh ashrfyh,Āstāneh,Āstāneh-ye Ashrafīyeh,آستانه اشرفیه', 37.2631800, 49.9432500, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79712, 'Āshtīān', 'Ashtian', 'Ashtian,Ashtiyan,Ashtīyan,aashtyan,ashtyan,Āshtīān,آشتيان,اَشتيَّن', 34.5229800, 50.0060800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79713, 'Āshkhāneh', 'Ashkhaneh', 'Ashkhaneh,ashkhanh,Āshkhāneh,آشخانه', 37.5615000, 56.9212500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79714, 'Bandar-e ‘Asalūyeh', 'Bandar-e `Asaluyeh', 'Asalu,Bandar-e `Asalu,Bandar-e `Asaluyeh,Bandar-e ‘Asalū,Bandar-e ‘Asalūyeh,PGU,`Asaluyeh,بندر عسلویه,بَندَرِ عَسَلو,عسلويه,‘Asalūyeh', 27.4761000, 52.6074000, 'IR', '2017-03-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79715, 'Asadīyeh', 'Asadiyeh', 'Asadiyeh,Asadīyeh,asdyh,اسدیه', 32.9428000, 59.7199800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79716, 'Asadābād', 'Asadabad', 'Asadabad,Asadabada,Asadābād,asd abad,Асадабада,اسد آباد', 34.7824100, 48.1201200, 'IR', '2016-09-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79717, 'Arzū’īyeh', 'Arzu''iyeh', 'Arzoo''eyeh,Arzoo’eyeh,Arzu,Arzu''iyeh,Arzū’īyeh,Orzu''iyeh,Orzū’īyeh,Ozu''iyeh,Ozū’īyeh,`Orsu''iyeh,arzwyyh,Ārzū,ارزوئیه,‘Orsū’īyeh', 28.4414000, 56.3728000, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79718, 'Arsanjān', 'Arsanjan', 'Arsanjan,Arsanjān,Arsenjan,Arsenjān,Arsinjan,Arsinjān,arsnjan,ارسنجان', 29.9124000, 53.3085000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79719, 'Ardestān', 'Ardestan', 'Ardestan,Ardestān,Ardistan,Ardistān,ardstan,اردستان', 33.3761000, 52.3694000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79720, 'Ardal', 'Ardal', 'Ardal,Ardel,ardl,اردل', 31.9996900, 50.6623100, 'IR', '2016-12-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79721, 'Ardakān', 'Ardakan', 'Ardakan,Ardakān,Ardekan,ardkan,اردکان', 32.3100100, 54.0174700, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79722, 'Ardabīl', 'Ardabil', 'ADU,Ardabel,Ardabil,Ardabīl,Ardebil,Ardebīl,Erdebil,aardibyl,ardbyl,Ərdəbil,Ардабел,اردبيل,اردبیل,اَردِبيل', 38.2498000, 48.2933000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79723, 'Ārān Bīdgol', 'Aran Bidgol', 'Aran,Aran Bidgol,Aran va Bidgol,Arun,Arūn,Gol Ara,Gol Ārā,aran,aran byd gl,aran w bydgl,gl ara,Ārān,Ārān Bīdgol,Ārān va Bīdgol,آران,آران بيد گل,آران و بيدگل,گل آرا', 34.0575100, 51.4829100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79724, 'Arāk', 'Arak', 'Arak,Arak - sawh,Arak - ساوه,Arok,Arāk,Ehrak,Soltanabad,Solţānābād,Sultanabad,Sultānābād,`Iraq,arak,sawh,sultan abad,Арак,Арок,Эрак,اراک,ساوه,سُلطان آباد,‘Irāq', 34.0917400, 49.6891600, 'IR', '2013-11-27', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79725, 'Ārādān', 'Aradan', 'Aradan,Ardan,Ardān,Azadan,aardan,aradan,Ārādān,Āzādān,آرادان,اَردان', 35.2494100, 52.4942200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79726, 'Andīmeshk', 'Andimeshk', 'Andimeshg,Andimeshk,Andimishk,Andremeshl,Andīmeshg,Andīmeshk,Andīmīshk,Salehabad,Salehābād,andymshk,اندیمشک', 32.4615000, 48.3536800, 'IR', '2016-01-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79727, '‘Anbarābād', '`Anbarabad', 'Ambarabad,Ambārābād,`Anbarabad,عنبر آباد,‘Anbarābād', 28.4759000, 57.8480000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79728, 'Anār', 'Anar', 'Anar,Anār,anar,انار', 30.8706600, 55.2702500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79729, 'Āmol', 'Amol', 'Amol,Amol'',Amul,aml,Āmol,Амоль,آمل', 36.4696100, 52.3507200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79730, 'Amlash', 'Amlash', 'Amlash,Amlesh,Amlish,amlsh,املش', 37.0974300, 50.1865200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79731, 'Alvand', 'Alvand', 'Alband,Alvand,Alwand,El''vend,El’vend,aalband,alwnd,Алванд,الوند,اَلبَند,اِلءوِند', 36.3187000, 49.1678000, 'IR', '2012-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79732, 'Shahrīār', 'Shahriar', 'Ali Shah `Iwaz,Ali Shāh ‘Iwaz,Shahreyar,Shahreyār,Shahriar,Shahriyar,Shahriyār,Shahrīār,Shakhrijar,`Ali Shah `Avaz,shhryar,Шахрияр,شهريار,‘Alī Shāh ‘Avaẕ', 35.6588400, 51.0577500, 'IR', '2015-12-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79733, 'Alīgūdarz', 'Aligudarz', 'Aligoodarz,Aligudarz,Alīgūdarz,`Ali Gudar,alygwdrz,Алигударз,اليگودرز,‘Ali Gudār', 33.4006300, 49.6949000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79734, '‘Alīābād-e Katūl', '`Aliabad-e Katul', '`Aliabad,`Aliabad-e Katul,علی آباد,علی آباد کتول,‘Alīābād,‘Alīābād-e Katūl', 36.9101100, 54.8673700, 'IR', '2016-03-09', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79735, 'Aleshtar', 'Aleshtar', 'Alashtar,Aleshtar,Alishtar,Alishtār,Qal`eh Mozaffari,Qal`eh `Alishtar,Qal‘eh Moz̧affari,Qal‘eh ‘Alishtār,alshtr,الشتر', 33.8641900, 48.2625800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79736, 'Akbarābād', 'Akbarabad', 'Akbar Abad Kawar,Akbarabad,Akbarabad-e Kavar,Akbarābād,Akbarābād-e Kavār,akbr abad,Акбарабад,اکبر آباد', 29.2464000, 52.7793000, 'IR', '2012-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79737, '‘Ajab Shīr', '`Ajab Shir', 'Ajabshahr,`Ajab Shir,aajabshahr,اَجَبشَهر,عجب شیر,‘Ajab Shīr', 37.4776000, 45.8943000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79738, 'Ahvaz', 'Ahvaz', 'AWZ,Ahvaz,Ahvaz - ahwaz,Ahvaz - اهواز,Ahvaza,Ahvazas,Ahvazo,Ahvoz,Ahváz,Ahvāz,Ahvāza,Ahwaz,Ahwāz,Akhvaz,Akhvaz shaary,Axvaz,Bandar Nasiri,Bandar Nāsirī,Bandar-e Naser,Bandar-e Nāşer,Ehvaz,Gorad Akhvaz,Naseri,Nasiri,Nāsiri,Nāşerī,a wa shi,abajeu,afuvu~azu,ahabaja,ahavaza,ahvazi,ahwaz,akvacu,alahwaz,Əhvaz,Ахваз,Ахваз шаары,Аҳвоз,Горад Ахваз,Ախվազ,אהוואז,ئەھواز,الأهواز,اهواز,اہواز,अहवाज़,আহবাজ,ਅਹਵਾਜ਼,ஆக்வாசு,ཨཱ་ཝཛ།,აჰვაზი,アフヴァーズ,阿瓦士,아바즈', 31.3190100, 48.6842000, 'IR', '2015-05-13', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79739, 'Ahram', 'Ahram', 'Ahram,Ahrom,ahrm,اهرم', 28.8826000, 51.2746000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79740, 'Ahar', 'Ahar', 'Ahar,Akhar,Eher,a ha er,ahaleu,ahara,ahr,Əhər,Ахар,Аҳар,أهر,اهر,اہار,اہر,अहार,阿哈尔,아하르', 38.4774000, 47.0699000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79741, 'Aghajari', 'Aghajari', 'AKW,Agha Jari,Aghajari,Aqa Jari,aghajary,Āghā Jārī,Āghājārī,Āqā Jarī,آغاجاری', 30.7006000, 49.8315000, 'IR', '2013-05-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79742, 'Ābyek', 'Abyek', 'Abiak,abyik,آبيِك', 36.0666700, 50.5500000, 'IR', '2006-08-21', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79743, 'Ābyek', 'Abyek', 'Abiak,Abiak Sarai,Abiak Sarāi,Abyek,Abyek Sofla,Abyek-e Pa''in,aabyik sufla,abyiki payyn,abyk,Ābyek,Ābyek-e Pā’īn,آبيِكِ پائين,آبيک,اَبيِك سُفلَ', 36.0399300, 50.5310100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79744, 'Abhar', 'Abhar', 'Abhar,Abkhar,aabkhar,abhr,abr,Абхар,ابر,ابهر,اَبخَر', 36.1468000, 49.2180000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79745, 'Ābdānān', 'Abdanan', 'Abdanan,Qal`a Ab-i-Danan,Qal`eh Ab-i-Danan,Qal`eh-ye Ab Danan,Qal`eh-ye Abdaran,Qal‘a Ab-ī-Danan,Qal‘eh Āb-ī-Dānān,Qal‘eh-ye Āb Dānān,Qal‘eh-ye Ābdārān,abdanan,Ābdānān,آبدانان,قَلعِۀ آب دانان,قَلعِۀ آبداران', 32.9926000, 47.4198000, 'IR', '2015-04-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79746, '‘Abbāsābād', '`Abbasabad', 'Varaak,Varsak,`Abbasabad,عباس آباد,‘Abbāsābād', 36.7276900, 51.1057400, 'IR', '2017-03-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79747, 'Ābbar', 'Abbar', 'Abbar,Obar,Ubar,Ubār,ab br,Ābbar,آب بر', 36.9262700, 48.9583200, 'IR', '2017-07-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79748, 'Abarkūh', 'Abarkuh', 'Abar Qu,Abar Qū,Abarghoo,Abarku,Abarkuh,Abarkū,Abarkūh,Abarquh,Abarqūh,aabarghu,aabarkw,aabarqwh,abr qw,abrkwh,ابر قو,ابرکوه,اَبَرغُّ,اَبَرقوه,اَبَركو', 31.1289000, 53.2824000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79749, 'Ābādeh', 'Abadeh', 'Abade,Abadeh,abadh,Ābādeh,Абаде,آباده', 31.1608000, 52.6506000, 'IR', '2016-10-10', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79750, 'Abadan', 'Abadan', 'ABD,Abadan,Abadana,Abadanas,Abadano,Abadán,Ampantan,Gorad Abadan,Obodon,a ba dan,abadan,abadana,abadani,Ábádán,Ābadāna,Ābādān,ʿbadan,Αμπαντάν,Абадан,Горад Абадан,Ободон,Աբադան,אבאדאן,آبادان,ابادان,عبادان,अबादान,ਆਬਾਦਾਨ,აბადანი,アバダーン,アーバーダーン,阿巴丹,아바단', 30.3392000, 48.3043000, 'IR', '2014-05-28', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79751, 'Kūh Sefīd', 'Kuh Sefid', 'Kuh Sefid,Kuh-e Sefid,Kūh Sefīd,Kūh-e Sefīd,kwh sfyd,کوه سفید', 29.2762000, 56.8014000, 'IR', '2012-01-19', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79752, 'Abū Mūsā', 'Abu Musa', 'Abu Musa,Abū Mūsā,abw mwsy,ابو موسیٰ', 25.8669800, 55.0236300, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79753, 'Showţ', 'Showt', 'Shot,Showt,Showţ,Shoţ,shut,shwt,شوط,شُط', 39.2192000, 44.7700000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79754, 'Pāsārgād', 'Pasargad', 'Pasargad,Pāsārgād', 30.2019400, 53.1800000, 'IR', '2016-11-13', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79755, 'Shahrak-e Pābedānā', 'Shahrak-e Pabedana', 'Kian Shahr,Kiyan Shar,Kīyān Shār,Kīān Shahr,Shahrak-e Pabedana,Shahrak-e Pābedānā', 31.1344400, 56.3980600, 'IR', '2013-05-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79756, 'Khavāş Kūh', 'Khavas Kuh', 'Khas Kuh,Khas Kuhi,Khas Kūhī,Khavas Kuh,Khavāş Kūh,Khāş Kūh,khas kwh,khas kwhy,khawas kwh,خاص كوه,خَس كوهی,خَواص كوه', 32.3061100, 53.6744400, 'IR', '2012-01-19', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79757, 'Sepīdān', 'Sepidan', 'Ardakan,Ardakān,Sepidan,Sepīdān,ardkan,spydan,اردکان,سپیدان', 30.2606100, 51.9842400, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79758, 'Eqbālīyeh', 'Eqbaliyeh', 'Eqbaliyeh,Eqbālīyeh,aqbalyh,اقباليّه', 35.3022000, 51.5358000, 'IR', '2012-12-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79759, 'Shāhīn Shahr', 'Shahin Shahr', 'Shahin Shahr,Shāhīn Shahr,shahyn shhr,شاهین شهر', 32.8578800, 51.5529000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79760, 'Shāhreẕā', 'Shahreza', '', 32.0338900, 51.8794400, 'IR', '2006-01-17', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79761, 'Zarrīn Shahr', 'Zarrin Shahr', 'Qal`eh Riz,Qal‘eh Rīz,Riz,Riz-e Lanjan,Rīz,Rīz-e Lanjān,Zarrin Shahr,Zarrīn Shahr,zryn shhr,زرّین شهر', 32.3897000, 51.3766000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79762, 'Tīrān', 'Tiran', 'Tehran,Tehrān,Tihran,Tihrān,Tiran,Tirun,Tirūn,Tīrān,tyran,تیران', 32.7026000, 51.1537000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79763, 'Rehnān', 'Rehnan', 'Rahnan,Rehnan,Rehnān,Renan,Renān,Rohanan,Rohnan,rhnan,rnan,رنان,رهنان', 32.6832500, 51.6015800, 'IR', '2015-12-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79764, 'Shahreẕā', 'Shahreza', 'Qomisheh,Qomsheh,Qomīsheh,Qowmsheh,Qumisheh,Shahreza,Shahreẕā,Shahriza,qmshh,shhrda,شهرضا,قمشه', 32.0089000, 51.8668000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79765, 'Qahderījān', 'Qahderijan', 'Kedargun,Kedargūn,Qadrijan,Qadrijān,Qadrja,Qadrjā,Qahderijan,Qahderījān,qhdryjan,قهدریجان', 32.5767000, 51.4550000, 'IR', '2012-01-19', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79766, 'Najafābād', 'Najafabad', 'Nadzhafabad,Najafabad,Najafābād,Nejafabad,Nejafābād,njf abad,Наджафабад,نجف آباد', 32.6344000, 51.3668000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79767, 'Mobārakeh', 'Mobarakeh', 'Mobarakeh,Mobārakeh,Mubarakeh,Mubārakeh,mbarkh,مبارکه', 32.3465100, 51.5044900, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79768, 'Khomeynī Shahr', 'Khomeyni Shahr', 'Homayoon Shahr,Homayunshahr,Homāyūnshahr,Khomeyni Shahr,Khomeynishahr,Khomeynī Shahr,Khomeynīshahr,Sedeh,khmyny shhr,خمینی شهر', 32.6856000, 51.5360900, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79769, 'Kelīshād va Sūdarjān', 'Kelishad va Sudarjan', 'Baba `Abdollah,Bābā ‘Abdollāh,Gulshad,Gulshād,Kalushad,Kalūshād,Kelishad,Kelishad va Sudarjan,Kelishad-e Sofla,Kelīshād,Kelīshād va Sūdarjān,Kelīshād-e Soflá,klyshad,klyshad w swdrjan,کلیشاد,کلیشاد و سودرجان', 32.5511800, 51.5275800, 'IR', '2014-10-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79770, 'Falāvarjān', 'Falavarjan', 'Falavar Jan,Falavarjan,Falāvar Jān,Falāvarjān,Felavarjan,Felāvarjān,Mollavarjan,Mollāvarjān,Pol-e Vargan,Pol-e Vargān,Pol-e Varqan,Pol-e Varqān,Pul-i-Vargan,Pul-i-Vargān,flawrjan,mlawrjan,فلاورجان,ملاورجان', 32.5553000, 51.5097300, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79771, 'Isfahan', 'Isfahan', 'Aspadana,Dakbayan sa Esfahan,Dakbayan sa Esfahān,Esfahan,Esfahano,Esfahān,Esfehan,Eşfahān,Eşfehān,Gorad Isfakhan,IFN,Isfachan,Isfahan,Isfahana,Isfahanas,Isfahanum,Isfahon,Isfahán,Isfahāna,Isfakhan,Isfehan,Ispahan,Iszfahan,Iszfahán,Kota Isfahan,Spahan,Yspyhan,asfhan,aysfahan,esaphahana,esufahan,icupakan,isafahana,iseupahan,isfahana,isphahana,xis fa han,yi si fa han,Îsfehan,İsfahan,İsfehan,Ισφαχάν,Ісфахан,Горад Ісфахан,Исфахан,Исфаҳон,Исфаһан,Սպահան,אספהאן,أصفهان,ئسفأھان,ئەسفەھان,اصفهان,اصفہان,ایصفاهان,इस्फहान,इस्फ़हान,এসফাহন,ਇਸਫ਼ਹਾਨ,இசுபகான்,อิสฟาฮาน,ისპაანი,エスファハーン,伊斯法罕,이스파한', 32.6524600, 51.6746200, 'IR', '2014-08-19', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79816, 'Siglufjörður', 'Siglufjoerdur', 'Gorad Siglufijordur,SIJ,Siglifjerdir,Sigljuf''jordjur,Sigljuf''ordjur,Siglufirdi,Siglufirði,Siglufjardar,Siglufjarðar,Siglufjoerd,Siglufjoerdur,Siglufjordur,Siglufjörð,Siglufjörður,shigurufiyoruzuru,sigaluphiyordura,sigeullwipioeleudwileu,siglupiorduri,xi ge lu fei e ze,Горад Сіглуфіёрдур,Сиглифјердир,Сиглюфьордюр,Сиглюфьёрдюр,সিগলুফিয়োর্দুর,სიგლუფიორდური,シグルフィヨルズル,錫格呂菲厄澤,시글뤼피외르뒤르', 66.1519800, -18.9081500, 'IS', '2017-06-14', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79817, 'Sauðárkrókur', 'Saudarkrokur', 'Saudarkrok,Saudarkroki,Saudarkrokr,Saudarkroks,Saudarkrokur,Saudharkrokur,Sauðarkrokur,Sauðárkrók,Sauðárkróki,Sauðárkróks,Sauðárkrókur,soizaurukuroukuru,ソイザウルクロウクル', 65.7461100, -19.6394400, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79818, 'Neskaupstaður', 'Neskaupstadur', 'NOR,Neskaupstad,Neskaupstadar,Neskaupstadur,Neskaupstað,Neskaupstaðar,Neskaupstaður,Neskejpstadir,Neskjojpstadjur,nei si ke yi si ta ze,neseukoeipeuseutadwileu,nesukoipusutazuru,Нескејпстадир,Нескёйпстадюр,ネスコイプスタズル,內斯克伊斯塔澤,네스쾨이프스타뒤르', 65.1481900, -13.6836800, 'IS', '2017-01-11', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79819, 'Húsavík', 'Husavik', 'Husavik,Husavikur,Husayik,Húsavík,Húsavíkur,Khusavik,Nordurthing,Norðurþing,Хусавик', 66.0414800, -17.3383400, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79820, 'Höfn', 'Hoefn', 'Gepn,Gorad Khjobn,HFN,Hafnar,Hafnar i Hornafirdi,Hafnar í Hornafirði,Hoefn,Hoefn i Hornafirdi,Hofn,Höfn,Höfn í Hornafirði,Khebn,Khjobn,Sveitarfelagid Hornafjoerdur,Sveitarfélagið Hornafjörður,he ben,hepun,hoepeun,Гепн,Горад Хёбн,Хебн,Хёбн,ヘプン,赫本,회픈', 64.2538800, -15.2121200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79821, 'Eskifjörður', 'Eskifjoerdur', 'Eskifirdi,Eskifirði,Eskifjardar,Eskifjarðar,Eskifjoerd,Eskifjoerdur,Eskifjordur,Eskifjörð,Eskifjörður', 65.0730600, -14.0152500, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79822, 'Egilsstaðir', 'Egilsstadir', 'EGS,Egilsstada,Egilsstadi,Egilsstadir,Egilsstaða,Egilsstaði,Egilsstaðir,Egilsstoedum,Egilsstöðum,Ehgil''sstadir,Эгильсстадир', 65.2668700, -14.3948500, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79823, 'Dalvík', 'Dalvik', 'Dal''vik,Dalvik,Dalvikur,Dalvikurbyggd,Dalvík,Dalvíkur,Dalvíkurbyggð,da er wei ke,dalbikeu,daruvu~iku,Далвик,Далвік,Дальвик,დალვიკი,ダールヴィーク,達爾維克,달비크', 65.9701800, -18.5286100, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79824, 'Reyðarfjörður', 'Reydarfjoerdur', 'Budareyri,Búðareyri,Fjardabyggd,Fjarðabyggð,Rejdarf''ordjur,Rejdarfjerdir,Reydarfirdi,Reydarfjardar,Reydarfjoerd,Reydarfjoerdur,Reydarfjordur,Reyðarfirði,Reyðarfjarðar,Reyðarfjörð,Reyðarfjörður,lei zha er fei e ze,reizarufiyoruzuru,Рейдарфьордюр,Рејдарфјердир,レイザルフィヨルズル,雷扎爾菲厄澤', 65.0316400, -14.2183200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79825, 'Akureyri', 'Akureyri', 'AEY,Agireiri,Akirejri,Akjurejri,Akourefri,Akuereyri,Akureiris,Akurejri,Akureyrar,Akureyri,Aküreyri,Gorad Akjurehjry,a ke lei li,akuleili,akureiri,akwryry,Άκουρεϋρι,Акирејри,Акурейрі,Акюрейри,Горад Акюрэйры,Աքուրեյրի,אקוריירי,أكوريري,აკურეირი,アークレイリ,阿克雷里,아쿠레이리', 65.6835300, -18.0878000, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79826, 'Vogar', 'Vogar', 'Voga,Vogar,Vogar a Vatnsleysustroend,Vogar á Vatnsleysuströnd,Vogum', 63.9816000, -22.3847300, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79827, 'Vestmannaeyjar', 'Vestmannaeyjar', 'VEY,Vestmannaehjjar,Vestmannaeyja,Vestmannaeyjar,Vestmannaeyjum,Вестманнаэйяр', 63.4427300, -20.2733900, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79828, 'Þorlákshöfn', 'THorlakshoefn', 'THorlakshafnar,THorlakshoefn,Thorlakshofn,Þorlákshafnar,Þorlákshöfn', 63.8559100, -21.3833700, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79829, 'Stykkishólmur', 'Stykkisholmur', 'SYK,Stykkisholmi,Stykkisholmur,Stykkishólmi,Stykkishólmur', 65.0753700, -22.7297700, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79830, 'Selfoss', 'Selfoss', 'Arborg,Gorad Sel''fas,Sel''foss,Selfos,Selfosas,Selfoss,Selfossi,sai er fu si,selaphasa,selposeu,serufosu,slfws,slpws,sylfws,Árborg,Σέλφος,Горад Сельфас,Селфос,Сельфосс,סלפוס,سلفوس,سیلفوس,সেলফস,セールフォス,塞尔福斯,셀포스', 63.9331100, -20.9971200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79831, 'Sandgerði', 'Sandgerdi', 'Sandgerdi,Sandgerdis,Sandgerði,Sandgerðis,Sangerdi', 64.0376200, -22.7079900, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79832, 'Reykjavík', 'Reykjavik', 'Gorad Rehjkjavik,REK,Recwic,Refkiavik,Reiciavicia,Reicivic,Reikiavik,Reikiavike,Reikjaveks,Reikjavik,Reikjavika,Reikjavikas,Reikjavīka,Reiquiavik,Reiquiavique,Rejk''javik,Rejkijavik,Rejkjavik,Rejkjaviko,Rekyavik,Reykiavica,Reykjavik,Reykjavikur,Reykjavík,Reykjavíkur,Reykjawik,Reykyabik,Reykyavik,Rèkyavik,Réicivíc,Rēcwīc,Rėikjavėks,kartuli,lei ke ya wei ke,leikyabikeu,re''ikiyabhika,reikyavu~iku,rekavik,rekh ya wik,reki''avika,rekjabhika,rekjavika,rekyavika,reyikyavik,reykyavik,rykjawk,rykyafyk,rykyawk,rykyawyk,Ρέικιαβικ,Ρευκιαβικ,Горад Рэйкявік,Рейкиявик,Рейкьявик,Рейкявик,Рейкявік,Рејкјавик,Ռեյկյավիկ,רייקיאוויק,רעקיאוויק,ريكيافيك,ریکجاوک,ریکیاوک,ریکیاویک,رېيكياۋىك,ڕێکیاڤیک,रेक्जाविक,रेक्याविक,রেইকিয়াভিক,ਰੇਕਿਆਵਿਕ,ରେକ୍ଜାଭିକ,ரெய்க்யவிக்,రేకవిక్,റെയിക്യാവിക്,เรคยาวิก,རེཀ་ཇ་བིཀ།,რეიკიავიკი,ქართული,ሬይኪያቪክ,レイキャヴィーク,雷克亞維克,雷克雅未克,雷克雅維克,레이캬비크', 64.1354800, -21.8954100, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79833, 'Ólafsvík', 'Olafsvik', 'Gorad Oulafsvik,OLI,Olafsvik,Oulafsvik,Oulafsvikas,ollapeuseubikeu,ou la fu si wei ke,Ólafsvík,Горад Оўлафсвік,Оулафсвик,Оулафсвік,ოულაფსვიკი,歐拉夫斯維克,올라프스비크', 64.8942900, -23.7091800, 'IS', '2017-02-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79834, 'Seltjarnarnes', 'Seltjarnarnes', 'Seltjarnarnes,Seltjarnarnesi', 64.1530900, -21.9949900, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79835, 'Mosfellsbær', 'Mosfellsbaer', 'Mosfedl''sbajr,Mosfedlsbajr,Mosfel''sbair,Mosfellsbae,Mosfellsbaejar,Mosfellsbaer,Mosfellsbæ,Mosfellsbæjar,Mosfellsbær,mo si fei de si bai er,Мосфедлсбајр,Мосфедльсбайр,Мосфельсбаїр,מוספלסבאיר,莫斯费德斯拜尔', 64.1666700, -21.7000000, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79836, 'Kópavogur', 'Kopavogur', 'Gorad Koupavagur,Kopavog,Kopavogi,Kopavogs,Kopavogsbaer,Kopavogskaupstadur,Kopavogur,Kopavonkour,Koupavogir,Koupavogjur,Koupavogur,Koupavoguras,Koupavogyur,Kópavog,Kópavogi,Kópavogs,Kópavogsbær,Kópavogskaupstaður,Kópavogur,ke pa wo yu er,kopabogwileu,kopavu~oguru,kwbafwghwr,kwpawwgwr,Κόπαβογκουρ,Горад Коўпавагур,Коупавогир,Коупавогюр,Коупавоґур,Կոուպավոգյուր,קואופווגיר,كوبافوغور,کوپاووگور,კუპავოგური,コーパヴォグル,科帕沃于尔,코파보귀르', 64.1123400, -21.9129800, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79837, 'Keflavík', 'Keflavik', 'Gorad Keflavik,Keblavik,Keblavikas,Keflavik,Keflavika,Keflavikur,Keflavík,Keflavíkur,Keflavīka,Kephlabik,Keplavik,kai fu la wei ke,kepeullabikeu,kepuravu~iku,kyflafyk,Κεφλαβίκ,Горад Кефлавік,Кеблавик,Кеплавик,Кеплавік,Кефлавик,Կեֆլավիկ,קפלאוויק,كيفلافيك,კებლავიკი,ケプラヴィーク,凯夫拉维克,케플라비크', 64.0049200, -22.5624200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79838, 'Ísafjörður', 'Isafjoerdur', 'Gorad Isafijordur,IFJ,Isaf''ordjur,Isafiordour,Isafiordr,Isafirdi,Isafjardar,Isafjardardjup,Isafjerdir,Isafjoerd,Isafjoerdur,Isafjorduer,Isafjordur,Isafjorduras,Isafjordür,Isafyorduer,Issafjordur,Issafjörður,aysafjrwyr,aysafywrdr,isafiyoruzu~uru,isapioeleudwileu,isapiorduri,yi sa fei e ze,Ísafirði,Ísafjardardjup,Ísafjarðar,Ísafjörð,Ísafjörður,İsafyordür,Ίσαφιορδουρ,Ісафьордюр,Горад Ісафіёрдур,Исафьордюр,Исафјердир,איסאפיירדור,ایسافجرویر,ایسافیوردر,ისაფიორდური,イーサフィヨルズゥル,伊萨菲厄泽,이사피외르뒤르', 66.0747500, -23.1349800, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79839, 'Hveragerði', 'Hveragerdi', 'Hveragerdi,Hveragerdis,Hveragerdisbaer,Hveragerði,Hveragerðis,Hveragerðisbær,kuberageruji,kuvu~erageruji,クベラゲルジ,クヴェラゲルジ', 64.0003900, -21.1860200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79840, 'Hafnarfjörður', 'Hafnarfjoerdur', 'Chafnarfiordour,Gapnarfjordur,Gorad Khabnarfijordur,Habnarfjorduras,Habnarfyordyur,Hafnarfirdi,Hafnarfirði,Hafnarfjardar,Hafnarfjardarkaupstadur,Hafnarfjarðar,Hafnarfjarðarkaupstaður,Hafnarfjoerdur,Hafnarfjordur,Hafnarfjörður,Halfnarfjordur,Halfnarfjorður,Khabnarf''ordjur,Khabnarfjerdir,Khapnarf''ordjur,ha fu na fu yue du er,habnarpiorduri,hafnarfywrdwr,hafunarufiyoruzu~uru,hapeunaleupioeleudwileu,hpnrpyyrdyr,Χαφναρφιόρδουρ,Гапнарфйордур,Горад Хабнарфіёрдур,Хабнарфьордюр,Хабнарфјердир,Хапнарфьордюр,Հաբնարֆյորդյուր,הפנרפיירדיר,هافنارفيوردور,ჰაბნარფიორდური,ハフナルフィヨルズゥル,哈夫纳夫约杜尔,하프나르피외르뒤르', 64.0671000, -21.9377400, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79841, 'Grindavík', 'Grindavik', 'Gorad Gryndavik,Grindavik,Grindavikas,Grindavikur,Grindavikurbaer,Grindavík,Grindavíkur,Grindavíkurbær,ge lin da wei ke,geulindabikeu,gurindavu~iku,Горад Грындавік,Гриндавик,Ґріндавік,グリンダヴィーク,格林达维克,그린다비크', 63.8384900, -22.4393100, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79842, 'Garður', 'Gardur', 'Gard,Gardar,Gardi,Gardur,Garð,Garðar,Garði,Garður,Gerdar,Gerðar,Goerdum,Görðum', 64.0655800, -22.6465600, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79843, 'Garðabær', 'Gardabaer', 'Gardabae,Gardabaejar,Gardabaer,Gardabair,Gardabairas,Gardabajr,Gardabayr,Garðabaer,Garðabæ,Garðabæjar,Garðabær,Gorad Gardabajr,galeudabaileu,gardhabayr,garuzabairu,hardabairi,jia er zha bai er,Гардабайр,Горад Гардабайр,Ґардабаїр,Գարդաբայր,גארדבאיר,گارذابایر,ჰარდაბაირი,ガルザバイル,加尔扎拜尔,가르다바이르', 64.0886500, -21.9229800, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79844, 'Álftanes', 'Alftanes', 'Al''ftanes,Alftanes,Alftanesi,Aul''ftanes,Aulftanes,Gorad Al''ftanes,alftans,ao er ta nei si,aulpeutaneseu,a~urutanesu,Álftanes,Álftanesi,Альфтанес,Аулфтанес,Аульфтанес,Горад Альфтанес,אאולפטאנס,آلفتانس,アゥルタネース,奧爾塔內斯,아울프타네스', 64.1000000, -22.0166700, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79845, 'Borgarnes', 'Borgarnes', 'Borganes,Borgarbyggd,Borgarbyggð,Borgarnes,Borgarnesas,Borgarnesi,Borqarnes,Gorad Borgarnes,bo er jia nei si,boleugaleuneseu,borgarnesi,borugarunesu,Боргарнес,Борґарнес,Горад Боргарнес,Բորգարնես,ბორგარნესი,ボルガルネース,博尔加内斯,보르가르네스', 64.5383400, -21.9206400, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79846, 'Akranes', 'Akranes', 'Akranes,Akranesas,Akranesi,Akraneskaupstadur,Akraneskaupstaður,Skipaskagi,a ke la nei si,akeulaneseu,akuranesu,Ακρανές,Акранес,אקרנס,აკრანესი,アクラネース,阿克拉内斯,아크라네스', 64.3217900, -22.0749000, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79847, 'Laugar', 'Laugar', 'Laugar,Reykjadalur', 65.7215900, -17.3735200, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79848, 'Reykjanesbær', 'Reykjanesbaer', 'Reykjanesbae,Reykjanesbaejar,Reykjanesbaer,Reykjanesbar,Reykjanesbæ,Reykjanesbæjar,Reykjanesbær', 63.9981300, -22.5611100, 'IS', '2016-12-03', 102);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79772, 'Dowlatābād', 'Dowlatabad', 'Daulatabad,Daulatābād,Dowlatabad,Dowlatābād,dwlt abad,دولت آباد', 32.7997800, 51.6955300, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79773, 'Dorcheh Pīāz', 'Dorcheh Piaz', 'Darcheh Piaz,Darcheh Pīāz,Dorcheh Peyaz,Dorcheh Peyāz,Dorcheh Piaz,Dorcheh Pīāz', 32.6152800, 51.5555600, 'IR', '2011-09-12', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79774, 'Eslāmshahr', 'Eslamshahr', 'Eslamshahr,Eslāmshahr,aslamshhr,اسلامشهر', 35.5522200, 51.2350400, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79775, 'Shahrak-e Bākharz', 'Shahrak-e Bakharz', 'Shahr-e Now,Shahrak-e Bakharz,Shahrak-e Bākharz,shhrk bakhrz,شهرک باخرز', 34.9920400, 60.3171400, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79776, 'Zābol', 'Zabol', 'ACZ,Zabol,Zabol'',Zābol,zabl,Заболь,زابل', 31.0306000, 61.4949000, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79777, 'Zahedan', 'Zahedan', 'Dowzdab,Dowzdāb,Duzdab,Duzdap,Duzdāb,Duzdāp,Gorad Zakhedan,ZAH,Zahedan,Zahedan-e (Yek),Zahedanas,Zahedano,Zahedán,Zahidan,Zaidan,Zaidān,Zakhedan,Záhedán,Zāhedān,Zāhedān-e (Yek),cakitan,jahedan,jahedana,zahdan,zahedan,zahedana,zahedani,zha hei dan,Горад Захедан,Захедан,Зоҳидон,Զահեդան,زاهدان,زاہدان,ज़ाहेदान,জহেদন,சாகிதன்,ზაჰედანი,ザーヘダーン,扎黑丹,자헤단', 29.4963000, 60.8629000, 'IR', '2014-08-19', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79778, 'Zehak', 'Zehak', 'Deh-e Zahak,Zahak,Zehak,zhk,زهک', 30.8940000, 61.6804000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79779, 'Zābolī', 'Zaboli', 'Magas,Mehrestan,Mehrestān,Qal`eh-ye Zaboli,Qal‘eh-ye Zābolī,Zaboli,Zābolī,mhrstan,zably,زابلی,مهرستان', 27.1310000, 61.6744500, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79780, 'Torbat-e Jām', 'Torbat-e Jam', 'Torbat-e Jam,Torbat-e Jām,Torbat-e Sheykh Jam,Torbat-e Sheykh Jām,Turbat-i-Shaikh Jam,trbt jam,تربت جام', 35.2440000, 60.6225000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79781, 'Tāybād', 'Taybad', 'Taiabad,Taybad,Tayebad,Tayebat,Tayyebat,Taīabad,Tāybād,Tāyebāt,taybad,Ţayyebāt,تايباد', 34.7400000, 60.7756000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79782, 'Sūrān', 'Suran', 'Sooran,Suran,Surar,Sūrān,Sūrār,swran,سوران', 27.2855000, 61.9965000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79783, 'Sarakhs', 'Sarakhs', 'CKT,Sarahs,Sarakhs,Serakhs,srkhs,Сарахс,سرخس', 36.5449000, 61.1577000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79784, 'Rāsak', 'Rasak', 'Rasak,Rask,Razk,Rāsak,Rāsk,Rāzk,rask,راسک', 26.2368200, 61.3990100, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79785, 'Qaşr-e Qand', 'Qasr-e Qand', 'Barqan,Barqān,Borgan,Qasr Qand,Qasr-e Qand,Qasr-e-Qand,Qaşr Qand,Qaşr-e Qand', 26.2483300, 60.7525000, 'IR', '2014-07-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79786, 'Nīkshahr', 'Nikshahr', 'Geh,Keh,Nik,Nikshahr,Nīk,Nīkshahr,nykshhr,نیکشهر', 26.2258000, 60.2143000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79787, 'Nehbandān', 'Nehbandan', 'Nah,Neh,Nehbandan,Nehbandān,nhbndan,نهبندان', 31.5418500, 60.0364800, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79788, 'Konārak', 'Konarak', 'Kenarak,Kenārak,Konarak,Konārak,Kumarak,Kunarak,Kunark,Kunārak,Kūmārak,knark,کنارک', 25.3604000, 60.3995000, 'IR', '2014-10-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79789, 'Khvāf', 'Khvaf', 'Khaf,Khvaf,Khvāf,Khāf,Qasabeh-ye Rud,Qaşabeh-ye Rūd,Rud,Rui Khaf,Ruy,Rūd,Rūi Khāf,Rūy,khwaf,خواف', 34.5763000, 60.1409300, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79790, 'Khāsh', 'Khash', 'Kavash,Khash,Khāsh,Kwash,Kwāsh,Vasht,Vāsht,khash,Хаш,خاش', 28.2210700, 61.2158200, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79791, 'Iranshahr', 'Iranshahr', 'Fahrej,Fehruj,IHR,Iranshahr,Qal`eh-ye Naseri,Qal‘eh-ye Nāşerī,ayranshhr,Īrānshahr,ايرانشهر', 27.2024500, 60.6847600, 'IR', '2017-02-25', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79792, 'Ḩājjīābād', 'Hajjiabad', 'Hajabad,Hajiabad,Hajjiabad,Hajābād,Hājīābād,hajy abad,حاجی آباد,Ḩājjīābād', 33.6049600, 59.9934000, 'IR', '2014-09-30', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79793, 'Dūst Moḩammad Khān', 'Dust Mohammad Khan', 'Dust Mohammad Khan,Dūst Moḩammad Khān,dwst mhmd khan,دوست محمد خان', 31.1447000, 61.7925000, 'IR', '2014-09-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79794, 'Chabahar', 'Chabahar', 'Cabahar,Cahbahar,Chabahar,Chabakhar,Chah Bahar,Chakhbekhar,Chāh Bahār,Czabahar,Tschahbahar,ZBR,bndr chabhar,cabahara,chabhar,chah bhar,qia he ba ha er,tshabhar,Çabahar,Čabahar,Čáhbahár,Чабахар,Чахбехар,Чҳобаҳор,بندر چابهار,تشابهار,چابهار,چابہار,چاه بهار,چاہ بہار,चाबहार,ਚਾਬਹਾਰ,恰赫巴哈爾', 25.2919000, 60.6430000, 'IR', '2015-10-03', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79795, 'Māmūnīyeh', 'Mamuniyeh', 'Mamuniyeh,Māmūnīyeh,mamwnyh,مامونیه', 35.3055500, 50.4992000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79796, 'Mahābād', 'Mahabad', 'Mahabad,Mahābād,Mekhabad,mhabad,Мехабад,مهاباد', 36.7499000, 45.7229000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79797, 'Āz̄arshahr', 'Azarshahr', 'Azarshahr,Dehkhvareqan,Dehkhvāreqān,adhrshhr,dihkhwariqan,Āz̄arshahr,آذرشهر,دِهخوارِقان', 37.7590000, 45.9783000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79798, 'Tāzehābād', 'Tazehabad', 'Tazehabad,Tāzehābād,tazh abad,تازه آباد', 34.7387000, 46.1496000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79799, 'Kāshān', 'Kashan', 'Kachan,Kashan,Kāshān,kashan,كاشان', 33.9972800, 51.4415800, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79800, 'Jīroft', 'Jiroft', 'JYR,Jiroft,Jīroft,Sabzawaran,Sabzevaran,Sabzevaran-e Jiroft,Sabzevārān,Sabzevārān-e Jiroft,Sabzvaran,Sabzvārān,Sabzāwārān,jyrft,جیرفت', 28.6780600, 57.7405600, 'IR', '2017-02-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79801, 'Eslāmābād', 'Eslamabad', 'Eslamabad,Eslamabad-e Rudbar,Eslāmābād,Eslāmābād-e Rūdbār,Rudbar,Rūdbār,aslam abad,aslam abad rwdbar,rwdbar,اسلام آباد,اسلام آباد رودبار,رودبار', 28.0261100, 58.0000000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79802, 'Famast', 'Famast', '', 34.0389700, 48.4626000, 'IR', '2009-11-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79803, 'Kahnūj', 'Kahnuj', 'Kahnuj,Kahnūj,khnwj,کهنوج', 27.9519000, 57.6996000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79804, 'Mahdishahr', 'Mahdishahr', 'Mahdishahr,Sangsar,mhdyshhr,sngsr,سنگسر,مهدیشهر', 35.7107100, 53.3539400, 'IR', '2014-01-05', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79805, 'Dalgān', 'Dalgan', 'Dalgan,Dalgān,Galmurti,Galmūrtī,dlgan,glmwrty,دلگان,گلمورتی', 27.4823200, 59.4465600, 'IR', '2014-10-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79806, 'Āq Qalā', 'Aq Qala', 'Aq Qal`eh,Aq Qala,Pahlavi Dezh,Pahlavi-dej,Pahlavī Dezh,Pahlevi Diz,aq qla,Āq Qalā,Āq Qal‘eh,آق قلا', 37.0139000, 54.4550400, 'IR', '2014-10-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79807, 'Bandar-e Emam Khomeyni', 'Bandar-e Emam Khomeyni', 'Bandar Imam,Bandar Imam Khomeini,Bandar Jomeiny,Bandar Sahpur,Bandar Šâhpur,Bandar-e Chomejni,Bandar-e Emam Khomeyni,Bandar-e Homeini,Bandar-e Imam Chomeini,Bandare Chomeinis,Bandare Emm Xomeyni,Bender Imam Humeyni,Bender İmam Humeyni,Bender-Imam-Khomejni,Bender-Khomejni,Bəndər İmam Xomeyni,QBR,bandaleueemamhomeini,bandara-e-imama khumeyani,bandare・emamu・homeini,bndr amam khmyny,bndramam khmyny,huo mei ni gang,mynaʾ alamam alkhmyny,Бендер-Імам-Хомейні,Бендер-Хомейни,بندر امام خمينى,بندر امام خمینی,بندرامام خمینی,ميناء الإمام الخميني,बंदर-ए-इमाम खुमेयनी,バンダレ・エマーム・ホメイニー,霍梅尼港,반다르에에맘호메이니', 30.4369800, 49.1028800, 'IR', '2013-04-21', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79808, 'Qā’em Shahr', 'Qa''em Shahr', 'Qa''em Shahr,Qā’em Shahr,qaym shhr,قائم شهر', 36.4814400, 52.8910900, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79809, 'Pākdasht', 'Pakdasht', 'Mamazan,Māmāzān,Pakdasht,Pākdasht,mamazan,pakdsht,مامازان,پاکدشت', 35.4785400, 51.6834000, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79810, 'Boshrūyeh', 'Boshruyeh', 'Bocruye,Boshruiyeh,Boshruyeh,Boshrūyeh,Boshrūīyeh,Bushruieh,Bushruiyeh,Bushrūīeh,Bushrūīyeh,bshrwyh,بشرویه', 33.8684500, 57.4288500, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79811, 'Taft', 'Taft', 'Taft,tft,تفت', 31.7605600, 54.2230300, 'IR', '2014-09-06', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79812, 'Gīvī', 'Givi', 'Givi,Gīvī,gywy,گیوی', 37.6858500, 48.3420400, 'IR', '2014-09-07', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79813, 'Rey', 'Rey', 'Gorad Rehj,Raj,Ray,Rayy,Rei,Rej,Rejus,Rey,Rhagae,Rėjus,Shahr-e Rey,alry,lei yi,ry,shhr ry,Ρέι,Горад Рэй,Рей,الري,رى,ری,رے,شهر ری,雷伊', 35.5935400, 51.4399700, 'IR', '2014-09-08', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79814, 'Behābād', 'Behabad', 'Behabad,Behābād,bhabad,بهاباد', 31.8709100, 56.0243300, 'IR', '2014-10-04', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79815, 'Pasragad Branch', 'Pasragad Branch', '', 34.7777200, 48.4716800, 'IR', '2015-09-02', 105);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79849, 'Zumpano', 'Zumpano', 'Zumpano', 39.3105300, 16.2926900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79850, 'Zerfaliu', 'Zerfaliu', 'Zerfaliu', 39.9608800, 8.7097100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79851, 'Zeddiani', 'Zeddiani', 'Zeddiani', 39.9889800, 8.5958000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79852, 'Zambrone', 'Zambrone', 'Zambrone', 38.6987800, 15.9898200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79853, 'Zagarise', 'Zagarise', 'Zagarise', 38.9998500, 16.6642000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79854, 'Zafferana Etnea', 'Zafferana Etnea', 'Zafarana Etnea,Zaffarana Etnea,Zafferana,Zafferana Etnea', 37.6789500, 15.1043200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79855, 'Zaccanopoli', 'Zaccanopoli', 'Cakkanopoli,Dzakanopoli,Zaccanopoli,Zaccanopuli,Zaccanòpuli,Zachanopolis,Zambrone,zakkanopori,zha ka nuo bo li,zhakknwpwly,Дзаканополи,Цакканополи,Цакканополі,Ցաքանոպոլի,ژاککنوپولی,ザッカノーポリ,扎卡诺波利', 38.6654800, 15.9287400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79856, 'Vizzini', 'Vizzini', 'Vizzini', 37.1618800, 14.7571200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79857, 'Vittoria', 'Vittoria', 'Vittoira,Vittoria,vu~ittoria,ヴィットーリア', 36.9515100, 14.5278800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79858, 'Vita', 'Vita', 'Vita,vu~ita,ヴィータ', 37.8688600, 12.8275500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79859, 'Villaurbana', 'Villaurbana', 'Villaurbana', 39.8850500, 8.7783100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79860, 'Villaspeciosa', 'Villaspeciosa', 'Villaspeciosa', 39.3114200, 8.9258400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79861, 'Villasor', 'Villasor', 'Villasor', 39.3813000, 8.9427000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79862, 'Villasmundo', 'Villasmundo', '', 37.2513200, 15.0908700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79863, 'Villasimius', 'Villasimius', 'Villasimius', 39.1448100, 9.5182300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79864, 'Villa San Giovanni', 'Villa San Giovanni', 'Villa San Giovanni,Villa San Giuvanni', 38.2199100, 15.6368900, 'IT', '2016-11-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79865, 'Villasalto', 'Villasalto', 'Villasalto', 39.4920900, 9.3902300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79866, 'Villarosa', 'Villarosa', 'Villarosa,Villarosa Sicilia', 37.5875300, 14.1708900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79867, 'Villaputzu', 'Villaputzu', 'Villaputzu', 39.4405800, 9.5756400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79868, 'Villapiana', 'Villapiana', '', 39.8457300, 16.4552800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79869, 'Villanova Truschedu', 'Villanova Truschedu', 'Villanova Truschedu', 39.9884200, 8.7517700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79870, 'Villanovafranca', 'Villanovafranca', 'Villanovafranca', 39.6444200, 9.0024400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79871, 'Villanovaforru', 'Villanovaforru', 'Villanovaforru', 39.6319600, 8.8697900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79872, 'Villamassargia', 'Villamassargia', 'Villamassargia', 39.2748400, 8.6411000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79873, 'Villamar', 'Villamar', 'Villamar', 39.6188400, 8.9587700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79874, 'Villalba', 'Villalba', 'Vilalba,Villa Alba,Villal''ba,Villalba,Villarba,fylalba,vilalba,vu~irraruba,wei la er ba,Вилалба,Виллальба,Віллальба,Վիլալբա,فيلالبا,ვილალბა,ヴィッラルバ,维拉尔巴', 37.6545700, 13.8445200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79875, 'Villagrande Strisaili', 'Villagrande Strisaili', 'Villagrande,Villagrande Strisaile,Villagrande Strisaili', 39.9592900, 9.5094300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79876, 'Villafrati', 'Villafrati', 'Villafrati', 37.9064600, 13.4848600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79877, 'Villafranca Tirrena', 'Villafranca Tirrena', 'Villafranca Tirrena', 38.2395200, 15.4388500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79878, 'Villafranca Sicula', 'Villafranca Sicula', 'Villafranca,Villafranca Sicula', 37.5876100, 13.2904800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79879, 'Villacidro', 'Villacidro', 'Villacidro,vu~irrachidoro,ヴィッラチードロ', 39.4573400, 8.7410500, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79880, 'Villabate', 'Villabate', 'Villabate,Villabbati', 38.0778900, 13.4427500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79881, 'Viggianello', 'Viggianello', 'Viggianello', 39.9722700, 16.0852100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79882, 'Vicari', 'Vicari', 'Vicari', 37.8237100, 13.5688900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79883, 'Vibo Valentia', 'Vibo Valentia', 'Monteleone di Calabria,Vibbu Valenzia,Vibo Valentia,Vibo-Valentija,Вибо-Валентия,ヴィボ・ヴァレンツィア', 38.6761800, 16.1009400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79884, 'Viagrande', 'Viagrande', 'Viagrande,Viagranni', 37.6103200, 15.0979400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79885, 'Verzino', 'Verzino', 'Verzino', 39.3132500, 16.8561300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79886, 'Verbicaro', 'Verbicaro', 'Verbicaro', 39.7607600, 15.9073000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79887, 'Ventimiglia di Sicilia', 'Ventimiglia di Sicilia', 'Calamigna,Ventimiglia di Sicilia', 37.9236100, 13.5676800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79888, 'Venetico Superiore', 'Venetico Superiore', 'Venetico', 38.1930700, 15.3811900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79889, 'Vazzano', 'Vazzano', 'Vacano,Vaccano,Vatianum,Vazzano,Vazzanu,vu~attsu~ano,wa zha nuo,wznw,Вацано,Ваццано,Վացանո,وزنو,ヴァッツァーノ,瓦扎诺', 38.6328800, 16.2480000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79890, 'Varapodio', 'Varapodio', 'Varapodio', 38.3163300, 15.9834700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79891, 'Vallermosa', 'Vallermosa', 'Vallermosa', 39.3638900, 8.7955600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79892, 'Vallelunga Pratameno', 'Vallelunga Pratameno', 'Vaddilonga,Vallelunga Pratameno', 37.6820500, 13.8315600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79893, 'Vallelonga', 'Vallelonga', 'Vallelonga', 38.6474200, 16.2965900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79894, 'Vallefiorita', 'Vallefiorita', 'Vallefiorita', 38.7763800, 16.4610000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79895, 'Valledolmo', 'Valledolmo', 'Vaddilurmu,Valledolmo', 37.7470300, 13.8281100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79896, 'Valguarnera Caropepe', 'Valguarnera Caropepe', 'Carrapipi,Valguarnera,Valguarnera Caropepe', 37.4952700, 14.3902500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79897, 'Valdina', 'Valdina', 'Valdina', 38.1935100, 15.3698000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79898, 'Vaccarizzo Albanese', 'Vaccarizzo Albanese', 'Vaccarizzo Albanese,Vakarici', 39.5854000, 16.4328900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79899, 'Uta', 'Uta', 'Uta', 39.2918600, 8.9523400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79900, 'Ustica', 'Ustica', 'Ustica,usutika dao,ウスティカ島', 38.7098500, 13.1929300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79901, 'Ussassai', 'Ussassai', 'Ussassai', 39.8099800, 9.3950800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79902, 'Ussaramanna', 'Ussaramanna', 'Ussaramanna', 39.6925000, 8.9085000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79903, 'Ussana', 'Ussana', 'Ussana', 39.3937400, 9.0749600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79904, 'Usellus', 'Usellus', 'Usellus', 39.8083300, 8.8516700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79905, 'Uras', 'Uras', 'Uras', 39.6979900, 8.7014300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79906, 'Umbriatico', 'Umbriatico', 'Umbriatico', 39.3533600, 16.9179800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79907, 'San Ciro-Ulmi-Filci', 'San Ciro-Ulmi-Filci', '', 37.8332800, 12.7822900, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79908, 'Ulassai', 'Ulassai', 'Ulassai', 39.8103300, 9.4996200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79909, 'Ugento', 'Ugento', 'Ugento', 39.9272400, 18.1583200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79910, 'Ucria', 'Ucria', 'Ucria', 38.0462400, 14.8808700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79911, 'Tusa', 'Tusa', 'Tusa', 37.9838500, 14.2360600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79912, 'Turri', 'Turri', 'Turri', 39.7047600, 8.9165600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79913, 'Tuili', 'Tuili', 'Tuili', 39.7147700, 8.9602000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79914, 'Tropea', 'Tropea', 'Tropea,toropea,トロペーア', 38.6744900, 15.8950500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79915, 'Troina', 'Troina', 'Troina,Truina', 37.7843700, 14.5960500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79916, 'Tripi', 'Tripi', 'Tripi', 38.0467300, 15.0967000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79917, 'Tricase', 'Tricase', 'Tricase', 39.9301800, 18.3542100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79918, 'Trenta', 'Trenta', 'Trenta,torenta,トレンタ', 39.2854100, 16.3209300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79919, 'Trecastagni', 'Trecastagni', 'Trecastagni,Tricastagni', 37.6154300, 15.0779600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79920, 'Trebisacce', 'Trebisacce', 'Trebisacce', 39.8712800, 16.5342000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79921, 'Tratalias', 'Tratalias', 'Tratalias', 39.1034700, 8.5785800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79922, 'Trapani', 'Trapani', 'Drepanum,TPS,Trapani,Trapena,Tràpani,Tràpena,Trápani,torapani,Трапани,טרפאני,トラーパニ', 38.0176000, 12.5361700, 'IT', '2017-07-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79923, 'Tramatza', 'Tramatza', 'Tramatza', 40.0029200, 8.6494400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79924, 'Trabia', 'Trabia', 'Trabbia,Trabbìa,Trabia', 38.0042000, 13.6339300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79925, 'Tortorici', 'Tortorici', 'Tortorici,Turturici', 38.0297300, 14.8221200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79926, 'Tortora', 'Tortora', 'Tortora', 39.9413000, 15.8051800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79927, 'Tortolì', 'Tortoli', 'TTB,Tortoli,Tortolì,torutori,Тортоли,トルトリ', 39.9262600, 9.6556900, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79928, 'Torretta', 'Torretta', 'La Torretta,Torretta', 39.4535800, 17.0363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79929, 'Torretta', 'Torretta', 'Torretta', 38.1303600, 13.2354900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79930, 'Campora San Giovanni', 'Campora San Giovanni', 'Campora San Giuann,Campora San Giuànn,Campora Sancte Iohannes,Kampora San Covanni,Kampora San DZovani,Kampora San Dzhovani,Kampora San Dziovanis,Kampora San Dziuovanis,Kampora San Dzowanni,Kampora San Džiovanis,Kampora San Džiuovanis,Kampora San Džowanni,Kampora San Jovanni,Kampora San-Dzhovanni,Kampora Sandzovanni,Kampora Sandžovanni,Kampora-San-Dzhavani,Kampora-San-Dzhovanni,kambwra san jwfany,kampara sana jobhanni,kampolasanjobanni,kampwra san jwwany,ken bo la sheng ji ao wa ni,Кампора Сан Џовани,Кампора Сан Джовани,Кампора Сан-Джованні,Кампора-Сан-Джавані,Кампора-Сан-Джованни,Կամպորա Սան Ջովաննի,קמפורה סן גובאני,كامبورا سان جوفاني,کامپورا سان جووانی,কাম্পরা সান জোভান্নি,കാംപോറ സാൻ ജന്നി,კამპორა-სან-ჯოვანი,ካምፖራ ሳን ጆቫኒ,カンポラ・サン・ジョヴァンニ,肯波拉圣吉奥瓦尼,캄포라산조반니', 39.0679800, 16.0956600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79931, 'Torrenova', 'Torrenova', 'Torrenova', 38.0924600, 14.6791700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79932, 'Torre Melissa', 'Torre Melissa', '', 39.3101300, 17.1066000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79933, 'Torregrotta', 'Torregrotta', 'Torregrotta', 38.2026200, 15.3501000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79934, 'Torre di Ruggiero', 'Torre di Ruggiero', 'Torre,Torre di Ruggero,Torre di Ruggiero', 38.6529300, 16.3721100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79935, 'Torano Castello', 'Torano Castello', 'Torano Castello', 39.5039600, 16.1610300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79936, 'Tiriolo', 'Tiriolo', 'Tiriolo', 38.9406900, 16.5104600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79937, 'Tiggiano', 'Tiggiano', 'Tiggiano', 39.9028400, 18.3650100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79938, 'Teulada', 'Teulada', 'Teulada', 38.9665800, 8.7714900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79939, 'Tertenia', 'Tertenia', 'Tertenia', 39.6951800, 9.5787800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79940, 'Terravecchia', 'Terravecchia', 'Terravecchia', 39.4659400, 16.9462300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79941, 'Terrasini', 'Terrasini', 'Terrasini', 38.1462100, 13.0831900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79942, 'Terranova Sappo Minulio', 'Terranova Sappo Minulio', 'Terranova,Terranova Sappo Minulio,Terranuova', 38.3217500, 16.0074700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79943, 'Terranova da Sibari', 'Terranova da Sibari', 'Terranova da Sibari,Terranova da Síbari', 39.6554800, 16.3397900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79944, 'Terranova di Pollino', 'Terranova di Pollino', 'Terranova di Pollino', 39.9776500, 16.2958300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79945, 'Terralba', 'Terralba', 'Tarraba,Terralba', 39.7205600, 8.6350400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79946, 'Termini Imerese', 'Termini Imerese', 'QTI,Termini,Termini Imerese,Thermae Himerarae,Tèrmini', 37.9822500, 13.6972900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79947, 'Taviano', 'Taviano', 'Taviano', 39.9822400, 18.0815100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79948, 'Taverna', 'Taverna', 'Taberna,Taverna,ta wei er na,tavu~eruna,Таверна,Տավերնա,タヴェルナ,塔韦尔纳', 39.0220000, 16.5808100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79949, 'Taurisano', 'Taurisano', 'Tanrisano,Taurisano', 39.9574600, 18.2149800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79950, 'Taurianova', 'Taurianova', 'Iatrinoli,Taurianova', 38.3552500, 16.0130600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79951, 'Tarsia', 'Tarsia', 'Tarsia', 39.6231100, 16.2733700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79952, 'Taormina', 'Taormina', 'TFC,Taorima,Taormina,Taurmina,Tauromenium,tao er mi na,taorumina,tawrmyna,Таормина,Таорміна,Տաորմինա,טאורמינה,تاورمينا,ടാഓർമിന,タオルミーナ,陶尔米纳', 37.8535800, 15.2885100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79953, 'Sutera', 'Sutera', 'Sutera', 37.5249300, 13.7327400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79954, 'Surdo', 'Surdo', '', 39.3275200, 16.2013900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79955, 'Suelli', 'Suelli', 'Suelli', 39.5625700, 9.1324500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79956, 'Strongoli', 'Strongoli', '', 39.2657600, 17.0541300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79957, 'Stilo', 'Stilo', 'Stilo,Stilo vald,Stilu,Stylo,Stylum,si di luo,stylw,sutiro,Στύλο,Стило,Стіло,Ստիլո,ستيلو,スティーロ,斯蒂洛', 38.4762800, 16.4674600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79958, 'Stignano', 'Stignano', 'Stignano', 38.4170500, 16.4701100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79959, 'Staletti', 'Staletti', 'Staletti,Stalettì', 38.7642800, 16.5393200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79960, 'Staiti', 'Staiti', 'Staiti', 37.9998900, 16.0334100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79961, 'Squillace', 'Squillace', 'Squillace', 38.7809100, 16.5117500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79962, 'Spilinga', 'Spilinga', 'Spilinga', 38.6282500, 15.9057200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79963, 'Spezzano Piccolo', 'Spezzano Piccolo', 'Spezzano Piccolo', 39.2901000, 16.3421100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79964, 'Spezzano della Sila', 'Spezzano della Sila', 'Spezzano della Sila', 39.3003300, 16.3392300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79965, 'Spezzano Albanese', 'Spezzano Albanese', 'Spezzano Albanese,Spixana', 39.6685400, 16.3093900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79966, 'Sperlinga', 'Sperlinga', '', 37.7665300, 14.3507500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79967, 'Specchia', 'Specchia', 'Specchia', 39.9391300, 18.2978400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79968, 'Sparta''', 'Sparta''', 'Sparta,Sparta di Messina,Spartà,Spartà di Messina', 38.2937100, 15.5350300, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79969, 'Spadafora', 'Spadafora', 'Spadafora', 38.2234900, 15.3817800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79970, 'Soveria Simeri', 'Soveria Simeri', 'Soveria,Soveria Simeri', 38.9498600, 16.6785400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79971, 'Soveria Mannelli', 'Soveria Mannelli', 'Soveria Mannelli', 39.0778400, 16.3770800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79972, 'Soverato Superiore', 'Soverato Superiore', '', 38.6899300, 16.5339100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79973, 'Soverato Marina', 'Soverato Marina', 'Marina di Soverato,Soverato', 38.6849800, 16.5499100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79974, 'Sortino', 'Sortino', 'Sciurtinu,Sortino', 37.1588100, 15.0299800, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79975, 'Soriano Calabro', 'Soriano Calabro', 'Soriano Calabro', 38.6003800, 16.2220500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79976, 'Sorianello', 'Sorianello', 'Sorianello', 38.5941500, 16.2321200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79977, 'Sorbo San Basile', 'Sorbo San Basile', 'Sarbo,Sorbo,Sorbo San Basile', 39.0193900, 16.5691000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79978, 'Sommatino', 'Sommatino', 'Sommatino,Summatinu', 37.3347100, 13.9973900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79979, 'Soleminis', 'Soleminis', 'Soleminis,Solèminis,soreminisu,suo lai mi ni si,Солеминис,Солемініс,Սոլեմինիս,ソレーミニス,索莱米尼斯', 39.3476000, 9.1812700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79980, 'Solarussa', 'Solarussa', 'Solarussa', 39.9549900, 8.6739300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79981, 'Solarino', 'Solarino', 'San Paulu,Solarino', 37.1013600, 15.1198800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79982, 'Solanas', 'Solanas', '', 39.9303100, 8.5534000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79983, 'Siris', 'Siris', 'Siris', 39.7122800, 8.7750700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79984, 'Siracusa', 'Siracusa', 'Gorad Sirakuza,Lungsod ng Siracusa,QIC,Sarausa,Sioracus,Sioracús,Siracuesa,Siracusa,Siracuxa,Siracuza,Siracüsa,Sirakueza,Sirakusa,Sirakuz,Sirakuza,Sirakuzae,Sirakuzai,Sirakuzas,Sirakuze,Sirakuzo,Sirakuzy,Siraküza,Sirakūzai,Sirakūzas,Syracusae,Syracuse,Syrakouses,Syrakus,Syrakusa,Syrakusy,Syrakuzy,Syrakúzy,sayrakwz,shirakusa,si ra ku sa,silakusa,srqwst,syrakwz,syrqwzh,xi la ku zha,Συρακούσες,Горад Сіракуза,Сиракузæ,Сиракуза,Сиракузы,Сіракуза,Սիրակուզա,סירקוזה,سائراکوز,سرقوسة,سرقوسہ، صقلیہ,سیراکوز,ซีรากูซา,სირაკუზა,シラクサ,锡拉库扎,시라쿠사', 37.0841500, 15.2762800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79985, 'Sinopoli', 'Sinopoli', 'Sinopoli,shinopori,シノーポリ', 38.2634200, 15.8771000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79986, 'Sinnai', 'Sinnai', 'Sinnai', 39.3028600, 9.2028300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79987, 'Sini', 'Sini', 'Sini', 39.7535300, 8.9048600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79988, 'Sinagra', 'Sinagra', 'Sinagra', 38.0819100, 14.8500900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79989, 'Simbario', 'Simbario', 'Simbario,Simbarium,Zimbariu,shinbario,xin ba liao,Симбарио,Сімбаріо,Սիմբարիո,シンバーリオ,辛巴廖', 38.6115700, 16.3359700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79990, 'Simaxis', 'Simaxis', 'Simaxis', 39.9299500, 8.6897900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79991, 'Simala', 'Simala', 'Simala', 39.7209900, 8.8280200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79992, 'Silius', 'Silius', 'Silius', 39.5169500, 9.2936000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79993, 'Siliqua', 'Siliqua', '', 39.3010000, 8.8058400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79994, 'Silì', 'Sili', '', 39.9178900, 8.6219400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79995, 'Siderno', 'Siderno', 'Siderno,Siderno Marino,shideruno,シデルノ', 38.2699300, 16.2960700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79996, 'Siddi', 'Siddi', 'Siddi', 39.6725500, 8.8881500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79997, 'Siculiana', 'Siculiana', 'Siculiana', 37.3351500, 13.4243200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79998, 'Sibari', 'Sibari', 'Sibari', 39.7473300, 16.4551000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(79999, 'Siapiccia', 'Siapiccia', 'Siapiccia', 39.9276500, 8.7627000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80000, 'Siano', 'Siano', '', 38.9154700, 16.6022400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80001, 'Siamanna', 'Siamanna', 'Siamanna', 39.9193600, 8.7618500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80002, 'Siamaggiore', 'Siamaggiore', 'Siamaggiore', 39.9496600, 8.6346100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80003, 'Seulo', 'Seulo', 'Seulo', 39.8695500, 9.2360600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80004, 'Seui', 'Seui', 'Seui', 39.8390800, 9.3234700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80005, 'Setzu', 'Setzu', 'Setzu', 39.7230600, 8.9397200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80006, 'Settimo San Pietro', 'Settimo San Pietro', 'Seltimo San Pietro,Settimo San Pietro', 39.2911000, 9.1857000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80007, 'Sestu', 'Sestu', 'Sestu', 39.2984600, 9.0924800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80008, 'Sersale', 'Sersale', 'Sarsale,Sersale,Sersale vald,Sersalis,sai er sa lai,serusare,Серсале,Սերսալե,セルサーレ,塞尔萨莱', 39.0101300, 16.7296000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80009, 'Serri', 'Serri', 'Seri,Serri,Serris,Sery,serri,Сери,Серри,Серрі,Серы,Սերրի,セッリ', 39.7015000, 9.1449000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80010, 'Serrenti', 'Serrenti', 'Serrenti', 39.4927700, 8.9765900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80011, 'Serrata', 'Serrata', 'Serrata', 38.5128800, 16.1007000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80012, 'Serrastretta', 'Serrastretta', 'Serrastretta', 39.0131900, 16.4163000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80013, 'Serra San Bruno', 'Serra San Bruno', 'Serra San Bruno', 38.5747400, 16.3262200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80014, 'Serra Pedace', 'Serra Pedace', 'Serra,Serra Pedace', 39.2789800, 16.3455700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80015, 'Serramanna', 'Serramanna', 'Serramanna', 39.4233500, 8.9224300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80016, 'Serradifalco', 'Serradifalco', 'Serradifalco,Serradifarcu', 37.4538400, 13.8804600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80017, 'Serra d''Aiello', 'Serra d''Aiello', 'Serra d''Aiello,Serra di Aiello', 39.0900400, 16.1261200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80018, 'Serdiana', 'Serdiana', 'Serdiana', 39.3745700, 9.1585100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80019, 'Senorbì', 'Senorbi', 'Senorbi,Senorbì', 39.5334100, 9.1316800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80020, 'Senis', 'Senis', 'Senis', 39.8231800, 8.9391600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80021, 'Seminara', 'Seminara', 'Seminara', 38.3360300, 15.8702500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80022, 'Sellia', 'Sellia', 'Sellia', 38.9820600, 16.6307000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80023, 'Selegas', 'Selegas', 'Selegas', 39.5678000, 9.1034800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80024, 'Selargius', 'Selargius', 'Selargius', 39.2577900, 9.1632300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80025, 'Segariu', 'Segariu', 'Segariu', 39.5640300, 8.9816300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80026, 'Scordia', 'Scordia', 'Scordia,Scurdia', 37.2954800, 14.8405800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80027, 'Scoglitti', 'Scoglitti', '', 36.8942400, 14.4335500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80028, 'Sclafani Bagni', 'Sclafani Bagni', '', 37.8217500, 13.8547600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80029, 'Scillato', 'Scillato', 'Scillato', 37.8577800, 13.9063200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80030, 'Scilla', 'Scilla', 'Scilla,Scylleum,Shila,Shilla,Silla,Skylla tis Messinis,U Scigghiu,shirra,shyla,stshyla,sylh,Σκύλλα της Μεσσήνης,Шила,Шилла,Շիլլա,שילה,ستشيلا,شیلا,シッラ', 38.2520100, 15.7183700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80031, 'Scido', 'Scido', 'Scido,shido,シード', 38.2443900, 15.9325100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80032, 'Scicli', 'Scicli', 'Scicli,Shikli,shikuri,Шикли,シクリ', 36.7901400, 14.7028000, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80033, 'Sciara', 'Sciara', 'Sara,Sciara,Shara,Shiara,shara,xia la,Шара,Шіара,Շարա,شارا,シャーラ,夏拉', 37.9151100, 13.7617700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80034, 'Sciacca', 'Sciacca', 'Sciacca,Sciacea,Shaka,Xaca,Шака', 37.5069300, 13.0839900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80035, 'Scarcelli', 'Scarcelli', '', 39.4000000, 16.0166700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80036, 'Scandale', 'Scandale', 'Scandale', 39.1233900, 16.9618500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80037, 'Scaletta Zanclea', 'Scaletta Zanclea', 'Scaletta,Scaletta Zanclea', 38.0479600, 15.4676900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80038, 'Scalea', 'Scalea', 'Scalea', 39.8060500, 15.7963500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80039, 'Scala Coeli', 'Scala Coeli', 'Scala Coeli', 39.4482400, 16.8865800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80040, 'Savelli', 'Savelli', 'Savelli', 39.3127800, 16.7764200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80041, 'Satriano', 'Satriano', 'Satriano', 38.6664000, 16.4797000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80042, 'Sartano', 'Sartano', 'Sarcano,Sartano', 39.5116900, 16.1791500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80043, 'Sarroch', 'Sarroch', 'Sarroch', 39.0657700, 9.0093700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80044, 'Sardara', 'Sardara', 'Sardara', 39.6146500, 8.8208800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80045, 'Saracena', 'Saracena', 'Saracena', 39.7786200, 16.1591300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80046, 'Saponara', 'Saponara', 'Saponara,Sapunara', 38.1924100, 15.4344200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80047, 'San Vito Sullo Ionio', 'San Vito Sullo Ionio', 'San Vito,San Vito sul Ionio,San Vito sull''Jonio,San Vito sullo Ionio,San Vito sullo Iónio', 38.7074900, 16.4086200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80048, 'San Vito Lo Capo', 'San Vito Lo Capo', 'San Vito,San Vito Lo Capo,San Vito lo Cape,San Vito lo Capo', 38.1739500, 12.7359900, 'IT', '2015-07-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80049, 'San Vito', 'San Vito', 'San Vito', 39.4414200, 9.5406500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80050, 'San Vincenzo la Costa', 'San Vincenzo la Costa', 'San Vincenzo,San Vincenzo La Costa', 39.3654400, 16.1511000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80051, 'Santo Stefano Quisquina', 'Santo Stefano Quisquina', 'Santo Stefano Quisquina,Santu Stefanu Quisquina,Santu Stèfanu Quisquina', 37.6260600, 13.4897600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80052, 'Santo Stefano in Aspromonte', 'Santo Stefano in Aspromonte', 'San Stefano,Santo Stefano,Santo Stefano d''Aspromonte,Santo Stefano in Aspromonte', 38.1690900, 15.7898300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80053, 'Santo Stefano di Rogliano', 'Santo Stefano di Rogliano', 'Santo Stefano di Rogliano,サント・ステーファノ・ディ・ロリアーノ', 39.1922300, 16.3207900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80054, 'Santo Stefano di Camastra', 'Santo Stefano di Camastra', 'Santo Stefano di Camastra', 38.0129500, 14.3514200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80055, 'San Sperate', 'San Sperate', 'San Sperate,Santi Sperate,Santo Sperale,Santo Sperate', 39.3575800, 9.0081400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80056, 'Sant''Onofrio', 'Sant''Onofrio', 'Sant''Onofrio', 38.6975200, 16.1475500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80057, 'Sant''Ilario dello Ionio', 'Sant''Ilario dello Ionio', 'Sant''Ilario,Sant''Ilario Jonio,Sant''Ilario dell Ionio,Sant''Ilário,Sant''Ilário dell Ionio', 38.2191400, 16.1951700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80058, 'Santa Eufemia Lamezia', 'Santa Eufemia Lamezia', 'Sant''Eufemia Lamezia,Santa Eufemia Lamezia', 38.9198200, 16.2522100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80059, 'Sant''Eufemia d''Aspromonte', 'Sant''Eufemia d''Aspromonte', 'Sant''Eufemia d''Aspromonte,Sant''Eufemia di Aspromonte', 38.2631400, 15.8566900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80060, 'San Teodoro', 'San Teodoro', '', 37.8479700, 14.6987800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80061, 'Sant''Elia', 'Sant''Elia', '', 38.9578800, 16.5852100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80062, 'Santa Venerina', 'Santa Venerina', 'Santa Venerina,Santa Vinirina', 37.6910300, 15.1388000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80063, 'Santa Teresa di Riva', 'Santa Teresa di Riva', 'Santa Teresa di Riva', 37.9463500, 15.3667100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80064, 'Santa Sofia d''Epiro', 'Santa Sofia d''Epiro', 'Santa Sofia d''Epiro,Santa Sofia d''Epvo,Shen Sofia', 39.5459700, 16.3281500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80065, 'Santa Severina', 'Santa Severina', 'Santa Severina', 39.1477000, 16.9111200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80066, 'Sant''Antioco', 'Sant''Antioco', 'Sant''Antioco,SantAntioco', 39.0701700, 8.4524300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80067, 'Sant''Anna Arresi', 'Sant''Anna Arresi', 'Arresi,Sant''Anna Arresi', 39.0061800, 8.6423600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80068, 'Santa Ninfa', 'Santa Ninfa', 'Santa Ninfa', 37.7704200, 12.8774400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80069, 'Sant''Angelo Muxaro', 'Sant''Angelo Muxaro', 'Sant''Angelo Muxaro,Sant''Angilu Muxaru,Sant''Àngilu Muxaru', 37.4801400, 13.5455400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80070, 'Sant''Angelo di Brolo', 'Sant''Angelo di Brolo', 'Sant''Angelo,Sant''Angelo di Brolo', 38.1151800, 14.8840300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80071, 'Gerocarne', 'Gerocarne', 'Dzherokarne,Gerocarne,Girucarni,Hyerocarnes,Jerokarne,jerokarune,jie luo ka er nei,Джерокарне,Ջերոկարնե,ジェロカルネ,杰罗卡尔内', 38.5876700, 16.2181800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80072, 'Sant''Andrea Frius', 'Sant''Andrea Frius', 'Sant''Andrea Frius', 39.4791700, 9.1700000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80073, 'Sant''Andrea Apostolo dello Ionio', 'Sant''Andrea Apostolo dello Ionio', 'Sant''Andrea,Sant''Andrea Aposlolo dello Ionio,Sant''Andrea Apostolo,Sant''Andrea Apostolo dello Ionio', 38.6216500, 16.5304800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80074, 'Santa Marina Salina', 'Santa Marina Salina', 'Salina,Salina Isola,Santa Marina Salina,サンタ・マリーナ・サリーナ', 38.5611700, 14.8707700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80075, 'Santa Maria di Licodia', 'Santa Maria di Licodia', 'Santa Maria di Licodia,Santa Maria di Licuddia', 37.6168400, 14.8933700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80076, 'Santa Margherita di Belice', 'Santa Margherita di Belice', 'San Margherita,Santa Margarita,Santa Margherita Belice,Santa Margherita di Belice', 37.6928100, 13.0158400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80077, 'Santa Lucia del Mela', 'Santa Lucia del Mela', 'Santa Lucia del Mela', 38.1440800, 15.2805500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80078, 'Sant''Alfio', 'Sant''Alfio', 'Sant''Alfio,Sant''Arfiu', 37.7439300, 15.1395200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80079, 'Sant''Alessio Siculo', 'Sant''Alessio Siculo', 'Sant''Alessio Siculo,Sant''Alessiu Siculu,Sant''Alessiu Sìculu', 37.9251600, 15.3496800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80080, 'Sant''Alessio in Aspromonte', 'Sant''Alessio in Aspromonte', 'Sant''Alessio in Aspromonte', 38.1722000, 15.7573000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80081, 'Santa Giusta', 'Santa Giusta', 'Santa Giusta', 39.8807000, 8.6091600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80082, 'Sant''Agata di Militello', 'Sant''Agata di Militello', 'San Agata,Sant''Agata,Sant''Agata di Militello,Sant''Ágata,Sant-Agata-di-Militello,Сант-Агата-ди-Милителло', 38.0683800, 14.6360000, 'IT', '2014-04-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80083, 'Sant''Agata di Esaro', 'Sant''Agata di Esaro', 'Sant''Agata,Sant''Agata d''Esaro,Sant''Agata di Esaro', 39.6223500, 15.9829500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80084, 'Santa Flavia', 'Santa Flavia', 'Santa Flavia', 38.1044800, 13.5334000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80085, 'Santa Elisabetta', 'Santa Elisabetta', 'Santa Elisabbetta,Santa Elisabetta,Santa Elizabetta', 37.4317100, 13.5538600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80086, 'Santa Domenica Vittoria', 'Santa Domenica Vittoria', 'Santa Domenica,Santa Domenica Vittoria', 37.9162400, 14.9628800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80087, 'Santa Domenica Talao', 'Santa Domenica Talao', 'Santa Domenica Talao', 39.8187500, 15.8538000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80088, 'Santa Domenica', 'Santa Domenica', 'Santa Domenica di Ricadi', 38.6622000, 15.8628900, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80089, 'Santadi', 'Santadi', 'Santadi', 39.0935600, 8.7125900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80090, 'Santa Croce Camerina', 'Santa Croce Camerina', 'Santa Croce Camerina,Santa Cruci Camarina,サンタ・クローチェ・カメリーナ', 36.8284200, 14.5253800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80091, 'Santa Cristina Gela', 'Santa Cristina Gela', 'Santa Cristina Gela,Sendahstina', 37.9851400, 13.3274700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80092, 'Santa Cristina d''Aspromonte', 'Santa Cristina d''Aspromonte', 'Santa Cristina,Santa Cristina d''Aspromonte', 38.2548000, 15.9699600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80093, 'Santa Caterina Villarmosa', 'Santa Caterina Villarmosa', 'Santa Catarina,Santa Caterina Villarmosa', 37.5903400, 14.0355400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80094, 'Santa Caterina dello Ionio', 'Santa Caterina dello Ionio', 'Santa Caterina,Santa Caterina del Jonio,Santa Caterina dell Ionio,Santa Caterina dell Iónio,Santa Caterina dell''Jonio,Santa Caterina dello Ionio', 38.5332400, 16.5217600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80095, 'Santa Caterina Albanese', 'Santa Caterina Albanese', 'Picilia,Santa Caterina,Santa Caterina Albanese', 39.5859000, 16.0703900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80096, 'San Sosti', 'San Sosti', 'San Sosti', 39.6587900, 16.0295800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80097, 'San Sostene', 'San Sostene', 'San Sostene', 38.6373300, 16.4875100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80098, 'San Salvatore di Fitalia', 'San Salvatore di Fitalia', 'San Salvatore,San Salvatore di Fitalia', 38.0684100, 14.7779900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80099, 'San Roberto', 'San Roberto', 'Fanum Sancti Ruberti,San Roberto,San Rubertu,San-Roberto,san rwbyrtw,sheng luo bei er tuo,Сан Роберто,Сан-Роберто,Սան Ռոբերտո,سان روبيرتو,サン・ロベルト,圣罗贝尔托', 38.2111400, 15.7359400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80100, 'San Procopio', 'San Procopio', 'San Procopio', 38.2821400, 15.8908300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80101, 'Villa San Pietro', 'Villa San Pietro', 'San Pietro Pula,Villa San Pietro', 39.0355400, 8.9969500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80102, 'San Pietro in Guarano', 'San Pietro in Guarano', 'San Pietro in Guarano', 39.3416400, 16.3130400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80103, 'San Pietro in Amantea', 'San Pietro in Amantea', 'San Pietro,San Pietro in Amantea', 39.1365800, 16.1124300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80104, 'San Pietro Apostolo', 'San Pietro Apostolo', 'Fanum Sancti Petri ad Tyriolum,San Pietro Apostolo,San Pietro Apostolo vald,San-P''etro-Apostolo,San-Petro-Apostolo,Santu Pietru de Tiriuolu,sheng pi ye te luo a bo si tuo luo,Сан Пиетро Апостоло,Сан-Пьетро-Апостоло,Сан-Пєтро-Апостоло,サン・ピエトロ・アポストロ,圣皮耶特罗阿波斯托洛', 39.0041300, 16.4678300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80105, 'San Pietro a Maida', 'San Pietro a Maida', 'San Pietro,San Pietro a Maida', 38.8473100, 16.3411600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80106, 'San Piero Patti', 'San Piero Patti', 'San Piero Patti,San Pietro Patti', 38.0521400, 14.9681600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80107, 'San Pier Niceto', 'San Pier Niceto', 'San Pier Niceto', 38.1605000, 15.3498200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80108, 'San Nicolo''Gerrei', 'San Nicolo''Gerrei', 'San Nicolo Gerrei,San Nicolò Gerrei', 39.4983300, 9.3061100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80109, 'San Nicolò d''Arcidano', 'San Nicolo d''Arcidano', 'San Nicolo d''Arcidano,San Nicolò d''Arcidano,San Nicolò d’Arcidano', 39.6841700, 8.6436100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80110, 'San Nicolò', 'San Nicolo', '', 38.6342600, 15.8514700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80111, 'San Nicola dell''Alto', 'San Nicola dell''Alto', 'San Nicola dell''Alto,Shen Kolli', 39.2909400, 16.9717900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80112, 'San Nicola da Crissa', 'San Nicola da Crissa', 'San Nicola da Crissa,San Nicola di Crissa', 38.6635400, 16.2859200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80113, 'San Nicola Arcella', 'San Nicola Arcella', 'San Nicola Arcella', 39.8434100, 15.7863400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80114, 'San Michele di Ganzaria', 'San Michele di Ganzaria', 'San Michele,San Michele di Ganzaria,San Micheli di Ganzaria', 37.2804200, 14.4263300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80115, 'San Mauro Marchesato', 'San Mauro Marchesato', '', 39.1055900, 16.9256100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80116, 'San Mauro Castelverde', 'San Mauro Castelverde', 'San Mauro,San Mauro Castelverde,Santu Mauru', 37.9147800, 14.1896100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80117, 'San Martino di Finita', 'San Martino di Finita', 'San Martino,San Martino di Finita,Shen Murtiri', 39.4898800, 16.1096800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80118, 'San Martino', 'San Martino', 'San Martino', 38.3615700, 15.9763400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80119, 'San Marco d''Alunzio', 'San Marco d''Alunzio', 'San Marco d''Alunzio', 38.0726100, 14.7009300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80120, 'San Marco Argentano', 'San Marco Argentano', 'San Marco Argentano', 39.5572500, 16.1245200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80121, 'San Mango d''Aquino', 'San Mango d''Aquino', 'San Mango,San Mango d''Aquino', 39.0603600, 16.1922400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80122, 'Sanluri', 'Sanluri', 'Sanluri,Sullurium,sanruri,Санлури,サンルーリ', 39.5617600, 8.8996900, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80123, 'San Lucido', 'San Lucido', 'San Lucido', 39.3101200, 16.0531700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80124, 'San Luca', 'San Luca', 'Fanum Sancti Lucae,San Luca,San Luka,San-Luka,Santu Luca,san lwka,sheng lu ka,Сан Лука,Сан-Лука,Սան Լուկա,سان لوكا,サン・ルーカ,圣卢卡', 38.1467200, 16.0662500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80125, 'San Lorenzo del Vallo', 'San Lorenzo del Vallo', 'San Lorenzo de Vallo,San Lorenzo del Vallo', 39.6673900, 16.2986600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80126, 'San Lorenzo Bellizzi', 'San Lorenzo Bellizzi', 'San Lorenzo,San Lorenzo Bellizzi', 39.8886700, 16.3302900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80127, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo di Reggio Calabria', 38.0109700, 15.8344000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80128, 'San Leone Mosè', 'San Leone Mose', '', 37.2649700, 13.5843400, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80129, 'San Gregorio d''Ippona', 'San Gregorio d''Ippona', 'San Gregorio,San Gregorio d''Ippona', 38.6452800, 16.1035600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80130, 'San Gregorio di Catania', 'San Gregorio di Catania', 'San Gregorio,San Gregorio di Catania,San Grigoriu', 37.5676400, 15.1112000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80131, 'San Giuseppe Jato', 'San Giuseppe Jato', 'San Giuseppe Jato', 37.9733100, 13.1888900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80132, 'San Giovanni Suergiu', 'San Giovanni Suergiu', 'San Giovanni,San Giovanni Suergiu', 39.1095500, 8.5203900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80133, 'Samo', 'Samo', 'Samo,San Giovanni,San Giovanni Samo,samo,サーモ', 38.0739900, 16.0593300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80134, 'San Giovanni la Punta', 'San Giovanni la Punta', 'San Giovanni,San Giovanni la Punta,San Giuvanni la Punta', 37.5769000, 15.0937100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80135, 'San Giovanni in Fiore', 'San Giovanni in Fiore', 'San Giovanni in Fiore', 39.2544600, 16.6969900, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80136, 'San Giovanni Gemini', 'San Giovanni Gemini', 'San Giovanni Gemini,San Giuvanni', 37.6278500, 13.6435700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80137, 'San Giovanni di Gerace', 'San Giovanni di Gerace', 'Fanum Sancti Ioannis,San Dzhovani di Dzherache,San Giovanni di Gerace,San Giovanni di Jeraci,San-Dzhovanni-di-Dzherache,san jywfany dy jyratshy,sheng jiao wan ni di jie la qie,Сан Джовани ди Джераче,Сан-Джованни-ди-Джераче,Сан-Джованні-ді-Джераче,Սան Ջովաննի դի Ջերաչե,سان جيوفاني دي جيراتشي,サン・ジョヴァンニ・ディ・ジェラーチェ,圣焦万尼迪杰拉切', 38.3650800, 16.2777000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80138, 'San Giorgio Morgeto', 'San Giorgio Morgeto', 'San Giorgio,San Giorgio Morgeto,San Giórgio', 38.3919000, 16.0879000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80139, 'San Giorgio Albanese', 'San Giorgio Albanese', 'Mbuzati,San Giorgio,San Giorgio Albanese', 39.5823000, 16.4534900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80140, 'San Giorgio', 'San Giorgio', '', 38.1683400, 14.9482500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80141, 'Sangineto', 'Sangineto', 'Sangineto', 39.6055300, 15.9148100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80142, 'San Gavino Monreale', 'San Gavino Monreale', 'San Gavino Monreale', 39.5500800, 8.7906500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80143, 'San Fratello', 'San Fratello', 'Fratello,San Fratello', 38.0155600, 14.5981800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80144, 'San Floro', 'San Floro', 'San Flaro,San Floro', 38.8379900, 16.5187000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80145, 'San Filippo del Mela', 'San Filippo del Mela', '', 38.1700700, 15.2733800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80146, 'San Fili', 'San Fili', 'Fanum Sancti Felicis,San Fili,San-Fili,Santu Fili,sheng fei li,Сан Фили,Сан-Фили,Сан-Філі,Սան Ֆիլի,サン・フィーリ,圣菲利', 39.3397100, 16.1444800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80147, 'San Ferdinando', 'San Ferdinando', 'San Ferdinando', 38.4840300, 15.9187700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80148, 'San Donato di Ninea', 'San Donato di Ninea', 'San Donato,San Donato di Ninea', 39.7115600, 16.0474200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80149, 'San Demetrio Corone', 'San Demetrio Corone', 'San Demetrio Corone,Shen Mitri', 39.5699000, 16.3614900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80150, 'San Costantino Calabro', 'San Costantino Calabro', 'San Costantino,San Costantino Calabro', 38.6328300, 16.0757100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80151, 'San Cosmo Albanese', 'San Cosmo Albanese', 'San Cosmo,San Cosmo Albanese,Strighari', 39.5836300, 16.4146900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80152, 'San Cono', 'San Cono', 'San Cono,Santu Conu', 37.2899200, 14.3670900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80153, 'San Cipirello', 'San Cipirello', 'San Cipirello,San Ciupirreddu', 37.9606700, 13.1773200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80154, 'San Cataldo', 'San Cataldo', 'San Cataldo,San Cataldu', 37.4841200, 13.9854200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80155, 'San Carlo-Condofuri Marina', 'San Carlo-Condofuri Marina', '', 37.9332400, 15.8716600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80156, 'San Calogero', 'San Calogero', 'Fanum Sancti Calogeris,San Calogero,San Kalodzhero,San Kalojero,San-Kalodzhero,Santu Calojaru,Santu Calòjaru,sheng ka luo jie luo,Сан Калоджеро,Сан-Калоджеро,Սան Կալոջերո,サン・カロージェロ,圣卡洛杰罗', 38.5744700, 16.0193300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80157, 'San Biagio Platani', 'San Biagio Platani', 'San Biaggio,San Biaggiu Platini,San Biaggiu Plàtini,San Biagio,San Biagio Platani,San Biággio', 37.5092700, 13.5284400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80158, 'San Benedetto Ullano', 'San Benedetto Ullano', 'San Benedetto Ullano', 39.4271000, 16.1237900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80159, 'San Basilio', 'San Basilio', 'San Basilio', 39.5378500, 9.1975300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80160, 'San Basile', 'San Basile', 'San Basile', 39.8096000, 16.1632800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80161, 'Samugheo', 'Samugheo', 'Samugheo,Samugheu', 39.9485400, 8.9415200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80162, 'Sambuca di Sicilia', 'Sambuca di Sicilia', 'Sambuca,Sambuca Sicilia,Sambuca di Sicilia,Sammuca', 37.6529400, 13.1146200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80163, 'Samatzai', 'Samatzai', 'Samatzai', 39.4829700, 9.0346600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80164, 'Samassi', 'Samassi', 'Samassi', 39.4820800, 8.9053800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80165, 'Salve', 'Salve', 'Salve', 39.8611100, 18.2949300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80166, 'Saline Ioniche', 'Saline Ioniche', '', 37.9395700, 15.7194300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80167, 'Salemi', 'Salemi', 'Salemi', 37.8219900, 12.8050600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80168, 'Salaparuta', 'Salaparuta', 'Salaparuta', 37.7569400, 13.0098100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80169, 'Sadali', 'Sadali', '', 39.8145600, 9.2724600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80170, 'Ruinas', 'Ruinas', 'Ruinas', 39.9063100, 8.8970500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80171, 'Ruffano', 'Ruffano', 'Ruffano', 39.9819500, 18.2497400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80172, 'Rovito', 'Rovito', 'Rovito', 39.3063600, 16.3174600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80173, 'Rotonda', 'Rotonda', 'Rotonda', 39.9521500, 16.0390400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80174, 'Rota Greca', 'Rota Greca', 'Rota Greca', 39.4670300, 16.1141200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80175, 'Rossano Stazione', 'Rossano Stazione', '', 39.5985500, 16.6348500, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80176, 'Rossano', 'Rossano', 'Roscianum,Rossano,rossano,Россано,ロッサーノ', 39.5762200, 16.6344700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80177, 'Rosolini', 'Rosolini', 'Rosolini,Rusalini', 36.8214500, 14.9513200, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80178, 'Roseto Capo Spulico', 'Roseto Capo Spulico', 'Roseto,Roseto Capo Spulico,Rosito,Rosito Capo Spulico,Rosito Capo Spúlico', 39.9864300, 16.6036300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80179, 'Rose', 'Rose', 'Rose,roze,ローゼ', 39.3993200, 16.2944600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80180, 'Rosarno', 'Rosarno', 'Rosarno', 38.4871700, 15.9795600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80181, 'Rombiolo', 'Rombiolo', '', 38.5953500, 16.0023700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80182, 'Rogliano', 'Rogliano', 'Rogliano,roriano,ロリアーノ', 39.1784100, 16.3170900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80183, 'Roggiano Gravina', 'Roggiano Gravina', 'Roggiano Gravina,Rogiano Gravina', 39.6178600, 16.1617300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80184, 'Rodì', 'Rodi', '', 38.1082300, 15.1693300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80185, 'Roccella Valdemone', 'Roccella Valdemone', 'Roccella,Roccella Valdemone', 37.9328900, 15.0099700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80186, 'Roccella Ionica', 'Roccella Ionica', 'Roccella Ionica,Roccella Jonica,Rochchella-Ionika,Rochchella-Jonika,Rochela Jonika,Rucceja,Rupella,luo qie la yi ao ni ka,rwtshyla ywnyka,Рочела Йоника,Роччелла-Ионика,Роччелла-Йоника,Роччелла-Йоніка,Ռոչելլա Իոնիկա,روتشيلا يونيكا,ロッチェッラ・イオーニカ,罗切拉伊奥尼卡', 38.3211700, 16.3968900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80187, 'Roccavaldina', 'Roccavaldina', 'Roccavaldina', 38.1829600, 15.3740200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80188, 'Roccapalumba', 'Roccapalumba', 'Roccapalumba', 37.8082500, 13.6367100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80189, 'Roccamena', 'Roccamena', 'Roccamena', 37.8382400, 13.1551300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80190, 'Roccalumera', 'Roccalumera', 'Roccalumera', 37.9755400, 15.3943900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80191, 'Roccaforte del Greco', 'Roccaforte del Greco', 'Richudi,Roccaforte,Roccaforte del Greco', 38.0475100, 15.8919800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80192, 'Rocca di Neto', 'Rocca di Neto', 'Rocca di Neto', 39.1829200, 17.0076400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80193, 'Roccabernarda', 'Roccabernarda', 'Roccabernarda', 39.1327600, 16.8608200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80194, 'Rizziconi', 'Rizziconi', 'Riccikoni,Ridzikoni,Riziconum,Rizziconi,Rizzicuni,Rizztconi,li qi ke ni,rittsu~ikoni,ryzykwny,Ридзикони,Риццикони,Рицциконі,Ռիցիկոնի,ريزيكوني,リッツィーコニ,里齐科尼', 38.4099400, 15.9597400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80195, 'Riposto', 'Riposto', 'Riposto,Ripostu', 37.7318300, 15.2057600, 'IT', '2016-04-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80196, 'Riola Sardo', 'Riola Sardo', 'Riola,Riola Sardo', 39.9936100, 8.5412700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80197, 'Riesi', 'Riesi', 'Riesi', 37.2807900, 14.0831700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80198, 'Ricadi', 'Ricadi', '', 38.6251700, 15.8667400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80199, 'Ribera', 'Ribera', 'Ribera,Рибера', 37.4977300, 13.2667600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80200, 'Riace Marina', 'Riace Marina', '', 38.3918600, 16.5303300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80201, 'Resuttano', 'Resuttano', 'Resuttana,Resuttano', 37.6786500, 14.0294600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80202, 'Rende', 'Rende', 'Rende,Ренде', 39.3315400, 16.1804100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80203, 'Reitano', 'Reitano', 'Reitano', 37.9719800, 14.3441800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80204, 'Reggio Calabria', 'Reggio Calabria', 'REG,Redzho-di-Kalabrija,Reggio Calabria,Reggio de Calabre,Reggio de Calabria,Reggio de Calàbria,Reggio di Calabria,Regio,Regio de Calabria,Rhegium,Riggiu Calabbria,lei jiao ka la bu li ya,rg''w dy qlbryh,rydjw kalabrya,Реджо-ди-Калабрия,רג''ו די קלבריה,ريدجو كالابريا,レッジョ・ディ・カラブリア,雷焦卡拉布里亚', 38.1104700, 15.6612900, 'IT', '2014-06-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80205, 'Regalbuto', 'Regalbuto', 'Recalbutu,Regalbulo,Regalbuto', 37.6519500, 14.6391500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80206, 'Realmonte', 'Realmonte', 'Realmonte,Rialmunti', 37.3084700, 13.4642900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80207, 'Ravanusa', 'Ravanusa', 'Ravanusa,Rivinusa', 37.2665900, 13.9683400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80208, 'Randazzo', 'Randazzo', 'Randazzo,Rannazzu', 37.8773600, 14.9501200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80209, 'Ramacca', 'Ramacca', 'Ramacca,Rammacca', 37.3861600, 14.6924100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80210, 'Ragusa', 'Ragusa', 'QRG,Ragusa,Raguse,Raguza,Rausa,raguza,rgwzh,Рагуза,רגוזה,ラグーザ', 36.9257400, 14.7244300, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80211, 'Raffadali', 'Raffadali', 'Rafadali,Raffadali', 37.4021400, 13.5317500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80212, 'Raddusa', 'Raddusa', 'Buddusa,Rabdusa,Raddusa,Radduza,Raduza,la du sa,raddo~uza,radwsa,Раддуза,Радуза,Ռադուզա,رادوسا,ラッドゥーザ,拉杜萨', 37.4752900, 14.5352100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80213, 'Raccuja', 'Raccuja', 'Raccuja', 38.0558300, 14.9104400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80214, 'Racalmuto', 'Racalmuto', 'Racalmuto,Ragalmutu,Recalmutu', 37.4049800, 13.7299500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80215, 'Racale', 'Racale', 'Racale', 39.9608600, 18.0915400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80216, 'Quattromiglia', 'Quattromiglia', '', 39.3447400, 16.2380200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80217, 'Quartu Sant''Elena', 'Quartu Sant''Elena', 'Cuartu Santa Aleni,Cuartu Santa Alèni,Quarto Sant''Elena,Quartu Sant''Elena', 39.2293500, 9.2500400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80218, 'Quartucciu', 'Quartucciu', 'Quartuccio,Quartucciu', 39.2526200, 9.1776400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80219, 'Pula', 'Pula', 'Pauli Norae,Pula,pu luo,pulla,pura,pwla  sardynya,Пула,Պուլա,پولا، ساردینیا,プーラ,普洛,풀라', 39.0072700, 9.0022300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80220, 'Prizzi', 'Prizzi', 'Prizzi', 37.7208800, 13.4343500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80221, 'Priolo Gargallo', 'Priolo Gargallo', 'Priolo,Priolo Gargallo,Priolu', 37.1551200, 15.1824800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80222, 'Presicce', 'Presicce', 'Presicce', 39.9005500, 18.2628200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80223, 'Praia a Mare', 'Praia a Mare', 'Praia a Mare,Praia d''Aieta,Praja-a-Mare,Прая-а-Маре', 39.8941000, 15.7842100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80224, 'Pozzallo', 'Pozzallo', 'Pozzallo,Puzzaddu,pottsu~arro,ポッツァッロ', 36.7302800, 14.8467200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80225, 'Portoscuso', 'Portoscuso', 'Portoscuso', 39.2073900, 8.3808600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80226, 'Portopalo di Capo Passero', 'Portopalo di Capo Passero', 'Terra Nobile', 36.6821900, 15.1337800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80227, 'Porto Empedocle', 'Porto Empedocle', 'Porto Empedocle,Portu Empedocli', 37.2894200, 13.5249400, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80228, 'Portigliola', 'Portigliola', 'Pertigliola,Portigliola', 38.2271200, 16.2028700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80229, 'Portella di Mare', 'Portella di Mare', '', 38.0730400, 13.4619900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80230, 'Pompu', 'Pompu', 'Pompu,ponpu,ポンプ', 39.7251800, 8.7964000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80231, 'Pollina', 'Pollina', 'Poilina,Pollina,Puoddina,Puòddina', 37.9930900, 14.1458600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80232, 'Polizzi Generosa', 'Polizzi Generosa', '', 37.8115900, 14.0026800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80233, 'Polistena', 'Polistena', 'Polistena', 38.4054400, 16.0733000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80234, 'Polia', 'Polia', 'Polia,Polija,Pulia,poria,Полия,Полія,Պոլիա,ポリーア', 38.7511800, 16.3122000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80235, 'Nuovo Centro Urbano Poggioreale', 'Nuovo Centro Urbano Poggioreale', 'Poggioreale', 37.7640400, 13.0359400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80236, 'Platì', 'Plati', 'Plati,Platì', 38.2214900, 16.0453000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80237, 'Platania', 'Platania', '', 39.0062000, 16.3219400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80238, 'Plataci', 'Plataci', 'Plataci,Platici,Pllatani', 39.9004200, 16.4327200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80239, 'Placanica', 'Placanica', 'Placanica', 38.4107800, 16.4527400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80240, 'Pizzoni', 'Pizzoni', 'Pizzoni', 38.6228600, 16.2487600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80241, 'Pizzo', 'Pizzo', 'Picco,Pico,Pitium,Pizzo,U Pizzu,bytsw,pittsu~o,Пицо,Пиццо,Піццо,Պիցո,بيتسو,ピッツォ', 38.7525900, 16.1869600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80242, 'Piscopio', 'Piscopio', '', 38.6636100, 16.1110100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80243, 'Piscinas', 'Piscinas', 'Piscinas', 39.0743500, 8.6663400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80244, 'Piraino', 'Piraino', 'Piraino,Pirainu', 38.1612700, 14.8610000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80245, 'Pioppo', 'Pioppo', '', 38.0500000, 13.2333300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80246, 'Pimentel', 'Pimentel', 'Pimentel', 39.4871800, 9.0651600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80247, 'Pietraperzia', 'Pietraperzia', 'Petrapirzia,Pietraperzia', 37.4185200, 14.1373900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80248, 'Pietrapaola', 'Pietrapaola', 'Pietrapaola', 39.4870100, 16.8159700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80249, 'Pietrafitta', 'Pietrafitta', 'Pietrafitta', 39.2610300, 16.3394000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80250, 'Piedimonte Etneo', 'Piedimonte Etneo', 'Piedimonte,Piedimonte Etnea,Piedimonte Etneo,Piemunti', 37.8067700, 15.1751600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80251, 'Piazza Armerina', 'Piazza Armerina', 'Ciazza,Cjassa,Piazza Armerina', 37.3841700, 14.3692100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80252, 'Pianopoli', 'Pianopoli', 'Pianopoli', 38.9524600, 16.3886300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80253, 'Piane Crati', 'Piane Crati', 'Piane,Piane Crati', 39.2347200, 16.3231300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80254, 'Piana degli Albanesi', 'Piana degli Albanesi', 'Chiana,Hora e Arbereshevet,Piana de'' Greci,Piana degli Albanesi,Piana dei Greci,Piana di Greci', 37.9937200, 13.2846400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80255, 'Pettineo', 'Pettineo', 'Pettineo', 37.9679300, 14.2911800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80256, 'Petrosino', 'Petrosino', 'Petrosino,Pitrusinu', 37.7127100, 12.4996400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80257, 'Petronà', 'Petrona', 'Petrona,Petronà', 39.0437000, 16.7579600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80258, 'Petrizzi', 'Petrizzi', 'Petrizzi', 38.7017900, 16.4718700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80259, 'Petralia Sottana', 'Petralia Sottana', 'Petralia Sottana,Pitralia Suttana,Pitralìa Suttana,Sottana Petralia', 37.8091900, 14.0929300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80260, 'Petralia Soprana', 'Petralia Soprana', 'Petralia Soprana,Pitralia Suprana,Pitralìa Suprana', 37.8006400, 14.1081300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80261, 'Petilia Policastro', 'Petilia Policastro', 'Petilia Policastro', 39.1129300, 16.7816700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80262, 'Pernocari-Presinaci', 'Pernocari-Presinaci', '', 38.6118400, 16.0046300, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80263, 'Perdaxius', 'Perdaxius', 'Perdaxius', 39.1602800, 8.6108300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80264, 'Perdasdefogu', 'Perdasdefogu', 'Foghesu,Perdasdefogu,Perdazdefogu,Petrae Igneae,pei er da si de fu gu,perudazudefogu,Пердаздефогу,Пердасдефогу,Պերդասդեֆոգու,ペルダズデフォーグ,佩尔达斯德福古', 39.6795900, 9.4408200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80265, 'Pentone', 'Pentone', 'Pentone', 38.9857900, 16.5825000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80266, 'Pedivigliano', 'Pedivigliano', 'Pedivigliano', 39.1103400, 16.3048600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80267, 'Pedara', 'Pedara', 'Pedara,Pidara', 37.6238600, 15.0567200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80268, 'Pedagaggi', 'Pedagaggi', '', 37.1918200, 14.9365400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80269, 'Pedace-Perito', 'Pedace-Perito', 'Pedace', 39.2763900, 16.3363900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80270, 'Pazzano', 'Pazzano', 'Pazzano', 38.4761200, 16.4510700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80271, 'Pavigliana', 'Pavigliana', '', 38.1072100, 15.7210800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80272, 'Pauli Arbarei', 'Pauli Arbarei', 'Pauli Arbarei', 39.6618300, 8.9221200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80273, 'Pau', 'Pau', 'Pau', 39.7916700, 8.8022200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80274, 'Patù', 'Patu', 'Patu,Patù', 39.8407800, 18.3378400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80275, 'Patti', 'Patti', 'Patti', 38.1473600, 14.9640900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80276, 'Paterno Calabro', 'Paterno Calabro', 'Paterno,Paterno Calabro', 39.2284900, 16.2648900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80277, 'Paternò', 'Paterno', 'Paterno,Paternò,Patirno,Patirnò,pateruno,Патерно,パテルノー', 37.5667500, 14.9025400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80278, 'Partinico', 'Partinico', '', 38.0465700, 13.1178500, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80279, 'Partanna', 'Partanna', 'Partanna', 37.7268000, 12.8891700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80280, 'Parghelia', 'Parghelia', 'Parghelia', 38.6818900, 15.9207500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80281, 'Parenti', 'Parenti', 'Parenti,Parietes,pa lun di,parenti,Паренти,Паренті,Պարենտի,パレンティ,帕伦蒂', 39.1607100, 16.4114000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80282, 'Paravati', 'Paravati', '', 38.5902000, 16.0581500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80283, 'Papasidero', 'Papasidero', 'Papasidero,Papasideru,Papasiderum,Papazidero,pa pa xi de luo,papajidero,Папазидеро,Папазідеро,Папасидеро,Պապասիդերո,パパジーデロ,帕帕西德罗', 39.8715900, 15.9058100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80284, 'Papanice', 'Papanice', '', 39.0707700, 17.0272100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80285, 'Paola', 'Paola', 'Paola,Paula,Pàula,bao la,paolla,paora,paywla  kalabrya,Паола,Պաոլա,پائولا، کالابریا,パオラ,保拉,파올라', 39.3631300, 16.0369100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80286, 'Pantelleria', 'Pantelleria', 'PNL,Pantelaria,Pantelleria,Pantel·leria,Pantelária,Pantilliria,Pantillirìa,panterreria,pntlryh,פנטלריה,パンテッレリーア', 36.8283600, 11.9461100, 'IT', '2016-03-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80287, 'Pannaconi', 'Pannaconi', '', 38.6929100, 16.0441100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80288, 'Panettieri', 'Panettieri', 'Panettieri', 39.0600700, 16.4537500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80289, 'Paludi', 'Paludi', 'Paludi', 39.5294300, 16.6796300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80290, 'Palmi', 'Palmi', 'Palmi,parumi,パルミ', 38.3594300, 15.8515500, 'IT', '2015-07-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80291, 'Palmas Arborea', 'Palmas Arborea', 'Palmas Arborea', 39.8767000, 8.6439100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80292, 'Palma di Montechiaro', 'Palma di Montechiaro', 'Palma di Montechiaro,Parma di Muntichiaru', 37.1906600, 13.7660300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80293, 'Pallagorio', 'Pallagorio', 'Pallagorio,Puheriu', 39.3076400, 16.9081600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80294, 'Palizzi Marina', 'Palizzi Marina', 'Marina di Palizzi,Palizzi Marina', 37.9199500, 15.9792700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80295, 'Palizzi', 'Palizzi', 'Palizzi,Palizzi Superiore', 37.9666700, 15.9867000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80296, 'Palermo', 'Palermo', 'PMO,Palerm,Palerma,Palermas,Palerme,Palermo,Palermu,Panormus,Pałermo,ba lei mo shi,balyrmw,palermo,palleleumo,palrmw,parerumo,plrmw,Палерма,Палермо,פלרמו,باليرمو,پالرمو,पलेर्मो,パレルモ,巴勒莫市,팔레르모', 38.1320500, 13.3356100, 'IT', '2017-06-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80297, 'Palermiti', 'Palermiti', 'Palermiti', 38.7486800, 16.4522000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80298, 'Palazzolo Acreide', 'Palazzolo Acreide', 'Palazzolo Acreide,Palazzolo Acréide,Palazzolu Acreidi,パラッツォーロ・アクレイデ', 37.0626100, 14.9059300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80299, 'Palazzo Adriano', 'Palazzo Adriano', 'Chiusa Palazzo,Palazzo Adriano,Palazzu Adrianu,Pallaci,パラッツォ・アドリアーノ', 37.6806600, 13.3794100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80300, 'Palagonia', 'Palagonia', 'Palagonia,Palagunia', 37.3295500, 14.7447400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80301, 'Pagliarelle', 'Pagliarelle', '', 39.1401700, 16.7510100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80302, 'Pagliara', 'Pagliara', 'Pagliara', 37.9854600, 15.3596900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80303, 'Pachino', 'Pachino', 'Pachino,Pachinu,Pakino,Пакино', 36.7152200, 15.0901900, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80304, 'Paceco', 'Paceco', 'Paceco', 37.9802600, 12.5576600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80305, 'Pabillonis', 'Pabillonis', 'Pabillonis', 39.5922800, 8.7214300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80306, 'Osini', 'Osini', 'Osini', 39.8225700, 9.4964000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80307, 'Ortacesus', 'Ortacesus', 'Ortacesus', 39.5390400, 9.0869500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80308, 'Orsomarso', 'Orsomarso', 'Orsomarso', 39.7991000, 15.9074800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80309, 'Orroli', 'Orroli', 'Orroli', 39.6923700, 9.2499500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80310, 'Oristano', 'Oristano', 'Aristanis,FNU,Oristano,Oristanum,Oristany,orisutano,Ористано,オリスターノ', 39.9036000, 8.5925700, 'IT', '2016-12-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80311, 'Albagiara', 'Albagiara', 'Albagiara,Ollastra Usellus', 39.7872400, 8.8618400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80312, 'Oliveri', 'Oliveri', 'Oliveri', 38.1251500, 15.0606800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80313, 'Olivadi', 'Olivadi', 'Olivadi', 38.7255800, 16.4237000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80314, 'Nuxis', 'Nuxis', 'Nuxis', 39.1545600, 8.7395300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80315, 'Nurri', 'Nurri', 'Nurri', 39.7112200, 9.2299000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80316, 'Nureci', 'Nureci', 'Nureci', 39.8232900, 8.9748400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80317, 'Nuraxinieddu', 'Nuraxinieddu', 'Nuraxinieddu,Nuraxinteddu', 39.9384300, 8.5991000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80318, 'Nuraminis', 'Nuraminis', 'Nuraminis', 39.4425800, 9.0139500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80319, 'Nurallao', 'Nurallao', 'Nurallao', 39.7890800, 9.0780200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80320, 'Nuragus', 'Nuragus', 'Nuragus', 39.7777100, 9.0372400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80321, 'Nurachi', 'Nurachi', 'Nurachi,Nuragis,Nuraki,nu la ji,nuraki,Нураки,Нуракі,Նուրակի,ヌラーキ,努拉基', 39.9745100, 8.5396500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80322, 'Nunziata', 'Nunziata', 'Annunziata,Nunziata', 37.7585800, 15.1705800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80323, 'Novara di Sicilia', 'Novara di Sicilia', 'Noara,Novara Sicilia,Novara di Sichilija,Novara di Sicilia,Novara-di-Sicilija,Nuvara,nuo wa la di xi qi li ya,nwfara dy syshylya,Новара ди Сичилия,Новара-ди-Сицилия,Новара-ді-Сицилія,Նովարա դի Սիցիլիա,نوفارا دي سيشيليا,ノヴァーラ・ディ・シチーリア,诺瓦拉迪西奇利亚', 38.0153800, 15.1313400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80324, 'Noto', 'Noto', 'Netum,Noto,Nuotu,noto,Ното,ノート', 36.8924400, 15.0697700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80325, 'Nocera Terinese', 'Nocera Terinese', 'Nocera Terinese,Nocera Tirinese', 39.0347400, 16.1673700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80326, 'Nizza di Sicilia', 'Nizza di Sicilia', 'Nizza di Sicilia', 37.9908100, 15.4095600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80327, 'Nissoria', 'Nissoria', 'Nissoria,Nissoria Sicilia,Nissuria', 37.6541000, 14.4481000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80328, 'Niscemi', 'Niscemi', 'Niscemi,Nishemi,Нишеми', 37.1464900, 14.3938100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80329, 'Nicotera', 'Nicotera', 'Marina di Nicotera', 38.5491500, 15.9358400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80330, 'Nicosia', 'Nicosia', 'Nicosia,Nicosia Sicilia,Nicusia', 37.7474700, 14.3921800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80331, 'Nicolosi', 'Nicolosi', 'Nicolosi,Niculosi,Nikolozi,Николози', 37.6214800, 15.0278500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80332, 'Nicastro-Sambiase', 'Nicastro-Sambiase', 'Nicastro,Nikastro,Никастро', 38.9708900, 16.3128500, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80333, 'Naso', 'Naso', 'Naso', 38.1221500, 14.7870200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80334, 'Naro', 'Naro', 'Naro,Naru', 37.2924800, 13.7933700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80335, 'Nardodipace', 'Nardodipace', 'Nardo,Nardodipace', 38.4741800, 16.3429500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80336, 'Narcao', 'Narcao', 'Narcao', 39.1675000, 8.6750000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80337, 'Mussomeli', 'Mussomeli', 'Mussomeli,Mussumeli', 37.5806700, 13.7521400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80338, 'Musei', 'Musei', 'Musei,Museis,Muzei,Muzej,mu sai yi,muzei,mwsy,Музеи,Музей,Музеі,Музеї,Մուզեի,موسی,ムゼーイ,穆塞伊', 39.3023200, 8.6661300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80339, 'Muravera', 'Muravera', 'Muravera', 39.4197200, 9.5747100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80340, 'Motta Sant''Anastasia', 'Motta Sant''Anastasia', 'Motta Sant''Anastasia', 37.5120500, 14.9662800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80341, 'Motta Santa Lucia', 'Motta Santa Lucia', 'Motta,Motta Santa Lucia', 39.0912200, 16.2931300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80342, 'Motta San Giovanni', 'Motta San Giovanni', 'Motta,Motta San Giovanni', 38.0102700, 15.7126200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80343, 'Mottafollone', 'Mottafollone', 'Mottafollone', 39.6485000, 16.0645100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80344, 'Mosorrofa', 'Mosorrofa', '', 38.0950000, 15.7125900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80345, 'Mormanno', 'Mormanno', 'Mormanno', 39.8934000, 15.9917500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80346, 'Morgongiori', 'Morgongiori', 'Morgongiori', 39.7463000, 8.7704100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80347, 'Morciano di Leuca', 'Morciano di Leuca', 'Morciano,Morciano di Leuca', 39.8471900, 18.3108900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80348, 'Morano Calabro', 'Morano Calabro', 'Morano Calabro', 39.8413800, 16.1383700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80349, 'Montevago', 'Montevago', 'Montevago,Muntivagu', 37.7022400, 12.9858400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80350, 'Montesardo', 'Montesardo', '', 39.8757200, 18.3396700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80351, 'Montesano Salentino', 'Montesano Salentino', 'Montesano,Montesano Salentino', 39.9754400, 18.3227700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80352, 'Monterosso Almo', 'Monterosso Almo', 'Monterosso Almo,Muntirrussu,Muntirussu,モンテロッソ・アルモ', 37.0888400, 14.7649800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80353, 'Monterosso Calabro', 'Monterosso Calabro', '', 38.7174600, 16.2906600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80354, 'Montepaone', 'Montepaone', 'Montepaone', 38.7222200, 16.4979500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80355, 'Montemaggiore Belsito', 'Montemaggiore Belsito', '', 37.8481800, 13.7620600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80356, 'Montelepre', 'Montelepre', 'Montelepre,Muncilebbri,Muntilepri', 38.0902600, 13.1751800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80357, 'Montedoro', 'Montedoro', 'Montedoro,Muntidoru', 37.4543100, 13.8168400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80358, 'Montebello Ionico', 'Montebello Ionico', 'Montebello,Montebello Ionico,Montebello Jonico,モンテベッロ・イオーニコ', 37.9827700, 15.7580000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80359, 'Montauro', 'Montauro', 'Montauro', 38.7492700, 16.5122600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80360, 'Montalto Uffugo', 'Montalto Uffugo', 'Montalto Uffugo', 39.4033100, 16.1553400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80361, 'Montallegro', 'Montallegro', 'Montallegro,Muntallegru', 37.3912100, 13.3517900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80362, 'Montalbano Elicona', 'Montalbano Elicona', 'Montalbano Elicona,Montalbano d''Elicona,Muntarbanu', 38.0236000, 15.0139300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80363, 'Montagnareale', 'Montagnareale', 'Montagnareale,Muntagnariali', 38.1321600, 14.9465800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80364, 'Monserrato', 'Monserrato', 'Monserrato,Monserratu', 39.2564200, 9.1444000, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80365, 'Monreale', 'Monreale', 'Monreal'',Monreale,Murriali,monreare,Монреаль,モンレアーレ', 38.0812500, 13.2894700, 'IT', '2015-08-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80366, 'Mongrassano', 'Mongrassano', 'Mongrassano,Mungrasana', 39.5264400, 16.1122500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80367, 'Mongiuffi Melia', 'Mongiuffi Melia', 'Mongiuffi Melia,Monguiffi,Mungiuffi', 37.9033600, 15.2753900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80368, 'Mongiana', 'Mongiana', 'Mongiana', 38.5147700, 16.3194000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80369, 'Monforte San Giorgio', 'Monforte San Giorgio', 'Monforte,Monforte San Giorgio', 38.1573300, 15.3813200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80370, 'Monastir', 'Monastir', 'Monasteri Sardenias,Monastir,Μοναστήρι Σαρδηνίας', 39.3836000, 9.0444500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80371, 'Monasterace', 'Monasterace', 'Monasterace', 38.4531800, 16.5516300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80372, 'Molochio', 'Molochio', 'Molochio', 38.3078900, 16.0314100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80373, 'Moio Alcantara', 'Moio Alcantara', 'Moio,Moio Alcantara,Mojo Alcantara,Moju d''Alcantara', 37.9005600, 15.0507200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80374, 'Mogoro', 'Mogoro', 'Mogoro', 39.6841500, 8.7766100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80375, 'Mogorella', 'Mogorella', 'Mogorella', 39.8644700, 8.8591300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80376, 'Modica', 'Modica', 'Modica,Modika,Muorica,Muòrica,Módica,modika,Модика,モーディカ', 36.8586800, 14.7596600, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80377, 'Mistretta', 'Mistretta', 'Mistretta,Mistritta', 37.9282300, 14.3578000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80378, 'Misterbianco', 'Misterbianco', 'Misterbianco,Mistirjancu', 37.5180300, 15.0091300, 'IT', '2015-08-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80379, 'Misilmeri', 'Misilmeri', 'Misilmeri', 38.0318300, 13.4479500, 'IT', '2015-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80380, 'Mirto', 'Mirto', '', 39.6006900, 16.7739000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80381, 'Mirto', 'Mirto', 'Mirto,Mirtu', 38.0843900, 14.7460900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80382, 'Mirabella Imbaccari', 'Mirabella Imbaccari', 'Mirabedda Mbaccari,Mirabella Imbaccari', 37.3270200, 14.4460500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80383, 'Mineo', 'Mineo', 'Mineo,Miniu', 37.2649400, 14.6938100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80384, 'Milo', 'Milo', 'Milo,Milu', 37.7245000, 15.1155400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80385, 'Militello Rosmarino', 'Militello Rosmarino', 'Militello,Militello Rosmarino,Militello di Rosmarino,Militieddu', 38.0457500, 14.6758400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80386, 'Militello in Val di Catania', 'Militello in Val di Catania', 'Militeddu in Val di Catania,Militello in Val di Catania,ミリテッロ・イン・ヴァル・ディ・カターニア', 37.2759400, 14.7934200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80387, 'Mileto', 'Mileto', 'Mileto', 38.6078000, 16.0675100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80388, 'Milena', 'Milena', 'Milena,Milocca', 37.4713300, 13.7361300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80389, 'Milazzo', 'Milazzo', 'Milacco,Milazzo,Milazzu,Mylae,mirattsu~o,Милаццо,מילאי,ミラッツォ', 38.2200800, 15.2402300, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80390, 'Miglierina', 'Miglierina', 'Migliaro,Miglierina,Migtierina', 38.9506000, 16.4723300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80391, 'Miggiano', 'Miggiano', 'Miggiano', 39.9618000, 18.3111900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80392, 'Mezzojuso', 'Mezzojuso', 'Mezzoiuso,Mezzojuso,Munxifsi', 37.8650900, 13.4650900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80393, 'Messina', 'Messina', 'Mesina,Messana,Messina,Messine,Mesyna,Missina,QME,mesina,messhina,mo xi na,msynh,mysyna,Месина,Мессина,מסינה,ميسينا,メッシーナ,墨西拿,메시나', 38.1939400, 15.5525600, 'IT', '2017-06-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80394, 'Messignadi', 'Messignadi', 'Mesignadi,Messignadi', 38.2996400, 15.9964200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80395, 'Mesoraca', 'Mesoraca', 'Mesoraca,Mesuraca', 39.0794800, 16.7880800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80396, 'Merì', 'Meri', 'Meri,Merì', 38.1663000, 15.2497000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80397, 'Menfi', 'Menfi', 'Menfi,Менфи', 37.6040900, 12.9688900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80398, 'Mendicino', 'Mendicino', 'Mendicino', 39.2628200, 16.1945200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80399, 'Melito di Porto Salvo', 'Melito di Porto Salvo', 'Melito,Melito Porto Salvo,Melito di Porto Salvo,Mélito,メーリト・ディ・ポルト・サルヴォ', 37.9262900, 15.7499000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80400, 'Melissano', 'Melissano', 'Melissano', 39.9731500, 18.1211300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80401, 'Melissa', 'Melissa', 'Melissa,merissa,メリッサ', 39.3095300, 17.0296800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80402, 'Melilli', 'Melilli', 'Melilli,Mellili,Miliddi', 37.1782100, 15.1302000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80403, 'Melicucco', 'Melicucco', 'Melicucco', 38.4329800, 16.0574800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80404, 'Melicuccà', 'Melicucca', 'Melicucca,Melicuccà', 38.3031100, 15.8815300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80405, 'Meana Sardo', 'Meana Sardo', 'Meana Sardo', 39.9446700, 9.0735500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80406, 'Mazzarrà Sant''Andrea', 'Mazzarra Sant''Andrea', 'Mazzarra,Mazzarra Sant''Andrea,Mazzarrà,Mazzarrà Sant''Andrea', 38.0896900, 15.1353500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80407, 'Mazzarino', 'Mazzarino', 'Macarino,Maccarino,Madzarino,Majarino,Mazarinus,Mazzarino,Mazzarinu,ma zha li nuo,madzarino,matsarynw,mattsu~arino,Мадзарино,Мацарино,Маццарино,Մաձարինո,ماتسارينو,მაძარინო,マッツァリーノ,马扎里诺', 37.3018800, 14.2095900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80408, 'Mazara del Vallo', 'Mazara del Vallo', 'Mazara del Vallo,Mazzara', 37.6553500, 12.5898600, 'IT', '2016-11-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80409, 'Maracalagonis', 'Maracalagonis', 'Maracalagonis,Matacalagonis', 39.2857400, 9.2287400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80410, 'Masullas', 'Masullas', 'Masullas', 39.7004400, 8.7837100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80411, 'Mascalucia', 'Mascalucia', 'Mascalucia,Maskalucha,Маскалуча', 37.5746500, 15.0496400, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80412, 'Mascali', 'Mascali', 'Mascali,Màscali', 37.7579400, 15.1966200, 'IT', '2017-06-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80413, 'Masainas', 'Masainas', 'Masainas', 39.0499300, 8.6292400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80414, 'Marzi', 'Marzi', 'Marzi', 39.1706300, 16.3070500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80415, 'Martone', 'Martone', 'Martone', 38.3535300, 16.2880000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80416, 'Martirano Lombardo', 'Martirano Lombardo', 'Martirano Lombardo', 39.0746900, 16.2320000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80417, 'Martirano', 'Martirano', 'Martirano', 39.0811900, 16.2482900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80418, 'Marsala', 'Marsala', 'Marsala,QMR,marusara,Марсала,マルサーラ', 37.7992000, 12.4367000, 'IT', '2015-09-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80419, 'Marrubiu', 'Marrubiu', 'Marrubiu', 39.7512400, 8.6376600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80420, 'Marittima', 'Marittima', 'Marittima', 39.9960900, 18.3989500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80421, 'Marineo', 'Marineo', 'Marineo', 37.9518500, 13.4178100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80422, 'Marinella', 'Marinella', 'Marinella Selinunte', 37.5947500, 12.8443400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80423, 'Marina di Schiavonea', 'Marina di Schiavonea', 'Marina Schiavonia,Schiavonea,Schiavonia,Schiavunea', 39.6500000, 16.5333300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80424, 'Marina di Ragusa', 'Marina di Ragusa', 'Marina di Ragusa,Marina-di-Raguza,Mazzareddi,Марина-ди-Рагуза', 36.7857500, 14.5547400, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80425, 'Monasterace Marina', 'Monasterace Marina', 'Marina Monasterace,Marina di Monasterace,Monasterace Marina', 38.4348900, 16.5702500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80426, 'Marina di Gioiosa Ionica', 'Marina di Gioiosa Ionica', 'Gioiosa Marina,Marina di Gioiosa,Marina di Gioiosa Ionica,Marina di Gioiosa Jonica', 38.3015900, 16.3314800, 'IT', '2015-07-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80427, 'Marina di Fuscaldo', 'Marina di Fuscaldo', '', 39.4241800, 16.0069400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80428, 'Marina di Camerota', 'Marina di Camerota', 'Marina di Camerota,Marina e Cammarota', 40.0035600, 15.3671700, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80429, 'Marianopoli', 'Marianopoli', 'Marianopoli,Paisi di li Manchi', 37.5984000, 13.9152000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80430, 'Marcellinara', 'Marcellinara', 'Marcellinara', 38.9257400, 16.4875700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80431, 'Marcedusa', 'Marcedusa', 'Marcedusa', 39.0267500, 16.8361200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80432, 'Marausa', 'Marausa', '', 37.9416600, 12.5094800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80433, 'Maratea', 'Maratea', 'Maratea', 39.9993200, 15.7153900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80434, 'Marano Principato', 'Marano Principato', 'Marano Principato', 39.2978200, 16.1743000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80435, 'Marano Marchesato', 'Marano Marchesato', 'Marano,Marano Marchesato', 39.3127400, 16.1735400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80436, 'Mangone', 'Mangone', 'Mangone', 39.2043700, 16.3326200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80437, 'Mandatoriccio', 'Mandatoriccio', 'Mandatoriccio', 39.4667500, 16.8342000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80438, 'Mandas', 'Mandas', 'Mandas', 39.6551400, 9.1295500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80439, 'Mandanici', 'Mandanici', 'Mandanice,Mandanichi,Mandanichy,Mandanici,Mandonicis,Mannanici,man da ni qi,mandanichi,mandanytshy,Манданичи,Манданічы,Манданічі,Մանդանիչի,ماندانيتشي,マンダニーチ,曼达尼奇', 38.0035600, 15.3166900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80440, 'Mammola', 'Mammola', 'Mammola', 38.3626200, 16.2387100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80441, 'Malvito', 'Malvito', 'Malvito', 39.6010500, 16.0534100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80442, 'Malvagna', 'Malvagna', 'Lanza,Malvagna,Marvagna', 37.9175200, 15.0554800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80443, 'Malito', 'Malito', 'Malito', 39.1577500, 16.2467700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80444, 'Malfa', 'Malfa', 'Malfa,marufa,マルファ', 38.5773000, 14.8359800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80445, 'Maletto', 'Maletto', 'Maletto,Malettu', 37.8291400, 14.8640300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80446, 'Maierato', 'Maierato', 'Maerato,Maierato,Maieratum,Majerato,Majeratu,ma yi ai la tuo,maierato,Майерато,Маєрато,Մաիերատո,マイエラート,马伊埃拉托', 38.7111100, 16.1753200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80447, 'Maierà', 'Maiera', 'Maiera,Maierà', 39.7165500, 15.8501200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80448, 'Maida', 'Maida', '', 38.8588400, 16.3627700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80449, 'Magisano', 'Magisano', 'Magisano', 39.0133900, 16.6279000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80450, 'Luzzi', 'Luzzi', 'Luzzi', 39.4479900, 16.2873000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80451, 'Lungro', 'Lungro', 'Lungro,Ungra', 39.7377200, 16.1258600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80452, 'Lunamatrona', 'Lunamatrona', 'Lunamatrona', 39.6494300, 8.8996600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80453, 'Lucugnano', 'Lucugnano', '', 39.9349000, 18.3217400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80454, 'Lucca Sicula', 'Lucca Sicula', 'Lucca Sicula,Lucca Sìcula', 37.5778300, 13.3057900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80455, 'Lotzorai', 'Lotzorai', 'Lotzorai', 39.9694000, 9.6635000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80456, 'Longobucco', 'Longobucco', 'Longobucco', 39.4483000, 16.6105000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80457, 'Longobardi', 'Longobardi', '', 39.2105900, 16.0746400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80458, 'Longi', 'Longi', 'Lonci,Londzhi,Longi,Longis,Lonji,long ji,lwnghy,ronji,Лонджи,Лонджі,Լոնջի,لونغي,ロンジ,隆吉', 38.0261700, 14.7530600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80459, 'Locri', 'Locri', 'Epizefyrioi Lokroi,Gerace Marina,Locres Epizefiris,Locri,Locros,Lokri,lokeuli,luo ke li,lwkry,lwqry,rokuri,Επιζεφύριοι Λοκροί,Локри,Локрі,Լոկրի,לוקרי,لوكري,لوکری,ロクリ,洛克里,로크리', 38.2386800, 16.2595700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80460, 'Loceri', 'Loceri', 'Loceri', 39.8581600, 9.5836800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80461, 'Lipari', 'Lipari', '', 38.4674300, 14.9539800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80462, 'Linguaglossa', 'Linguaglossa', 'Linguaglossa,Linguarossa', 37.8424300, 15.1377400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80463, 'Linera', 'Linera', '', 37.6638000, 15.1365300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80464, 'Limbadi-Caroni', 'Limbadi-Caroni', 'Limbadi', 38.5590200, 15.9644100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80465, 'Licodia Eubea', 'Licodia Eubea', 'Licodia Eubea,Licuddia', 37.1567400, 14.7055500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80466, 'Licata', 'Licata', 'Licata', 37.1026700, 13.9397200, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80467, 'Librizzi', 'Librizzi', 'Librizzi', 38.0971900, 14.9590900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80468, 'Leuca', 'Leuca', 'Cascine di Leuca,Leuca,Levike', 39.7994900, 18.3581500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80469, 'Letojanni', 'Letojanni', 'Letoianni,Letojanni', 37.8805000, 15.3073500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80470, 'Lercara Friddi', 'Lercara Friddi', 'Lercara,Lercara Friddi', 37.7465700, 13.6039100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80471, 'Leonforte', 'Leonforte', 'Leonforte,Liunforti', 37.6419700, 14.3976600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80472, 'Lentini', 'Lentini', 'Lentini,Leontini,Lintini,lntyny,rentini,Лентини,לנטיני,レンティーニ', 37.2855600, 14.9973700, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80473, 'Leni', 'Leni', 'Leni,reni,レーニ', 38.5553400, 14.8249700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80474, 'Le Castella', 'Le Castella', 'Castella', 38.9101000, 17.0221600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80475, 'Lazzaro', 'Lazzaro', '', 37.9727600, 15.6651100, 'IT', '2017-02-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80476, 'Laurignano', 'Laurignano', '', 39.2791500, 16.2423200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80477, 'Laureana di Borrello', 'Laureana di Borrello', 'Laureana di Borello,Laureana di Borrello', 38.4921500, 16.0842900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80478, 'Lattarico', 'Lattarico', 'Lattarico', 39.4510500, 16.1270000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80479, 'Las Plassas', 'Las Plassas', 'Las Plassas', 39.6797900, 8.9844200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80480, 'Lascari', 'Lascari', 'Lascari', 38.0006700, 13.9405300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80481, 'Rocca di Capri Leone', 'Rocca di Capri Leone', 'La Rocca,Rocca di Caprileone', 38.1067700, 14.7103200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80482, 'Larderia', 'Larderia', 'Larderia,Larderia Inferiore,Lareria', 38.1410100, 15.5028700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80483, 'Lappano', 'Lappano', 'Lappano', 39.3196400, 16.3114300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80484, 'Lanusei', 'Lanusei', 'Lanusei,ranuzei,Ланусеи,ラヌゼイ', 39.8792700, 9.5402200, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80485, 'Lampedusa', 'Lampedusa', 'LMP,Lampedusa', 35.5014200, 12.6096400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80486, 'La Maddalena', 'La Maddalena', '', 39.1442900, 9.0122300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80487, 'Laino Castello-Nuovo Centro', 'Laino Castello-Nuovo Centro', 'Laino Castello', 39.9363000, 15.9765800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80488, 'Laino Borgo', 'Laino Borgo', 'Laino Borgo', 39.9543000, 15.9734800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80489, 'Lago', 'Lago', 'Lacu,Lacum,Ladzho,Lago,la ge,lago,rago,Лаго,Ладжо,Լագո,ラーゴ,拉戈,라고', 39.1706800, 16.1482500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80490, 'Laganadi', 'Laganadi', 'Laganadi,Laganadum,la jia na di,laganady,laghandy,raganadi,Лаганади,Лаганаді,Լագանադի,لاغاندي,لاگانادی,ラガナーディ,拉加纳迪', 38.1739100, 15.7413300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80491, 'Laconi', 'Laconi', 'Laconi,rakoni,ラーコニ', 39.8532500, 9.0519600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80492, 'Kamma', 'Kamma', 'Kamma,Khamma', 36.7970100, 12.0361700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80493, 'Itala', 'Itala', 'Itala', 38.0514400, 15.4370600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80494, 'Ispica', 'Ispica', 'Spaccaforno', 36.7862200, 14.9053000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80495, 'Isola delle Femmine', 'Isola delle Femmine', 'Isola delle Femmine,Isula', 38.1912300, 13.2469100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80496, 'Isola di Capo Rizzuto', 'Isola di Capo Rizzuto', 'Isola', 38.9584400, 17.0924200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80497, 'Isnello', 'Isnello', 'Isneddu,Isnello', 37.9432400, 14.0072400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80498, 'Isili', 'Isili', 'Isili', 39.7395200, 9.1111400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80499, 'Isca sullo Ionio', 'Isca sullo Ionio', 'Isca,Isca dell''Ionio,Isca dello Ionio,Isca dello Iónio,Isca sull''Ionio,Isca sullo Ionio', 38.6010300, 16.5201000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80500, 'Joppolo Giancaxio', 'Joppolo Giancaxio', 'Ioppolo,Joppolo,Joppolo Giancaxio,Joppulu Giancaxiu', 37.3868100, 13.5558600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80501, 'Ilbono', 'Ilbono', 'Ilbono', 39.8925800, 9.5458200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80502, 'Iglesias', 'Iglesias', 'Ecclesia,Esglesies,Esglèsies,Esglésies,Iglesias,Iglezias,igurejiasu,Иглезиас,イグレージアス', 39.3092000, 8.5372000, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80503, 'Jerzu', 'Jerzu', 'Ierzu,Jerzu', 39.7928900, 9.5178500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80504, 'Guspini', 'Guspini', 'Guspini', 39.5395400, 8.6350200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80505, 'Guasila', 'Guasila', 'Guasila', 39.5598000, 9.0440400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80506, 'Aprigliano', 'Aprigliano', 'Aprigliano,apuririano,アプリリアーノ', 39.2422800, 16.3404600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80507, 'Guardia Piemontese', 'Guardia Piemontese', 'Guardia,Guardia Piemontesa,Guardia Piemontese,Guárdia,Guárdia Piemontese,La Gardia,La Gouardia,La Gàrdia', 39.4657200, 15.9997000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80508, 'Guardavalle', 'Guardavalle', 'Guardavalle', 38.5051000, 16.5066900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80509, 'Guamaggiore', 'Guamaggiore', 'Guamaggiore', 39.5684900, 9.0739100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80510, 'Grotteria', 'Grotteria', 'Grotteria', 38.3650900, 16.2652200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80511, 'Grotte', 'Grotte', 'Grotte,Grutti', 37.4034600, 13.6988900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80512, 'Grisolia', 'Grisolia', 'Grisolia,Grisolia Cipollina', 39.7253800, 15.8560500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80513, 'Grimaldi', 'Grimaldi', 'Grimal''di,Grimaldi,Grimaldum,Grimaudu,Grimàudu,ge li ma er di,geulimaldi,gurimarudi,Грималди,Гримальди,Грімальді,Գրիմալդի,グリマルディ,格里马尔迪,그리말디', 39.1411100, 16.2351100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80514, 'Gratteri', 'Gratteri', 'Gratteri,Ratteri', 37.9660700, 13.9731400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80515, 'Grammichele', 'Grammichele', 'Grammichele,Grammicheli', 37.2132600, 14.6331100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80516, 'Gonnostramatza', 'Gonnostramatza', 'Gonnostramatza', 39.6830600, 8.8328300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80517, 'Gonnosnò', 'Gonnosno', 'Gonnosno,Gonnosnò', 39.7610400, 8.8713500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80518, 'Gonnosfanadiga', 'Gonnosfanadiga', 'Gonnosfanadiga', 39.4942600, 8.6620000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80519, 'Gonnoscodina', 'Gonnoscodina', 'Gonnoscodina', 39.6996200, 8.8359800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80520, 'Gonnesa', 'Gonnesa', 'Gonnesa', 39.2653500, 8.4703800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80521, 'Goni', 'Goni', 'Goni', 39.5790600, 9.2851900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80522, 'Godrano', 'Godrano', 'Godramo,Godrano,Gudranu', 37.9031000, 13.4282300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80523, 'Gizzeria', 'Gizzeria', 'Gizzeria', 38.9802500, 16.2067100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80524, 'Giuliana', 'Giuliana', 'Giuliana,juriana,ジュリアーナ', 37.6728000, 13.2373700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80525, 'Girifalco', 'Girifalco', 'Girifalco', 38.8259400, 16.4268800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80526, 'Girasole', 'Girasole', 'Girasole', 39.9520500, 9.6609800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80527, 'Gioiosa Marea', 'Gioiosa Marea', 'Gioiosa Marea,Giojosa Marea,Giujusa', 38.1737300, 14.8993200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80528, 'Gioiosa Ionica', 'Gioiosa Ionica', 'Gioiosa Ionica,Gioiosa Jonica', 38.3272300, 16.3040700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80529, 'Gioia Tauro', 'Gioia Tauro', 'Gioia Tauro', 38.4251000, 15.8975000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80530, 'Gimigliano', 'Gimigliano', '', 38.9733800, 16.5316500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80531, 'Giffone', 'Giffone', 'Dzhiffone,Dzhifone,Giffone,Giffonium,Jifone,Lu Casali,ji fu nei,jiffone,jyfwnh,jyfwny,Ђифоне,Джифоне,Джиффоне,Ջիֆոնե,جيفوني,جیفونه,ジッフォーネ,吉福内', 38.4395700, 16.1489800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80532, 'Nuova Gibellina', 'Nuova Gibellina', 'Gibbellina,Gibellina', 37.8070400, 12.8695400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80533, 'Giba', 'Giba', 'Giba', 39.0715100, 8.6358000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80534, 'Giarre', 'Giarre', 'Dzharre,Giarre,Giarre Riposto,Giarri,Girarre,Джарре', 37.7244000, 15.1816500, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80535, 'Giarratana', 'Giarratana', 'Giarratana,jarratana,ジャッラターナ', 37.0474100, 14.7945400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80536, 'Giardini-Naxos', 'Giardini-Naxos', 'Giardini,Giardini Naxos', 37.8275500, 15.2671300, 'IT', '2016-01-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80537, 'Giardinello', 'Giardinello', 'Giardineddu,Giardinello', 38.0870600, 13.1564800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80538, 'Giardina Gallotti', 'Giardina Gallotti', '', 37.3507300, 13.5227200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80539, 'Gesturi', 'Gesturi', 'Gesturi', 39.7323700, 9.0207700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80540, 'Gesico', 'Gesico', 'Gesico', 39.6163600, 9.1066500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80541, 'Gergei', 'Gergei', 'Gergei', 39.6987800, 9.0996500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80542, 'Geraci Siculo', 'Geraci Siculo', 'Geraci,Geraci Siculo,Jiraci', 37.8590100, 14.1533300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80543, 'Gerace', 'Gerace', 'Gerace,Gerace Superiore', 38.2713700, 16.2207000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80544, 'Genuri', 'Genuri', 'Genari,Genuri', 39.7432700, 8.9240700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80545, 'Genoni', 'Genoni', 'Genoni', 39.7936100, 9.0079700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80546, 'Gemini', 'Gemini', '', 39.9113400, 18.1874200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80547, 'Gela', 'Gela', 'Dzhela,Gela,ge la,jera,jie la,Джела,ジェーラ,杰拉,格拉', 37.0738100, 14.2403800, 'IT', '2015-08-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80548, 'Gasperina', 'Gasperina', 'Gasperina', 38.7403900, 16.5066600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80549, 'Gangi', 'Gangi', 'Gangi,ganji,ガンジ', 37.7956500, 14.2043700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80550, 'Gallodoro', 'Gallodoro', 'Gallodoro,Jaddudoru', 37.9020600, 15.2935900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80551, 'Galatro', 'Galatro', 'Galatro,Galatru,Galatrum,garatoro,ghalatrw,jia la te luo,Галатро,Գալատրո,غالاترو,ガーラトロ,加拉特罗', 38.4606700, 16.1084000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80552, 'Galati Mamertino', 'Galati Mamertino', 'Galati,Galati Mamertino', 38.0317600, 14.7714500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80553, 'Gairo Sant''Elena', 'Gairo Sant''Elena', 'Gairo,Gairo Nuoro', 39.8497200, 9.5047200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80554, 'Gagliano del Capo', 'Gagliano del Capo', 'Gagliano del Capo', 39.8432300, 18.3696200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80555, 'Gagliano Castelferrato', 'Gagliano Castelferrato', 'Gagghianu,Gagliano Castelferrato', 37.7096700, 14.5352400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80556, 'Gaggi', 'Gaggi', 'Caggi,Gadzhi,Gaggi,Gaggis,Gaji,Kaggi,gaji,gajji,ghadjy,jia ji,Гаджи,Гаджі,Գաջի,غادجي,გაჯი,ガッジ,加吉', 37.8599500, 15.2212600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80557, 'Gadoni', 'Gadoni', 'Gadoni', 39.9138800, 9.1856000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80558, 'Fuscaldo', 'Fuscaldo', 'Fuscaldo', 39.4142100, 16.0283900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80559, 'Furtei', 'Furtei', 'Furtei', 39.5625300, 8.9477300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80560, 'Furci Siculo', 'Furci Siculo', 'Fulci,Furci Siculo,Furci Siculu', 37.9615900, 15.3776300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80561, 'Frazzanò', 'Frazzano', 'Frazzano,Frazzanò', 38.0720200, 14.7440700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80562, 'Frascineto', 'Frascineto', 'Frascineto,Frasnita', 39.8338200, 16.2637800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80563, 'Francofonte', 'Francofonte', 'Carlintini,Francofonte,Francufonti,furankofonte,フランコフォンテ', 37.2247700, 14.8748800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80564, 'Francica', 'Francica', 'Franchika,Francica,fu lan qi ka,furanchika,Франчика,Ֆրանչիկա,フランチカ,弗兰奇卡', 38.6169700, 16.1000700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80565, 'Francavilla Marittima', 'Francavilla Marittima', 'Francavilla,Francavilla Marittima', 39.8161000, 16.3949900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80566, 'Francavilla di Sicilia', 'Francavilla di Sicilia', 'Francavigghia di Sicilia,Francavilla di Sicilia', 37.9019700, 15.1382100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80567, 'Francavilla Angitola', 'Francavilla Angitola', 'Francavilla,Francavilla Angitola', 38.7801600, 16.2722800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80568, 'Fossato Serralta', 'Fossato Serralta', 'Fossato Serralta', 38.9962900, 16.5796000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80569, 'Fossato Ionico-Fossatello-San Luca Marcelluzzo', 'Fossato Ionico-Fossatello-San Luca Marcelluzzo', '', 38.0106500, 15.7630200, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80570, 'Forza d''Agrò', 'Forza d''Agro', 'Forza d''Agro,Forza d''Agrò', 37.9153900, 15.3340900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80571, 'Fordongianus', 'Fordongianus', 'Fordongianus', 39.9943600, 8.8101900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80572, 'Fluminimaggiore', 'Fluminimaggiore', 'Fluminimaggiore', 39.4387800, 8.4975800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80573, 'Floridia', 'Floridia', 'Ciuriddia,Floridia,Floridii,furoridia,Флоридии,フロリーディア', 37.0834300, 15.1533200, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80574, 'Floresta', 'Floresta', 'Floresta,Fluresta,flwrsta,fu luo lei si ta,furoresuta,Флореста,Ֆլորեստա,فلورستا,フロレスタ,弗洛雷斯塔', 37.9877900, 14.9109600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80575, 'Fiumefreddo Sicilia', 'Fiumefreddo Sicilia', 'Ciumifriddu,Fiumefreddo di Sicilia,Sciummefriddo', 37.7914600, 15.2091900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80576, 'Fiumefreddo Bruzio', 'Fiumefreddo Bruzio', 'Fiumefreddo Bruzio', 39.2356800, 16.0705600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80577, 'Fiumedinisi', 'Fiumedinisi', 'Ciumidinisi,Fiumedinisi', 38.0259600, 15.3809900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80578, 'Firmo', 'Firmo', 'Ferma,Firmo', 39.7220800, 16.1634400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80579, 'Finale', 'Finale', 'Finale', 38.0189100, 14.1615100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80580, 'Filogaso', 'Filogaso', 'Filogaso', 38.6828700, 16.2258400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80581, 'Filadelfia', 'Filadelfia', 'Filadelfia,firaderufia,フィラデルフィア', 38.7846800, 16.2920000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80582, 'Ficarra', 'Ficarra', 'Ficarra', 38.1084900, 14.8299000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80583, 'Ficarazzi', 'Ficarazzi', 'Ficarazzi', 38.0922900, 13.4639000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80584, 'Ferruzzano', 'Ferruzzano', 'Ferruccano,Ferrutianum,Ferruzzano,Ferruzzano vald,Ferruzzanu,Ferucano,fei lu zha nuo,ferruttsu~ano,fyrwzanw,Ферруццано,Феруцано,Ֆերուցանո,فيروزانو,フェッルッツァーノ,费鲁扎诺', 38.0369900, 16.0891800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80585, 'Feroleto della Chiesa', 'Feroleto della Chiesa', 'Feroleto,Feroleto della Chiesa', 38.4660900, 16.0701200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80586, 'Ferla', 'Ferla', 'Ferla,ferura,フェルラ', 37.1197800, 14.9388100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80587, 'Felline', 'Felline', 'Felline,Fellini', 39.9365100, 18.1182200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80588, 'Favignana', 'Favignana', 'Aegusa,Favignana,Favin''jana,Favinana,Favinjana,Favinyana,Isla Favignana,Porto de Favignana,fa wei ni ya na,fafynyana,favu~inyana,fawynyana,paviniana,Фавиньяна,Фавиняна,Фавињана,Фавіньяна,Ֆավինյանա,فافينيانا,فاوینیانا,ფავინიანა,ファヴィニャーナ,法维尼亚纳', 37.9295100, 12.3295800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80589, 'Favara', 'Favara', 'Favara', 37.3175400, 13.6622600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80590, 'Faro Superiore', 'Faro Superiore', 'Faro,Faro Superiore', 38.2679400, 15.5826800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80591, 'Falerna', 'Falerna', 'Falerna', 39.0029800, 16.1715100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80592, 'Falcone', 'Falcone', 'Falcone,Falcuni', 38.1169800, 15.0796500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80593, 'Falconara Albanese', 'Falconara Albanese', 'Falconara,Falconara Albanese,Fallkunara', 39.2752400, 16.0881900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80594, 'Fagnano Castello', 'Fagnano Castello', 'Fagnano Castello', 39.5716000, 16.0625300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80595, 'Fabrizia', 'Fabrizia', 'Fabrizia', 38.4898900, 16.2983200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80596, 'Esterzili', 'Esterzili', 'Esterzili', 39.7804100, 9.2835700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80597, 'Escolca', 'Escolca', 'Escolca', 39.6986100, 9.1213900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80598, 'Escalaplano', 'Escalaplano', 'Escalaplano', 39.6257400, 9.3535000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80599, 'Erice', 'Erice', 'Ehriche,Erice,Erici,Mont Eryx,Mont Éryx,Monte San Giuliano,Èrici,Эриче', 38.0378500, 12.5877800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80600, 'Enna', 'Enna', 'Castrugiuvanni,Ehnna,Ena,Enna,Haenna,en''na,Ена,Энна,אנה,エンナ', 37.5655000, 14.2743300, 'IT', '2015-07-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80601, 'Elmas', 'Elmas', 'Elmas', 39.2687800, 9.0502100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80602, 'Elini', 'Elini', 'Elini', 39.8995200, 9.5319800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80603, 'Drapia', 'Drapia', 'Drapia', 38.6661200, 15.9112200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80604, 'Doria', 'Doria', '', 39.7304200, 16.3559700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80605, 'Donorì', 'Donori', 'Donori,Donorì,Donoti', 39.4318200, 9.1267400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80606, 'Donnici Inferiore', 'Donnici Inferiore', '', 39.2502000, 16.2930700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80607, 'Donnalucata', 'Donnalucata', '', 36.7611700, 14.6402200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80608, 'Donigala Fenugheddu', 'Donigala Fenugheddu', 'Donigala', 39.9350100, 8.5731100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80609, 'Domusnovas', 'Domusnovas', 'Domusnovas', 39.3240400, 8.6492100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80610, 'Domus de Maria', 'Domus de Maria', 'Domus de Maria', 38.9445100, 8.8625000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80611, 'Domanico', 'Domanico', 'Domanico', 39.2169300, 16.2072100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80612, 'Dolianova', 'Dolianova', 'Dolianova', 39.3779100, 9.1769700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80613, 'Diso', 'Diso', 'Diso', 40.0091500, 18.3914400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80614, 'Dinami', 'Dinami', 'Dinami', 38.5313600, 16.1446100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80615, 'Diamante', 'Diamante', '', 39.6807000, 15.8216800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80616, 'Depressa', 'Depressa', 'Depressa', 39.9590800, 18.3617400, 'IT', '2014-02-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80617, 'Delianuova', 'Delianuova', 'Delianova,Delianuova', 38.2358700, 15.9171400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80618, 'Delia', 'Delia', 'Delia', 37.3579600, 13.9286700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80619, 'Decollatura', 'Decollatura', 'Decollatura', 39.0464500, 16.3575300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80620, 'Decimoputzu', 'Decimoputzu', 'Decimoputzu', 39.3352200, 8.9144000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80621, 'Decimomannu', 'Decimomannu', 'DCI,Decimomannu,Decimontanne,Decimontanno', 39.3103300, 8.9696400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80622, 'Davoli', 'Davoli', 'Davoli', 38.6490400, 16.4876400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80623, 'Dasà', 'Dasa', 'Dasa,Dasà,Daza,da sa,dasa,Даза,Դազա,ダサ,達薩', 38.5651400, 16.1952100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80624, 'Cutro', 'Cutro', 'Cutro', 39.0348400, 16.9865800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80625, 'Custonaci', 'Custonaci', 'Castonaci,Custonaci,Custunaci', 38.0793100, 12.6857100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80626, 'Curinga', 'Curinga', 'Curinga,Curinga a Maida,Curinga a Máida', 38.8281100, 16.3134400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80627, 'Curcuris', 'Curcuris', 'Curcuris', 39.7462500, 8.8315400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80628, 'Crucoli', 'Crucoli', '', 39.4271300, 17.0028100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80629, 'Crotone', 'Crotone', 'CRV,Cotrone,Croto,Croton,Crotona,Cutroni,Kroton,Krotona,Krotonas,Krotone,Krotono,Krotonė,ke luo tuo nei,keulotone,kor tone,krwtwn,krwtwny,kurotone,qrwtwnh,Κρότωνας,Кротон,Кротоне,קרוטונה,كروتوني,کروتون,โกรโตเน,クロトーネ,克羅托內,크로토네', 39.0807700, 17.1276400, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80630, 'Crosia', 'Crosia', 'Crosia,Crosta', 39.5682200, 16.7712600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80631, 'Cropani', 'Cropani', 'Cropani', 38.9669000, 16.7802200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80632, 'Cropalati', 'Cropalati', 'Cropalati', 39.5167300, 16.7267400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80633, 'Crichi', 'Crichi', '', 38.9529600, 16.6417800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80634, 'Cotronei', 'Cotronei', 'Cotronei', 39.1593500, 16.7768800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80635, 'Cosoleto', 'Cosoleto', 'Cosoleto', 38.2748300, 15.9281400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80636, 'Cosenza', 'Cosenza', 'Cosenza,Cusenza,Kozenca,QCS,kozentsu~a,Козенца,コゼンツァ', 39.2989000, 16.2530700, 'IT', '2015-08-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80637, 'Cortale', 'Cortale', 'Cortale', 38.8400900, 16.4096000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80638, 'Corsano', 'Corsano', 'Corsano', 39.8891100, 18.3674700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80639, 'Corleone', 'Corleone', 'Corleone,Curliuni,Korleone,Korleonė,korureone,Κορλεόνε,Корлеоне,קורלאונה,コルレオーネ', 37.8133800, 13.3017000, 'IT', '2014-03-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80640, 'Corigliano Calabro', 'Corigliano Calabro', 'Corigliano Calabro,コリリアーノ・カーラブロ', 39.5955300, 16.5190700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80641, 'Contessa Entellina', 'Contessa Entellina', 'Contessa Entellina,Cuntissa', 37.7300500, 13.1842500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80642, 'Condrò', 'Condro', 'Condro,Condrò,Cundro,Cundrò', 38.1737500, 15.3266000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80643, 'Condofuri', 'Condofuri', 'Condofuri,Kontocori', 38.0044700, 15.8577000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80644, 'Comitini', 'Comitini', 'Comitini,Cumitini', 37.4073500, 13.6453000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80645, 'Comiso', 'Comiso', 'CIY,Comiso,Comisu,Commisu,Còmisu,Còmmisu,Komizo,komizo,Комизо,コーミゾ', 36.9489300, 14.6073100, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80646, 'Colosimi', 'Colosimi', 'Colosimi', 39.1191100, 16.3990900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80647, 'Collinas', 'Collinas', 'Collinas', 39.6405900, 8.8395500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80648, 'Collesano', 'Collesano', 'Collesano,Gulisanu', 37.9180900, 13.9370200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80649, 'Cleto', 'Cleto', 'Cleto', 39.0901900, 16.1583900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80650, 'Civita', 'Civita', 'Cifti,Civita', 39.8280400, 16.3133700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80651, 'Cittanova', 'Cittanova', 'Casale Novum,Chitanova,Chittanova,Cittanova,chittanovu~a,qi ta nuo wa,tshtanwfa,Читанова,Читтанова,Չիտանովա,تشتانوفا,チッタノーヴァ,奇塔诺瓦', 38.3543100, 16.0789800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80652, 'Cittadella del Capo', 'Cittadella del Capo', 'Cittadella di Capo Bonifati', 39.5593200, 15.8760200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80653, 'Cirò Marina', 'Ciro Marina', 'Ciro Marina,Cirò Marina,Marina di Ciro', 39.3687600, 17.1247700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80654, 'Cirò', 'Ciro', 'Ciro,Cirò', 39.3829700, 17.0637700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80655, 'Cinque Frondi', 'Cinque Frondi', 'Cinquefrondi', 38.4161800, 16.0842000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80656, 'Cinisi', 'Cinisi', 'Cinisi', 38.1608200, 13.1009900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80657, 'Ciminna', 'Ciminna', 'Ciminna', 37.8976500, 13.5596600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80658, 'Ciminà', 'Cimina', 'Cimina,Ciminà', 38.2461800, 16.1402300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80659, 'Cicala', 'Cicala', 'Cicala', 39.0221900, 16.4861000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80660, 'Ciavolo', 'Ciavolo', '', 37.7794300, 12.5377400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80661, 'Cianciana', 'Cianciana', 'Cianciana', 37.5189600, 13.4334900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80662, 'Chiusa Sclafani', 'Chiusa Sclafani', 'Chiusa,Chiusa Sclafani,Sclafani', 37.6769200, 13.2707400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80663, 'Chiaravalle Centrale', 'Chiaravalle Centrale', 'Chiaravalle Centrale', 38.6793600, 16.4086400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80664, 'Chiaramonte Gulfi', 'Chiaramonte Gulfi', 'Chiaramonte Gulfi,Ciaramunti,キアラモンテ・グルフィ', 37.0305000, 14.7030200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80665, 'Cetraro', 'Cetraro', 'Cetraro', 39.5166000, 15.9415800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80666, 'Cessaniti', 'Cessaniti', 'Cessaniti,Cessanti', 38.6639500, 16.0295900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80667, 'Cesarò', 'Cesaro', 'Cesaro,Cesarò,Chezaro,Чезаро', 37.8447600, 14.7130800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80668, 'Cerzeto', 'Cerzeto', 'Cerzeto,Qana', 39.5078900, 16.1160300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80669, 'Cervicati', 'Cervicati', 'Cervicati,Cervikati', 39.5423700, 16.1268200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80670, 'Cerva', 'Cerva', 'Cerva', 39.0239700, 16.7453800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80671, 'Cerisano', 'Cerisano', 'Cerisano', 39.2771500, 16.1765400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80672, 'Cerenzia', 'Cerenzia', 'Cerenzia', 39.2455400, 16.7875800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80673, 'Cerda', 'Cerda', 'Cerda', 37.9057800, 13.8149600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80674, 'Cerchiara di Calabria', 'Cerchiara di Calabria', 'Cerchiara di Calabria', 39.8597800, 16.3836800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80675, 'Ceramida-Pellegrina', 'Ceramida-Pellegrina', '', 38.2966700, 15.8257200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80676, 'Cerami', 'Cerami', 'Cerami,Cirami', 37.8095300, 14.5066000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80677, 'Centuripe', 'Centuripe', 'Centorvu,Centuripe', 37.6233600, 14.7404900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80678, 'Centrache', 'Centrache', 'Centrache', 38.7287200, 16.4310100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80679, 'Cenadi', 'Cenadi', 'Cenadi', 38.7193400, 16.4158200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80680, 'Cellara', 'Cellara', 'Cellara', 39.2184900, 16.3348000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80681, 'Celico', 'Celico', 'Celico', 39.3100900, 16.3398900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80682, 'Cefalù', 'Cefalu', 'Cefalas,Cefalu,Cefalu'',Cefalù,Cefalú,Cifalu,Cifalù,z''plw,צ''פלו', 38.0385600, 14.0228500, 'IT', '2016-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80683, 'Cefalà Diana', 'Cefala Diana', 'Cefala,Cefala Diana,Cefalà Diana,Cifala Diana,Cifalà Diana', 37.9156500, 13.4632500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80684, 'Cava d''Aliga', 'Cava d''Aliga', '', 36.7296400, 14.6903100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80685, 'Caulonia', 'Caulonia', 'Caulonia', 38.3817100, 16.4095100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80686, 'Cattolica Eraclea', 'Cattolica Eraclea', 'Catolica Eraclia,Cattolica,Cattolica Eraclea,Cattolica Eraclia,Catòlica Eraclìa', 37.4406900, 13.3926500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80687, 'Catenanuova', 'Catenanuova', 'Cantagnenuova', 37.5687600, 14.6907600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80688, 'Catanzaro', 'Catanzaro', 'Catanzara,Catanzaro,Catanzaru,Katandzaro,QCZ,katanchalo,katantsu~aro,Катандзаро,カタンツァーロ,카탄차로', 38.8824700, 16.6008600, 'IT', '2017-06-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80689, 'Catania', 'Catania', 'CTA,Catane,Catania,Catina,Catània,Catânia,Katane,Katania,Katanija,Katānija,katania,katanya,qtnyh,Κατάνη,Катания,Катанија,קטניה,كاتانيا,კატანია,カターニア', 37.4922300, 15.0704100, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80690, 'Castrovillari', 'Castrovillari', 'Castrovillari,Kastrovillari,Кастровиллари', 39.8163200, 16.2018300, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80691, 'Castroregio', 'Castroregio', 'Castroregio,Kasternexhi', 39.9922000, 16.4784600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80692, 'Castroreale', 'Castroreale', 'Castroreale,Castruriali', 38.0985700, 15.2101200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80693, 'Castronuovo di Sicilia', 'Castronuovo di Sicilia', 'Castronovo di Sicilia,Castronuovo,Castrunovu', 37.6789400, 13.6034600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80694, 'Castrolibero', 'Castrolibero', 'Castrolibero', 39.3100200, 16.1945300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80695, 'Castrofilippo', 'Castrofilippo', 'Castrofilippo,Castrufilippu', 37.3504600, 13.7500100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80696, 'Castrignano del Capo', 'Castrignano del Capo', 'Castignano del Capo,Castrignano del Capo', 39.8328000, 18.3508700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80697, 'Castiglione', 'Castiglione', 'Castiglione,Castiglione d''Otranto', 39.9833300, 18.3500000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80698, 'Castiglione di Sicilia', 'Castiglione di Sicilia', 'Castigghiuni di Sicilia,Castiglione di Sicilia', 37.8815000, 15.1215600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80699, 'Castiglione Cosentino', 'Castiglione Cosentino', 'Castiglione,Castiglione Cosentino', 39.3527100, 16.2882100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80700, 'Castiadas', 'Castiadas', 'Casa di Pena,Castiadas', 39.2370400, 9.4997500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80701, 'Castelvetrano', 'Castelvetrano', 'Castedduvitranu,Castelvetrano,Castelvetranu,Castrum Veteranum,Kastel''vetrano,Kastelvetranas,Kastelvetrano,ka si tai er wei te la nuo,kastl wtranw,kastlftranw,kasuteruvu~etorano,Кастелветрано,Кастельветрано,Կաստելվետրանո,كاستلفترانو,کاستل وترانو,კასტელვეტრანო,カステルヴェトラーノ,卡斯泰尔韦特拉诺', 37.6808100, 12.7919400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80702, 'Casteltermini', 'Casteltermini', 'Casteltermini', 37.5387400, 13.6460100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80703, 'Castelmola', 'Castelmola', '', 37.8582900, 15.2771300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80704, 'Castelluzzo', 'Castelluzzo', '', 38.1009600, 12.7359900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80705, 'Castell''Umberto', 'Castell''Umberto', 'Castania,Castell''Umberto,Castello Umberto', 38.0862600, 14.8068600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80706, 'Castelluccio Inferiore', 'Castelluccio Inferiore', 'Castelluccio,Castelluccio Inferiore', 40.0015100, 15.9814900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80707, 'Castellana Sicula', 'Castellana Sicula', 'Castellana,Castellana Sicula,Castiddana', 37.7868600, 14.0390600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80708, 'Castellammare del Golfo', 'Castellammare del Golfo', 'Casteddammari,Castellammare del Golfo', 38.0265300, 12.8818300, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80709, 'Castel di Lucio', 'Castel di Lucio', 'Castel di Lucio,Castel di Luciu', 37.8869800, 14.3111600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80710, 'Castel di Judica', 'Castel di Judica', 'Carrulo,Castel di Iudica,Castel di Judica,Giardinelli,Giumarra', 37.4947500, 14.6474400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80711, 'Casteldaccia', 'Casteldaccia', 'Casteldaccia,Castellatium,Castiddaccia,Kastel''dachcha,Kastel''dachchia,Kasteldacha,ka si tai er da qia,kastldatsha,kasuterudatcha,Кастелдача,Кастельдачча,Кастельдаччиа,Կաստելդաչա,كاستلداتشا,カステルダッチャ,卡斯泰尔达恰', 38.0512100, 13.5304100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80712, 'Castelbuono', 'Castelbuono', 'Castelbuono,Castiddubbuonu', 37.9253000, 14.0866500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80713, 'Castanea delle Furie', 'Castanea delle Furie', 'Castanea,Castanea delle Furie', 38.2616500, 15.5217800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80714, 'Cassibile', 'Cassibile', 'Cassibbili,Cassibile,Cassìbbili,Kasibile,Касибиле', 36.9786200, 15.2006100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80715, 'Cassaro', 'Cassaro', 'Cassaro,Cassaru,kassaro,カッサロ', 37.1057100, 14.9469700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80716, 'Cassano Allo Ionio', 'Cassano Allo Ionio', 'Cassano Jonio,Cassano al Jonio,Cassano all''Ionio,Cassano all''Iónio', 39.7814200, 16.3273800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80717, 'Casole Bruzio', 'Casole Bruzio', 'Casole Bruzio', 39.2838400, 16.3319300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80718, 'Casignana', 'Casignana', 'Casignana', 38.1018700, 16.0899000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80719, 'Casarano', 'Casarano', 'Casarano,Casaranu', 40.0113100, 18.1623700, 'IT', '2015-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80720, 'Casalvecchio Siculo', 'Casalvecchio Siculo', 'Casalvecchio,Casalvecchio Siculo,Casalvecchiu Siculu', 37.9585000, 15.3237100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80721, 'Casabona', 'Casabona', 'Casabona', 39.2495100, 16.9544600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80722, 'Carpanzano', 'Carpanzano', 'Carpanzano', 39.1481700, 16.3045100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80723, 'Marina di Caronia', 'Marina di Caronia', 'Caronia Marina,Marina,Marina di Caronia', 38.0354500, 14.4418200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80724, 'Caronia', 'Caronia', 'Caronia,Carunia,Carunìa,Karonia,Karonija,ka luo ni ya,karonia,karwnya,Карония,Каронија,Каронія,Կարոնիա,كارونيا,კარონია,カロニーア,卡罗尼亚', 38.0238100, 14.4414200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80725, 'Carolei', 'Carolei', 'Carolei', 39.2547200, 16.2197900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80726, 'Carlopoli', 'Carlopoli', 'Carlopoli', 39.0540600, 16.4545500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80727, 'Carloforte', 'Carloforte', 'Carloforte', 39.1408100, 8.3039000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80728, 'Carlentini', 'Carlentini', 'Carlentini,Carlintini,Carruntini,karurentini,カルレンティーニ', 37.2807100, 15.0102000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80729, 'Carini', 'Carini', 'Carini,Karina,Карина', 38.1324000, 13.1827400, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80730, 'Cariati', 'Cariati', 'Cariati', 39.4962700, 16.9549500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80731, 'Carfizzi', 'Carfizzi', 'Carfizzi,Karfici', 39.3077100, 16.9744700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80732, 'Careri', 'Careri', 'Careri', 38.1774100, 16.1161400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80733, 'Cardinale', 'Cardinale', 'Cardinale', 38.6537900, 16.3871500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80734, 'Cardeto', 'Cardeto', 'Cardeto', 38.0844000, 15.7657700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80735, 'Carbonia', 'Carbonia', 'Carbonia,Carbònia,Karbonija,ka er bo ni ya,karubonia,Карбония,Карбонија,Карбонія,カルボーニア,卡尔博尼亚', 39.1646500, 8.5213000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80736, 'Caraffa di Catanzaro', 'Caraffa di Catanzaro', 'Caraffa,Caraffa di Catanzaro', 38.8819400, 16.4867500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80737, 'Caraffa del Bianco', 'Caraffa del Bianco', 'Caraffa del Bianco,Caraffa del Bianco vald,Carapha,Karafa del Bianko,Karaffa-del''-B''janko,Karaffa-del''-Bjanko,ka la fa de er bi ya en ke,karfa dyl bykanw,Карафа дел Бианко,Караффа-дель-Бьянко,Караффа-дель-Бянко,Կարաֆա դել Բիանկո,كارفا ديل بيكانو,カラッファ・デル・ビアンコ,卡拉法德尔比亚恩科', 38.0925900, 16.0876600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80738, 'Capri Leone', 'Capri Leone', 'Capri Leone,Capri Liuni', 38.0868200, 14.7295900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80739, 'Capoterra', 'Capoterra', 'Cabuderra,Capoterra,Kapoterra,Капотерра', 39.1752000, 8.9719900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80740, 'Capo Rizzuto', 'Capo Rizzuto', 'Capo Rizzuto,Madonna Greca', 38.9041200, 17.0987200, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80741, 'Capo d''Orlando', 'Capo d''Orlando', 'Capo d''Orlando,Capu d''Orlannu', 38.1426200, 14.7329200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80742, 'Dipignano', 'Dipignano', 'Dipignano', 39.2386900, 16.2518400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80743, 'Capizzi', 'Capizzi', 'Capizzi', 37.8478800, 14.4797600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80744, 'Capistrano', 'Capistrano', 'Capistrano,Capistranu,Capistronum,Kapistrano,ka pi si te la nuo,kapisutorano,Капистрано,Капістрано,Կապիստրանո,カピストラーノ,卡皮斯特拉诺', 38.6913100, 16.2893500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80745, 'Capaci', 'Capaci', 'Capaci', 38.1710700, 13.2393000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80746, 'Canolo', 'Canolo', 'Canolo', 38.3149700, 16.1999000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80747, 'Canneto', 'Canneto', '', 38.4950500, 14.9603700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80748, 'Canicattini Bagni', 'Canicattini Bagni', 'Canicattini,Canicattini Bagni,カニカッティーニ・バーニ', 37.0317100, 15.0638800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80749, 'Canicattì', 'Canicatti', 'Canicatti,Canicattì', 37.3584200, 13.8478600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80750, 'Candidoni', 'Candidoni', 'Candidoni,Candidoni vald,Candidonum,Candioni,Kandidoni,kan di duo ni,kandidoni,kandydwny,Кандидони,Кандідоні,Կանդիդոնի,كانديدوني,カンディードニ,坎迪多尼', 38.5054800, 16.0863000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80751, 'Camporeale', 'Camporeale', 'Camporeale,Campuriali', 37.8861200, 13.1010700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80752, 'Campofranco', 'Campofranco', 'Campofranco,Campufrancu', 37.5120800, 13.7121300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80753, 'Campofiorito', 'Campofiorito', 'Campofiorito,Campuciurutu', 37.7537400, 13.2687500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80754, 'Campofelice di Roccella', 'Campofelice di Roccella', 'Campofelice,Campofelice Roccella,Campofelice di Roccella,La Ruccedda', 37.9927000, 13.8764800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80755, 'Campofelice di Fitalia', 'Campofelice di Fitalia', 'Campo Felice,Campofelice di Fitalia,Campufilici di Fitalia', 37.8268600, 13.4857200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80756, 'Campobello di Mazara', 'Campobello di Mazara', 'Campobello di Mazara,Campobello di Mazzara,Campubbeddu', 37.6346400, 12.7494600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80757, 'Campobello di Licata', 'Campobello di Licata', 'Campobello di Licata,Campubbeddu,Campubeddu', 37.2575900, 13.9181100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80758, 'Campana', 'Campana', '', 39.4136000, 16.8222000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80759, 'Cammarata', 'Cammarata', 'Cammarata', 37.6336100, 13.6272200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80760, 'Camini', 'Camini', 'Camini,Caminium,Kamini,ka mi ni,kamini,kamyny,Камини,Каміні,Կամինի,كاميني,カミーニ,卡米尼', 38.4317900, 16.4832100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80761, 'Camastra', 'Camastra', 'Camastra,Camastra ex Solfara', 37.2538000, 13.7921100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80762, 'Caltavuturo', 'Caltavuturo', 'Caltavuturo,Caltavuturu', 37.8204000, 13.8915800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80763, 'Caltanissetta', 'Caltanissetta', 'Caltanisetta,Caltanissetta,Kal''tanissetta,Nissa,QCL,karutanissetta,qltnysth,Кальтаниссетта,קלטניסטה,カルタニッセッタ', 37.4902500, 14.0621600, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80764, 'Caltagirone', 'Caltagirone', 'Caltaggiruni,Caltagirone,Kal''tadzhirone,karutajirone,Кальтаджироне,カルタジローネ', 37.2378500, 14.5155100, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80765, 'Caltabellotta', 'Caltabellotta', 'Caltabellotta,Cataviddotta', 37.5754300, 13.2163200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80766, 'Caloveto', 'Caloveto', 'Caloveto', 39.5065600, 16.7606500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80767, 'Caloppezzati', 'Caloppezzati', 'Calopezzati', 39.5612000, 16.8018000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80768, 'Calatafimi', 'Calatafimi', '', 37.9144000, 12.8636400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80769, 'Calatabiano', 'Calatabiano', 'Calatabiano,Calatabianu', 37.8204900, 15.2306900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80770, 'Calasetta', 'Calasetta', 'Calasetta', 39.1069700, 8.3680300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80771, 'Calascibetta', 'Calascibetta', 'Calascibetta,karashibetta,カラシベッタ', 37.5902400, 14.2718000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80772, 'Calanna', 'Calanna', 'Calanna,Kalana,Kalanna,ka lan na,kalana,karan''na,Калана,Каланна,Կալաննա,كالانا,カランナ,卡兰纳', 38.1845700, 15.7229300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80773, 'Calamonaci', 'Calamonaci', 'Calamonaci', 37.5256600, 13.2905300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80774, 'Cagliari', 'Cagliari', 'CAG,Cagliari,Cajari,Caliari,Caller,Caralis,Casteddu,Castel,Castèl,Càgliari,Càliari,Càller,Cáller,Gorad Kal''jary,Kagliari,Kal''jari,Kalari,Kaliari,Kaljari,Kaljaris,Kaljaro,Kaljāri,Kalyari,Lungsod ng Cagliari,ka li ya li,kagali''ari,kagliyari,kaglyary,kal ya ri,kaliyari,kalliali,kalyary,karyari,Κάλιαρι,Горад Кальяры,Кальяри,Кальярі,Каляри,Каљари,Կալիարի,קליארי,كالياري,کالیاری,کاگلیاری,कगलिआरी,काग्लियारी,கலியாரி,กาลยารี,კალიარი,カリャリ,卡利亚里,卡利亞里,칼리아리', 39.2305400, 9.1191700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80775, 'Caccuri', 'Caccuri', 'Caccuri', 39.2256200, 16.7776700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80776, 'Caccamo', 'Caccamo', '', 37.9335700, 13.6680800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80777, 'Cabras', 'Cabras', 'Cabras', 39.9287100, 8.5324200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80778, 'Butera', 'Butera', 'Butera,Vutera', 37.1910000, 14.1823200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80779, 'Buscemi', 'Buscemi', 'Bascemi,Buscemi,bushemi,ブシェーミ', 37.0860400, 14.8849900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80780, 'Burgio', 'Burgio', 'Burgio,Burgiu', 37.6009400, 13.2882600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80781, 'Burcei', 'Burcei', 'Burcei', 39.3437900, 9.3602700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80782, 'Buonvicino', 'Buonvicino', 'Buonvicino', 39.6887700, 15.8840000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80783, 'Buggerru', 'Buggerru', 'Budzhehru,Budzherru,Budzheru,Bugerru,Buggerru,Buggerrus,Bujeru,bu jie lu,bujjerru,Буджерру,Буджеру,Буджэру,Буђеру,Բուջերու,ブッジェッル,布杰鲁', 39.3983100, 8.4018600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80784, 'Buccheri', 'Buccheri', 'Buccheri,bukkeri,ブッケリ', 37.1249400, 14.8522200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80785, 'Bruzzano Zeffirio', 'Bruzzano Zeffirio', 'Bruzzano Zeffirio', 38.0132700, 16.0826000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80786, 'Brucoli', 'Brucoli', 'Brucoli,Brugoli', 37.2819100, 15.1883600, 'IT', '2016-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80787, 'Bronte', 'Bronte', 'Branteh,Bronte,Brontes,Bronti,brwnth,brwnty,bu long tai,buronte,Брантэ,Бронте,Բրոնտե,برونته,برونتي,ブロンテ,布龙泰', 37.7886300, 14.8337700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80788, 'Brolo', 'Brolo', 'Brolo,Brolu,buroro,ブローロ', 38.1562300, 14.8279900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80789, 'Briatico', 'Briatico', 'Briatico', 38.7225400, 16.0273700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80790, 'Brancaleone', 'Brancaleone', 'Brancaleone', 37.9629700, 16.1004000, 'IT', '2012-03-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80791, 'Brancaleone-Marina', 'Brancaleone-Marina', 'Brancaleone Marina,Marina di Brancaleone', 37.9666700, 16.1000000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80792, 'Bova Marina', 'Bova Marina', 'Bova Marina', 37.9350300, 15.9173600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80793, 'Bovalino Superiore', 'Bovalino Superiore', '', 38.1690500, 16.1584900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80794, 'Bovalino', 'Bovalino', 'Bovalino,Marina di Bovalino', 38.1537600, 16.1723200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80795, 'Botricello', 'Botricello', 'Botricello,Bottricello', 38.9299700, 16.8580100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80796, 'Borgia', 'Borgia', 'Bordzha,Borgia,boruja,bwrjya,Борджа,بورجیا,ボルジャ', 38.8262700, 16.5077000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80797, 'Borgetto', 'Borgetto', 'Borgetto,Lu Burgettu', 38.0466400, 13.1407100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80798, 'Bonifati', 'Bonifati', 'Bonifati', 39.5859500, 15.9016300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80799, 'Bompietro', 'Bompietro', 'Bompietro,Bompietru,Buompietro', 37.7439400, 14.0947000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80800, 'Bompensiere', 'Bompensiere', 'Bampensiere,Bompensiere,Naduri', 37.4724000, 13.7814000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80801, 'Bolognetta', 'Bolognetta', 'Bolognetta,Bulugnetta', 37.9712000, 13.4562700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80802, 'Bocchigliero', 'Bocchigliero', 'Bocchiglicro,Bocchigliero', 39.4193000, 16.7505700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80803, 'Bivongi', 'Bivongi', 'Bivongi', 38.4832800, 16.4525100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80804, 'Bivona', 'Bivona', 'Bivona', 37.6179700, 13.4389500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80805, 'Bisignano', 'Bisignano', 'Bisignano', 39.5072700, 16.2810600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80806, 'Bisacquino', 'Bisacquino', 'Bisacquino,Busacchinu', 37.7035200, 13.2605100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80807, 'Bianco', 'Bianco', 'Bianco', 38.0917000, 16.1515900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80808, 'Bianchi', 'Bianchi', 'Bianchi,bianki,ビアンキ', 39.1005800, 16.4101800, 'IT', '2014-04-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80809, 'Biancavilla', 'Biancavilla', 'Biancavilla', 37.6444200, 14.8668500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80810, 'Benestare', 'Benestare', 'Benestare', 38.1848700, 16.1390000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80811, 'Belvì', 'Belvi', 'Bel''vi,Belvi,Belvinum,Belvì,Brebi,Brebì,Brevie,Brevìe,bei er fu yi,beruvu~i,blwy,Белви,Бельви,Бельві,Բելվի,بلوی,ベルヴィ,贝尔夫伊', 39.9618100, 9.1841900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80812, 'Belvedere', 'Belvedere', 'Belvedere di Siracusa,Belvedete', 37.0883900, 15.2131400, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80813, 'Belvedere Marittimo', 'Belvedere Marittimo', 'Belevedere,Belvedere,Belvedere Marittimo,Marina di Belvedere,ベルヴェデーレ・マリッティモ', 39.6364100, 15.8446300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80814, 'Belvedere Spinello', 'Belvedere Spinello', 'Belvedere,Belvedere Spinello,Belvedere di Spinello', 39.2067400, 16.8923300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80815, 'Belsito', 'Belsito', 'Belsiio,Belsito,berushito,ベルシート', 39.1768500, 16.2874500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80816, 'Belpasso', 'Belpasso', 'Belpasso,Belpassu', 37.5919200, 14.9798500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80817, 'Belmonte Mezzagno', 'Belmonte Mezzagno', 'Belmonte Mezzagno,Belmunti Minzagnu', 38.0465300, 13.3920700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80818, 'Belmonte Calabro', 'Belmonte Calabro', 'Belmonte,Belmonte Calabro,ベルモンテ・カーラブロ', 39.1639800, 16.0821500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80819, 'Baucina', 'Baucina', 'Bauchina,Baucina,bao qi na,bauchina,bawtshyna,Баучина,Բաուչինա,باوتشينا,バウチーナ,包奇纳', 37.9252100, 13.5363600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80820, 'Basicò', 'Basico', 'Basico,Basicò', 38.0607700, 15.0626300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80821, 'Barumini', 'Barumini', 'Barumini,barumini,バルーミニ', 39.7021500, 9.0033800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80822, 'Barrali', 'Barrali', 'Barrali', 39.4753200, 9.1020400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80823, 'Barrafranca', 'Barrafranca', '', 37.3785000, 14.2027000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80824, 'Bari Sardo', 'Bari Sardo', 'Bari Sardo', 39.8413500, 9.6460600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80825, 'Baressa', 'Baressa', 'Baressa', 39.7130800, 8.8745900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80826, 'Barcellona Pozzo di Gotto', 'Barcellona Pozzo di Gotto', 'Barcellona,Barcellona Pozzo di Gotto,Barcillona siciliana', 38.1477200, 15.2146900, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80827, 'Baratili San Pietro', 'Baratili San Pietro', 'Baratili San Pietro', 39.9922000, 8.5558600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80828, 'Baradili', 'Baradili', 'Baradili', 39.7218900, 8.8973100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80829, 'Villa Verde', 'Villa Verde', 'Bannari,Bannari d''Usellus,Bannari di Usellus,Bannari d’Usellus,Villa Verde', 39.7955100, 8.8211400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80830, 'Ballao', 'Ballao', 'Ballao,Ballau', 39.5491900, 9.3617800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80831, 'Balestrate', 'Balestrate', 'Balestrate-Foce', 38.0512500, 13.0072400, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80832, 'Bagnara Calabra', 'Bagnara Calabra', 'Bagnara Calabra,ba na la,巴納拉', 38.2877800, 15.8059100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80833, 'Bagheria', 'Bagheria', 'Bagerija,Bagheria,Багерия', 38.0789200, 13.5123700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80834, 'Bagaladi', 'Bagaladi', 'Bagaladi', 38.0256000, 15.8215200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80835, 'Badolato Marina', 'Badolato Marina', 'Badolato Stazione,Marina Badolato,Marina di Badolato', 38.5761300, 16.5652700, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80836, 'Badolato', 'Badolato', 'Badolato', 38.5686800, 16.5246100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80837, 'Bacu Abis', 'Bacu Abis', 'Bacu Abis,Miniera Bacu Abis,Miniera di Bacu Abis', 39.2430100, 8.4649100, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80838, 'Avola', 'Avola', 'Aebura,Avola,Avula,avu~ora,Àvula,アーヴォラ', 36.9084000, 15.1393700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80839, 'Augusta', 'Augusta', 'Augusta,Austa,augusuta,アウグスタ', 37.2406500, 15.2212100, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80840, 'Atzara', 'Atzara', 'Atzara', 39.9924900, 9.0761600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80841, 'Asuni', 'Asuni', 'Asuni,Asunis,Azuni,Gorad Azuni,a su ni,aswny,azuni,Азуни,Азуні,Горад Азуні,Ազունի,آسونی,アズーニ,阿苏尼', 39.8710100, 8.9460300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80842, 'Assoro', 'Assoro', 'Asaru,Assero,Assoro', 37.6221000, 14.4181000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80843, 'Assolo', 'Assolo', 'Assolo', 39.8091500, 8.9193200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80844, 'Assemini', 'Assemini', 'Assemini,Assèmini,Ассемини', 39.2912300, 8.9987900, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80845, 'Arzana', 'Arzana', 'Arzana', 39.9174200, 9.5276600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80846, 'Armungia', 'Armungia', 'Armungia,Armunja', 39.5215400, 9.3806600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80847, 'Aritzo', 'Aritzo', 'Aritzo', 39.9590300, 9.1926500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80848, 'Argusto', 'Argusto', 'Argusto', 38.6805100, 16.4362700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80849, 'Arena', 'Arena', 'Arena', 38.5623500, 16.2106000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80850, 'Ardore Marina', 'Ardore Marina', '', 38.1666700, 16.2000000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80851, 'Ardore', 'Ardore', 'Ardore,Ardore Superiore', 38.1917300, 16.1673400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80852, 'Arbus', 'Arbus', 'Arbus', 39.5261600, 8.5997000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80853, 'Arborea', 'Arborea', 'Arborea,Arboree,Mussolinia,Mussolinia di Sardegna,Villaggio Mussolini', 39.7727600, 8.5812900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80854, 'Arbatax', 'Arbatax', 'Arbataks,Arbatassa,Arbatax,Arbatax di Tortoli,Àrbatax,Арбатакс', 39.9344400, 9.7055600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80855, 'Aragona', 'Aragona', 'Aragona,Araguna', 37.3990400, 13.6197400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80856, 'Antonimina', 'Antonimina', 'Antonimina', 38.2729800, 16.1482400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80857, 'Antillo', 'Antillo', 'Antillo,Antillu', 37.9793700, 15.2402900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80858, 'Anoia Superiore', 'Anoia Superiore', '', 38.4314400, 16.0974000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80859, 'Anoia Inferiore', 'Anoia Inferiore', 'Anoia', 38.4361800, 16.0794000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80860, 'Andrano', 'Andrano', 'Andrano', 39.9854600, 18.3823200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80861, 'Andali', 'Andali', 'Andali', 39.0128100, 16.7692600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80862, 'Amica', 'Amica', 'Amica,Mica', 39.6008500, 16.6669400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80863, 'Amendolara', 'Amendolara', 'Amendolara,amendorara,アメンドラーラ', 39.9516200, 16.5829300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80864, 'Amato', 'Amato', '', 38.3833300, 16.1333300, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80865, 'Amaroni', 'Amaroni', 'Amaroni', 38.7942400, 16.4480900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80866, 'Amantea', 'Amantea', 'Amantea,amantea,アマンテーア', 39.1265800, 16.0751200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80867, 'Altomonte', 'Altomonte', 'Altomonte,arutomonte,アルトモンテ', 39.6990000, 16.1299900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80868, 'Altofonte', 'Altofonte', 'Altofonte,Parco,Parcu', 38.0429800, 13.2943400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80869, 'Altilia', 'Altilia', 'Altilia,arutiria,アルティーリア', 39.1304900, 16.2526900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80870, 'Altavilla Milicia', 'Altavilla Milicia', 'Altavilla Milicia', 38.0380000, 13.5494700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80871, 'Alliste', 'Alliste', 'Alliste', 39.9480300, 18.0897100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80872, 'Allai', 'Allai', 'Allai', 39.9570100, 8.8635400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80873, 'Aliminusa', 'Aliminusa', 'Aliminusa,Montemaggiore', 37.8639500, 13.7812600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80874, 'Alimena', 'Alimena', 'Alimena', 37.6931000, 14.1136900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80875, 'Alia', 'Alia', 'Alia', 37.7786700, 13.7139100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80876, 'Alì', 'Ali', 'Ali,Ali Superiore,Alì', 38.0267800, 15.4191000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80877, 'Alessano', 'Alessano', 'Alessano', 39.8938100, 18.3322100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80878, 'Alessandria della Rocca', 'Alessandria della Rocca', 'Alessandria della Rocca,Lisciannira di la Rocca,Lisciànnira di la Rocca', 37.5676700, 13.4534300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80879, 'Alessandria del Carretto', 'Alessandria del Carretto', 'Alessandria,Alessandria del Carretto,Alessándria,アレッサンドリア・デル・カッレット', 39.9587400, 16.3796300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80880, 'Ales', 'Ales', 'Abas,Ala,Ales,a lai si,alleseu,alyz  sardynya,aresu,Алес,Ալես,الیز، ساردینیا,アーレス,阿莱斯,알레스', 39.7683000, 8.8152000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80881, 'Alcara Li Fusi', 'Alcara Li Fusi', 'Alcara,Alcara Li Fusi,Alcara li Fusi', 38.0214300, 14.7014200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80882, 'Alcamo', 'Alcamo', 'Al''kamo,Alcamo,Arcamu,Àrcamu,Алькамо', 37.9779000, 12.9647300, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80883, 'Albidona', 'Albidona', 'Albidona,arubidona,アルビドーナ', 39.9233200, 16.4723700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80884, 'Albi', 'Albi', 'Albi', 39.0245600, 16.5972100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80885, 'Aieta', 'Aieta', 'Aieta,Ajeta,aieta,アイエータ', 39.9278000, 15.8234800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80886, 'Aiello Calabro', 'Aiello Calabro', 'Aiello,Aiello Calabro,アイエッロ・カーラブロ', 39.1178500, 16.1653900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80887, 'Aidone', 'Aidone', 'Aidone,Aidoni', 37.4146800, 14.4454200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80888, 'Agrigento', 'Agrigento', 'Agridzentas,Agridzhento,Agridžentas,Agrigent,Agrigente,Agrigento,Agrigentum,Agrixento - Agrigento,Girgenti,QAO,agurijento,Агридженто,אגריג''נטו,アグリジェント', 37.3106500, 13.5766100, 'IT', '2015-07-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80889, 'Agnana Calabra', 'Agnana Calabra', 'Agnana,Agnana Calabra', 38.3020600, 16.2271800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80890, 'Agira', 'Agira', 'Agira,Agurion', 37.6558000, 14.5197200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80891, 'Africo Vecchio', 'Africo Vecchio', '', 38.0666700, 15.9833300, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80892, 'Adrano', 'Adrano', 'Aderno,Adernó,Adrano,Адрано', 37.6635800, 14.8328300, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80893, 'Acri', 'Acri', 'Acri,Akri,akuri,Акри,アクリ', 39.4962400, 16.3863500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80894, 'Acquedolci', 'Acquedolci', '', 38.0570800, 14.5855000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80895, 'Acquaviva Platani', 'Acquaviva Platani', 'Acquaviva Platani,Acquaviva Plàtani', 37.5717400, 13.7015600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80896, 'Acquaro', 'Acquaro', 'Acquaro,Acquaru,Akkuaro,Akuaro,Akvaro,Aquarium,a kua luo,akkuaro,akwarw,Акваро,Аккуаро,Акуаро,Աքուարո,اکوارو,アックアーロ,阿夸罗', 38.5572900, 16.1878100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80897, 'Acquarica del Capo', 'Acquarica del Capo', 'Acquarica,Acquarica del Capo', 39.9097900, 18.2468000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80898, 'Acquappesa', 'Acquappesa', 'Acquappesa,Acquappessa,akkuappeza,アックアッペーザ', 39.4957300, 15.9541900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80899, 'Acquaformosa', 'Acquaformosa', 'Acquaformosa,Firmoza,akkuaforumoza,アックアフォルモーザ', 39.7227800, 16.0909600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80900, 'Aci Sant''Antonio', 'Aci Sant''Antonio', 'Aci Sant''Antonio,Jaci Sant''Antoniu', 37.6049900, 15.1229400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80901, 'Acireale', 'Acireale', '', 37.6088600, 15.1657700, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80902, 'Aci Catena', 'Aci Catena', 'Aci Catena,Jaci Catena', 37.6061400, 15.1416500, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80903, 'Aci Castello', 'Aci Castello', 'Aci Castello,Jaci Casteddu', 37.5556400, 15.1453500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80904, 'Aci Bonaccorsi', 'Aci Bonaccorsi', 'Aci Bonaccorsi,Aci Buonaccorsi,Jaci Bonaccossi', 37.5964000, 15.1072400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80905, 'Acate', 'Acate', 'Biscari,Vischiri', 37.0231800, 14.4930200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80906, 'Olia Speciosa', 'Olia Speciosa', '', 39.2780600, 9.5250000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80907, 'Santa Maria Navarrese', 'Santa Maria Navarrese', 'Santa Maria Navarrese', 39.9902900, 9.6839800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80908, 'Cardedu', 'Cardedu', 'Cardedu', 39.7971400, 9.6265200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80909, 'Siurgus Donigala', 'Siurgus Donigala', 'Siurgus Donigala', 39.5996100, 9.1874600, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80910, 'Volpago del Montello', 'Volpago del Montello', 'Volpago,Volpago del Montello', 45.7777000, 12.1185700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80911, 'Granarolo dell''Emilia e Viadagola', 'Granarolo dell''Emilia e Viadagola', 'Granarolo', 44.5532700, 11.4429100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80912, 'Zungoli', 'Zungoli', 'Zungoli', 41.1276600, 15.2025500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80913, 'Zuglio', 'Zuglio', 'Zuglio,Zui', 46.4583000, 13.0258900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80914, 'Zuccarello', 'Zuccarello', 'Sucare,Sucarê,Zuccarello,Zuccarrello', 44.1097300, 8.1181400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80915, 'Zovencedo', 'Zovencedo', 'Zovencedo', 45.4289300, 11.5038700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80916, 'Zoppola', 'Zoppola', 'Copule,Zoppola', 45.9662400, 12.7682800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80917, 'Zollino', 'Zollino', 'Tzuddhino,Zollino', 40.2058100, 18.2477400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80918, 'Zolla', 'Zolla', 'Col,Monrupino,Repentabor,Zolla,Zolla Monrupino,Zolla di Monrupino', 45.7169800, 13.8103800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80919, 'Zola Predosa', 'Zola Predosa', 'Zola', 44.4896700, 11.2183100, 'IT', '2016-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80920, 'Zogno', 'Zogno', 'Zogno', 45.7937800, 9.6599200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80921, 'Zocca', 'Zocca', '', 44.3456600, 10.9930800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80922, 'Zoagli', 'Zoagli', 'Zoaggi,Zoagli', 44.3366800, 9.2668000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80923, 'Zinasco Vecchio', 'Zinasco Vecchio', 'Zinasco', 45.1283600, 9.0297500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80924, 'Zimone', 'Zimone', 'Zimone', 45.4491200, 8.0373400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80925, 'Zibido San Giacomo', 'Zibido San Giacomo', 'Zibido San Giacomo,ジービド・サン・ジャコモ', 45.3604100, 9.1111900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80926, 'Zibello', 'Zibello', 'Zibello,jiberro,ジベッロ', 45.0184700, 10.1296800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80927, 'Ziano Piacentino', 'Ziano Piacentino', 'Ziano,Ziano Piacentino', 44.9998000, 9.3948600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80928, 'Ziano di Fiemme', 'Ziano di Fiemme', 'Ziano di Fiemme,ジアーノ・ディ・フィエンメ', 46.2857200, 11.5649600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80929, 'Panchià', 'Panchia', 'Panchia,Panchia Ziano,Panchià,Panchià Ziano,pankia,パンキア', 46.2864800, 11.5406100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80930, 'Zevio', 'Zevio', 'Zevio', 45.3720900, 11.1292900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80931, 'Zero Branco', 'Zero Branco', 'Zero Branco', 45.5995200, 12.1638100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80932, 'Zermeghedo', 'Zermeghedo', 'Zermeghedo', 45.4758500, 11.3743800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80933, 'Zerbolò', 'Zerbolo', 'Zerbolo,Zerbolò', 45.2067600, 9.0144100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80934, 'Zerbo', 'Zerbo', 'Zerbo', 45.1104600, 9.3960600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80935, 'Zepponami', 'Zepponami', '', 42.5251800, 12.0541100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80936, 'Zenson di Piave', 'Zenson di Piave', 'Zenson,Zenson di Piave,Zenzon di Piave', 45.6797100, 12.4891300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80937, 'Zeme', 'Zeme', '', 45.1968600, 8.6673300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80938, 'Zelo Buon Persico', 'Zelo Buon Persico', 'Zelo Buon Persico,ゼーロ・ブオン・ペルシコ', 45.4117000, 9.4317100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80939, 'Zelarino', 'Zelarino', '', 45.5150800, 12.2079000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80940, 'Zavattarello', 'Zavattarello', 'Zavattarello,Zavattarello-Valverde', 44.8676600, 9.2666200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80941, 'Zapponeta', 'Zapponeta', 'Zapponeta,Zapponete,Zapponétë', 41.4571000, 15.9561500, 'IT', '2017-01-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80942, 'Zanica', 'Zanica', 'Zanica', 45.6408800, 9.6856600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80943, 'Zanè', 'Zane', 'Zane,Zanè', 45.7220000, 11.4493200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80944, 'Zandobbio', 'Zandobbio', 'Zandobbio', 45.6861300, 9.8578500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80945, 'Zambana', 'Zambana', 'Cambana,Dzambana,Jambana,Zambana,zan ba na,zanbana,Дзамбана,Цамбана,Ձամբանա,ザンバーナ,赞巴纳', 46.1517000, 11.0961800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80946, 'Zagarolo', 'Zagarolo', 'Zagarolo,zagarolo,zagaroro,ザガローロ', 41.8415900, 12.8154000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80947, 'Volvera', 'Volvera', 'Volvera,vu~oruvu~era,ヴォルヴェーラ', 44.9548400, 7.5114200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80948, 'Volturino', 'Volturino', 'Volturino', 41.4772300, 15.1242400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80949, 'Volturara Irpina', 'Volturara Irpina', 'Volturara Irpina', 40.8829300, 14.9180100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80950, 'Volturara Appula', 'Volturara Appula', 'Volturara Appula', 41.4960300, 15.0522400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80951, 'Voltido', 'Voltido', 'Voltido', 45.1119700, 10.3329800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80952, 'Volterra', 'Volterra', 'Vol''terra,Volterra,Вольтерра', 43.4025100, 10.8615200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80953, 'Voltana', 'Voltana', 'Il Casino,Voltana', 44.5410900, 11.9353300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80954, 'Volta Mantovana', 'Volta Mantovana', 'Volta Mantovana,ヴォルタ・マントヴァーナ', 45.3219200, 10.6589100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80955, 'Voltago Agordino', 'Voltago Agordino', '', 46.2713900, 12.0057400, 'IT', '2013-02-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80956, 'Voltaggio', 'Voltaggio', 'Voltaggio', 44.6209500, 8.8427400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80957, 'Volpiano', 'Volpiano', 'Volpian,Volpiano,vu~orupyano,ヴォルピャーノ', 45.1994000, 7.7754600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80958, 'Volpedo', 'Volpedo', 'Volpedo', 44.8888700, 8.9861500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80959, 'Volpara', 'Volpara', 'Volpara', 44.9537900, 9.2975000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80960, 'Volongo', 'Volongo', 'Volongo', 45.2115500, 10.3024200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80961, 'Volargne', 'Volargne', '', 45.5368400, 10.8182000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80962, 'Volano', 'Volano', 'Volano,vu~orano,ヴォラーノ', 45.9171800, 11.0635100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80963, 'Vogogna', 'Vogogna', 'Vogogna', 46.0100200, 8.2913700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80964, 'Voghera', 'Voghera', 'Iria,Vogera,Voghera,vu~ogera,Вогера,ヴォゲーラ', 44.9915100, 9.0117500, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80965, 'Vodo', 'Vodo', 'Vodo,Vodo Cadore,Vodo di Cadore', 46.4192100, 12.2455700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80966, 'Vobbia', 'Vobbia', 'Obbia,Vobbia', 44.6012500, 9.0386600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80967, 'Vobarno', 'Vobarno', 'Vobarno,vu~obaruno,ヴォバルノ', 45.6415300, 10.4986600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80968, 'Vizzola Ticino', 'Vizzola Ticino', 'Vizzola,Vizzola Ticino', 45.6261500, 8.6965100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80969, 'Vivaro Romano', 'Vivaro Romano', 'Vivaro Romano,ヴィヴァーロ・ロマーノ', 42.1009500, 13.0058900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80970, 'Vivaro', 'Vivaro', 'Vivar,Vivaro', 46.0765600, 12.7791200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80971, 'Viù', 'Viu', 'Viu,Viù,vu~iu,ヴィウ', 45.2378500, 7.3733300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80972, 'Vitulazio', 'Vitulazio', 'Vitulazio', 41.1630200, 14.2134100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80973, 'Vitulano', 'Vitulano', 'Vitulano', 41.1741900, 14.6482100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80974, 'Vittuone', 'Vittuone', 'Vittuone,vu~itto~uone,ヴィットゥオーネ', 45.4879200, 8.9514100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80975, 'Vittorito', 'Vittorito', 'Vittorito', 42.1270300, 13.8167000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80976, 'Vittorio Veneto', 'Vittorio Veneto', 'Vitorio,Vittorio,Vittorio Veneto,Vittorio-Veneto,Vitòrio,Витторио-Венето,ヴィットリオ・ヴェネト', 45.9802600, 12.3006500, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80977, 'Vitorchiano', 'Vitorchiano', '', 42.4656500, 12.1715100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80978, 'Vitigliano', 'Vitigliano', '', 40.0395100, 18.4117000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80979, 'Viticuso', 'Viticuso', 'Viticuso', 41.5247500, 13.9702700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80980, 'Viterbo', 'Viterbo', 'Viterbe,Viterbium,Viterbo,vu~iterubo,Витербо,ヴィテルボ', 42.4193700, 12.1056000, 'IT', '2015-07-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80981, 'Vistrorio', 'Vistrorio', 'Vistrorio,vu~isutororio,ヴィストローリオ', 45.4414700, 7.7678100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80982, 'Visso', 'Visso', '', 42.9335100, 13.0805100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80983, 'Visciano', 'Visciano', 'Visciano,vu~ishano,ヴィシャーノ', 40.9238000, 14.5823700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80984, 'Visano', 'Visano', 'Visano,vu~izano,ヴィザーノ', 45.3168400, 10.3709200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80985, 'Virle Piemonte', 'Virle Piemonte', 'Virle Piemonte,ヴィルレ・ピエモンテ', 44.8636900, 7.5703300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80986, 'Vipiteno', 'Vipiteno', 'Shtercing,Stearzing,Sterzing,Vipiteno,Vipitenum,vu~ipiteno,wei pi tai nuo,Βιπιτένο,Випитено,Віпітено,Штерцинг,Վիպիտենո,ヴィピテーノ,维皮泰诺', 46.8931300, 11.4296100, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80987, 'Vione', 'Vione', 'Vione,vu~ione,ヴィオーネ', 46.2480800, 10.4484200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80988, 'Viola', 'Viola', 'Viola', 44.2908100, 7.9649100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80989, 'Vinzaglio', 'Vinzaglio', 'Vinzaglio', 45.3230900, 8.5197900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80990, 'Vinci', 'Vinci', 'Vinchi,Vinci,Vincis,Vinčis,binchi,fen qi,fynshy,vinchi,vu~inchi,wynchy,wynzy,Винчи,Вінчі,Վինչի,וינצי,فينشي,ونچی، تسکانہ,وینچی,ვინჩი,ヴィンチ,芬奇,빈치', 43.7813300, 10.9236500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80991, 'Vinchiaturo', 'Vinchiaturo', 'Vinchiaturo', 41.4928200, 14.5920000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80992, 'Vinadio', 'Vinadio', 'Vinadio,vinadio,Винадио', 44.3075900, 7.1762800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80993, 'Vimodrone', 'Vimodrone', 'Vimodrone,vu~imodorone,ヴィモドローネ', 45.5146100, 9.2877200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80994, 'Vimercate', 'Vimercate', 'Vicus Mercati,Vimercate,Vimerkate,vu~imerukate,Вимеркате,ヴィメルカーテ', 45.6154500, 9.3680100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80995, 'Villotta', 'Villotta', 'Villota,Villotta,Villotta di Chions,Villutta', 45.8633600, 12.7541800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80996, 'Lancenigo-Villorba', 'Lancenigo-Villorba', 'Villorba', 45.7128900, 12.2569700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80997, 'Villongo', 'Villongo', 'Villongo', 45.6693900, 9.9307600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80998, 'Villimpenta', 'Villimpenta', 'Villimpenta', 45.1411100, 11.0317000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(80999, 'Villetta Barrea', 'Villetta Barrea', 'Villetta Barrea', 41.7764600, 13.9389200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81000, 'Villesse', 'Villesse', 'Viles,Villesse', 45.8652600, 13.4438000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81001, 'Villefranche', 'Villefranche', '', 45.7406400, 7.4159800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81002, 'Villa Vicentina', 'Villa Vicentina', 'Vile Visintine,Villa Vicentina', 45.8137800, 13.3933200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81003, 'Villa Verucchio', 'Villa Verucchio', 'La Villa', 44.0051000, 12.4357500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81004, 'Villaverla', 'Villaverla', 'Villaverla', 45.6493900, 11.4917600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81005, 'Vergano-Villa', 'Vergano-Villa', 'Vergano,Villa Vergano', 45.7941600, 9.3746000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81006, 'Villavallelonga', 'Villavallelonga', 'Villavallelonga', 41.8710400, 13.6208800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81007, 'Villata', 'Villata', 'La Vilata,Villata', 45.3865000, 8.4327900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81008, 'Villastellone', 'Villastellone', 'Villastellone,vu~irrasuterrone,ヴィッラステッローネ', 44.9220100, 7.7436000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81009, 'Villa Santo Stefano', 'Villa Santo Stefano', 'Villa Santo Stefano', 41.5168300, 13.3104600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81010, 'Villa Santina', 'Villa Santina', 'Vile Santine,Villa Santina', 46.4136800, 12.9244500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81011, 'Villa Santa Maria', 'Villa Santa Maria', 'Villa Santa Maria', 41.9513000, 14.3514800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81012, 'Villa Santa Lucia degli Abruzzi', 'Villa Santa Lucia degli Abruzzi', 'Villa Santa Lucia degli Abruzzi', 42.3328600, 13.7779200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81013, 'Villa Santa Lucia', 'Villa Santa Lucia', 'Villa Santa Lucia', 41.5121700, 13.7692900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81014, 'Villasanta', 'Villasanta', 'Santa,Villasanta,vu~irrasanta,ヴィッラサンタ', 45.6063400, 9.3079700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81015, 'Villa San Secondo', 'Villa San Secondo', 'Vila San Sgond,Villa San Secondo', 45.0051300, 8.1346200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81016, 'Villar Perosa', 'Villar Perosa', 'Villa Perosa,Villar Perosa,ヴィッラール・ペローザ', 44.9184900, 7.2482100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81017, 'Villar Pellice', 'Villar Pellice', 'Villar Pellice,ヴィッラール・ペッリチェ', 44.8089300, 7.1597800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81018, 'Villarotta', 'Villarotta', '', 44.9251700, 10.7438200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81019, 'Villaricca', 'Villaricca', 'Villaricca,Villarikka,vu~irrarikka,Вилларикка,ヴィッラリッカ', 40.9200600, 14.1933900, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81020, 'Villar Focchiardo', 'Villar Focchiardo', 'Villar Focchiardo,ヴィッラール・フォッキアルド', 45.1124400, 7.2384100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81021, 'Villareggia', 'Villareggia', 'Villareggia,vu~irrarejja,ヴィッラレッジャ', 45.3088500, 7.9772400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81022, 'Villarboit', 'Villarboit', 'Villarboit', 45.4377500, 8.3369400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81023, 'Villa Potenza', 'Villa Potenza', '', 43.3214900, 13.4264900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81024, 'Villa Pedergnano', 'Villa Pedergnano', 'Pedergnano,Villa Pedergnano', 45.5852800, 9.9938100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81025, 'Villanuova sul Clisi', 'Villanuova sul Clisi', 'Villanuova sul Clisi,ヴィッラヌオーヴァ・スル・クリージ', 45.5993800, 10.4527500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81026, 'Villanterio', 'Villanterio', 'Villanterio', 45.2178000, 9.3610000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81027, 'Villanova', 'Villanova', 'Villanova', 45.0259700, 9.9986500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81028, 'Villanova Monteleone', 'Villanova Monteleone', 'Villanova Monteleone', 40.5026400, 8.4711500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81029, 'Villanova Monferrato', 'Villanova Monferrato', 'Vilaneuva Monfra,Vilaneuva Monfrà,Villanova,Villanova Monferrato', 45.1811100, 8.4781300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81030, 'Villanova Mondovì', 'Villanova Mondovi', 'Villanova,Villanova Mondovi,Villanova Mondovì', 44.3480400, 7.7675200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81031, 'Villanova Marchesana', 'Villanova Marchesana', 'Villanova', 44.9923100, 11.9667500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81032, 'Villanova del Battista', 'Villanova del Battista', 'Villanova del Battista', 41.1189700, 15.1583900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81033, 'Villanova d''Asti', 'Villanova d''Asti', 'Vilaneuva d''Ast,Villanova d''Asti,Villanuova d''Asti', 44.9429900, 7.9367100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81034, 'Villanova d''Ardenghi', 'Villanova d''Ardenghi', 'Villanova d''Ardenghi', 45.1704900, 9.0407800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81035, 'Villanova d''Albenga', 'Villanova d''Albenga', 'Villanova,Villanova d''Albenga', 44.0472500, 8.1433600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81036, 'Villanova', 'Villanova', '', 46.1322600, 12.9708400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81037, 'Villanova', 'Villanova', 'Villanova,Villanuova', 44.4999500, 11.4310900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81038, 'Villanova', 'Villanova', '', 44.4480000, 12.0500700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81039, 'Villammare', 'Villammare', 'Villamare,Villammare', 40.0774700, 15.5940100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81040, 'Villa Minozzo', 'Villa Minozzo', '', 44.3648000, 10.4654500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81041, 'Villamarzana', 'Villamarzana', '', 45.0145700, 11.6922500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81042, 'Villamaina', 'Villamaina', 'Villamaina', 40.9714400, 15.0885500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81043, 'Villamagna', 'Villamagna', 'Villamagna', 42.3298400, 14.2368900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81044, 'Villalvernia', 'Villalvernia', 'Villaivernia,Villalvernia', 44.8138700, 8.8553200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81045, 'Villa Literno', 'Villa Literno', 'Villa Literno', 41.0094200, 14.0761200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81046, 'Villalfonsina', 'Villalfonsina', 'Villalfonsina', 42.1603800, 14.5693200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81047, 'Villa Latina', 'Villa Latina', 'Villa Latina', 41.6152200, 13.8359100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81048, 'Villalago', 'Villalago', 'Villalago', 41.9351400, 13.8386800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81049, 'Villa Lagarina', 'Villa Lagarina', 'Villa Lagarina,ヴィッラ・ラガリーナ', 45.9184300, 11.0330300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81050, 'Villa Guardia', 'Villa Guardia', 'Villa Guardia', 45.7750500, 9.0232100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81051, 'Villaganzerla', 'Villaganzerla', '', 45.4361200, 11.6185900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81052, 'Villaga', 'Villaga', 'Villaga', 45.4027300, 11.5346800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81053, 'Villafranca Piemonte', 'Villafranca Piemonte', 'Villafranca,Villafranca Piemonte,Villafranca Sabauda,ヴィッラフランカ・ピエモンテ', 44.7882400, 7.5078800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81054, 'Villafranca in Lunigiana', 'Villafranca in Lunigiana', 'Villafranca,Villafranca Lunigiana,Villafranca in Lunigiana,ヴィッラフランカ・イン・ルニジャーナ', 44.2984400, 9.9534700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81055, 'Villafranca di Verona', 'Villafranca di Verona', 'Villafranca di Verona,ヴィッラフランカ・ディ・ヴェローナ', 45.3540500, 10.8446200, 'IT', '2015-06-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81056, 'Villafranca d''Asti', 'Villafranca d''Asti', 'Vilafranca d''Ast,Villafranca,Villafranca d''Asti', 44.9153900, 8.0265800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81057, 'Villa Faraldi', 'Villa Faraldi', 'A Vila Faraodi,Villa Faraldi', 43.9684300, 8.0896500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81058, 'Villafalletto', 'Villafalletto', 'Villafalletto', 44.5462400, 7.5406900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81059, 'Villa Estense', 'Villa Estense', '', 45.1746500, 11.6702200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81060, 'Villadossola', 'Villadossola', 'Villa,Villadossola', 46.0708000, 8.2670900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81061, 'Villadose', 'Villadose', 'Viladose,Villadose,Viładose', 45.0721900, 11.8989900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81062, 'Villa', 'Villa', 'Villa di Tirano', 46.2039000, 10.1338500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81063, 'Villa di Serio', 'Villa di Serio', 'Serio,Villa di Serio', 45.7226000, 9.7352200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81064, 'Villa di Chiavenna', 'Villa di Chiavenna', 'Villa Chiavenna,Villa di Chiavenna', 46.3306900, 9.4811400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81065, 'Villa del Conte', 'Villa del Conte', '', 45.5847500, 11.8594200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81066, 'Villa del Bosco', 'Villa del Bosco', 'Villa del Bosco', 45.6166900, 8.2777600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81067, 'Villa d''Almè', 'Villa d''Alme', 'Ela,Villa d''Alme,Villa d''Almè,Éla', 45.7484300, 9.6170200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81068, 'Villa Cortese', 'Villa Cortese', 'Villa Cortese,ヴィッラ・コルテーゼ', 45.5666600, 8.8871200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81069, 'Villachiara', 'Villachiara', 'Villachiara,vu~irrakiara,ヴィッラキアーラ', 45.3544500, 9.9308100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81070, 'Villa Celiera', 'Villa Celiera', 'Villa Celiera', 42.3818400, 13.8586000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81071, 'Villa Castelli', 'Villa Castelli', 'Villa Castelli', 40.5829300, 17.4746800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81072, 'Villa Caldari', 'Villa Caldari', 'Villa Caldari', 42.2956600, 14.3615700, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81073, 'Villabruna-Umin', 'Villabruna-Umin', '', 46.0567500, 11.9270000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81074, 'Villabassa', 'Villabassa', 'Niederdorf,Vilabasa,Villa Ima,Villabassa,vu~irrabassa,wei la ba sa,Виллабасса,Вілабаса,Віллабасса,ヴィッラバッサ,维拉巴萨', 46.7378100, 12.1726600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81075, 'Villa Basilica', 'Villa Basilica', 'Vila Bazilika,Vila-Bazilika,Villa Basilica,Villa Basílica,Villa Bazilika,Villa-Bazilika,wei la ba xi li ka,Вила Базилика,Вилла-Базилика,Віла-Базіліка,Вілла-Базіліка,Վիլլա Բազիլիկա,ヴィッラ・バジーリカ,维拉巴西利卡', 43.9257200, 10.6451800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81076, 'Villa Bartolomea', 'Villa Bartolomea', 'Villa Bartolomea', 45.1546100, 11.3538000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81077, 'Villa', 'Villa', '', 45.7182400, 10.2790600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81078, 'Villa Carcina', 'Villa Carcina', '', 45.6332900, 10.1955600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81079, 'Viguzzolo', 'Viguzzolo', 'Viguzzolo', 44.9056700, 8.9196800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81080, 'Vigonza', 'Vigonza', '', 45.4348400, 11.9746500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81081, 'Vigonovo-Fontanafredda', 'Vigonovo-Fontanafredda', '', 45.9892700, 12.5470700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81082, 'Vigonovo', 'Vigonovo', 'Vigonovo', 45.3869100, 12.0064200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81083, 'Vigone', 'Vigone', 'Vigon,Vigone,vu~igone,ヴィゴーネ', 44.8423600, 7.4977400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81084, 'Vigolzone', 'Vigolzone', '', 44.9139400, 9.6685200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81085, 'Vigolo Vattaro', 'Vigolo Vattaro', 'Vigolo Vattaro,ヴィゴーロ・ヴァッターロ', 46.0052300, 11.1979000, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81086, 'Vigolo', 'Vigolo', 'Vigolo', 45.7164200, 10.0263400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81087, 'Vigo di Fassa', 'Vigo di Fassa', 'Vigo di Fassa,ヴィーゴ・ディ・ファッサ', 46.4189800, 11.6741800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81088, 'Vigo di Cadore', 'Vigo di Cadore', 'Vigo di Cadore', 46.4990400, 12.4711100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81089, 'Vigodarzere', 'Vigodarzere', 'Vigodarzere', 45.4575100, 11.8855500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81090, 'Vignolo', 'Vignolo', 'Vignolo', 44.3636400, 7.4720800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81091, 'Vignola', 'Vignola', '', 46.0443600, 11.2773800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81092, 'Vignola', 'Vignola', 'Vignola,Viynola', 44.4838300, 11.0109600, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81093, 'Vignate', 'Vignate', 'Vignate,vu~inyate,ヴィニャーテ', 45.4993900, 9.3771900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81094, 'Vignanello', 'Vignanello', 'Vignanello', 42.3787900, 12.2784500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81095, 'Vignale Monferrato', 'Vignale Monferrato', '', 45.0099600, 8.3970300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81096, 'Vignacastrisi', 'Vignacastrisi', 'Vignacastrisi,Villacastrisi', 40.0160400, 18.4070400, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81097, 'Vigliano Biellese', 'Vigliano Biellese', 'Vigliano Biellese', 45.5631700, 8.1050900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81098, 'Viggiù', 'Viggiu', 'Viggiu,Viggiù', 45.8709600, 8.9086100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81099, 'Viggiano', 'Viggiano', '', 40.3421300, 15.8996400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81100, 'Vigevano', 'Vigevano', 'Vidzhevano,Vigebanum,Vigevano,vu~ijevu~ano,Виджевано,ヴィジェーヴァノ', 45.3140700, 8.8543700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81101, 'Vigatto', 'Vigatto', '', 44.7199900, 10.3303700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81102, 'Vigasio', 'Vigasio', 'Vigasio', 45.3178000, 10.9437100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81103, 'Vigarano Pieve', 'Vigarano Pieve', 'Vigarano,Vigarano Pieve', 44.8612600, 11.5095000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81104, 'Vigarano Mainarda', 'Vigarano Mainarda', 'Vigarano,Vigarano Mainarda,ヴィガラーノ・マイナルダ', 44.8407900, 11.4935400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81105, 'Vietri sul Mare', 'Vietri sul Mare', 'Vietri sul Mare,Виетри сул Маре', 40.6702000, 14.7266100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81106, 'Vietri di Potenza', 'Vietri di Potenza', 'Vietri di Potenza', 40.6002700, 15.5078700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81107, 'Vieste', 'Vieste', 'VIF,Vieste', 41.8820900, 16.1713900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81108, 'Vidor', 'Vidor', 'Vidor,vu~idoru,ヴィドール', 45.8665900, 12.0451700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81109, 'Vidigulfo', 'Vidigulfo', 'Vidigulfo', 45.2924500, 9.2349800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81110, 'Vicovaro', 'Vicovaro', 'Vicovaro,Vicovaru,Vicus Varronis,Vikovaro,bikobalo,vu~ikovu~aro,wei ke wa luo,Виковаро,Віковаро,Վիկովարո,ヴィコヴァーロ,维科瓦罗,비코바로', 42.0192400, 12.9000100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81111, 'Vicopisano', 'Vicopisano', 'Vicopis,Vicopisano', 43.6930500, 10.5835900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81112, 'Vico nel Lazio', 'Vico nel Lazio', '', 41.7782200, 13.3427900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81113, 'Vicomoscano', 'Vicomoscano', '', 44.9747600, 10.4504500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81114, 'Vicolungo', 'Vicolungo', 'Vicolungo', 45.4752200, 8.4612400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81115, 'Vicoli', 'Vicoli', 'Vicoli', 42.3409500, 13.8968800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81116, 'Vicofertile', 'Vicofertile', '', 44.7855700, 10.2620000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81117, 'Vico Equense', 'Vico Equense', 'Vico Equense,ヴィーコ・エクエンセ', 40.6597700, 14.4338600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81118, 'Vico del Gargano', 'Vico del Gargano', 'Vico Garganico,Vico del Gargano', 41.8966100, 15.9568200, 'IT', '2015-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81119, 'Vico Canavese', 'Vico Canavese', 'Vico Canavese,ヴィーコ・カナヴェーゼ', 45.4934200, 7.7788700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81120, 'Viciomaggio', 'Viciomaggio', '', 43.4321800, 11.7732300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81121, 'Vicenza', 'Vicenza', 'VIC,Vicence,Vicenza,Vicenzsa,Vicetia,Vichenca,vu~ichentsu~a,Виченца,ヴィチェンツァ', 45.5467200, 11.5475000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81122, 'Vicchio', 'Vicchio', 'Vicchio', 43.9341300, 11.4600400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81123, 'Vicarello', 'Vicarello', '', 43.6123800, 10.4651500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81124, 'Vicalvi', 'Vicalvi', '', 41.6780900, 13.7081300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81125, 'Vibonati', 'Vibonati', 'Vibonati', 40.0992100, 15.5835700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81126, 'Viareggio', 'Viareggio', 'Viaredzhio,Viareggio,Viareggiu,vu~iarejjo,Виареджио,ヴィアレッジョ', 43.8669300, 10.2502000, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81127, 'Viano', 'Viano', '', 44.5451600, 10.6243500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81128, 'Viadana', 'Viadana', 'Viadana,Viadena', 44.9355300, 10.5189800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81129, 'Vezzano sul Crostolo', 'Vezzano sul Crostolo', 'Vezzano', 44.6024100, 10.5446900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81130, 'Vezzano Ligure', 'Vezzano Ligure', 'Vessan Ligure,Vezzano,Vezzano Ligure', 44.1414400, 9.8869200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81131, 'Vezzano', 'Vezzano', 'Vezzano,Vezzano di Trento,vu~ettsu~ano,ヴェッツァーノ', 46.0786700, 10.9973500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81132, 'Vezza d''Oglio', 'Vezza d''Oglio', 'Vezza,Vezza d''Oglio,veca d''ol''o,Веца д''Ольо', 46.2386700, 10.3982500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81133, 'Vetto', 'Vetto', '', 44.4840700, 10.3388200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81134, 'Vetralla', 'Vetralla', 'Vetralla,vu~etorarra,ヴェトラッラ', 42.3178700, 12.0732300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81135, 'Vestone', 'Vestone', 'Vestone', 45.7078300, 10.3961100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81136, 'Vestignè', 'Vestigne', 'Vestigne,Vestignè,vu~esutinye,ヴェスティニェ', 45.3865500, 7.9533600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81137, 'Vestenanova', 'Vestenanova', 'Vestenanova', 45.5742100, 11.2286800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81138, 'Vessalico', 'Vessalico', 'Vesarco,Vessalico', 44.0455900, 7.9601300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81139, 'Vespolate', 'Vespolate', 'Vespolate', 45.3495300, 8.6687800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81140, 'Vesime', 'Vesime', 'Vesime,Vesme', 44.6353500, 8.2268300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81141, 'Vescovato', 'Vescovato', 'Vescovato', 45.1741900, 10.1645100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81142, 'Vescovana', 'Vescovana', 'Vescovana,Vescovanum,Veskovana,vu~esukovu~ana,wei si ke wa na,Вескована,Վեսկովանա,ヴェスコヴァーナ,韦斯科瓦纳', 45.1342200, 11.7126100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81143, 'Verzuolo', 'Verzuolo', 'Verzuolo', 44.5927900, 7.4816400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81144, 'Vervò', 'Vervo', 'Vervo,Vervò,vu~eruvu~o,ヴェルヴォ', 46.3098900, 11.1197200, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81145, 'Verucchio', 'Verucchio', 'Verucchio', 43.9817100, 12.4231700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81146, 'Vertova', 'Vertova', 'Vertova', 45.8100000, 9.8494400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81147, 'Vertemate Con Minoprio', 'Vertemate Con Minoprio', 'Vertemate Minoprio,Vertemate con Minoprio', 45.7251800, 9.0730000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81148, 'Verrone', 'Verrone', 'Verrone', 45.5082400, 8.1151400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81149, 'Verres', 'Verres', 'Castel Verres,Castel Verrès,Verres,Verrès', 45.6665600, 7.6891100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81150, 'Veronella', 'Veronella', 'Veronella', 45.3237800, 11.3258200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81151, 'Verona', 'Verona', 'VRN,Verona,Verone,Vérone,Werona,belona,fyrwna,verona,vu~erona,wei luo na,wrwna,wrwnh,Верона,ורונה,فيرونا,ورونا,वेरोना,ヴェローナ,维罗纳,베로나', 45.4299000, 10.9844400, 'IT', '2017-06-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81152, 'Veroli', 'Veroli', 'Veroli', 41.6943300, 13.4166400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81153, 'Verolengo', 'Verolengo', 'Verolengo,vu~erorengo,ヴェロレンゴ', 45.1904000, 7.9712600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81154, 'Verolavecchia', 'Verolavecchia', 'Verolavecchia', 45.3286200, 10.0549300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81155, 'Verolanuova', 'Verolanuova', 'Veralanuova,Verolanuova', 45.3283400, 10.0785700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81156, 'Vernole', 'Vernole', 'Vernole', 40.2883400, 18.3016500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81157, 'Vernio', 'Vernio', 'Vernio,vu~erunio,ヴェルニオ', 44.0475500, 11.1505200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81158, 'Vernazza', 'Vernazza', 'Vernassa,Vernazza,vu~erunattsu~a,ヴェルナッツァ', 44.1350100, 9.6834600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81159, 'Vernate', 'Vernate', 'Vernate,vu~erunate,ヴェルナーテ', 45.3158900, 9.0604500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81160, 'Vernasca', 'Vernasca', '', 44.7986700, 9.8305400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81161, 'Vernante', 'Vernante', 'Vernant,Vernante', 44.2444700, 7.5345500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81162, 'Vermiglio', 'Vermiglio', 'Vermiglio,vu~erumirio,ヴェルミーリオ', 46.2969100, 10.6913600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81163, 'Vermezzo', 'Vermezzo', 'Vermecco,Vermeco,Vermetium,Vermezz,Vermezzo,vu~erumettsu~o,wei er mei zuo,wrmzw,Вермецо,Вермеццо,Վերմեցո,ورمزو,ヴェルメッツォ,韦尔梅佐', 45.3962700, 8.9790400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81164, 'Vergiate', 'Vergiate', 'Vergiate,Verigate', 45.7221000, 8.6953000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81165, 'Verghereto', 'Verghereto', '', 43.7945000, 12.0052000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81166, 'Vergato', 'Vergato', 'Vergato', 44.2823200, 11.1095300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81167, 'Verdello', 'Verdello', 'Verdello', 45.6037200, 9.6285200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81168, 'Vercurago', 'Vercurago', 'Vercurago', 45.8094300, 9.4221100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81169, 'Vercelli', 'Vercelli', 'Verceil,Vercellae,Vercelli,Verchelli,Vercèlli,vu~erucherri,Верчелли,ヴェルチェッリ', 45.3216300, 8.4198900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81170, 'Verceia', 'Verceia', 'Verceia', 46.1986900, 9.4547400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81171, 'Venzone', 'Venzone', 'Vencon,Venzone,Vençon', 46.3303100, 13.1382500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81172, 'Venturina', 'Venturina', '', 43.0288300, 10.6014700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81173, 'Ventotene', 'Ventotene', 'Ventotene,vu~entotene,ヴェントテーネ', 40.7940400, 13.4277700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81174, 'Ventoso', 'Ventoso', '', 44.5862100, 10.6876700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81175, 'Ventimiglia', 'Ventimiglia', 'Albintimilium,Ventemiglia,Ventemilha,Ventimiglia,Ventimil''ja,Ventimila,Ventimilja,Vintimille,vu~entimiria,wen di mi li ya,Вентимилья,Вентимиля,Вентимиља,Вентімілья,ヴェンティミーリア,文蒂米利亚', 43.7895600, 7.6087200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81176, 'Venosa', 'Venosa', 'Venosa,vu~enoza,ヴェノーザ', 40.9628300, 15.8128500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81177, 'Venice', 'Venice', 'Benatky,Benetia,Benetke,Benezia,Benátky,Feneyjar,V''nise,VCE,Velence,Venecia,Venecia - Venezia,Venecija,Venecio,Venedeg,Venedig,Venedik,Venediku,Venesia,Venetia,Venetie,Venetik,Venetië,Venetsia,Veneza,Venezia,Venezsia,Veneția,Venice,Venies,Venise,Venizia,Venècia,Venèsia,Vignesie,Vinezzia,Wenecja,albndqyt,an Veineis,an Veinéis,benechia,beniseu,benisu,venetsia,vu~enetsu~ia,vu~enisu,wei ni si,wnyz,wnzyh,Βενετία,Венеция,Венеција,Венеція,Վենետիկ,ונציה,البندقية,ونیز,ۋېنىتسىيە,ვენეცია,ベニス,ヴェニス,ヴェネツィア,威尼斯,베네치아,베니스', 45.4371300, 12.3326500, 'IT', '2017-06-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81178, 'Venegono Superiore', 'Venegono Superiore', 'Venegono,Venegono Superiore', 45.7524600, 8.8973400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81179, 'Venegono Inferiore', 'Venegono Inferiore', 'Venegono Inferiore', 45.7356900, 8.8954500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81180, 'Venasca', 'Venasca', 'Venasca', 44.5613400, 7.3969800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81181, 'Venarotta', 'Venarotta', 'Venarotta,vu~enarotta,ヴェナロッタ', 42.8826600, 13.4915700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81182, 'Venaria Reale', 'Venaria Reale', 'Venaria,Venaria Reale,ヴェナリーア・レアーレ', 45.1259700, 7.6313600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81183, 'Venaus', 'Venaus', 'Venaus,Venàus,vu~enausu,ヴェナーウス', 45.1571000, 7.0107000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81184, 'Venafro', 'Venafro', 'Venafro', 41.4827500, 14.0477300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81185, 'Velturno', 'Velturno', 'Feldthurns,Vel''turna,Vel''turno,Velturno,Velturno - Feldthurns,Velturnum,vu~eruto~uruno,wei er tu er nuo,Велтурно,Вельтурна,Вельтурно,Վելտուրնո,ヴェルトゥルノ,韦尔图尔诺', 46.6670500, 11.5971200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81186, 'Vellezzo Bellini', 'Vellezzo Bellini', 'Vellezzo Bellini', 45.2694800, 9.1008800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81187, 'Velletri', 'Velletri', 'Velitrae,Velletri,vu~erretori,ヴェッレトリ', 41.6857300, 12.7775300, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81188, 'Veleso', 'Veleso', 'Veleso', 45.9087500, 9.1809000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81189, 'Vejano', 'Vejano', 'Veiano,Vejano', 42.2190500, 12.0939800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81190, 'Veglie', 'Veglie', 'Veglie', 40.3347400, 17.9623800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81191, 'Veggiano', 'Veggiano', 'Veggiano', 45.4471900, 11.7128000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81192, 'Vedeseta', 'Vedeseta', 'Vedeseta', 45.8910200, 9.5392700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81193, 'Vedelago', 'Vedelago', 'Vedelago', 45.6872200, 12.0185300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81194, 'Vedano Olona', 'Vedano Olona', 'Vedano Olona', 45.7757000, 8.8877100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81195, 'Vecchiano-Nodica', 'Vecchiano-Nodica', '', 43.7833400, 10.3844000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81196, 'Vazzola', 'Vazzola', 'Lavazola,Vaccola,Vacola,Vazola,Vazoła,Vazzola,vu~attsu~ora,wa zuo la,wzla,Вацола,Ваццола,Վացոլա,وزلا,ヴァッツォーラ,瓦佐拉', 45.8351100, 12.4085100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81197, 'Vattaro', 'Vattaro', 'Vattaro,vu~attaro,ヴァッターロ', 45.9938800, 11.2179200, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81198, 'Vastogirardi', 'Vastogirardi', '', 41.7746000, 14.2584400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81199, 'Vasto', 'Vasto', 'Istonio,Vasto,Васто', 42.1115000, 14.7064900, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81200, 'Vasia', 'Vasia', 'Vasia,Vaxia,Vaxìa', 43.9326800, 7.9538900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81201, 'Vasanello', 'Vasanello', 'Bassanello,Vasanello', 42.4150700, 12.3476700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81202, 'Vas', 'Vas', 'Vas', 45.9380400, 11.9357900, 'IT', '2016-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81203, 'Varzo', 'Varzo', 'Varzo', 46.2073600, 8.2526700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81204, 'Varzi', 'Varzi', 'Varzi', 44.8229700, 9.1976200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81205, 'Varsi', 'Varsi', 'Varsi', 44.6627400, 9.8487900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81206, 'Varna', 'Varna', 'Vahrn,Varna,vu~aruna,ヴァルナ', 46.7390100, 11.6374900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81207, 'Varmo', 'Varmo', 'Varmo,Vil di Var', 45.8863000, 12.9900500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81208, 'Varese Ligure', 'Varese Ligure', 'Vaise Ligure,Varese Ligure', 44.3768700, 9.5937200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81209, 'Varese', 'Varese', 'Baretium,QVA,Vareis,Varese,Vareze,Varèis,Varèse,vu~areze,wa lei ze,Варезе,ヴァレーゼ,瓦雷澤', 45.8205800, 8.8251100, 'IT', '2015-09-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81210, 'Varenna', 'Varenna', 'Varenna', 46.0107800, 9.2846500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81211, 'Varedo', 'Varedo', 'Varedo,vu~aredo,ヴァレード', 45.5976100, 9.1632300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81212, 'Varco Sabino', 'Varco Sabino', 'Varco Sabino', 42.2401600, 13.0205200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81213, 'Varazze', 'Varazze', 'Vaeze,Varazze,Väze,vu~arattsu~e,ヴァラッツェ', 44.3641200, 8.5963000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81214, 'Varano De'' Melegari', 'Varano De'' Melegari', 'Varano de'' Melegari,Varano de''Melegari', 44.6880600, 10.0114800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81215, 'Varallo Pombia', 'Varallo Pombia', 'Varallo Pombia', 45.6678400, 8.6285000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81216, 'Varallo', 'Varallo', 'Varallo Sesia,Varallo Sésia,vu~ararro,ヴァラッロ', 45.8138300, 8.2581400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81217, 'Varago', 'Varago', '', 45.7372600, 12.3108300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81218, 'Vaprio D''Agogna', 'Vaprio D''Agogna', 'Vaprio d''Agogna', 45.6032200, 8.5540200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81219, 'Vaprio d''Adda', 'Vaprio d''Adda', 'Vaprio,Vaprio d''Ada,Vaprio d''Adda,Ваприо д''Ада,ヴァプリオ・ダッダ', 45.5764000, 9.5240700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81220, 'Vanzone', 'Vanzone', '', 45.9778500, 8.1082600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81221, 'Vanzago', 'Vanzago', 'Vanzago,vu~anzago,ヴァンザーゴ', 45.5256600, 8.9909700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81222, 'Vanzaghello', 'Vanzaghello', 'Vanzaghello,vu~anzagerro,ヴァンザゲッロ', 45.5796400, 8.7823400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81223, 'Vandoies di Sotto', 'Vandoies di Sotto', 'Niedervintl,Vandoies di Sotto', 46.8160000, 11.7218300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81224, 'Valvasone', 'Valvasone', 'Valvasone,Voleson', 45.9933100, 12.8665900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81225, 'Valva', 'Valva', 'Valva', 40.7387100, 15.2680500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81226, 'Valtorta', 'Valtorta', 'Valtorta', 45.9768500, 9.5347800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81227, 'Valstagna', 'Valstagna', 'Valstagna', 45.8510800, 11.6664200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81228, 'Valsinni', 'Valsinni', 'Valsinni', 40.1709800, 16.4438800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81229, 'Valprato Soana', 'Valprato Soana', 'Valprato,Valprato Soana,ヴァルプラート・ソアーナ', 45.5216600, 7.5494800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81230, 'Valperga', 'Valperga', 'Valperga,vu~aruperuga,ヴァルペルガ', 45.3700400, 7.6612400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81231, 'Valpelline', 'Valpelline', 'Valpellina,Valpelline', 45.8248600, 7.3255000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81232, 'Valnegra', 'Valnegra', 'Valnegra', 45.9490900, 9.6893500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81233, 'Valmontone', 'Valmontone', 'Valmontone,vu~arumontone,ヴァルモントーネ', 41.7732300, 12.9185600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81234, 'Valmadrera-Caserta', 'Valmadrera-Caserta', 'Valmadrera', 45.8462800, 9.3582400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81235, 'Valmacca', 'Valmacca', 'Valmacca', 45.1010100, 8.5838200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81236, 'Vallo della Lucania', 'Vallo della Lucania', 'Vallo della Lucania,Vallo di Lucania', 40.2278600, 15.2663500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81237, 'Vallinfreda', 'Vallinfreda', 'Vallinfreda', 42.0848500, 12.9959500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81238, 'Valli del Pasubio', 'Valli del Pasubio', 'Valli d''Pasubio,Valli dei Signori,Valli del Pasubio,Valli di Pasubio', 45.7403000, 11.2635400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81239, 'Vallese', 'Vallese', '', 45.3282700, 11.0860800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81240, 'Valle San Nicolao', 'Valle San Nicolao', 'Valle San Nicolao', 45.6070600, 8.1410200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81241, 'Vallerotonda', 'Vallerotonda', 'Vadditunna,Valerotonda,Vallerotonda,Vallis Rotunda,ballelotonda,vu~arrerotonda,wa lai luo tong da,Валеротонда,Валлеротонда,Վալերոտոնդա,ヴァッレロトンダ,瓦莱罗通达,발레로톤다', 41.5513500, 13.9137200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81242, 'Vallerano', 'Vallerano', 'Vallerano', 42.3833100, 12.2614400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81243, 'Vallepietra', 'Vallepietra', 'Vallepietra,vu~arrepietora,ヴァッレピエトラ', 41.9255200, 13.2312700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81244, 'Valle Mosso', 'Valle Mosso', 'Valle Mosso', 45.6306900, 8.1476400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81245, 'Vallemaio', 'Vallemaio', 'Vallefredda,Vallemaio', 41.3662800, 13.8083900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81246, 'Valle Lomellina', 'Valle Lomellina', 'Valle Lomellina', 45.1509600, 8.6695700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81247, 'Valle di Maddaloni', 'Valle di Maddaloni', '', 41.0794600, 14.4178800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81248, 'Valle dell''Angelo', 'Valle dell''Angelo', 'Valle dell''Angelo', 40.3438100, 15.3684600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81249, 'Vallecupa', 'Vallecupa', '', 42.2536600, 13.5746700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81250, 'Vallecrosia', 'Vallecrosia', 'Valecreusa,Vallecrosia', 43.7867100, 7.6390200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81251, 'Vallecorsa', 'Vallecorsa', 'Vallecorsa', 41.4435100, 13.4063400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81252, 'Valle Castellana', 'Valle Castellana', 'Valle Castellana', 42.7361400, 13.4970900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81253, 'Vallebona', 'Vallebona', 'Valebona,Valebòna,Vallebona', 43.8122000, 7.6653500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81254, 'Valle Agricola', 'Valle Agricola', '', 41.4247700, 14.2558400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81255, 'Vallata', 'Vallata', 'Vallata', 41.0401900, 15.2538300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81256, 'Vall''Alta', 'Vall''Alta', '', 45.7611600, 9.8264000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81257, 'Vallà', 'Valla', '', 45.7071100, 11.9327100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81258, 'Valgrana', 'Valgrana', 'Valgrana', 44.4118100, 7.3806800, 'IT', '2017-07-31', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81259, 'Valgioie', 'Valgioie', 'Valgioie,vu~arujoie,ヴァルジョーイエ', 45.0640000, 7.3492700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81260, 'Valganna', 'Valganna', 'Valganna', 45.9022800, 8.8233300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81261, 'San Nicolò', 'San Nicolo', '', 46.4629900, 10.4099800, 'IT', '2012-02-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81262, 'Valfenera', 'Valfenera', 'Valfenera', 44.9017500, 7.9643300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81263, 'Valfabbrica', 'Valfabbrica', 'Valfabbrica', 43.1578400, 12.6020200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81264, 'Valenzano', 'Valenzano', 'Valenzano', 41.0437600, 16.8849100, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81265, 'Valenza', 'Valenza', 'Valensa,Valenza,Валенса', 45.0124200, 8.6437900, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81266, 'Valentano', 'Valentano', 'Valentano,vu~arentano,ヴァレンターノ', 42.5637700, 11.8274800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81267, 'Valeggio sul Mincio', 'Valeggio sul Mincio', 'Valeggio,Valeggio sul Mincio,ヴァレッジョ・スル・ミンチョ', 45.3533300, 10.7363500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81268, 'Valeggio', 'Valeggio', 'Valeggio', 45.1506500, 8.8613200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81269, 'Valduggia', 'Valduggia', 'Valduggia', 45.7272200, 8.3273000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81270, 'Valdottavo', 'Valdottavo', '', 43.9418700, 10.4811500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81271, 'Valdobbiadene', 'Valdobbiadene', 'Valdobbiadene', 45.8968900, 11.9824500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81272, 'Valdieri', 'Valdieri', 'Valdieri', 44.2776300, 7.3976300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81273, 'Valdaora di Mezzo', 'Valdaora di Mezzo', 'Aulacum,Olang,Valdaora,Valdapra,vu~arudaora,ヴァルダーオラ', 46.7602700, 12.0295100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81274, 'Valdagno', 'Valdagno', 'Valdagno', 45.6449800, 11.2988600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81275, 'Bondione', 'Bondione', 'Bondione', 46.0354100, 10.0083200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81276, 'Vairano-Patenora', 'Vairano-Patenora', 'Vairano Patenora', 41.3370200, 14.1311200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81277, 'Vajont', 'Vajont', 'Vaiont,Vajont', 46.1453400, 12.6964700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81278, 'Vailate', 'Vailate', 'Vailate', 45.4623100, 9.6032600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81279, 'Vaiano Cremasco', 'Vaiano Cremasco', 'Vaiano Cremasco', 45.3713300, 9.5879300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81280, 'Vaiano', 'Vaiano', 'Vaiano,Vaianu,Vajana,Vajano,Varianum,Vayano,baiano,vu~aiano,wa yi a nuo,wayanw,Ваяна,Ваяно,Վայանո,وایانو,ヴァイアーノ,瓦伊阿诺,바이아노', 43.9679200, 11.1237400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81281, 'Vaglio Basilicata', 'Vaglio Basilicata', 'Vaglio Basilicata,Vaglio Lucano', 40.6664300, 15.9143400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81282, 'Vaglia', 'Vaglia', 'Vaglia', 43.9107000, 11.2799700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81283, 'Vado Ligure', 'Vado Ligure', 'Vado Ligure,Vooe,Voœ,ヴァード・リーグレ', 44.2691300, 8.4337500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81284, 'Vado', 'Vado', '', 44.3168900, 11.2585100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81285, 'Vadena', 'Vadena', 'Pfatten,Vadena,vu~adena,ヴァーデナ', 46.4136100, 11.3049800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81286, 'Vada', 'Vada', '', 43.3526400, 10.4556400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81287, 'Vacri', 'Vacri', 'Vacri', 42.2976400, 14.2290100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81288, 'Vacone', 'Vacone', 'Vacone', 42.3810000, 12.6450400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81289, 'Uzzano', 'Uzzano', 'Uzzano', 43.8972800, 10.7040300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81290, 'Usseglio', 'Usseglio', 'Usseglio,usserio,ウッセーリオ', 45.2327400, 7.2199300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81291, 'Usmate-Velate', 'Usmate-Velate', 'Usmate,Usmate Velate,ウズマーテ・ヴェラーテ', 45.6479800, 9.3624500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81292, 'Usini', 'Usini', 'Usini', 40.6641600, 8.5391900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81293, 'Uscio', 'Uscio', 'Aosci,Uscio,Usho,Ушо', 44.4123300, 9.1622700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81294, 'Urzulei', 'Urzulei', 'Ursulei,Ursulèi,Urzulei', 40.0928400, 9.5080000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81295, 'Ururi', 'Ururi', 'Ruri,Ururi', 41.8151800, 15.0161100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81296, 'Uri', 'Uri', 'Uri', 40.6384100, 8.4888100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81297, 'Urgnano', 'Urgnano', 'Urgnano', 45.5994300, 9.6947300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81298, 'Urbisaglia', 'Urbisaglia', 'Urbisaglia,Urbisaglia Bonservizi', 43.1930400, 13.3747400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81299, 'Urbino', 'Urbino', 'Urbin,Urbino,Urbinu,Urvinum Mataurense,urubino,Урбино,אורבינו,ウルビーノ', 43.7262100, 12.6363300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81300, 'Urbania', 'Urbania', '', 43.6683200, 12.5209300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81301, 'Umbertide', 'Umbertide', 'Umbertide', 43.3034100, 12.3374900, 'IT', '2016-04-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81302, 'Uliveto Terme', 'Uliveto Terme', '', 43.6960900, 10.5172800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81303, 'Ulà Tirso', 'Ula Tirso', 'Ula Tirso,Ulà Tirso', 40.0457000, 8.9032600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81304, 'Uggiate Trevano', 'Uggiate Trevano', '', 45.8233800, 8.9596400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81305, 'Uggiano Montefusco', 'Uggiano Montefusco', '', 40.3861200, 17.6046000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81306, 'Uggiano la Chiesa', 'Uggiano la Chiesa', 'Uggiano,Uggiano la Chiesa', 40.1009100, 18.4487200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81307, 'Udine', 'Udine', 'UDN,Udin,Udine,Удине', 46.0693000, 13.2371500, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81308, 'Tuscania', 'Tuscania', 'Tuscania,to~usukania,トゥスカーニア', 42.4188900, 11.8684600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81309, 'Tursi', 'Tursi', 'Tursi', 40.2465100, 16.4714000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81310, 'Turrivalignani', 'Turrivalignani', 'Turrivalignani', 42.2629600, 14.0285200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81311, 'Turriaco', 'Turriaco', 'Turiac,Turiàc,Turriaco', 45.8211900, 13.4436900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81312, 'Turi', 'Turi', '', 40.9165700, 17.0203800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81313, 'Turbigo', 'Turbigo', 'Turbigo,to~urubigo,トゥルビーゴ', 45.5307600, 8.7367100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81314, 'Turano Lodigiano', 'Turano Lodigiano', 'Turano Lodigiano,トゥラーノ・ロディジャーノ', 45.2478500, 9.6222100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81315, 'Turania', 'Turania', 'Petescia,Turania', 42.1351700, 13.0098300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81316, 'Tuoro sul Trasimeno', 'Tuoro sul Trasimeno', 'Tuoro,Tuoro sul Trasimeno', 43.2065400, 12.0746500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81317, 'Tula', 'Tula', 'Tula,to~ura,tu la,Тула,Տուլա,トゥーラ,圖拉', 40.7324600, 8.9839200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81318, 'Tuglie', 'Tuglie', 'Tuglie', 40.0734600, 18.0987200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81319, 'Tufino', 'Tufino', 'Tufino,to~ufino,トゥフィーノ', 40.9558600, 14.5656800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81320, 'Tufillo', 'Tufillo', 'Tufillo', 41.9168500, 14.6255800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81321, 'Tuenno', 'Tuenno', 'Tuenno,to~uen''no,トゥエンノ', 46.3284400, 11.0230600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81322, 'Tubre', 'Tubre', 'Taufers,Taufers im Muenstertal,Taufers im Münstertal,Tuberis,Tubre,Tubreh,to~ubure,tu bu lei,Тубре,Тубрэ,トゥブレ,图布雷', 46.6440300, 10.4632800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81323, 'Truccazzano', 'Truccazzano', 'Trucazzano,Truccazzano', 45.4845500, 9.4695000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81324, 'Trovo', 'Trovo', 'Trovo', 45.2829600, 9.0354500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81325, 'Troviggiano', 'Troviggiano', '', 43.3786800, 13.2502200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81326, 'Tronzano Vercellese', 'Tronzano Vercellese', 'Tronsan,Tronzano,Tronzano Vercellese', 45.3422600, 8.1736800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81327, 'Tronzano Lago Maggiore', 'Tronzano Lago Maggiore', 'Tronzano Lago Maggiore', 46.0887100, 8.7331000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81328, 'Tromello', 'Tromello', '', 45.2089000, 8.8705400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81329, 'Troia', 'Troia', 'Aecae,Troia,Troja,Troya,Troìa,te luo ya,toroia,trwya,Троя,Տրոյա,ترويا,トローイア,特罗亚', 41.3642800, 15.3173000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81330, 'Trofarello', 'Trofarello', 'Trofarello,torofarerro,トロファレッロ', 44.9823800, 7.7468800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81331, 'Trodena', 'Trodena', 'Trodena,Trodena nel parco naturale,Truden,Truden im Naturpark,torodena,トローデナ', 46.3218100, 11.3498200, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81332, 'Trivigno', 'Trivigno', 'Trivigno', 40.5801500, 15.9885700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81333, 'Trivignano Udinese', 'Trivignano Udinese', 'Trivignan,Trivignano,Trivignano Udinese', 45.9460100, 13.3401900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81334, 'Trivero-Prativero-Ponzone', 'Trivero-Prativero-Ponzone', 'Trivero', 45.6604700, 8.1740200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81335, 'Trivento', 'Trivento', 'Trivento', 41.7700400, 14.5461300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81336, 'Triuggio', 'Triuggio', 'Triuecc,Triuggio,Triücc,toriujjo,トリウッジョ', 45.6614400, 9.2669100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81337, 'Trissino', 'Trissino', 'Trissino', 45.5599400, 11.3767800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81338, 'Trisobbio', 'Trisobbio', 'Trisobbio', 44.6606300, 8.5862100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81339, 'Triora', 'Triora', 'Trieua,Triora,Triêua', 43.9930900, 7.7636900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81340, 'Trino', 'Trino', 'Trin,Trino', 45.1953800, 8.2962100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81341, 'Trinitapoli', 'Trinitapoli', 'Trinitapoli', 41.3565400, 16.0892400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81342, 'Trinità d''Agultu e Vignola', 'Trinita d''Agultu e Vignola', '', 40.9837700, 8.9156200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81343, 'Trinità', 'Trinita', 'Trinita,Trinità', 44.5073000, 7.7563700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81344, 'Trigolo', 'Trigolo', 'Trigolo', 45.3299700, 9.8141500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81345, 'Triggiano', 'Triggiano', 'Triggiano', 41.0654900, 16.9250100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81346, 'Trieste', 'Trieste', 'Gorad Tryest,TRS,Tergeste,Tergesti,Terst,Tit-li-nga-su-thit,Tit-lî-ngâ-sṳ̂-thi̍t,Triest,Triestas,Trieste,Triesti,Triesto,Triests,Trieszt,Triëst,Trst,de li ya si te,di li ya si te,teulieseute,toriesute,tri xe s te,tri''esta,tri''este,triyesrre,triyeste,trysth,tryysty,Τεργέστη,Горад Трыест,Триест,Трст,Трієст,Տրիեստ,טריאסטה,ترييستي,تریسته,تریستے,ٹریسٹ,ट्रिएस्ट,त्रिएस्ते,ত্রিয়েস্তে,ട്രിയെസ്റ്റെ,ตรีเอสเต,ტრიესტი,トリエステ,的里雅斯特,第里雅斯特,트리에스테', 45.6495300, 13.7767800, 'IT', '2017-05-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81347, 'Triei', 'Triei', 'Triei', 40.0349800, 9.6399500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81348, 'Tricesimo', 'Tricesimo', 'Tresesin,Tricesimo', 46.1605800, 13.2156600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81349, 'Tricerro', 'Tricerro', 'Tricerro', 45.2357000, 8.3274600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81350, 'Tricarico', 'Tricarico', 'Tricarico', 40.6145800, 16.1425900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81351, 'Tribiano', 'Tribiano', 'Tribiano,toribiano,トリビアーノ', 45.4132300, 9.3769300, 'IT', '2016-05-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81352, 'Tribano', 'Tribano', 'Tribano', 45.2091200, 11.8363900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81353, 'Trezzo sull''Adda', 'Trezzo sull''Adda', 'Treco sul''Ada,Trezzo,Trezzo sull''Adda,Tritium super Adduam,Трецо сул''Ада,トレッツォ・スッラッダ', 45.6052300, 9.5141700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81354, 'Trezzano sul Naviglio', 'Trezzano sul Naviglio', 'Trezzano sul Naviglio,トレッツァーノ・スル・ナヴィーリオ', 45.4221200, 9.0634200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81355, 'Trezzano Rosa', 'Trezzano Rosa', 'Trecano Roza,Treccano-Roza,Trescian,Trezzano Rosa,Trezzanum,te lei zha nuo luo sa,Трецано Роза,Треццано-Роза,Տրեցանո Ռոզա,トレッツァーノ・ローザ,特雷扎诺罗萨', 45.5822800, 9.4856700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81356, 'Treviso', 'Treviso', 'Tarvisium,Trevise,Treviso,Trevixo,Trevizo,Trévise,torevu~izo,trwwyzw,Тревизо,טרוויזו,トレヴィーゾ', 45.6667300, 12.2416000, 'IT', '2015-09-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81357, 'Trevi nel Lazio', 'Trevi nel Lazio', 'Trevi nel Lazio', 41.8625800, 13.2479300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81358, 'Trevignano Romano', 'Trevignano Romano', 'Trevignano', 42.1602000, 12.2377500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81359, 'Trevignano', 'Trevignano', 'Trevignano,Trevignano Veneto', 45.7367000, 12.0671900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81360, 'Treviglio', 'Treviglio', 'Treviglio,Trevil''o,Trevilio,torevu~irio,Тревильо,トレヴィーリオ', 45.5208100, 9.5910200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81361, 'Trevico', 'Trevico', 'Trehvika,Trevico,Trevicu,Treviko,Trivicum,te lei wei ke,teulebiko,torevu~iko,Тревико,Тревіко,Трэвіка,Տրևիկո,تره‌ویکو,トレヴィーコ,特雷维科,트레비코', 41.0480800, 15.2329200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81362, 'Trevi', 'Trevi', 'Trevi', 42.8776900, 12.7493800, 'IT', '2016-05-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81363, 'Trevenzuolo', 'Trevenzuolo', 'Trevenzuolo', 45.2697400, 10.9338600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81364, 'Tresnuraghes', 'Tresnuraghes', '', 40.2523500, 8.5209200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81365, 'Tresigallo-Final di Rero', 'Tresigallo-Final di Rero', 'Tresigallo', 44.8159800, 11.8947200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81366, 'Trescore Cremasco', 'Trescore Cremasco', 'Trescorre Cremasco', 45.4029800, 9.6227800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81367, 'Trescore Balneario', 'Trescore Balneario', 'Trescore,Trescore Balneario', 45.6940900, 9.8417300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81368, 'Trescine', 'Trescine', '', 41.0225600, 14.6203900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81369, 'Tres', 'Tres', 'Tres,toresu,トレス', 46.3217900, 11.0965400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81370, 'Trequanda', 'Trequanda', 'Trequanda,torekuanda,トレクアンダ', 43.1874900, 11.6681800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81371, 'Trepuzzi', 'Trepuzzi', 'Trepuzzi', 40.4053500, 18.0762500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81372, 'Treppo Grande', 'Treppo Grande', 'Trep Grant,Treppo Grande', 46.1998800, 13.1535000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81373, 'Treponti', 'Treponti', '', 45.3672700, 11.7090500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81374, 'Trentola-Ducenta', 'Trentola-Ducenta', 'Trentola-Ducenta,Tréntola-Ducenta', 40.9751700, 14.1749000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81375, 'Trento', 'Trento', 'Gorad Trehnta,Treant,Trent,Trent/o,Trentas,Trente,Trento,Trentu,Trident,Tridentum,Trient,Trionta,Trydent,Trénto,ZIA,te lun tuo,teulento,torento,trntw,tryntw,Τρέντο,Горад Трэнта,Тренто,טרנטו,ترنتو,ترينتو,ٹرنٹو,ტრენტო,トレント,特伦托,트렌토', 46.0678700, 11.1210800, 'IT', '2016-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81376, 'Trentinara', 'Trentinara', 'Trentinara', 40.3999800, 15.1154500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81377, 'Tremignon', 'Tremignon', '', 45.5207600, 11.8057700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81378, 'Tremezzo', 'Tremezzo', 'Tremezzo', 45.9842300, 9.2161300, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81379, 'Tremenico', 'Tremenico', 'Tremenico', 46.0759200, 9.3660200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81380, 'Treia', 'Treia', 'Treia,Treja', 43.3085000, 13.3103600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81381, 'Tregnago', 'Tregnago', 'Tregnago', 45.5139700, 11.1642100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81382, 'Treglio', 'Treglio', 'Treglio', 42.2618400, 14.4231500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81383, 'Treggiaia', 'Treggiaia', '', 43.6230500, 10.6732500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81384, 'Tredozio', 'Tredozio', '', 44.0795800, 11.7414000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81385, 'Trecenta', 'Trecenta', 'Trecenta', 45.0293700, 11.4593100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81386, 'Trecchina', 'Trecchina', 'Trecchina', 40.0261100, 15.7758500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81387, 'Trecate', 'Trecate', 'Trecate', 45.4339900, 8.7364000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81388, 'Trecasali', 'Trecasali', 'Trecasali', 44.9374700, 10.2727900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81389, 'Trebaseleghe', 'Trebaseleghe', 'Trebaseleghe', 45.5929500, 12.0439200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81390, 'Travo', 'Travo', 'Travo', 44.8632100, 9.5443000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81391, 'Travesio', 'Travesio', 'Traves,Travesio', 46.1966700, 12.8674000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81392, 'Traversetolo', 'Traversetolo', 'Traversetolo', 44.6424400, 10.3803600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81393, 'Traversella', 'Traversella', 'Traversella,toravu~eruserra,トラヴェルセッラ', 45.5090700, 7.7493800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81394, 'Travedona Monate', 'Travedona Monate', '', 45.8042700, 8.6714300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81395, 'Travagliato', 'Travagliato', 'Travagliato', 45.5239100, 10.0801300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81396, 'Trasaghis', 'Trasaghis', 'Trasaghis', 46.2816400, 13.0754500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81397, 'Trasacco', 'Trasacco', 'Trasacco', 41.9574200, 13.5327000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81398, 'Trarivi', 'Trarivi', '', 43.9367200, 12.5440000, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81399, 'Trarego', 'Trarego', '', 46.0343500, 8.6699800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81400, 'Traona', 'Traona', 'Traona,Trauna,Trevonia,te lao na,toraona,Траона,Տրաոնա,トラオーナ,特劳纳', 46.1473700, 9.5325600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81401, 'Transacqua', 'Transacqua', 'Transacqua,toransakkua,トランサックア', 46.1736700, 11.8327900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81402, 'Trani', 'Trani', 'Trani,Turenum,torani,Трани,トラーニ', 41.2773300, 16.4101100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81403, 'Trana', 'Trana', 'Tran-a,Trana,torana,トラーナ', 45.0386200, 7.4210000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81404, 'Tramutola', 'Tramutola', 'Tramutola', 40.3185800, 15.7875300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81405, 'Tramonti di Sopra', 'Tramonti di Sopra', 'Tramonc Disore,Tramonti Sopra,Tramonti di Sopra,Tramonç Disore', 46.3102300, 12.7899400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81406, 'Tramonti', 'Tramonti', 'Tramonte,Tramonti,Трамонти', 40.6915400, 14.6449000, 'IT', '2012-09-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81407, 'Tragliatella Campitello', 'Tragliatella Campitello', 'Castle Tragliatella,Tragliatella', 42.0133400, 12.2520000, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81408, 'Tradate', 'Tradate', 'Tradate', 45.7084300, 8.9076300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81409, 'Tossicia', 'Tossicia', 'Tossicia', 42.5447200, 13.6459500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81410, 'Toscolano Maderno', 'Toscolano Maderno', 'Toscolano Maderno,Toscolano-Maderno', 45.6397700, 10.6076000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81411, 'Torviscosa', 'Torviscosa', 'Tor di Zuin,Torviscosa', 45.8233700, 13.2805000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81412, 'Tortoreto', 'Tortoreto', 'Tortoreto', 42.8037100, 13.9134600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81413, 'Tortorella', 'Tortorella', 'Tortorella', 40.1423600, 15.6062500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81414, 'Tortona', 'Tortona', 'Tortona', 44.8978400, 8.8637400, 'IT', '2015-08-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81415, 'Torrita Tiberina', 'Torrita Tiberina', 'Torrita,Torrita Tiberina,トッリータ・ティベリーナ', 42.2382100, 12.6163300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81416, 'Torrita di Siena', 'Torrita di Siena', 'Taryta-dzi-S''ena,Torita di Siena,Torrita,Torrita di Siena,Torrita-di-S''ena,Turrita,tolitadisiena,tuo li ta di xie na,Тарыта-дзі-Сьена,Торита ди Сиена,Торрита-ди-Сьена,Торрита-ді-Сьєна,Տորիտա դի Սիենա,トッリータ・ディ・シエーナ,托里塔迪谢纳,토리타디시에나', 43.1724500, 11.7837600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81417, 'Torrioni', 'Torrioni', 'Torrioni', 41.0341000, 14.8135100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81418, 'Torrile', 'Torrile', 'Torrile', 44.9252200, 10.3238100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81419, 'Torri in Sabina', 'Torri in Sabina', 'Torri in Sabina', 42.3505700, 12.6415700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81420, 'Torriglia', 'Torriglia', 'Torriggia,Torriglia', 44.5175500, 9.1581100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81421, 'Torri di Quartesolo', 'Torri di Quartesolo', 'Torri,Torri di Quartesolo', 45.5190100, 11.6246900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81422, 'Torri del Benaco', 'Torri del Benaco', 'Torri,Torri del Benaco', 45.6101300, 10.6866900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81423, 'Torricella', 'Torricella', 'Torricella Sicura', 42.6590400, 13.6571900, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81424, 'Torricella Peligna', 'Torricella Peligna', 'Torricella Peligna', 42.0239700, 14.2585400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81425, 'Torricella in Sabina', 'Torricella in Sabina', 'Torricella,Torricella Sabina,Torricella in Sabina', 42.2625200, 12.8717000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81426, 'Torricella del Pizzo', 'Torricella del Pizzo', '', 45.0202300, 10.2949700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81427, 'Torricella', 'Torricella', 'Torricella', 40.3550900, 17.4984600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81428, 'Torrice', 'Torrice', 'Torrice', 41.6337400, 13.4037500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81429, 'Torriana', 'Torriana', 'Taryjana,Toriana,Torriana,Turriana,torriana,tuo li ya na,twryana,Тарыяна,Торриана,Торріана,Տորիանա,توريانا,トッリアーナ,托里亚纳', 43.9848500, 12.3854100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81430, 'Torrevecchia', 'Torrevecchia', 'Torrevecchia Teatina', 42.3827400, 14.2133100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81431, 'Torre Santa Susanna', 'Torre Santa Susanna', 'Torre Santa Susanna', 40.4676200, 17.7386400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81432, 'Torre San Patrizio', 'Torre San Patrizio', 'Torre San Patrizio', 43.1831100, 13.6111300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81433, 'Torre Pellice', 'Torre Pellice', 'Torre Pellice,トッレ・ペッリチェ', 44.8210200, 7.2167200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81434, 'Torre Orsaia', 'Torre Orsaia', 'Torre Orsaia', 40.1327700, 15.4725000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81435, 'Torrenieri', 'Torrenieri', '', 43.0856600, 11.5483900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81436, 'Torremaggiore', 'Torremaggiore', '', 41.6889400, 15.2940800, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81437, 'Torre le Nocelle', 'Torre le Nocelle', 'Torre Le Nocelle', 41.0231200, 14.9093400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81438, 'Torreglia', 'Torreglia', '', 45.3361700, 11.7360800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81439, 'Torre d''Isola', 'Torre d''Isola', '', 45.2179600, 9.0765100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81440, 'Torre di Santa Maria', 'Torre di Santa Maria', 'Torre Santa Maria,Torre di Santa Maria', 46.2335600, 9.8522800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81441, 'Torre di Mosto', 'Torre di Mosto', 'Torre di Mosto,トッレ・ディ・モスト', 45.6862900, 12.7002700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81442, 'Torre de'' Picenardi', 'Torre de'' Picenardi', '', 45.1431700, 10.2880300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81443, 'Torre de'' Passeri', 'Torre de'' Passeri', 'Torre dei Passeri', 42.2432400, 13.9333000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81444, 'Torre del Mangano', 'Torre del Mangano', '', 45.2520800, 9.1304200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81445, 'Torre del Lago Puccini', 'Torre del Lago Puccini', 'Torre del Lago,Torre del Lago Puccini', 43.8288700, 10.2891200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81446, 'Torre del Greco', 'Torre del Greco', 'Torre d''''o Grieco,Torre del Greco,Torre-del''-Greko,Торре-дель-Греко,トッレ・デル・グレーコ', 40.7893100, 14.3680600, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81447, 'Torre de'' Busi', 'Torre de'' Busi', 'Torre de'' Busi,Torre de''Busi', 45.7740800, 9.4802500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81448, 'Torrecuso', 'Torrecuso', 'Torrecuso', 41.1858200, 14.6812600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81449, 'Torrebruna', 'Torrebruna', 'Torrebruna', 41.8674200, 14.5414800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81450, 'Torre Boldone', 'Torre Boldone', 'Torre Boldone', 45.7172500, 9.7079200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81451, 'Torre Beretti', 'Torre Beretti', 'Torreberretti', 45.0599600, 8.6709400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81452, 'Torrebelvicino', 'Torrebelvicino', 'Torrebelvicino', 45.7158300, 11.3186900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81453, 'Torreano', 'Torreano', 'Torean,Torreano', 46.1278600, 13.4293300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81454, 'Torre Annunziata', 'Torre Annunziata', 'Torre Annunziata,Torre Nunziata,Torre-Annunciata,Торре-Аннунциата,トッレ・アンヌンツィアータ', 40.7533700, 14.4525100, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81455, 'Torrazzo', 'Torrazzo', 'Torrazzo', 45.4987400, 7.9542800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81456, 'Torrazza Coste', 'Torrazza Coste', '', 44.9782000, 9.0761300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81457, 'Torralba', 'Torralba', 'Torralba', 40.5129600, 8.7653200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81458, 'Torraca', 'Torraca', 'Torraca', 40.1109900, 15.6363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81459, 'Torpè', 'Torpe', 'Torpe,Torpè', 40.6278000, 9.6791600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81460, 'Toro', 'Toro', 'Toro', 41.5731300, 14.7618300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81461, 'Tornolo', 'Tornolo', '', 44.4852400, 9.6274400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81462, 'Torno', 'Torno', 'Torno', 45.8559300, 9.1170700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81463, 'Tornata', 'Tornata', '', 45.1043700, 10.4307800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81464, 'Tornareccio', 'Tornareccio', 'Tornareccio', 42.0376300, 14.4152500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81465, 'Tornaco', 'Tornaco', 'Tornaco', 45.3565100, 8.7174500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81466, 'Torlino Vimercati', 'Torlino Vimercati', 'Torlino', 45.4174700, 9.5947600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81467, 'Toritto', 'Toritto', 'Toritto,toritto,トリット', 40.9977400, 16.6794500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81468, 'Torino di Sangro', 'Torino di Sangro', 'Torino di Sangro', 42.1910000, 14.5427200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81469, 'Turin', 'Turin', 'Augusta Taurinorum,Gorad Turyn,Julia Augusta Taurinorum,Lungsod ng Turino,TRN,Tori,Torin,Torino,Torinu,Torí,Tueri,Turen,Turijn,Turim,Turin,Turina,Turinas,Turino,Turinu,Turyn,Turén,Turìn,Turín,Turīna,Tórínó,Türì,dou ling,tolino,torino,tu rin,tulin,turin,turina,twryn,twrynw,Τορίνο,Горад Турын,Торино,Турин,Թուրին,טורין,טורינו,تورينو,تورین,टोरीनो,तोरिनो,তুরিন,துரின்,ตูริน,ཊུ་རིན།,ტურინი,トリノ,都灵,토리노,투린', 45.0704900, 7.6868200, 'IT', '2017-06-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81470, 'Torgnon', 'Torgnon', 'Torgnon', 45.8061600, 7.5698000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81471, 'Torgiano', 'Torgiano', 'Tordzhano,Torgiano,Torgianu,Torjano,Turgianum,toleujano,torujano,tuo er gu nuo,twrjanw,Торджано,Տորջանո,تورجانو,トルジャーノ,托尔贾诺,토르자노', 43.0276100, 12.4401500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81472, 'Torella del Sannio', 'Torella del Sannio', 'Torella del Sannio', 41.6387800, 14.5203100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81473, 'Torella dei Lombardi', 'Torella dei Lombardi', '', 40.9373100, 15.1078400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81474, 'Torchiarolo', 'Torchiarolo', 'Torchiarolo', 40.4834900, 18.0512200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81475, 'Torchiara', 'Torchiara', 'Torchiara', 40.3216200, 15.0537000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81476, 'Torbole sul Garda', 'Torbole sul Garda', 'Torbole sul Garda', 45.8695100, 10.8756100, 'IT', '2013-12-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81477, 'Torbole Casaglia', 'Torbole Casaglia', 'Torborle', 45.5127900, 10.1170000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81478, 'Torano Nuovo', 'Torano Nuovo', 'Torano Nuovo,Torano-Nuovo,Toranu Novu,Toranum,tolanonuobo,tuo la nuo nuo wo,twranw nwfw,Торано Нуово,Торано-Нуово,Տորանո Նուովո,تورانو نوفو,トラーノ・ヌオーヴォ,托拉诺诺沃,토라노누오보', 42.8230500, 13.7772900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81479, 'Tora', 'Tora', '', 41.3398700, 14.0239900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81480, 'Tonezza del Cimone', 'Tonezza del Cimone', 'Tonezza,Tonezza del Cimone', 45.8588900, 11.3459200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81481, 'Tonco', 'Tonco', 'Tonch,Tonco', 45.0234400, 8.1894200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81482, 'Tonara', 'Tonara', 'Tonara', 40.0246500, 9.1720400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81483, 'Tonadico', 'Tonadico', 'Tonadico,tonadiko,トナディーコ', 46.1811100, 11.8393900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81484, 'Tombolo', 'Tombolo', 'Tombolo,tonboro,トンボロ', 45.6391600, 11.8243500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81485, 'Tolve', 'Tolve', 'Tolve', 40.6942200, 16.0162700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81486, 'Tolmezzo', 'Tolmezzo', 'Tolmezzo,Tumiec,Tumieç', 46.3999600, 13.0205100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81487, 'Tollo', 'Tollo', 'Tollo', 42.3454200, 14.3236000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81488, 'Tollegno', 'Tollegno', 'Tollegno', 45.5907700, 8.0508900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81489, 'Tolfa', 'Tolfa', 'Tolfa,torufa,トルファ', 42.1502300, 11.9321600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81490, 'Tolentino', 'Tolentino', 'Tolentino', 43.2091800, 13.2852400, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81491, 'Toirano', 'Toirano', 'Toian,Toirano,Toiàn', 44.1273200, 8.2072500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81492, 'Toffia', 'Toffia', 'Toffia', 42.2130000, 12.7550000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81493, 'Todi', 'Todi', 'Todi', 42.7788100, 12.4120200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81494, 'Tocco da Casauria', 'Tocco da Casauria', 'Tocco,Tocco Casauria,Tocco da Casauria', 42.2120300, 13.9154700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81495, 'Tocco Caudio', 'Tocco Caudio', '', 41.1258700, 14.6342200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81496, 'Toano', 'Toano', 'Italia Toano,Toano,Тоано', 44.3760100, 10.5631100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81497, 'Tizzano Val Parma', 'Tizzano Val Parma', '', 44.5193100, 10.1981900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81498, 'Tivoli', 'Tivoli', 'Tibur,Tivoli,tivu~ori,tybwly,Тиволи,טיבולי,ティヴォリ', 41.9595200, 12.8016000, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81499, 'Tito', 'Tito', 'Tito', 40.5837000, 15.6762100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81500, 'Tissi', 'Tissi', 'Tissi', 40.6783200, 8.5612700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81501, 'Marina di Pisa-Tirrenia-Calambrone', 'Marina di Pisa-Tirrenia-Calambrone', 'Tirren''ja,Tirrenia,Тирренья', 43.6271900, 10.2920400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81502, 'Tires', 'Tires', 'Tiers,Tires,Tyrehs,di lei si,tiresu,Тирес,Тырэс,Тірес,ティーレス,蒂雷斯', 46.4681700, 11.5270400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81503, 'Tirano', 'Tirano', 'Tirano,Tiranum,tirano,Тирано', 46.2148200, 10.1633500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81504, 'Tione di Trento', 'Tione di Trento', 'T''one-di-Trento,Thionum,Tio,Tione,Tione di Trento,Tione in Giudicarie,Tió,di ao nei di te lun tuo,Тьоне-ди-Тренто,Тьоне-ді-Тренто,ティオーネ・ディ・トレント,蒂奥内迪特伦托', 46.0355000, 10.7267900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81505, 'Tione degli Abruzzi', 'Tione degli Abruzzi', 'Tione degli Abruzzi', 42.2039300, 13.6357000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81506, 'Tinnura', 'Tinnura', 'Tinnura', 40.2691600, 8.5481500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81507, 'Tiglieto', 'Tiglieto', 'O Tilieto,Tiglieto', 44.5232400, 8.6192500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81508, 'Ticineto', 'Ticineto', 'Ticineto,Tisneis,Tisnèis', 45.0962700, 8.5531500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81509, 'Ticengo', 'Ticengo', '', 45.3692700, 9.8276600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81510, 'Tecchiena', 'Tecchiena', 'Tecchiena,Ticchiena', 41.6882200, 13.3453800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81511, 'Tiana', 'Tiana', 'Tiana', 40.0674600, 9.1481700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81512, 'Thiesi', 'Thiesi', 'Thiesi,Tiesi', 40.5239800, 8.7200100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81513, 'Thiene', 'Thiene', 'T''ene,Thiene,Тьене', 45.7088000, 11.4795900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81514, 'Tezze', 'Tezze', 'Tezze,Tezze sul Brenta', 45.6901100, 11.7067200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81515, 'Tezze', 'Tezze', '', 45.5340200, 11.3699700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81516, 'Teti', 'Teti', 'Teti', 40.0973700, 9.1192300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81517, 'Testico', 'Testico', 'Testego,Testico', 44.0055300, 8.0263900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81518, 'Tessera', 'Tessera', 'Boarie Tessera,Tessera', 45.5024100, 12.3263200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81519, 'Tessennano', 'Tessennano', 'Tessennano', 42.4780300, 11.7910100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81520, 'Tesimo', 'Tesimo', 'Tehzima,Tesenum,Tesimo,Tezimo,Tisens,tai xi mo,tejimo,Тезимо,Тезімо,Тэзіма,Տեզիմո,テージモ,泰西莫', 46.5654200, 11.1693700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81521, 'Tesero', 'Tesero', 'Tesero,tezero,テーゼロ', 46.2918400, 11.5094600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81522, 'Terzorio', 'Terzorio', 'O Tresseu,Terzorio', 43.8523200, 7.8983500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81523, 'Terzigno', 'Terzigno', 'Terzigno,terutsu~inyo,テルツィーニョ', 40.8040000, 14.4930900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81524, 'Terruggia', 'Terruggia', 'Terruggia,Trugia', 45.0819900, 8.4442800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81525, 'Terrossa', 'Terrossa', '', 45.4634000, 11.3186000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81526, 'Terricciola', 'Terricciola', '', 43.5250500, 10.6796100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81527, 'Terrazzo', 'Terrazzo', '', 45.1726000, 11.3948500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81528, 'Terrarossa', 'Terrarossa', 'Terrarossa', 44.2336200, 9.9611000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81529, 'Terranuova Bracciolini', 'Terranuova Bracciolini', '', 43.5508100, 11.5807500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81530, 'Terracina', 'Terracina', 'Terrachina,Terracina,terrachina,Террачина,テッラチーナ', 41.2917400, 13.2435900, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81531, 'Terontola', 'Terontola', '', 43.2100900, 12.0111300, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81532, 'Terni', 'Terni', 'Interamna,Terni,teruni,Терни,テルニ', 42.5633500, 12.6432900, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81533, 'Ternate', 'Ternate', 'Ternate', 45.7867300, 8.6993100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81534, 'Termoli', 'Termoli', 'Termoli,Термоли', 41.9999400, 14.9938900, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81535, 'Termeno', 'Termeno', 'Tarmeno,Tarmèno,Tramin,Tramin an der Weinstrasse,Tramín', 46.3415100, 11.2422800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81536, 'Terlizzi', 'Terlizzi', 'Terlicci,Terlizzi,Терлицци', 41.1290500, 16.5453600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81537, 'Terlano', 'Terlano', 'Terlan,Terlano,terurano,テルラーノ', 46.5321600, 11.2468900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81538, 'Terlago', 'Terlago', 'Terlago,terurago,テルラーゴ', 46.0973700, 11.0450500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81539, 'Terenzo', 'Terenzo', '', 44.6104800, 10.0895600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81540, 'Zugliano-Terenzano-Cargnacco', 'Zugliano-Terenzano-Cargnacco', '', 46.0075000, 13.2169400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81541, 'Terento', 'Terento', 'Tehrehnta,Terenten,Terento,Terentum,tai lun tuo,terento,Теренто,Тэрэнта,Տերենտո,テレント,泰伦托', 46.8299200, 11.7828800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81542, 'Terelle', 'Terelle', 'Terelle', 41.5521200, 13.7784100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81543, 'Terdobbiate', 'Terdobbiate', 'Terdobbiate', 45.3758800, 8.6945800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81544, 'Teramo', 'Teramo', 'Interamnium,QEA,Teramo,Téramo,teramo,Терамо,テーラモ', 42.6612300, 13.6990100, 'IT', '2017-07-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81545, 'Teora', 'Teora', 'Teora', 40.8528200, 15.2533500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81546, 'Teor', 'Teor', 'Teor', 45.8541600, 13.0560800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81547, 'Tenno', 'Tenno', 'Ten,Tenno,Teno,Thennum,ten''no,teng nuo,Тенно,Тено,Տեննո,テンノ,滕诺', 45.9193700, 10.8316000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81548, 'Tencarola', 'Tencarola', '', 45.3949000, 11.8091900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81549, 'Temù', 'Temu', '', 46.2502200, 10.4659200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81550, 'Tempio Pausania', 'Tempio Pausania', 'Tempio Pausania,Tempio Pausanija,Tempiu,Templum,Tèmpiu,Темпио Паусания,テンピオ・パウザーニア', 40.9006800, 9.1045600, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81551, 'Telve', 'Telve', 'Telve,Telve Valsugana,teruvu~e,テルヴェ', 46.0701100, 11.4802200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81552, 'Telti', 'Telti', 'Telti', 40.8757500, 9.3532800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81553, 'Telgate', 'Telgate', 'Telgate', 45.6279200, 9.8491200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81554, 'Telese', 'Telese', 'Telese', 41.2175200, 14.5268100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81555, 'Tegoleto', 'Tegoleto', '', 43.3945800, 11.7853000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81556, 'Teglio Veneto', 'Teglio Veneto', 'Teglio Veneto,Tei', 45.8163700, 12.8841400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81557, 'Teglio', 'Teglio', 'Teglio,Tel''o,Тельо', 46.1723500, 10.0639900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81558, 'Teggiano-Macchiaroli', 'Teggiano-Macchiaroli', 'Teggiano,Tegiano', 40.3792100, 15.5404600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81559, 'Teano', 'Teano', 'Teano,teano,Теано', 41.2513200, 14.0665200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81560, 'Teana', 'Teana', 'Teana,Theana,tai ya na,teana,tyana,Теана,Տեանա,تيانا,テアーナ,泰亚纳', 40.1258600, 16.1528100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81561, 'Tavullia', 'Tavullia', 'Tavulia,Tavulija,Tavullia,Tavullija,Tavułia,Tomba di Pesaro,Tumba Pisaurensium,Urbania,ta wu li ya,tavurria,Тавулия,Тавуллия,Тавуллія,Тавулія,Տավուլիա,タヴッリア,塔武利亚', 43.8979100, 12.7510800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81562, 'Tavoleto', 'Tavoleto', 'Tavoleto', 43.8440200, 12.5941800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81563, 'Tavernole', 'Tavernole', 'Tavernole,Tavernole sul Mella', 45.7461800, 10.2395200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81564, 'Tavernola Bergamasca', 'Tavernola Bergamasca', 'Tavernola,Tavernola Bergamasca', 45.7084600, 10.0445400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81565, 'Tavernelle', 'Tavernelle', '', 43.7320300, 12.8834900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81566, 'Tavernelle', 'Tavernelle', '', 43.0033300, 12.1452000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81567, 'Taverne D''Arbia', 'Taverne D''Arbia', 'Taverne,Taverne d''Arbia', 43.2949000, 11.3948300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81568, 'Tavenna', 'Tavenna', 'Tavenna', 41.9089800, 14.7617600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81569, 'Tavazzano', 'Tavazzano', '', 45.3278300, 9.4047300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81570, 'Tavarnuzze', 'Tavarnuzze', '', 43.7101900, 11.2172100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81571, 'Tavagnasco', 'Tavagnasco', 'Settimo Tavagnasco,Tavagnasch,Tavagnasco,tavu~anyasuko,タヴァニャスコ', 45.5444800, 7.8229300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81572, 'Tavagnacco', 'Tavagnacco', 'Tavagna,Tavagnacco', 46.1097600, 13.2225100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81573, 'Taurasi', 'Taurasi', 'Taurasi', 41.0108000, 14.9598000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81574, 'Taurano', 'Taurano', 'Taurano', 40.8844400, 14.6342700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81575, 'Tassullo', 'Tassullo', 'Tassullo,Tassullum,Tasulo,ta su luo,tassurro,Тассулло,Տասուլո,タッスッロ,塔苏洛', 46.3429800, 11.0453900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81576, 'Tarzo', 'Tarzo', 'Larzo,Tarzo', 45.9771100, 12.2291700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81577, 'Tarvisio', 'Tarvisio', 'Tarvis,Tarvisio,Tarvisium,Tarvizia,Tarvizijus,Tarvizio,Trbiz,Trbiž,ta er wei xiao,tarfyzyw,taruvu~ijio,tarwyzyw,trwwyzyw,Тарвизио,Тарвізіа,Тарвізіо,Տարվիզիո,טרוויזיו,تارفيزيو,تارویزیو,タルヴィージオ,塔尔维肖', 46.5056700, 13.5868900, 'IT', '2016-07-31', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81578, 'Tarquinia', 'Tarquinia', 'Tarkvinii,Tarquinia,Tarquínia,tarukuinia,Тарквинии,タルクイーニア', 42.2541900, 11.7565700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81579, 'Tarcento', 'Tarcento', 'Tarcento,Tarcint', 46.2125100, 13.2151400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81580, 'Taranto', 'Taranto', 'TAR,Taranto,Tarde,Tarent,Tarente,Tarento,Tarento - Taranto,Tarentum,Tàrent,taranto,tarantw,Таранто,تارانتو,ტარანტო,ターラント', 40.4643800, 17.2470700, 'IT', '2017-05-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81581, 'Tarantasca', 'Tarantasca', 'Tarantasca', 44.4932200, 7.5445900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81582, 'Taranta Peligna', 'Taranta Peligna', 'Taranta Peligna', 42.0205200, 14.1710300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81583, 'Tarano', 'Tarano', 'Taramne,Tarano,Taranu,ta la nuo,talano,tarano,Тарано,Տարանո,タラーノ,塔拉诺,타라노', 42.3559300, 12.5949700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81584, 'Taneto', 'Taneto', '', 44.7720200, 10.4556300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81585, 'La Saletta-Tamara', 'La Saletta-Tamara', '', 44.8815100, 11.7723600, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81586, 'Tamai', 'Tamai', '', 45.9242700, 12.5718700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81587, 'Talmassons', 'Talmassons', 'Talmassons', 45.9281000, 13.1219900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81588, 'Talla', 'Talla', 'Talla', 43.6018500, 11.7871400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81589, 'Talana', 'Talana', 'Talana', 40.0415700, 9.4955400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81590, 'Talamello', 'Talamello', 'Talamello', 43.9056600, 12.2848400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81591, 'Taipana', 'Taipana', 'Taipana,Taipane', 46.2491100, 13.3415000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81592, 'Taino', 'Taino', 'Taino', 45.7624900, 8.6165400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81593, 'Taibon Agordino', 'Taibon Agordino', '', 46.2983800, 12.0131200, 'IT', '2013-02-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81594, 'Taglio di Po', 'Taglio di Po', 'Taglio di Po', 45.0018900, 12.2138600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81595, 'Taglio', 'Taglio', 'Contarina-Taglio,Contarina-Tàglio,Porto Viro,Taglio,Taglio di Porto Viro,Taglio-Contarina', 45.0222200, 12.2108300, 'IT', '2012-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81596, 'Tagliacozzo', 'Tagliacozzo', 'Tagliacozzo', 42.0693300, 13.2546900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81597, 'Taggia', 'Taggia', 'Taggia', 43.8461200, 7.8522300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81598, 'Tadasuni', 'Tadasuni', 'Tadasuni', 40.1099500, 8.8835300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81599, 'Taceno', 'Taceno', 'Taceno,Tacenum,Tacheno,Tasen,Tazeno,ta qie nuo,tacheno,Тазено,Тачено,Տազենո,タチェーノ,塔切诺', 46.0225300, 9.3640000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81600, 'Suzzara', 'Suzzara', '', 44.9924200, 10.7440700, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81601, 'Suvereto', 'Suvereto', 'Suvereto,suvu~ereto,スヴェレート', 43.0766900, 10.6774000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81602, 'Sutri', 'Sutri', '', 42.2459600, 12.2171500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81603, 'Sustinente', 'Sustinente', '', 45.0709600, 11.0217800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81604, 'Susegana', 'Susegana', 'Susegana', 45.8560400, 12.2574100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81605, 'Susa', 'Susa', 'Segusium,Susa,Susa i Italia,Suse,Suza,susa,suza,swsa,swsa  pymwnt,Суза,Սուզա,سوسا,سوسا، پیمونت,スーザ,수사', 45.1367700, 7.0580900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81606, 'Surbo', 'Surbo', 'Surbo', 40.3938300, 18.1345600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81607, 'Surano', 'Surano', 'Surano', 40.0281800, 18.3459100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81608, 'Supino', 'Supino', 'Supino', 41.6213500, 13.2345200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81609, 'Supersano', 'Supersano', 'Supersano', 40.0165500, 18.2420500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81610, 'Suno', 'Suno', 'Suno', 45.6313700, 8.5443700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81611, 'Suni', 'Suni', 'Suni', 40.2808500, 8.5494200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81612, 'Summonte', 'Summonte', 'Summonte', 40.9487400, 14.7445800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81613, 'Sumirago', 'Sumirago', 'Sumirago', 45.7365100, 8.7835600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81614, 'Sulzano', 'Sulzano', 'Sulzano', 45.6873200, 10.0998800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81615, 'Sulmona', 'Sulmona', 'QLN,Salmona,Sulmo,Sulmona,Сулмона', 42.0494500, 13.9257800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81616, 'Sueglio', 'Sueglio', 'Sueglio', 46.0857900, 9.3337400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81617, 'Subiaco', 'Subiaco', 'Sub''jako,Subiaco,Subiacu,Subiako,Subijako,Subjako,Sublacum,Subyako,su bi ya ke,subiako,Субиако,Субијако,Субьяко,Субяко,Սուբյակո,スビアーコ,苏比亚科,수비아코', 41.9261900, 13.0890600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81618, 'Subbiano', 'Subbiano', 'Subb''jano,Subbiano,Subbianu,Subbjano,Subian,Subiano,Subianum,Subjana,su bi ya nuo,subbiano,Суббьяно,Суббяно,Субиано,Субяна,Սուբիանո,スッビアーノ,苏比亚诺', 43.5781500, 11.8714000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81619, 'Suardi', 'Suardi', 'Suardi', 45.0324700, 8.7412700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81620, 'Sturno', 'Sturno', 'Sturno', 41.0221700, 15.1124800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81621, 'Strudà', 'Struda', '', 40.3199100, 18.2817600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81622, 'Strozza', 'Strozza', 'Strozza', 45.7729400, 9.5788600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81623, 'Stroppo', 'Stroppo', 'Stroppo', 44.5065300, 7.1265200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81624, 'Stroppiana', 'Stroppiana', 'Stroppiana', 45.2303700, 8.4546100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81625, 'Stroncone', 'Stroncone', 'Castrum Hugonis,Stronkone,Struncuni,seuteulonkone,si te long ke nei,strwnkwny,sutoronkone,Стронконе,Ստրոնկոնե,سترونكوني,ストロンコーネ,斯特龙科内,스트론코네', 42.5119600, 12.6477000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81626, 'Strigno', 'Strigno', 'Strigno,sutorinyo,ストリーニョ', 46.0669000, 11.5222400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81627, 'Striano', 'Striano', 'Striano,sutoriano,ストリアーノ', 40.8154300, 14.5753400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81628, 'Strevi', 'Strevi', '', 44.6998500, 8.5247000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81629, 'Strettoia', 'Strettoia', 'Strettoia,Strettoja', 43.9898700, 10.1935700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81630, 'Stresa', 'Stresa', 'Strehza,Stresa,Stresa Borromeo,Streza,Strixia,si te lei sa,sutoreza,Стреза,Стрэза,ストレーザ,斯特雷萨', 45.8815800, 8.5383400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81631, 'Stregna', 'Stregna', 'Stregna,Stregne', 46.1268900, 13.5776100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81632, 'Strangolagalli', 'Strangolagalli', 'Strangolagalli', 41.5999200, 13.4922800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81633, 'Strambino', 'Strambino', 'Strambin,Strambino,Strambino Romano,sutoranbino,ストランビーノ', 45.3799000, 7.8896700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81634, 'Stradella', 'Stradella', 'Stradela,Stradella,Stradéla,Stratella,si te la de la,strdyla,sutoraderra,Страдела,Страделла,Ստրադելա,سترديلا,ストラデッラ,斯特拉德拉', 45.0744500, 9.3016900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81635, 'Strada in Chianti', 'Strada in Chianti', 'Strada in Chianti', 43.6587400, 11.2967800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81636, 'Stra', 'Stra', 'Stra', 45.4112300, 12.0141800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81637, 'Storo', 'Storo', 'Storo,sutoro,ストーロ', 45.8492500, 10.5802200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81638, 'Stornarella', 'Stornarella', 'Stornarella', 41.2559100, 15.7302300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81639, 'Stornara', 'Stornara', 'Stornara', 41.2867200, 15.7700300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81640, 'Stio', 'Stio', 'Stio', 40.3102000, 15.2515300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81641, 'Stintino', 'Stintino', 'Istintino,Stintino', 40.9520100, 8.2197800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81642, 'Stimigliano', 'Stimigliano', 'Stinugliano', 42.3010300, 12.5633700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81643, 'Stigliano', 'Stigliano', 'Stigliano', 40.4023700, 16.2298300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81644, 'Stienta', 'Stienta', 'St''enta,Stienta,si di ye en ta,sutienta,Стиента,Стьента,Стієнта,Ստիենտա,スティエンタ,斯蒂耶恩塔', 44.9397000, 11.5437500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81645, 'Stia', 'Stia', 'Staia,Stia,Stija,Styja,si di ya,sutia,Стия,Стыя,Стія,Ստիա,スティーア,斯蒂亚', 43.7987700, 11.7089400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81646, 'Stezzano', 'Stezzano', 'Stezzano', 45.6496800, 9.6519200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81647, 'Sternatia', 'Sternatia', 'Starnaitta,Starnaìtta,Sternatia,Sternatìa', 40.2202200, 18.2274800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81648, 'Stenico', 'Stenico', 'Stenico,suteniko,ステーニコ', 46.0512400, 10.8556200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81649, 'Stelvio', 'Stelvio', 'Stehl''via,Stel''vio,Stelvio,Stilfs,Stilvis,si tai er wei ao,suteruvu~io,Στέλβιο,Стелвио,Стельвио,Стельвіо,Стэльвіа,Ստելվիո,ステルヴィオ,斯泰尔维奥', 46.5976700, 10.5458000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81650, 'Stellanello', 'Stellanello', 'Stellanello,Stenanelo', 43.9999300, 8.0602500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81651, 'Stella Cilento', 'Stella Cilento', 'Stella Cilento', 40.2318000, 15.0928600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81652, 'Stazzano', 'Stazzano', 'Stazzano', 44.7272800, 8.8684600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81653, 'Statte', 'Statte', 'Statte', 40.5285600, 17.2012200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81654, 'Staranzano', 'Staranzano', 'Staranzan,Staranzano', 45.8023300, 13.5022600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81655, 'Stanghella', 'Stanghella', 'Stranghella', 45.1350900, 11.7574100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81656, 'Stanghe', 'Stanghe', 'Sianga,Stanga,Stanghe', 46.8821900, 11.3776400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81657, 'Stagno Lombardo', 'Stagno Lombardo', '', 45.0745900, 10.0889000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81658, 'Staggia', 'Staggia', '', 43.4218200, 11.1836400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81659, 'Staffolo', 'Staffolo', 'Staffolo,sutafforo,スタッフォロ', 43.4332600, 13.1848700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81660, 'Staffa', 'Staffa', '', 45.9685500, 7.9670800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81661, 'Stabbia', 'Stabbia', '', 43.7826600, 10.8347500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81662, 'Squinzano', 'Squinzano', 'Squinzano', 40.4351300, 18.0408600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81663, 'Spresiano', 'Spresiano', 'Spresiano', 45.7790800, 12.2562800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81664, 'Spotorno', 'Spotorno', 'Spotorno', 44.2263800, 8.4164700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81665, 'Sporminore', 'Sporminore', 'Sporminore,suporuminore,スポルミノーレ', 46.2369200, 11.0291900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81666, 'Spormaggiore', 'Spormaggiore', 'Spor,Spormaggiore,suporumajjore,スポルマッジョーレ', 46.2185300, 11.0480500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81667, 'Spongano', 'Spongano', 'Spongano', 40.0178200, 18.3656300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81668, 'Spoltore', 'Spoltore', 'Spoltore', 42.4550100, 14.1398800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81669, 'Spoleto', 'Spoleto', 'Spoletas,Spolete,Spoletium,Spoleto,Spolète,Spuletu,sbwlytw,seupolleto,si bo lai tuo,spwltw,suporeto,Сполето,ספולטו,سبوليتو,スポレート,斯波莱托,스폴레토', 42.7407100, 12.7389900, 'IT', '2015-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81670, 'Spirano', 'Spirano', 'Spirano', 45.5814400, 9.6686300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81671, 'Spinoso', 'Spinoso', 'Spinoso', 40.2692100, 15.9665800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81672, 'Spino d''Adda', 'Spino d''Adda', 'Spino d''Ada,Spino d''Adda,Спино д''Ада', 45.4008600, 9.4867400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81673, 'Spinetta Marengo', 'Spinetta Marengo', 'Spinetta,Spinetta Marengo', 44.8855400, 8.6775000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81674, 'Spinetoli', 'Spinetoli', 'Spinetoli', 42.8898400, 13.7649700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81675, 'Spinete', 'Spinete', 'Spinete', 41.5443100, 14.4874300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81676, 'Le Casine-Perignano-Spinelli', 'Le Casine-Perignano-Spinelli', 'Le Casine,Perignano,Spinelli', 43.6000000, 10.5833300, 'IT', '2017-01-31', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81677, 'Spineda', 'Spineda', 'Spineda', 45.0614000, 10.5116500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81678, 'Spinazzola', 'Spinazzola', 'Spinazzola', 40.9639900, 16.0911100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81679, 'Spilimbergo', 'Spilimbergo', 'Spilimberc,Spilimbergo', 46.1134500, 12.8924100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81680, 'Spilamberto', 'Spilamberto', '', 44.5327300, 11.0169700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81681, 'Spigno Saturnia Superiore', 'Spigno Saturnia Superiore', 'Spigno,Spigno Saturnia,スピーニョ・サトゥルニア', 41.3142500, 13.7088800, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81682, 'Spigno Monferrato', 'Spigno Monferrato', 'Spign,Spigno,Spigno Monferrato', 44.5431400, 8.3339500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81683, 'Spianate', 'Spianate', '', 43.8107500, 10.7151000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81684, 'Sperlonga', 'Sperlonga', 'Sperlonga,superuronga,スペルロンガ', 41.2589700, 13.4330200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81685, 'Spello', 'Spello', 'Spello', 42.9923100, 12.6663200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81686, 'Sparone', 'Sparone', 'Sparon,Sparone,suparone,スパローネ', 45.4144200, 7.5451600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81687, 'Sparanise', 'Sparanise', 'Sparanise', 41.1878800, 14.0962800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81688, 'Sozzago', 'Sozzago', '', 45.3983200, 8.7227100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81689, 'Sovicille', 'Sovicille', 'Sovicille,sovu~ichirre,ソヴィチッレ', 43.2803300, 11.2282800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81690, 'Soverzene', 'Soverzene', 'Soverzene', 46.2033100, 12.3030100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81691, 'Sovere', 'Sovere', 'Sovere', 45.8118800, 10.0343800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81692, 'Sotto il Monte Giovanni XXIII', 'Sotto il Monte Giovanni XXIII', 'Sotto il Monte Gioganni XX111', 45.7056800, 9.5034500, 'IT', '2012-03-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81693, 'Sossano', 'Sossano', 'Sossano', 45.3575400, 11.5081900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81694, 'Sospirolo', 'Sospirolo', 'Sospirold,Sospirolo', 46.1413400, 12.0736500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81695, 'Sospiro', 'Sospiro', 'Sexpilas,Sospiro,Suspir,sosupiro,suo si pi luo,Соспиро,Соспіро,Սոսպիրո,ソスピーロ,索斯皮罗', 45.1076200, 10.1585300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81696, 'Sorso', 'Sorso', 'Sorso', 40.7994900, 8.5757000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81697, 'Sorrento', 'Sorrento', 'RRO,Sorrent,Sorrente,Sorrento,Surriento,sorento,swrntw,Сорренто,סורנטו,सोरेन्टो,ソレント', 40.6237500, 14.3809600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81698, 'Sorradile', 'Sorradile', 'Sorradile', 40.1063400, 8.9323600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81699, 'Sormano', 'Sormano', 'Sormano', 45.8780300, 9.2458200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81700, 'Sorisole', 'Sorisole', 'Sorisole', 45.7314000, 9.6371500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81701, 'Soriano nel Cimino', 'Soriano nel Cimino', 'Soriano nel Cimino', 42.4182000, 12.2341400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81702, 'Sori', 'Sori', 'Soei,Sori,Sory,Surium,Söi,sori,suo li,Сори,Соры,Сорі,Սորի,ソーリ,索里', 44.3730100, 9.1047000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81703, 'Sorgono', 'Sorgono', 'Sorgono', 40.0259500, 9.1020300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81704, 'Soresina', 'Soresina', 'Soresina', 45.2881900, 9.8586200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81705, 'Sordevolo', 'Sordevolo', 'Sordevolo', 45.5734600, 7.9734200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81706, 'Sorbo Serpico', 'Sorbo Serpico', 'Sorbo Serpico,Sorbo di Serpico,Sorbo di Sèrpico', 40.9168500, 14.8870900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81707, 'Sorbolo', 'Sorbolo', '', 44.8458700, 10.4437500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81708, 'Sorbara', 'Sorbara', '', 44.7480800, 11.0073100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81709, 'Sorano', 'Sorano', '', 42.6811800, 11.7194300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81710, 'Soragna', 'Soragna', 'Soragna', 44.9268600, 10.1201300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81711, 'Sora', 'Sora', 'QXE,Sora,sora,Сора,სორა', 41.7182900, 13.6135600, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81712, 'Soprabolzano', 'Soprabolzano', 'Soprabolzano,Unterinn,Ville di Bolzano', 46.5289900, 11.4040800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81713, 'Sonnino', 'Sonnino', 'Sonnino,son''nino,ソンニーノ', 41.4167300, 13.2459200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81714, 'Sonico', 'Sonico', 'Sonico', 46.1664000, 10.3507100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81715, 'Sondrio', 'Sondrio', 'Sondri,Sondrio,Sundrium,sang zhi ao,sondorio,sundrium,Сондрио,ソンドリオ,桑治奧', 46.1685200, 9.8713400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81716, 'Sondalo', 'Sondalo', 'Sondalo,Сондало', 46.3298300, 10.3269000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81717, 'Soncino', 'Soncino', 'Sonchino,Soncino,Сончино', 45.4003300, 9.8684500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81718, 'Sona', 'Sona', 'Sona,sona,ソーナ', 45.4327100, 10.8399000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81719, 'Somma Vesuviana', 'Somma Vesuviana', 'Somma,Somma Vesuviana,ソンマ・ヴェズヴィアーナ', 40.8732900, 14.4386500, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81720, 'Sommariva Perno', 'Sommariva Perno', 'Sommariva Perno,Summariva Perno', 44.7456400, 7.9006300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81721, 'Sommariva del Bosco', 'Sommariva del Bosco', 'Somariva Bosch,Somariva Bòsch,Sommariva Bosco,Sommariva del Bosco', 44.7725700, 7.7817700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81722, 'Somma Lombardo', 'Somma Lombardo', 'Somma,Somma Lombardo,ソンマ・ロンバルド', 45.6821300, 8.7075900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81723, 'Sommacampagna', 'Sommacampagna', 'Sommacamagna,Sommacampagna,sonmakanpanya,ソンマカンパーニャ', 45.4052800, 10.8438200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81724, 'Solto Collina', 'Solto Collina', 'Solto Collina', 45.7823000, 10.0263800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81725, 'Solopaca', 'Solopaca', '', 41.1953500, 14.5476700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81726, 'Solofra', 'Solofra', 'Solofra', 40.8334300, 14.8370500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81727, 'Solignano Nuovo', 'Solignano Nuovo', 'Solignano,Solignano Nuovo', 44.5274600, 10.9262600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81728, 'Soliera', 'Soliera', 'Soliera,soriera,ソリエーラ', 44.7338700, 10.9217700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81729, 'Solferino', 'Solferino', 'Sol''ferino,Solferino,Solférino,Sulferinum,Sulfri,Sulfrì,soruferino,su fa li nuo,swlfrynw,Σολφερίνο,Солферино,Сольферино,Սոլֆերինո,سولفرینو,ソルフェリーノ,蘇法利諾', 45.3723600, 10.5664800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81730, 'Soleto', 'Soleto', 'Soleto,Sulitu', 40.1878100, 18.2063000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81731, 'Solesino', 'Solesino', 'Solesino', 45.1792200, 11.7464700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81732, 'Solero', 'Solero', 'Solero', 44.9183500, 8.5075400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81733, 'Soldano', 'Soldano', 'O Saudan,Soldano', 43.8295400, 7.6562700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81734, 'Solbiate Olona', 'Solbiate Olona', 'Solbiate Olona', 45.6502800, 8.8819800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81735, 'Solbiate Arno', 'Solbiate Arno', 'Solbiate Arno', 45.7196000, 8.8137200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81736, 'Solarolo Rainerio', 'Solarolo Rainerio', 'Solarolo Bainerio,Solarolo Rainerio', 45.0812600, 10.3571100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81737, 'Solarolo', 'Solarolo', 'Solarolo,soraroro,ソラローロ', 44.3589200, 11.8466100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81738, 'Solaro', 'Solaro', 'Solarium,Solaro,Soree,soraro,suo la luo,Соларо,Սոլարո,ソラーロ,索拉罗', 45.6142700, 9.0830400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81739, 'Solaro', 'Solaro', '', 44.8799000, 9.1731500, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81740, 'Solagna', 'Solagna', 'Solagna', 45.8195100, 11.7178700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81741, 'Sogliano Cavour', 'Sogliano Cavour', 'Sogliano Cavour', 40.1482700, 18.1974100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81742, 'Sogliano al Rubicone', 'Sogliano al Rubicone', 'Sogliano,Sogliano al Rubicone', 44.0050000, 12.3012200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81743, 'Soddì', 'Soddi', 'Soddi,Soddì', 40.1299100, 8.8779800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81744, 'Soci', 'Soci', '', 43.7282100, 11.8109600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81745, 'Soave', 'Soave', 'Soave,soavu~e,ソアーヴェ', 45.4195500, 11.2459400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81746, 'Soave', 'Soave', '', 45.1950900, 10.7236500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81747, 'Sluderno', 'Sluderno', 'Schledurus,Schluderns,Sluderno,zuruderuno,ズルデルノ', 46.6652400, 10.5834500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81748, 'Sizzano', 'Sizzano', 'Sizzano', 45.5766300, 8.4361300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81749, 'Siziano', 'Siziano', 'Siziano', 45.3160600, 9.2035700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81750, 'Siviano', 'Siviano', '', 45.7148700, 10.0802600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81751, 'Siusi', 'Siusi', 'Scis,Seis am Schlern,Siusi,Siusi allo Sciliar', 46.5413300, 11.5586800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81752, 'Sistiana-Visogliano', 'Sistiana-Visogliano', 'Seestein,Sesljan,Sistiana,Sistijana-Vizolano,Систиана,Систијана-Визољано', 45.7723700, 13.6382400, 'IT', '2016-07-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81753, 'Sissa', 'Sissa', '', 44.9592700, 10.2605800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81754, 'Siror', 'Siror', 'Siror,shiroru,シロール', 46.1878400, 11.8311600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81755, 'Sirolo', 'Sirolo', 'Sirolo,shiroro,シローロ', 43.5224600, 13.6149800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81756, 'Sirmione', 'Sirmione', 'Sermione,Sirmione,Сирмионе', 45.4974400, 10.6050700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81757, 'Sirignano', 'Sirignano', '', 40.9496900, 14.6293500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81758, 'Siniscola', 'Siniscola', 'Siniscola', 40.5734400, 9.6969500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81759, 'Sindia', 'Sindia', 'Sindia', 40.2951800, 8.6570700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81760, 'Sinalunga', 'Sinalunga', '', 43.2149200, 11.7450700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81761, 'Silvi', 'Silvi', 'Silvi', 42.5498400, 14.1175900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81762, 'Silvano Pietra', 'Silvano Pietra', 'Silvano Pietra', 45.0392300, 8.9463700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81763, 'Silvano d''Orba', 'Silvano d''Orba', 'Silvano,Silvano d''Orba', 44.6858000, 8.6718200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81764, 'Sillavengo', 'Sillavengo', 'Sillavengo', 45.5206700, 8.4410300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81765, 'Sillano', 'Sillano', 'Silana,Silano,Sillano,Sillanu,Syllanum,shirrano,xi la nuo,Силано,Силлано,Сілана,Сіллано,Սիլանո,シッラーノ,西拉诺', 44.2229800, 10.3023500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81766, 'Siligo', 'Siligo', 'Siligo', 40.5748300, 8.7283500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81767, 'Silea', 'Silea', 'Silea', 45.6544400, 12.2970100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81768, 'Silanus', 'Silanus', 'Silanus', 40.2870900, 8.8919900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81769, 'Silandro', 'Silandro', 'Schlanderna,Schlanders,Schlånders,Silandra,Silandro,Siłandro,shirandoro,xi lan de luo,Силандро,Сіландра,Сіландро,Սիլանդրո,シランドロ,西兰德罗', 46.6283100, 10.7680900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81770, 'Signa', 'Signa', 'Signa', 43.7942000, 11.1036000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81771, 'Sigillo', 'Sigillo', '', 43.3311100, 12.7405900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81772, 'Siena', 'Siena', 'SAY,Saena Iulia,Saena Julia,Sena,Sien-a,Siena,Sienna,Sienne,Sieno,Séna,shiena,siyena,syynh,Σιένα,Сиена,Сіена,סיינה,सियेना,シエーナ', 43.3182200, 11.3306400, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81773, 'Sicignano degli Alburni', 'Sicignano degli Alburni', 'Sicignano degli Alburni', 40.5588200, 15.3056000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81774, 'Siano', 'Siano', 'Siano', 40.8020700, 14.6933400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81775, 'Sgurgola', 'Sgurgola', 'Castrum Sculculae,Sgurgola,Zgurgola,seuguleugolla,si gu er ge la,zugurugora,Згургола,Զգուրգոլա,ズグルゴラ,斯古尔戈拉,스구르골라', 41.6689700, 13.1500900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81776, 'Sgonico', 'Sgonico', 'Sgonico,Zgonik,zugoniko,ズゴニーコ', 45.7358300, 13.7470800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81777, 'Sforzacosta', 'Sforzacosta', '', 43.2567600, 13.4228400, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81778, 'Sezze', 'Sezze', 'Sezze,settsu~e,セッツェ', 41.5003200, 13.0617600, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81779, 'Seveso', 'Seveso', 'Seveso,sevu~ezo,セーヴェゾ', 45.6467000, 9.1429600, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81780, 'Settimo Vittone', 'Settimo Vittone', 'Settimo Tavagnasco,Settimo Vittone,セッティモ・ヴィットーネ', 45.5492900, 7.8332800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81781, 'Settimo Torinese', 'Settimo Torinese', 'Seto,Settimo,Settimo Torinese,セッティモ・トリネーゼ', 45.1392500, 7.7700800, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81782, 'Settimo Rottaro', 'Settimo Rottaro', 'Settimo Bottaro,Settimo Rottaro,セッティモ・ロッターロ', 45.4077600, 7.9935200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81783, 'Settimo', 'Settimo', '', 45.4792900, 10.9091000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81784, 'Settefrati', 'Settefrati', 'Settefrati', 41.6704500, 13.8507000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81785, 'Sestri Levante', 'Sestri Levante', 'Sestri Levante', 44.2731700, 9.3968300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81786, 'Sestriere', 'Sestriere', 'Colle Sestrieres,Colle Sestrières,Sestrier,Sestriere,Sestrieres,Sestrières,sesutoriere,Сестриере,セストリエーレ', 44.9586400, 6.8775100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81787, 'Sesto San Giovanni', 'Sesto San Giovanni', 'Sesto,Sesto San Giovanni,セスト・サン・ジョヴァンニ', 45.5332900, 9.2258500, 'IT', '2015-09-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81788, 'Sestola', 'Sestola', '', 44.2299400, 10.7734900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81789, 'Sesto Imolese', 'Sesto Imolese', '', 44.4595200, 11.7291900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81790, 'Sesto Fiorentino', 'Sesto Fiorentino', 'Sesto,Sesto Fiorentino', 43.8319300, 11.1992400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81791, 'Sesto ed Uniti', 'Sesto ed Uniti', 'Sesto ed Uniti', 45.1764700, 9.9140700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81792, 'Sesto Campano', 'Sesto Campano', 'Sesto Campano', 41.4204200, 14.0778200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81793, 'Sesto Calende', 'Sesto Calende', 'Sesto Calende', 45.7260800, 8.6339700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81794, 'Sesto al Reghena', 'Sesto al Reghena', 'Sest,Sesto al Reghena', 45.8493800, 12.8129500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81795, 'Sesto', 'Sesto', 'Sankt Veit,Sesto,Sexschtn,Sexta,Sexten,sai si tuo,sesuto,sstw,Σέστο,Сесто,Սեստո,سستو,セスト,塞斯托', 46.7021600, 12.3496200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81796, 'Sestino', 'Sestino', 'Sestino', 43.7096600, 12.2978500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81797, 'Sesta Godano', 'Sesta Godano', 'A Sesta,Sesta Godano', 44.2937500, 9.6753500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81798, 'Sessano del Molise', 'Sessano del Molise', 'Sessano,Sessano del Molise', 41.6392600, 14.3277900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81799, 'Sessa Cilento', 'Sessa Cilento', 'Sessa Cilento', 40.2592000, 15.0757600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81800, 'Sessa Aurunca', 'Sessa Aurunca', 'Sessa Aurunca,Suessa', 41.2398700, 13.9296600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81801, 'Servigliano', 'Servigliano', 'Servigliano', 43.0799300, 13.4926800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81802, 'Serrone', 'Serrone', 'Serrone', 41.8421200, 13.0951900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81803, 'Serre di Rapolano', 'Serre di Rapolano', 'Serre,Serre di Rapolano', 43.2565800, 11.6165500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81804, 'Serre', 'Serre', 'Serre', 40.5825100, 15.1855500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81805, 'Serravalle Sesia', 'Serravalle Sesia', 'Serravalle Sesia', 45.6848500, 8.3085000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81806, 'Serravalle Scrivia', 'Serravalle Scrivia', 'Serravalle Libarna,Serravalle Scrivia', 44.7227700, 8.8563500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81807, 'Serravalle Pistoiese', 'Serravalle Pistoiese', 'Serravalle Pistoiese', 43.9060500, 10.8327100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81808, 'Serravalle di Chienti', 'Serravalle di Chienti', 'Serravalle di Chienti', 43.0718500, 12.9521700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81809, 'Serravalle Langhe', 'Serravalle Langhe', 'Serravalle Langhe', 44.5599500, 8.0594400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81810, 'Serra Sant''Abbondio', 'Serra Sant''Abbondio', 'Serra Sant''Abbondio', 43.4915500, 12.7740900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81811, 'Serra San Quirico', 'Serra San Quirico', 'Serra San Quirico,セッラ・サン・クイーリコ', 43.4463700, 13.0226600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81812, 'Serra Riccò', 'Serra Ricco', 'A Sǽra,Serra Ricco,Serra Riccò,Serra Rocco', 44.5107100, 8.9380600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81813, 'Serrara Fontana', 'Serrara Fontana', 'Serrara Fontana,セッラーラ・フォンターナ', 40.7147500, 13.8959300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81814, 'Serrapetrona', 'Serrapetrona', 'Serrapetrona', 43.1767100, 13.1898100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81815, 'Serrano', 'Serrano', 'Serrano', 40.1843800, 18.3515600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81816, 'Serramonacesca', 'Serramonacesca', 'Serramonacesca', 42.2479500, 14.0929700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81817, 'Serramezzana', 'Serramezzana', 'Serramezzana', 40.2446000, 15.0324600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81818, 'Serramazzoni', 'Serramazzoni', 'Monfestino,Monfestino in Serra Mazzoni', 44.4273500, 10.7905500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81819, 'Serralunga di Crea', 'Serralunga di Crea', 'Seralonga ''d Crea,Serralunga di Crea,セッラルンガ・ディ・クレーア', 45.1011000, 8.2806900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81820, 'Serra de'' Conti', 'Serra de'' Conti', 'Serra de'' Conti,Serra de''Conti,セッラ・デ・コンティ', 43.5419600, 13.0356600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81821, 'Serracapriola', 'Serracapriola', 'Serracapriola', 41.8091200, 15.1609800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81822, 'Serole', 'Serole', 'Serole', 44.5540400, 8.2597400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81823, 'Sernaglia della Battaglia', 'Sernaglia della Battaglia', 'Sernaglia della Battaglia', 45.8714700, 12.1330200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81824, 'Sermoneta', 'Sermoneta', 'Sermoneta,serumoneta,セルモネータ', 41.5491900, 12.9848100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81825, 'Sermide', 'Sermide', 'Sermide,Сермиде', 45.0034900, 11.2929000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81826, 'Serle', 'Serle', 'Serle,serure,セルレ', 45.5613700, 10.3682100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81827, 'Serino', 'Serino', 'Serino', 40.8548100, 14.8722400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81828, 'Serina', 'Serina', '', 45.8707100, 9.7310200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81829, 'Seriate', 'Seriate', 'Seriate,Сериате', 45.6853200, 9.7248700, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81830, 'Sergnano', 'Sergnano', 'Sergnano', 45.4275500, 9.7012200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81831, 'Seren del Grappa', 'Seren del Grappa', 'Seren del Grapa,Seren del Grappa,Seren-del''-Grappa,Serena,sai lun de er ge la pa,Серен дел Грапа,Серен-дель-Граппа,Սերեն դել Գրապա,セレーン・デル・グラッパ,塞伦德尔格拉帕', 45.9959400, 11.8562400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81832, 'Seregno', 'Seregno', 'Seregn,Seregno,Serègn,serenyo,セレーニョ', 45.6500200, 9.2054800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81833, 'Seravezza', 'Seravezza', 'Seravezza', 43.9947100, 10.2272000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81834, 'Sequals', 'Sequals', 'Secual,Sequals', 46.1638500, 12.8303700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81835, 'Sepino', 'Sepino', 'Sepino', 41.4078200, 14.6193800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81836, 'Sennori', 'Sennori', 'Sennori', 40.7878000, 8.5928500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81837, 'Sennariolo', 'Sennariolo', 'Sennariolo', 40.2123500, 8.5557200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81838, 'Senna Lodigiana', 'Senna Lodigiana', 'Senna Lodigiana,センナ・ロディジャーナ', 45.1502300, 9.5937900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81839, 'Senise', 'Senise', 'Senise', 40.1461600, 16.2886700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81840, 'Senigallia', 'Senigallia', 'Senigallia,Senigallija,senigarria,Сенигаллия,セニガッリア', 43.7162600, 13.2088200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81841, 'Seniga', 'Seniga', 'Seniga,seniga,セニーガ', 45.2447900, 10.1775900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81842, 'Senerchia', 'Senerchia', 'Senerchia', 40.7413300, 15.2050200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81843, 'Seneghe', 'Seneghe', 'Seneghe', 40.0812800, 8.6135300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81844, 'Senale', 'Senale', 'Unsere Liebe Frau im Walde-St. Felix', 46.5107700, 11.1101200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81845, 'Senago', 'Senago', '', 45.5756200, 9.1262000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81846, 'Semiana', 'Semiana', 'Semiana', 45.1373700, 8.7297300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81847, 'Semestene', 'Semestene', 'Semestene', 40.3984600, 8.7254200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81848, 'Selvino', 'Selvino', 'Selvino', 45.7852500, 9.7529200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81849, 'Selvazzano Dentro', 'Selvazzano Dentro', 'Selvazzano Dentro', 45.3876400, 11.7923200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81850, 'Selvatelle', 'Selvatelle', '', 43.5628100, 10.6909100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81851, 'Selva di Cadore', 'Selva di Cadore', 'Selva Bellunese,Selva di Cadore', 46.4502800, 12.0569400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81852, 'Selva dei Molini', 'Selva dei Molini', 'Muehlwald,Muhlwald,Mühlwald,Selva dei Molini,セルヴァ・デイ・モリーニ', 46.8903100, 11.8583200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81853, 'Selva', 'Selva', 'Selva,Selva di Val Gardena,Sëlva,Wolkenstein,Wolkenstein in Groeden,Wolkenstein in Gröden,セルヴァ・ディ・ヴァル・ガルデーナ', 46.5547200, 11.7603800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81854, 'Sellero', 'Sellero', 'Seilero,Sellero,serrero,セッレロ', 46.0514500, 10.3476400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81855, 'Sellano', 'Sellano', 'Sellano', 42.8873500, 12.9231100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81856, 'Selci', 'Selci', 'Selci', 42.3029300, 12.6213500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81857, 'Segrate', 'Segrate', 'SWK,Segrate,segurate,セグラーテ', 45.4918500, 9.2981200, 'IT', '2015-08-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81858, 'Segni', 'Segni', 'Segni,Sen''i,Signia,seni,Сеньи,Сеньї,セーニ', 41.6889300, 13.0193400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81859, 'Seggiano', 'Seggiano', 'Seggiano', 42.9289700, 11.5573600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81860, 'Sefro', 'Sefro', 'Sefro', 43.1474300, 12.9485900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81861, 'Sedrina', 'Sedrina', 'Sedrina', 45.7806700, 9.6236200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81862, 'Sedriano', 'Sedriano', 'Sedriano,sedoriano,セドリアーノ', 45.4910500, 8.9716100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81863, 'Sedini', 'Sedini', 'Sedini', 40.8527700, 8.8167000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81864, 'Sedilo', 'Sedilo', 'Sedilo', 40.1729200, 8.9199300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81865, 'Sedico', 'Sedico', 'Sedico', 46.1056300, 12.0933000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81866, 'Sedegliano', 'Sedegliano', 'Sedean,Sedegliano,Sedigliano', 46.0139600, 12.9773400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81867, 'Secugnago', 'Secugnago', 'Secugnago,sekunyago,セクニャーゴ', 45.2313200, 9.5939400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81868, 'Seclì', 'Secli', 'Secli,Seclì', 40.1189700, 18.1093100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81869, 'Secinaro', 'Secinaro', 'Secinaro', 42.1506200, 13.6814500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81870, 'Secchiano', 'Secchiano', '', 43.9239900, 12.3161500, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81871, 'Seborga', 'Seborga', 'A Seborca,Seborga,Seborgaen,Seborgän,seboleuga,seborja,seboruga gong guo,Себорга,სებორჯა,セボルガ公国,세보르가', 43.8273000, 7.6958500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81872, 'Seano', 'Seano', '', 43.8303500, 11.0212200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81873, 'Scurcola Marsicana', 'Scurcola Marsicana', 'Scurcola Marsicana', 42.0631300, 13.3391900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81874, 'Scorzè', 'Scorze', 'Scorze,Scorzè,sukorutsu~e,スコルツェ', 45.5740500, 12.1115600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81875, 'Scortichino', 'Scortichino', '', 44.8833300, 11.3333300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81876, 'Scorrano', 'Scorrano', 'Scorrano', 40.0901800, 18.2999300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81877, 'Scoppito', 'Scoppito', 'Scoppito', 42.3694800, 13.2593600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81878, 'Scopello', 'Scopello', 'Scopel,Scopello,Scopellum,Scopél,Scupel,Skapela,Skopello,Skopelo,si ke pei luo,sukoperro,Скапела,Скопелло,Սկոպելո,スコペッロ,斯科佩洛', 45.7736900, 8.0943500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81879, 'Scontrone', 'Scontrone', 'Scontrone', 41.7468100, 14.0388000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81880, 'Scomigo', 'Scomigo', '', 45.9425500, 12.3201400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81881, 'Sciolze', 'Sciolze', 'Sciolze,Siosse,shorutsu~e,ショルツェ', 45.0945300, 7.8781800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81882, 'Naz-Sciaves - Natz-Schabs', 'Naz-Sciaves - Natz-Schabs', 'Natz-Schabs,Naz-Sciaves,Schabs,natsu=shavu~esu,ナツ＝シャーヴェス', 46.7688300, 11.6655800, 'IT', '2012-02-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81883, 'Schio', 'Schio', 'Schio,Skio,Скио', 45.7126200, 11.3567100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81884, 'Schilpario', 'Schilpario', 'Schilpario', 46.0087400, 10.1553400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81885, 'Schiavon', 'Schiavon', 'Schiavon', 45.6965400, 11.6457300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81886, 'Schiavi di Abruzzo', 'Schiavi di Abruzzo', 'Schiavi di Abruzzo', 41.8131100, 14.4865500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81887, 'Gazzada Schianno', 'Gazzada Schianno', '', 45.7801700, 8.8334400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81888, 'Scheggino', 'Scheggino', 'Scheggino', 42.7130400, 12.8300700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81889, 'Scheggia', 'Scheggia', 'Scheggia e Pascelupo', 43.4036400, 12.6658400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81890, 'Scerni', 'Scerni', 'Scerni', 42.1041800, 14.5742800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81891, 'Scerne', 'Scerne', 'La Sega,Scerne', 42.6475400, 14.0379100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81892, 'Scarperia', 'Scarperia', 'Castrum Sancti Barnabae,Scarperia,Skarperia,Skarperija,Skarperyja,si ka er pei li ya,sukaruperia,Скарперия,Скарперыя,Скарперія,Սկարպերիա,スカルペリーア,斯卡尔佩里亚', 43.9935700, 11.3541500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81893, 'Scarnafigi', 'Scarnafigi', 'Scarnafigi,Scarnafis,Soarnafigi', 44.6794400, 7.5651300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81894, 'Scarmagno', 'Scarmagno', 'Scarmagn,Scarmagno,sukarumanyo,スカルマーニョ', 45.3849200, 7.8411000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81895, 'Scarlino', 'Scarlino', 'Scarlino', 42.9079900, 10.8514800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81896, 'Scario', 'Scario', 'Scario', 40.0620700, 15.4742100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81897, 'Scapoli', 'Scapoli', 'Scapoli', 41.6144700, 14.0592900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81898, 'Scanzano Jonico', 'Scanzano Jonico', '', 40.2508500, 16.6982400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81899, 'Scansano', 'Scansano', 'Scansano', 42.6877900, 11.3297500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81900, 'Scano di Montiferro', 'Scano di Montiferro', '', 40.2152500, 8.5869200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81901, 'Scanno', 'Scanno', 'Scanno', 41.9044200, 13.8796100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81902, 'Scandriglia', 'Scandriglia', 'Scandriglia', 42.1612800, 12.8409600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81903, 'Scandolara Ripa d''Oglio', 'Scandolara Ripa d''Oglio', 'Scandolara Ripa d''Oglio', 45.2217100, 10.1571700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81904, 'Scandolara Ravara', 'Scandolara Ravara', 'Scandolara Ravara', 45.0530900, 10.3021500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81905, 'Scandicci', 'Scandicci', 'Scadicci,Scandicci,Skandichchi,Скандиччи', 43.7542300, 11.1879400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81906, 'Scandiano', 'Scandiano', 'Scandiano', 44.5983000, 10.6955800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81907, 'Scampitella', 'Scampitella', 'Scampitella,Scampitelli,Scampitello', 41.0925200, 15.2999500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81908, 'Scaltenigo', 'Scaltenigo', '', 45.4712000, 12.0810600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81909, 'Scalenghe', 'Scalenghe', 'Scalenghe,sukarenge,スカレンゲ', 44.8899000, 7.4942300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81910, 'Scaldasole', 'Scaldasole', 'Scaldasole', 45.1249500, 8.9102900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81911, 'Scala', 'Scala', 'Scala,Skala,seukalla,si ka la,sukara,Скала,Սկալա,スカーラ,斯卡拉,스칼라', 40.6566500, 14.6076100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81912, 'Scafati', 'Scafati', 'Scafati', 40.7602000, 14.5372300, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81913, 'Scafa', 'Scafa', 'Scafa', 42.2657500, 13.9966500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81914, 'Savona', 'Savona', 'Sann-a,Saona,Savo,Savo Oppidum Alpinum,Savon-a,Savona,Savone,savu~ona,Савона,サヴォーナ', 44.3090500, 8.4771500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81915, 'Savoia di Lucania', 'Savoia di Lucania', 'Savoia di Lucania', 40.5694900, 15.5513200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81916, 'Savogna d''Isonzo', 'Savogna d''Isonzo', 'Savogna d''Isonzo,Savogna d’Isonzo,Savogne di Gurice,Savogne di Gurize,Sovodnje ob Soci,Sovodnje ob Soči', 45.9089400, 13.5793600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81917, 'Saviore', 'Saviore', 'Saviore,Saviore dell''Adamello', 46.0804900, 10.3982300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81918, 'Savio', 'Savio', '', 44.3113900, 12.2947200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81919, 'Savigno', 'Savigno', 'Savigno', 44.3918600, 11.0748100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81920, 'Savignano sul Rubicone', 'Savignano sul Rubicone', 'Savignano,Savignano al Rubicone,Savignano di Romagna,Savignano sul Rubicone', 44.0900900, 12.3993500, 'IT', '2015-10-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81921, 'Savignano sul Panaro', 'Savignano sul Panaro', '', 44.4803600, 11.0351000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81922, 'Savignano Irpino', 'Savignano Irpino', 'Savignano Irpino,Savignano di Puglia', 41.2269800, 15.1793300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81923, 'Savigliano', 'Savigliano', 'Savian,Savigliano', 44.6480800, 7.6567700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81924, 'Saviano', 'Saviano', 'Saviano,savu~iano,サヴィアーノ', 40.9050700, 14.5049800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81925, 'Sava', 'Sava', 'Sava', 40.4020300, 17.5526700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81926, 'Sauze d''Oulx', 'Sauze d''Oulx', 'Salice d''Ulzio,Sauze D''Oulx,Sauze d''Oulx,サウゼ・ドゥルクス', 45.0265900, 6.8607400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81927, 'Sauze di Cesana', 'Sauze di Cesana', 'Sauz di Cesana,Sauze di Cesana,サウゼ・ディ・チェザーナ', 44.9405800, 6.8598800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81928, 'Sauris di Sotto', 'Sauris di Sotto', 'Sauris,Zahre', 46.4662400, 12.7085200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81929, 'Satriano di Lucania', 'Satriano di Lucania', 'Satriano di Lucania', 40.5429600, 15.6402400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81930, 'Sassuolo', 'Sassuolo', 'Sassuolo,Сассуоло', 44.5432000, 10.7848000, 'IT', '2015-06-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81931, 'Sasso Marconi', 'Sasso Marconi', 'Al Sas,Al Sâs,Praduro e Sasso,Sasso,Sasso Bolognese,Sasso Marconi', 44.4006400, 11.2517700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81932, 'Sassoferrato', 'Sassoferrato', 'Sassoferrato,sassoferrato,サッソフェッラート', 43.4310900, 12.8566000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81933, 'Sassofeltrio', 'Sassofeltrio', '', 43.8921200, 12.5097400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81934, 'Sasso di Castalda', 'Sasso di Castalda', 'Sasso di Castalda', 40.4852500, 15.6756900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81935, 'Sassocorvaro', 'Sassocorvaro', '', 43.7826600, 12.4991000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81936, 'Sassinoro', 'Sassinoro', 'Sassinoro', 41.3747200, 14.6645300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81937, 'Sassetta', 'Sassetta', 'Gorad Saseta,Saseta,Sassetta,Saxseta,sa sai ta,saseta,sassetta,Горад Сасета,Сасета,Сассетта,Սասետա,サッセッタ,萨塞塔,사세타', 43.1287400, 10.6435900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81938, 'Sassello', 'Sassello', 'Sasce,Sascê,Sassello', 44.4803600, 8.4937500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81939, 'Sassari', 'Sassari', 'QSS,Sassari,Sasser,Sàsser,Tatari,Tathari,Tattari,Tàthari,sasary,sassari,Сассари,ساساري,サッサリ', 40.7258600, 8.5555200, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81940, 'Sassano', 'Sassano', 'Sassano', 40.3403000, 15.5655500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81941, 'Sassa', 'Sassa', '', 42.3520400, 13.2992400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81942, 'Sarzana', 'Sarzana', 'Sarzana', 44.1117800, 9.9622000, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81943, 'Sarule', 'Sarule', 'Sarule', 40.2279600, 9.1664400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81944, 'Sartirana Lomellina', 'Sartirana Lomellina', 'Sartirana,Sartirana Lomellina', 45.1135200, 8.6671100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81945, 'Sarteano', 'Sarteano', 'Sarteano,saruteano,サルテアーノ', 42.9919300, 11.8647200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81946, 'Sarsina', 'Sarsina', 'Sarsina,sarushina,サルシナ', 43.9198100, 12.1425500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81947, 'Saronno', 'Saronno', 'Saronno', 45.6251300, 9.0351700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81948, 'Sarno', 'Sarno', 'Sarno,Сарно', 40.8074800, 14.6215100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81949, 'Sarnico', 'Sarnico', 'Sarnico', 45.6709900, 9.9615200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81950, 'Sarnano', 'Sarnano', 'Sarnano', 43.0347500, 13.2981800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81951, 'Sarmeola', 'Sarmeola', '', 45.4240000, 11.8167400, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81952, 'Sarmede', 'Sarmede', 'Sarmede', 45.9762500, 12.3858100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81953, 'Sarmato', 'Sarmato', '', 45.0567900, 9.4968300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81954, 'Sarezzo', 'Sarezzo', 'Sarezzo', 45.6606700, 10.1969000, 'IT', '2014-07-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81955, 'Sarezzano', 'Sarezzano', 'Sarezzano', 44.8687800, 8.9123700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81956, 'Sarentino', 'Sarentino', 'Sarehncina,Sarentino,Sarntal,Sarnthein,Sarntål,Vallis Serenae,sa lun di nuo,sarentino,Σαρεντίνο,Сарентино,Сарентіно,Сарэнціна,Սարենտինո,サレンティーノ,萨伦蒂诺', 46.6412100, 11.3541100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81957, 'Sarconi', 'Sarconi', 'Sarconi,Sarconium,Sarkoni,sa er ke ni,sarkwny,sarukoni,Саркони,Сарконі,Սարկոնի,ساركوني,サルコーニ,萨尔科尼', 40.2480000, 15.8883700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81958, 'Sarcedo', 'Sarcedo', 'Sarcedo', 45.7013400, 11.5296300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81959, 'Saracinesco', 'Saracinesco', 'Rocca Sarracinesium,Sarachinesko,Sarachyneska,Saracinesco,Saracinescu,sa la qi nei si ke,salachineseuko,sarachinesuko,Сарачинеско,Сарачынеска,Սարաչինեսկո,サラチネスコ,萨拉奇内斯科,사라치네스코', 42.0033200, 12.9532900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81960, 'Sapri', 'Sapri', 'Sapri,Satri,sapuri,サプリ', 40.0746400, 15.6321200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81961, 'Sappada', 'Sappada', 'Sapade,Sappada', 46.5666300, 12.6842100, 'IT', '2017-06-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81962, 'San Zenone al Po', 'San Zenone al Po', 'San Zenone al Po', 45.1085600, 9.3617600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81963, 'San Zenone al Lambro', 'San Zenone al Lambro', 'San Zenone al Lambro,サン・ゼノーネ・アル・ランブロ', 45.3268100, 9.3559800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81964, 'San Zenone degli Ezzelini', 'San Zenone degli Ezzelini', 'San Zenone degli Ezzelini', 45.7804000, 11.8372000, 'IT', '2012-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81965, 'San Zeno di Montagna', 'San Zeno di Montagna', 'San Zeno di Montagna', 45.6374900, 10.7321800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81966, 'Sanzeno', 'Sanzeno', 'Sanzeno,sanzeno,サンゼーノ', 46.3661400, 11.0755900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81967, 'Sanza', 'Sanza', 'Sanza', 40.2438900, 15.5541600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81968, 'San Vittore del Lazio', 'San Vittore del Lazio', '', 41.4621200, 13.9336700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81969, 'San Vittore', 'San Vittore', '', 46.3079900, 9.3831000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81970, 'San Vito Romano', 'San Vito Romano', 'San Vito,San Vito Romano,サン・ヴィート・ロマーノ', 41.8800100, 12.9779300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81971, 'San Vito di Leguzzano', 'San Vito di Leguzzano', 'San Vito di Leguzzano', 45.6849400, 11.3887200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81972, 'San Vito di Fagagna', 'San Vito di Fagagna', 'San Vit di Feagne,San Vito di Fagagna,Sant Vit di Feagne,Sant Vît di Feagne', 46.0910300, 13.0656900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81973, 'San Vito', 'San Vito', 'San Vito,San Vito del Cadore,San Vito di Cadore', 46.4627800, 12.2060800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81974, 'San Vito dei Normanni', 'San Vito dei Normanni', 'San Vito de'' Normanni', 40.6564200, 17.7081400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81975, 'San Vito Chietino', 'San Vito Chietino', 'San Vito Chietino', 42.2901400, 14.4427000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81976, 'San Vito al Tagliamento', 'San Vito al Tagliamento', 'San Vit dal Tiliment,San Vito al Tagliamento', 45.9168000, 12.8594500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81977, 'San Vito', 'San Vito', '', 45.7551400, 11.9155300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81978, 'San Vito', 'San Vito', '', 44.5582200, 10.9743200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81979, 'San Vincenzo Valle Roveto', 'San Vincenzo Valle Roveto', 'San Vincenzo Valle Roveto', 41.8445200, 13.5356600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81980, 'San Vincenzo', 'San Vincenzo', 'San Vincenzo,サン・ヴィンチェンツォ', 43.0906100, 10.5424600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81981, 'San Vero Milis', 'San Vero Milis', 'San Vero Milis', 40.0137700, 8.5983300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81982, 'San Vendemiano', 'San Vendemiano', 'San Vendemiano', 45.8873200, 12.3516400, 'IT', '2012-03-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81983, 'San Venanzo', 'San Venanzo', 'Castrum Sancti Venantii,San Venanco,San Venanzo,San Venanzu,San-Venanco,san fynanzw,sanbenancho,sheng wei nan zuo,Сан Венанцо,Сан-Венанцо,Սան Վենանցո,سان فينانزو,サン・ヴェナンツォ,圣韦南佐,산베난초', 42.8688600, 12.2685300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81984, 'San Valentino Torio', 'San Valentino Torio', 'San Valentino Torio', 40.7910900, 14.6033300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81985, 'San Valentino in Abruzzo Citeriore', 'San Valentino in Abruzzo Citeriore', 'San Valentino,San Valentino d''Abruzzo,San Valentino in Abruzzo Citeriore', 42.2330400, 13.9856100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81986, 'San Valentino', 'San Valentino', 'San Valentino,San Valentino di Fiumicello', 45.7903900, 13.4123600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81987, 'Santu Lussurgiu', 'Santu Lussurgiu', 'Santu Lussurgiu', 40.1411000, 8.6553900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81988, 'Santo Stino di Livenza', 'Santo Stino di Livenza', 'San Stin,San Stino di Livenza,Santo Stimo di Livenza,Santo Stino,Santo Stino di Livenza', 45.7255900, 12.6897100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81989, 'Santo Stefano Ticino', 'Santo Stefano Ticino', 'Santo Stefano Ticino,サント・ステーファノ・ティチーノ', 45.4863500, 8.9158200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81990, 'Santo Stefano di Sessanio', 'Santo Stefano di Sessanio', 'Santo Stefano di Sessanio', 42.3433900, 13.6447700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81991, 'Santo Stefano di Magra', 'Santo Stefano di Magra', 'Santo Stefano Magra,Santo Stefano di Magra', 44.1489100, 9.9218500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81992, 'Santo Stefano di Cadore', 'Santo Stefano di Cadore', 'San Stefano,Santo Stefano di Cadore,Santo Stephano di Cadore,Santo Stéphano di Cadore', 46.5582700, 12.5495600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81993, 'Santo Stefano del Sole', 'Santo Stefano del Sole', 'Santo Stefano del Sole', 40.8941400, 14.8667400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81994, 'Santo Stefano d''Aveto', 'Santo Stefano d''Aveto', 'San Steva d''Aveto,San Steva d’Aveto,Santo Stefano d''Aveto', 44.5467700, 9.4532500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81995, 'Santo Stefano Belbo', 'Santo Stefano Belbo', 'Santo Stefano,Santo Stefano Belbo', 44.7102300, 8.2326900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81996, 'Santo Stefano al Mare', 'Santo Stefano al Mare', 'Riva Santo Stefano,San Stefano al Mare,Santo Stefano al Mare', 43.8385500, 7.8972800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81997, 'Santorso', 'Santorso', 'Santorso', 45.7338300, 11.3878500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81998, 'Sant''Oreste', 'Sant''Oreste', 'Capena,Sant''Oreste,santoresute,サントレステ', 42.2329800, 12.5150700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(81999, 'Santopadre', 'Santopadre', '', 41.6019300, 13.6354800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82000, 'Sant''Omero', 'Sant''Omero', 'Sant''Omero', 42.7901100, 13.7890600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82001, 'Santomenna', 'Santomenna', 'Santomenna', 40.8068500, 15.3263900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82002, 'Celat-San Tomaso Agordino', 'Celat-San Tomaso Agordino', 'San Tominaso,San Tommaso', 46.3807200, 11.9743900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82003, 'Sant''Ippolito', 'Sant''Ippolito', 'Sant''Ippolito', 43.6797200, 12.8758100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82004, 'Sant''Ilario d''Enza', 'Sant''Ilario d''Enza', 'Sant''Ilario,Sant''Ilario d''Enza', 44.7589000, 10.4473700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82005, 'Santi Cosma e Damiano', 'Santi Cosma e Damiano', 'Khram na Romul,Kosmas- og Damiankirken,Santi Cosma e Damiano,Tempel van Romulus,Храм на Ромул', 41.3009100, 13.8156500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82006, 'Santhià', 'Santhia', 'Santhia,Santhià', 45.3679500, 8.1701200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82007, 'Sant''Eusanio Forconese', 'Sant''Eusanio Forconese', 'Sant''Eusanio Forconese', 42.2895100, 13.5242500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82008, 'Sant''Eusanio del Sangro', 'Sant''Eusanio del Sangro', 'Sant''Eusanio del Sangro', 42.1690800, 14.3277600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82009, 'Sant''Eufemia a Maiella', 'Sant''Eufemia a Maiella', 'Sant''Eufemia a Maiella,Sant''Eufemia a Majella', 42.1261300, 14.0265100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82010, 'Santerno', 'Santerno', '', 44.4369700, 12.0553300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82011, 'San Terenziano', 'San Terenziano', '', 42.8673100, 12.4731900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82012, 'Santeramo in Colle', 'Santeramo in Colle', 'Santeramo in Colle', 40.7923600, 16.7587300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82013, 'San Teodoro', 'San Teodoro', 'San Teodoro,サン・テオドーロ', 40.7735400, 9.6692900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82014, 'Sante Marie', 'Sante Marie', 'Sante Marie', 42.1036900, 13.2016300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82015, 'Sant''Elpidio a Mare', 'Sant''Elpidio a Mare', 'San Elpido a Mare,Sant''Elpidio a Mare', 43.2302400, 13.6881900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82016, 'Sant''Elia Fiumerapido', 'Sant''Elia Fiumerapido', 'San Elia Fiumerapido,Sant''Elia,Sant''Elia Fiumerapido', 41.5330400, 13.8626800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82017, 'Sant''Elia a Pianisi', 'Sant''Elia a Pianisi', '', 41.6204300, 14.8752300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82018, 'Sant''Elena Sannita', 'Sant''Elena Sannita', 'Sant''Elena Sannita', 41.5752500, 14.4707000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82019, 'Sant''Elena', 'Sant''Elena', 'Sant''Elena', 45.1874400, 11.7116900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82020, 'Sant''Egidio alla Vibrata', 'Sant''Egidio alla Vibrata', 'Sant''Egidio alla Vibrata', 42.8170500, 13.7216400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82021, 'San Vittoria in Matenano', 'San Vittoria in Matenano', 'San Vittoria,Santa Vittoria in Matenano', 43.0197500, 13.4961800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82022, 'Santa Vittoria d''Alba', 'Santa Vittoria d''Alba', 'Santa Vittoria d''Alba', 44.6986400, 7.9373300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82023, 'Santa Vittoria', 'Santa Vittoria', '', 44.8548300, 10.6334800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82024, 'Santa Valburga', 'Santa Valburga', 'Sankt Walburg,Santa Valburga in Ultimo,Santa Valpurga,Santa Valpurga d''Ultimo,St. Walburg', 46.5500000, 11.0000000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82025, 'Santa Teresa Gallura', 'Santa Teresa Gallura', 'Santa Teresa,Santa Teresa Gallura,Santa Teresa di Gallura,サンタ・テレーザ・ガッルーラ', 41.2385900, 9.1887300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82026, 'Santa Tecla-Castelpagano', 'Santa Tecla-Castelpagano', '', 40.6735300, 14.9180600, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82027, 'Santa Sofia', 'Santa Sofia', 'Santa Sofia', 43.9472400, 11.9086700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82028, 'Santa Rufina', 'Santa Rufina', '', 42.4089700, 12.9184300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82029, 'Sant''Arsenio', 'Sant''Arsenio', 'Sant''Arsenio', 40.4710900, 15.4840100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82030, 'Sant''Arpino', 'Sant''Arpino', 'S. Arpino,Sant''Arpino', 40.9571600, 14.2507500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82031, 'Sant''Arcangelo Trimonte', 'Sant''Arcangelo Trimonte', 'Sant''Arcangelo Trimonte', 41.1690100, 14.9388300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82032, 'Santarcangelo', 'Santarcangelo', 'Santarcangelo,Santarcangelo di Romagna', 44.0632600, 12.4465700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82033, 'Sant''Arcangelo', 'Sant''Arcangelo', 'Sant''Arcangelo', 40.2485200, 16.2704600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82034, 'Sant''Apollinare', 'Sant''Apollinare', 'Sant''Apollinare', 41.4017600, 13.8299200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82035, 'Santa Paolina', 'Santa Paolina', 'Santa Paolina', 41.0220200, 14.8463000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82036, 'Roncofreddo-Santa Paola', 'Roncofreddo-Santa Paola', '', 44.0425100, 12.3152300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82037, 'Sant''Antonino di Susa', 'Sant''Antonino di Susa', 'Sant''Antonino,Sant''Antonino di Susa,サンタントニーノ・ディ・スーザ', 45.1076300, 7.2733300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82038, 'Sant''Antonio Abate', 'Sant''Antonio Abate', 'Sant''Antonio Abate,サンタントーニオ・アバーテ', 40.7215200, 14.5402100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82039, 'Sant''Antonio', 'Sant''Antonio', '', 46.4611000, 10.4173800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82040, 'Sant''Antonio', 'Sant''Antonio', '', 45.1964900, 10.7938100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82041, 'Sant''Antonio di Gallura', 'Sant''Antonio di Gallura', 'San Antonio', 40.9914600, 9.3015300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82042, 'Sant''Antimo', 'Sant''Antimo', 'Sant''Antimo,santantimo,サンタンティモ', 40.9422300, 14.2347600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82043, 'Sant''Anna d''Alfaedo', 'Sant''Anna d''Alfaedo', 'Sant''Anna d''Alfaedo', 45.6271900, 10.9516800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82044, 'Sant''Angelo Romano', 'Sant''Angelo Romano', 'Sant''Angelo Romano,サンタンジェロ・ロマーノ', 42.0357000, 12.7134200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82045, 'Sant''Angelo Lomellina', 'Sant''Angelo Lomellina', 'Sant''Angelo di Lomellino', 45.2466300, 8.6431700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82046, 'Sant''Angelo Lodigiano', 'Sant''Angelo Lodigiano', 'Sant''Angelo Lodigiano,サンタンジェロ・ロディジャーノ', 45.2352600, 9.4065100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82047, 'Sant''Angelo Limosano', 'Sant''Angelo Limosano', '', 41.6926600, 14.6034600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82048, 'Sant''Angelo le Fratte', 'Sant''Angelo le Fratte', '', 40.5449000, 15.5615600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82049, 'Sant''Angelo in Vado', 'Sant''Angelo in Vado', 'San Angelo in Vado,Sant''Angelo in Vado', 43.6652600, 12.4175700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82050, 'Sant''Angelo in Pontano', 'Sant''Angelo in Pontano', 'Sant''Angelo in Pontano', 43.0978000, 13.3969000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82051, 'Sant''Angelo in Lizzola', 'Sant''Angelo in Lizzola', 'San Angelo,Sant''Angelo in Lizzola', 43.8269600, 12.8007600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82052, 'Sant''Angelo in Formis', 'Sant''Angelo in Formis', 'Sant''Angelo in Formis', 41.1166700, 14.2500000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82053, 'Sant''Angelo di Piove di Sacco', 'Sant''Angelo di Piove di Sacco', 'Sant''Angelo di Piove di Sacco', 45.3173500, 12.0094100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82054, 'Sant''Angelo del Pesco', 'Sant''Angelo del Pesco', 'Sant''Angelo,Sant''Angelo del Pesco', 41.8819300, 14.2535400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82055, 'Sant''Angelo dei Lombardi', 'Sant''Angelo dei Lombardi', 'Sant''Angelo dei Lombardi', 40.9293700, 15.1753500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82056, 'Sant''Angelo d''Alife', 'Sant''Angelo d''Alife', 'Sant''Angelo d''Alife', 41.3611900, 14.2612500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82057, 'Sant''Angelo A Scala', 'Sant''Angelo A Scala', 'Sant''Angelo a Scala', 40.9746500, 14.7404100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82058, 'Sant''Angelo A Fasanella', 'Sant''Angelo A Fasanella', 'Sant''Angelo Fasanella,Sant''Angelo a Fasanella', 40.4572400, 15.3409100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82059, 'Sant''Angelo', 'Sant''Angelo', '', 45.5203100, 12.0186200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82060, 'Sant''Andrea in Casale', 'Sant''Andrea in Casale', '', 43.9333300, 12.6500000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82061, 'Sant''Andrea di Conza', 'Sant''Andrea di Conza', 'Sant''Andrea di Conza', 40.8448200, 15.3696500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82062, 'Sant''Andrea del Garigliano', 'Sant''Andrea del Garigliano', 'Sant''Andrea,Sant''Andrea del Garigliano', 41.3686800, 13.8419800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82063, 'Santandrà', 'Santandra', 'Sant''Andra,Sant''Andreag,Sant''Andrà', 45.7477800, 12.2011100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82064, 'Sant''Anatolia di Narco', 'Sant''Anatolia di Narco', 'Sant''Anatolia,Sant''Anatolia di Narco', 42.7331900, 12.8357600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82065, 'Sant''Anastasia', 'Sant''Anastasia', 'Sant''Anastasia,santanasutajia,サンタナスタジーア', 40.8684200, 14.4019600, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82066, 'San Tammaro', 'San Tammaro', 'San Tammaro', 41.0758800, 14.2310500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82067, 'Sant''Ambrogio sul Garigliano', 'Sant''Ambrogio sul Garigliano', 'Ambrogio,Sant''Ambrogio,Sant''Ambrogio sul Garigliano', 41.3942300, 13.8689100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82068, 'Sant''Ambrogio di Valpollicella', 'Sant''Ambrogio di Valpollicella', 'San Ambrogio di Valpolicella,Sant''Ambrogio,Sant''Ambrogio di Valpolicella', 45.5208900, 10.8361800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82069, 'Sant''Ambrogio di Torino', 'Sant''Ambrogio di Torino', 'San Ambrogio di Torino,Sant''Ambreus ed Turin,Sant''Ambreus ëd Turin,Sant''Ambrogio,Sant''Ambrogio di Torino,Sant’Ambreus ëd Turin', 45.0962200, 7.3660000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82070, 'Santa Marinella', 'Santa Marinella', 'Santa Marinella,サンタ・マリネッラ', 42.0342500, 11.8541600, 'IT', '2015-10-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82071, 'Santa Marina', 'Santa Marina', 'Santa Marina', 40.1052000, 15.5415300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82072, 'Santa Maria Nuova', 'Santa Maria Nuova', 'Santa Maria Nuova,サンタ・マリーア・ヌオーヴァ', 43.4916400, 13.3237000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82073, 'Santa Maria Nuova', 'Santa Maria Nuova', '', 44.2000000, 12.1938900, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82074, 'Santa Maria Maggiore', 'Santa Maria Maggiore', 'Santa Maria Maggiore,サンタ・マリーア・マッジョーレ', 46.1368300, 8.4610800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82075, 'Santa Maria Maddalena', 'Santa Maria Maddalena', '', 44.9023100, 11.6066300, 'IT', '2014-04-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82076, 'Santa Maria la Longa', 'Santa Maria la Longa', 'Santa Maria la Longa,Sante Marie la Lungje', 45.9340300, 13.2891100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82077, 'Santa Maria la Fossa', 'Santa Maria la Fossa', 'Santa Maria,Santa Maria la Fossa', 41.0917100, 14.1282200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82078, 'Santa Maria Imbaro', 'Santa Maria Imbaro', 'Santa Maria Imbaro', 42.2199900, 14.4502700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82079, 'Venezzano', 'Venezzano', '', 44.6833300, 11.3333300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82080, 'Santa Maria di Sala', 'Santa Maria di Sala', 'Santa Maria di Sala,サンタ・マリーア・ディ・サーラ', 45.5069900, 12.0356500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82081, 'Santa Maria', 'Santa Maria', 'Santa Maria,Santa Maria di Castellabate', 40.2978200, 14.9521400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82082, 'Santa Maria del Molise', 'Santa Maria del Molise', 'San Angelo in Grotte,Sant''Angelo in Grotte,Santa Maria del Molise', 41.5528500, 14.3676200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82083, 'Santa Maria degli Angeli', 'Santa Maria degli Angeli', 'Angeli', 43.0569100, 12.5749700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82084, 'Santa Maria Codifiume', 'Santa Maria Codifiume', '', 44.6642400, 11.6509900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82085, 'Santa Maria Capua Vetere', 'Santa Maria Capua Vetere', 'Santa Maria Capua Vetere,Santa Maria Capua Vetiri,Santa Marija Kapua Vetere,Santa-Marija-Kapua-Vetere,Villa Sanctae Mariae Maioris,santa marya kabwa fytyry,santamaliakapuabetele,sheng ma li ya ka pu a wei tai lei,Санта Мария Капуа Ветере,Санта Марија Капуа Ветере,Санта-Мария-Капуа-Ветере,Санта-Марія-Капуа-Ветере,سانتا ماريا كابوا فيتيري,サンタ・マリーア・カープア・ヴェーテレ,圣马里亚卡普阿韦泰雷,산타마리아카푸아베테레', 41.0815600, 14.2534200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82086, 'Santa Maria A Vico', 'Santa Maria A Vico', 'Santa Maria a Vico', 41.0261100, 14.4651500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82087, 'Santa Maria a Monte', 'Santa Maria a Monte', 'Santa Maria a Monte', 43.7079300, 10.6919600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82088, 'Santa Maria Coghinas', 'Santa Maria Coghinas', 'Santa Maria Coghinas,Santa Maria Coghínas', 40.9042300, 8.8638300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82089, 'Santa Margherita Ligure', 'Santa Margherita Ligure', 'Santa Margaita,Santa Margherita,Santa Margherita Ligure,Santa-Margarita Ligureh,Санта-Маргарита Лигурэ', 44.3345600, 9.2120400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82090, 'Santa Margherita d''Adige', 'Santa Margherita d''Adige', '', 45.2121000, 11.5575900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82091, 'Santa Lucia di Serino', 'Santa Lucia di Serino', 'San Lucia,San Lucia di Serino,Santa Lucia di Serino', 40.8704200, 14.8759400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82092, 'Santa Luce', 'Santa Luce', 'Santa Luce Orciano', 43.4714300, 10.5626900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82093, 'Sant''Alberto', 'Sant''Alberto', '', 44.5382200, 12.1619100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82094, 'Sant''Albano Stura', 'Sant''Albano Stura', 'Sant''Albano Stura', 44.5075900, 7.7228200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82095, 'Sant''Agostino', 'Sant''Agostino', 'Sant'' Agostino,Sant''Agostino,santagosutino,サンタゴスティーノ', 44.7921800, 11.3852200, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82096, 'Sant''Agnello', 'Sant''Agnello', 'Sant'' Agnello-Sorrent,Sant''Agnello,Sant-An''ello,santanyerro,Сант-Аньелло,サンタニェッロ', 40.6294200, 14.3995700, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82097, 'Santa Giustina in Colle', 'Santa Giustina in Colle', 'Fanum Sanctae Iustinae in Collo,Santa Justina,Santa Justina in Kole,Santa-Dzhustina-in-Kolle,sheng zhu si di na yi en ke lai,Санта-Джустина-ин-Колле,Санта-Джустіна-ін-Колле,Սանտա Ջուստինա ին Կոլե,サンタ・ジュスティーナ・イン・コッレ,圣朱斯蒂纳伊恩科莱', 45.5750600, 11.9003900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82098, 'Santa Giustina', 'Santa Giustina', 'Santa Giustina,Santa Giustina Bellunese', 46.0811800, 12.0382200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82099, 'Santa Giustina', 'Santa Giustina', '', 44.0677800, 12.4850000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82100, 'Santa Giuletta', 'Santa Giuletta', '', 45.0339700, 9.1812600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82101, 'Sant''Agata sul Santerno', 'Sant''Agata sul Santerno', 'Sant''Agata,Sant''Agata sul Santerno,サンタガータ・スル・サンテルノ', 44.4435100, 11.8611200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82102, 'Sant''Agata Feltria', 'Sant''Agata Feltria', 'Sant''Agata Feltria', 43.8628200, 12.2069000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82103, 'Sant''Agata di Puglia', 'Sant''Agata di Puglia', 'Sant''Agata', 41.1512700, 15.3796800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82104, 'Sant''Agata de''Goti', 'Sant''Agata de''Goti', 'Sant''Agata de'' Goti,Sant''Agata de''Goti,Sant''Agata dei Goti', 41.0893200, 14.4974300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82105, 'Sant''Agata Bolognese', 'Sant''Agata Bolognese', 'Sant''Agata Bolognese,Sant''Agata-Bolognese,Sant''Egata,Sant’Ègata,サンターガタ・ボロニェーゼ', 44.6601600, 11.1329200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82106, 'Sant''Agapito', 'Sant''Agapito', '', 41.5437200, 14.2220400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82107, 'Santa Fiora', 'Santa Fiora', 'Santa Fiora', 42.8312900, 11.5847400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82108, 'Santa Croce sull''Arno', 'Santa Croce sull''Arno', '', 43.7170900, 10.7724200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82109, 'Santa Croce', 'Santa Croce', 'Santa Croce,Santa Croce di Trieste,Sveti Kriz,Sveti Križ', 45.7347200, 13.6927800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82110, 'Santa Croce di Magliano', 'Santa Croce di Magliano', 'Santa Croce di Magliano', 41.7122300, 14.9873200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82111, 'Santa Cristina', 'Santa Cristina', 'San Cristina e Bissone', 45.1575600, 9.3997600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82112, 'Santa Cristina Valgardena', 'Santa Cristina Valgardena', 'Santa Cristina,Santa Cristina Val Gardena,St. Christina,St. Christina in Groeden,St. Christina in Gröden', 46.5629900, 11.7321600, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82113, 'Santa Cristina', 'Santa Cristina', 'Santa Cristina,Santa Cristina del Tiveron', 45.6435000, 12.1390300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82114, 'Santa Cesarea Terme', 'Santa Cesarea Terme', 'Santa Cesarea,Santa Cesarea Terme,Terme di Santa Cesarea', 40.0360700, 18.4554200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82115, 'Santa Brigida', 'Santa Brigida', 'Santa Brigida', 45.9848900, 9.6211500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82116, 'San Sossio Baronia', 'San Sossio Baronia', 'San Sossio Baronia', 41.0708100, 15.2012200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82117, 'San Severo', 'San Severo', 'San Severo,サン・セヴェーロ', 41.6856400, 15.3814800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82118, 'San Severino Marche', 'San Severino Marche', 'San Severino Marche', 43.2302800, 13.1799000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82119, 'San Severino Lucano', 'San Severino Lucano', 'San Severino,San Severino Lucano', 40.0202100, 16.1386000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82120, 'Sansepolcro', 'Sansepolcro', 'Sansepolcro', 43.5725800, 12.1385800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82121, 'San Secondo Parmense', 'San Secondo Parmense', 'San Secondo Parmense', 44.9221800, 10.2303800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82122, 'San Secondo', 'San Secondo', 'San Secondo', 43.4046800, 12.2338900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82123, 'San Sebastiano Curone', 'San Sebastiano Curone', 'San Sebastiano,San Sebastiano Curone', 44.7863300, 9.0644600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82124, 'San Sebastiano al Vesuvio', 'San Sebastiano al Vesuvio', '', 40.8434400, 14.3642800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82125, 'San Sebastiano', 'San Sebastiano', '', 45.6519200, 10.2568100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82126, 'San Salvo', 'San Salvo', 'San Salvo', 42.0441300, 14.7333500, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82127, 'San Salvatore Telesino', 'San Salvatore Telesino', 'San Salvatore Telesino', 41.2353700, 14.4983200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82128, 'San Salvatore Monferrato', 'San Salvatore Monferrato', 'San Salvatore Monferrato', 44.9948900, 8.5663900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82129, 'San Rufo', 'San Rufo', 'Fanum Sancti Ruphi,San Rufo,San Rufu,San-Rufo,sanlupo,sheng lu fu,Сан Руфо,Сан-Руфо,Սան Ռուֆո,サン・ルーフォ,圣鲁福,산루포', 40.4345100, 15.4636600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82130, 'San Romano', 'San Romano', '', 43.6892200, 10.7690000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82131, 'San Remo', 'San Remo', 'San Remo,San-Remo,Sanremo,Sanremu,Villa Matuciana,sanremo,sn rmw,Сан Ремо,Сан-Ремо,Санремо,סן רמו,サンレーモ', 43.8172500, 7.7772000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82132, 'San Quirino', 'San Quirino', 'San Cuarin,San Quirino', 46.0341100, 12.6784600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82133, 'San Quirico d''Orcia', 'San Quirico d''Orcia', 'San Quirico d''Orcia,サン・クイリーコ・ドルチャ', 43.0578200, 11.6052500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82134, 'San Quirico', 'San Quirico', '', 45.6768500, 11.2726000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82135, 'San Prisco', 'San Prisco', 'San Prisco', 41.0859200, 14.2767500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82136, 'San Potito Ultra', 'San Potito Ultra', 'San Potito Ultra', 40.9279600, 14.8712400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82137, 'San Potito Sannitico', 'San Potito Sannitico', 'San Potito Sannitico', 41.3369800, 14.3918500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82138, 'San Ponso', 'San Ponso', 'San Ponso,サン・ポンソ', 45.3510100, 7.6711100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82139, 'San Polomatese', 'San Polomatese', 'San Polo Matese', 41.4593200, 14.4934300, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82140, 'San Polo d''Enza', 'San Polo d''Enza', 'San Polo d''Enza', 44.6269000, 10.4266700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82141, 'San Polo dei Cavalieri', 'San Polo dei Cavalieri', 'San Polo de Cavalieri,San Polo dei Cavalieri,サン・ポーロ・ディ・カヴァリエーリ', 42.0103700, 12.8398900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82142, 'San Polo', 'San Polo', '', 44.9786800, 9.7407000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82143, 'San Pio delle Camere', 'San Pio delle Camere', 'San Pio delle Camere', 42.2842300, 13.6557000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82144, 'San Pietro Viminario', 'San Pietro Viminario', 'Fanum Sancti Petri in Viminario,San Piero Viminario,San Pietro Viminario,San-P''etro-Viminario,San-Petro-Viminario,sheng pi ye te luo wei mi na liao,Сан-Пьетро-Виминарио,Сан-Пєтро-Вімінаріо,Սան Պիետրո Վիմինարիո,サン・ピエトロ・ヴィミナーリオ,圣皮耶特罗维米纳廖', 45.2450100, 11.8204900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82145, 'San Pietro Vernotico', 'San Pietro Vernotico', 'San Pietro Vernotico', 40.4889000, 17.9975200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82146, 'San Pietro Mosezzo', 'San Pietro Mosezzo', 'San Pietro Mosezzo', 45.4545500, 8.5445000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82147, 'San Pietro In Vincoli', 'San Pietro In Vincoli', 'San Pietro', 44.3005100, 12.1455600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82148, 'San Pietro in Lama', 'San Pietro in Lama', 'San Pietro in Lama', 40.3071100, 18.1278700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82149, 'San Pietro in Gu', 'San Pietro in Gu', '', 45.6087900, 11.6735500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82150, 'San Pietro Infine', 'San Pietro Infine', 'San Pietro,San Pietro Infine', 41.4455200, 13.9602900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82151, 'San Pietro in Casale', 'San Pietro in Casale', 'San Pietro in Casale', 44.7007900, 11.4049200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82152, 'San Pietro d''Olba', 'San Pietro d''Olba', 'Olba,San Pietro d''Olba', 44.4876200, 8.5895100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82153, 'San Pietro di Feletto', 'San Pietro di Feletto', '', 45.9139100, 12.2510100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82154, 'San Pietro di Cadore', 'San Pietro di Cadore', 'San Pietro,San Pietro Cadore,San Pietro di Cadore', 46.5719000, 12.5869000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82155, 'San Pietro Capofiume', 'San Pietro Capofiume', '', 44.6504000, 11.6480200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82156, 'San Pietro Avellana', 'San Pietro Avellana', 'San Pietro Avellana', 41.7888600, 14.1832300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82157, 'San Pietro al Tanagro', 'San Pietro al Tanagro', 'San Pietro,San Pietro al Tanagro', 40.4548800, 15.4869200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82158, 'San Pietro al Natisone', 'San Pietro al Natisone', 'San Pieri dai Sclavons,San Pietro,San Pietro al Natisone', 46.1144400, 13.4829600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82159, 'San Pietro', 'San Pietro', '', 46.6413300, 11.6827700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82160, 'San Piero in Bagno', 'San Piero in Bagno', 'San Piero', 43.8579300, 11.9771600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82161, 'San Piero a Sieve', 'San Piero a Sieve', 'Plebs Sancti Petri de Sieve,San Piero a Sieve,San Pieru a Sievi,San-P''ero-a-S''eve,San-Pera-a-S''eveh,San-Pero-a-S''eve,sheng pi ye luo a xie wei,Сан-Пера-а-Сьевэ,Сан-Пьеро-а-Сьеве,Сан-Пєро-а-Сьєве,Սան Պիեռո ա Սիևե,サン・ピエーロ・ア・シエーヴェ,圣皮耶罗阿谢韦', 43.9625100, 11.3242600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82162, 'San Pier d''Isonzo', 'San Pier d''Isonzo', 'San Pier d''Isonzo,San Pieri dai Sclas,San Pieri dal Lusinc,San Pieri dal Lusinç', 45.8445200, 13.4676400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82163, 'San Pellegrino Terme', 'San Pellegrino Terme', 'San Pellegrino,San Pellegrino Terme', 45.8344300, 9.6675300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82164, 'San Paolo di Jesi', 'San Paolo di Jesi', '', 43.4545600, 13.1727700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82165, 'San Paolo di Civitate', 'San Paolo di Civitate', 'San Paolo Civitate,San Paolo di Civitate', 41.7389300, 15.2608000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82166, 'San Paolo Bel Sito', 'San Paolo Bel Sito', 'San Paolo Bel Sito,サン・パオロ・ベル・シート', 40.9135400, 14.5486200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82167, 'San Paolo Albanese', 'San Paolo Albanese', 'Casalnuovo Lucano,Casalnuoyo Lucano,San Paolo Albanese,Shen Pali', 40.0356700, 16.3349800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82168, 'San Paolo', 'San Paolo', 'Pedergnaga Oriana,San Paolo', 45.3724900, 10.0239700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82169, 'San Panfilo d''Ocre', 'San Panfilo d''Ocre', 'San Panfilo,San Panfilo d''Ocre,San Panfilo d’Ocre', 42.2861600, 13.4751800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82170, 'San Pancrazio Salentino', 'San Pancrazio Salentino', 'San Pancrazio,San Pancrazio Salentino', 40.4180000, 17.8341900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82171, 'San Pancrazio', 'San Pancrazio', 'Fanum Sancti Pancratii in Ultum,San Pancrazio,San Pankracio,San-Pankracio,Sankt Pankraz,St Pankraz,St. Pankraz,sheng pan ke la qi ao,Сан Панкрацио,Сан-Панкрацио,Сан-Панкраціо,Սան Պանկրացիո,サン・パンクラーツィオ,圣潘克拉齐奥', 46.5860000, 11.0857100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82172, 'San Pancrazio', 'San Pancrazio', 'San Panerazio', 44.3581000, 12.0785200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82173, 'San Niccolò di Celle', 'San Niccolo di Celle', 'San Niccolo di Celle,San Nicolo di Celle,San Nicolò di Celle', 43.0166700, 12.3833300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82174, 'San Nicola Baronia', 'San Nicola Baronia', 'San Nicola Baronia', 41.0580800, 15.2000600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82175, 'Sannicola', 'Sannicola', 'San Nicola di Gallipoli,Sannicola', 40.0924400, 18.0676500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82176, 'Sannicandro Garganico', 'Sannicandro Garganico', '', 41.8384400, 15.5653500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82177, 'Sannicandro di Bari', 'Sannicandro di Bari', 'San Nicandro,Sannicandro di Bari', 41.0004700, 16.7971400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82178, 'San Nazzaro Sesia', 'San Nazzaro Sesia', 'San Nazzaro Sesia', 45.4380400, 8.4249800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82179, 'Sannazzaro de'' Burgondi', 'Sannazzaro de'' Burgondi', 'Sannazzara de'' Burgondi', 45.1022600, 8.9063500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82180, 'San Nazario', 'San Nazario', '', 45.8398200, 11.6889300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82181, 'San Miniato', 'San Miniato', '', 43.6795400, 10.8497500, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82182, 'San Miniato Basso', 'San Miniato Basso', 'San Miniato,San Miniato Basso,San Miniatu,サン・ミニアート', 43.6933200, 10.8411900, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82183, 'San Michele Salentino', 'San Michele Salentino', 'San Michele Salentino', 40.6316300, 17.6325400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82184, 'San Michele Mondovì', 'San Michele Mondovi', 'San Michele,San Michele Mondovi,San Michele Mondovì', 44.3759500, 7.9082900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82185, 'San Michele di Serino', 'San Michele di Serino', 'San Michele di Serino', 40.8756200, 14.8546400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82186, 'San Michele al Tagliamento', 'San Michele al Tagliamento', 'Saint Michael,San Micele al Tagliamento,San Michel dal Tiliment,San Michele,San Michele al Tagliamento', 45.7643500, 12.9949400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82187, 'San Michele All''Adige', 'San Michele All''Adige', 'San Michele,San Michele all''Adige,サン・ミケーレ・アッラーディジェ', 46.1896700, 11.1321200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82188, 'San Michele di Piave', 'San Michele di Piave', 'San Michele,San Michele di Piave', 45.7966700, 12.3463400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82189, 'San Michele-San Giorgio', 'San Michele-San Giorgio', '', 45.6959400, 9.0585600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82190, 'Olivetta San Michele', 'Olivetta San Michele', '', 43.8787200, 7.5150400, 'IT', '2012-03-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82191, 'Borgo San Michele', 'Borgo San Michele', 'Borgo San Michele,Capograssa,San Michele', 41.4382800, 12.9735100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82192, 'San Mauro Torinese', 'San Mauro Torinese', 'San Mauro Torinese,San Mo,San Mò,サン・マウロ・トリネーゼ', 45.1035900, 7.7680300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82193, 'San Mauro Pascoli', 'San Mauro Pascoli', 'San Mauro,San Mauro Pascoli,San Mauro di Romagna', 44.1089000, 12.4195300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82194, 'San Mauro la Bruca', 'San Mauro la Bruca', 'San Mauro la Bruca', 40.1224600, 15.2910900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82195, 'San Mauro Forte', 'San Mauro Forte', 'San Mauro Forte', 40.4833300, 16.2515500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82196, 'San Mauro di Saline', 'San Mauro di Saline', 'San Mauro di Saline', 45.5645200, 11.1123400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82197, 'San Mauro Cilento', 'San Mauro Cilento', 'San Mauro Cilento', 40.2262800, 15.0447600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82198, 'San Mauro', 'San Mauro', 'San Mauro a Signa', 43.7941800, 11.1249900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82199, 'San Maurizio D''Opaglio', 'San Maurizio D''Opaglio', 'San Maurizio d''Opaglio', 45.7729900, 8.3959900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82200, 'San Maurizio', 'San Maurizio', 'San Maurizio Canavese,San Morizio Canavese,サン・マウリーツィオ・カナヴェーゼ', 45.2170500, 7.6305200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82201, 'San Massimo', 'San Massimo', 'San Massimo', 41.4929200, 14.4102300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82202, 'San Marzano sul Sarno', 'San Marzano sul Sarno', 'San Marzano sul Sarno', 40.7780100, 14.5800600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82203, 'San Marzano di San Giuseppe', 'San Marzano di San Giuseppe', 'San Marzano di San Giuseppe,Shen Marcani', 40.4545500, 17.5035100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82204, 'San Martino Valle Caudina', 'San Martino Valle Caudina', 'San Martino,San Martino Valle Caudina', 41.0276400, 14.6644600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82205, 'San Martino sulla Marrucina', 'San Martino sulla Marrucina', '', 42.2241900, 14.2157700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82206, 'San Martino Siccomario', 'San Martino Siccomario', 'San Martino Siccomario', 45.1634000, 9.1406200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82207, 'San Martino Sannita', 'San Martino Sannita', 'San Martino Sannita', 41.0654600, 14.8349200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82208, 'San Martino in Rio', 'San Martino in Rio', 'Fanum Sancti Martini ad Rivum,San Martino in Rio,San-Martino-in-Rio,san martynw fy ryw,sheng ma er di nuo yin liao,Сан Мартино ин Рио,Сан-Мартино-ин-Рио,Сан-Мартіно-ін-Ріо,Սան Մարտինո ին Ռիո,سان مارتينو في ريو,サン・マルティーノ・イン・リーオ,圣马尔蒂诺因廖', 44.7336800, 10.7849000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82209, 'San Martino in Pensilis', 'San Martino in Pensilis', 'San Martino in Pensilis', 41.8781400, 15.0182400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82210, 'San Martino in Freddana-Monsagrati', 'San Martino in Freddana-Monsagrati', '', 43.9092100, 10.4377800, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82211, 'San Martino', 'San Martino', 'San Martino,San Martino in Casies,San Martino in Casies Valbassa', 46.8109700, 12.2268400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82212, 'San Martino in Campo', 'San Martino in Campo', '', 43.0360800, 12.4026500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82213, 'San Martino in Argine', 'San Martino in Argine', '', 44.5887600, 11.6065000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82214, 'San Martino di Venezze', 'San Martino di Venezze', 'San Martino,San Martino di Venezze', 45.1253200, 11.8701800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82215, 'San Martino di Lupari', 'San Martino di Lupari', '', 45.6512800, 11.8600400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82216, 'San Martino del Lago', 'San Martino del Lago', '', 45.0724300, 10.3156800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82217, 'San Martino della Battaglia', 'San Martino della Battaglia', '', 45.4383200, 10.6005300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82218, 'San Martino Dall''Argine', 'San Martino Dall''Argine', 'San Martino,San Martino dell''Argine', 45.0971500, 10.5176600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82219, 'San Martino d''Agri', 'San Martino d''Agri', 'San Martino d''Agri', 40.2391300, 16.0521600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82220, 'San Martino Canavese', 'San Martino Canavese', 'San Martino Canavese,サン・マルティーノ・カナヴェーゼ', 45.3945300, 7.8162200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82221, 'San Martino Buon Albergo', 'San Martino Buon Albergo', 'San Martino Buon Albergo', 45.4208300, 11.0956200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82222, 'San Martino al Cimino', 'San Martino al Cimino', '', 42.3697800, 12.1251500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82223, 'San Martino in Passiria', 'San Martino in Passiria', 'Passirium,San Martino in Badia,San Martino in Pasiria,San Martino in Pasirija,San Martino in Passiria,San-Martino-in-Passirija,Sankt Martin in Passeier,St Martin in Passeier,St. Martin in Passeier,sheng ma er di nuo yin pa xi li ya,Сан Мартино ин Пасирия,Сан-Мартино-ин-Пассирия,Сан-Мартіно-ін-Пассірія,Սան Մարտինո ին Պասիրիա,サン・マルティーノ・イン・パッシーリア,圣马尔蒂诺因帕西里亚', 46.7839200, 11.2272700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82224, 'San Martino', 'San Martino', '', 44.7779400, 11.5875100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82225, 'San Marco la Catola', 'San Marco la Catola', 'San Marco la Catola', 41.5248300, 15.0059400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82226, 'San Marco in Lamis', 'San Marco in Lamis', 'San Marco in Lamis', 41.7121000, 15.6382500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82227, 'San Marco Evangelista', 'San Marco Evangelista', 'San Marco Evangelista', 41.0370200, 14.3397900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82228, 'San Marco dei Cavoti', 'San Marco dei Cavoti', 'San Marco de'' Cavoti', 41.3088100, 14.8792400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82229, 'San Marcello Pistoiese', 'San Marcello Pistoiese', 'San Marcello,San Marcello Pistoiese', 44.0558300, 10.7936600, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82230, 'San Marcello', 'San Marcello', 'San Marcello,サン・マルチェッロ', 43.5752600, 13.2082700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82231, 'San Mango sul Calore', 'San Mango sul Calore', 'Fanum Sancti Magni,San Mango sul Calore,San Mango sul Calore vald,San Mango sul Kalore,San Mangu supra lu Caluri,San-Manga-sul''-Kaloreh,San-Mango-sul''-Kalore,sanmangosulkallole,sheng man ge su er ka luo lei,Сан Манго сул Калоре,Сан-Манга-суль-Калорэ,Сан-Манго-суль-Калоре,Սան Մանգո սուլ Կալորե,サン・マンゴ・スル・カローレ,圣曼戈苏尔卡洛雷,산만고술칼로레', 40.9589000, 14.9725100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82232, 'San Mango Piemonte', 'San Mango Piemonte', 'San Mango Piemonte', 40.7002400, 14.8391900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82233, 'San Lupo', 'San Lupo', 'San Lupo', 41.2614800, 14.6352800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82234, 'San Lorenzo Nuovo', 'San Lorenzo Nuovo', 'Fanum Sancti Laurentii Novi,San Lorenco Nuovo,San Lorenzo Novu,San Lorenzo Nuovo,San-Lorenco-Nuovo,sanlolenchonuobo,sheng luo lun zuo nuo wo,Сан Лоренцо Нуово,Сан-Лоренцо-Нуово,Սան Լորենցո Նուովո,サン・ロレンツォ・ヌオーヴォ,圣洛伦佐诺沃,산로렌초누오보', 42.6862600, 11.9071800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82235, 'San Lorenzo Maggiore', 'San Lorenzo Maggiore', 'San Lorenzo Maggiore', 41.2488500, 14.6243800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82236, 'San Lorenzo in Campo', 'San Lorenzo in Campo', 'San Lorenzo in Campo', 43.6014900, 12.9439800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82237, 'San Lorenzo di Sebato', 'San Lorenzo di Sebato', 'Fanum Sancti Laurentii Saevatiensis,San Lorenco di Sebato,San Lorenzo di Sebato,San-Lorenco-di-Sebato,Sankt Lorenzen,St. Lorenzen,sheng luo lun zuo di sai ba tuo,Сан Лоренцо ди Себато,Сан-Лоренцо-ди-Себато,Сан-Лоренцо-ді-Себато,Սան Լորենցո դի Սեբատո,サン・ロレンツォ・ディ・セバート,圣洛伦佐迪塞巴托', 46.7851400, 11.9081200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82238, 'San Lorenzo al Mare', 'San Lorenzo al Mare', 'San Lorenzo al Mare', 43.8537800, 7.9640600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82239, 'San Lorenzo', 'San Lorenzo', '', 46.1272000, 8.2006500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82240, 'San Lorenzello', 'San Lorenzello', 'San Lorenzello', 41.2760200, 14.5417300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82241, 'San Leucio del Sannio-Cavuoti', 'San Leucio del Sannio-Cavuoti', 'San Leucio del Sannio', 41.0744200, 14.7574400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82242, 'San Leonardo in Passiria', 'San Leonardo in Passiria', 'Fanum Sancti Leonardi,San Leonardo in Pasiria,San Leonardo in Passiria,San Leonarnto in Pasiria,San-Leanarda-in-Pasiryja,San-Leonardo-in-Passirija,Sankt Leonhard,Sankt Leonhard in Passeier,St Leonhard in Passeier,St. Leonhard im Passeiertal,St. Leonhard in Passeier,sheng lai ao na er duo yin pa xi li ya,Σαν Λεονάρντο ιν Πασίρια,Сан-Леанарда-ін-Пасірыя,Сан-Леонардо-ин-Пассирия,Сан-Леонардо-ін-Пассірія,Սան Լեոնարդո ին Պասիրիա,サン・レオナルド・イン・パッシーリア,圣莱奥纳尔多因帕西里亚', 46.8128200, 11.2457700, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82243, 'San Leonardo', 'San Leonardo', 'San Leonardo,Sant Lenart', 46.1191300, 13.5308500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82244, 'San Leo', 'San Leo', 'Civitas Sancti Leonis,Montefel''tro,San Leo,San-Leo,san lyw,sheng lai ao,Монтефельтро,Сан-Лео,סן לאו,سان ليو,サン・レーオ,圣莱奥', 43.8963700, 12.3446000, 'IT', '2016-07-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82245, 'San Lazzaro', 'San Lazzaro', 'San Lazzaro di Savena', 44.4705000, 11.4085100, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82246, 'Sanguinetto', 'Sanguinetto', 'Sanguinetto', 45.1856700, 11.1441200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82247, 'San Gregorio Magno', 'San Gregorio Magno', 'San Gregorio Magno', 40.6599200, 15.3991400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82248, 'San Gregorio da Sassola', 'San Gregorio da Sassola', 'San Gregorio,San Gregorio da Sassola,サン・グレゴーリオ・ダ・サッソラ', 41.9188100, 12.8744700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82249, 'San Gregorio Matese', 'San Gregorio Matese', '', 41.3855600, 14.3721700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82250, 'San Godenzo', 'San Godenzo', 'San Godenzo', 43.9250400, 11.6198200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82251, 'San Giusto Canavese', 'San Giusto Canavese', 'San Giusto,San Giusto Canavese,サン・ジュスト・カナヴェーゼ', 45.3153500, 7.8100100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82252, 'San Giustino Valdarno', 'San Giustino Valdarno', 'San Giustino,San Giustino Valdarno', 43.5526900, 11.7049700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82253, 'San Giustino', 'San Giustino', 'San Giustino,San Giustino Umbro', 43.5466000, 12.1752800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82254, 'San Giuseppe Vesuviano', 'San Giuseppe Vesuviano', 'San Giuseppe,San Giuseppe Vesuviano,サン・ジュゼッペ・ヴェズヴィアーノ', 40.8356000, 14.5048700, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82255, 'San Giuseppe', 'San Giuseppe', '', 44.7220200, 12.2171200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82256, 'San Giuliano Vecchio', 'San Giuliano Vecchio', '', 44.8890200, 8.7605700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82257, 'San Giuliano Terme', 'San Giuliano Terme', 'Bagni San Giuliano,Bagni di Pisa,Bagni di San Giuliano,San Giuliano,San Giuliano Terme', 43.7637200, 10.4385600, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82258, 'San Giuliano Milanese', 'San Giuliano Milanese', 'San Giuliano,San Giuliano Milanese,サン・ジュリアーノ・ミラネーゼ', 45.3940200, 9.2910900, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82259, 'San Giuliano di Puglia', 'San Giuliano di Puglia', 'San Giuliano di Puglia', 41.6879600, 14.9623100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82260, 'San Giuliano del Sannio', 'San Giuliano del Sannio', 'San Giuliano del Sannio', 41.4575200, 14.6416900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82261, 'San Giovanni Valdarno', 'San Giovanni Valdarno', 'S. Giovanni Valdarno,San Giovanni V.no,San Giovanni Valdarno,サン・ジョヴァンニ・ヴァルダルノ', 43.5675700, 11.5298700, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82262, 'San Giovanni Rotondo', 'San Giovanni Rotondo', 'GBN,Giovanni Rotondo,San Giovanni Rotondo', 41.7064300, 15.7277000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82263, 'San Giovanni Lupatoto', 'San Giovanni Lupatoto', 'Lupatoto,San Giovanni Lupatoto', 45.3819300, 11.0447400, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82264, 'San Giovanni Lipioni', 'San Giovanni Lipioni', 'San Giovanni Lipioni', 41.8438300, 14.5627100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82265, 'San Giovanni in Persiceto', 'San Giovanni in Persiceto', 'Persiceto,San Giovanni in Persiceto', 44.6383800, 11.1841900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82266, 'San Giovanni in Marignano', 'San Giovanni in Marignano', 'San Giovanni,San Giovanni in Marianano,San Giovanni in Marignano', 43.9398900, 12.7116600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82267, 'San Giovanni in Galdo', 'San Giovanni in Galdo', 'San Giovanni in Galdo', 41.5911000, 14.7520200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82268, 'San Giovanni in Croce', 'San Giovanni in Croce', '', 45.0739600, 10.3731500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82269, 'San Giovanni Incarico', 'San Giovanni Incarico', 'San Giovanni Incarico', 41.5000100, 13.5586400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82270, 'San Giovanni Ilarione', 'San Giovanni Ilarione', 'San Giovanni Ilarione', 45.5192700, 11.2370700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82271, 'San Giovanni del Dosso', 'San Giovanni del Dosso', 'San Giovanni', 44.9662700, 11.0811400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82272, 'San Giovanni d''Asso', 'San Giovanni d''Asso', 'San Giovanni d''Asso,サン・ジョヴァンニ・ダッソ', 43.1533400, 11.5893800, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82273, 'San Giovanni Bianco', 'San Giovanni Bianco', 'San Giovanni Bianco', 45.8734200, 9.6542000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82274, 'San Giovanni A Piro', 'San Giovanni A Piro', 'San Giovanni a Piro', 40.0515000, 15.4462000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82275, 'San Giovanni al Natisone', 'San Giovanni al Natisone', 'San Giovanni al Natisone,San Giovanni di Manzano,San Giovanni di Mauzano,San Zuan dal Nadison,Sant Zuan dal Nadison,サン・ジョヴァンニ・アル・ナティゾーネ', 45.9707900, 13.4018200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82276, 'San Giovanni', 'San Giovanni', 'San Giovanni,San Giovanni di Polcenigo', 46.0210400, 12.5155600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82277, 'San Giorio', 'San Giorio', '', 45.1275200, 7.1768300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82278, 'San Giorgio Piacentino', 'San Giorgio Piacentino', 'San Giorgio,San Giorgio Piacentino', 44.9519800, 9.7377300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82279, 'San Giorgio Lucano', 'San Giorgio Lucano', 'San Giorgio Lucano', 40.1113200, 16.3893000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82280, 'San Giorgio la Molara', 'San Giorgio la Molara', '', 41.2766700, 14.9309900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82281, 'San Giorgio Ionico', 'San Giorgio Ionico', 'San Giorgio Ionico,San Giorgio Jonico,San Giorgio sotto Taranto', 40.4579600, 17.3803400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82282, 'San Giorgio in Salici', 'San Giorgio in Salici', 'San Giorgio in Salice,San Giorgio in Salici', 45.4267600, 10.7890600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82283, 'San Giorgio in Bosco', 'San Giorgio in Bosco', 'Fanum Sancti Georgii in Bosco,San Dordi in Bosco,San Giorgio,San Giorgio in Bosco,San Jorjo in Bosko,San-Dzhordzho-in-Bosko,sheng jiao er jiao yin bo si ke,Сан-Джорджо-ин-Боско,Сан-Джорджо-ін-Боско,Սան Ջորջո ին Բոսկո,サン・ジョルジョ・イン・ボスコ,圣焦尔焦因博斯科', 45.5886300, 11.8073600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82284, 'San Giorgio di Piano', 'San Giorgio di Piano', 'San Giorgio di Piano', 44.6472400, 11.3744600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82285, 'San Giorgio di Pesaro', 'San Giorgio di Pesaro', '', 43.7224800, 12.9796900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82286, 'San Giorgio di Nogaro', 'San Giorgio di Nogaro', 'San Giorgio di Nogaro,San Zorc di Nuiar,Sant Zorc di Noiar,Sant Zorç di Noiâr', 45.8274500, 13.2108800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82287, 'San Giorgio di Lomellina', 'San Giorgio di Lomellina', 'San Giorgio,San Giorgio Lomellina,San Giorgio di Lomellina', 45.1748600, 8.7901400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82288, 'San Giorgio di Livenza', 'San Giorgio di Livenza', '', 45.6533000, 12.7969200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82289, 'San Giorgio del Sannio', 'San Giorgio del Sannio', 'San Giorgio Montagna', 41.0684400, 14.8532200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82290, 'San Giorgio della Richinvelda', 'San Giorgio della Richinvelda', 'San Giorgio della Richinvelda,San Zorc de Richinvelde', 46.0477800, 12.8686700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82291, 'San Giorgio Canavese', 'San Giorgio Canavese', 'San Giorgio,San Giorgio Canavese,San Giors Canaveis,San Giòrs Canavèis,サン・ジョルジョ・カナヴェーゼ', 45.3355700, 7.7982300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82292, 'San Giorgio a Liri', 'San Giorgio a Liri', 'San Giorgio', 41.4058400, 13.7597900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82293, 'San Giorgio a Cremano', 'San Giorgio a Cremano', 'San Giorgio a Cremano,サン・ジョルジョ・ア・クレマーノ', 40.8326100, 14.3416200, 'IT', '2015-08-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82294, 'San Giorgio', 'San Giorgio', '', 41.2706500, 14.3127800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82295, 'San Ginesio', 'San Ginesio', 'San Ginesio', 43.1075200, 13.3212100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82296, 'San Gimignano', 'San Gimignano', 'San Gimignano,סן ג''ימיניאנו,サン・ジミニャーノ', 43.4738000, 11.0297500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82297, 'San Gillio', 'San Gillio', 'San Gillio,サン・ジッリオ', 45.1405000, 7.5328500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82298, 'San Giacomo delle Segnate', 'San Giacomo delle Segnate', 'San Giacomo delle Segnate', 44.9741800, 11.0343400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82299, 'San Giacomo degli Schiavoni', 'San Giacomo degli Schiavoni', 'San Giacomo degli Schiavoni', 41.9623400, 14.9448100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82300, 'San Giacomo', 'San Giacomo', 'San Giacomo,San Giacomo di Spoleto', 42.7938700, 12.7524300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82301, 'San Gervasio Bresciano', 'San Gervasio Bresciano', 'San Gervasio Bresciano', 45.3077400, 10.1465200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82302, 'San Germano Vercellese', 'San Germano Vercellese', 'San Germano,San Germano Vercellese', 45.3509000, 8.2471700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82303, 'San Gennaro Vesuviano', 'San Gennaro Vesuviano', 'San Gennaro Vesuviano,サン・ジェンナーロ・ヴェズヴィアーノ', 40.8622600, 14.5241400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82304, 'San Genesio ed Uniti', 'San Genesio ed Uniti', 'Fanum Sancti Genexii et Municipia Coniuncta,San Genesio ed Uniti,San Gines,San Jenezio ed Yuniti,San-Dzhenez''o-ehd-Juniti,San-Dzhenezio-ed-Uniti,san ghynysyw ad ywnyty,sheng jie nei xiao ai du ni di,Сан-Дженезьо-эд-Юнити,Сан-Дженезіо-ед-Уніті,Սան Ջենեզիո էդ Յունիտի,سان غينيسيو إد يونيتي,サン・ジェネージオ・エド・ウニーティ,圣杰内肖埃杜尼蒂', 45.2341400, 9.1799700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82305, 'San Genesio Atesino', 'San Genesio Atesino', 'Jenesien,San Genesio,San Genesio Atesino,サン・ジェネージオ・アテジーノ', 46.5346000, 11.3297100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82306, 'San Gemini', 'San Gemini', 'Casventum,San Dzhemini,San Gemini,San Jemini,San-Dzhemini,san jymyny,sanjemini,sheng jie mi ni,Сан Джемини,Сан-Джемини,Сан-Джеміні,Սան Ջեմինի,سان جيميني,サン・ジェーミニ,圣杰米尼,산제미니', 42.6137800, 12.5452800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82307, 'Sangano', 'Sangano', 'Sangan,Sangano', 45.0250800, 7.4498700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82308, 'San Gabriele-Mondonuovo', 'San Gabriele-Mondonuovo', '', 44.6666700, 11.5833300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82309, 'Sanfront', 'Sanfront', 'Fanum Sancti Frontiniani,Sanfront,Sant Front,Sant Frònt,sanfuronto,sang fu long te,Санфронт,Սանֆրոնտ,サンフロント,桑夫龙特', 44.6469800, 7.3224300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82310, 'Sanfrè', 'Sanfre', 'Sanfre,Sanfrè', 44.7518000, 7.8028900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82311, 'Aglientu', 'Aglientu', 'Aglientu,Santo Franciscu di l''Aglientu', 41.0790600, 9.1126700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82312, 'San Francesco al Campo', 'San Francesco al Campo', 'San Francesco al Campo,San Fransesch,サン・フランチェスコ・アル・カンポ', 45.2273200, 7.6547900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82313, 'San Floriano del Collio', 'San Floriano del Collio', 'San Florean dai Cuei,San Florean dal Cuei,San Floriano del Collio', 45.9808800, 13.5887500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82314, 'San Floriano', 'San Floriano', '', 45.5179600, 10.9081700, 'IT', '2015-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82315, 'San Fior di Sopra', 'San Fior di Sopra', 'San Fior', 45.9221900, 12.3613700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82316, 'San Fiorano', 'San Fiorano', 'San Fiorano,サン・フィオラーノ', 45.1381500, 9.7206300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82317, 'San Ferdinando di Puglia', 'San Ferdinando di Puglia', 'San Ferdinando di Puglia', 41.3026300, 16.0704600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82318, 'San Felice sul Panaro', 'San Felice sul Panaro', 'San Felice,San Felice sul Panaro', 44.8367100, 11.1379100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82319, 'San Felice del Molise', 'San Felice del Molise', 'San Felice,San Felice Slavo,San Felice del Littorio,San Felice del Molise', 41.8900000, 14.7008800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82320, 'San Felice del Benaco', 'San Felice del Benaco', 'San Felice,San Felice del Benaco,San Felice di Scovolo', 45.5827600, 10.5538000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82321, 'San Felice Circeo', 'San Felice Circeo', 'San Felice Circeo,サン・フェリーチェ・チルチェーオ', 41.2371600, 13.0941600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82322, 'San Felice', 'San Felice', '', 46.4942900, 11.1302200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82323, 'San Felice', 'San Felice', '', 45.1430100, 10.0737300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82324, 'San Fele', 'San Fele', 'San Fele', 40.8164700, 15.5404300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82325, 'San Fedele Superiore', 'San Fedele Superiore', 'San Fedele Intelvi di sopra,San Fedele Superiore', 45.9666700, 9.0666700, 'IT', '2012-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82326, 'Sandrigo', 'Sandrigo', 'Sandrigo', 45.6608300, 11.5892100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82327, 'Dolina', 'Dolina', 'Dol-Ottelza,Dolina,San Dorligo della Valle,サン・ドルリーゴ・デッラ・ヴァッレ', 45.6008000, 13.8592900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82328, 'San Donato Val di Comino', 'San Donato Val di Comino', 'San Donato Val di Comino', 41.7072600, 13.8122000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82329, 'San Donato Milanese', 'San Donato Milanese', 'San Donato Milanese,サン・ドナート・ミラネーゼ', 45.4104700, 9.2683800, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82330, 'San Donato di Lecce', 'San Donato di Lecce', 'San Donato di Lecce', 40.2672800, 18.1825600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82331, 'San Donà di Piave', 'San Dona di Piave', 'San Dona di Piave,San Dona'' Di Piave,San Donà di Piave,San-Dona-di-P''jave,San-Dona-dzi-P''javeh,san dwna dy byafy,Сан-Дона-дзі-П''явэ,Сан-Дона-ди-Пьяве,سان دونا دي بيافي,サン・ドナ・ディ・ピアーヴェ', 45.6301900, 12.5681000, 'IT', '2016-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82332, 'San Donaci', 'San Donaci', 'San Donaci', 40.4485300, 17.9225200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82333, 'Sandigliano', 'Sandigliano', 'Sandighano,Sandigliano', 45.5220400, 8.0766000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82334, 'San Demetrio Ne'' Vestini', 'San Demetrio Ne'' Vestini', 'San Demetrio nei Vestini', 42.2896300, 13.5551900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82335, 'San Daniele del Friuli', 'San Daniele del Friuli', 'San Daniele,San Daniele del Friuli,San Denel,Sant Denel,Sant Denêl', 46.1571400, 13.0072600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82336, 'San Damiano Macra', 'San Damiano Macra', 'San Damiano Macra', 44.4884800, 7.2560600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82337, 'San Damiano d''Asti', 'San Damiano d''Asti', 'San Damian,San Damiano,San Damiano d''Asti', 44.8334400, 8.0635300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82338, 'San Damiano al Colle', 'San Damiano al Colle', 'San Damiano al Colle', 45.0271300, 9.3486000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82339, 'Santa Croce del Sannio', 'Santa Croce del Sannio', '', 41.3879300, 14.7322900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82340, 'San Cristoforo', 'San Cristoforo', 'San Cristoforo', 44.6930400, 8.7493900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82341, 'San Costanzo', 'San Costanzo', 'San Costanzo', 43.7672000, 13.0730600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82342, 'San Costantino Albanese', 'San Costantino Albanese', 'San Costantino Albanese,Shen Kostadini', 40.0367900, 16.3047500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82343, 'San Colombano al Lambro', 'San Colombano al Lambro', 'San Colombano,San Colombano al Lambro,サン・コロンバーノ・アル・ランブロ', 45.1832200, 9.4902800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82344, 'San Clemente', 'San Clemente', 'San Clemente', 43.9326900, 12.6270700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82345, 'San Clemente', 'San Clemente', '', 41.3402700, 13.9559700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82346, 'San Cipriano Po', 'San Cipriano Po', 'San Cipriano Po', 45.1090900, 9.2808900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82347, 'San Cipriano Picentino', 'San Cipriano Picentino', 'San Cipriano Picentino', 40.7200800, 14.8719500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82348, 'San Chirico Raparo', 'San Chirico Raparo', 'San Chirico Raparo', 40.1924200, 16.0761800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82349, 'San Chirico Nuovo', 'San Chirico Nuovo', 'Chirico,San Chirico Nuovo', 40.6776400, 16.0789200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82350, 'San Cesario sul Panaro', 'San Cesario sul Panaro', 'San Cesario sul Panaro,サン・チェザーリオ・スル・パーナロ', 44.5635200, 11.0350800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82351, 'San Cesario di Lecce', 'San Cesario di Lecce', 'San Cesario,San Cesario di Lecce', 40.3022100, 18.1609800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82352, 'San Cesareo', 'San Cesareo', 'San Cesareo,サン・チェザーレオ', 41.8211300, 12.8044700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82353, 'San Castrese', 'San Castrese', '', 41.2586200, 13.8654100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82354, 'San Cassiano', 'San Cassiano', '', 46.2769700, 9.3974300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82355, 'San Cassiano', 'San Cassiano', 'San Cassiano', 40.0563100, 18.3339200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82356, 'San Casciano in Val di Pesa', 'San Casciano in Val di Pesa', 'San Casciano Val di Pesa,San Casciano in Val di Pesa', 43.6597500, 11.1849400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82357, 'San Casciano dei Bagni', 'San Casciano dei Bagni', 'San Casciano de''Bagni,San Casciano dei Bagni,サン・カシャーノ・デイ・バーニ', 42.8700800, 11.8765600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82358, 'San Carlo', 'San Carlo', '', 44.8036100, 11.4099900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82359, 'San Candido', 'San Candido', 'India,Innichen,San Candido,San Kantinto,San-Kandido,san kandydw,sheng kan di duo,Σαν Κάντιντο,Сан-Кандидо,Сан-Кандідо,سان كانديدو,サン・カンディド,圣坎迪多', 46.7324000, 12.2785500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82360, 'San Buono', 'San Buono', 'San Buono', 41.9814000, 14.5681800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82361, 'San Bonifacio', 'San Bonifacio', 'Sambonifacio,San Bonifacio', 45.3959500, 11.2735200, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82362, 'San Biase', 'San Biase', 'San Biase', 41.7152600, 14.5904900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82363, 'San Biagio Saracinisco', 'San Biagio Saracinisco', 'Fanum Sancti Blasii Sarracinescum,San Biadzho Sarachinisko,San Biaggiu Saraciniscu,San Biagio Saracinisco,San Biágio Saracinisco,San-B''jadzho-Sarachinisko,San-Bjadzha-Sarachyniska,San-Bjadzho-Sarachinisko,sanbiajosalachiniseuko,sheng bi ya jiao sa la qi ni si ke,Сан Биаджо Сарачиниско,Сан-Бьяджо-Сарачиниско,Сан-Бяджа-Сарачыніска,Сан-Бяджо-Сарачиніско,Սան Բյաջո Սարաչինիսկո,サン・ビアージョ・サラチニスコ,圣比亚焦萨拉奇尼斯科,산비아조사라치니스코', 41.6132200, 13.9275800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82364, 'San Biagio di Callalta', 'San Biagio di Callalta', 'San Biagio di Callalta', 45.6836100, 12.3772200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82365, 'San Biagio della Cima', 'San Biagio della Cima', 'San Biagio della Cima', 43.8178400, 7.6513300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82366, 'San Biagio', 'San Biagio', '', 44.5869500, 11.8691800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82367, 'San Benigno Canavese', 'San Benigno Canavese', 'San Benigno Canavese,サン・ベニーニョ・カナヴェーゼ', 45.2261700, 7.7842700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82368, 'San Benedetto Val di Sambro', 'San Benedetto Val di Sambro', 'San Benedetto,San Benedetto Val di Sambro', 44.2140500, 11.2356700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82369, 'San Benedetto Po', 'San Benedetto Po', 'San Benedetto,San Benedetto Po', 45.0461200, 10.9336700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82370, 'San Benedetto in Perillis', 'San Benedetto in Perillis', 'San Benedetto in Perillis', 42.1837700, 13.7699600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82371, 'San Benedetto dei Marsi', 'San Benedetto dei Marsi', 'San Benedetto', 42.0076000, 13.6238100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82372, 'San Benedetto del Tronto', 'San Benedetto del Tronto', 'San Benedetto del Tronto', 42.9568000, 13.8767600, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82373, 'San Bellino', 'San Bellino', 'San Bellino', 45.0294300, 11.5922200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82374, 'San Bassano', 'San Bassano', 'San Bassano', 45.2437800, 9.8095400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82375, 'San Bartolomeo in Galdo', 'San Bartolomeo in Galdo', 'San Bartolommeo in Galdo', 41.4159500, 15.0170900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82376, 'San Bartolomeo In Bosco', 'San Bartolomeo In Bosco', '', 44.7309400, 11.6357300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82377, 'Sanarica', 'Sanarica', 'Sanarica', 40.0890800, 18.3480300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82378, 'Sampeyre', 'Sampeyre', 'Sampeyre,Sampéyre', 44.5784600, 7.1903900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82379, 'Samone', 'Samone', 'Samone,samone,サモーネ', 45.4491400, 7.8419800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82380, 'Sammichele di Bari', 'Sammichele di Bari', 'Sammichele di Bari,San Michele di Bari', 40.8871100, 16.9491900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82381, 'Sambuco', 'Sambuco', 'Sambuco', 44.3351000, 7.0787800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82382, 'Sambuci', 'Sambuci', 'Sambuci,sanbuchi,サンブーチ', 41.9853600, 12.9381700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82383, 'Samarate', 'Samarate', 'Samarate', 45.6241000, 8.7850700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82384, 'Salzano', 'Salzano', 'Salzano,sarutsu~ano,サルツァーノ', 45.5222100, 12.1015100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82385, 'Salza Irpina', 'Salza Irpina', 'Salza Irpina', 40.9189300, 14.8899600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82386, 'Salvitelle', 'Salvitelle', 'Salvitelle', 40.5906400, 15.4576000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82387, 'Salvirola', 'Salvirola', 'Salvirola', 45.3563000, 9.7792400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82388, 'Salvatronda', 'Salvatronda', '', 45.6742500, 11.9770900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82389, 'Salvaterra', 'Salvaterra', '', 44.5992500, 10.7686000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82390, 'Saluzzo', 'Saluzzo', '', 44.6467100, 7.4930900, 'IT', '2016-04-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82391, 'La Salute di Livenza', 'La Salute di Livenza', 'Casa Salute,La Salute,La Salute di Livenza,Salute', 45.6536600, 12.8013100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82392, 'Salussola', 'Salussola', 'Salussola', 45.4466600, 8.1110000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82393, 'Saluggia', 'Saluggia', 'Saluggia', 45.2368700, 8.0146000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82394, 'Saludecio', 'Saludecio', 'Saludecio', 43.8754000, 12.6611800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82395, 'Saltara', 'Saltara', 'Saltara', 43.7525200, 12.8985300, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82396, 'Salsomaggiore Terme', 'Salsomaggiore Terme', 'Salsomaggiore,Salsomaggiore Terme', 44.8159200, 9.9863700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82397, 'Salorno', 'Salorno', 'Salorno,Salurn,saroruno,サロルノ', 46.2406200, 11.2119200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82398, 'Salò', 'Salo', 'Pagus Salodium,Salo,Salò,saro,Сало,サロ', 45.6068500, 10.5205000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82399, 'Salmour', 'Salmour', 'Salmour', 44.5755600, 7.7914800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82400, 'Salle', 'Salle', 'Sale,Salle,Salles,Salli,sa lai,salle,saly,sarre,Сале,Салле,Սալլե,سالي,サッレ,萨莱,살레', 42.1775600, 13.9609100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82401, 'Salizzole', 'Salizzole', 'Salizzole', 45.2400400, 11.0954000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82402, 'Sali Vercellese', 'Sali Vercellese', 'Sala Vercellese,Sali Vercellese', 45.3098600, 8.3289300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82403, 'Salitto-Valle', 'Salitto-Valle', '', 40.6741200, 15.0224100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82404, 'Salisano', 'Salisano', '', 42.2594700, 12.7477400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82405, 'Salionze', 'Salionze', '', 45.4049300, 10.7225900, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82406, 'Saline', 'Saline', 'Saline,Saline di Volterra', 43.3618500, 10.8135400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82407, 'Saliceto', 'Saliceto', 'Saliceto,saricheto,サリチェート', 44.4133400, 8.1686400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82408, 'Salice Terme', 'Salice Terme', 'Salice', 44.9151000, 9.0263000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82409, 'Salice Salentino', 'Salice Salentino', 'Salice Salentino', 40.3848500, 17.9613400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82410, 'Salgareda', 'Salgareda', 'Salgareda,Salgareda Vecchia', 45.7050000, 12.4883300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82411, 'Saletto-San Bartolomeo', 'Saletto-San Bartolomeo', '', 45.7263900, 12.3955600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82412, 'Saletto', 'Saletto', 'Saletto', 45.2288900, 11.5378000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82413, 'Salerno', 'Salerno', 'QSR,Salernas,Salerne,Salerno,Salernu,Salernum,Salierno,salyrnw,sareruno,Салерно,ساليرنو,サレルノ', 40.6754500, 14.7932800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82414, 'Salento', 'Salento', '', 40.2491300, 15.1893800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82415, 'Sale Marasino', 'Sale Marasino', 'Sale Marasino', 45.7063800, 10.1121600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82416, 'Sale', 'Sale', 'Sale', 44.9793200, 8.8096300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82417, 'Salcito', 'Salcito', 'Salcito', 41.7464000, 14.5108500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82418, 'Salcedo', 'Salcedo', 'Salcedo', 45.7578300, 11.5662100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82419, 'Salassa', 'Salassa', 'Salassa,sarassa,サラッサ', 45.3617500, 7.6829700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82420, 'Salara', 'Salara', 'Salara', 44.9858600, 11.4265500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82421, 'Salandra', 'Salandra', 'Salandra', 40.5266800, 16.3203700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82422, 'Sala Monferrato', 'Sala Monferrato', 'Sala Monferrato', 45.0754600, 8.3611900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82423, 'Sala Consilina', 'Sala Consilina', 'Sala Consilina,Sala Cosilina', 40.4013400, 15.5914000, 'IT', '2016-04-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82424, 'Sala Bolognese', 'Sala Bolognese', 'Sala Bolognese', 44.6138700, 11.2566900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82425, 'Sala Biellese', 'Sala Biellese', 'Sala Biellese', 45.5085600, 7.9580000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82426, 'Salbertrand', 'Salbertrand', 'Salbertrand,saruberutorando,サルベルトランド', 45.0735000, 6.8874400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82427, 'Sala Baganza', 'Sala Baganza', 'Sala Baganza', 44.7156300, 10.2262200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82428, 'Sairano', 'Sairano', '', 45.1367200, 9.0516200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82429, 'Saint-Vincent', 'Saint-Vincent', 'Saint-Vincent,San Vincenzo della Fonte,Sen-Vensan,Сен-Венсан', 45.7508200, 7.6481500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82430, 'San Leonardo', 'San Leonardo', 'Saint-Leonard,Saint-Léonard', 45.8236600, 7.1814000, 'IT', '2016-05-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82431, 'Saint-Pierre', 'Saint-Pierre', 'Saint-Pierre', 45.7115300, 7.2268300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82432, 'Saint-Oyen', 'Saint-Oyen', 'Saint-Oyen', 45.8243900, 7.2137200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82433, 'Sagrado', 'Sagrado', 'Sagrado,Sagrado d''Isonzo,Sagrado d’Isonzo,Sagrat', 45.8739300, 13.4841800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82434, 'Sagama', 'Sagama', 'Sagama', 40.2615500, 8.5775200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82435, 'Sacrofano', 'Sacrofano', 'Sacrofano,sakurofano,サクロファーノ', 42.1045700, 12.4478100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82436, 'Sacile', 'Sacile', 'Sacil,Sacile,Sacîl', 45.9541200, 12.5027400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82437, 'Saccolongo', 'Saccolongo', 'Saccolongo', 45.4015200, 11.7486300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82438, 'Sacco', 'Sacco', 'Sacco', 40.3767100, 15.3778300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82439, 'La Caletta', 'La Caletta', '', 40.6098800, 9.7506200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82440, 'Sabbioneta', 'Sabbioneta', 'Sabbioneta', 44.9978700, 10.4884800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82441, 'Sabbio Chiese', 'Sabbio Chiese', 'Sabbio Chiese', 45.6558900, 10.4219300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82442, 'Sabbia', 'Sabbia', 'Sabbia', 45.8572000, 8.2358000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82443, 'Sabaudia', 'Sabaudia', 'Sabaudia,sabaudia,サバウディア', 41.3002500, 13.0281500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82444, 'Ruvo di Puglia', 'Ruvo di Puglia', 'Ruvo di Puglia', 41.1175800, 16.4842100, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82445, 'Ruvo del Monte', 'Ruvo del Monte', 'Ruvo del Monte', 40.8495100, 15.5421700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82446, 'Ruviano', 'Ruviano', '', 41.2106300, 14.4098300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82447, 'Rutino', 'Rutino', 'Rutino', 40.3007200, 15.0732800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82448, 'Rutigliano', 'Rutigliano', 'Rutigliano', 41.0099700, 17.0055800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82449, 'Russi', 'Russi', 'Russi,russhi,ルッシ', 44.3764500, 12.0333500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82450, 'Ruoti', 'Ruoti', 'Ruoti', 40.7166000, 15.6836900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82451, 'Rufina', 'Rufina', 'Rufina', 43.8239600, 11.4867300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82452, 'Ruffia', 'Ruffia', 'Ruffia', 44.7059800, 7.6039100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82453, 'Rudiano', 'Rudiano', 'Rudiano,rudiano,ルディアーノ', 45.4895200, 9.8860600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82454, 'Rubiera', 'Rubiera', 'Rubiera', 44.6515800, 10.7794000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82455, 'Rubiana', 'Rubiana', 'Rubian-a,Rubiana,rubiana,ルビアーナ', 45.1362200, 7.3843900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82456, 'Rubano', 'Rubano', 'Rubano', 45.4251400, 11.7914600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82457, 'Pragelato-Ruà', 'Pragelato-Rua', 'Pragela,Pragelato,Prajalats,purajerato,プラジェラート', 45.0136400, 6.9416100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82458, 'Rozzano', 'Rozzano', 'Rozzano,rottsu~ano,ロッツァーノ', 45.3819300, 9.1559000, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82459, 'Rovigo', 'Rovigo', 'Rodigium,Rovigo,rovu~igo,Ровиго,ロヴィーゴ', 45.0698200, 11.7902200, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82460, 'Roviano', 'Roviano', 'Roviano,rovu~iano,ロヴィアーノ', 42.0264300, 12.9939000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82461, 'Rovetta', 'Rovetta', 'Rovetta', 45.8917800, 9.9821200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82462, 'Rovereto', 'Rovereto', 'Rovereto,rovu~ereto,Роверето,ロヴェレート', 45.8904000, 11.0405300, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82463, 'Rovereto', 'Rovereto', '', 44.8338100, 10.9515700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82464, 'Roveredo in Piano', 'Roveredo in Piano', 'Lavoreit,Roveredo,Roveredo in Piano', 46.0084700, 12.6193800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82465, 'Roverè della Luna', 'Rovere della Luna', 'Rovere della Luna,Roverè della Luna,ロヴェレー・デッラ・ルーナ', 46.2500800, 11.1723300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82466, 'Roverbella', 'Roverbella', 'Roverbella,Ровербелла', 45.2665900, 10.7704700, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82467, 'Rovello Porro', 'Rovello Porro', 'Rodellum,Rovell,Rovello Poro,Rovello Porro,Rovello-Porro,luo wei luo bo luo,Ровелло-Порро,Ռովելլո Պորո,ロヴェッロ・ポッロ,罗韦洛波罗', 45.6521000, 9.0394000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82468, 'Rovellasca', 'Rovellasca', 'Rovellasca,Rovi Porro', 45.6666400, 9.0488400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82469, 'Rovato', 'Rovato', 'Rovato', 45.5634200, 10.0021300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82470, 'Rovasenda', 'Rovasenda', 'Bovasenda,Roasenda,Rovasenda', 45.5386600, 8.3159200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82471, 'Rovagnate', 'Rovagnate', 'Rovagnaa,Rovan''ate,Rovan''jate,Rovaniatum,Rovanyate,luo wa ni ya tai,rovu~anyate,Рованьате,Рованьяте,Ռովանյատե,ロヴァニャーテ,罗瓦尼亚泰', 45.7369200, 9.3711100, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82472, 'Rottofreno', 'Rottofreno', '', 45.0552700, 9.5500700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82473, 'Rottanova', 'Rottanova', '', 45.1436100, 12.0184900, 'IT', '2014-04-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82474, 'Rotondi', 'Rotondi', 'Rotondi', 41.0329300, 14.5954800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82475, 'Rotondella', 'Rotondella', 'Rotondella', 40.1713600, 16.5249100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82476, 'Rotello', 'Rotello', 'Rotello', 41.7477600, 15.0060800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82477, 'Rotella', 'Rotella', 'Rotella', 42.9543500, 13.5584900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82478, 'Rossiglione', 'Rossiglione', 'Roscigion,Rossiglione', 44.5635800, 8.6695600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82479, 'Rossano Veneto', 'Rossano Veneto', 'Rossano Veneto', 45.7030800, 11.8036900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82480, 'Rossana', 'Rossana', 'Rossana', 44.5447000, 7.4319300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82481, 'Rosora', 'Rosora', 'Rosora,rozora,ロゾーラ', 43.4833600, 13.0681900, 'IT', '2014-06-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82482, 'Rosolina', 'Rosolina', 'Rosolina,Rosolinia,Roxolina,Roxołina,Rozolina,luo suo li na,rozorina,Розолина,Розоліна,Ռոզոլինա,ロゾリーナ,罗索利纳', 45.0767400, 12.2297700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82483, 'Rosignano Solvay-Castiglioncello', 'Rosignano Solvay-Castiglioncello', 'Rosignano,Rosignano Solvay', 43.3894600, 10.4361500, 'IT', '2017-02-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82484, 'Rosignano Marittimo', 'Rosignano Marittimo', 'Rosignano Marittimo,ロジニャーノ・マリッティモ', 43.4068600, 10.4723100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82485, 'Rosia', 'Rosia', '', 43.2461100, 11.2217600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82486, 'Roseto Valfortore', 'Roseto Valfortore', 'Roseto,Roseto Valfortore', 41.3754400, 15.0982400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82487, 'Roseto degli Abruzzi', 'Roseto degli Abruzzi', 'Rosburgo,Roseto degli Abruzzi', 42.6716400, 14.0148100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82488, 'Rosello', 'Rosello', 'Rosello', 41.9011600, 14.3491900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82489, 'Roscigno', 'Roscigno', 'Roscigno', 40.3999700, 15.3458500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82490, 'Rosciano', 'Rosciano', '', 43.8162000, 12.9999200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82491, 'Rosciano', 'Rosciano', 'Rosciano', 42.3222700, 14.0455500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82492, 'Rosate', 'Rosate', 'Rosate,rozate,ロザーテ', 45.3496500, 9.0165900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82493, 'Rosasco', 'Rosasco', 'Rosasco', 45.2503100, 8.5793000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82494, 'Rosa', 'Rosa', '', 45.9305600, 12.8708300, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82495, 'Rosà', 'Rosa', 'Rosa,Rosà', 45.7019800, 11.7614100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82496, 'Ronzone', 'Ronzone', 'Romzone,Ronzone,rontsu~one,ロンツォーネ', 46.4243700, 11.1527500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82497, 'Ronta', 'Ronta', '', 44.0031000, 11.4289400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82498, 'Ronsecco', 'Ronsecco', 'Ronsecco', 45.2528400, 8.2774900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82499, 'Rondissone', 'Rondissone', 'Rondisson,Rondissone,rondissone,ロンディッソーネ', 45.2463000, 7.9642600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82500, 'Ronco Scrivia', 'Ronco Scrivia', 'Ronco,Ronco Scrivia', 44.6135700, 8.9504200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82501, 'Roncone', 'Roncone', 'Roncone,ronkone,ロンコーネ', 45.9827000, 10.6681700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82502, 'Roncofreddo', 'Roncofreddo', 'Roncofreddo', 44.0422200, 12.3008300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82503, 'Roncoferraro', 'Roncoferraro', 'Roncoferraro', 45.1381200, 10.9421000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82504, 'Roncocesi', 'Roncocesi', '', 44.7384300, 10.5781600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82505, 'Ronco Canavese', 'Ronco Canavese', 'Ronco,Ronco Canavese,ロンコ・カナヴェーゼ', 45.5008100, 7.5470200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82506, 'Ronco All''Adige', 'Ronco All''Adige', 'Ronco all''Adige', 45.3364700, 11.2365800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82507, 'Ronciglione', 'Ronciglione', 'Ronciglione', 42.2889900, 12.2147900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82508, 'Ronchis', 'Ronchis', 'Ronchis,Roncjis di Tisane', 45.8079200, 12.9954500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82509, 'Ronchi dei Legionari', 'Ronchi dei Legionari', 'Ronchi,Ronchi dei Legionari,Roncji,Roncjis', 45.8273500, 13.5041700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82510, 'Roncegno', 'Roncegno', 'Roncegno,ronchenyo,ロンチェーニョ', 46.0493400, 11.4082400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82511, 'Roncade', 'Roncade', 'Roncade', 45.6216500, 12.3764300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82512, 'Roncà', 'Ronca', 'Ronca,Roncà', 45.4798700, 11.2932300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82513, 'Romentino', 'Romentino', 'Romentino', 45.4629600, 8.7181100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82514, 'Romeno', 'Romeno', 'Romeno,romeno,ロメーノ', 46.3945200, 11.1192000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82515, 'Romans d''Isonzo', 'Romans d''Isonzo', 'Romans,Romans d''Isonzo,Romans dal Lusinc', 45.8881600, 13.4418700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82516, 'Romano di Lombardia', 'Romano di Lombardia', 'Romano di Lombardia', 45.5208100, 9.7544000, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82517, 'Romano Canavese', 'Romano Canavese', 'Ramana-Kanavezeh,Roman,Romano,Romano Canavese,Romano Kanaveze,Romano-Kanaveze,Romanum,luo ma nuo ka na wei sai,Рамана-Канавезэ,Романо-Канавезе,Ռոմանո Կանավեզե,ロマーノ・カナヴェーゼ,罗马诺卡纳韦塞', 45.3992500, 7.8688500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82518, 'Romanengo', 'Romanengo', 'Romanengo,Romanengo vald,Rumanench,Rumanénch,luo ma nen ge,romanengo,Романенго,Ռոմանենգո,ロマネンゴ,罗马嫩戈', 45.3781500, 9.7877700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82519, 'Romana', 'Romana', 'Romana', 40.4843900, 8.5857100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82520, 'Romagnese', 'Romagnese', 'Romagnese', 44.8413100, 9.3281000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82521, 'Romagnano Sesia', 'Romagnano Sesia', 'Romagnano,Romagnano Sesia,ロマニャーノ・セージア', 45.6327900, 8.3869700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82522, 'Scalo Romagnano al Monte', 'Scalo Romagnano al Monte', 'Romagnano al Monte', 40.6103100, 15.4476800, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82523, 'Romagnano', 'Romagnano', '', 46.0180700, 11.1056300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82524, 'Rome', 'Rome', 'An Roimh,An Ròimh,An Róimh,Erroma,Hrom,Lungsod ng Roma,Mji wa Roma,ROM,Ramma,Rhufain,Rim,Rim",Roeme,Rom,Roma,Rome,Romma,Romo,Romë,Rooma,Roum,Rym,Rzym,Råmma,Rím,Róm,Róma,Urbs,loma,luo ma shi,rm,rom,roma,romi,rwm,rwma,rym,Řím,Ρώμη,Рим,Римъ,Ром,Рым,Հռոմ,רומא,رم,روم,روما,رىم,ܪܘܡܐ,रोम,रोमा,โรม,რომი,ሮማ,ローマ,罗马市,로마', 41.8919300, 12.5113300, 'IT', '2016-12-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82525, 'Rolo', 'Rolo', 'Rolo', 44.8848200, 10.8596100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82526, 'La Cretaz-Roisan', 'La Cretaz-Roisan', 'Roisan', 45.7839600, 7.3131000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82527, 'Roio del Sangro', 'Roio del Sangro', 'Roio del Sangro', 41.9115300, 14.3738200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82528, 'Roiate', 'Roiate', 'Roiate,roiate,ロイアーテ', 41.8733200, 13.0662700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82529, 'Rogolo', 'Rogolo', 'Rogolo', 46.1372100, 9.4852800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82530, 'Rognano', 'Rognano', 'Rognano', 45.2884700, 9.0902500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82531, 'Rofrano', 'Rofrano', 'Rofrano', 40.2127700, 15.4284800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82532, 'Rodigo', 'Rodigo', 'Rodigo,rodigo,ローディゴ', 45.1991200, 10.6252700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82533, 'Rodi Garganico', 'Rodi Garganico', 'Rodi Garganico', 41.9274500, 15.8821700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82534, 'Rodengo', 'Rodengo', 'Radehnga,Rodeneck,Rodeneck-Rodengo,Rodengo,Rodengum,luo deng ge,rodengo,Радэнга,Роденго,Ռոդենգո,ロデンゴ,罗登戈', 46.8000000, 11.7000000, 'IT', '2012-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82535, 'Rodeano', 'Rodeano', 'Rodeano,Rodeano Basso', 46.1108500, 13.0111000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82536, 'Lucino-Rodano', 'Lucino-Rodano', 'Rodano,rodano,ローダノ', 45.4760700, 9.3531500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82537, 'Rocchetta Sant''Antonio', 'Rocchetta Sant''Antonio', 'Rocchetta San Antonio,Rocchetta Sant''Antonio,Rochetta Sant''Antonio', 41.1032600, 15.4599300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82538, 'Rocchetta Nervina', 'Rocchetta Nervina', 'Rocchetta Nervina', 43.8898800, 7.6007100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82539, 'Rocchetta Ligure', 'Rocchetta Ligure', 'Rocchetta Ligure', 44.7065500, 9.0504600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82540, 'Rocchetta di Vara', 'Rocchetta di Vara', 'A Rocheta,Rocchetta di Vara', 44.2505900, 9.7579100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82541, 'Rocchetta a Volturno', 'Rocchetta a Volturno', 'Rocchetta,Rocchetta al Volturno', 41.6258200, 14.0890200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82542, 'Rocchetta', 'Rocchetta', '', 41.2371600, 14.1576500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82543, 'Roccavivi', 'Roccavivi', '', 41.8121400, 13.5366200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82544, 'Roccavivara', 'Roccavivara', '', 41.8333600, 14.6001300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82545, 'Roccavione', 'Roccavione', 'Roccavione', 44.3135500, 7.4784500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82546, 'Susella', 'Susella', 'Rocca Susella', 44.9126700, 9.0965100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82547, 'Roccastrada', 'Roccastrada', 'Roccastrada', 43.0088800, 11.1676200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82548, 'Roccaspinalveti-Santa Giusta', 'Roccaspinalveti-Santa Giusta', 'Roccaspinalveti', 41.9423300, 14.4709200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82549, 'Rocca Sinibalda', 'Rocca Sinibalda', '', 42.2721500, 12.9246900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82550, 'Roccasicura', 'Roccasicura', '', 41.6967600, 14.2306500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82551, 'Roccasecca dei Volsci', 'Roccasecca dei Volsci', 'Roccasecca dei Volsci,ロッカセッカ・デイ・ヴォルシ', 41.4785200, 13.2128000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82552, 'Roccasecca', 'Roccasecca', 'Roccasecca,rokkasekka,ロッカセッカ', 41.5513200, 13.6671100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82553, 'Roccascalegna', 'Roccascalegna', 'Roccascalegna', 42.0621200, 14.3080200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82554, 'Rocca San Felice', 'Rocca San Felice', 'Rocca San Felice', 40.9501400, 15.1665600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82555, 'Rocca San Casciano', 'Rocca San Casciano', 'Rocca San Casciano', 44.0587100, 11.8427400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82556, 'Roccaromana', 'Roccaromana', '', 41.2736000, 14.2219000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82557, 'Roccaraso', 'Roccaraso', 'Roccarasa,Roccaraso', 41.8487200, 14.0784600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82558, 'Roccarainola', 'Roccarainola', 'Roccarainola,rokkarainora,ロッカライーノラ', 40.9725000, 14.5428300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82559, 'Rocca Priora', 'Rocca Priora', 'Rocca Priora,ロッカ・プリオーラ', 41.7658500, 12.7657700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82560, 'Roccapiemonte', 'Roccapiemonte', 'Roccapiemonte', 40.7600900, 14.6908900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82561, 'Rocca Pia', 'Rocca Pia', 'Rocca Pia', 41.9342900, 13.9772600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82562, 'Roccantica', 'Roccantica', 'Roccantica', 42.3207300, 12.6939800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82563, 'Roccanova', 'Roccanova', 'Roccanova', 40.2125000, 16.2042900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82564, 'San Rocco', 'San Rocco', 'Roccamontepiano', 42.2429400, 14.1289100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82565, 'Roccamonfina', 'Roccamonfina', 'Roccamonfina', 41.2868300, 13.9790500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82566, 'Rocca Massima', 'Rocca Massima', 'Rocca Massima,ロッカ・マッシマ', 41.6790700, 12.9211600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82567, 'Roccamandolfi', 'Roccamandolfi', '', 41.4958300, 14.3521700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82568, 'Roccalbegna', 'Roccalbegna', 'Roccalbegna', 42.7863000, 11.5078800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82569, 'Rocca Imperiale', 'Rocca Imperiale', 'Rocca Imperiale', 40.1101400, 16.5782200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82570, 'Roccagloriosa', 'Roccagloriosa', 'Roccagloriosa', 40.1062800, 15.4364200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82571, 'Roccagiovine', 'Roccagiovine', 'Rocca Giovane,Rocca Giòvane,Roccagiovine,rokkajovu~ine,ロッカジョーヴィネ', 42.0506900, 12.8992500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82572, 'Roccafranca', 'Roccafranca', 'Roccafranca', 45.4640500, 9.9126000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82573, 'Roccaforzata', 'Roccaforzata', 'Roccaforzata', 40.4370000, 17.3898600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82574, 'Roccaforte Mondovì', 'Roccaforte Mondovi', 'Roccaforte,Roccaforte Mondovi,Roccaforte Mondovì', 44.3172100, 7.7442600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82575, 'Roccaforte Ligure', 'Roccaforte Ligure', 'Roccaforte Ligure', 44.6778000, 9.0280000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82576, 'Rocca di Papa', 'Rocca di Papa', 'Rocca di Papa,ロッカ・ディ・パーパ', 41.7658000, 12.7018800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82577, 'Rocca di Mezzo', 'Rocca di Mezzo', 'Rocca di Mezzo', 42.2044100, 13.5184000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82578, 'Rocca di Cave', 'Rocca di Cave', 'Rocca di Cave,ロッカ・ディ・カーヴェ', 41.8458900, 12.9450900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82579, 'Rocca di Cambio', 'Rocca di Cambio', 'Rocca di Cambio', 42.2375500, 13.4890600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82580, 'Rocca di Botte', 'Rocca di Botte', 'Rocca di Botte', 42.0310200, 13.0718500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82581, 'Roccadaspide', 'Roccadaspide', 'Roccadaspide', 40.4233300, 15.1911800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82582, 'Rocca d''Arce', 'Rocca d''Arce', '', 41.5871200, 13.5851100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82583, 'Roccacasale', 'Roccacasale', 'Roccacasale', 42.1224900, 13.8875800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82584, 'Rocca Canavese', 'Rocca Canavese', 'Rocca Canavese,ロッカ・カナヴェーゼ', 45.3087000, 7.5787500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82585, 'Roccabianca', 'Roccabianca', 'Roccabianca', 45.0077200, 10.2182400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82586, 'Robilante', 'Robilante', 'Robilante', 44.2928800, 7.5136700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82587, 'Robecco sul Naviglio', 'Robecco sul Naviglio', 'Robecco,Robecco sul Naviglio,ロベッコ・スル・ナヴィーリオ', 45.4366200, 8.8857300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82588, 'Robecco d''Oglio', 'Robecco d''Oglio', 'Robecco,Robecco d''Oglio', 45.2585100, 10.0771800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82589, 'Robecchetto Con Induno', 'Robecchetto Con Induno', 'Robecchetto con Induno,ロベッケット・コン・インドゥーノ', 45.5284800, 8.7706800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82590, 'Robbio', 'Robbio', 'Robbio', 45.2890100, 8.5928900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82591, 'Robbiate', 'Robbiate', '', 45.6882900, 9.4371200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82592, 'Robassomero', 'Robassomero', 'Robassome,Robassomero,Robassomé,robassomero,ロバッソメーロ', 45.1984100, 7.5675400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82593, 'Roasio', 'Roasio', 'Roasio', 45.6045700, 8.2848200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82594, 'Roana', 'Roana', 'Roana', 45.8769600, 11.4527400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82595, 'Ro', 'Ro', 'Ro,Ro Ferrara,ro,ロ', 44.9469500, 11.7600600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82596, 'Rivolta d''Adda', 'Rivolta d''Adda', 'Rivolta,Rivolta d''Ada,Rivolta d''Adda,Риволта д''Ада', 45.4696200, 9.5125100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82597, 'Rivoli', 'Rivoli', 'Rivoli,Rivoli Torinese,rivu~ori,Риволи,リーヴォリ', 45.0707300, 7.5146500, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82598, 'Rivodutri', 'Rivodutri', 'Rivodutri', 42.5168400, 12.8559500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82599, 'Rivignano', 'Rivignano', 'Rivignan,Rivignano', 45.8757500, 13.0419000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82600, 'Rivergaro', 'Rivergaro', 'Rivergaro', 44.9150000, 9.6044300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82601, 'Rivello', 'Rivello', 'Rivello', 40.0782100, 15.7579800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82602, 'Rive d''Arcano', 'Rive d''Arcano', 'Rive d''Arcano,Rive d’Arcano,Rivis d''Arcjan', 46.1272200, 13.0322200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82603, 'Rive', 'Rive', 'Rive', 45.2136400, 8.4170100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82604, 'Rivarolo Mantovano', 'Rivarolo Mantovano', 'Rivarolo Mantovano', 45.0727200, 10.4371300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82605, 'Rivarolo del Re', 'Rivarolo del Re', 'Rivarolo del Re,Rivarolo del Re ed Uniti', 45.0311600, 10.4725300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82606, 'Rivarolo Canavese', 'Rivarolo Canavese', 'Rivareul,Rivarolo Canavese,リヴァローロ・カナヴェーゼ', 45.3282900, 7.7211000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82607, 'Rivara', 'Rivara', 'Rivara,rivu~ara,リヴァーラ', 45.3304200, 7.6490000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82608, 'Riva Presso Chieri', 'Riva Presso Chieri', 'Riva,Riva di Chieri,Riva presso Chieri,リーヴァ・プレッソ・キエーリ', 44.9833800, 7.8731300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82609, 'Rivanazzano', 'Rivanazzano', 'Rivanazzano,Rivanazzano Terme', 44.9290800, 9.0136800, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82610, 'Rivamonte Agordino', 'Rivamonte Agordino', '', 46.2522600, 12.0230300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82611, 'Rivalta di Torino', 'Rivalta di Torino', 'Arvauta,Arvàuta,Rivalta di Torino,リヴァルタ・ディ・トリーノ', 45.0326800, 7.5204200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82612, 'Riva Ligure', 'Riva Ligure', 'Riva Ligure', 43.8388300, 7.8793500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82613, 'Rivalba', 'Rivalba', 'Rivalba,rivu~aruba,リヴァルバ', 45.1166900, 7.8881100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82614, 'Riva del Garda', 'Riva del Garda', 'Riva,Riva del Garda,Riva sul Garda,リーヴァ・デル・ガルダ', 45.8857700, 10.8411700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82615, 'Ripi', 'Ripi', 'Ripi', 41.6136600, 13.4240000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82616, 'Ripe San Ginesio', 'Ripe San Ginesio', 'Ripe', 43.1420200, 13.3672400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82617, 'Ripe', 'Ripe', 'Ripe,ripe,リーペ', 43.6690600, 13.1058600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82618, 'Ripatransone', 'Ripatransone', '', 43.0001500, 13.7620300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82619, 'Ripa Teatina', 'Ripa Teatina', 'Ripa Teatina', 42.3660300, 14.2444100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82620, 'Riparbella', 'Riparbella', 'Riparbella', 43.3641700, 10.5979900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82621, 'Ripalta Nuova', 'Ripalta Nuova', 'Ripalta,Ripalta Cremasca', 45.3320300, 9.6924400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82622, 'Ripalimosani', 'Ripalimosani', 'Ripalimosano', 41.6106400, 14.6630600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82623, 'Ripacandida', 'Ripacandida', 'Ripacandida', 40.9125600, 15.7259700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82624, 'Ripabottoni', 'Ripabottoni', '', 41.6899600, 14.8086600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82625, 'Vignale Riotorto', 'Vignale Riotorto', '', 42.9799800, 10.6847100, 'IT', '2017-03-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82626, 'Rio Saliceto', 'Rio Saliceto', 'Rio Saliceto', 44.8114700, 10.8041400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82627, 'Rionero Sannitico', 'Rionero Sannitico', 'Rionero,Rionero Sannitico', 41.7121900, 14.1391700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82628, 'Rionero in Vulture', 'Rionero in Vulture', 'Arniuro in Vulture,Rionero in Vulture', 40.9232800, 15.6711000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82629, 'Rio Marina', 'Rio Marina', 'Rio Marina,リオ・マリーナ', 42.8139500, 10.4260000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82630, 'Riomaggiore', 'Riomaggiore', 'Rimazo,Rimazò,Riomaggiore,riomajjore,リオマッジョーレ', 44.0997900, 9.7386900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82631, 'Riolunato', 'Riolunato', 'Riolunato', 44.2310200, 10.6531000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82632, 'Riolo Terme', 'Riolo Terme', 'Riolo Terme,Riolo dei Bagni,リオーロ・テルメ', 44.2760900, 11.7272200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82633, 'Riofreddo', 'Riofreddo', 'Riofreddo,riofureddo,リオフレッド', 42.0587500, 12.9966100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82634, 'Rio di Pusteria', 'Rio di Pusteria', 'Muehlbach,Muehlbach im Pustertal,Muhlbach,Mühlbach,Mühlbach im Pustertal,Rio di Pusteria,リオ・ディ・プステリーア', 46.7965800, 11.6675400, 'IT', '2016-01-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82635, 'Rio nell''Elba', 'Rio nell''Elba', 'Rio nell''Elba,リオ・ネッレルバ', 42.8116900, 10.4008500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82636, 'Rimini', 'Rimini', 'Ariminum,RMI,Remin,Rimini,Rèmin,Rímini,rimini,rymyny,Римини,Ріміні,ريميني,リミニ', 44.0575500, 12.5652800, 'IT', '2014-08-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82637, 'Rimella', 'Rimella', 'Rimella', 45.9080700, 8.1822200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82638, 'Rimasco', 'Rimasco', 'Rimasco', 45.8602500, 8.0641200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82639, 'Rima', 'Rima', 'Rima,Rima San Giuseppe', 45.8854200, 7.9986400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82640, 'Rigolato', 'Rigolato', 'Rigolato,Rigulat', 46.5539300, 12.8461900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82641, 'Rignano sull''Arno', 'Rignano sull''Arno', 'Rignano', 43.7214500, 11.4518300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82642, 'Rignano Garganico', 'Rignano Garganico', 'Rignano Garganico', 41.6793400, 15.5883500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82643, 'Rignano Flaminio', 'Rignano Flaminio', 'Rignano Flaminio,リニャーノ・フラミーニオ', 42.2055000, 12.4806800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82644, 'Scena', 'Scena', 'Scena,Schenna,Schoenna,Schönna,shena,シェーナ', 46.6884000, 11.1885500, 'IT', '2016-10-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82645, 'Rieti', 'Rieti', 'QRT,Rieti,rieti,Риети,リエーティ', 42.4047600, 12.8573500, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82646, 'Riese Pio X', 'Riese Pio X', '', 45.7285800, 11.9180100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82647, 'Ricigliano', 'Ricigliano', 'Ricigliano', 40.6680300, 15.4779000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82648, 'Riccò del Golfo', 'Ricco del Golfo', 'Ricco del Golfo,Ricco del Golfo di Spezia,Riccò del Golfo,Riccò del Golfo di Spezia,Rico,Ricò', 44.1541000, 9.7641400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82649, 'Riccione', 'Riccione', 'Arzoe,Arzö,Riccione,Richchone,Richione,Richone,Ricʻone,li qiao nei,rytshwny,Ричионе,Ричоне,Риччоне,Ռիչոնե,ريتشوني,里乔内', 43.9994200, 12.6568900, 'IT', '2016-07-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82650, 'Riccia', 'Riccia', '', 41.4831400, 14.8318100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82651, 'Ribolla', 'Ribolla', '', 42.9708700, 11.0355500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82652, 'Riardo', 'Riardo', 'Riardo,Riardu,Riardum,Rijardo,li ya er duo,lialeudo,riarudo,Риардо,Ријардо,Ріардо,Ռիարդո,リアルド,里亚尔多,리아르도', 41.2619700, 14.1504500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82653, 'Riano', 'Riano', 'Riano,riano,リアーノ', 42.0934700, 12.5146200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82654, 'Riale', 'Riale', 'Cuvara,Riale', 44.4833300, 11.2333300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82655, 'Rho', 'Rho', 'Rho,Ro,ro,Ро,ロー', 45.5324500, 9.0402000, 'IT', '2015-08-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82656, 'Rhemes-Notre-Dame', 'Rhemes-Notre-Dame', 'Rheme Notre Dame,Rhemes-Notre-Dame,Rhême Notre Dame,Rhêmes-Notre-Dame', 45.5696500, 7.1187000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82657, 'Rezzoaglio', 'Rezzoaglio', 'Rezoaggi,Rezzoaglio', 44.5262500, 9.3882700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82658, 'Rezzo', 'Rezzo', 'Rezzo', 44.0210100, 7.8719900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82659, 'Rezzato', 'Rezzato', 'Rezzato', 45.5118200, 10.3173100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82660, 'Rezzago', 'Rezzago', 'Rezzago', 45.8667300, 9.2486300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82661, 'Revò', 'Revo', 'Rehva,Revo,Revodium,Revò,lei wo,revu~o,Рево,Рэва,Ռևո,レヴォ,雷沃', 46.3922600, 11.0580800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82662, 'Revine', 'Revine', 'Revine,Revine Lago,Rèvine', 45.9993500, 12.2556100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82663, 'Revigliasco', 'Revigliasco', '', 45.0158900, 7.7330600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82664, 'Revere', 'Revere', 'Revere', 45.0520700, 11.1305900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82665, 'Revello', 'Revello', 'Revel,Revello', 44.6545100, 7.3902600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82666, 'Retorbido', 'Retorbido', 'Retorbido', 44.9498000, 9.0368000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82667, 'Resiutta', 'Resiutta', 'Reseute,Resiutta', 46.3937100, 13.2179600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82668, 'Rescaldina', 'Rescaldina', 'Rescaldina,resukarudina,レスカルディーナ', 45.6200200, 8.9487800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82669, 'Resana', 'Resana', '', 45.6353500, 11.9547200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82670, 'Renazzo', 'Renazzo', '', 44.7652700, 11.2860500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82671, 'Remedello di Sopra', 'Remedello di Sopra', '', 45.2787300, 10.3710900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82672, 'Remanzacco', 'Remanzacco', 'Ramanzas,Remanzacco', 46.0853500, 13.3235800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82673, 'Reino', 'Reino', 'Reino', 41.2921900, 14.8234700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82674, 'Reggio nell''Emilia', 'Reggio nell''Emilia', 'Redzho-Ehmilija,Reggio,Reggio Emilia,Reggio nell''Emilia,ZRO,Реджо-Эмилия', 44.6982500, 10.6312500, 'IT', '2016-11-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82675, 'Reggiolo', 'Reggiolo', 'Reggiolo', 44.9182400, 10.8101600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82676, 'Reggello', 'Reggello', 'Reggello', 43.6796700, 11.5297600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82677, 'Refrontolo', 'Refrontolo', 'Refrontolo', 45.9230500, 12.2086500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82678, 'Recoaro Terme', 'Recoaro Terme', 'Recoaro,Recoaro Terme', 45.7037300, 11.2221600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82679, 'Recetto', 'Recetto', 'Recetto', 45.4596500, 8.4350300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82680, 'Recco', 'Recco', 'Recco,Reko,Реко', 44.3622700, 9.1435400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82681, 'Recanati', 'Recanati', 'Recanati,Rekanati,Реканати', 43.4038100, 13.5537900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82682, 'Recale', 'Recale', 'Recale', 41.0570200, 14.3027000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82683, 'Reano', 'Reano', 'Rean,Reano,reano,レアーノ', 45.0521700, 7.4277900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82684, 'Re', 'Re', 'Re,re,レ', 46.1314800, 8.5456900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82685, 'Raviscanina', 'Raviscanina', 'Raviscanina', 41.3709000, 14.2433500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82686, 'Raveo', 'Raveo', 'Raveo,Raviei', 46.4339200, 12.8716500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82687, 'Ravenna', 'Ravenna', 'RAN,Ravena,Ravenna,Ravenne,Rawenna,Rávena,la wen na,ravenna,ravu~en''na,rwwnh,Равена,Равенна,רוונה,रवेन्ना,ラヴェンナ,拉文納', 44.4134400, 12.2012100, 'IT', '2014-06-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82688, 'Ravello', 'Ravello', 'Ravello,Ravielle,ravelo,Равело', 40.6493200, 14.6116700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82689, 'Ravascletto', 'Ravascletto', 'Ravasclet,Ravascletto', 46.5250400, 12.9213800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82690, 'Ravarino', 'Ravarino', 'Ravarino', 44.7247500, 11.0958800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82691, 'Rauscedo-Domanins', 'Rauscedo-Domanins', '', 46.0408300, 12.8247200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82692, 'Rasura', 'Rasura', 'Rasura', 46.1005900, 9.5527400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82693, 'Rassina', 'Rassina', '', 43.6473700, 11.8363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82694, 'Rapone', 'Rapone', 'Rapone', 40.8471000, 15.4981800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82695, 'Rapolla', 'Rapolla', 'Rapolla', 40.9749900, 15.6720100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82696, 'Rapolano Terme', 'Rapolano Terme', 'Rapalana-Tehrmeh,Rapolan Terme,Rapolano,Rapolano Terme,Rapolano-Terme,Rapolanu Termi,Rapolanum,Rapołan Terme,la bo la nuo tai er mei,lapollanoteleume,rabwlanw tyrmy,rapwlanw trmh,Рапалана-Тэрмэ,Раполано Терме,Раполано-Терме,Ռապոլանո Տերմե,رابولانو تيرمي,راپولانو ترمه,ラポラーノ・テルメ,拉波拉诺泰尔梅,라폴라노테르메', 43.2949800, 11.6026400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82697, 'Rapino', 'Rapino', 'Rapino', 42.2093100, 14.1849300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82698, 'Rapallo', 'Rapallo', 'Rapallo,raparro,Рапалло,ラパッロ', 44.3496000, 9.2279600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82699, 'Rapagnano', 'Rapagnano', '', 43.1598500, 13.5887300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82700, 'Ranco', 'Ranco', 'Ranco', 45.7973300, 8.5710500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82701, 'Rancio Valcuvia', 'Rancio Valcuvia', 'Rancio Valcuvia', 45.9159400, 8.7715700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82702, 'Ramon', 'Ramon', '', 45.7138600, 11.8682800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82703, 'Ramiseto', 'Ramiseto', 'Ramiseto', 44.4128400, 10.2768900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82704, 'Raldon', 'Raldon', '', 45.3492100, 11.0378600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82705, 'Raiano', 'Raiano', 'Raiano,Rarano', 42.1015800, 13.8138600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82706, 'Radicondoli', 'Radicondoli', 'Radicondoli,Radicundulum,Radikondoli,Radzikandoli,la di kong duo li,ladikondolli,radikondori,Радзікандолі,Радикондоли,Радікондолі,Ռադիկոնդոլի,ラディコンドリ,拉迪孔多利,라디콘돌리', 43.2604700, 11.0458200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82707, 'Radicofani', 'Radicofani', 'Radicofanum,Radikofani,Radzikafani,la di ke fa ni,ladikopani,radikofani,Радзікафані,Радикофани,Радікофані,Ռադիկոֆանի,ラディコーファニ,拉迪科法尼,라디코파니', 42.8961800, 11.7683900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82708, 'Radda in Chianti', 'Radda in Chianti', 'Radda,Radda in Chianti,ラッダ・イン・キアンティ', 43.4854000, 11.3743700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82709, 'Racines', 'Racines', 'Rachines,Racines,Rasinae,Ratschings,la qi nei si,rachinesu,Рачинес,Ռաչինես,ラチーネス,拉奇内斯', 46.8666700, 11.3000000, 'IT', '2012-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82710, 'Racconigi', 'Racconigi', 'Racconigi,Racunis,rakkoniji,ラッコニージ', 44.7659800, 7.6789300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82711, 'Quistello', 'Quistello', 'Quistello', 45.0079400, 10.9837700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82712, 'Quinzano d''Oglio', 'Quinzano d''Oglio', 'Quizano', 45.3143000, 10.0078500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82713, 'Quinto Vicentino', 'Quinto Vicentino', 'Quinto Vicentino', 45.5753400, 11.6281500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82714, 'Quinto Vercellese', 'Quinto Vercellese', 'Quinto,Quinto Vercellese', 45.3792000, 8.3621000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82715, 'Quinto di Treviso', 'Quinto di Treviso', 'Quinto,Quinto di Trevisio,Quinto di Treviso', 45.6435100, 12.1650900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82716, 'Quingentole', 'Quingentole', '', 45.0380100, 11.0457500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82717, 'Quindici', 'Quindici', 'Quindici', 40.8649700, 14.6466300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82718, 'Quincinetto', 'Quincinetto', 'Quincinetto,Quinsne,Quinsné,kuinchinetto,クインチネット', 45.5615700, 7.8083400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82719, 'Quiliano', 'Quiliano', 'Cuggioen,Cuggiœn,Quiliano,kuiriano,クイリアーノ', 44.2921500, 8.4140600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82720, 'Quero', 'Quero', '', 45.9209400, 11.9315100, 'IT', '2016-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82721, 'Quercianella', 'Quercianella', 'Quercianella Sonnino', 43.4595900, 10.3675700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82722, 'Ripa-Pozzi-Querceta-Ponterosso', 'Ripa-Pozzi-Querceta-Ponterosso', '', 43.9780600, 10.2037200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82723, 'Quattro Castella', 'Quattro Castella', 'Quattro Castella', 44.6349600, 10.4742900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82724, 'Quattordio', 'Quattordio', 'Quatordi,Quattordio,Quatòrdi', 44.8987700, 8.4049500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82725, 'Quassolo', 'Quassolo', 'Quassolo,kuassoro,クアッソーロ', 45.5229400, 7.8330500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82726, 'Quasano', 'Quasano', 'Quasani,Quasano', 40.9672400, 16.5735400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82727, 'Quarto Inferiore', 'Quarto Inferiore', '', 44.5309000, 11.4167900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82728, 'Quarto d''Altino', 'Quarto d''Altino', 'Quarto d''Altino,Quarto d’Altino,クアルト・ダルティーノ', 45.5794400, 12.3733300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82729, 'Quartesana', 'Quartesana', 'Quartesana,Quartesana Balbo', 44.8049000, 11.7387300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82730, 'Quart', 'Quart', 'Chateau de Quart,Quart', 45.7409600, 7.4152000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82731, 'Quarrata', 'Quarrata', '', 43.8483700, 10.9788800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82732, 'Quarona', 'Quarona', 'Quarona', 45.7604400, 8.2674900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82733, 'Quarna Sopra', 'Quarna Sopra', 'Quarna Sopra', 45.8730700, 8.3735500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82734, 'Quargnento', 'Quargnento', 'Quargnent,Quargnento', 44.9456600, 8.4882100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82735, 'Quarata', 'Quarata', '', 43.4985900, 11.8274200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82736, 'Quarantoli', 'Quarantoli', '', 44.9195400, 11.1032400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82737, 'Qualiano', 'Qualiano', 'Qualiano,kuariano,クアリアーノ', 40.9189900, 14.1535200, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82738, 'Quagliuzzo', 'Quagliuzzo', 'Quagliuzzo,kuariuttsu~o,クアリウッツォ', 45.4265400, 7.7810100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82739, 'Quadri', 'Quadri', 'Quadri,kuadori,クアドリ', 41.9240200, 14.2876800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82740, 'Quadrelle', 'Quadrelle', '', 40.9485100, 14.6393400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82741, 'Putignano', 'Putignano', 'Putignano,Putin''jano,Путиньяно', 40.8510600, 17.1219000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82742, 'Putifigari', 'Putifigari', 'Putifigari', 40.5614500, 8.4606300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82743, 'Pusiano', 'Pusiano', 'Pasiano,Pusiano', 45.8147800, 9.2821700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82744, 'Puos d''Alpago', 'Puos d''Alpago', 'Puos,Puos d''Alpago', 46.1415400, 12.3617600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82745, 'Punta Marina', 'Punta Marina', '', 44.4427200, 12.2908900, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82746, 'Pumenengo', 'Pumenengo', 'Pumenengo', 45.4800200, 9.8677500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82747, 'Pulsano', 'Pulsano', 'Pulsano', 40.3810900, 17.3561200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82748, 'Pulfero', 'Pulfero', 'Pulfar,Pulfero', 46.1737600, 13.4836300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82749, 'Puianello', 'Puianello', '', 44.6263000, 10.5642000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82750, 'Puglianello', 'Puglianello', 'Puglianello', 41.2217900, 14.4502300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82751, 'Provvidenti', 'Provvidenti', '', 41.7179500, 14.8234900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82752, 'Prossedi', 'Prossedi', 'Prossedi,purossedi,プロッセーディ', 41.5167400, 13.2610000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82753, 'Prosecco-Contovello', 'Prosecco-Contovello', 'Prosecco,Prosek', 45.7080700, 13.7337600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82754, 'Propata', 'Propata', 'Propa,Propata,Propâ', 44.5648700, 9.1858700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82755, 'Procida', 'Procida', 'Proceta,Procida,ZJJ,purochida,プローチダ', 40.7563600, 14.0145700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82756, 'Proceno', 'Proceno', '', 42.7574500, 11.8290000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82757, 'Priverno', 'Priverno', 'Piperno,Priverno,purivu~eruno,プリヴェルノ', 41.4704700, 13.1786700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82758, 'Priola', 'Priola', 'Priola', 44.2447800, 8.0214900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82759, 'Prignano sulla Secchia', 'Prignano sulla Secchia', 'Prignano sulla Secchia', 44.4383600, 10.6919000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82760, 'Prignano Cilento', 'Prignano Cilento', 'Prignano Cilento', 40.3333500, 15.0673900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82761, 'Prezza', 'Prezza', 'Prezza', 42.0578900, 13.8359200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82762, 'Preturo', 'Preturo', 'Preturo', 42.3780800, 13.2963300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82763, 'Pretoro', 'Pretoro', 'Pretoro', 42.2192300, 14.1424800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82764, 'Pressana', 'Pressana', 'Pressana', 45.2825800, 11.4072400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82765, 'Presenzano', 'Presenzano', 'Presenzano', 41.3782300, 14.0916200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82766, 'Prè Saint Didier', 'Pre Saint Didier', 'Pre-Saint-Didier,Prè-Saint-Didier,Pré-Saint-Didier,San Desiderio Terme', 45.7641600, 6.9857900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82767, 'Preore', 'Preore', 'Preore,pureore,プレオーレ', 46.0466300, 10.7596900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82768, 'Premosello-Chiovenda', 'Premosello-Chiovenda', 'Premosello,Premosello-Chiovenda', 46.0038000, 8.3297300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82769, 'Premilcuore', 'Premilcuore', 'Premilcuore', 43.9808400, 11.7819300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82770, 'Premeno', 'Premeno', 'Premeno', 45.9781800, 8.5958700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82771, 'Premariacco', 'Premariacco', 'Premaria,Premariacco', 46.0614500, 13.3946100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82772, 'Premana', 'Premana', 'Praemana,Premana,Promana,pu lei ma na,puremana,Премана,Պրեմանա,プレマーナ,普雷马纳', 46.0524500, 9.4212900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82773, 'Preganziol', 'Preganziol', 'Preganziol', 45.6013900, 12.2372200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82774, 'Predosa', 'Predosa', 'Predosa', 44.7504900, 8.6556800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82775, 'Predore', 'Predore', 'Predore', 45.6808500, 10.0127100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82776, 'Predoi', 'Predoi', 'Prataus,Predoi,Predoj,Prehdoj,Prettau,pu lei duo yi,puredoi,Предои,Предой,Предої,Прэдой,Պրեդոի,プレドーイ,普雷多伊', 47.0403100, 12.1066300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82777, 'Predazzo', 'Predazzo', 'Predazzo,puredattsu~o,プレダッツォ', 46.3114000, 11.5996000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82778, 'Preci', 'Preci', 'Castrum Precis,Prechi,Prehchy,brytshy,peulechi,pu lei qi,purechi,Пречи,Пречі,Прэчы,Պրեչի,بريتشي,プレーチ,普雷奇,프레치', 42.8806900, 13.0374700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82779, 'Precenicco', 'Precenicco', 'Precenicco,Precenins', 45.7969400, 13.0755400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82780, 'Prazzo Superiore', 'Prazzo Superiore', 'Prazzo Superiore', 44.4829700, 7.0546800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82781, 'Pray', 'Pray', 'Pray,purai,プライ', 45.6750800, 8.2095100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82782, 'Pravisdomini', 'Pravisdomini', 'Pravisdomini', 45.8197200, 12.6947800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82783, 'Pratovecchio', 'Pratovecchio', 'Pratavekjo,Pratovecchio,Pratovecchio Stia,Pratovecio,Pratovekio,Pratovekk''o,Pratum Vetus,Pratuvecchiu,pu la tuo wei ji ao,puratovu~ekkio,Пратавекё,Пратовекио,Пратовеккьо,Պրատովեքիո,プラトヴェッキオ,普拉托韦基奥', 43.7868500, 11.7235300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82784, 'Prato Sesia', 'Prato Sesia', 'Prato Sesia', 45.6506700, 8.3729300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82785, 'Pratola Serra', 'Pratola Serra', 'Pratola,Pratola Serra', 40.9865500, 14.8514900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82786, 'Pratola Peligna', 'Pratola Peligna', 'Paatola Peligna,Paàtola Peligna,Pratola,Pratola Peligna', 42.0970100, 13.8746700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82787, 'Prato', 'Prato', 'Prato,Prato di Resia,Resia,Resie,Résia', 46.3736400, 13.3065900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82788, 'Prato Carnico', 'Prato Carnico', 'Prat,Prato,Prato Carnico', 46.5204900, 12.8088600, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82789, 'Prato Allo Stelvio', 'Prato Allo Stelvio', 'Prad am Stilfser Joch,Prad am Stilfserjoch,Prato,Prato allo Stelvio,プラート・アッロ・ステルヴィオ', 46.6190100, 10.5913600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82790, 'Prato', 'Prato', 'Prato,Pratu,Pre,Prè,bratw,pu la tuo,purato,Прато,براتو,プラート,普拉托', 43.8805000, 11.0969900, 'IT', '2016-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82791, 'Pratella', 'Pratella', 'Pratela,Pratella,Pratilla,peulatella,pu la tai la,puraterra,Пратела,Прателла,Պրատելլա,プラテッラ,普拉泰拉,프라텔라', 41.4057900, 14.1791300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82792, 'Prata Sannita Centro', 'Prata Sannita Centro', 'Prata Sannita', 41.4328200, 14.2027200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82793, 'Pratantico-Indicatore', 'Pratantico-Indicatore', '', 43.4807100, 11.8053100, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82794, 'Prata di Principato Ultra', 'Prata di Principato Ultra', 'Prata,Prata di Princhipato Ultra,Prata di Principato Ultra,Prata di Principato Ultra vald,Prata di Principatu Ultra,Prata-di-Princhipato-Ul''tra,peulatadipeulinchipatoulteula,pu la ta di pu lin qi pa tu er te la,Прата ди Принчипато Ултра,Прата-ди-Принчипато-Ультра,Прата-ді-Принчипато-Ультра,Պրատա դի Պրինչիպատո Ուլտրա,プラータ・ディ・プリンチパート・ウルトラ,普拉塔迪普林奇帕图尔特拉,프라타디프린치파토울트라', 40.9862600, 14.8380300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82795, 'Prata di Pordenone', 'Prata di Pordenone', 'Prata,Prata di Pordenone,Prate', 45.8944100, 12.5884300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82796, 'Prata d''Ansidonia', 'Prata d''Ansidonia', 'Prata d''Ansidonia', 42.2779300, 13.6083000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82797, 'Prata Camportaccio', 'Prata Camportaccio', 'Prada Campustazz,Prata,Prata Camportaccio,Prata Kamportacho,Prata-Kamportachcho,pu la ta kan bo er ta qiao,Прата Кампортачо,Прата-Кампортаччо,Պրատա Կամպորտաչո,プラータ・カンポルタッチョ,普拉塔坎波尔塔乔', 46.3071900, 9.3952400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82798, 'Prascorsano', 'Prascorsano', 'Prascorsano', 45.3672100, 7.6172700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82799, 'Prarolo', 'Prarolo', 'Prareul,Prarolo', 45.2814900, 8.4778400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82800, 'Pralungo', 'Pralungo', '', 45.5899900, 8.0397600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82801, 'Pralormo', 'Pralormo', 'Pralormo', 44.8597600, 7.9044000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82802, 'Prali', 'Prali', 'Praal,Prali,Prali Villa', 44.8894400, 7.0513100, 'IT', '2013-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82803, 'Pralboino', 'Pralboino', 'Pralboino', 45.2672000, 10.2183900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82804, 'Praiano', 'Praiano', 'Praiano,Prajano,Праяно', 40.6121300, 14.5246100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82805, 'Pradleves', 'Pradleves', 'Pradleves,Pradléves', 44.4178600, 7.2814600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82806, 'Pozzuolo del Friuli', 'Pozzuolo del Friuli', 'Pocui,Pozzuolo,Pozzuolo del Friuli,Pucui,Puçui', 45.9851700, 13.1972400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82807, 'Pozzuolo', 'Pozzuolo', 'Pozzuolo', 43.1216500, 11.9559900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82808, 'Pozzuoli', 'Pozzuoli', 'Pocuoli,Pouzzoles,Pozzuoli,Puteoli,Puzzuolo,pottsuori,Поцуоли,ポッツオリ,ポッツオーリ', 40.8439400, 14.0952000, 'IT', '2015-08-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82809, 'Pozzonovo', 'Pozzonovo', 'Pozzonovo,Pozzonuovo', 45.1962900, 11.7917100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82810, 'Pozzomaggiore', 'Pozzomaggiore', 'Pozzomaggiore', 40.3976700, 8.6593100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82811, 'Pozzolo Formigaro', 'Pozzolo Formigaro', 'Pozzolo Formigaro', 44.7992500, 8.7836400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82812, 'Pozzoleone', 'Pozzoleone', 'Pozzoleone', 45.6496500, 11.6709800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82813, 'Pozzolengo', 'Pozzolengo', 'Pozzolengo', 45.4051500, 10.6304000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82814, 'Pozzillo', 'Pozzillo', '', 41.2033700, 14.1953000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82815, 'Pozzilli', 'Pozzilli', 'Poczilli,Pozzilli', 41.5114200, 14.0625200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82816, 'Pozzaglio ed Uniti', 'Pozzaglio ed Uniti', 'Pozzaglio ed Uniti', 45.2002700, 10.0505700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82817, 'Pozzaglia Sabino', 'Pozzaglia Sabino', 'Pozzaglia Sabina', 42.1586300, 12.9642800, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82818, 'Pozza di Fassa', 'Pozza di Fassa', '', 46.4280600, 11.6871100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82819, 'Pozza', 'Pozza', '', 44.5264100, 10.8923400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82820, 'Povoletto', 'Povoletto', 'Paulet,Povoletto', 46.1156800, 13.2917100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82821, 'Poviglio', 'Poviglio', 'Poviglio', 44.8422700, 10.5393600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82822, 'Povegliano Veronese', 'Povegliano Veronese', 'Povegliano Veronese', 45.3473000, 10.8805600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82823, 'Potenza Picena', 'Potenza Picena', 'Potenza Picena', 43.3663500, 13.6224900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82824, 'Potenza', 'Potenza', 'Oppido Lucano,Potentia,Potenza,Putenza,QPO,potentsu~a,ポテンツァ', 40.6417500, 15.8079400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82825, 'Postua', 'Postua', 'Postua', 45.7135500, 8.2285300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82826, 'Postioma', 'Postioma', '', 45.7175300, 12.1521800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82827, 'Postiglione', 'Postiglione', 'Postiglione', 40.5590100, 15.2323600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82828, 'Postalesio', 'Postalesio', 'Postalesio', 46.1737900, 9.7765900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82829, 'Postal', 'Postal', 'Burgstall,Postal,posutaru,ポスタル', 46.6094900, 11.1931300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82830, 'Posta', 'Posta', '', 42.5256200, 13.0972300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82831, 'Posta Fibreno', 'Posta Fibreno', '', 41.6918900, 13.6801300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82832, 'Possagno', 'Possagno', 'Posan''o,Possagno,Посаньо', 45.8479500, 11.8846700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82833, 'Positano', 'Positano', 'Posidianum,Positano,Positanu,Pozitano,Pusitano,bo xi ta nuo,po si ta no,pojitano,positano,pwzytanw,Позитано,Позітано,Պոզիտանո,پوزیتانو,โปซีตาโน,პოზიტანო,ポジターノ,波西塔諾,포시타노', 40.6282900, 14.4842700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82834, 'Posina', 'Posina', 'Posina', 45.7910600, 11.2624400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82835, 'Posatora', 'Posatora', '', 43.5991700, 13.4898400, 'IT', '2012-02-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82836, 'Posada', 'Posada', 'Pasada,Pausada,Posada,Pozada,bo sa da,pozada,Позада,Պոզադա,ポザーダ,波萨达', 40.6320300, 9.7190400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82837, 'Portula', 'Portula', 'Portula', 45.6751200, 8.1724400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82838, 'Portovenere', 'Portovenere', 'Portivene,Portovenere,Pòrtivene,porutovu~enere,Портовенере,ポルトヴェーネレ', 44.0508300, 9.8343100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82839, 'Porto Valtravaglia', 'Porto Valtravaglia', 'Porto Valtravaglia', 45.9608800, 8.6810900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82840, 'Porto Torres', 'Porto Torres', 'Porto Torres,Porto-Torres,Порто-Торрес', 40.8337500, 8.4053100, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82841, 'Porto Tolle', 'Porto Tolle', 'Porto Tolle', 44.9496900, 12.3245300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82842, 'Porto Santo Stefano', 'Porto Santo Stefano', '', 42.4382500, 11.1154200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82843, 'Porto Sant''Elpidio', 'Porto Sant''Elpidio', 'Porto Sant''Elpidio,Porto Sant''Elpidio a Mare', 43.2529700, 13.7597000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82844, 'Porto San Giorgio', 'Porto San Giorgio', 'Porto San Giorgio', 43.1778400, 13.7941100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82845, 'Porto Recanati', 'Porto Recanati', 'Porto Recanati', 43.4329600, 13.6616500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82846, 'Porto Potenza Picena', 'Porto Potenza Picena', 'Porto Potenza Picena,Porto di Potenza Picena', 43.3575100, 13.6974600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82847, 'Portomaggiore', 'Portomaggiore', 'Portomaggiore,porutomajjore,ポルトマッジョーレ', 44.6976300, 11.8076000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82848, 'Portogruaro', 'Portogruaro', 'Portogruaro,Puart,porutoguruaro,ポルトグルアーロ', 45.7807100, 12.8405200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82849, 'Porto Garibaldi', 'Porto Garibaldi', '', 44.6812300, 12.2367800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82850, 'Porto Fuori', 'Porto Fuori', 'Porto Fuori,Santa Maria in Porto Fuori', 44.4055700, 12.2521800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82851, 'Portofino', 'Portofino', 'Portofin,Portofino,fei nuo gang,porutofino,Портофино,ポルトフィーノ,菲諾港', 44.3034900, 9.2094200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82852, 'Portoferraio', 'Portoferraio', 'Ferrajo,Port Ferraio,Portoferraio,porutoferraio,ポルトフェッラーイオ', 42.8123300, 10.3129700, 'IT', '2017-07-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82853, 'Porto Corsini', 'Porto Corsini', 'Porto Corsin', 44.4941000, 12.2787500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82854, 'Civitanova Marche', 'Civitanova Marche', 'Civitanova Marche,Porto Civitanova', 43.3049100, 13.7206800, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82855, 'Porto Ceresio', 'Porto Ceresio', 'Porto Ceresi,Porto Ceresio,Porto-Cherezio,Portus,Pòrto Ceresi,bo er tuo qie lei xiao,Порто-Черезио,Порто-Черезіо,Պորտո Չերեզիո,ポルト・チェレージオ,波尔托切雷肖', 45.9128500, 8.8968400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82856, 'Portocannone', 'Portocannone', 'Portkanuni,Portocannone', 41.9144100, 15.0084500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82857, 'Portobuffolè', 'Portobuffole', 'Portobuffole,Portobuffolè', 45.8566500, 12.5376100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82858, 'Porto Azzurro', 'Porto Azzurro', 'Porto Azzuro,Porto Azzurro,Porto Longone,ポルト・アッズッロ', 42.7675400, 10.3972300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82859, 'Portico di Romagna', 'Portico di Romagna', 'Portico,Portico di Romagna,Poruco', 44.0265700, 11.7813300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82860, 'Portico di Caserta', 'Portico di Caserta', 'Portico di Caserta', 41.0556200, 14.2802200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82861, 'Portici', 'Portici', 'Portichi,Portici,Puortece,bwrtysh,porutichi,Портичи,بورتيش,ポルティチ', 40.8156300, 14.3371600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82862, 'Porto Ercole', 'Porto Ercole', 'Port Ercole,Port''Ercole', 42.4017100, 11.2052300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82863, 'Portalbera', 'Portalbera', 'Portalbera', 45.0978900, 9.3177400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82864, 'Porretta Terme', 'Porretta Terme', 'Bagni della Porretta,Porretta Terme,Puratta', 44.1632500, 10.9743200, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82865, 'Porporano', 'Porporano', '', 44.7526600, 10.3505400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82866, 'Porpetto', 'Porpetto', 'Porpet,Porpetto', 45.8570000, 13.2170300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82867, 'Porotto-Cassama', 'Porotto-Cassama', '', 44.8500000, 11.5500000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82868, 'Pornassio', 'Pornassio', 'Pornasce,Pornassio', 44.0705300, 7.8695400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82869, 'Porlezza', 'Porlezza', 'Porlezza,Portus Laetitiae', 46.0371400, 9.1292100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82870, 'Pordenone', 'Pordenone', 'Pordenon,Pordenone,Portus Naonis,QAD,porudenone,Порденоне,ポルデノーネ', 45.9568900, 12.6605100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82871, 'Porcia', 'Porcia', 'Porcia,Purcie', 45.9630100, 12.6164200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82872, 'Porcellengo', 'Porcellengo', '', 45.7061300, 12.1422500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82873, 'Porcari', 'Porcari', 'Porcari', 43.8415200, 10.6163200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82874, 'Porano', 'Porano', '', 42.6809900, 12.1033100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82875, 'Poppi', 'Poppi', 'Poppi', 43.7212300, 11.7664200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82876, 'Popoli', 'Popoli', 'Popoli', 42.1686600, 13.8299700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82877, 'Ponzone', 'Ponzone', 'Ponzone', 44.5881400, 8.4593500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82878, 'Ponzano di Fermo', 'Ponzano di Fermo', '', 43.1039000, 13.6597900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82879, 'Ponza', 'Ponza', 'Ponza,ZJY,pontsu~a,pontsu~a dao,ポンツァ,ポンツァ島', 40.8954100, 12.9588900, 'IT', '2016-04-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82880, 'Pont-Saint-Martin', 'Pont-Saint-Martin', 'Pont-Saint-Martin,Ponte San Martino', 45.5953600, 7.7945100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82881, 'Pontremoli', 'Pontremoli', 'Pontremoli,pontoremori,ポントレーモリ', 44.3751500, 9.8788800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82882, 'Pontinvrea', 'Pontinvrea', 'O Ponte,Pontinvrea', 44.4420500, 8.4362300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82883, 'Pontinia', 'Pontinia', 'Borgo Pasubio,Pontinia,pontinia,ポンティーニア', 41.4109700, 13.0425900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82884, 'Pontida', 'Pontida', 'Pontida', 45.7312900, 9.5114100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82885, 'Ponticino', 'Ponticino', '', 43.4801200, 11.7162200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82886, 'Ponti', 'Ponti', 'Ponti', 44.6284700, 8.3646100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82887, 'Pontevico', 'Pontevico', 'Pons Vicus,Pontevico,Ponteviko,Puntic,Puntìc,bwntyfykw,peng tai wei ke,pontevu~iko,Понтевико,Понтевіко,Պոնտևիկո,بونتيفيكو,ポンテヴィーコ,蓬泰维科', 45.2731500, 10.0924800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82888, 'Lavena Ponte Tresa', 'Lavena Ponte Tresa', '', 45.9671000, 8.8572500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82889, 'Ponte Taro', 'Ponte Taro', 'Ponte Taro,Stradella', 44.8287200, 10.2103700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82890, 'Pontestura', 'Pontestura', 'Pont da Stura,Pontestura', 45.1424500, 8.3332400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82891, 'Ponte San Pietro', 'Ponte San Pietro', 'Ponte San Pietro', 45.7059600, 9.5905000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82892, 'Ponte San Nicolò', 'Ponte San Nicolo', 'Ponto San Nicolo', 45.3671800, 11.9234100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82893, 'Ponte Ronca', 'Ponte Ronca', '', 44.5016600, 11.1897300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82894, 'Pontenure', 'Pontenure', 'Pontenure', 44.9982100, 9.7913900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82895, 'Ponte Nossa', 'Ponte Nossa', 'Nossa,Ponte Nossa,Ponte di Nossa', 45.8661100, 9.8836400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82896, 'Ponte Nizza', 'Ponte Nizza', 'Ponte Nizza', 44.8518800, 9.0973900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82897, 'Ponte nelle Alpi', 'Ponte nell''Alpi', 'Ponte nelle Alpi', 46.1808300, 12.2833300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82898, 'Pontelongo', 'Pontelongo', 'Pontelongo', 45.2459000, 12.0258200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82899, 'Pontelatone', 'Pontelatone', 'Pons Latonae,Pontelatone,Puntilatuni,peng tai la tuo nei,pontellatone,ponteratone,Понтелатоне,Պոնտելատոնե,ポンテラトーネ,蓬泰拉托内,폰텔라토네', 41.1946000, 14.2481400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82900, 'Pontelandolfo', 'Pontelandolfo', 'Pontelandol''fo,Pontelandolfo,Понтеландольфо', 41.2923100, 14.6895600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82901, 'Ponte Lambro', 'Ponte Lambro', 'Ponte Lambro', 45.8253900, 9.2245500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82902, 'Ponte Gardena', 'Ponte Gardena', 'Ponte Gardena,Ponte all''Isarco,Ponte in Gardena,Ponte-Gardena,Ponteh-Gardehna,Sublavio,Waidbruch,Waidbruck,peng tai jia er de na,Понте-Гардена,Понтэ-Гардэна,Պոնտե Գարդենա,ポンテ・ガルデーナ,蓬泰加尔德纳', 46.5971200, 11.5308800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82903, 'Ponte Galeria-La Pisana', 'Ponte Galeria-La Pisana', 'Casale Ponte Galeria', 41.8463400, 12.3392500, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82904, 'Ponte di Piave', 'Ponte di Piave', 'Ponte di Piave', 45.7190400, 12.4618600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82905, 'Ponte di Legno', 'Ponte di Legno', 'Ponte di Legno,ponte di len''o,Понте ди Леньо,ポンテ・ディ・レーニョ', 46.2589600, 10.5104800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82906, 'Ponte di Barbarano', 'Ponte di Barbarano', '', 45.3920600, 11.5784700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82907, 'Pontedera', 'Pontedera', 'Pontedera', 43.6614100, 10.6306700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82908, 'Ponte dell''Olio', 'Ponte dell''Olio', 'Ponte d''Olio,Ponte d''Ólio,Ponte dell''Olio', 44.8676200, 9.6443300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82909, 'Ponte Arche', 'Ponte Arche', 'Arche', 46.0352600, 10.8732000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82910, 'Ponte della Venturina', 'Ponte della Venturina', 'Ponte Venturina,Ponte della Venturina', 44.1304200, 10.9911300, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82911, 'Pontedassio', 'Pontedassio', 'O Pontedasce,Pontedassio', 43.9383000, 8.0146400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82912, 'Pontecurone', 'Pontecurone', 'Pontecurone', 44.9588000, 8.9328900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82913, 'Pontecorvo', 'Pontecorvo', 'Ponte Corvo,Pontecorvo', 41.4586100, 13.6661800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82914, 'Pontecchio Polesine', 'Pontecchio Polesine', 'Pontecchio Polesine', 45.0202000, 11.8132100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82915, 'Pontecagnano', 'Pontecagnano', 'Pontekan''jano,Понтеканьяно', 40.6444800, 14.8762800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82916, 'Ponte Caffaro', 'Ponte Caffaro', 'Caffaro', 45.8207800, 10.5270700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82917, 'Ponte Buggianese', 'Ponte Buggianese', 'Ponte Buggianese', 43.8459900, 10.7478900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82918, 'Pontebba', 'Pontebba', 'Pontebba,Pontebe', 46.5054000, 13.3062200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82919, 'Ponte A Tressa', 'Ponte A Tressa', '', 43.2515800, 11.3951400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82920, 'Giovi-Ponte alla Chiassa', 'Giovi-Ponte alla Chiassa', '', 43.5263400, 11.8655800, 'IT', '2015-11-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82921, 'Grassina Ponte a Ema', 'Grassina Ponte a Ema', '', 43.7333300, 11.3000000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82922, 'Ponte A Elsa', 'Ponte A Elsa', 'Ponte Elsa,Ponte a Elsa', 43.6890700, 10.8928100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82923, 'Ponte', 'Ponte', 'Ponte', 41.2155400, 14.6982600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82924, 'Pont-Canavese', 'Pont-Canavese', 'Pont-Canavese,ponto=kanavu~eze,ポント＝カナヴェーゼ', 45.4213800, 7.6002400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82925, 'Pontassieve', 'Pontassieve', 'Pontass,Pontassieve', 43.7747700, 11.4310900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82926, 'Ponso', 'Ponso', 'Palsum,Ponso,Ponxo,peng suo,ponso,Понсо,Պոնսո,ポンソ,蓬索', 45.1823200, 11.5793300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82927, 'Ponsacco', 'Ponsacco', 'Ponsacco', 43.6230700, 10.6266100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82928, 'Ponna Superiore', 'Ponna Superiore', '', 45.9895700, 9.0940600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82929, 'Poncarale', 'Poncarale', 'Poncarale', 45.4608900, 10.1797600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82930, 'Pomponesco', 'Pomponesco', 'Pomponesco', 44.9311800, 10.5940200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82931, 'Pompiano', 'Pompiano', 'Pompiano', 45.4311600, 9.9891000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82932, 'Pompeiana', 'Pompeiana', 'Pompeiana,Pompejana', 43.8529700, 7.8883600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82933, 'Pompei', 'Pompei', 'Pompei,Pompeya,Valle di Pompei,Помпеи', 40.7457400, 14.4969800, 'IT', '2015-12-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82934, 'Pomigliano d''Arco', 'Pomigliano d''Arco', 'Pomigliano d''Arco,ポミリアーノ・ダルコ', 40.9097500, 14.3831600, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82935, 'Pomezia', 'Pomezia', 'Pomezia,QEZ,pometsu~ia,ポメーツィア', 41.6693100, 12.5012400, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82936, 'Pometo', 'Pometo', '', 44.9278800, 9.2734800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82937, 'Pombia', 'Pombia', 'Pombia', 45.6555000, 8.6284600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82938, 'Pomaro Monferrato', 'Pomaro Monferrato', 'Pomaro Monferrato', 45.0624600, 8.5960400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82939, 'Pomarico', 'Pomarico', 'Pomarico', 40.5280400, 16.5270800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82940, 'Pomaretto', 'Pomaretto', 'Pomaret,Pomaretto', 44.9559000, 7.1812800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82941, 'Pomarance', 'Pomarance', 'Pamarancheh,Pomarance,Pomaranche,Pomaranci,Pomarantse,Ripomarancium,bo ma lan qie,pomaranche,Πομαράντσε,Памаранчэ,Помаранче,Պոմարանչե,ポマランチェ,波马兰切', 43.2959200, 10.8722300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82942, 'Polvica', 'Polvica', '', 40.6948400, 14.6401900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82943, 'Polverigi', 'Polverigi', 'Polverigi,poruvu~eriji,ポルヴェリージ', 43.5287600, 13.3829400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82944, 'Polverara', 'Polverara', 'Polverara', 45.3094500, 11.9547400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82945, 'Ponte nelle Alpi-Polpet', 'Ponte nelle Alpi-Polpet', '', 46.1883300, 12.2783300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82946, 'Pollutri', 'Pollutri', 'Pollutri', 42.1378400, 14.5917200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82947, 'Pollone', 'Pollone', 'Pollone', 45.5797600, 8.0059200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82948, 'Pollica', 'Pollica', 'Pollica', 40.1907000, 15.0571600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82949, 'Pollenza', 'Pollenza', 'Pollenza', 43.2659500, 13.3478800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82950, 'Pollein', 'Pollein', 'Pollein', 45.7278000, 7.3514600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82951, 'Polla', 'Polla', 'Pola,Polla,bo la,polla,porra,Пола,Полла,Պոլլա,ポッラ,波拉,폴라', 40.5143300, 15.4971500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82952, 'Polino', 'Polino', 'Palina,Polino,Polinu,Pollinum,bo li nuo,bwlynw,pollino,porino,pwlynw,Паліна,Полино,Поліно,Պոլինո,بولينو,پولینو,ポリーノ,波利诺,폴리노', 42.5842300, 12.8443700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82953, 'Polinago', 'Polinago', 'Polinago', 44.3450200, 10.7259700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82954, 'Polignano a Mare', 'Polignano a Mare', 'Polignano,Polignano a Mare', 40.9922100, 17.2214900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82955, 'Policoro', 'Policoro', 'Policoro', 40.2128000, 16.6779500, 'IT', '2015-06-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82956, 'Policastro Bussentino', 'Policastro Bussentino', 'Policastro,Policastro Bussentino,Policastro del Golfo', 40.0751100, 15.5216500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82957, 'Poli', 'Poli', '', 41.8891300, 12.8903700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82958, 'Polesine Parmense', 'Polesine Parmense', 'Polesine Parmense', 45.0168200, 10.0901500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82959, 'Polesella', 'Polesella', 'Polesella', 44.9645700, 11.7488700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82960, 'Polcenigo', 'Polcenigo', 'Polcenigo,Pulcini', 46.0382200, 12.5032100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82961, 'Poirino', 'Poirino', 'Poirin,Poirino,poirino,ポイリーノ', 44.9204700, 7.8446500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82962, 'Poiano', 'Poiano', '', 45.4702900, 11.0187500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82963, 'Poiana Maggiore', 'Poiana Maggiore', 'Poiana', 45.2903900, 11.5025000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82964, 'Pogno', 'Pogno', 'Pogno', 45.7580600, 8.3855900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82965, 'Pognana Lario', 'Pognana Lario', 'Pognana,Pognana Lario', 45.8804400, 9.1576200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82966, 'Pogliano Milanese', 'Pogliano Milanese', 'Pogliano Milanese,ポリアーノ・ミラネーゼ', 45.5378600, 8.9940300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82967, 'Poggiridenti Alto', 'Poggiridenti Alto', 'Poggiridenti', 46.1748000, 9.9260500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82968, 'Poggio San Vicino', 'Poggio San Vicino', 'Poggio San Vicino', 43.3746600, 13.0796400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82969, 'Poggio Sannita', 'Poggio Sannita', 'Poggio Sannita', 41.7793900, 14.4148500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82970, 'Poggio San Lorenzo', 'Poggio San Lorenzo', 'Poggio Lorenzo,Poggio San Lorenzo,Póggio Lorenzo', 42.2517400, 12.8434300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82971, 'Poggio Rusco', 'Poggio Rusco', 'Poggio Rusco', 44.9669300, 11.1041900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82972, 'Poggio Renatico', 'Poggio Renatico', 'Poggio Renatico,Poggio Reratico,Póggio Rerático,ポッジョ・レナーティコ', 44.7658100, 11.4869500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82973, 'Villa Opicina', 'Villa Opicina', 'Opcine,Opicina,Opčine,Poggioreale del Carso,Villa Opicina', 45.6878000, 13.7886100, 'IT', '2015-08-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82974, 'Poggio Picenze', 'Poggio Picenze', 'Podium Picentiae,Podzha-Pichehnceh,Podzho Pichence,Podzho-Pichence,Poggio Picenze,Poggiu Picenzi,bo jiao pi qin ze,bwdjw bytshnzy,pojopichenche,Поджа-Пічэнцэ,Поджо Пиченце,Поджо-Пиченце,Поджо-Піченце,Պոջո Պիչենցե,بودجو بيتشنزي,ポッジョ・ピチェンツェ,波焦皮琴泽,포조피첸체', 42.3206100, 13.5403600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82975, 'Poggio Nativo', 'Poggio Nativo', 'Poggio Nativo', 42.2178300, 12.7969100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82976, 'Poggio Moiano', 'Poggio Moiano', 'Poggio Moiano', 42.2041100, 12.8813600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82977, 'Poggio Mirteto', 'Poggio Mirteto', 'Poggio Mirteto', 42.2676300, 12.6883700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82978, 'Poggiomarino', 'Poggiomarino', 'Poggiomarino,pojjomarino,ポッジョマリーノ', 40.8011400, 14.5406600, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82979, 'Battifolle-Ruscello-Poggiola', 'Battifolle-Ruscello-Poggiola', '', 43.4500000, 11.8000000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82980, 'Poggio Imperiale', 'Poggio Imperiale', 'Poggio Imperiale', 41.8250300, 15.3668000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82981, 'Poggiofiorito', 'Poggiofiorito', 'Poggiofiorito', 42.2541400, 14.3208200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82982, 'Poggiodomo', 'Poggiodomo', 'Poggiodomo', 42.7123700, 12.9325100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82983, 'Poggio Catino', 'Poggio Catino', 'Poggio Catino', 42.2942000, 12.6983800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82984, 'Poggio Bustone', 'Poggio Bustone', 'Poggio Bustone', 42.5033000, 12.8852400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82985, 'Poggio Berni', 'Poggio Berni', 'Poggio Berni', 44.0263900, 12.4094400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82986, 'Poggio A Caiano', 'Poggio A Caiano', 'Poggio a Caiano,ポッジョ・ア・カイアーノ', 43.8137800, 11.0518600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82987, 'Poggibonsi', 'Poggibonsi', 'Podzhibonsi,Poggibonsi,pojjibonshi,Поджибонси,ポッジボンシ', 43.4706400, 11.1480400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82988, 'Poggiardo', 'Poggiardo', 'Poggiardo', 40.0531500, 18.3781900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82989, 'Pofi', 'Pofi', 'Pofi', 41.5654200, 13.4146000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82990, 'Podenzano', 'Podenzano', 'Podenzano', 44.9548400, 9.6831500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82991, 'Podenzana', 'Podenzana', 'Podenzana,podentsu~ana,ポデンツァーナ', 44.2062500, 9.9419900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82992, 'Pocenia', 'Pocenia', 'Pocenia,Pucinie', 45.8357000, 13.1014500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82993, 'Ploaghe', 'Ploaghe', 'Ploaghe', 40.6706800, 8.7496200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82994, 'Plaus', 'Plaus', 'Plaus,purausu,プラウス', 46.6562300, 11.0417800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82995, 'Pizzone', 'Pizzone', 'Pizzone', 41.6733200, 14.0366600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82996, 'Pizzoli', 'Pizzoli', 'Pizzoli', 42.4360300, 13.2988600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82997, 'Pizzoferrato', 'Pizzoferrato', 'Pizzoferrato', 41.9224400, 14.2363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82998, 'Pizzighettone', 'Pizzighettone', 'Picigetone,Pizzighettone,Пицигетоне', 45.1869000, 9.7878100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(82999, 'Piuro', 'Piuro', 'Piuro,Plurs', 46.3297900, 9.4206400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83000, 'Piumazzo', 'Piumazzo', '', 44.5463100, 11.0672700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83001, 'Piubega', 'Piubega', 'Piubega', 45.2267700, 10.5319500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83002, 'Pitigliano', 'Pitigliano', '', 43.4500000, 11.9333300, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83003, 'Pitigliano', 'Pitigliano', 'Pitigliano', 42.6358200, 11.6746200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83004, 'Piteglio', 'Piteglio', 'Piteglio', 44.0279000, 10.7657100, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83005, 'Pistrino', 'Pistrino', 'Pistrino', 43.5096600, 12.1518100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83006, 'Pistoia', 'Pistoia', 'Pistoia,Pistoja,Pistojja,Pistola,Pistoria,Pistòja,pisutoia,Пистойя,ピストイア', 43.9306400, 10.9236500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83007, 'Pisticci', 'Pisticci', 'Pesticium,Pisticci', 40.3901700, 16.5591900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83008, 'Pisoniano', 'Pisoniano', 'Pisoniano,pizoniano,ピゾニアーノ', 41.9081600, 12.9579400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83009, 'Pisogne', 'Pisogne', 'Piscogne,Pisogne,pizonye,ピゾーニェ', 45.8077700, 10.1102300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83010, 'Pisignano', 'Pisignano', '', 40.3047000, 18.2715500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83011, 'Pisciotta', 'Pisciotta', 'Pisciotta', 40.1089000, 15.2345600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83012, 'Pisa', 'Pisa', 'PSA,Pisa,Pisae,Pise,Piza,Pizo,Písa,bi sa,byza,pisa,pyzh,Пиза,פיזה,بيزا,पीसा,ピサ,比萨', 43.7085300, 10.4036000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83013, 'Piozzano', 'Piozzano', 'Piozzano', 44.9253300, 9.4955900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83014, 'Piovene Rocchette', 'Piovene Rocchette', 'Piovene Rocchette,Piovene-Rocchette', 45.7560100, 11.4327300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83015, 'Piove di Sacco-Piovega', 'Piove di Sacco-Piovega', 'Piove di Sacco', 45.2966500, 12.0368300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83016, 'Piossasco', 'Piossasco', 'Piossasch,Piossasco', 44.9880200, 7.4601000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83017, 'Pioraco', 'Pioraco', 'Pioraco', 43.1807400, 12.9767600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83018, 'Piombino Dese', 'Piombino Dese', 'Piombino,Piombino Dese', 45.6096400, 11.9941600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83019, 'Piombino', 'Piombino', 'P''ombino,Piombino,pionbino,Пьомбино,ピオンビーノ', 42.9255400, 10.5258500, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83020, 'Pioltello', 'Pioltello', 'Pioltello,pioruterro,ピオルテッロ', 45.5014700, 9.3305300, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83021, 'Piode', 'Piode', 'Piode', 45.7705900, 8.0526500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83022, 'Piobesi Torinese', 'Piobesi Torinese', '', 44.7666700, 7.6166700, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83023, 'Piobesi d''Alba', 'Piobesi d''Alba', 'Piobesi d''Alba', 44.7344400, 7.9793700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83024, 'Piobbico', 'Piobbico', 'Piobbico', 43.5881900, 12.5096200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83025, 'Pinzolo', 'Pinzolo', 'Pinzolo,pintsu~oro,ピンツォーロ', 46.1597600, 10.7637600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83026, 'Pinzano al Tagliamento', 'Pinzano al Tagliamento', 'Pincan,Pinzano,Pinzano al Tagliamento', 46.1821600, 12.9443300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83027, 'Pino sulla Sponda del Lago Maggiore', 'Pino sulla Sponda del Lago Maggiore', 'Pin,Pina-sula-Sponda-dehl''-Laga-Madzhoreh,Pino sula Sponda del Lago Majore,Pino-sulla-Sponda-del''-Lago-Madzhore,pi nuo su la si peng da de la ge ma jiao lei,pynw swl aspwnda dy lagw mjwrh,Пино-сулла-Спонда-дель-Лаго-Маджоре,Піна-сула-Спонда-дэль-Лага-Маджорэ,Піно-сулла-Спонда-дель-Лаго-Маджоре,Պինո սուլա Սպոնդա դել Լագո Մաջորե,پینو سول اسپوندا دی لاگو مجوره,ピーノ・スッラ・スポンダ・デル・ラーゴ・マッジョーレ,皮诺苏拉斯蓬达德拉戈马焦雷', 46.1007800, 8.7387300, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83028, 'Pinocchio di Ancona', 'Pinocchio di Ancona', 'Pinocchio,Pinocchio di Ancona,Pinokkio-di-Ankona,Пиноккио-ди-Анкона', 43.5898600, 13.4941300, 'IT', '2012-02-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83029, 'Pineto', 'Pineto', 'Pineto', 42.6087900, 14.0663900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83030, 'Pinerolo', 'Pinerolo', 'Penarol,Peñarol,Pignerol,Pinareul,Pinerolo,pineroro,Пинероло,ピネローロ', 44.8853400, 7.3313500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83031, 'Pincara', 'Pincara', 'Pincara', 45.0006400, 11.6210100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83032, 'Pimonte', 'Pimonte', 'Locus qui apud Montes,Pimonte,Pimunti,pi meng tai,pimonte,Пимонте,Пімонте,Պիմոնտե,ピモンテ,皮蒙泰,피몬테', 40.6736100, 14.5098400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83033, 'Pila', 'Pila', '', 43.0532900, 12.3285700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83034, 'Pigra', 'Pigra', 'Pigra', 45.9573500, 9.1264900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83035, 'Pignone', 'Pignone', 'Pignon,Pignone', 44.1778000, 9.7232700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83036, 'Pignola', 'Pignola', 'Pignola,Pignola di Basilicata,Pignola di Lucania', 40.5741200, 15.7829500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83037, 'Pignataro Maggiore', 'Pignataro Maggiore', 'Pignataro Maggiore', 41.1900600, 14.1697800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83038, 'Pignataro Interamna', 'Pignataro Interamna', 'Pignataro Interamna', 41.4392200, 13.7862100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83039, 'Pigna', 'Pigna', 'Pigna,Pin''ja,Pinia,pinya,Пинья,Пінья,ピーニャ', 43.9320500, 7.6612300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83040, 'Piglio', 'Piglio', 'Piglio', 41.8300600, 13.1333000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83041, 'Pieve Vergonte', 'Pieve Vergonte', 'Pieve Vergonte', 46.0129800, 8.2608200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83042, 'Pieve Torina', 'Pieve Torina', 'Pieve Torina', 43.0429900, 13.0476900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83043, 'Pieve Tesino', 'Pieve Tesino', 'Pieve Tesino,ピエーヴェ・テジーノ', 46.0682000, 11.6112200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83044, 'Pieve Santo Stefano', 'Pieve Santo Stefano', 'P''eve-Santo-Stefano,Peve-Santo-Stefano,Peveh-Santa-Stehfana,Pieve Santo Stefano,Pievi Santu Stefanu,Pjeve Santo Stefano,Plebs Sancti Stephani,pi ye wei sang tuo si tai fa nuo,pywh santw astfanw,Певэ-Санта-Стэфана,Пиеве Санто Стефано,Пьеве-Санто-Стефано,Пєве-Санто-Стефано,Пјеве Санто Стефано,Պիևե Սանտո Ստեֆանո,پیوه سانتو استفانو,ピエーヴェ・サント・ステーファノ,皮耶韦桑托斯泰法诺', 43.6714500, 12.0412400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83045, 'Pieve San Giacomo', 'Pieve San Giacomo', 'Pieve San Giacomo', 45.1320400, 10.1877500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83046, 'Pieve Porto Morone', 'Pieve Porto Morone', 'P''eve-Porto-Morone,Peve-Porto-Morone,Piev Porta Muron,Piev Porta Murón,Pieve Porto Morone,Plebs Portus Moroni,byyfy bwrtw mwrwny,pi ye wei bo er tuo mo luo nei,Пьеве-Порто-Мороне,Пєве-Порто-Мороне,Պիևե Պորտո Մորոնե,بييفي بورتو موروني,ピエーヴェ・ポルト・モローネ,皮耶韦波尔托莫罗内', 45.1097900, 9.4401900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83047, 'Pievepelago', 'Pievepelago', 'Pievepelago', 44.2047500, 10.6166000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83048, 'Pieve Ligure', 'Pieve Ligure', 'A Ceive de Soei,A Ceive de Söi,Pieve Ligure', 44.3749400, 9.0941000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83049, 'Pieve Fosciana', 'Pieve Fosciana', 'Pieve Fosciana', 44.1306700, 10.4095200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83050, 'Pieve d''Olmi', 'Pieve d''Olmi', 'Pieve d''Olmi', 45.0895700, 10.1236800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83051, 'Pieve di Teco', 'Pieve di Teco', 'Pieve di Teco', 44.0470600, 7.9156400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83052, 'Pieve di Soligo', 'Pieve di Soligo', 'Pieve di Soligo', 45.8983600, 12.1712800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83053, 'Pieve di Cento', 'Pieve di Cento', 'Pieve di Cento', 44.7129300, 11.3092200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83054, 'Pieve di Cadore', 'Pieve di Cadore', 'Piava di Cadore,Piave di Cadore,Pieve di Cadore', 46.4246600, 12.3641600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83055, 'Pieve del Cairo', 'Pieve del Cairo', 'Pieve del Cairo', 45.0492000, 8.8032200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83056, 'Pieve d''Alpago', 'Pieve d''Alpago', 'Pieve d''Alpago', 46.1665800, 12.3534400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83057, 'Pievebovigliana', 'Pievebovigliana', 'Pievebovigliana', 43.0628700, 13.0837500, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83058, 'Pieve Albignola', 'Pieve Albignola', 'Pieve Albignola', 45.1131600, 8.9599900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83059, 'Pieve', 'Pieve', '', 45.7727300, 10.7591300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83060, 'Pietrelcina', 'Pietrelcina', 'Pietrelcina', 41.1994200, 14.8441400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83061, 'Pietravairano', 'Pietravairano', 'Pietravairano', 41.3252200, 14.1659200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83062, 'Pietrastornina', 'Pietrastornina', 'Pietrastornina', 40.9953500, 14.7183300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83063, 'Pietrasanta', 'Pietrasanta', 'Pietrasanta,pietorasanta,Пиетрасанта,ピエトラサンタ', 43.9595200, 10.2278400, 'IT', '2015-07-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83064, 'Pietraporzio', 'Pietraporzio', 'Pietraporzio', 44.3435200, 7.0343300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83065, 'Pietrapertosa', 'Pietrapertosa', '', 40.5173100, 16.0624400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83066, 'Pietranico', 'Pietranico', 'P''etraniko,Petranicum,Petranika,Petraniko,Pietranico,Pietranicu,Pietraniko,byytranykw,pi ye te la ni ke,pieteulaniko,pietoraniko,pytranykw,Петраніка,Пиетранико,Пьетранико,Пєтраніко,Պիետրանիկո,بييترانيكو,پیترانیکو,ピエトラーニコ,皮耶特拉尼科,피에트라니코', 42.2756500, 13.9107700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83067, 'Pietramurata', 'Pietramurata', '', 46.0203300, 10.9431600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83068, 'Pietramontecorvino', 'Pietramontecorvino', '', 41.5422800, 15.1289400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83069, 'Pietramelara', 'Pietramelara', 'Pietramelara', 41.2708600, 14.1871100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83070, 'Pietralunga', 'Pietralunga', 'Pietralunga', 43.4360900, 12.4292100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83071, 'Pietra Ligure', 'Pietra Ligure', 'A Pria,A Prïa,Pietra Ligure', 44.1492000, 8.2820600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83072, 'Pietra la Croce', 'Pietra la Croce', '', 43.6022400, 13.5388700, 'IT', '2012-02-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83073, 'Pietragalla', 'Pietragalla', 'Pietragalla', 40.7457200, 15.8739800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83074, 'Pietraferrazzana', 'Pietraferrazzana', 'Pietraferrazzana', 41.9694300, 14.3745100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83075, 'Pietra de'' Giorgi', 'Pietra de'' Giorgi', 'Pietra de'' Giorgi,Pietra de''Giorgi,Pietra dei Giorgi', 45.0213600, 9.2303600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83076, 'Pietradefusi', 'Pietradefusi', 'Pietradefusi', 41.0431600, 14.8841500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83077, 'Pietracuta', 'Pietracuta', '', 43.9540000, 12.3713800, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83078, 'Pietracupa', 'Pietracupa', 'Pietracupa', 41.6825300, 14.5193300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83079, 'Pietracatella', 'Pietracatella', 'Pietracatella', 41.5806400, 14.8729800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83080, 'Pietracamela', 'Pietracamela', 'Pietracamela', 42.5234400, 13.5543100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83081, 'Pietrabruna', 'Pietrabruna', 'Pietrabruna,Prebuna', 43.8892700, 7.9031900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83082, 'Pietrabbondante', 'Pietrabbondante', 'Pietrabbondante', 41.7452700, 14.3848000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83083, 'Pieris', 'Pieris', '', 45.8124300, 13.4491700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83084, 'Pienza', 'Pienza', 'P''enca,Penca,Pienca,Pientia,Pienza,Pijenca,pi en zha,pi xen sa,piencha,pientsu~a,pyntza,pyynzh,Пиенца,Пијенца,Пьенца,Пєнца,פיינצה,پینتزا,ปีเอนซา,პიენცა,ピエンツァ,皮恩扎,피엔차', 43.0787300, 11.6767100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83085, 'Piegaro', 'Piegaro', 'P''egaro,Pegaro,Piegaro,Piegaru,Plagarium,byyjarw,pi ye jia luo,piegalo,piegaro,Пиегаро,Пьегаро,Пєгаро,Պիեգարո,بييجارو,ピエガーロ,皮耶加罗,피에가로', 42.9659600, 12.0840900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83086, 'Piedimulera', 'Piedimulera', 'Piedimulera', 46.0240800, 8.2589700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83087, 'Piedimonte San Germano', 'Piedimonte San Germano', 'P''edimonte-San-Dzhermano,Pedemontium Sancti Germani,Pedimonte-San-Dzhermano,Pedimunti San Germanu,Piedimonte San Dzhermano,Piedimonte San Germano,Pyedimonte San Jermano,pi ye di meng tai sheng jie er ma nuo,piedimontesanjeleumano,Пиедимонте Сан Джермано,Пьедимонте-Сан-Джермано,Пєдімонте-Сан-Джермано,Պյեդիմոնտե Սան Ջերմանո,ピエディモンテ・サン・ジェルマーノ,皮耶迪蒙泰圣杰尔马诺,피에디몬테산제르마노', 41.4979600, 13.7501700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83088, 'Piedimonte', 'Piedimonte', 'Piedimonte Rivoli', 41.1888600, 13.8985600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83089, 'Piedicavallo', 'Piedicavallo', 'Pedcaval,Piedicavallo', 45.6898600, 7.9548200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83090, 'Pie'' del Sasso', 'Pie'' del Sasso', '', 42.9942900, 12.9988900, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83091, 'Pie'' del Colle', 'Pie'' del Colle', '', 43.0298400, 13.1753500, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83092, 'Piea', 'Piea', 'Piea', 45.0270600, 8.0714600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83093, 'Pico', 'Pico', 'Pico,piko,ピーコ', 41.4502500, 13.5589400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83094, 'Picinisco', 'Picinisco', 'Picinisco', 41.6456800, 13.8679100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83095, 'Picerno', 'Picerno', 'Picerno', 40.6397500, 15.6423200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83096, 'Picciano', 'Picciano', 'Picciano', 42.4752500, 13.9899000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83097, 'Piazzola sul Brenta', 'Piazzola sul Brenta', 'Piazzola,Piazzola sul Brenta', 45.5384500, 11.7843700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83098, 'Piazzatorre', 'Piazzatorre', 'Piazzatorre', 45.9927300, 9.6894200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83099, 'Piazza Brembana', 'Piazza Brembana', 'Piazza Brembana', 45.9476900, 9.6733000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83100, 'Piazza al Serchio-San Michele', 'Piazza al Serchio-San Michele', 'Piassa al Serchio,Piazza al Serchio', 44.1845500, 10.2968900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83101, 'Piazza', 'Piazza', '', 45.8770500, 11.1580900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83102, 'Piazza', 'Piazza', '', 45.5872500, 10.1552600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83103, 'Piazza', 'Piazza', '', 45.2158500, 11.1424400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83104, 'Piateda Centro', 'Piateda Centro', 'Piateda', 46.1596000, 9.9349500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83105, 'Piasco', 'Piasco', 'Piasco', 44.5610600, 7.4442000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83106, 'Piantedo', 'Piantedo', 'Piantedo', 46.1366300, 9.4277000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83107, 'Piansano', 'Piansano', 'Piansano', 42.5244900, 11.8297800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83108, 'Pianoro', 'Pianoro', 'Pianoro', 44.3889300, 11.3426200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83109, 'Pianola', 'Pianola', '', 42.3234100, 13.4039400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83110, 'Piano di Sorrento', 'Piano di Sorrento', 'Piano ''e Surriento,Piano di Sorrento,ピャーノ・ディ・ソッレント', 40.6280600, 14.4172900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83111, 'Piano di Follo', 'Piano di Follo', 'Follo,Folo,San Martino Durasoa', 44.1637500, 9.8618800, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83112, 'Piano-Molini d''Isola', 'Piano-Molini d''Isola', '', 44.8319400, 8.1807300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83113, 'Piano', 'Piano', '', 40.8205000, 14.7600500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83114, 'Pianillo', 'Pianillo', '', 40.6341600, 14.5492200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83115, 'Pianiga', 'Pianiga', 'Pianiga,pyaniga,ピャニーガ', 45.4570800, 12.0076200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83116, 'Piangipane', 'Piangipane', '', 44.4219800, 12.0906600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83117, 'Pianezze', 'Pianezze', 'Pianezze', 45.7414100, 11.6270000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83118, 'Pianezza', 'Pianezza', 'Pianessa,Pianezza,Pianëssa,pianettsu~a,ピアネッツァ', 45.1042000, 7.5500300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83119, 'Pianello Val Tidone', 'Pianello Val Tidone', 'Pianello Val Tidone', 44.9466600, 9.4051600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83120, 'Pianella', 'Pianella', 'Pianella', 42.3991800, 14.0478100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83121, 'Pian di Scò', 'Pian di Sco', 'P''jan-di-Sko,Pian de Sco,Pian di Sco,Pian di Scò,Pian di Sko,Pjan-di-Sko,Pjan-dzi-Sko,Planities ad Rescum,pi ya en di si ke ao,Пиан ди Ско,Пьян-ди-Ско,Пян-дзі-Ско,Пян-ді-Ско,Պիան դի Սկո,ピアーン・ディ・スコ,皮亚恩迪斯克奥', 43.6419500, 11.5452300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83122, 'Piandimeleto', 'Piandimeleto', 'Piandimeleto', 43.7232000, 12.4085500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83123, 'Piamborno', 'Piamborno', 'Piancogno', 45.9196900, 10.2252600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83124, 'Piancastagnaio', 'Piancastagnaio', 'Pian Castagnajo,Piancastagnaio,piankasutanyaio,ピアンカスタニャーイオ', 42.8506700, 11.6901400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83125, 'Pian Camuno', 'Pian Camuno', 'Pian Camuno,Pian d''Artogne', 45.8418600, 10.1418100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83126, 'Pianazzo', 'Pianazzo', '', 46.4281500, 9.3442000, 'IT', '2016-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83127, 'Piana Crixia', 'Piana Crixia', '', 44.4850400, 8.3080500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83128, 'Piana Battolla', 'Piana Battolla', 'Piana di Battolla', 44.1932200, 9.8534500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83129, 'Piaggine', 'Piaggine', 'Piaggine', 40.3449800, 15.3777700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83130, 'Piagge', 'Piagge', 'Piagge,Piaggie', 43.7338100, 12.9685100, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83131, 'Piadena', 'Piadena', '', 45.1285900, 10.3710100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83132, 'Piacenza d''Adige', 'Piacenza d''Adige', 'Piacenza d''Adige', 45.1274900, 11.5433300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83133, 'Piacenza', 'Piacenza', 'P''jachehnca,P''jachenca,Piacenza,Piaseinsa,Piasensa,Piasëinsa,Placencia,Placentia,Placência,Plaisance,Plasencia,QPZ,pi ya qin cha,piachentsu~a,pyachnza,П''ячэнца,Пьяченца,پیاچنزا,ピアチェンツァ,皮亚琴察', 45.0524200, 9.6934200, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83134, 'Lama Pezzoli', 'Lama Pezzoli', '', 45.0435700, 11.9094200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83135, 'Pezze di Greco', 'Pezze di Greco', '', 40.8100400, 17.4133300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83136, 'Pezzana', 'Pezzana', 'Pezzana', 45.2615200, 8.4839600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83137, 'Peveragno', 'Peveragno', 'Peveragno', 44.3206000, 7.6185900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83138, 'Pettorazza Grimani', 'Pettorazza Grimani', 'Pettorazza,Pettorazza Grimani', 45.1358500, 11.9877900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83139, 'Pettorano sul Gizio', 'Pettorano sul Gizio', 'Pettorano sul Gizio', 41.9732600, 13.9600100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83140, 'Pettoranello del Molise', 'Pettoranello del Molise', 'Pettoranello del Molise', 41.5733100, 14.2783900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83141, 'Pettinengo', 'Pettinengo', 'Pettinengo', 45.6130600, 8.1042200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83142, 'Petruro Irpino', 'Petruro Irpino', '', 41.0319200, 14.7975400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83143, 'Petritoli', 'Petritoli', '', 43.0680900, 13.6638500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83144, 'Petriolo', 'Petriolo', 'Petriolo', 43.2214100, 13.4617300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83145, 'Petrignano', 'Petrignano', 'Petrignano', 43.1026900, 12.5323900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83146, 'Petriano', 'Petriano', 'Petriano', 43.7793500, 12.7321400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83147, 'Petrella Tifernina', 'Petrella Tifernina', 'Petrella Tifernina', 41.6913500, 14.6975100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83148, 'Petrella Salto', 'Petrella Salto', 'Petrella Salto', 42.2940500, 13.0679400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83149, 'Petina', 'Petina', 'Petina', 40.5321100, 15.3734600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83150, 'Petacciato', 'Petacciato', 'Petacciato', 42.0082700, 14.8602600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83151, 'Pessione', 'Pessione', 'Pessione,Пессионе', 44.9650400, 7.8411500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83152, 'Pessinetto', 'Pessinetto', 'Pessinetto', 45.2867500, 7.4153100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83153, 'Pessina Cremonese', 'Pessina Cremonese', 'Pessina Cremonese', 45.1850500, 10.2481500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83154, 'Pescosolido', 'Pescosolido', 'Pescosolido', 41.7486400, 13.6569000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83155, 'Pescosansonesco Nuovo', 'Pescosansonesco Nuovo', 'Pescosansonesco', 42.2552400, 13.8848000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83156, 'Pesco Sannita', 'Pesco Sannita', 'Pesco Sannita,Pescolamazza', 41.2327300, 14.8112200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83157, 'Pescorocchiano', 'Pescorocchiano', 'Pescorocchiano', 42.2062300, 13.1471500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83158, 'Pescopennataro', 'Pescopennataro', 'Pescopennataro', 41.8777700, 14.2939800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83159, 'Pescopagano', 'Pescopagano', 'Pescopagano', 40.8349400, 15.3994600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83160, 'Pescolanciano', 'Pescolanciano', 'Pescolanciano', 41.6797200, 14.3365800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83161, 'Pescocostanzo', 'Pescocostanzo', 'Pescocostanzo', 41.8872200, 14.0661400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83162, 'Pescina', 'Pescina', 'Pescina', 42.0235100, 13.6511600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83163, 'Pescia Romana', 'Pescia Romana', '', 42.3996300, 11.4965100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83164, 'Pescia', 'Pescia', 'Pescia,Pesha,Pesia,pesha,Πέσια,Пеша,ペーシャ', 43.8871000, 10.6884900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83165, 'Peschiera del Garda', 'Peschiera del Garda', 'Peschiera,Peschiera del Garda,Peschiera sul Lago di Garda,Pesciera,ペスキエーラ・デル・ガルダ', 45.4391200, 10.6861400, 'IT', '2015-10-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83166, 'Bettola-Zeloforomagno', 'Bettola-Zeloforomagno', '', 45.4308000, 9.3087000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83167, 'Peschici', 'Peschici', 'Peschici', 41.9452100, 16.0161200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83168, 'Pesche', 'Pesche', 'Pesche', 41.6055200, 14.2762000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83169, 'Pescasseroli', 'Pescasseroli', 'Pescasseroli', 41.8034300, 13.7870700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83170, 'Pescarolo', 'Pescarolo', 'Pescarolo ed Uniti', 45.1938700, 10.1864700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83171, 'Pescara', 'Pescara', 'PSR,Pescara,Peskara,byskara,pesukara,Пескара,بيسكارا,ペスカーラ', 42.4584000, 14.2028300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83172, 'Pescantina', 'Pescantina', 'Pescantina', 45.4854800, 10.8679600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83173, 'Pescaglia', 'Pescaglia', 'Pescaglia', 43.9651700, 10.4129200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83174, 'Pesaro', 'Pesaro', 'Pesaro,Pesaru,Pezaro,Pisaurum,Pèsaru,pezaro,Пезаро,ペーザロ', 43.9092100, 12.9164000, 'IT', '2015-09-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83175, 'Perugia', 'Perugia', 'PEG,Perosa,Perouse,Perudzha,Perugia,Perusa,Perusia,Pérouse,byrwdja,pei lu jia,peruja,prwg''h,Перуджа,Перуђа,פרוג''ה,بيرودجا,ペルージャ,佩鲁贾', 43.1122000, 12.3887800, 'IT', '2016-04-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83176, 'Pertosa', 'Pertosa', 'Pertosa', 40.5434600, 15.4500900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83177, 'Pertengo', 'Pertengo', 'Pertengo', 45.2360600, 8.4165100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83178, 'Perrero', 'Perrero', '', 44.9384900, 7.1126300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83179, 'Perosa Argentina', 'Perosa Argentina', 'Peirosa,Perosa Argentina,ペローザ・アルジェンティーナ', 44.9590900, 7.1916700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83180, 'Pernumia', 'Pernumia', 'Parnumia,Parnùmia,Pernumia,Pernumija,Pernumium,pei er nu mi ya,perunumia,Пернумия,Пернумія,Պերնումիա,ペルヌーミア,佩尔努米亚', 45.2589900, 11.7872100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83181, 'Pernate', 'Pernate', '', 45.4595800, 8.6784500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83182, 'Perito', 'Perito', 'Perito', 40.2985400, 15.1474600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83183, 'Perinaldo', 'Perinaldo', 'Perinaldo,Preinaodo', 43.8668900, 7.6719400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83184, 'Pergola', 'Pergola', '', 43.5548500, 12.8363300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83185, 'Pergine Valsugana', 'Pergine Valsugana', 'Pergine,Pergine Valsugana,Perigine Valsugana,ペルジーネ・ヴァルスガーナ', 46.0643400, 11.2375800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83186, 'Pergine Valdarno', 'Pergine Valdarno', 'Pergine,Pergine Valdarno', 43.4702800, 11.6855200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83187, 'Perfugas', 'Perfugas', 'Perfugas', 40.8323100, 8.8835400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83188, 'Pereto', 'Pereto', '', 42.0582100, 13.1023100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83189, 'Perdifumo', 'Perdifumo', 'Perdifumo', 40.2669400, 15.0165200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83190, 'Percoto', 'Percoto', 'Percoto,Percotto', 45.9747100, 13.3230400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83191, 'Percile', 'Percile', 'Percile,peruchire,ペルチーレ', 42.0949700, 12.9104800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83192, 'Perca', 'Perca', 'Perca,Percha,Perka,Pircha,pei er ka,peruka,Перка,Պերկա,ペルカ,佩尔卡', 46.7934300, 11.9833900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83193, 'Perarolo di Cadore', 'Perarolo di Cadore', 'Perarolo,Perarolo di Cadore', 46.3938300, 12.3563600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83194, 'Perano', 'Perano', 'Perano', 42.1046000, 14.3958100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83195, 'Penne', 'Penne', 'Pene,Penne,Pinna,byny,pen''ne,peng nei,penne,Пене,Пенне,بيني,ペンネ,彭内,펜네', 42.4547400, 13.9275400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83196, 'Penna Sant''Andrea', 'Penna Sant''Andrea', 'Penna Sant''Andrea', 42.5940300, 13.7721500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83197, 'Penna San Giovanni', 'Penna San Giovanni', 'Penna San Giovanni', 43.0560800, 13.4253900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83198, 'Pennapiedimonte', 'Pennapiedimonte', 'Pennapiedimonte', 42.1556300, 14.1943200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83199, 'Penna in Teverina', 'Penna in Teverina', 'Penna in Teverina', 42.4934200, 12.3584500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83200, 'Pennadomo', 'Pennadomo', 'Pennadomo', 42.0039400, 14.3233800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83201, 'Pennabilli', 'Pennabilli', 'Penabili,Penabiłi,Pennabili,Pennabilli,Pennábili,Pinna Billorum,bynabyly,pen''nabirri,peng na bi li,Пенабілі,Пеннабилли,Пеннабіллі,بينابيلي,ペンナビッリ,彭纳比利', 43.8174600, 12.2670800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83202, 'Pellizzano', 'Pellizzano', 'Pellizzano,perrittsu~ano,ペッリッツァーノ', 46.3098000, 10.7579000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83203, 'Pellezzano', 'Pellezzano', 'Pellezzano', 40.7252100, 14.7574400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83204, 'Pellestrina', 'Pellestrina', 'Pellestrina', 45.2771600, 12.3023800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83205, 'Pellegrino Parmense', 'Pellegrino Parmense', 'Pellegrino Parmense', 44.7295000, 9.9324000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83206, 'Pella', 'Pella', 'Pella', 45.7972200, 8.3844400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83207, 'Pelago', 'Pelago', 'Pelago', 43.7725500, 11.5014800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83208, 'Pegolotte', 'Pegolotte', '', 45.1917800, 12.0379100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83209, 'Pegognaga', 'Pegognaga', 'Pegognaga', 44.9945600, 10.8596700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83210, 'Peglio', 'Peglio', '', 43.6964600, 12.4978500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83211, 'Pedesina', 'Pedesina', 'Pedesina', 46.0818900, 9.5494400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83212, 'Pederobba', 'Pederobba', 'Pederobba', 45.8756700, 11.9497700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83213, 'Pedavena', 'Pedavena', 'Pedavena,pedavu~ena,pei da wei na,Педавена,Պեդավենա,ペダヴェーナ,佩达韦纳', 46.0395100, 11.8831000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83214, 'Pedaso', 'Pedaso', 'Pedaso', 43.0983900, 13.8408300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83215, 'Pecorara', 'Pecorara', 'Pecorara', 44.8758200, 9.3838700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83216, 'Pecetto di Valenza', 'Pecetto di Valenza', 'Pecetto di Valenza', 44.9890400, 8.6699600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83217, 'Pecetto', 'Pecetto', '', 45.0176000, 7.7510700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83218, 'Peccioli', 'Peccioli', 'Peccioli', 43.5496300, 10.7172000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83219, 'Pavullo nel Frignano', 'Pavullo nel Frignano', 'Paullo nel Frignano,Pavullo,Pavullo nel Frignano,pavulo nel frinjano,Павуло нел Фриняно,パヴッロ・ネル・フリニャーノ', 44.3335200, 10.8354400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83220, 'Pavone del Mella', 'Pavone del Mella', 'Pavone,Pavone del Mella', 45.3014700, 10.2098400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83221, 'Pavone Canavese', 'Pavone Canavese', 'Pavon,Pavone Canavese,パヴォーネ・カナヴェーゼ', 45.4419300, 7.8529400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83222, 'Pavona', 'Pavona', 'La Pavona', 41.7262900, 12.6164200, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83223, 'Pavia', 'Pavia', 'Papia,Pavia,Pavie,Pavija,Pavio,Pavìa,Pavía,Pawia,Ticinum,pa wei ya,pavu~ia,Павия,パヴィア,帕維亞', 45.1920500, 9.1591700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83224, 'Pavarolo', 'Pavarolo', 'Pavareul,Pavarolo,pavu~aroro,パヴァローロ', 45.0666500, 7.8394300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83225, 'Paupisi', 'Paupisi', 'Paupisi,Popisi', 41.1966200, 14.6645700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83226, 'Paullo', 'Paullo', 'Paullo,paurro,パウッロ', 45.4183400, 9.4004200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83227, 'Paulilatino', 'Paulilatino', 'Paulilatino', 40.0847000, 8.7644900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83228, 'Paularo', 'Paularo', 'Paular,Paularo', 46.5310100, 13.1188600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83229, 'Pattada', 'Pattada', 'Pattada', 40.5806700, 9.1112900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83230, 'Patrica', 'Patrica', 'Patrica', 41.5908500, 13.2436300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83231, 'Patigno', 'Patigno', '', 44.3531600, 9.7629700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83232, 'Paternopoli', 'Paternopoli', 'Paternopoli', 40.9726800, 15.0324200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83233, 'Paterno', 'Paterno', 'Paterno,pateruno,パテルノ', 40.3750700, 15.7351000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83234, 'Pastrengo', 'Pastrengo', 'Pastrengo', 45.4958800, 10.7989700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83235, 'Pastena', 'Pastena', 'Pastena', 41.4684200, 13.4911100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83236, 'Passo di Treia', 'Passo di Treia', 'Passo di Treia,Passo di Treja', 43.2864700, 13.3324600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83237, 'Passo di Mirabella-Pianopantano', 'Passo di Mirabella-Pianopantano', '', 41.0546800, 15.0164900, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83238, 'Passirano', 'Passirano', 'Passirano', 45.5967300, 10.0698600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83239, 'Passignano sul Trasimeno', 'Passignano sul Trasimeno', 'Passignano,Passignano sul Trasimeno', 43.1904300, 12.1353500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83240, 'Passarella', 'Passarella', '', 45.5943600, 12.6053700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83241, 'Paspardo', 'Paspardo', 'Paspardo', 46.0322500, 10.3687900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83242, 'Pasiano', 'Pasiano', 'Pasiano di Pordenon', 45.8497200, 12.6272200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83243, 'Pasian di Prato', 'Pasian di Prato', 'Pasian di Prat,Pasian di Prato', 46.0466700, 13.1878000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83244, 'Parzanica', 'Parzanica', 'Parzanica', 45.7387300, 10.0351800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83245, 'Paruzzaro', 'Paruzzaro', 'Paruzzaro', 45.7481800, 8.5148600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83246, 'Parre', 'Parre', '', 45.8745900, 9.8908600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83247, 'Parrano', 'Parrano', 'Parrano', 42.8662400, 12.1102600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83248, 'Parona', 'Parona', 'Parona,Parona di Valpolicella', 45.4788200, 10.9441400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83249, 'Parona', 'Parona', 'Parona', 45.2816500, 8.7505500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83250, 'Parolise', 'Parolise', 'Parolise', 40.9304500, 14.8817200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83251, 'Parma', 'Parma', 'PMF,Parma,Parme,Perma,Pèrma,barma,parma,paruma,Парма,פארמה,بارما,پارما,パルマ', 44.7993500, 10.3261800, 'IT', '2017-02-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83252, 'Parella', 'Parella', 'Parela,Parella,parerra,パレッラ', 45.4301800, 7.7912800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83253, 'Parcines', 'Parcines', 'Parchines,Parchynes,Parcines,Partschins,pa er qi nei si,paruchinesu,Парчинес,Парчынес,Պարչինես,パルチーネス,帕尔奇内斯', 46.6842200, 11.0733700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83254, 'Paratico', 'Paratico', 'Paratico', 45.6587900, 9.9579200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83255, 'Parabita', 'Parabita', 'Parabita', 40.0513900, 18.1265100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83256, 'Parabiago', 'Parabiago', 'Parabiago,parabiago,パラビアーゴ', 45.5603400, 8.9454500, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83257, 'Papozze', 'Papozze', '', 44.9833300, 12.1666700, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83258, 'Paolisi', 'Paolisi', 'Paolisi', 41.0373100, 14.5791800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83259, 'Panzano in Chianti', 'Panzano in Chianti', 'Panzano,Panzano in Chianti', 43.5442200, 11.3143800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83260, 'Pantigliate', 'Pantigliate', 'Pantigliate,pantiriate,パンティリアーテ', 45.4352600, 9.3522000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83261, 'Pantalla', 'Pantalla', '', 42.8728700, 12.3986100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83262, 'Panni', 'Panni', 'Panni', 41.2208200, 15.2756000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83263, 'Pannarano', 'Pannarano', 'Pannarano', 41.0108200, 14.7029300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83264, 'Panicale', 'Panicale', 'Panicale', 43.0283000, 12.0999300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83265, 'Piazza di Pandola', 'Piazza di Pandola', '', 40.8074800, 14.7718000, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83266, 'Pandino', 'Pandino', 'Pandino', 45.4055900, 9.5521800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83267, 'Pancarana', 'Pancarana', 'Pancarana', 45.0752300, 9.0510900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83268, 'Pancalieri', 'Pancalieri', 'Pancale,Pancalerium,Pancalieri,Pancalé,Pankal''eri,Pankal''ery,Pankaleri,pan ka lie li,pankarieri,Панкальери,Панкальеры,Панкальєрі,Պանկալերի,パンカリエーリ,潘卡列里', 44.8334400, 7.5859200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83269, 'Pamparato', 'Pamparato', 'Pamparato', 44.2766600, 7.9143200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83270, 'Paluzza', 'Paluzza', 'Paluce,Paluzza', 46.5320200, 13.0158600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83271, 'Palù del Fersina', 'Palu del Fersina', 'Palu,Palu del Fersina,Palù,Palù del Fersina,パルー・デル・フェルシーナ', 46.1295100, 11.3508800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83272, 'Paludea', 'Paludea', 'Paladea,Paludea', 46.1995000, 12.9034400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83273, 'Palù', 'Palu', 'Palu,Palù', 45.3247300, 11.1563500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83274, 'Palosco', 'Palosco', 'Palosco', 45.5892800, 9.8364600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83275, 'Palomonte', 'Palomonte', 'Palomonte', 40.6625100, 15.2918600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83276, 'Palombaro', 'Palombaro', '', 42.1232300, 14.2298900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83277, 'Palombara Sabina', 'Palombara Sabina', 'Palombara Sabina,パロンバーラ・サビーナ', 42.0690900, 12.7668400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83278, 'Palombaio', 'Palombaio', 'Palombaio,Palombaro', 41.0703600, 16.6096200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83279, 'Palo del Colle', 'Palo del Colle', 'Palo del Colle,Palo-del''-Kolle,Пало-дель-Колле', 41.0556200, 16.7032100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83280, 'Palmiano', 'Palmiano', 'Palmiano', 42.8994600, 13.4593700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83281, 'Palmariggi', 'Palmariggi', 'Palmariggi', 40.1309900, 18.3786300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83282, 'Palmanova', 'Palmanova', 'Palmanov,Palmanova,Palme', 45.9054000, 13.3099800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83283, 'Palma Campania', 'Palma Campania', 'Palma Campania,パルマ・カンパーニア', 40.8660800, 14.5517000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83284, 'Pallerone', 'Pallerone', '', 44.2048500, 10.0027900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83285, 'Palazzolo sull''Oglio', 'Palazzolo sull''Oglio', 'Palazzolo,Palazzolo sull''Oglio', 45.5966500, 9.8868800, 'IT', '2015-07-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83286, 'Pallare', 'Pallare', 'Palere,Pallare,Palëre,parrare,パッラーレ', 44.3277000, 8.2786400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83287, 'Pallanzeno', 'Pallanzeno', 'Pallanzeno', 46.0420200, 8.2594900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83288, 'Palinuro', 'Palinuro', 'Palinuro,Палинуро', 40.0368100, 15.2881200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83289, 'Palidano', 'Palidano', '', 44.9720300, 10.7794300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83290, 'Paliano', 'Paliano', 'Paliano', 41.7797500, 13.0766100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83291, 'Palestro', 'Palestro', 'Palestro', 45.3030200, 8.5332000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83292, 'Palestrina', 'Palestrina', 'Palestrina,Praeneste,paresutorina,Палестрина,パレストリーナ', 41.8327400, 12.8817800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83293, 'Palena', 'Palena', 'Palena,Polena', 41.9835300, 14.1369600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83294, 'Palazzuolo sul Senio', 'Palazzuolo sul Senio', 'Palazzuolo,Palazzuolo di Romagna,Palazzuolo sul Senio', 44.1129800, 11.5427000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83295, 'Palazzo San Gervasio', 'Palazzo San Gervasio', 'Palazzo San Gervasio', 40.9315600, 15.9814900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83296, 'Palazzolo Vercellese', 'Palazzolo Vercellese', 'Palazzolo,Palazzolo Vercellese', 45.1855400, 8.2330200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83297, 'Palazzolo dello Stella', 'Palazzolo dello Stella', 'Palacul,Palazzolo,Palazzolo dello Stella', 45.7982300, 13.0877600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83298, 'Palazzo Canavese', 'Palazzo Canavese', 'Palass,Palazzo,Palazzo Canavese,パラッツォ・カナヴェーゼ', 45.4596200, 7.9777600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83299, 'Palazzo', 'Palazzo', 'Palazzo', 43.0970800, 12.5643600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83300, 'Palau', 'Palau', 'Palau,Palau  Sardegna,QPD,parau,パラウ', 41.1793600, 9.3819000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83301, 'Palata', 'Palata', 'Palata', 41.8879000, 14.7877800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83302, 'Palanzano', 'Palanzano', 'Palanzano', 44.4362900, 10.1940000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83303, 'Palaia', 'Palaia', 'Palaia,Palaia (Pisa)', 43.6056700, 10.7702000, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83304, 'Palagiano', 'Palagiano', 'Palagiano', 40.5776200, 17.0381200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83305, 'Palagianello', 'Palagianello', 'Palagianello', 40.6085100, 16.9780200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83306, 'Palagano', 'Palagano', 'Palagano', 44.3215200, 10.6466000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83307, 'Pago Veiano', 'Pago Veiano', 'Pago Veiano', 41.2424300, 14.8649700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83308, 'Pagnona', 'Pagnona', 'Pagnona', 46.0596900, 9.4027400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83309, 'Paglieta', 'Paglieta', 'Paglieta', 42.1613900, 14.5030600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83310, 'Paganico Sabino', 'Paganico Sabino', 'Civitella Paganico,Paganico Sabino,Pagánico Sabino', 42.1896300, 12.9968900, 'IT', '2012-03-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83311, 'Paganica-Tempera', 'Paganica-Tempera', '', 42.3571500, 13.4713800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83312, 'Pagani', 'Pagani', 'Pagani,pagani,パガーニ', 40.7419900, 14.6144800, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83313, 'Paese', 'Paese', 'Paese', 45.6741700, 12.1638900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83314, 'Paesana', 'Paesana', 'Paesana', 44.6833200, 7.2757100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83315, 'Padulle', 'Padulle', '', 44.6294500, 11.2773800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83316, 'Paduli', 'Paduli', 'Paduli', 41.1679300, 14.8868800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83317, 'Stazione di Padule', 'Stazione di Padule', '', 43.3076600, 12.6155700, 'IT', '2015-11-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83318, 'Padula', 'Padula', '', 40.3390100, 15.6563400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83319, 'Padru', 'Padru', 'Padra,Padru', 40.7661900, 9.5210000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83320, 'Padria', 'Padria', 'Padria', 40.3963500, 8.6299200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83321, 'Padova', 'Padova', 'Padoa,Padoue,Padova,Padovo,Padua,Paduja,Padwa,Patavium,Pàdua,Pádua,QPA,badwfa,pa duo wa,padoba,padovu~a,Падова,Падуа,Падуя,פאדובה,بادوفا,პადუა,パドヴァ,帕多瓦,파도바', 45.4079700, 11.8858600, 'IT', '2015-01-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83322, 'Padivarma', 'Padivarma', '', 44.1964800, 9.7675300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83323, 'Paderno Franciacorta', 'Paderno Franciacorta', 'Paderno Franciacorta,パデルノ・フランチャコルタ', 45.5868700, 10.0797500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83324, 'Paderno Dugnano', 'Paderno Dugnano', 'Paderno Dugnano,パデルノ・ドゥニャーノ', 45.5689900, 9.1648300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83325, 'Paderno d''Adda', 'Paderno d''Adda', 'Paderno d''Adda', 45.6787900, 9.4449100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83326, 'Paderno Ponchielli', 'Paderno Ponchielli', 'Paderno Ossolaro', 45.2379700, 9.9287600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83327, 'Paderna', 'Paderna', 'Paderna', 44.8214800, 8.8908800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83328, 'Padergnone', 'Padergnone', 'Padergnone,paderunyone,パデルニョーネ', 46.0598200, 10.9847800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83329, 'Padenghe sul Garda', 'Padenghe sul Garda', 'Padenghe,Padenghe sul Garda', 45.5078700, 10.5185700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83330, 'Paciano', 'Paciano', 'Paciano', 43.0228800, 12.0678800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83331, 'Pacentro', 'Pacentro', 'Pacentro,Pacentru,Pacentrum,Pachehntra,Pachentro,batshntrw,pa qin te luo,pachenteulo,pachentoro,Пачентро,Пачэнтра,Պաչենտրո,باتشنترو,パチェントロ,帕琴特罗,파첸트로', 42.0504300, 13.9915100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83332, 'Ozzero', 'Ozzero', 'Ozzero,ottsu~ero,オッツェロ', 45.3677500, 8.9244000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83333, 'Ozzano Monferrato', 'Ozzano Monferrato', 'Ozzano,Ozzano Monferrato', 45.1059200, 8.3723800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83334, 'Ozieri', 'Ozieri', 'Ozieri', 40.5863000, 9.0034000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83335, 'Ozegna', 'Ozegna', 'Ozegna,ozenya,オゼーニャ', 45.3480100, 7.7450300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83336, 'Oyace', 'Oyace', 'Oiasse,Oyace', 45.8511600, 7.3830000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83337, 'Ovodda', 'Ovodda', 'Ovodda', 40.0952500, 9.1610300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83338, 'Ovindoli', 'Ovindoli', 'Ovindoli', 42.1376500, 13.5160300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83339, 'Ovaro', 'Ovaro', 'Davar,Ovaro', 46.4840900, 12.8670400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83340, 'Ovada', 'Ovada', 'Ovada', 44.6372700, 8.6419600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83341, 'Oulx', 'Oulx', 'Ols,Ors,Oulx,Ulzia,Ulzio,urukusu,ウルクス', 45.0364100, 6.8337200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83342, 'Ottone', 'Ottone', 'Ottone', 44.6232500, 9.3326700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83343, 'Ottobiano', 'Ottobiano', 'Ottobiano', 45.1541800, 8.8319800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83344, 'Ottiglio', 'Ottiglio', 'Ottiglio', 45.0542600, 8.3398000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83345, 'Ottaviano', 'Ottaviano', '', 40.8519300, 14.4782600, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83346, 'Ottati', 'Ottati', 'Ottati', 40.4629100, 15.3152600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83347, 'Ottana', 'Ottana', 'Ottana', 40.2340200, 9.0445900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83348, 'Otricoli', 'Otricoli', 'Otricoli,Otriculum,Otrikoli,ao te li ke li,awtrykwly,oteulikolli,otorikori,Отриколи,Отриколі,Օտրիկոլի,أوتريكولي,オトリーコリ,奥特里科利,오트리콜리', 42.4207900, 12.4773700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83349, 'Otranto', 'Otranto', 'Derento,Derentò,Gorad Atranta,Hydruntum,Otrantas,Otrante,Otranto,Utrantu,ao te lang tuo,awtrantw,otoranto,Òtranto,Οτράντο,Горад Атранта,Отранто,Օտրանտո,أوترانتو,اوترانتو,اوٹرانٹو,オトラント,奧特朗托', 40.1478900, 18.4868200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83350, 'Ostuni', 'Ostuni', 'Ostuni,Остуни', 40.7291300, 17.5767500, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83351, 'Ostra Vetere', 'Ostra Vetere', 'Ostra,Ostra Vetere,Ostra Vetus,Ostra-Vetehreh,Ostra-Vetere,ao si te la wei tai lei,Остра Ветере,Остра-Ветере,Остра-Ветэрэ,Օստրա Վետերե,オストラ・ヴェーテレ,奥斯特拉韦泰雷', 43.6033600, 13.0615000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83352, 'Ostra', 'Ostra', 'Ostra,osutora,オストラ', 43.6161100, 13.1584900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83353, 'Ostiglia', 'Ostiglia', 'Ostiglia', 45.0697800, 11.1349900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83354, 'Ostiano', 'Ostiano', 'Ostiano', 45.2226000, 10.2545000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83355, 'Osteno-Claino', 'Osteno-Claino', '', 46.0036700, 9.0874100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83356, 'Ostellato', 'Ostellato', 'Ostelato,Ostellato,Ostełato,Ustullatum,ao si tai la tuo,awstlatw,osuterrato,Остелато,Остеллато,Օստելատո,أوستلاتو,オステッラート,奥斯泰拉托', 44.7455600, 11.9427600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83357, 'Ossona', 'Ossona', 'Ossona,ossona,オッソーナ', 45.5070800, 8.8931400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83358, 'Ossi', 'Ossi', 'Ossi', 40.6748300, 8.5925400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83359, 'Ossago Lodigiano', 'Ossago Lodigiano', '', 45.2421000, 9.5372000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83360, 'Ospitaletto', 'Ospitaletto', 'Ospitaletto', 45.5522100, 10.0756200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83361, 'Ospitale di Cadore', 'Ospitale di Cadore', 'Ospitale,Ospitale Bellunese,Ospitale di Cadore', 46.3280800, 12.3226300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83362, 'Ospedalicchio', 'Ospedalicchio', 'Ospedalicchio', 43.0781200, 12.5007400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83363, 'Ospedaletto Euganeo', 'Ospedaletto Euganeo', 'Ospedaletto Euganeo', 45.2184200, 11.6034500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83364, 'Ospedaletto d''Alpinolo', 'Ospedaletto d''Alpinolo', '', 40.9390600, 14.7465200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83365, 'Ospedaletto', 'Ospedaletto', 'Ospedaletto,osupedaretto,オスペダレット', 46.0428600, 11.5543900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83366, 'Ospedaletto', 'Ospedaletto', '', 45.6619400, 12.0788400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83367, 'Ospedaletto', 'Ospedaletto', 'Ospedaletto,Оспедалетто', 43.9838000, 12.5705600, 'IT', '2016-07-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83368, 'Ospedaletti', 'Ospedaletti', 'Ospedaletti,Spiareti', 43.8022100, 7.7183000, 'IT', '2015-05-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83369, 'Osoppo', 'Osoppo', 'Osof,Osoppo', 46.2553600, 13.0845300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83370, 'Osnago', 'Osnago', 'Osnago', 45.6754800, 9.3919200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83371, 'Osmate', 'Osmate', 'Osmate', 45.7886700, 8.6552300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83372, 'Osimo', 'Osimo', 'Osimo,ojimo,Осимо,オージモ', 43.4853900, 13.4822200, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83373, 'Osilo', 'Osilo', 'Osilo', 40.7434900, 8.6711300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83374, 'Osiglia', 'Osiglia', 'Oseria,Osiglia', 44.2814500, 8.2009600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83375, 'Osidda', 'Osidda', 'Osidda', 40.5236800, 9.2205300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83376, 'Oschiri', 'Oschiri', 'Oscari,Oscheri,Oschiri,Oskiri,ao si ji li,osukiri,Оскири,Оскірі,Օսկիրի,オスキリ,奥斯基里', 40.7197700, 9.1010200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83377, 'Orzivecchi', 'Orzivecchi', 'Orzivecchi', 45.4205800, 9.9632600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83378, 'Orzinuovi', 'Orzinuovi', 'Castrum Urceorum Novorum,Orzinuovi,orutsu~inuovu~i,オルツィヌオーヴィ', 45.4019100, 9.9231900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83379, 'Orvinio', 'Orvinio', 'Orvinio', 42.1303900, 12.9376200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83380, 'Orvieto', 'Orvieto', 'Orvieto,oruvu~ieto,Орвието,オルヴィエート', 42.7192400, 12.1124900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83381, 'Orune', 'Orune', 'Orune', 40.4078600, 9.3696300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83382, 'Ortueri', 'Ortueri', 'Ortueri', 40.0354500, 8.9859100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83383, 'Ortucchio', 'Ortucchio', 'Ortucchio', 41.9552500, 13.6465100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83384, 'Ortovero', 'Ortovero', 'Ortoe,Ortovero,Ortoê', 44.0538500, 8.0995000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83385, 'Ortona dei Marsi', 'Ortona dei Marsi', '', 41.9982000, 13.7290900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83386, 'Ortona', 'Ortona', 'Ortona,Ortona a Mare,Ортона', 42.3508700, 14.4034200, 'IT', '2016-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83387, 'Ortisei', 'Ortisei', 'Artyzej,Ortisei,Ortizei,Ortizej,St. Ulrich im Groednertal,St. Ulrich im Grödnertal,St. Ulrich in Groeden,St. Ulrich in Gröden,Urticetum,Urtijei,Urtijëi,ao er di sai yi,awrtyjy,orutizei,Ορτιζέι,Артызей,Ортизеи,Ортизей,Ортізеї,Օրտիզեի,اورتیجی,オルティゼーイ,奥尔蒂塞伊', 46.5760300, 11.6717600, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83388, 'Ortignano Raggiolo', 'Ortignano Raggiolo', 'Ortignano Raggiolo', 43.6799500, 11.7488300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83389, 'Ortezzano', 'Ortezzano', 'Ortezzano', 43.0304200, 13.6053100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83390, 'Ortelle', 'Ortelle', 'Ortelle', 40.0337100, 18.3912500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83391, 'Orte', 'Orte', 'Orte,orute,オルテ', 42.4611700, 12.3863500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83392, 'Orta San Giulio', 'Orta San Giulio', 'Orta,Orta San Giulio,オルタ・サン・ジューリオ', 45.7972700, 8.4143700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83393, 'Orta Nova', 'Orta Nova', 'Orta Nova', 41.3287900, 15.7099400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83394, 'Orsogna', 'Orsogna', 'Orsogna', 42.2234400, 14.2808500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83395, 'Orsenigo', 'Orsenigo', 'Orsenigh,Orsenigo,Orsenigum,ao er sai ni ge,orusenigo,Орсениго,Орсеніго,Օրսենիգո,オルセニーゴ,奥尔塞尼戈', 45.7783900, 9.1796300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83396, 'Orsara di Puglia', 'Orsara di Puglia', 'Orsara Danno Irpina,Orsara di Puglia', 41.2816300, 15.2676500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83397, 'Orria', 'Orria', 'Orria', 40.2997100, 15.1711600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83398, 'Orotelli', 'Orotelli', 'Orotelli', 40.3066300, 9.1215000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83399, 'Orosei', 'Orosei', 'Orosei', 40.3782600, 9.6924800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83400, 'Ornica', 'Ornica', 'Ornica', 45.9889200, 9.5784800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83401, 'Ornavasso', 'Ornavasso', 'Ornavasso', 45.9679500, 8.4158400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83402, 'Ornago', 'Ornago', 'Ornago,orunago,オルナーゴ', 45.5998700, 9.4209900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83403, 'Ormea', 'Ormea', 'Ormea', 44.1558600, 7.9281100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83404, 'Oriolo Romano', 'Oriolo Romano', 'Oriolo,Oriolo Romano', 42.1626100, 12.1385900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83405, 'Oriolo', 'Oriolo', 'Oriolo', 40.0532000, 16.4466300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83406, 'Orio Litta', 'Orio Litta', 'Orio Litta,オーリオ・リッタ', 45.1624400, 9.5544700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83407, 'Orio Canavese', 'Orio Canavese', 'Orio Canavese,オーリオ・カナヴェーゼ', 45.3288300, 7.8599100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83408, 'Orio al Serio', 'Orio al Serio', 'Orio al Serio', 45.6749000, 9.6908300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83409, 'Origgio', 'Origgio', 'Origgio', 45.5967600, 9.0164500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83410, 'Oricola', 'Oricola', 'Oricola', 42.0492200, 13.0393900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83411, 'Oria', 'Oria', 'Urium', 40.4999900, 17.6428000, 'IT', '2015-09-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83412, 'Orgosolo', 'Orgosolo', 'Orgosolo,Orgòsolo', 40.2053000, 9.3544500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83413, 'Orgiano', 'Orgiano', '', 45.3336600, 11.4595300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83414, 'Ordona', 'Ordona', 'Ordona', 41.3150100, 15.6283200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83415, 'Orciano di Pesaro', 'Orciano di Pesaro', 'Orciano di Pesaro', 43.6893800, 12.9720600, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83416, 'Orcenico Inferiore', 'Orcenico Inferiore', '', 45.9497700, 12.7645200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83417, 'Orbetello', 'Orbetello', 'Orbetello,Orbetellu,Орбетелло', 42.4415800, 11.2214000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83418, 'Orbassano', 'Orbassano', 'Orbassan,Orbassano,orubassano,Орбассано,オルバッサーノ', 45.0054700, 7.5381300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83419, 'Oratino', 'Oratino', 'Oratino', 41.5859800, 14.5946300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83420, 'Cursolo', 'Cursolo', '', 46.0985800, 8.5682200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83421, 'Orani', 'Orani', 'Orani', 40.2520000, 9.1814900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83422, 'Ora', 'Ora', 'Auer,Auer bei Bozen,Ora,ora,オーラ', 46.3468700, 11.2974700, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83423, 'Oppido Lucano', 'Oppido Lucano', 'Oppido Lucano,Palinira,Palmira', 40.7617400, 15.9881800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83424, 'Oppeano', 'Oppeano', 'Oppeano', 45.3033100, 11.1800500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83425, 'Opi', 'Opi', '', 41.7783800, 13.8293200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83426, 'Opera', 'Opera', 'Opera,opera,オーペラ', 45.3735500, 9.2108400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83427, 'Oniferi', 'Oniferi', 'Oniferi', 40.2719600, 9.1703300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83428, 'Onifai', 'Onifai', 'Oniai,Oniài', 40.4069400, 9.6500500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83429, 'Oneta', 'Oneta', 'Oneta', 45.8714900, 9.8193500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83430, 'Onano', 'Onano', 'Onano,onano,オナーノ', 42.6910400, 11.8155200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83431, 'Onanì', 'Onani', 'Onani,Onanì', 40.4853600, 9.4432400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83432, 'Omignano', 'Omignano', 'Omignano', 40.2493200, 15.0840600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83433, 'Omegna', 'Omegna', 'Omegna,omenja,omenya,Оменя,オメーニャ', 45.8800200, 8.4066500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83434, 'Olzai', 'Olzai', 'Olzai', 40.1823800, 9.1467900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83435, 'Oltrona di San Mamette', 'Oltrona di San Mamette', 'Oltrona di San Mamette', 45.7557800, 8.9767300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83436, 'Oltre Il Colle', 'Oltre Il Colle', 'Oltre il Colle', 45.8894900, 9.7692500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83437, 'Olmo al Brembo', 'Olmo al Brembo', 'Olmo,Olmo al Brembo', 45.9700600, 9.6503400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83438, 'Vignole-Olmi', 'Vignole-Olmi', 'Gli Olmi,Olmi', 43.8669600, 10.9904500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83439, 'Olmeneta', 'Olmeneta', 'Olmeneta', 45.2354000, 10.0231800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83440, 'Olmedo', 'Olmedo', 'Olmedo', 40.6515600, 8.3802100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83441, 'Ollolai', 'Ollolai', 'Ollolai', 40.1680500, 9.1777600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83442, 'Oliveto Lucano', 'Oliveto Lucano', 'Oliveto Lucano', 40.5355400, 16.1854700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83443, 'Vassena', 'Vassena', 'Oliveto Lario,Vassena', 45.9299800, 9.2839900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83444, 'Oliveto Citra', 'Oliveto Citra', 'Oliveto Citra', 40.6903900, 15.2334600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83445, 'Oliena', 'Oliena', 'Oliena,Uliana,Ulìana,Олиена', 40.2761700, 9.4019300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83446, 'Olginate', 'Olginate', 'Olginate', 45.7912600, 9.4186900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83447, 'Olgiate Olona', 'Olgiate Olona', 'Olgiate Olona', 45.6370600, 8.8814700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83448, 'Olgiate Comasco', 'Olgiate Comasco', 'Olgiate,Olgiate Comasco,Olgiate Novocomense', 45.7843600, 8.9681600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83449, 'Olevano sul Tusciano', 'Olevano sul Tusciano', 'Olevano sul Tusciano', 40.6572100, 15.0230500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83450, 'Olevano Romano', 'Olevano Romano', 'Olevano,Olevano Romano,オレーヴァノ・ロマーノ', 41.8586900, 13.0360100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83451, 'Olevano di Lomellina', 'Olevano di Lomellina', 'Olevano di Lomellina', 45.2132200, 8.7175000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83452, 'Oleggio', 'Oleggio', 'Oleggio', 45.5967400, 8.6421300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83453, 'Oldenico', 'Oldenico', 'Oldenico', 45.4027600, 8.3810300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83454, 'Olcenengo', 'Olcenengo', 'Olcenengo', 45.3634600, 8.3098300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83455, 'Olbia', 'Olbia', 'OLB,Ol''bija,Olbia,Tarranoa,Tarranóa,Terranoa,Terranòa,Ольбия', 40.9233700, 9.4980200, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83456, 'Ogliastro Cilento', 'Ogliastro Cilento', 'Ogliastro,Ogliastro Cilento', 40.3511300, 15.0463800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83457, 'Oglianico', 'Oglianico', 'Oglianico,orianiko,オリアーニコ', 45.3415400, 7.6919600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83458, 'Oggiono', 'Oggiono', 'Odzhono,Oggiono,Оджоно', 45.7913300, 9.3481500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83459, 'Offlaga', 'Offlaga', '', 45.3852600, 10.1173600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83460, 'Offida', 'Offida', 'Offida', 42.9349900, 13.6977300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83461, 'Offanengo', 'Offanengo', 'Offanengo', 45.3788700, 9.7423600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83462, 'Offagna', 'Offagna', 'Offagna,offanya,オッファーニャ', 43.5258800, 13.4407600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83463, 'Ofena', 'Ofena', 'Ofena', 42.3253600, 13.7586400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83464, 'Odolo', 'Odolo', 'Odolo,odoro,オードロ', 45.6455000, 10.3830900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83465, 'Oderzo', 'Oderzo', 'Oderzo', 45.7811400, 12.4944200, 'IT', '2015-06-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83466, 'Occimiano', 'Occimiano', 'Occimiano', 45.0599100, 8.5066600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83467, 'Occhiobello', 'Occhiobello', 'Occhiobello', 44.9224000, 11.5813900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83468, 'Occhieppo Superiore', 'Occhieppo Superiore', 'Occhieppo Superiore', 45.5640000, 8.0061800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83469, 'Occhieppo Inferiore', 'Occhieppo Inferiore', 'Occhieppo Inferiore', 45.5500600, 8.0210200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83470, 'Nuvolento', 'Nuvolento', 'Nuvolento', 45.5459900, 10.3880900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83471, 'Nusco', 'Nusco', 'Nusco', 40.8882000, 15.0918500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83472, 'Nuoro', 'Nuoro', 'Nugoro,Nuoro,Nùgoro,QNU,nuoro,Нуоро,ヌオロ', 40.3199100, 9.3256800, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83473, 'Numana', 'Numana', 'Numana,numana,ヌマーナ', 43.5113600, 13.6211800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83474, 'Nulvi', 'Nulvi', 'Nuivi,Nujvi,Nul''vi,Nulvi,nu er wei,nuruvu~i,Нулви,Нульви,Нульві,Նուլվի,ヌルヴィ,努尔维', 40.7844700, 8.7435800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83475, 'Nule', 'Nule', 'Nule', 40.4626600, 9.1907600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83476, 'Nughedu Santa Vittoria', 'Nughedu Santa Vittoria', 'Nughedu San Vittoria,Nughedu Santa Vittoria', 40.1013500, 8.9524700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83477, 'Nughedu San Nicolò', 'Nughedu San Nicolo', 'Nughedu San Nicolo,Nughedu San Nicolò', 40.5573600, 9.0214200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83478, 'Nucetto', 'Nucetto', 'Nucetto', 44.3396300, 8.0596000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83479, 'Novoli', 'Novoli', 'Novoli', 40.3767300, 18.0475700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83480, 'Novi Velia', 'Novi Velia', '', 40.2226200, 15.2860000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83481, 'Novi Ligure', 'Novi Ligure', 'Novi Ligure,Novi-Ligure,Нови-Лигуре,ノーヴィ・リーグレ', 44.7624600, 8.7870000, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83482, 'Novi di Modena', 'Novi di Modena', 'Novi di Modena', 44.8897400, 10.9002700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83483, 'Noventa Vicentina', 'Noventa Vicentina', 'Noventa,Noventa Vicentina', 45.2943800, 11.5484300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83484, 'Noventa di Piave', 'Noventa di Piave', 'Noventa di Piave,ノヴェンタ・ディ・ピアーヴェ', 45.6598100, 12.5332200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83485, 'Novello', 'Novello', 'Novello', 44.5888200, 7.9258700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83486, 'Novellara', 'Novellara', 'Novellara', 44.8448800, 10.7274500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83487, 'Nove', 'Nove', 'Nove,novu~e,ノーヴェ', 45.7215900, 11.6783300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83488, 'Novate Milanese', 'Novate Milanese', 'Novate Milanese,ノヴァーテ・ミラネーゼ', 45.5305000, 9.1395400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83489, 'Novate Mezzola', 'Novate Mezzola', 'Novate,Novate Mecola,Novate Mezola,Novate Mezoła,Novate Mezzola,Novate-Meccola,Novate-Medzola,Novatum,Nuvaa,nuo wa tai mei zuo la,Новате Мецола,Новате-Медзола,Новате-Меццола,Նովատե Մեցոլա,ノヴァーテ・メッツォーラ,诺瓦泰梅佐拉', 46.2193900, 9.4497100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83490, 'Nova Siri', 'Nova Siri', 'Nova Siri', 40.1482300, 16.5397600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83491, 'Novara', 'Novara', 'Novara,Novare,Novaria,Nuara,Nuvara,novu~ara,Новара,ノヴァーラ', 45.4469400, 8.6211800, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83492, 'Nova Ponente', 'Nova Ponente', 'Deutschnofen,Nova Ponente,Nova Teutonica,Nova-Panenteh,Nova-Ponente,Nòva Ponènte,nuo wa bo nen tai,Нова-Панентэ,Нова-Поненте,ノーヴァ・ポネンテ,诺瓦波嫩泰', 46.4140400, 11.4252300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83493, 'Nova Milanese', 'Nova Milanese', 'Nova Milanese,ノーヴァ・ミラネーゼ', 45.5888200, 9.1979200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83494, 'Nova Levante', 'Nova Levante', 'Nova Latina,Nova Levante,Nova-Levante,Nova-Levanteh,Welschnofen,nuo wa lai wan tai,Нова Леванте,Нова-Леванте,Нова-Левантэ,Նովա Լևանտե,ノーヴァ・レヴァンテ,诺瓦莱万泰', 46.4289900, 11.5394200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83495, 'Novalesa', 'Novalesa', 'Novalaise,Novaleisa,Novalesa,Novalèisa,novu~areza,ノヴァレーザ', 45.1906500, 7.0141600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83496, 'Novaledo', 'Novaledo', 'Novaledo,novu~aredo,ノヴァレード', 46.0234000, 11.3660700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83497, 'Novafeltria', 'Novafeltria', 'Mercatino,Mercatino Marecchia,Novafeltria', 43.8948600, 12.2889400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83498, 'Notaresco', 'Notaresco', 'Notaresco', 42.6574200, 13.8949100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83499, 'Nosate', 'Nosate', 'Nosate,nozate,ノザーテ', 45.5507400, 8.7250900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83500, 'Norma', 'Norma', '', 41.5864300, 12.9707300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83501, 'Norcia', 'Norcia', 'Norcia,Nursja,norucha,ノルチャ', 42.7910500, 13.0960000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83502, 'Norbello', 'Norbello', 'Norbello', 40.1347500, 8.8320300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83503, 'Noragugume', 'Noragugume', 'Noragugume', 40.2244300, 8.9201200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83504, 'None', 'None', 'None,none,ノーネ', 44.9364500, 7.5401500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83505, 'Nonantola', 'Nonantola', 'Nonantola,Nonantoła,Nonantula,nonantora,nuo nan tuo la,nwnatwla,Нонантола,نوناتولا,ノナントラ,诺南托拉', 44.6778500, 11.0378500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83506, 'Nomi', 'Nomi', 'Nomi,nomi,ノーミ', 45.9292300, 11.0719800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83507, 'Nomaglio', 'Nomaglio', 'Nomaglio,nomario,ノマーリオ', 45.5361600, 7.8603200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83508, 'Noli', 'Noli', '', 44.2060800, 8.4145800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83509, 'Nole', 'Nole', 'Nole,Nole Canavese,nore,ノーレ', 45.2415900, 7.5698300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83510, 'Nola', 'Nola', 'Nola,nora,ノーラ', 40.9260600, 14.5281600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83511, 'Noicattaro', 'Noicattaro', 'Noicattaro', 41.0344900, 16.9896300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83512, 'Noha', 'Noha', '', 40.1532300, 18.1656900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83513, 'Nogarole Rocca', 'Nogarole Rocca', 'Nogarole Rocca,Nogarole di Rocca', 45.2902700, 10.8834200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83514, 'Nogara', 'Nogara', 'Nogara', 45.1810900, 11.0600800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83515, 'Noepoli', 'Noepoli', 'Noepoli', 40.0870500, 16.3283400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83516, 'Nociglia', 'Nociglia', 'Nociglia,Nocilia', 40.0380400, 18.3275700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83517, 'Noci', 'Noci', 'Noci,nochi,ノーチ', 40.7935600, 17.1268100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83518, 'Noceto', 'Noceto', 'Noceto', 44.8095300, 10.1773000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83519, 'Nocera Umbra', 'Nocera Umbra', 'Nocera Umbra', 43.1140000, 12.7892500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83520, 'Nocera Superiore', 'Nocera Superiore', 'Nocera Superiore', 40.7424800, 14.6744700, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83521, 'Nocera Inferiore', 'Nocera Inferiore', 'Nocera,Nocera Inferiore,ノチェーラ・インフェリオーレ', 40.7454000, 14.6454200, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83522, 'Nocelleto', 'Nocelleto', '', 41.1706700, 14.0156500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83523, 'Nocciano', 'Nocciano', 'Nocciano', 42.3336600, 13.9857100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83524, 'Nocara', 'Nocara', 'Nocara', 40.0994100, 16.4818900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83525, 'Noasca', 'Noasca', 'Noasca,noasuka,ノアスカ', 45.4533200, 7.3149400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83526, 'Noale', 'Noale', 'Noale,noare,ノアーレ', 45.5459600, 12.0644500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83527, 'Nizza Monferrato', 'Nizza Monferrato', 'Monferrato,Nissa,Nizza Monferrato', 44.7741600, 8.3578400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83528, 'Nimis', 'Nimis', 'Nimis,Valle Nimis', 46.2065900, 13.2677700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83529, 'Niella Belbo', 'Niella Belbo', 'Niella Belbo', 44.5127500, 8.0803600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83530, 'Nichelino', 'Nichelino', 'El Niclin,Nichelino,Nikelino,nikerino,Ël Niclin,Никелино,ニケリーノ', 45.0003100, 7.6530500, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83531, 'Nibbiano', 'Nibbiano', 'Nibbiano', 44.9050600, 9.3282600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83532, 'Neviano degli Arduini', 'Neviano degli Arduini', 'Neviano degli Arduini', 44.5834400, 10.3163800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83533, 'Neviano', 'Neviano', 'Neviano', 40.1065000, 18.1151700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83534, 'Nettuno', 'Nettuno', 'Neptunium,Nettuno,Nettunu,Netunas,Netuno,Netūnas,netto~uno,netuno,nie tu nuo,ntwnw,nytwnw,Неттуно,Нетуно,Նետունո,نتونو,نيتونو,نیتونو,ネットゥーノ,聶圖諾,네투노', 41.4579400, 12.6639300, 'IT', '2015-04-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83535, 'Netro', 'Netro', 'Netro,netoro,ネトロ', 45.5400400, 7.9469500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83536, 'Nespolo', 'Nespolo', 'Nespolo', 42.1567100, 13.0693800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83537, 'Nerviano', 'Nerviano', 'Nerviano,neruvu~iano,ネルヴィアーノ', 45.5534300, 8.9792000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83538, 'Nervesa della Battaglia', 'Nervesa della Battaglia', 'Nervesa,Nervesa della Battaglia', 45.8123200, 12.1983700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83539, 'Nerola', 'Nerola', 'Nerola,nerora,ネーロラ', 42.1601100, 12.7852900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83540, 'Nerito', 'Nerito', '', 42.5476300, 13.4775900, 'IT', '2014-03-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83541, 'Nereto', 'Nereto', 'Nereto', 42.8154800, 13.8198900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83542, 'Nepi', 'Nepi', 'Nepi,nepi,ネーピ', 42.2422100, 12.3435500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83543, 'Nepezzano', 'Nepezzano', 'Nepezzano', 42.6899400, 13.7565000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83544, 'Neoneli', 'Neoneli', 'Neoneli', 40.0647500, 8.9467300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83545, 'Nemoli', 'Nemoli', 'Nemoli', 40.0676500, 15.7996200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83546, 'Nemi', 'Nemi', 'Nemi,nemi,ネーミ', 41.7218500, 12.7180900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83547, 'Nembro', 'Nembro', 'Nembro', 45.7441100, 9.7612700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83548, 'Bricco di Neive', 'Bricco di Neive', 'Neive', 44.7115900, 8.1340900, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83549, 'Neirone', 'Neirone', 'Neion,Neirone', 44.4548200, 9.1913300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83550, 'Negrar', 'Negrar', 'Negar,Negrar', 45.5291800, 10.9389900, 'IT', '2015-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83551, 'Conscenti', 'Conscenti', '', 44.3449100, 9.3953700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83552, 'Nazzano', 'Nazzano', 'Nazzano,nattsu~ano,ナッツァーノ', 42.2301800, 12.5944000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83553, 'Navelli', 'Navelli', 'Navelli', 42.2372100, 13.7296100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83554, 'Nave', 'Nave', '', 45.5848000, 10.2794700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83555, 'Naturno', 'Naturno', 'Natourno,Naturna,Naturno,Naturns,Naturnum,na tu er nuo,nato~uruno,Νατούρνο,Натурна,Натурно,Նատուրնո,ナトゥルノ,纳图尔诺', 46.6480100, 11.0012900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83556, 'Nasino-Borgo', 'Nasino-Borgo', 'Nasino,Naxin', 44.1136300, 8.0320500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83557, 'Narzole', 'Narzole', 'Narzole', 44.5944100, 7.8676500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83558, 'Narni Scalo', 'Narni Scalo', '', 42.5362000, 12.5168000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83559, 'Narni', 'Narni', 'Narni,naruni,ナルニ', 42.5195600, 12.5275800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83560, 'Nardò', 'Nardo', 'Nardo,Nardò,narudo,ナルド', 40.1795300, 18.0317400, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83561, 'Narbolia', 'Narbolia', 'Narbolia', 40.0478400, 8.5755200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83562, 'Naples', 'Naples', 'Gorad Neapal'',NAP,Napels,Naples,Naplés,Napoles,Napoli,Napolo,Napols,Napoly,Nappoli,Napul,Napule,Napuli,Napulj,Napólí,Neapel,Neapelj,Neapol,Neapol'',Neapole,Neapolis,Noapels,Nàpoli,Nàpols,Nàpuli,Nàpułi,Nápoles,Nápoli,Nápols,Nápoly,Parthenope,na bu lei si,nabwly,napl,napoli,napolli,napori,napwly,nepalasa,nepalsa,nepeils,nyplz,Νάπολη,Горад Неапаль,Напуљ,Неапол,Неаполь,Նեապոլ,נאפאלי,נאפולי,نابولي,ناپل,ناپولی,نیپلز,नापोलि,नापोली,नेपल्स,নেপলস,நாபொலி,เนเปิลส์,ნეაპოლი,ナポリ,那不勒斯,나폴리', 40.8521600, 14.2681100, 'IT', '2017-05-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83563, 'Nalles', 'Nalles', 'Nalles,Nals,narresu,ナッレス', 46.5434100, 11.2062500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83564, 'Nago-Torbole', 'Nago-Torbole', 'Nacus-Turbulae,Nago Torbole,Nago-Torbole,Nago-Torbołe,Nago–Torbole,na ge-tuo er bo lai,nago=torubore,Наго-Торболе,Նագո Տորբոլե,ナーゴ＝トルボレ,纳戈-托尔博莱', 45.8759400, 10.8910600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83565, 'Muzzana del Turgnano', 'Muzzana del Turgnano', 'Mucane,Muzzana,Muzzana del Turgnano', 45.8179900, 13.1275100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83566, 'San Pietro Mussolino', 'San Pietro Mussolino', '', 45.5835900, 11.2593000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83567, 'Musso', 'Musso', 'Musso', 46.1129500, 9.2737900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83568, 'Musile di Piave', 'Musile di Piave', 'Musile,Musile di Piave,ムジーレ・ディ・ピアーヴェ', 45.6205700, 12.5417700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83569, 'Musano', 'Musano', '', 45.7264600, 12.1178500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83570, 'Muros', 'Muros', 'Muros', 40.6790200, 8.6178000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83571, 'Muro Lucano', 'Muro Lucano', 'Muro Lucano', 40.7537900, 15.4880800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83572, 'Muro Leccese', 'Muro Leccese', 'Muro Leccese', 40.1028600, 18.3367400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83573, 'Murlo', 'Murlo', 'Gorad Murla,Murlo,Murlu,Murlum,mu er luo,muleullo,mururo,Горад Мурла,Мурло,Մուրլո,ムルロ,穆尔洛,무를로', 43.1611400, 11.3879400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83574, 'Murisengo', 'Murisengo', 'Ambrusengh,Murisengo', 45.0816500, 8.1355400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83575, 'Murialdo', 'Murialdo', 'Moriaodo,Murialdo', 44.3169300, 8.1681500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83576, 'Murazzano', 'Murazzano', 'Murazzano', 44.4733400, 8.0193800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83577, 'Murano', 'Murano', 'Ile de Murano,Murano,mu la nuo dao,murano,Île de Murano,מוראנו,ムラーノ,穆拉诺岛', 45.4585700, 12.3568300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83578, 'Mura', 'Mura', 'Mura,mura,ムーラ', 45.7130700, 10.3420400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83579, 'Mulazzo', 'Mulazzo', 'Mulazzo,Mulazzo Lunigania,murattsu~o,ムラッツォ', 44.3156400, 9.8910100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83580, 'Mugnano di Napoli', 'Mugnano di Napoli', 'Mugnano ''e Napule,Mugnano di Napoli,ムニャーノ・ディ・ナーポリ', 40.9093600, 14.2098400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83581, 'Mugnano del Cardinale', 'Mugnano del Cardinale', 'Mugnano del Cardinale', 40.9424800, 14.6361000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83582, 'Muggiò', 'Muggio', 'Muggio,Muggiò,mujjo,ムッジョ', 45.5887800, 9.2278400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83583, 'Muggia', 'Muggia', 'Milje,Mudha,Muggia,Muggio,Muđa,mujja,ムッジャ', 45.6041900, 13.7675400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83584, 'Muccia', 'Muccia', 'Muccia,Muccia Vallicchio,Múccia Vallicchio', 43.0823200, 13.0432300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83585, 'Mozzecane', 'Mozzecane', 'Mozzecane', 45.3076300, 10.8155400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83586, 'Mozzate', 'Mozzate', 'Mozzate', 45.6747300, 8.9564400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83587, 'Mozzanica', 'Mozzanica', '', 45.4768000, 9.6884900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83588, 'Mozzagrogna', 'Mozzagrogna', 'Mozzagrogna', 42.2126700, 14.4425800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83589, 'Mottola', 'Mottola', 'Mottola', 40.6389000, 17.0343200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83590, 'Motta Visconti', 'Motta Visconti', 'Motta Visconti,モッタ・ヴィスコンティ', 45.2877400, 8.9925400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83591, 'Motta Montecorvino', 'Motta Montecorvino', 'Motta Montecorvino', 41.5074300, 15.1141400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83592, 'Mottalciata', 'Mottalciata', 'Mottalciata', 45.5001900, 8.2106500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83593, 'Motta di Livenza', 'Motta di Livenza', 'Motta di Livenza', 45.7755200, 12.6041100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83594, 'Motta Dè Conti', 'Motta De Conti', '', 45.1935600, 8.5209400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83595, 'Motta Baluffi', 'Motta Baluffi', 'Motta Baluffi', 45.0556900, 10.2585500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83596, 'Motta', 'Motta', '', 45.5954000, 11.4979800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83597, 'Mosso Santa Maria', 'Mosso Santa Maria', '', 45.6495800, 8.1368200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83598, 'Mossa', 'Mossa', 'Massa,Mossa,Mosse', 45.9367400, 13.5493300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83599, 'Moso in Passiria', 'Moso in Passiria', 'Moos,Moos in Passeier,Moso in Passiria,Mosum in Valle Passiriae,Mozo in Pasiria,Mozo in Pasirija,Mozo-in-Passirija,mo suo yin pa xi li ya,Мозо ин Пасирия,Мозо-ин-Пассирия,Мозо-ін-Пассірія,Մոզո ին Պասիրիա,モーゾ・イン・パッシーリア,莫索因帕西里亚', 46.8315400, 11.1670800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83600, 'Mosnigo', 'Mosnigo', '', 45.8630300, 12.0785200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83601, 'Moscufo', 'Moscufo', 'Moscufo', 42.4271300, 14.0543400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83602, 'Mosciano Sant''Angelo', 'Mosciano Sant''Angelo', 'Mosciano Sant''Angelo', 42.7470000, 13.8889100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83603, 'Moscazzano', 'Moscazzano', 'Moscazzano,Moscuzzano', 45.2935800, 9.6813500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83604, 'Moruzzo', 'Moruzzo', 'Moruc,Moruzzo', 46.1196700, 13.1240000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83605, 'Morterone', 'Morterone', 'Morterone,moruterone,モルテローネ', 45.8748000, 9.4823300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83606, 'Mortegliano', 'Mortegliano', 'Mortean,Mortegliano', 45.9455300, 13.1725500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83607, 'Mortara', 'Mortara', 'Mortara,morutara,モルターラ', 45.2494000, 8.7330200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83608, 'Morsano', 'Morsano', 'Morsan dal Tiliment,Morsano,Morsano al Tagliamento,Morsano al Tagliano', 45.8596900, 12.9276900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83609, 'Morrovalle', 'Morrovalle', 'Morrovalle', 43.3183000, 13.5953500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83610, 'Morro Reatino', 'Morro Reatino', 'Morro Reatino', 42.5222600, 12.8344900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83611, 'Morrone del Sannio', 'Morrone del Sannio', 'Morrone del Sannio', 41.7110700, 14.7808700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83612, 'Morro d''Oro', 'Morro d''Oro', 'Morro d''Oro', 42.6629100, 13.9212900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83613, 'Morro d''Alba', 'Morro d''Alba', 'Morro d''Alba,モッロ・ダルバ', 43.6000000, 13.2133100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83614, 'Morra de Sanctis', 'Morra de Sanctis', 'Morra De Sanctis', 40.9290200, 15.2428500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83615, 'Morozzo', 'Morozzo', 'Morozzo', 44.4227700, 7.7100600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83616, 'Morolo', 'Morolo', 'Morolo', 41.6383800, 13.1980900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83617, 'Mornago', 'Mornago', 'Mornago', 45.7451600, 8.7504600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83618, 'Morlupo', 'Morlupo', 'Morlupo,morurupo,モルルーポ', 42.1500200, 12.5030600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83619, 'Morimondo', 'Morimondo', 'Morimondo,morimondo,モリモンド', 45.3538100, 8.9562600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83620, 'Morigerati', 'Morigerati', 'Morigerati', 40.1405600, 15.5550800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83621, 'Moricone', 'Moricone', 'Moricone,morikone,モリコーネ', 42.1166100, 12.7723400, 'IT', '2014-04-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83622, 'Moriago della Battaglia', 'Moriago della Battaglia', 'Moriago,Moriago della Battaglia', 45.8658900, 12.1007700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83623, 'Mori', 'Mori', 'Mori,mori,モーリ', 45.8518700, 10.9805200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83624, 'Morgex', 'Morgex', 'Morgex,Valdigna,Valdigna d''Aosta', 45.7566400, 7.0412300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83625, 'Morfasso', 'Morfasso', 'Morfasso', 44.7227000, 9.7022100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83626, 'Moretta', 'Moretta', 'Moretta,Morëtta', 44.7613700, 7.5363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83627, 'Moresco', 'Moresco', 'Moresco', 43.0866600, 13.7304100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83628, 'Mores', 'Mores', 'Mores', 40.5474500, 8.8330200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83629, 'Mordano', 'Mordano', 'Mordano', 44.3969600, 11.8076300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83630, 'Morcone', 'Morcone', 'Marcone,Morcone', 41.3426900, 14.6688900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83631, 'Morciano di Romagna', 'Morciano di Romagna', 'Morciano di Romagna', 43.9144000, 12.6510400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83632, 'Morbegno', 'Morbegno', 'Morbegno,Morben''o,Морбеньо', 46.1372000, 9.5741500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83633, 'Morano sul Po', 'Morano sul Po', 'Morano,Morano Po,Morano sul Po', 45.1662100, 8.3667400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83634, 'Monzuno', 'Monzuno', 'Monzuno', 44.2782500, 11.2668400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83635, 'Monzambano', 'Monzambano', 'Monzambano,montsu~anbano,モンツァンバーノ', 45.3853400, 10.6933100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83636, 'Monza', 'Monza', 'Modicia,Monca,Monsa,Monza,Munscia,meng zha,mnza,montsu~a,mwnzh,Монца,מונצה,منزا,モンツァ,蒙扎', 45.5800500, 9.2724600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83637, 'Montù Beccaria', 'Montu Beccaria', 'Montu Beccaria,Montù Beccaria', 45.0363300, 9.3126800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83638, 'Montresta', 'Montresta', 'Montresta', 40.3736500, 8.4996200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83639, 'Montottone', 'Montottone', 'Montottone', 43.0620500, 13.5900900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83640, 'Montorso Vicentino', 'Montorso Vicentino', 'Montorso,Montorso Vicentino', 45.4908900, 11.3601900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83641, 'Montorio', 'Montorio', 'Montorio,Montorio Veronese', 45.4582600, 11.0658900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83642, 'Montorio Romano', 'Montorio Romano', 'Montorio Romano,モントーリオ・ロマーノ', 42.1373800, 12.8040400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83643, 'Montorio Nei Frentani', 'Montorio Nei Frentani', 'Montorio dei Frentani,Montorio nei Frentani', 41.7588400, 14.9331400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83644, 'Montorio al Vomano', 'Montorio al Vomano', 'Montorio Vomano,Montorio al Vomano', 42.5812300, 13.6371500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83645, 'Montopoli', 'Montopoli', 'Montopoli in Val d''Arno', 43.6735400, 10.7495100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83646, 'Montopoli in Sabina', 'Montopoli in Sabina', '', 42.2459300, 12.6920800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83647, 'Montone', 'Montone', '', 43.3607800, 12.3234600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83648, 'Montoggio', 'Montoggio', 'Monteuggio,Montoggio', 44.5169900, 9.0492300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83649, 'Montodine', 'Montodine', 'Montodine', 45.2841900, 9.7091000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83650, 'Montjovet', 'Montjovet', 'Mongiove,Montjovet', 45.7079600, 7.6741100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83651, 'Montignoso', 'Montignoso', 'Mancinjoza,Mons Tiniosus,Montignoso,Montin''ozo,Montinozo,Muntignusu,meng di ni ao suo,montinyoso,montinyozo,mwntynywzw,Манцінёза,Монтиньозо,Монтіньозо,Մոնտինոզո,مونتینیوزو,モンティニョーゾ,蒙蒂尼奥索,몬티뇨소', 44.0240500, 10.1725900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83652, 'Montiglio', 'Montiglio', '', 45.0646200, 8.0987800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83653, 'Montieri', 'Montieri', 'Montieri,Montreri', 43.1311300, 11.0166300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83654, 'Monticiano', 'Monticiano', 'Monticiano,montichano,モンティチャーノ', 43.1396500, 11.1771000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83655, 'Montichiari', 'Montichiari', 'Montichiari,montikiari,モンティキアーリ', 45.4131700, 10.3979900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83656, 'Monticello Conte Otto', 'Monticello Conte Otto', 'Monticello Conte Otto', 45.5978400, 11.5723400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83657, 'Monticelli', 'Monticelli', '', 40.6500000, 15.0166700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83658, 'Monticelli d''Ongina', 'Monticelli d''Ongina', 'Monticelli,Monticelli d''Ongina', 45.0885100, 9.9342400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83659, 'Monticchio', 'Monticchio', '', 42.3203500, 13.4638200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83660, 'Montiano', 'Montiano', 'Monfiano,Montiano', 44.0823200, 12.3045500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83661, 'Monti', 'Monti', 'Monti', 40.8071500, 9.3255300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83662, 'Monte Vidon Corrado', 'Monte Vidon Corrado', 'Monte Vidon Corrado', 43.1208700, 13.4893100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83663, 'Monteviale', 'Monteviale', 'Monteviale', 45.5592000, 11.4571500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83664, 'Monteverdi Marittimo', 'Monteverdi Marittimo', 'Monteverdi,Monteverdi Marittimo', 43.1778700, 10.7113300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83665, 'Monteverde', 'Monteverde', 'Monteverde', 40.9985800, 15.5336100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83666, 'Montevarchi', 'Montevarchi', 'Montevarchi,Montevarki,Монтеварки', 43.5252000, 11.5723800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83667, 'Monteu Roero', 'Monteu Roero', 'Monteu,Monteu Roero', 44.7805900, 7.9338300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83668, 'Monte Urano', 'Monte Urano', 'Monte Urano', 43.1903900, 13.6618000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83669, 'Monteu da Po', 'Monteu da Po', 'Monte da Po,Monteu da Po,モンテーウ・ダ・ポー', 45.1503100, 8.0142800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83670, 'Montespertoli', 'Montespertoli', 'Montespertoli', 43.6426000, 11.0733100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83671, 'Montesilvano Marina', 'Montesilvano Marina', '', 42.5114000, 14.1450700, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83672, 'Montesegale', 'Montesegale', 'Montesegale,Montesgale', 44.9069600, 9.1263600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83673, 'Montese', 'Montese', 'Montese', 44.2699300, 10.9454500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83674, 'Montescudo', 'Montescudo', 'Montescudo', 43.9175300, 12.5408300, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83675, 'Montescaglioso', 'Montescaglioso', 'Montescaglioso', 40.5502400, 16.6654100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83676, 'Montesarchio', 'Montesarchio', 'Caudium,Montesarchio', 41.0622700, 14.6409600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83677, 'Monte San Vito', 'Monte San Vito', 'Monte San Vito,モンテ・サン・ヴィート', 43.6005600, 13.2681700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83678, 'Monte Sant''Angelo', 'Monte Sant''Angelo', 'Monte Sant''Angelo,モンテ・サンタンジェロ', 41.7053000, 15.9606800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83679, 'Monte Santa Maria Tiberina', 'Monte Santa Maria Tiberina', 'Monte Santa Maria,Monte Santa Maria Tiberina', 43.4368800, 12.1622000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83680, 'Monte San Savino', 'Monte San Savino', 'Monte San Savino', 43.3321300, 11.7266300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83681, 'Monte San Pietrangeli', 'Monte San Pietrangeli', 'Monsampietrangeli,Monsampietrángeli,Monte San Pietrangeli', 43.1895900, 13.5771800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83682, 'Montesano sulla Marcellana', 'Montesano sulla Marcellana', 'Montesano sulla Marcellana', 40.2761000, 15.7039000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83683, 'Monte San Martino', 'Monte San Martino', 'Monte San Martino', 43.0321900, 13.4403300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83684, 'Monte San Giusto', 'Monte San Giusto', 'Monte San Giustano,Monte San Giusto', 43.2356500, 13.5931600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83685, 'Monte San Giovanni in Sabina', 'Monte San Giovanni in Sabina', 'Monte San Giovanni in Sabina', 42.3270300, 12.7785800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83686, 'Monte San Giovanni Campano', 'Monte San Giovanni Campano', 'Monte San Giovanni Campano', 41.6431000, 13.5108800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83687, 'Monte San Giacomo', 'Monte San Giacomo', 'Monte San Giacomo', 40.3441100, 15.5422100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83688, 'Monte San Biagio', 'Monte San Biagio', 'Castrum Monticelli,Monte San Biadzho,Monte San Biagio,Monte San Byajo,Monte-San-B''jadzho,Monte-San-Bjadzho,Munti San Biaggiu,meng tai sheng bi ya jiao,montesanbiajo,Монте Сан Биаджо,Монте-Сан-Бьяджо,Монте-Сан-Бяджо,Մոնտե Սան Բյաջո,モンテ・サン・ビアージョ,蒙泰圣比亚焦,몬테산비아조', 41.3536000, 13.3518400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83689, 'Monterubbiano', 'Monterubbiano', 'Monterubbiano', 43.0856000, 13.7191100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83690, 'Monterotondo Marittimo', 'Monterotondo Marittimo', 'Monterotondo Marittimo', 43.1455600, 10.8559100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83691, 'Monterotondo', 'Monterotondo', 'Crustumerium,Monterotondo,monterotondo,Монтеротондо,モンテロトンド', 42.0515900, 12.6196900, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83692, 'Monterosso al Mare', 'Monterosso al Mare', 'Monterosso,Monterosso al Mare,モンテロッソ・アル・マーレ', 44.1466600, 9.6549400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83693, 'Monterosi', 'Monterosi', 'Monterosi', 42.1969800, 12.3084200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83694, 'Monteroni di Lecce', 'Monteroni di Lecce', '', 40.3192900, 18.0916300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83695, 'Monteroni d''Arbia', 'Monteroni d''Arbia', 'Monteroni,Monteroni d''Arbia,モンテローニ・ダルビア', 43.2296800, 11.4222800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83696, 'Monte Romano', 'Monte Romano', 'Monte Romano', 42.2674500, 11.8965800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83697, 'Monteroduni', 'Monteroduni', 'Monteroduni', 41.5224000, 14.1764100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83698, 'Monte Roberto', 'Monte Roberto', 'Monte Roberto,モンテ・ロベルト', 43.4805600, 13.1379700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83699, 'Monte Rinaldo', 'Monte Rinaldo', 'Monte Rinaldo', 43.0282500, 13.5819800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83700, 'Monteriggioni', 'Monteriggioni', 'Monteridzhoni,Monteriggioni,monterijjoni,Монтериджони,モンテリッジョーニ', 43.3899400, 11.2232300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83701, 'Monterenzio', 'Monterenzio', 'Monterenzio', 44.3263200, 11.4044600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83702, 'Montereale Valcellina', 'Montereale Valcellina', 'Montereale,Montereale Cellina,Montereale Valcellina,Montreal,Montreâl', 46.1511000, 12.6477100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83703, 'Montereale', 'Montereale', '', 42.5233200, 13.2458500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83704, 'Monterchi', 'Monterchi', 'Monterchi', 43.4873300, 12.1105400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83705, 'Monterado', 'Monterado', 'Monterado,monterado,モンテラード', 43.6968600, 13.0905600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83706, 'Montepulciano Stazione', 'Montepulciano Stazione', '', 43.1352000, 11.8554500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83707, 'Montepulciano', 'Montepulciano', 'Mons Politianus,Montepulciano,montepuruchano,モンテプルチャーノ', 43.0999800, 11.7870400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83708, 'Monteprandone', 'Monteprandone', 'Monteprandone', 42.9205000, 13.8391000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83709, 'Monte Porzio Catone', 'Monte Porzio Catone', 'Monte Porzio,Monte Porzio Catone,モンテ・ポルツィオ・カトーネ', 41.8158500, 12.7143200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83710, 'Monteparano', 'Monteparano', 'Monteparano', 40.4433500, 17.4130800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83711, 'Monteodorisio', 'Monteodorisio', 'Monteodorisio', 42.0848500, 14.6538600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83712, 'Montenero Val Cocchiara', 'Montenero Val Cocchiara', 'Montenero Val Cocchiara', 41.7168300, 14.0694100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83713, 'Montenerodomo', 'Montenerodomo', 'Montenerodomo', 41.9768200, 14.2517700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83714, 'Montenero di Bisaccia', 'Montenero di Bisaccia', 'Montenero di Bisaccia', 41.9643700, 14.7810300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83715, 'Montemurro', 'Montemurro', 'Montemurro', 40.2976500, 15.9918200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83716, 'Montemurlo', 'Montemurlo', 'Montemurlo,montemururo,モンテムルロ', 43.9268600, 11.0371800, 'IT', '2013-09-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83717, 'Montemonaco', 'Montemonaco', 'Montemonaco', 42.8987100, 13.3301800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83718, 'Montemitro', 'Montemitro', 'Montemitro', 41.8881300, 14.6466600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83719, 'Montemilone', 'Montemilone', 'Montemilone', 41.0274200, 15.9666100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83720, 'Montemiletto', 'Montemiletto', 'Montemiletto', 41.0116800, 14.9003400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83721, 'Montemesola', 'Montemesola', 'Montemesola', 40.5676000, 17.3366500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83722, 'Monte Marenzo', 'Monte Marenzo', 'Monte Marenzo', 45.7721300, 9.4547600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83723, 'Montemarciano', 'Montemarciano', 'Montemarciano,montemaruchano,モンテマルチャーノ', 43.6384700, 13.3080100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83724, 'Montemarano', 'Montemarano', 'Montemarano', 40.9141400, 14.9976600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83725, 'Montemagno', 'Montemagno', 'Mantehman''jo,Mons Magnus,Montemagno,Monteman''o,Montemano,Montmagn,meng tai ma ni ao,montemanyo,mwnth manyw,mwntymanyw,Мантэманьё,Монтеманьо,Մոնտեմանո,مونته مانیو,مونتيمانيو,モンテマーニョ,蒙泰马尼奥', 44.9830500, 8.3253400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83726, 'Montemaggiore al Metauro', 'Montemaggiore al Metauro', 'Montemaggiore al Metauro', 43.7366600, 12.9453600, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83727, 'Montelupone', 'Montelupone', 'Montelupone', 43.3427000, 13.5707400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83728, 'Montelupo Fiorentino', 'Montelupo Fiorentino', 'Montelupo,Montelupo Fiorentino', 43.7295800, 11.0099700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83729, 'Montelupo Albese', 'Montelupo Albese', 'Monteiup Albese,Montelupo Albese', 44.6215100, 8.0472000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83730, 'Montelparo', 'Montelparo', 'Montelparo', 43.0175500, 13.5369800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83731, 'Montelongo', 'Montelongo', 'Montelongo', 41.7370500, 14.9503400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83732, 'Monteleone Sabino', 'Monteleone Sabino', 'Mantehleoneh-Sabina,Mons Leonis Sabinus,Monteleone Sabino,Monteleone-Sabino,Muntiliuni Sabinu,meng tai lai ao nei sa bi nuo,montelle-onesabino,Мантэлеонэ-Сабіна,Монтелеоне Сабино,Монтелеоне-Сабино,Монтелеоне-Сабіно,Մոնտելեոնե Սաբինո,مونته‌لئونه سابینو,モンテレオーネ・サビーノ,蒙泰莱奥内萨比诺,몬텔레오네사비노', 42.2326700, 12.8582800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83733, 'Monteleone Rocca Doria', 'Monteleone Rocca Doria', 'Monteleone Rocca Doria', 40.4720600, 8.5607100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83734, 'Monteleone d''Orvieto', 'Monteleone d''Orvieto', 'Monteleone d''Orvieto,Monteleone di Orrieto', 42.9217100, 12.0534700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83735, 'Monteleone di Spoleto', 'Monteleone di Spoleto', 'Monteleone,Monteleone di Spoleto', 42.6504600, 12.9515800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83736, 'Monteleone di Puglia', 'Monteleone di Puglia', 'Monteleone di Puglia', 41.1671100, 15.2582200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83737, 'Montelapiano', 'Montelapiano', 'Montelapiano', 41.9626700, 14.3421200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83738, 'Montelanico', 'Montelanico', 'Montelanico,monteraniko,モンテラーニコ', 41.6506900, 13.0402700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83739, 'Montelabbate', 'Montelabbate', 'Montelabate,Montelabbate', 43.8473200, 12.7876300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83740, 'Monteiasi', 'Monteiasi', 'Monteiasi,Montejasi', 40.4999200, 17.3826000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83741, 'Montegrotto Terme', 'Montegrotto Terme', 'Montegrotto Terme', 45.3311900, 11.7863400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83742, 'Montegrosso Pian Latte', 'Montegrosso Pian Latte', 'Montegrosso Pian Latte', 44.0663100, 7.8160200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83743, 'Montegrosso', 'Montegrosso', 'Montegrosso d''Asti', 44.8206500, 8.2375400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83744, 'Monte Grimano', 'Monte Grimano', '', 43.4666700, 12.4666700, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83745, 'Montegranaro', 'Montegranaro', 'Montegranaro', 43.2309900, 13.6304700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83746, 'Montegiorgio', 'Montegiorgio', 'Montegiorgio', 43.1298800, 13.5392500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83747, 'Montegiordano', 'Montegiordano', 'Montegiordano', 40.0430100, 16.5343900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83748, 'Monte Giberto', 'Monte Giberto', 'Monte Giberto', 43.0909200, 13.6313300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83749, 'Montegaldella', 'Montegaldella', 'Montegaldella', 45.4371700, 11.6702200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83750, 'Montegabbione', 'Montegabbione', 'Montegabbione', 42.9197300, 12.0921200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83751, 'Montefusco', 'Montefusco', 'Montefusco', 41.0369100, 14.8549800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83752, 'Montefredane', 'Montefredane', 'Montefredane', 40.9597800, 14.8137400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83753, 'Montefranco', 'Montefranco', 'Montefranco', 42.5983500, 12.7637600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83754, 'Montefortino', 'Montefortino', 'Montefortino,Монтефортино', 42.9435100, 13.3441700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83755, 'Monteforte Irpino', 'Monteforte Irpino', 'Monteforte Irpino', 40.9024600, 14.7440000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83756, 'Monteforte d''Alpone', 'Monteforte d''Alpone', 'Monteforte,Monteforte d''Alpone', 45.4201300, 11.2844600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83757, 'Monteforte Cilento', 'Monteforte Cilento', 'Monteforte,Monteforte Cilento', 40.3648100, 15.1948600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83758, 'Monteflavio', 'Monteflavio', '', 42.1093500, 12.8307600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83759, 'Montefiorino', 'Montefiorino', 'Montefiorino', 44.3538200, 10.6237500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83760, 'Montefiore dell''Aso', 'Montefiore dell''Aso', 'Montefiore dell''Aso', 43.0527600, 13.7551800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83761, 'Montefiore Conca', 'Montefiore Conca', 'Montefiore Conca', 43.8891600, 12.6114500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83762, 'Montefino', 'Montefino', 'Montefino', 42.5455100, 13.8847900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83763, 'Montefiascone', 'Montefiascone', 'Montefiascone,montefiasukone,モンテフィアスコーネ', 42.5425500, 12.0319200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83764, 'Monteferrante', 'Monteferrante', 'Monteferrante', 41.9539600, 14.3885600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83765, 'Montefano', 'Montefano', 'Montefano', 43.4098200, 13.4369000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83766, 'Montefalcone di Val Fortore', 'Montefalcone di Val Fortore', 'Montefalcone di Val Fortore', 41.3243000, 15.0089800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83767, 'Montefalcone nel Sannio', 'Montefalcone nel Sannio', '', 41.8666300, 14.6382300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83768, 'Montefalcone Appennino', 'Montefalcone Appennino', 'Montefalcone Appennino', 42.9900500, 13.4568800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83769, 'Montefalco', 'Montefalco', 'Montefalco', 42.8908400, 12.6482700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83770, 'Montefalcione', 'Montefalcione', 'Montefalcione', 40.9617300, 14.8831200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83771, 'Monte di Procida', 'Monte di Procida', 'Monte ''e Proceta,Monte di Procida,モンテ・ディ・プローチダ', 40.7980900, 14.0502300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83772, 'Montedinove', 'Montedinove', 'Montedinove', 42.9726200, 13.5897200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83773, 'Monte di Malo', 'Monte di Malo', 'Monte di Malo', 45.6601100, 11.3612700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83774, 'Montecosaro', 'Montecosaro', 'Montecosaro', 43.3161900, 13.6376200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83775, 'Montecorvino Rovella', 'Montecorvino Rovella', 'Montecorvino Rovella', 40.6918000, 14.9786200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83776, 'Montecorice', 'Montecorice', 'Montecorice', 40.2344400, 14.9850400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83777, 'Montecompatri', 'Montecompatri', 'Monte Compatri,モンテ・コンパトリ', 41.8089200, 12.7377800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83778, 'Montecilfone', 'Montecilfone', 'Montecilfone,Munxhfuni', 41.9016300, 14.8368000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83779, 'Monteciccardo', 'Monteciccardo', 'Monteciccardo', 43.8241500, 12.8034400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83780, 'Montechiarugolo', 'Montechiarugolo', 'Mons Clariculus,Montechiarugolo,Montek''jarugolo,Montekiarugolo,Montekijarugolo,Montekjarugolo,meng tai ji ya lu ge luo,montekiarugoro,mwntykyarwghwlw,Монтекиаруголо,Монтекијаруголо,Монтекьяруголо,Монтекяруголо,Մոնտեկիարուգոլո,مونتيكياروغولو,モンテキアルーゴロ,蒙泰基亚鲁戈洛', 44.6926100, 10.4212800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83781, 'Montechiaro d''Asti', 'Montechiaro d''Asti', 'Montechiaro d''Asti', 45.0070100, 8.1128600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83782, 'Monte Cerignone', 'Monte Cerignone', 'Monte Cerignone', 43.8398300, 12.4142700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83783, 'Montecelio', 'Montecelio', '', 42.0206700, 12.7435400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83784, 'Montecchio Maggiore-Alte Ceccato', 'Montecchio Maggiore-Alte Ceccato', 'Montecchio Maggiore', 45.5036900, 11.4120000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83785, 'Montecchio Emilia', 'Montecchio Emilia', 'Montecchio,Montecchio Emilia', 44.6993700, 10.4521100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83786, 'Montecchio', 'Montecchio', 'Montecchio', 42.6623400, 12.2880300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83787, 'Montecchia di Crosara', 'Montecchia di Crosara', 'Montecchia,Montecchia di Crosara', 45.4819000, 11.2543800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83788, 'Montecavolo', 'Montecavolo', '', 44.6327500, 10.5426400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83789, 'Montecatini-Terme', 'Montecatini-Terme', 'Montecatini Terme,Montecatini-Terme,モンテカティーニ・テルメ', 43.8815300, 10.7723000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83790, 'Montecatini Val di Cecina', 'Montecatini Val di Cecina', 'Montecatini,Montecatini Val di Cecina,Montecatini di Val di Cecina,モンテカティーニ・テルメ', 43.3923400, 10.7490400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83791, 'Montecastrilli', 'Montecastrilli', 'Montecastrilli', 42.6508700, 12.4881100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83792, 'Monte Castello di Vibio', 'Monte Castello di Vibio', 'Castrum Vibiense,Monte Castello di Vibio,Monte Kastelo di Vibio,Monte-Kastello-di-Vibio,Munti Casteddu di Vibiu,meng tai ka si tai luo di wei bi ao,montekaseutellodibibio,mwnty kastylw dy fybyw,Монте Кастело ди Вибио,Монте-Кастелло-ди-Вибио,Монте-Кастелло-ді-Вібіо,Մոնտե Կաստելո դի Վիբիո,مونتي كاستيلو دي فيبيو,モンテ・カステッロ・ディ・ヴィービオ,蒙泰卡斯泰洛迪维比奥,몬테카스텔로디비비오', 42.8404000, 12.3524000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83793, 'Montecassiano', 'Montecassiano', 'Montecassiano', 43.3651800, 13.4395000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83794, 'Montecarotto', 'Montecarotto', 'Montecarotto,montekarotto,モンテカロット', 43.5282800, 13.0665600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83795, 'Montecarlo', 'Montecarlo', 'Montecarlo', 43.8521800, 10.6674200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83796, 'Montecalvoli', 'Montecalvoli', 'Montecalvo,Montecalvoli', 43.6857600, 10.6650800, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83797, 'Montecalvo Irpino', 'Montecalvo Irpino', 'Montecalvo Irpino', 41.1961600, 15.0344600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83798, 'Montecalvo in Foglia', 'Montecalvo in Foglia', 'Montecalvo in Foglia', 43.8109900, 12.6316100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83799, 'Montebuono', 'Montebuono', 'Montebuono', 42.3677000, 12.5972100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83800, 'Montebruno', 'Montebruno', 'Montebrun,Montebruno', 44.5257700, 9.2483100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83801, 'Montebelluna', 'Montebelluna', 'Montebelluna,Монтебеллуна', 45.7750400, 12.0490400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83802, 'Montebello Vicentino', 'Montebello Vicentino', 'Montebello,Montebello Vicentino', 45.4591900, 11.3827200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83803, 'Montebello sul Sangro', 'Montebello sul Sangro', 'Buonanotte,Montebello sul Sangro', 41.9866300, 14.3240200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83804, 'Montebello di Bertona', 'Montebello di Bertona', 'Montebello di Bertona', 42.4168600, 13.8711900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83805, 'Montebello', 'Montebello', 'Montebello,Montebello della Battaglia', 44.9999400, 9.1026300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83806, 'Montazzoli', 'Montazzoli', 'Montazzoli', 41.9488700, 14.4306900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83807, 'Montasola', 'Montasola', 'Montasola', 42.3849500, 12.6812700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83808, 'Montaquila', 'Montaquila', 'Montaquila', 41.5650200, 14.1133300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83809, 'Montappone', 'Montappone', 'Montappone', 43.1361700, 13.4693200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83810, 'Montano Antilia', 'Montano Antilia', 'Montano Antilia', 40.1626400, 15.3631500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83811, 'Montanaso Lombardo', 'Montanaso Lombardo', '', 45.3352200, 9.4655100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83812, 'Montanaro', 'Montanaro', 'Montanaro,montanaro,モンタナーロ', 45.2327400, 7.8549200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83813, 'Montanara', 'Montanara', '', 45.1353100, 10.7187900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83814, 'Montalto Pavese', 'Montalto Pavese', 'Montalto,Montalto Pavese', 44.9780200, 9.2123200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83815, 'Montalto Ligure', 'Montalto Ligure', 'Montalto,Montalto Ligure', 43.9286800, 7.8449100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83816, 'Montalto Dora', 'Montalto Dora', 'Montalto Dora,モンタルト・ドーラ', 45.4899300, 7.8625300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83817, 'Montalto di Castro', 'Montalto di Castro', 'Montalto di Castro', 42.3498300, 11.6078800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83818, 'Montalto delle Marche', 'Montalto delle Marche', 'Montalto delle Marche', 42.9896400, 13.6082000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83819, 'Montalenghe', 'Montalenghe', 'Montalenghe,montarenge,モンタレンゲ', 45.3366600, 7.8379400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83820, 'Montale', 'Montale', '', 44.5692300, 10.9077100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83821, 'Montale', 'Montale', 'Montale,montare,モンターレ', 43.9348600, 11.0165500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83822, 'Montalcino', 'Montalcino', 'Mantal''chyna,Mons Ilcinus,Montal''chino,Montalchino,Montalcino,Muntalcinu,meng da qi nuo,montalchino,montaruchino,Мантальчына,Монталчино,Монтальчино,Մոնտալչինո,モンタルチーノ,蒙达奇诺,몬탈치노', 43.0539700, 11.4885300, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83823, 'Montalbano Jonico', 'Montalbano Jonico', 'Montalbano Jonico', 40.2859100, 16.5696000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83824, 'Montaione', 'Montaione', 'Montaione', 43.5514400, 10.9137100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83825, 'Montaguto', 'Montaguto', 'Montaguto', 41.2487300, 15.2484500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83826, 'Montagnana', 'Montagnana', 'Montagnana', 45.2322900, 11.4648300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83827, 'Montagna', 'Montagna', 'Mantanja,Montagna,Montan,Montan''ja,Montana,Montanja,Montanya,montanya,Мантаня,Монтанья,Монтаня,Մոնտանյա,モンターニャ', 46.3303300, 11.3002700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83828, 'Montagano', 'Montagano', 'Montagano', 41.6453800, 14.6740500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83829, 'Montà', 'Monta', 'Monta,Montà', 44.8147400, 7.9547700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83830, 'Monsummano Terme', 'Monsummano Terme', 'Monsumanno,Monsumanno Terme,Monsummano Terme', 43.8672000, 10.8129500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83831, 'Monselice', 'Monselice', 'Monselice', 45.2390000, 11.7498400, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83832, 'Monsano', 'Monsano', 'Monsano,monsano,モンサーノ', 43.5622100, 13.2518600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83833, 'Monsampolo del Tronto', 'Monsampolo del Tronto', 'Monsampolo del Tronto', 42.8974900, 13.7934900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83834, 'Monsampietro Morico', 'Monsampietro Morico', 'Monsampietro Morico', 43.0677500, 13.5556800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83835, 'Monopoli', 'Monopoli', 'Monopoli,monopori,Монополи,モノーポリ', 40.9491800, 17.2971700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83836, 'Monno', 'Monno', 'Monno,mon''no,モンノ', 46.2122500, 10.3401200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83837, 'Moniga del Garda', 'Moniga del Garda', '', 45.5266500, 10.5372800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83838, 'Monguelfo', 'Monguelfo', 'Monguelfo,Monguelfo-Tesido,Welsberg,Welsberg-Taisten,monguerufo=teshido,モングエルフォ＝テシド', 46.7577400, 12.1055600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83839, 'Mongrando', 'Mongrando', 'Mongrando', 45.5282600, 8.0071200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83840, 'Mongiardino Ligure', 'Mongiardino Ligure', 'Mongiardino,Mongiardino Ligure', 44.6344300, 9.0646200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83841, 'Monghidoro', 'Monghidoro', 'Monghidoro', 44.2232700, 11.3233100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83842, 'Mongardino', 'Mongardino', 'Mongardin,Mongardino', 44.8491500, 8.2190600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83843, 'Monforte d''Alba', 'Monforte d''Alba', 'Monforte,Monforte d''Alba', 44.5827100, 7.9679300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83844, 'Monfalcone', 'Monfalcone', 'Monfal''kone,Monfalcon,Monfalcone,monfarukone,Монфальконе,モンファルコーネ', 45.8046300, 13.5329200, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83845, 'Monesiglio', 'Monesiglio', 'Monesiglio', 44.4655000, 8.1191500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83846, 'Moneglia', 'Moneglia', 'Monegia,Moneglia', 44.2390500, 9.4908100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83847, 'Mondragone', 'Mondragone', 'Mondragone,Mundragone', 41.1139900, 13.8915700, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83848, 'Mondovì', 'Mondovi', 'El Mondvi,Mondovi,Mondovì,mondovu~i,Ël Mondvì,Мондови,モンドヴィ', 44.3960300, 7.8176400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83849, 'Mondolfo', 'Mondolfo', 'Mondolfo', 43.7452900, 13.1022900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83850, 'Mondavio', 'Mondavio', 'Mondavio', 43.6746800, 12.9660100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83851, 'Moncucco Torinese', 'Moncucco Torinese', 'Moncucco Torinese', 45.0673800, 7.9324600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83852, 'Monclassico', 'Monclassico', 'Monclassico,monkurasshiko,モンクラッシコ', 46.3341000, 10.8860400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83853, 'Monchio delle Corti', 'Monchio delle Corti', 'Monchio delle Corti', 44.4117200, 10.1237000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83854, 'Monchiero Borgonuovo', 'Monchiero Borgonuovo', 'Monchiero', 44.5705400, 7.9202400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83855, 'Moncalvo', 'Moncalvo', 'Moncalv,Moncalvo', 45.0505700, 8.2627700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83856, 'Moncalieri', 'Moncalieri', 'Moncale,Moncalieri,Moncalé,monkarieri,モンカリエーリ', 44.9994000, 7.6823600, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83857, 'Monastier di Treviso', 'Monastier di Treviso', 'Monastier di Treviso', 45.6577800, 12.4175000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83858, 'Monasterolo del Castello', 'Monasterolo del Castello', '', 45.7631900, 9.9316600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83859, 'Monacilioni', 'Monacilioni', 'Monacilioni', 41.6107700, 14.8100000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83860, 'Mompeo', 'Mompeo', 'Mompeo', 42.2478000, 12.7513000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83861, 'Momo', 'Momo', 'Momo,momo,モーモ', 45.5742400, 8.5539000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83862, 'Mombaroccio', 'Mombaroccio', 'Mombaroccio', 43.7950600, 12.8547600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83863, 'Mombaldone', 'Mombaldone', 'Mombaldone', 44.5702500, 8.3330200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83864, 'Molveno', 'Molveno', 'Molveno,moruvu~eno,モルヴェーノ', 46.1423800, 10.9630000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83865, 'Molteno', 'Molteno', 'Mol''teno,Molteno,Moltenum,Multee,mo er tai nuo,moruteno,Мольтено,Մոլտենո,モルテーノ,莫尔泰诺', 45.7781900, 9.3038600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83866, 'Mollia', 'Mollia', 'Mollia', 45.8166700, 8.0303100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83867, 'Moliterno', 'Moliterno', '', 40.2439400, 15.8654400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83868, 'Molise', 'Molise', 'Molise,morize,モリーゼ', 41.6314700, 14.4925200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83869, 'Molino del Piano', 'Molino del Piano', 'Molin del Piano,Molino del Piano,Mulino del Piano', 43.8109800, 11.3999200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83870, 'Molino del Pallone', 'Molino del Pallone', '', 44.1002800, 10.9613500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83871, 'Mühlen in Taufers', 'Muehlen in Taufers', 'Molini di Tures,Muehlen in Taufers,Mühlen in Taufers', 46.8992600, 11.9431700, 'IT', '2016-01-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83872, 'Molini di Triora', 'Molini di Triora', 'Molina di Triora,Molini di Triora', 43.9890500, 7.7746300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83873, 'Molini', 'Molini', '', 43.9259400, 7.9383500, 'IT', '2017-01-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83874, 'Molinella', 'Molinella', 'Molinella', 44.6175800, 11.6671900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83875, 'Molinara', 'Molinara', 'Molinara,Molinaria,mo li na la,mollinala,morinara,Молинара,Молінара,Մոլինարա,モリナーラ,莫利纳拉,몰리나라', 41.2972800, 14.9086700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83876, 'Molina di Ledro', 'Molina di Ledro', 'Malina-dzi-Ledra,Molina,Molina de Ledro,Molina di Ledro,Molina-di-Ledro,Mołina de Łedro,Mulina de Leder,Mulìna de Léder,mo li na di lai de luo,Маліна-дзі-Ледра,Молина-ди-Ледро,Моліна-ді-Ледро,Մոլինա դի Լեդրո,モリーナ・ディ・レードロ,莫利纳迪莱德罗', 45.8709500, 10.7740800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83877, 'Molina Aterno', 'Molina Aterno', 'Molina Aterno', 42.1490300, 13.7354000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83878, 'Molfetta', 'Molfetta', 'Mol''fetta,Molfetta,Мольфетта', 41.2003600, 16.5990500, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83879, 'Molazzana', 'Molazzana', 'Molazzana', 44.0717500, 10.4178000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83880, 'Molare', 'Molare', 'Molare', 44.6180700, 8.5996000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83881, 'Mola di Bari', 'Mola di Bari', 'Mola di Bari', 41.0599700, 17.0900100, 'IT', '2016-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83882, 'Moio della Civitella-Pellare', 'Moio della Civitella-Pellare', 'Moio della Civitella', 40.2471000, 15.2688600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83883, 'Moimacco', 'Moimacco', 'Moimacco,Monnacco,Muimans', 46.0914500, 13.3727000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83884, 'Moie', 'Moie', 'Moie,Moie di Maiolati', 43.5036600, 13.1327500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83885, 'Moiano', 'Moiano', 'Moiano', 41.0796800, 14.5443100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83886, 'Mogliano Veneto', 'Mogliano Veneto', 'Mogliano,Mogliano Veneto,モリアーノ・ヴェーネト', 45.5559400, 12.2429400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83887, 'Mogliano', 'Mogliano', 'Mogliano', 43.1875000, 13.4912300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83888, 'Moglia', 'Moglia', 'Moglia', 44.9356100, 10.9146300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83889, 'Moggio Udinese', 'Moggio Udinese', 'Moggio Udinese,Muec', 46.4108300, 13.2013900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83890, 'Moggio', 'Moggio', 'Moggio', 45.9323900, 9.4862300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83891, 'Moena', 'Moena', 'Moena,moena,Моена,モエーナ', 46.3765500, 11.6594100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83892, 'Modugno', 'Modugno', 'Modugno,Modun''o,Модуньо', 41.0843300, 16.7834200, 'IT', '2015-06-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83893, 'Modolo', 'Modolo', 'Modolo', 40.2753500, 8.5300200, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83894, 'Modigliana', 'Modigliana', 'Modigliana,Modil''jana,Modiliana,Modiljana,Mutiliana,mo di li ya na,modiriana,mwdylyana,Модильяна,Модиляна,Модільяна,Մոդիլիանա,موديليانا,モディリアーナ,莫迪利亚纳', 44.1595400, 11.7928600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83895, 'Modena', 'Modena', 'Modena,Modene,Modna,Modène,Mutina,Mòdena,Mòdna,Módena,ZMO,modena,mwdyna,Модена,مودينا,モデナ', 44.6478300, 10.9253900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83896, 'Missanello', 'Missanello', 'Missanello', 40.2831100, 16.1665000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83897, 'Missaglia', 'Missaglia', '', 45.7065600, 9.3347100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83898, 'Misinto', 'Misinto', 'Misinto,mijinto,ミジント', 45.6614200, 9.0812900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83899, 'Misano di Gera d''Adda', 'Misano di Gera d''Adda', '', 45.4694600, 9.6212900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83900, 'Misano Adriatico', 'Misano Adriatico', 'Misano,Misano Adriatico,Misano in Villa Vittoria', 43.9771400, 12.6980500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83901, 'Mirano', 'Mirano', 'Mirano,mirano,Мирано,ミラーノ', 45.4945800, 12.1077500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83902, 'Mirandola', 'Mirandola', 'Mirandola,Мирандола', 44.8851500, 11.0690200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83903, 'Miranda', 'Miranda', '', 41.6443400, 14.2464300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83904, 'Miradolo Terme', 'Miradolo Terme', 'Miradolo,Miradolo Terme,Terme di Miradolo', 45.1709400, 9.4444200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83905, 'Mirabello Sannitico', 'Mirabello Sannitico', 'Mirabello Sannitice,Mirabello Sannitico', 41.5162800, 14.6731500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83906, 'Mirabello Monferrato', 'Mirabello Monferrato', 'Mirabel,Mirabello,Mirabello Monferrato,Mirabèl', 45.0349600, 8.5238500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83907, 'Mirabello', 'Mirabello', 'Mirabello', 44.8229500, 11.4566900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83908, 'Mirabella Eclano', 'Mirabella Eclano', 'Mirabella Eclano', 41.0449600, 15.0002200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83909, 'Mira Taglio', 'Mira Taglio', 'Mira,mira,Мира,ミーラ', 45.4346000, 12.1294200, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83910, 'Minucciano', 'Minucciano', 'Minucciano', 44.1700000, 10.2080700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83911, 'Minturno', 'Minturno', 'Minturno,minto~uruno,ミントゥルノ', 41.2629400, 13.7458300, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83912, 'Minori', 'Minori', 'Minori,Minure,Минори', 40.6503000, 14.6268400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83913, 'Minervino Murge', 'Minervino Murge', '', 41.0826400, 16.0786100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83914, 'Minervino di Lecce', 'Minervino di Lecce', 'Minervino di Lecce', 40.0902500, 18.4213900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83915, 'Minerbio', 'Minerbio', 'Minerbio', 44.6181100, 11.4725700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83916, 'Minerbe', 'Minerbe', 'Minerbe', 45.2319800, 11.3524900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83917, 'Millesimo', 'Millesimo', 'Merexo,Millesimo,mirrejimo,ミッレージモ', 44.3669500, 8.2035400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83918, 'Milis', 'Milis', 'Milis', 40.0504500, 8.6370200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83919, 'Milan', 'Milan', 'Lungsod ng Milano,MIL,Mailand,Mediolan,Mediolanum,Mila,Milaan,Milan,Milana,Milanas,Milano,Milanu,Milao,Milà,Milán,Miláno,Milánó,Milão,Milāna,Mílanó,Mилан,mi lan,milan,milani,millano,mirano,mylan,mylanw,Милан,Милано,Мілан,מילאנו,مىلان,ميلانو,மிலன்,มิลาน,მილანი,ミラノ,米蘭,밀라노', 45.4642700, 9.1895100, 'IT', '2017-04-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83920, 'Milanere', 'Milanere', '', 45.1043600, 7.4337300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83921, 'Mignano Monte Lungo', 'Mignano Monte Lungo', 'Mignano,Mignano Monte Lungo', 41.4059200, 13.9855200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83922, 'Mignanego', 'Mignanego', 'Mignanego', 44.5274800, 8.9141200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83923, 'Miglionico', 'Miglionico', 'Miglionico', 40.5676300, 16.4996400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83924, 'Migliaro', 'Migliaro', 'Migliaro,Mil''jaro,Miliarium,Miliaro,mi li ya luo,miriaro,mylyarw,Мильяро,Мільяро,Միլիարո,ميليارو,ミリアーロ,米利亚罗', 44.7991600, 11.9744000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83925, 'Migliarino', 'Migliarino', 'Migliarino,Mil''jarino,Miliarinium,Miliarino,mi li ya li nuo,miriarino,mylyarynw,Мильярино,Мільярино,Միլիարինո,ميليارينو,ミリアリーノ,米利亚里诺', 44.7699300, 11.9330400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83926, 'Migliarino', 'Migliarino', 'Migliarino Pisano', 43.7658900, 10.3395100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83927, 'Migliarina', 'Migliarina', 'Migliarina,Migliorina', 44.8104200, 10.8360000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83928, 'Miglianico', 'Miglianico', 'Miglianico', 42.3577300, 14.2917900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83929, 'Micigliano', 'Micigliano', 'Micigliano', 42.4520300, 13.0531800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83930, 'Miazzina', 'Miazzina', '', 45.9756600, 8.5230800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83931, 'Miane', 'Miane', 'Miane', 45.9434100, 12.0924600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83932, 'Mezzomerico', 'Mezzomerico', 'Mezzomerico', 45.6199100, 8.6061600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83933, 'Mezzolombardo', 'Mezzolombardo', 'Meccolombardo,Medzolombardo,Mejolombardo,Metalongobardica,Mezzolombardo,mei zuo long ba er duo,mettsu~oronbarudo,Медзоломбардо,Меццоломбардо,Մեձոլոմբարդո,メッツォロンバルド,梅佐隆巴尔多', 46.2077400, 11.0963600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83934, 'Mezzoldo', 'Mezzoldo', 'Berere,Mezzoldo', 46.0125900, 9.6655500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83935, 'Mezzolara', 'Mezzolara', 'Mezzolara,Mezzolaro', 44.5891700, 11.5649200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83936, 'Mezzogoro', 'Mezzogoro', '', 44.9025600, 12.0992500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83937, 'Mezzocorona', 'Mezzocorona', 'Mezzocorona,mettsu~okorona,メッツォコローナ', 46.2115900, 11.1225300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83938, 'Mezzano Inferiore', 'Mezzano Inferiore', '', 44.9129100, 10.4583800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83939, 'Mezzano', 'Mezzano', 'Mezzano,mettsu~ano,メッツァーノ', 46.1539300, 11.8087600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83940, 'Mezzano', 'Mezzano', '', 44.4662500, 12.0863200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83941, 'Mezzanino', 'Mezzanino', 'Mezzanino', 45.1248900, 9.2049700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83942, 'Mezzanego', 'Mezzanego', 'Mezanego,Mezzanego,Mezànego', 44.3827500, 9.3766700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83943, 'Mezzana Rabattone', 'Mezzana Rabattone', 'Mezzana Rabattone', 45.0948800, 9.0324700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83944, 'Mezzana Bigli', 'Mezzana Bigli', 'Mezzana Bigli', 45.0598800, 8.8472800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83945, 'Mezzana', 'Mezzana', 'Mezzana,Mezzana in Val di Sole,mettsu~ana,メッツァーナ', 46.3167100, 10.8000700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83946, 'Meta', 'Meta', '', 40.6408100, 14.4158200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83947, 'Mestrino', 'Mestrino', 'Mestrino', 45.4413900, 11.7593100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83948, 'Mestre', 'Mestre', 'Mestracum,Mestre,Mestre bei Venedig,mei si te lei,mesutore,mstrh,Местре,מסטרה,メストレ,梅斯特雷', 45.4916700, 12.2453800, 'IT', '2016-09-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83949, 'Mesola', 'Mesola', 'Mesola,Mesula,Mezola,mei suo la,mezora,myzwla,Мезола,ميزولا,メゾーラ,梅索拉', 44.9183100, 12.2312100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83950, 'Mese', 'Mese', 'Mese', 46.3036000, 9.3776900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83951, 'Mesagne', 'Mesagne', 'Mesagne', 40.5585100, 17.8077400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83952, 'Merlara', 'Merlara', 'Merlara,Merlaria,mei er la la,merurara,Мерлара,Մերլարա,メルラーラ,梅尔拉拉', 45.1670000, 11.4450400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83953, 'Merine', 'Merine', '', 40.3341800, 18.2238300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83954, 'Mergozzo', 'Mergozzo', 'Mergozzo', 45.9622900, 8.4540300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83955, 'Mergo', 'Mergo', 'Mergo,merugo,メルゴ', 43.4735000, 13.0350900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83956, 'Mereto di Tomba', 'Mereto di Tomba', 'Meret di Tombe,Mereto,Mereto di Tomba,Meretto,Meretto di Tomba', 46.0512800, 13.0443200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83957, 'Mercogliano', 'Mercogliano', 'Mercogliano', 40.9215700, 14.7449100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83958, 'Mercenasco', 'Mercenasco', 'Mercenasco,Mersnasch,meruchenasuko,メルチェナスコ', 45.3600200, 7.8801300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83959, 'Mercato Vecchio', 'Mercato Vecchio', '', 43.8042100, 12.3765300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83960, 'Mercato Saraceno', 'Mercato Saraceno', 'Mercato Saraceno,Mercato Sarareno', 43.9627400, 12.1963800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83961, 'Mercato San Severino', 'Mercato San Severino', 'Mercato San Severino,San Severino Rota', 40.7846800, 14.7536900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83962, 'Mercato', 'Mercato', '', 40.7161200, 14.9401000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83963, 'Mercatello sul Metauro', 'Mercatello sul Metauro', 'Mercatello,Mercatello sul Metauro', 43.6467700, 12.3361900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83964, 'Mercatale', 'Mercatale', 'Mercatale,Mercatale di Sassocorvato', 43.7827600, 12.4847800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83965, 'Mercallo', 'Mercallo', 'Marcallum,Mercall,Mercallo di Sassi,Merkallo,Merkalo,mei er ka luo,merukarro,Меркалло,Մերկալո,メルカッロ,梅尔卡洛', 45.7479100, 8.6699800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83966, 'Merate', 'Merate', 'Merate,merate,メラーテ', 45.6885800, 9.4208000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83967, 'Merano', 'Merano', 'Meran,Merano,Merona,merano,Мерано,メラーノ', 46.6681700, 11.1595300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83968, 'Meolo', 'Meolo', 'Meolo,meoro,メーオロ', 45.6197000, 12.4523600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83969, 'Mentana', 'Mentana', 'Mentana,mentana,メンターナ', 42.0353900, 12.6441300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83970, 'Ruffrè', 'Ruffre', '', 46.4148100, 11.1777700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83971, 'Menconico', 'Menconico', 'Menconico', 44.7965600, 9.2794600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83972, 'Menaggio', 'Menaggio', 'Menaggio', 46.0207500, 9.2390700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83973, 'Melzo', 'Melzo', 'Melzo,merutsu~o,メルツォ', 45.4981000, 9.4204300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83974, 'Meltina', 'Meltina', 'Mel''cina,Mel''tina,Meltina,Moelten,Moelten bei Meran,Moeltina,Mölten,Mölten bei Meran,mei er di na,merutina,Мелтина,Мельтина,Мельтіна,Мельціна,Մելտինա,メルティナ,梅尔蒂纳', 46.5874400, 11.2548700, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83975, 'Melpignano', 'Melpignano', 'Melpignano', 40.1562400, 18.2919400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83976, 'Mello', 'Mello', 'Mello', 46.1549000, 9.5473400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83977, 'Melle', 'Melle', 'Melle', 44.5619700, 7.3194800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83978, 'Melizzano', 'Melizzano', 'Melizzano', 41.1618100, 14.5055400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83979, 'Melito Irpino', 'Melito Irpino', 'Melito Irpino', 41.1031200, 15.0523500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83980, 'Melito di Napoli', 'Melito di Napoli', 'Melito ''e Napule,Melito di Napoli,メリート・ディ・ナーポリ', 40.9194800, 14.2310400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83981, 'Melfi', 'Melfi', 'Melfi,Melphi,Μέλφι', 40.9957100, 15.6557800, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83982, 'Roccasecca Stazione', 'Roccasecca Stazione', 'Melfa,Torre di Melfa', 41.5333300, 13.6500000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83983, 'Meleti', 'Meleti', 'Meleti,mereti,メレーティ', 45.1196700, 9.8356800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83984, 'Melendugno', 'Melendugno', 'Melendugno', 40.2725200, 18.3379800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83985, 'Melegnano', 'Melegnano', 'Marignan,Marignano,Melegnano,merenyano,メレニャーノ', 45.3578100, 9.3236000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83986, 'Meldola', 'Meldola', 'Meldola,merudora,メルドラ', 44.1277500, 12.0626000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83987, 'Melara', 'Melara', 'Melara', 45.0642100, 11.2011700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83988, 'Mel', 'Mel', 'Mel', 46.0637900, 12.0900000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83989, 'Meina', 'Meina', 'Meina,meina,メイナ', 45.7912300, 8.5376100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83990, 'Megliadino San Vitale', 'Megliadino San Vitale', 'Megliadino San Vitale,San Vitale', 45.1957700, 11.5240200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83991, 'Meggiano', 'Meggiano', '', 42.7547400, 12.8637900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83992, 'Meduno', 'Meduno', 'Meduno,Midun', 46.2151800, 12.7993200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83993, 'Medolla', 'Medolla', 'Medolla', 44.8466700, 11.0676000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83994, 'Medole', 'Medole', 'Medole', 45.3258800, 10.5135700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83995, 'Medolago', 'Medolago', 'Medolago', 45.6712900, 9.4980700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83996, 'Mediis', 'Mediis', '', 46.4033600, 12.8234100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83997, 'Medicina-Buda', 'Medicina-Buda', 'Medicina', 44.4786700, 11.6381200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83998, 'Medesano', 'Medesano', 'Medesano', 44.7582400, 10.1379400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(83999, 'Mede', 'Mede', 'Mede,mede,メーデ', 45.0967800, 8.7367900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84000, 'Meda', 'Meda', 'Med,Meda,meda,Мед,メーダ', 45.6612100, 9.1533700, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84001, 'Mazzo di Valtellina', 'Mazzo di Valtellina', 'Mazzo,Mazzo di Valtellina', 46.2573600, 10.2553400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84002, 'Mazzin', 'Mazzin', 'Mazin,Mazzin,Mazzin di Fassa,mattsu~in,マッツィーン', 46.4574200, 11.7001800, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84003, 'Mazze', 'Mazze', 'Masse,Massè,Mazze,Mazzè,mattsu~e,マッツェ', 45.3002500, 7.9327200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84004, 'Mazzano Romano', 'Mazzano Romano', 'Mazzano Romano,マッツァーノ・ロマーノ', 42.2059700, 12.3955400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84005, 'Mattinata', 'Mattinata', 'Matenete,Matenéte,Matinata,Mattinata', 41.7111200, 16.0508700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84006, 'Mattarello', 'Mattarello', '', 46.0086500, 11.1298400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84007, 'Matrice', 'Matrice', 'Matrice', 41.6187800, 14.7097700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84008, 'Matino', 'Matino', 'Matino', 40.0308300, 18.1363000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84009, 'Mathi', 'Mathi', 'Mathi,Mati,mati,マーティ', 45.2551500, 7.5420200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84010, 'Matera', 'Matera', 'Matera,Materia,matera,Матера,マテーラ', 40.6659900, 16.6046300, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84011, 'Matelica', 'Matelica', 'Matelica', 43.2578800, 13.0075000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84012, 'Massimeno', 'Massimeno', 'Massimeno,masshimeno,マッシメーノ', 46.1407000, 10.7731700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84013, 'Massignano', 'Massignano', 'Massignano', 43.0506200, 13.7979800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84014, 'Masserano', 'Masserano', 'Masserano', 45.5953600, 8.2219700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84015, 'Massenzatico', 'Massenzatico', '', 44.7347700, 10.6973600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84016, 'Massello', 'Massello', 'Massel,Massello,masserro,マッセッロ', 44.9587400, 7.0567100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84017, 'Massazza', 'Massazza', 'Massazza', 45.4918300, 8.1649500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84018, 'Massarosa', 'Massarosa', 'Masaroza,Massa Grausa,Massarosa,Massarose,Massaroza,ma sa luo sa,masarwza,massaroza,Масароза,Массароза,Массаросе,Մասարոզա,ماساروزا,マッサローザ,马萨罗萨', 43.8663800, 10.3445800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84019, 'Massa Martana', 'Massa Martana', 'Martanae Tudertinorum,Masa Martana,Massa Martana,Massa-Martana,ma sa ma er ta na,masa martana,masamaleutana,Маса Мартана,Масса-Мартана,Մասա Մարտանա,ماسا مارتانا,マッサ・マルターナ,马萨马尔塔纳,마사마르타나', 42.7731200, 12.5257900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84020, 'Massa Marittima', 'Massa Marittima', 'Massa Marittima', 43.0477900, 10.8929300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84021, 'Massa Lubrense', 'Massa Lubrense', '', 40.6093700, 14.3720200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84022, 'Massa Lombarda', 'Massa Lombarda', 'Massa Lombarda,マッサ・ロンバルダ', 44.4470300, 11.8209500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84023, 'Massafra', 'Massafra', 'Massafra', 40.5861800, 17.1163500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84024, 'Massa Fiscaglia', 'Massa Fiscaglia', 'Massa Fiscaglia', 44.8098300, 12.0074600, 'IT', '2014-04-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84025, 'Massa Fermana', 'Massa Fermana', 'Massa Fermana', 43.1469100, 13.4759700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84026, 'Massa d''Albe-Corona', 'Massa d''Albe-Corona', 'Massa d''Albe', 42.1072300, 13.3942900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84027, 'Massa', 'Massa', 'Massa,massa,Масса,マッサ', 44.0354100, 10.1392700, 'IT', '2015-08-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84028, 'Massa', 'Massa', 'Massa e Cozzile', 43.9092500, 10.7444100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84029, 'Massa', 'Massa', '', 43.1880300, 12.9314200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84030, 'Masone', 'Masone', 'Mason,Masone', 44.5016200, 8.7189100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84031, 'Maslianico', 'Maslianico', 'Marsilianigum,Masl''janiko,Maslianich,Mazlianiko,ma si li ya ni ke,mazurianiko,Мазлианико,Мазліаніко,Масльянико,Մազլիանիկո,マズリアーニコ,马斯利亚尼科', 45.8430100, 9.0483600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84032, 'Masi-Torello', 'Masi-Torello', 'Masi Torello', 44.7945800, 11.8018200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84033, 'Maserà di Padova', 'Masera di Padova', 'Masera,Masera di Padova,Maserà,Maserà di Padova', 45.3182700, 11.8654300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84034, 'Masera', 'Masera', 'Masera', 46.1388800, 8.3252600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84035, 'Maser', 'Maser', '', 45.8074000, 11.9750000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84036, 'Maschito', 'Maschito', 'Maschito,Mashqiti', 40.9089200, 15.8294600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84037, 'Marzio', 'Marzio', '', 45.9381800, 8.8581300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84038, 'Marzano di Nola', 'Marzano di Nola', 'Marzano di Nola', 40.9014100, 14.5835900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84039, 'Marzano Appio', 'Marzano', '', 41.3177200, 14.0450200, 'IT', '1993-12-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84040, 'Marzabotto', 'Marzabotto', 'Marzabot,Marzabotto,Marzabòt', 44.3429700, 11.2059300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84041, 'Maruggio', 'Maruggio', 'Maruggio', 40.3205400, 17.5705200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84042, 'Martis', 'Martis', 'Martis', 40.7780400, 8.8089700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84043, 'Martinsicuro', 'Martinsicuro', 'Martinsicuro', 42.8803100, 13.9132600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84044, 'Martiniana Po', 'Martiniana Po', 'Martiniana Po', 44.6272300, 7.3628200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84045, 'Martinengo', 'Martinengo', 'Martinengo', 45.5721600, 9.7675000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84046, 'Urbe', 'Urbe', 'L''Orba,Urbe,urube,ウルベ', 44.4871400, 8.5861500, 'IT', '2012-03-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84047, 'Martina Franca', 'Martina Franca', 'Martina Franca', 40.7035500, 17.3381400, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84048, 'Martignano', 'Martignano', 'Martignana,Martignano', 40.2382100, 18.2560200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84049, 'Martignacco', 'Martignacco', 'Martigna,Martignacco', 46.0931300, 13.1397300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84050, 'Marti', 'Marti', '', 43.6545300, 10.7405800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84051, 'Martellago', 'Martellago', 'Martellago,maruterrago,マルテッラーゴ', 45.5438300, 12.1636300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84052, 'La Martella', 'La Martella', 'La Martella,Martella', 40.6625100, 16.5355100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84053, 'Martano', 'Martano', 'Martana,Martano', 40.2020500, 18.3019300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84054, 'Marta', 'Marta', 'Marta,maruta,マルタ', 42.5331800, 11.9242300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84055, 'Marsicovetere', 'Marsicovetere', '', 40.3759100, 15.8256900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84056, 'Marsico Nuovo', 'Marsico Nuovo', 'Marsico Nuovo', 40.4235900, 15.7346200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84057, 'Marsia', 'Marsia', '', 42.8603000, 13.4761900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84058, 'Marsciano', 'Marsciano', 'Marsciano', 42.9209300, 12.3506600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84059, 'Marsaglia', 'Marsaglia', '', 44.7122800, 9.3835300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84060, 'Marradi', 'Marradi', 'Marradi', 44.0735300, 11.6109200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84061, 'Marotta', 'Marotta', '', 43.7639700, 13.1477200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84062, 'Marostica', 'Marostica', 'Marostica,marosutika,マロースティカ', 45.7454100, 11.6623700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84063, 'Marone', 'Marone', 'Marone,marone,マローネ', 45.7371900, 10.0957900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84064, 'Marola', 'Marola', '', 45.5399400, 11.6259300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84065, 'Marnate', 'Marnate', 'Marnate,marunate,マルナーテ', 45.6285500, 8.9091600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84066, 'Marmirolo', 'Marmirolo', 'Marmirolo,marumiroro,マルミローロ', 45.2192800, 10.7560900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84067, 'Marliana', 'Marliana', 'Marliana', 43.9338500, 10.7702100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84068, 'Marlengo', 'Marlengo', 'Marlengo,Marling,Marnea,ma er lun ge,marurengo,Марленго,Մարլենգո,マルレンゴ,马尔伦戈', 46.6526200, 11.1454600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84069, 'Mariotto', 'Mariotto', 'Mariotta,Mariotto', 41.0502800, 16.5614200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84070, 'Moriondo Torinese', 'Moriondo Torinese', '', 45.0385300, 7.9408600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84071, 'Marino', 'Marino', 'Castromenio,Marino,marino,Марино,マリーノ', 41.7698400, 12.6591700, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84072, 'Marina di San Vito', 'Marina di San Vito', 'Marina San Vito,Marina di San Vito', 42.3051400, 14.4484400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84073, 'Marina di Ravenna', 'Marina di Ravenna', '', 44.4862500, 12.2808700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84074, 'Marina di Pisa', 'Marina di Pisa', 'Marina de Pisa,Marina di Pisa,Marina-di-Piza,Pisae Maris,Марина-ди-Пиза', 43.6666700, 10.2666700, 'IT', '2013-05-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84075, 'Marina di Montemarciano', 'Marina di Montemarciano', 'Case Bruciate,Marina di Montemarciano', 43.6506300, 13.3364000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84076, 'Marina di Grosseto', 'Marina di Grosseto', 'Marina di Grosseto', 42.7190800, 10.9813800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84077, 'Marina di Carrara', 'Marina di Carrara', '', 44.0383700, 10.0414200, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84078, 'Marina di Campo', 'Marina di Campo', 'Campo', 42.7426000, 10.2342800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84079, 'Marina di Andora', 'Marina di Andora', 'Marina di Andora', 43.9535300, 8.1546000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84080, 'Marigliano', 'Marigliano', 'Marigliano,Maril''jano,maririano,Марильяно,マリリアーノ', 40.9248000, 14.4561200, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84081, 'Mariglianella', 'Mariglianella', 'Mariglianella,maririanerra,マリリアネッラ', 40.9296200, 14.4370300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84082, 'Mariano del Friuli', 'Mariano del Friuli', 'Marian,Mariano,Mariano del Friuli,Мариано дел Фриули', 45.9150900, 13.4594700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84083, 'Mariano Comense', 'Mariano Comense', 'Marian,Mariano,Mariano Comense,Mariàn', 45.6965100, 9.1818000, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84084, 'Margherita di Savoia', 'Margherita di Savoia', '', 41.3717400, 16.1527500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84085, 'Margarita', 'Margarita', 'Margarita,marugarita,マルガリータ', 44.4034300, 7.6849300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84086, 'Marene', 'Marene', 'Marene', 44.6611300, 7.7343600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84087, 'Mardimago', 'Mardimago', '', 45.1070300, 11.8374400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84088, 'Marcon-Gaggio-Colmello', 'Marcon-Gaggio-Colmello', 'Marcon,marukon,マルコーン', 45.5644400, 12.2988900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84089, 'Marco', 'Marco', '', 45.8425800, 11.0092500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84090, 'Marcignana', 'Marcignana', '', 43.7183000, 10.8843600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84091, 'Marciano della Chiana', 'Marciano della Chiana', '', 43.3049400, 11.7864400, 'IT', '2013-12-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84092, 'Marcianise', 'Marcianise', 'Marchanize,Marcianise,Марчанизе', 41.0306400, 14.2986800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84093, 'Marciana Marina', 'Marciana Marina', 'Marchana Marina,Marchana-Marina,Marchiana-Marina,Marchyjana-Maryna,Marciana Marina,Marciana Maris,ma er qia na ma li na,maleuchanamalina,Марчана Марина,Марчана-Марина,Марчиана-Марина,Марчыяна-Марына,Марчіана-Марина,Մարչիանա Մարինա,マルチャーナ・マリーナ,马尔恰纳马里纳,마르차나마리나', 42.8025600, 10.1948800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84094, 'Marciana', 'Marciana', 'Marciana,maruchana,マルチャーナ', 42.7930100, 10.1687000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84095, 'Marcheno', 'Marcheno', 'Marcheno,marukeno,マルケーノ', 45.7064900, 10.2144900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84096, 'Marcetelli', 'Marcetelli', 'Marcetelli', 42.2266300, 13.0458900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84097, 'Marcellina', 'Marcellina', 'Marcellina,marucherrina,マルチェッリーナ', 42.0243600, 12.8044500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84098, 'Marcaria', 'Marcaria', 'Marcaria', 45.1222500, 10.5327800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84099, 'Marcallo', 'Marcallo', 'Marcallo con Casone,マルカッロ・コン・カゾーネ', 45.4832700, 8.8719400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84100, 'Marano Vicentino', 'Marano Vicentino', 'Marano,Marano Vicentino', 45.6960000, 11.4323700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84101, 'Marano Ticino', 'Marano Ticino', 'Marano Ticino', 45.6278300, 8.6315500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84102, 'Marano sul Panaro', 'Marano sul Panaro', 'Marano,Marano sul Panaro', 44.4592400, 10.9687900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84103, 'Marano Lagunare', 'Marano Lagunare', 'Maran,Marano Lagunare', 45.7635300, 13.1673300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84104, 'Maranola-Trivio', 'Maranola-Trivio', '', 41.2852200, 13.6277700, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84105, 'Marano Equo', 'Marano Equo', 'Marano,Marano Equo,マラーノ・エークオ', 41.9953500, 13.0150100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84106, 'Marano di Valpolicella', 'Marano di Valpolicella', 'Marano di Valpolicella', 45.5563700, 10.9162200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84107, 'Marano di Napoli', 'Marano di Napoli', 'Marano,Marano ''e Napule,Marano di Napoli,マラーノ・ディ・ナーポリ', 40.8971000, 14.1882400, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84108, 'Maranello', 'Maranello', 'Maranello,Maranelo,maranerro,Маранелло,Маранело,マラネッロ', 44.5310100, 10.8688800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84109, 'Mara', 'Mara', 'Mara', 40.4101900, 8.6366400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84110, 'Mapello', 'Mapello', 'Mapello', 45.7125900, 9.5544300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84111, 'Manziana', 'Manziana', 'Manziana,mantsu~iana,マンツィアーナ', 42.1299800, 12.1253700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84112, 'Manzano', 'Manzano', 'Manzan,Manzano', 45.9884300, 13.3767400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84113, 'Mantova', 'Mantova', 'Mantoue,Mantova,Mantova Seng,Mantova Séng,Mantova ili,Mantova provints,Mantovan maakunta,Mantua,Mantua megye,Mantuako probintzia,Mantuja,Mantujas province,Mantujos provincija,Mantuya,Mântua,Provinca e Mantoves,Provinca e Mantovës,Province de Mantoue,Province o Mantua,Province of Mantua,Provincia Mantova,Provincia Mantuana,Provincia de Mantoa,Provincia de Mantua,Provincia di Mantova,Provincia ed Mantoa,Provincia ëd Màntoa,Provincie Mantova,Provinco Mantova,Provins Mantova,Provinsen Mantova,Provinsi Mantova,Provinsia de Mantova,Provinz Mantua,Proviñs Mantova,Província de Màntoa,Província de Màntua,Prowincja Mantua,Pruvincia de Mantua,Pruvincia di Mantuva,Pruvincia di Màntuva,Wilayah Mantua,astan mntwwa,man tuo wa sheng,mantoba hyeon,mantovu~a xian,mentuva makanam,mntwbh,Μάντοβα,Мантова,Мантуа,Мантуя,Մանտուա,מנטובה,استان منتووا,صوبہ مانتووا,ضلع مانٹووا,مقاطعة مانتوفا,மேன்டுவா மாகாணம்,მანტუის პროვინცია,マントヴァ県,曼托瓦省,만토바 현', 45.1603100, 10.7978400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84114, 'Mantignana', 'Mantignana', 'Mantignana', 43.1599200, 12.2885500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84115, 'Manta', 'Manta', 'Manta,manta,マンタ', 44.6158300, 7.4870300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84116, 'Mansuè', 'Mansue', 'Mansue,Mansuè', 45.8211800, 12.5351000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84117, 'Manoppello', 'Manoppello', 'Manoppello', 42.2591800, 14.0602400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84118, 'Manocalzati', 'Manocalzati', 'Manocalzati', 40.9415100, 14.8476700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84119, 'Maniago', 'Maniago', 'Mania,Maniago', 46.1664400, 12.7060200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84120, 'Mango', 'Mango', 'Mango,mango,マンゴ', 44.6881200, 8.1492200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84121, 'Manfredonia', 'Manfredonia', 'Manfredonia,Manfredonija,Manfredònia,manfuredonia,Манфредония,マンフレドーニア', 41.6306500, 15.9187600, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84122, 'Manerbio', 'Manerbio', 'Manerbio,manerbio,manerubio,Манербио,マネルビオ', 45.3539000, 10.1380300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84123, 'Manduria', 'Manduria', 'Manduria,Mandurija,Мандурия', 40.3989900, 17.6372600, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84124, 'Mandello del Lario', 'Mandello del Lario', 'Mandello,Mandello del Lario', 45.9219900, 9.3197400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84125, 'Mandela', 'Mandela', 'Mandela,mandera,マンデーラ', 42.0279500, 12.9208900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84126, 'Manciano', 'Manciano', 'Manciano', 42.5887500, 11.5180600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84127, 'Mamoiada', 'Mamoiada', 'Mamoiada,Mamojada', 40.2148700, 9.2818900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84128, 'Malvicino', 'Malvicino', 'Malvicino,Malvirino', 44.5593400, 8.4131500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84129, 'Malonno', 'Malonno', 'Malonno,maron''no,マロンノ', 46.1216800, 10.3184100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84130, 'Malo', 'Malo', 'Malo', 45.6591000, 11.4160100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84131, 'Malnate', 'Malnate', 'Malnate,marunate,マルナーテ', 45.7937700, 8.8810400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84132, 'Malmantile', 'Malmantile', '', 43.7471700, 11.0728500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84133, 'Malles Venosta', 'Malles Venosta', 'Males Venosta,Males-Venosta,Malles,Malles Venosta,Malles-Venosta,Mals,Málles,ma lai si wei nuo si ta,Μαλς,Малес Веноста,Малес-Веноста,Маллес-Веноста,Մալես Վենոստա,マッレス・ヴェノスタ,马莱斯韦诺斯塔', 46.6879100, 10.5465500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84134, 'Malgrate', 'Malgrate', 'Malgrate', 45.8489100, 9.3763000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84135, 'Malesco', 'Malesco', 'Malesco', 46.1280000, 8.4980100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84136, 'Maleo', 'Maleo', 'Maleo,mareo,マレーオ', 45.1663300, 9.7624100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84137, 'Malè', 'Male', 'Male,Maletum,Malè,Malé,mare,Мале,Մալե,マレ', 46.3535600, 10.9124600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84138, 'Malcesine', 'Malcesine', 'Mal''chezine,Malcesine,Malcexine,Malchezine,Malcèxine,Malesilica,ma er qie xi nei,malsysyny,maruchejine,Малчезине,Мальчезине,Мальчезіне,Մալչեզինե,مالسيسيني,マルチェージネ,马尔切西内', 45.7614000, 10.8086300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84139, 'Malborghetto', 'Malborghetto', 'Malborghet,Malborghetto,Malborghetto Valbruna,Malborghèt', 46.5067900, 13.4394600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84140, 'Malalbergo', 'Malalbergo', 'Malalbergo', 44.7186700, 11.5322100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84141, 'Maissana', 'Maissana', 'Maissana,Maissann-a', 44.3367500, 9.5358800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84142, 'Mairano', 'Mairano', 'Mairano,mairano,マイラーノ', 45.4480200, 10.0797700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84143, 'Mairano', 'Mairano', '', 45.3579400, 9.0693900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84144, 'Maiori', 'Maiori', 'Maiori,Majori,Majure,Майори', 40.6484800, 14.6407000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84145, 'Serra di Maiolo', 'Serra di Maiolo', 'Maiolo,San Biagio,Serra di Maiolo', 43.8730400, 12.3112900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84146, 'Maiolati Spontini', 'Maiolati Spontini', 'Maiolati,Maiolati Spontini,マイオラーティ・スポンティーニ', 43.4764000, 13.1199100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84147, 'Magugnano', 'Magugnano', 'Magugnano,Magugnano-Marniga', 45.7008400, 10.7622900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84148, 'Magreta', 'Magreta', '', 44.6000000, 10.8000000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84149, 'Magomadas', 'Magomadas', 'Magomadas', 40.2632100, 8.5232700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84150, 'Magno', 'Magno', '', 45.7066500, 10.1993700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84151, 'Magnano in Riviera', 'Magnano in Riviera', 'Magnan,Magnano,Magnano in Riviera', 46.2236900, 13.1948300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84152, 'Magnago', 'Magnago', 'Magnago,manyago,マニャーゴ', 45.5792000, 8.8024500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84153, 'Magnacavallo', 'Magnacavallo', 'Magnacavallo', 45.0064600, 11.1832600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84154, 'Maglie', 'Maglie', 'Maddhie,Maglie,marie,マリエ', 40.1206900, 18.2979700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84155, 'Magliano Vetere', 'Magliano Vetere', 'Magliano,Magliano Vetere', 40.3470100, 15.2366600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84156, 'Magliano Sabina', 'Magliano Sabina', 'Magliano Sabina,Magliano Sabino', 42.3656800, 12.4852000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84157, 'Magliano Romano', 'Magliano Romano', 'Magliano Romano,マリアーノ・ロマーノ', 42.1575000, 12.4366200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84158, 'Magliano in Toscana', 'Magliano in Toscana', 'Magliano Toscana,Magliano in Toscana', 42.5980200, 11.2923400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84159, 'Magliano di Tenna', 'Magliano di Tenna', 'Magliano di Tenna', 43.1379500, 13.5871800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84160, 'Magliano De''Marsi', 'Magliano De''Marsi', 'Magliano de'' Marsi,Magliano de''Marsi', 42.0915300, 13.3637900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84161, 'Magliano Alpi', 'Magliano Alpi', 'Magliano,Magliano Alpi', 44.4580800, 7.8192600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84162, 'Magliano', 'Magliano', 'Magliano', 40.3374000, 18.0628700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84163, 'Magione', 'Magione', 'Magione', 43.1417900, 12.2116900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84164, 'Magenta', 'Magenta', 'Castra Maxentia,Magenta,ma zhen ta,majenta,マジェンタ,马真塔', 45.4645600, 8.8845300, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84165, 'Magasa', 'Magasa', 'Magasa,Moerna,magaza,マガーザ', 45.7813900, 10.6159700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84166, 'Mafalda', 'Mafalda', 'Mafalda,Ripalta sul Trigno', 41.9430800, 14.7161000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84167, 'Maerne', 'Maerne', '', 45.5231300, 12.1547700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84168, 'Maenza', 'Maenza', 'Maenza,maentsu~a,マエンツァ', 41.5240200, 13.1834400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84169, 'Madonna dell''Acqua', 'Madonna dell''Acqua', '', 43.7426400, 10.3751300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84170, 'Madignano', 'Madignano', 'Madigna,Madignano,Madignà', 45.3451500, 9.7227100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84171, 'Maddaloni', 'Maddaloni', 'Maddaloni,Маддалони', 41.0357800, 14.3823000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84172, 'Macugnaga', 'Macugnaga', 'Macugnaga', 45.9692900, 7.9678300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84173, 'Macomer', 'Macomer', 'Macomer', 40.2623300, 8.7673300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84174, 'Macere', 'Macere', '', 41.7487300, 12.8583500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84175, 'Macerata Feltria', 'Macerata Feltria', 'Macerata Feltria', 43.8028500, 12.4420400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84176, 'Macerata Campania', 'Macerata Campania', 'Macerata Campania', 41.0632700, 14.2775000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84177, 'Macerata', 'Macerata', 'Macerata,Macherata,macherata,mz''rth,Мачерата,מצ''רטה,マチェラータ', 43.2978900, 13.4529300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84178, 'Macchia Valfortore', 'Macchia Valfortore', 'Macchia Valfortore', 41.5948700, 14.9123800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84179, 'Macchiagodena', 'Macchiagodena', 'Macchiagodena', 41.5589900, 14.4104900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84180, 'Macchia d''Isernia', 'Macchia d''Isernia', 'Macchia d''Isernia', 41.5605700, 14.1701500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84181, 'Maccarese', 'Maccarese', '', 41.8769600, 12.2197500, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84182, 'Maccagno', 'Maccagno', 'Maccagn,Maccagno,Makan''jo,Makkan''o,ma ka ni ao,makkanyo,Маканьё,Макканьо,Մաքանո,マッカーニョ,马卡尼奥', 46.0435700, 8.7341300, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84183, 'Maccacari', 'Maccacari', '', 45.1427600, 11.1349900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84184, 'Luzzara', 'Luzzara', 'Luzzara', 44.9592500, 10.6895300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84185, 'Luzzano', 'Luzzano', '', 41.0681800, 14.5361100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84186, 'Luzzana', 'Luzzana', 'Locosiana,Loessana,Luccana,Luzzana,Lössàna,lu zha na,ruttsu~ana,Луццана,Լուցանա,ルッツァーナ,卢扎纳', 45.7153000, 9.8810500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84187, 'Lustra', 'Lustra', '', 40.2883000, 15.0682600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84188, 'Luson - Luesen', 'Luson', 'Luesen,Lusen,Luson,Lüsen,ruzon,ルゾーン', 46.7462300, 11.7609800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84189, 'Lusiana', 'Lusiana', 'Lusiana,Luxiana,Luziana,lu xia na,rujiana,Лузиана,Лузіана,Լուզիանա,ルジアーナ,卢夏纳', 45.7842800, 11.5747800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84190, 'Lusia', 'Lusia', 'Lusia', 45.0984800, 11.6651100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84191, 'Lusevera', 'Lusevera', 'Lusevare,Lusevera', 46.2752900, 13.2692200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84192, 'Luserna', 'Luserna', 'Luserna,Luserna San Giovanni,Luserna Sant Jan,Luserna Sant Joan,Lusèrna,Lusèrna Sant Jan,Lusèrna Sant Joan,ルゼルナ・サン・ジョヴァンニ', 44.8074500, 7.2457900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84193, 'Luserna', 'Luserna', 'Lusern,Luserna,ruzeruna,ルゼルナ', 45.9226000, 11.3228900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84194, 'Lurate Caccivio', 'Lurate Caccivio', 'Caccivio,Lurate', 45.7670100, 8.9989700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84195, 'Luras', 'Luras', 'Luras,Lurisi', 40.9364300, 9.1748000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84196, 'Lurago Marinone', 'Lurago Marinone', '', 45.7048200, 8.9833000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84197, 'Lurago d''Erba', 'Lurago d''Erba', '', 45.7509700, 9.2181700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84198, 'Lupara', 'Lupara', 'Lupara', 41.7614100, 14.7339000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84199, 'Luogosanto', 'Luogosanto', '', 41.0468100, 9.2055300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84200, 'Luogosano', 'Luogosano', 'Luogosano', 40.9864300, 14.9920600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84201, 'Lungavilla', 'Lungavilla', 'Lungavilla', 45.0415100, 9.0784200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84202, 'Lunano', 'Lunano', 'Lunano', 43.7321400, 12.4432600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84203, 'Lumignano', 'Lumignano', '', 45.4596800, 11.5878600, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84204, 'Lumellogno', 'Lumellogno', 'Lumellogno', 45.4080100, 8.5878700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84205, 'Lula', 'Lula', 'Lula,Lulla,Luvula,Lùvula,rura,Лула,Լուլա,ルーラ', 40.4704800, 9.4868400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84206, 'Luino', 'Luino', 'Luino', 46.0018500, 8.7451200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84207, 'Lugugnana', 'Lugugnana', '', 45.7327700, 12.9595800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84208, 'Stallavena-Lugo', 'Stallavena-Lugo', '', 45.5628900, 10.9966900, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84209, 'Lugo', 'Lugo', 'Lugo,rugo,Луго,ルーゴ', 44.4213700, 11.9109400, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84210, 'Lugnano in Teverina', 'Lugnano in Teverina', 'Luchianum,Lugnano in Teverina,Lugnanu n Teverina,Lun''jano-in-Teverina,Lunjano in Teverina,Lunyano in Teverina,lu ni ya nuo yin tai wei li na,lunyanointebelina,lwnyanw fy tyfyryna,Луньяно-ин-Теверина,Луньяно-ін-Теверина,Луняно ин Теверина,Լունյանո ին Տեվերինա,لونيانو في تيفيرينا,ルニャーノ・イン・テヴェリーナ,卢尼亚诺因泰韦里纳,루냐노인테베리나', 42.5759200, 12.3333600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84211, 'Lugagnano Val d''Arda', 'Lugagnano Val d''Arda', 'Lugagnana Val d''Arda,Lugagnano Val d''Arda', 44.8230400, 9.8282800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84212, 'Lugagnano', 'Lugagnano', '', 45.4332700, 10.8840200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84213, 'Lucrezia', 'Lucrezia', 'Borgo Lucrezia,Lucrezia', 43.7731000, 12.9399500, 'IT', '2015-08-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84214, 'Luco dei Marsi', 'Luco dei Marsi', 'Luco de Marsi,Luco dei Marsi,Luco ne'' Marsi', 41.9592500, 13.4734900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84215, 'Lucito', 'Lucito', 'Lucito', 41.7319300, 14.6872300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84216, 'Montano Lucino', 'Montano Lucino', '', 45.7837800, 9.0424400, 'IT', '2012-03-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84217, 'Lucinasco', 'Lucinasco', 'Lucinasco,Luxinasco', 43.9660200, 7.9600500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84218, 'Lucignano', 'Lucignano', 'Lucignano', 43.2725900, 11.7459900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84219, 'Lucera', 'Lucera', 'Lucera,Luchera,lutseriumi,Лучера,ლუცერიუმი', 41.5055000, 15.3391000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84220, 'Lucca', 'Lucca', 'LCV,Locca,Luca,Lucca,Lucques,Luka,Lukka,lu ka,rukka,Лука,Лукка,ルッカ,卢卡', 43.8436900, 10.5044700, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84221, 'Lubriano', 'Lubriano', 'Lubriano', 42.6362300, 12.1087600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84222, 'Lu', 'Lu', 'Lu', 45.0018400, 8.4856100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84223, 'Lozzolo', 'Lozzolo', 'Lozzolo', 45.6189400, 8.3228400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84224, 'Lozzo di Cadore', 'Lozzo di Cadore', 'Lozzo,Lozzo di Cadore', 46.4864400, 12.4449300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84225, 'Lozzo Atestino', 'Lozzo Atestino', 'Lozzo Atestino', 45.2938400, 11.6049500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84226, 'Lovere', 'Lovere', 'Lovere,rovu~ere,ローヴェレ', 45.8137900, 10.0699500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84227, 'Loseto', 'Loseto', '', 41.0421400, 16.8491700, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84228, 'Lorsica', 'Lorsica', 'Lorsega,Lorsica,Lòrsega', 44.4341500, 9.2767700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84229, 'Loro Piceno', 'Loro Piceno', 'Loro,Loro Piceno', 43.1644200, 13.4116200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84230, 'Loro Ciuffenna', 'Loro Ciuffenna', 'Loro Ciuffenna', 43.5882700, 11.6288500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84231, 'Loria Bessica', 'Loria Bessica', 'Loria', 45.7300000, 11.8654000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84232, 'Loreto Aprutino', 'Loreto Aprutino', 'Loreto Aprutino', 42.4310400, 13.9805700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84233, 'Loreto', 'Loreto', 'Lauretum,Loreto,roreto,ロレート', 43.4361700, 13.6123200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84234, 'Loreo', 'Loreo', 'Loreo', 45.0621300, 12.1881200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84235, 'Lorenzana', 'Lorenzana', 'Larehncana,Laurentiana,Lorencana,Lorenzana,luo lun zha na,rorentsu~ana,Ларэнцана,Лоренцана,Լորենցանա,ロレンツァーナ,洛伦扎纳', 43.5353300, 10.5347700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84236, 'Lorenzago di Cadore', 'Lorenzago di Cadore', 'Lorenzago di Cadore', 46.4795400, 12.4598400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84237, 'Loreggiola', 'Loreggiola', '', 45.6089200, 11.9189900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84238, 'Loreggia', 'Loreggia', 'Loreggia', 45.5973300, 11.9476900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84239, 'Loranzè', 'Loranze', 'Loranse,Loransé,Loranze,Loranzè,rorantsu~e,ロランツェ', 45.4426900, 7.8132800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84240, 'Lonigo', 'Lonigo', 'Lonigo', 45.3857600, 11.3840200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84241, 'Longone Sabino', 'Longone Sabino', 'Longone Sabino', 42.2726000, 12.9665300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84242, 'Longiano', 'Longiano', 'Longiano', 44.0744600, 12.3297000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84243, 'Longastrino', 'Longastrino', '', 44.5884800, 12.0098200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84244, 'Longarone', 'Longarone', 'Longarone', 46.2657900, 12.2999200, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84245, 'Longare', 'Longare', 'Longare', 45.4772600, 11.6069600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84246, 'Longano', 'Longano', 'Longano', 41.5219900, 14.2466500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84247, 'Londa', 'Londa', '', 43.8634400, 11.5642500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84248, 'Lonato', 'Lonato', 'Lonato,Lonato del Garda,ronato,ロナート', 45.4607900, 10.4773200, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84249, 'Lonate Pozzolo', 'Lonate Pozzolo', 'Lonate Pozzolo', 45.5921300, 8.7519400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84250, 'Lonate Ceppino', 'Lonate Ceppino', 'Lonate Ceppino', 45.7086300, 8.8793600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84251, 'Lomello', 'Lomello', 'Lomello', 45.1200100, 8.7961200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84252, 'Lombardore', 'Lombardore', 'Lombardor,Lombardore,ronbarudore,ロンバルドーレ', 45.2358000, 7.7370300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84253, 'Lomazzo', 'Lomazzo', 'Lomazzo', 45.6967000, 9.0342700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84254, 'Lomagna', 'Lomagna', 'Lomagna', 45.6664000, 9.3765400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84255, 'Loiri Porto San Paolo', 'Loiri Porto San Paolo', '', 40.8426200, 9.4982000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84256, 'Loiano', 'Loiano', 'Loiano,Loianum,Lojan,Lojano,luo ya nuo,lwyanw,roiano,Лояно,Լոիանո,لويانو,ロイアーノ,洛亚诺', 44.2680600, 11.3284100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84257, 'Lograto', 'Lograto', 'Lograto,rogurato,ログラート', 45.4845800, 10.0566400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84258, 'Lodi Vecchio', 'Lodi Vecchio', 'Lodi Vecchio,ローディ・ヴェッキオ', 45.3042200, 9.4176000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84259, 'Lodine', 'Lodine', 'Lodine', 40.1492600, 9.2187300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84260, 'Lodi', 'Lodi', 'Laus Pompeia,Lod,Lodi,Lòd,rodi,Лоди,ローディ', 45.3098900, 9.5008500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84261, 'Lodè', 'Lode', 'Lode,Lodè', 40.5913700, 9.5387300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84262, 'Loculi', 'Loculi', 'Loculi', 40.4069600, 9.6105600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84263, 'Locorotondo', 'Locorotondo', 'Locorotondo,rokorotondo,ロコロトンド', 40.7566100, 17.3239200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84264, 'Locate Varesino', 'Locate Varesino', 'Locaa,Locatum,Lokate Varezino,Lokate-Varezino,luo ka tai wa lei xi nuo,Локате-Варезино,Локате-Варезіно,Լոկատե Վարեզինո,ロカーテ・ヴァレジーノ,洛卡泰瓦雷西诺', 45.6896900, 8.9299200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84265, 'Locate di Triulzi', 'Locate di Triulzi', 'Leucatum,Locaa,Locate Triulzi,Locate di Triulzi,Lokate-di-Tr''jul''ci,Lokate-di-Triul''ci,luo ka tai di te liu er qi,Локате-ди-Триульци,Локате-ді-Трьюльці,Լոկատե դի Տրիուլցի,ロカーテ・ディ・トリウルツィ,洛卡泰迪特留尔齐', 45.3569100, 9.2251600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84266, 'Locana', 'Locana', 'Locan-a,Locana,rokana,ロカーナ', 45.4141900, 7.4571200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84267, 'Loano', 'Loano', 'Leua,Loano', 44.1277700, 8.2574300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84268, 'Lizzano in Belvedere', 'Lizzano in Belvedere', 'Lizan,Lizzano Belvedere,Lizzano in Belvedere,Lizàn', 44.1613500, 10.8940800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84269, 'Lizzano', 'Lizzano', '', 40.3930100, 17.4457100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84270, 'Lizzanello', 'Lizzanello', 'Lizzanello', 40.3047500, 18.2228300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84271, 'Livorno Ferraris', 'Livorno Ferraris', 'Livorno Ferraris', 45.2827100, 8.0778000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84272, 'Livorno', 'Livorno', 'Labro,Leghorn,Levuorno,Liborno,Liorna,Livorn,Livornas,Livorno,Livornu,Livourne,lybwrnw,lyfwrnw,rivu~oruno,Λιβόρνο,Ливорно,ליבורנו,ليفورنو,リヴォルノ', 43.5442700, 10.3261500, 'IT', '2017-07-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84273, 'Livo', 'Livo', 'Livo,rivu~o,リーヴォ', 46.4047100, 11.0192700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84274, 'Livo', 'Livo', 'Livo,rivu~o,リーヴォ', 46.1684900, 9.3041400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84275, 'Livinallongo del Col di Lana', 'Livinallongo del Col di Lana', '', 46.4816200, 11.9539900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84276, 'Livigno', 'Livigno', 'Livigno', 46.5363000, 10.1334800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84277, 'Liveri', 'Liveri', 'Liveri,rivu~eri,リーヴェリ', 40.9040600, 14.5653600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84278, 'Lissone', 'Lissone', 'Lissone,Lissun,Lissún,rissone,Лиссоне,リッソーネ', 45.6123600, 9.2398500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84279, 'Liscate', 'Liscate', 'Liscate,risukate,リスカーテ', 45.4831600, 9.4103000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84280, 'Lioni', 'Lioni', 'Lioni', 40.8808300, 15.1833500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84281, 'Linate', 'Linate', 'Linate al Lambro', 45.4470100, 9.2722900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84282, 'Limosano', 'Limosano', 'Limosano', 41.6755400, 14.6223000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84283, 'Limone sul Garda', 'Limone sul Garda', 'Limone,Limone sul Garda,jia da,リモーネ・スル・ガルダ,加达', 45.8145000, 10.7927800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84284, 'Limone Piemonte', 'Limone Piemonte', 'Limon,Limone Piemonte', 44.2009100, 7.5786100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84285, 'Limiti di Greccio', 'Limiti di Greccio', 'Limiti,Luniti', 42.4532900, 12.7695500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84286, 'Limite', 'Limite', '', 43.7445000, 10.9799600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84287, 'Limena', 'Limena', 'Limena', 45.4694800, 11.8457400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84288, 'Limbiate', 'Limbiate', 'Limb''jate,Limbiate,rinbiate,Лимбьяте,リンビアーテ', 45.5995100, 9.1250900, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84289, 'Limatola', 'Limatola', 'Limatola', 41.1401200, 14.3943700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84290, 'Lillianes', 'Lillianes', 'Lilliana,Lillianes', 45.6294800, 7.8412600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84291, 'Ligosullo', 'Ligosullo', 'Ligosullo,Livussul', 46.5400800, 13.0754700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84292, 'Ligonchio', 'Ligonchio', 'Ligonchio', 44.3163500, 10.3422400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84293, 'Lignano Sabbiadoro', 'Lignano Sabbiadoro', 'Lignan,Lignano,Lignano Sabbiadoro', 45.6759000, 13.1172700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84294, 'Lignana', 'Lignana', 'Lignana', 45.2860600, 8.3439300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84295, 'Lierna', 'Lierna', 'Lierna', 45.9581800, 9.3051300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84296, 'Lido di Ostia', 'Lido di Ostia', 'Lido di Ostia,Lido di Roma,Lido-di-Ostija,Lido-di-Roma,Ostia Lido,Лидо-ди-Остия,Лидо-ди-Рома', 41.7321200, 12.2765400, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84297, 'Lido di Jesolo', 'Lido di Jesolo', 'Lido di Iesolo,Lido di Jesolo', 45.5069400, 12.6469400, 'IT', '2017-04-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84298, 'Lido', 'Lido', 'Bagni del Lido,Lido di Venezia', 45.4105000, 12.3664900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84299, 'Licusati', 'Licusati', '', 40.0541000, 15.3643700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84300, 'Licenza', 'Licenza', 'Licenza,richentsu~a,リチェンツァ', 42.0741300, 12.9000800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84301, 'Licciana Nardi', 'Licciana Nardi', 'Licciana,Licciana Nardi,リッチャーナ・ナルディ', 44.2647200, 10.0372500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84302, 'Liberi', 'Liberi', 'Liberi', 41.2264800, 14.2898500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84303, 'Lezzeno', 'Lezzeno', 'Lezzeno', 45.9441100, 9.1848800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84304, 'Levico Terme', 'Levico Terme', 'Levico,Levico Terme,レーヴィコ・テルメ', 46.0121700, 11.3042700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84305, 'Levice', 'Levice', 'Levice', 44.5382400, 8.1550400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84306, 'Leverano', 'Leverano', 'Leverano', 40.2885200, 17.9965000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84307, 'Levanto', 'Levanto', 'Levanto', 44.1742400, 9.6167000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84308, 'Levada', 'Levada', '', 45.7344200, 12.4712800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84309, 'Lettopalena', 'Lettopalena', 'Lettopalena', 42.0025100, 14.1565200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84310, 'Lettomanoppello', 'Lettomanoppello', 'Lettomanoppello', 42.2433600, 14.0384300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84311, 'Lestizza', 'Lestizza', 'Lestice,Lestizza,Listize', 45.9565600, 13.1422100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84312, 'Lestans', 'Lestans', '', 46.1579300, 12.8887200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84313, 'Lessona', 'Lessona', 'Lessona', 45.5869300, 8.1943300, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84314, 'Lessolo', 'Lessolo', 'Lesseul,Lessolo,ressoro,レッソロ', 45.4779400, 7.8157600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84315, 'Lesina', 'Lesina', '', 41.8612500, 15.3532200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84316, 'Lesignano de''Bagni', 'Lesignano de''Bagni', 'Lesignano de'' Bagni,Lesignano de''Bagni', 44.6434600, 10.3003900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84317, 'Lesegno', 'Lesegno', 'Lesegno,rezenyo,レゼーニョ', 44.4011000, 7.9694300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84318, 'Lesa', 'Lesa', 'Lesa,reza,レーザ', 45.8206600, 8.5596400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84319, 'Lerma', 'Lerma', 'Lerma', 44.6357700, 8.7132300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84320, 'Lerici', 'Lerici', 'Lerici,Lerze', 44.0758700, 9.9112100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84321, 'Lequile', 'Lequile', 'Lequile,Lequille', 40.3058300, 18.1402200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84322, 'Leporano', 'Leporano', 'Leporano', 40.3821800, 17.3342600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84323, 'Leonessa', 'Leonessa', 'Leonessa', 42.5685500, 12.9599600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84324, 'Lentigione-Sorbolo a Mane', 'Lentigione-Sorbolo a Mane', '', 44.8666700, 10.4833300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84325, 'Lentiai', 'Lentiai', 'Lent''jai,Lentiai,Lentiaj,Lentiei,Linteayum,lun di ya yi,rentiai,Лентиай,Лентьяи,Лентіаї,Լենտիաի,レンティアーイ,伦蒂亚伊', 46.0450400, 12.0205300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84326, 'Lentella', 'Lentella', 'Lentella', 41.9957600, 14.6769200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84327, 'Lentate sul Seveso', 'Lentate sul Seveso', 'Lentate,Lentate sul Seveso,レンターテ・スル・セーヴェゾ', 45.6763700, 9.1177400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84328, 'Lenta', 'Lenta', 'Lenta', 45.5569100, 8.3840200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84329, 'Lenola', 'Lenola', 'Lenola,renora,レーノラ', 41.4048500, 13.4593400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84330, 'Leno', 'Leno', 'Leno,reno,レーノ', 45.3693000, 10.2167500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84331, 'Lenno', 'Lenno', 'Lenn,Lenno,Leno,lun nuo,ren''no,Łeno,Ленно,Լենո,レンノ,伦诺', 45.9729800, 9.1908400, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84332, 'Lenna', 'Lenna', 'Lena,Lenna,Lèna,lun na,ren''na,Лена,Ленна,Լեննա,レンナ,伦纳', 45.9427300, 9.6787600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84333, 'Lendinara', 'Lendinara', 'Lendinara', 45.0830100, 11.6031800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84334, 'Villa Lempa', 'Villa Lempa', '', 42.7934500, 13.6443300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84335, 'Lemie', 'Lemie', 'Lemie,remie,レーミエ', 45.2286600, 7.2924800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84336, 'Leini', 'Leini', 'Leini,Leinì,Leyni,Leynj,reini,レイニ', 45.1827500, 7.7142200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84337, 'Lei', 'Lei', 'Lei,Lej,Lien,lai yi,ly  sardynya,rei,Леи,Лей,Леї,Լեի,لی، ساردینیا,レーイ,莱伊', 40.3064100, 8.9185800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84338, 'Le Grazie di Ancona', 'Le Grazie di Ancona', 'Le Grazie,Le Grazie di Ancona,Le Grázie', 43.6008100, 13.5152900, 'IT', '2012-02-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84339, 'Le Grazie', 'Le Grazie', '', 44.0669900, 9.8339200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84340, 'Legnaro', 'Legnaro', 'Legnaro', 45.3423800, 11.9648200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84341, 'Legnano', 'Legnano', 'Legnano,Len''jano,renyano,Леньяно,レニャーノ', 45.5978800, 8.9150600, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84342, 'Legnago', 'Legnago', 'Legnago,Len''jago,Леньяго', 45.1936500, 11.3022700, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84343, 'Leffe', 'Leffe', '', 45.7979300, 9.8842600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84344, 'Lecco', 'Lecco', 'Lecco,Lech,Lekko,Leucum,rekko,Лекко,レッコ', 45.8558900, 9.3970400, 'IT', '2015-08-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84345, 'Lecce Nei Marsi', 'Lecce Nei Marsi', 'Lecce dei Marse,Lecce nei Marsi', 41.9343600, 13.6843000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84346, 'Lecce', 'Lecce', 'LCC,Lecce,Lecci,Lece,Lechche,Leche,Letse,Lečė,Lungsod ng Lecce,Lupiae,Luppiu,lai qie,lchh,leche,letce,li che,lychy,lytshy,lzh,retche,Λέτσε,Лече,Лечче,Լեչե,לצה,ليتشي,لچه,لیچہ,لیچی,लेत्चे,ლეჩე,レッチェ,壢車,萊切,레체', 40.3548100, 18.1724400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84347, 'Lazzeretto', 'Lazzeretto', '', 43.7830500, 10.8605400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84348, 'Lazise', 'Lazise', 'Lazise', 45.5049900, 10.7392300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84349, 'Lavis', 'Lavis', 'Lavis,ravu~isu,ラヴィース', 46.1413100, 11.1093100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84350, 'Laviano', 'Laviano', 'Laviano', 40.7861900, 15.3079100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84351, 'Lavezzola', 'Lavezzola', '', 44.5609900, 11.8755700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84352, 'Lavenone', 'Lavenone', 'Lavenone,ravu~enone,ラヴェノーネ', 45.7385300, 10.4393000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84353, 'Laveno', 'Laveno', 'Laveno-Mombello,Лавено-Момбелло', 45.9088800, 8.6203600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84354, 'Lavello', 'Lavello', 'Forentum,Labellum,Lavello,Lavellu,Lavelo,la wei luo,lafylw,ravu~erro,Лавелло,Лавело,Լավելո,لافيلو,ラヴェッロ,拉韦洛', 41.0476900, 15.7891500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84355, 'La Valle Agordina', 'La Valle Agordina', 'La Valle Agordina', 46.2819800, 12.0684400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84356, 'Lavagna', 'Lavagna', 'Lavagna', 44.3062000, 9.3538300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84357, 'Lauzacco', 'Lauzacco', 'Lauzacco,Pavia d'' Udine,Pavia d’ Udine', 45.9813400, 13.2802400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84358, 'Lauro', 'Lauro', '', 41.2636500, 13.8905900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84359, 'Lauro', 'Lauro', '', 40.8797200, 14.6301300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84360, 'Laurito', 'Laurito', 'Laurito', 40.1691500, 15.4074100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84361, 'Laurino', 'Laurino', 'Laurino', 40.3391500, 15.3381000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84362, 'Lauriano', 'Lauriano', 'Laurian,Lauriano,rauriano,ラウリアーノ', 45.1598900, 7.9947400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84363, 'Lauria', 'Lauria', 'Lauria', 40.0470200, 15.8381200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84364, 'Laurenzana', 'Laurenzana', 'Laurencana,Laurentiana,Laurenzana,lao lun zha na,lawrynzana,raurentsu~ana,Лауренцана,Լաուրենցանա,لاورينزانا,ラウレンツァーナ,劳伦扎纳', 40.4590800, 15.9707500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84365, 'Lauregno', 'Lauregno', 'Lauregno,Lauregnum,Laurehn''jo,Laurein,Lauren''o,Laureno,lao lei ni ao,raurenyo,Лауреньо,Лаўрэньё,Լաուրենո,ラウレーニョ,劳雷尼奥', 46.4543100, 11.0617700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84366, 'Laureana Cilento', 'Laureana Cilento', 'Laureana Cilento', 40.3011000, 15.0387600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84367, 'Lauco', 'Lauco', 'Lauc,Lauco', 46.4239700, 12.9322200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84368, 'Latronico', 'Latronico', 'Latronico', 40.0890900, 16.0094700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84369, 'Latisana', 'Latisana', 'Latisana,Latisane,Tisane', 45.7685900, 13.0061800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84370, 'Latina', 'Latina', 'Latina,Littoria,QLT,ratina,Латина,ラティーナ', 41.4661400, 12.9043000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84371, 'Latiano', 'Latiano', 'Latiano', 40.5505200, 17.7185600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84372, 'La Thuile', 'La Thuile', 'La Thuile,Porta Littoria', 45.7136600, 6.9509900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84373, 'Laterza', 'Laterza', '', 40.6288100, 16.7994700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84374, 'Laterina', 'Laterina', 'Latehryna,Laterina,Laterinum,la tai li na,raterina,Łaterina,Латерина,Латэрына,Լատերինա,ラテリーナ,拉泰里纳', 43.5019300, 11.7173700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84375, 'Latera', 'Latera', 'Latera', 42.6292200, 11.8292200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84376, 'Lastra a Signa', 'Lastra a Signa', 'Lastra a Signa', 43.7699800, 11.1127100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84377, 'Lastebasse', 'Lastebasse', 'Lastebasse', 45.9151000, 11.2738900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84378, 'La Spezia', 'La Spezia', 'La Specija,La Spezia,QLP,Specija,Spedia,Speza,Spezia,Ла Специја,Специя,ラ・スペツィア', 44.1030000, 9.8237500, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84379, 'Lasino', 'Lasino', 'Lasino,rajino,ラジーノ', 46.0242000, 10.9835700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84380, 'La Salle', 'La Salle', 'La Sal,La Salle,La-Sal'',Sala,Sala Dora,la sa lai,lasalle,Ла-Саль,Լա Սալ,ラ・サル,拉萨莱,라살레', 45.7449700, 7.0729500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84381, 'Lasa', 'Lasa', 'Laas,Lasa,raza,ラーザ', 46.6178300, 10.6977700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84382, 'Larino', 'Larino', 'Larino,Larinu,Larinum,Laryna,la li nuo,lalino,larynw,rarino,Ларино,Ларына,لارينو,ラリーノ,拉里诺,라리노', 41.8044900, 14.9184300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84383, 'Lariano', 'Lariano', 'Lariano,rariano,ラリアーノ', 41.7184700, 12.8286800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84384, 'Lari', 'Lari', 'Castrum Lari,Lari,Lary,rari,Лари,Лары,Ларі,Լարի,ラーリ', 43.5660600, 10.5921100, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84385, 'Lardirago', 'Lardirago', 'Lardirago', 45.2357200, 9.2327200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84386, 'Lardaro', 'Lardaro', 'Lardaro,rarudaro,ラルダーロ', 45.9694600, 10.6612600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84387, 'L''Aquila', 'L''Aquila', 'Aquila,Aquila degli Abruzzi,L''Akvila,L''Aquila,L’Aquila,rakuira,Áquila,Л’Аквила,ラクイラ', 42.3505500, 13.3995400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84388, 'Lapio', 'Lapio', '', 40.9829300, 14.9465000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84389, 'Lapedona', 'Lapedona', 'Lapedona', 43.1092000, 13.7706300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84390, 'Panighina', 'Panighina', '', 44.1716200, 12.1632400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84391, 'Lanzo Torinese', 'Lanzo Torinese', 'Lans,Lanzo Torinese,ランツォ・トリネーゼ', 45.2765700, 7.4823500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84392, 'Lanzo d''Intelvi', 'Lanzo d''Intelvi', 'Lanzo,Lanzo d''Intelvi', 45.9794300, 9.0216600, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84393, 'Lanuvio', 'Lanuvio', 'Lanuvio,ranuvu~io,ラヌーヴィオ', 41.6729700, 12.6940300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84394, 'Langosco', 'Langosco', 'Langosco', 45.2145300, 8.5637200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84395, 'Langhirano', 'Langhirano', 'Langhirano', 44.6191300, 10.2665200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84396, 'Landriano', 'Landriano', 'Landriano', 45.3115500, 9.2604600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84397, 'Landiona', 'Landiona', 'Landiona', 45.4970300, 8.4222400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84398, 'Lanciano', 'Lanciano', 'Anxanum,Lanchano,Lanciano,Ланчано', 42.2271800, 14.3902400, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84399, 'Lana', 'Lana', 'Lana,Lana d''Adige,Lugugnanum,la na,rana,Λάνα,Лана,ラーナ,拉纳', 46.6120900, 11.1565300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84400, 'Lamporo', 'Lamporo', 'Lamporo', 45.2309200, 8.0984600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84401, 'Lamporecchio', 'Lamporecchio', 'Lamporecchio', 43.8074200, 10.8773300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84402, 'La Morra', 'La Morra', 'La Morra', 44.6379000, 7.9307800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84403, 'Lamon', 'Lamon', 'Lamon', 46.0471700, 11.7499100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84404, 'Lama', 'Lama', 'Lama,Lama Mocogno', 44.3072600, 10.7306000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84405, 'La Magdeleine', 'La Magdeleine', 'La Magdeleine', 45.8099600, 7.6187100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84406, 'Lama dei Peligni', 'Lama dei Peligni', 'Lama Di Peligni,Lama dei Peligni', 42.0421400, 14.1867800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84407, 'La Maddalena', 'La Maddalena', 'La Maddalena,ラ・マッダレーナ', 41.2142400, 9.4083300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84408, 'Selci-Lama', 'Selci-Lama', '', 43.5171900, 12.2129300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84409, 'La Loggia', 'La Loggia', 'La Loggia,La Logia,La Lògia,ラ・ロッジャ', 44.9549500, 7.6686400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84410, 'Lallio', 'Lallio', '', 45.6628300, 9.6288700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84411, 'Laives', 'Laives', 'Clivus,Laives,Lajves,Leifers,Leifors,la yi wei si,raivu~esu,Λάιβες,Лайвес,ライヴェス,拉伊韦斯', 46.4267900, 11.3384100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84412, 'Laion', 'Laion', 'Laion,Lajen,Lajon,Layon,Legianum,Loyen,la yi weng,raion,Лайон,Լայոն,ライオーン,拉伊翁', 46.6080900, 11.5655900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84413, 'Lainate', 'Lainate', 'Lainate,rainate,ライナーテ', 45.5717600, 9.0268100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84414, 'Laigueglia', 'Laigueglia', 'L''Aigheuja,Laigueglia,L’Aigheuja', 43.9759000, 8.1582300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84415, 'Lajatico', 'Lajatico', 'Castrum Aiatici,Lajacika,Lajatico,Lajaticu,Lajatiko,Lajàtico,Layatiko,la ya di ke,rayatiko,Лаятико,Лаятіко,Лаяціка,Լայատիկո,ラヤーティコ,拉亚蒂科', 43.4745700, 10.7284400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84416, 'Lagundo', 'Lagundo', 'Algund,Algundium,Lagundo,algand,la gong duo,ragundo,Лагундо,Լագունդո,الگاند,ラグンド,拉贡多', 46.6811300, 11.1257200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84417, 'Lagosanto', 'Lagosanto', 'Lagosanto', 44.7628200, 12.1400500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84418, 'Lagonegro', 'Lagonegro', 'Lagonegro', 40.1278500, 15.7621200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84419, 'Laglio', 'Laglio', 'Laglio,Laglio Brienno', 45.8805600, 9.1369700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84420, 'Giudecca', 'Giudecca', 'Giudecca', 45.4247700, 12.3290600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84421, 'Laghetti', 'Laghetti', 'I Laghetti,Laghetti', 46.2747300, 11.2401100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84422, 'Laerru', 'Laerru', 'Laerru', 40.8170500, 8.8365000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84423, 'Ladispoli', 'Ladispoli', 'Ladispoli,radisupori,Ладисполи,ラディスポリ', 41.9506800, 12.0750000, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84424, 'Laces', 'Laces', 'Laces,Laches,Latsch,Laudes,la qie si,rachesu,Лачес,Լաչես,ラーチェス,拉切斯', 46.6164100, 10.8572600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84425, 'Lacedonia', 'Lacedonia', 'Lacedonia', 41.0502200, 15.4216900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84426, 'Lacco Ameno', 'Lacco Ameno', 'Lacco Ameno,ラッコ・アメーノ', 40.7490100, 13.8871800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84427, 'Lacchiarella', 'Lacchiarella', '', 45.3229000, 9.1377700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84428, 'Casinina', 'Casinina', '', 43.8166700, 12.5833300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84429, 'Cappelletta', 'Cappelletta', '', 45.1051400, 10.7784700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84430, 'Labro', 'Labro', 'Labro', 42.5260300, 12.8006800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84431, 'Labico', 'Labico', 'Labico,rabiko,ラビーコ', 41.7926000, 12.8712700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84432, 'Izano', 'Izano', 'Izano', 45.3555200, 9.7513800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84433, 'Ivrea', 'Ivrea', 'Aebura,Eporedia,Ivrea,Ivree,Ivreja,Ivrèja,Ivrée,ivurea,Ивреа,イヴレーア', 45.4672300, 7.8761700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84434, 'Ittiri', 'Ittiri', 'Ittiri', 40.5915100, 8.5697600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84435, 'Ittireddu', 'Ittireddu', 'Ittireddu', 40.5439800, 8.9011800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84436, 'Itri', 'Itri', 'Itri,itori,イトリ', 41.2903400, 13.5300000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84437, 'Istrana', 'Istrana', 'Istrana', 45.6769100, 12.1011900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84438, 'Istia D''Ombrone-Le Stiacciole', 'Istia D''Ombrone-Le Stiacciole', 'Istia', 42.7824300, 11.1882000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84439, 'Issogne', 'Issogne', 'Issogne', 45.6549600, 7.6857100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84440, 'Issime', 'Issime', 'Issime', 45.6854600, 7.8541100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84441, 'Ispra', 'Ispra', 'Ispra', 45.8148000, 8.6129400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84442, 'Isorella', 'Isorella', 'Isorella,izorerra,イゾレッラ', 45.3091200, 10.3228100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84443, 'Isola Vicentina', 'Isola Vicentina', 'Isola Vicentina', 45.6293000, 11.4460800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84444, 'Isola Sant''Antonio', 'Isola Sant''Antonio', 'Isola Sant''Antonio', 45.0301900, 8.8492800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84445, 'Isola Dovarese', 'Isola Dovarese', 'Isola Dovarese', 45.1729200, 10.3087900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84446, 'Isola del Piano', 'Isola del Piano', 'Isola del Piano', 43.7377600, 12.7840600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84447, 'Isola del Liri', 'Isola del Liri', 'Isola del Liri,Isola di Liri', 41.6867800, 13.5967900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84448, 'Isola della Scala', 'Isola della Scala', '', 45.2694300, 11.0082400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84449, 'Isola del Gran Sasso d''Italia', 'Isola del Gran Sasso d''Italia', 'Isola,Isola del Gran Sasso,Isola del Gran Sasso d''Italia', 42.5032400, 13.6572100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84450, 'Isola del Cantone', 'Isola del Cantone', 'Isola del Cantone,L''Isoea do Canton,L’Isöa do Canton', 44.6478300, 8.9574600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84451, 'Isolabona', 'Isolabona', 'Isolabona,L''Isora', 43.8807600, 7.6399300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84452, 'Isola D''Arbia', 'Isola D''Arbia', '', 43.2586400, 11.3786600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84453, 'Isernia', 'Isernia', 'Isernia,Isérnia,Izernija,izerunia,Изерния,イゼルニア', 41.5960300, 14.2339900, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84454, 'Iseo', 'Iseo', 'Iseo,izeo,イゼーオ', 45.6588300, 10.0502400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84455, 'Ischitella', 'Ischitella', 'Ischitella', 41.9043400, 15.8994500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84456, 'Ischia Porto', 'Ischia Porto', 'Porto d''Ischia,Porto d’Ischia', 40.7391300, 13.9510000, 'IT', '2013-11-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84457, 'Ischia di Castro', 'Ischia di Castro', 'Ischia di Castro', 42.5442000, 11.7575900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84458, 'Ischia', 'Ischia', 'Bagni,Bagno,Bagno d''Ischia,ISH,Ischia,Iscla,Isk''ja,Villa Bagni,Искья', 40.7379300, 13.9486200, 'IT', '2014-07-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84459, 'Irsina', 'Irsina', 'Irsina', 40.7501500, 16.2381600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84460, 'Irgoli', 'Irgoli', 'Irgoli,Irgoli di Galtelli,Irgolis,irugori,yi er ge li,Ірголі,Ирголи,Իրգոլի,イルゴリ,伊尔戈利', 40.4099900, 9.6313500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84461, 'Jolanda di Savoia', 'Jolanda di Savoia', 'Jolanda di Savoia', 44.8831900, 11.9791000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84462, 'Inzago', 'Inzago', 'Andiciacum,Inzago,inzago,インザーゴ', 45.5399100, 9.4834300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84463, 'Invorio', 'Invorio', 'Invorio', 45.7567900, 8.4874100, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84464, 'Inveruno', 'Inveruno', 'Inveruno,in''vu~eruno,インヴェルーノ', 45.5139900, 8.8495400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84465, 'Inverno', 'Inverno', '', 45.1985900, 9.3842900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84466, 'Inverigo', 'Inverigo', 'Inverigo', 45.7379500, 9.2183600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84467, 'Introdacqua', 'Introdacqua', 'Introdacqua', 42.0096800, 13.8977900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84468, 'Introbio', 'Introbio', 'Introbio', 45.9738700, 9.4499800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84469, 'Pallanza-Intra-Suna', 'Pallanza-Intra-Suna', '', 45.9377800, 8.5708800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84470, 'Ingria', 'Ingria', 'Ingri,Ingria,inguria,イングリア', 45.4665000, 7.5711900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84471, 'Induno Olona', 'Induno Olona', 'Induno Olona', 45.8457100, 8.8405600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84472, 'Incisa in Val d''Arno', 'Incisa in Val d''Arno', 'Incisa,Incisa Val d''Arno,Incisa in Val d''Arno', 43.6548000, 11.4490100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84473, 'Impruneta', 'Impruneta', 'Impruneta', 43.6845300, 11.2543400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84474, 'Imperia', 'Imperia', 'Imperia,Imperija,Impéria,inperia,Империя,インペリア', 43.8891700, 8.0393300, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84475, 'Imola', 'Imola', 'Forum Cornelii,Imola,Iommla,imora,Ímola,Имола,イーモラ', 44.3591600, 11.7132000, 'IT', '2016-07-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84476, 'Illorai', 'Illorai', 'Illorai', 40.3527100, 9.0017000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84477, 'Illasi', 'Illasi', 'Illasi', 45.4666300, 11.1816500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84478, 'Capitello', 'Capitello', '', 45.2079200, 11.1401400, 'IT', '2016-02-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84479, 'Barba', 'Barba', '', 43.8829100, 10.9760800, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84480, 'Iesolo', 'Iesolo', 'Capazuccherina,Cavazuccherina,Jesolo,Jezolo,Lido di Ezolo,i~ezoro,Йезоло,Лидо ди Езоло,イェーゾロ', 45.5331100, 12.6447500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84481, 'Jesi', 'Jesi', 'Aesis,Dzezis,Dzhezi,Džezis,Ehzi,Ezi,Iesi,Jesi,Jezi,aysy,i~eji,yyzy,yzy,Єзі,Джези,Ези,Йези,Эзі,יזי,ایسی,ييزي,イェージ', 43.5214200, 13.2436800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84482, 'Jelsi', 'Jelsi', 'Jelsi', 41.5170400, 14.7979000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84483, 'Ialmicco', 'Ialmicco', '', 45.9133300, 13.3461100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84484, 'Borgo Hermada', 'Borgo Hermada', 'Borgo Ermada,Ermada,Hermada', 41.3055900, 13.1723500, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84485, 'Gussola', 'Gussola', 'Gussola', 45.0116500, 10.3489400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84486, 'Gussago', 'Gussago', '', 45.5835800, 10.1571700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84487, 'Guilmi', 'Guilmi', 'Guilmi', 41.9965300, 14.4788200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84488, 'Guiglia', 'Guiglia', 'Guiglia', 44.4243200, 10.9612500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84489, 'Guidonia', 'Guidonia', '', 41.9923200, 12.7187600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84490, 'Guidizzolo', 'Guidizzolo', 'Ghidisoel,Ghidisöl,Guidiccolo,Guidizolo,Guidizoło,Guidizzolo,Guidizzolum,gui di zuo luo,guidittsu~oro,gwydyzwlw,Гуидиццоло,Гуїдіццоло,Գուիդիցոլո,گویدیزولو,グイディッツォーロ,圭迪佐洛', 45.3205600, 10.5780100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84491, 'Guglionesi', 'Guglionesi', 'Guglionesi', 41.9209300, 14.9160000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84492, 'Gubbio', 'Gubbio', 'Gubbio,gubbio,gwbyw,Губбио,גוביו,グッビオ', 43.3499600, 12.5730900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84493, 'Guazzora', 'Guazzora', 'Guazzora', 45.0139200, 8.8482200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84494, 'Guazzino', 'Guazzino', '', 43.2127600, 11.7820900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84495, 'Guasticce', 'Guasticce', '', 43.5980500, 10.4086500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84496, 'Guastalla', 'Guastalla', 'Guastalla', 44.9117200, 10.6618600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84497, 'Guardistallo', 'Guardistallo', 'Guardistallo', 43.3140800, 10.6294400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84498, 'Guardia Sanframondi', 'Guardia Sanframondi', 'Guardia Sanframondi', 41.2564000, 14.5985100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84499, 'Guardiaregia', 'Guardiaregia', 'Guardiaregia', 41.4343600, 14.5434400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84500, 'Guardia Perticara', 'Guardia Perticara', 'Guardia Perticara', 40.3616700, 16.0984500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84501, 'Guardia Lombardi', 'Guardia Lombardi', 'Guardia Lombardi', 40.9517700, 15.2087800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84502, 'Guardialfiera', 'Guardialfiera', 'Guard''jal''f''era,Guard''jal''fera,Guardia Alpheria,Guardialfiera,Guardz''jal''fera,gua er di ya er fei ye la,gualeudialpiela,guarudiarufiera,Гуардзьяльфера,Гуардиалфиера,Гуардьяльфьера,Гуардьяльфєра,Գուարդիալֆիերա,グアルディアルフィエーラ,瓜尔迪亚尔菲耶拉,구아르디알피에라', 41.8042300, 14.7929300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84503, 'Guardiagrele', 'Guardiagrele', 'Guardiagrele', 42.1940600, 14.2193900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84504, 'Guardea', 'Guardea', 'Guardea,Guardeja,Guardia Tiberis,Guradea,ghardya,gua er dai ya,gualeudea,guarudea,Гуардеа,Гуардея,Գուրադեա,غارديا,グアルデーア,瓜尔代亚,구아르데아', 42.6237000, 12.2992800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84505, 'Guarda Veneta', 'Guarda Veneta', 'Guarda Veneta', 44.9818800, 11.8017800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84506, 'Guardamiglio', 'Guardamiglio', 'Guardamiglio,guarudamirio,グアルダミーリオ', 45.1074200, 9.6848100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84507, 'Guarcino', 'Guarcino', 'Guarcino', 41.7991700, 13.3143900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84508, 'Gualtieri', 'Gualtieri', 'Gualtieri', 44.8973600, 10.6286000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84509, 'Gualdo Tadino', 'Gualdo Tadino', 'Gualdo Tadino', 43.2294100, 12.7786200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84510, 'Gualdo Cattaneo', 'Gualdo Cattaneo', 'Gual''do-Kattaneo,Gualdo Cattaneo,Gualdo Kataneo,Gualdu Cattaniu,Gualdum Captaneorum,ghaldw katanyw,gua er duo ka ta nei ao,gualdokatane-o,gwaldw katanyw,Гуалдо Катанео,Гуальдо-Каттанео,Գուալդո Կատանեո,غالدو كاتانيو,گوالدو کاتانئو,グアルド・カッタネーオ,瓜尔多卡塔内奥,구알도카타네오', 42.9122800, 12.5566600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84511, 'Guagnano', 'Guagnano', 'Guagnano', 40.4012300, 17.9490200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84512, 'Grumo Nevano', 'Grumo Nevano', 'Grumo Nevano', 40.9359100, 14.2598300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84513, 'Grumolo Pedemonte', 'Grumolo Pedemonte', '', 45.7243000, 11.4923600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84514, 'Grumolo delle Abbadesse', 'Grumolo delle Abbadesse', 'Grumolo,Grumolo delle Abbadesse,Grumolo delle Badesse,Grùmolo', 45.5169200, 11.6719800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84515, 'Grumo Appula', 'Grumo Appula', 'Grumo Appula', 41.0108900, 16.7084400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84516, 'Grumes', 'Grumes', 'Grumes,gurumesu,グルーメス', 46.2211700, 11.2934600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84517, 'Grumento Nova', 'Grumento Nova', 'Grumento Nova,Saponaradi Grumento', 40.2828100, 15.8887700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84518, 'Grumello del Monte', 'Grumello del Monte', '', 45.6353500, 9.8752600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84519, 'Grumello Cremonese', 'Grumello Cremonese', '', 45.1941500, 9.8644300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84520, 'Grugliasco', 'Grugliasco', 'Grugliasco,Grujasch,gururiasuko,グルリアスコ', 45.0651600, 7.5795400, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84521, 'Gruaro', 'Gruaro', 'Gruar,Gruaro', 45.8347200, 12.8411100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84522, 'Grottolella', 'Grottolella', 'Grottolella', 40.9714400, 14.7889400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84523, 'Grottole', 'Grottole', 'Grottole', 40.6033300, 16.3783100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84524, 'Grotte Santo Stefano', 'Grotte Santo Stefano', '', 42.5169100, 12.1722600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84525, 'Grotte di Castro', 'Grotte di Castro', 'Grotte di Castro', 42.6756700, 11.8690800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84526, 'Grottazzolina', 'Grottazzolina', 'Grottazzolina', 43.1188000, 13.6069100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84527, 'Grottammare', 'Grottammare', 'Grottammare', 42.9818200, 13.8676500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84528, 'Grottaminarda', 'Grottaminarda', '', 41.0697200, 15.0589400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84529, 'Grottaglie', 'Grottaglie', 'Grottaglie,Grottal''e,Гротталье', 40.5369400, 17.4372300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84530, 'Grottaferrata', 'Grottaferrata', 'Grottaferrata', 41.7866400, 12.6714400, 'IT', '2015-07-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84531, 'Grosseto', 'Grosseto', 'GRS,Grosseto,Гроссето', 42.7629600, 11.1094100, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84532, 'Grosotto', 'Grosotto', 'Grosotto,Grossotto', 46.2819600, 10.2590800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84533, 'Grosio', 'Grosio', 'Gros,Grosio,Grosium,Groz''o,Grozio,ge luo xiao,gurojio,Грозио,Грозьо,Грозіо,Գրոզիո,グロージオ,格罗肖', 46.2997000, 10.2757200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84534, 'Groscavallo', 'Groscavallo', 'Groscavallo,Grosscaval,gurosukavu~arro,グロスカヴァッロ', 45.3680500, 7.2580100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84535, 'Gropparello', 'Gropparello', 'Gropparello', 44.8335400, 9.7280100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84536, 'Gropello Cairoli', 'Gropello Cairoli', 'Gropello,Gropello Cairoli', 45.1770700, 8.9935300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84537, 'Grontardo', 'Grontardo', 'Grontardo', 45.2013600, 10.1515000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84538, 'Gromo', 'Gromo', '', 45.9619000, 9.9263700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84539, 'Gromlongo', 'Gromlongo', '', 45.7289500, 9.5409700, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84540, 'Grizzana Morandi', 'Grizzana Morandi', '', 44.2582000, 11.1528800, 'IT', '2012-03-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84541, 'Grisignano di Zocco', 'Grisignano di Zocco', 'Grisignano,Grisignano di Zocco', 45.4868100, 11.7079400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84542, 'Grigno', 'Grigno', 'Grigno,gurinyo,グリーニョ', 46.0156900, 11.6356300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84543, 'Grignasco', 'Grignasco', 'Grignasch,Grignasco', 45.6798200, 8.3444200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84544, 'Gricignano di Aversa', 'Gricignano di Aversa', 'Gricignano', 40.9797300, 14.2308700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84545, 'Griante', 'Griante', 'Griant,Griante,Gryjanteh,ge li ya en tai,guriante,Грианте,Грыянтэ,Гріанте,Գրիանտե,グリアンテ,格里亚恩泰', 45.9952800, 9.2355400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84546, 'Grezzana', 'Grezzana', 'Grezzana', 45.5227200, 11.0174300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84547, 'Greve in Chianti', 'Greve in Chianti', 'Greve,Greve In Chianti', 43.5851400, 11.3171200, 'IT', '2017-02-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84548, 'Gressoney-Saint-Jean', 'Gressoney-Saint-Jean', 'Gressonei San Giovanni,Gressoney,Gressoney-Saint-Jean,Gréssonei San Giovanni', 45.7727200, 7.8280200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84549, 'Gressoney-La-Trinitè', 'Gressoney-La-Trinite', 'Gressonei-la-Trinita,Gressonei-la-Trinitá', 45.8296700, 7.8232100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84550, 'Gressan', 'Gressan', 'Gressan,Gressen', 45.7205000, 7.2931100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84551, 'Fontane-Zurane-Gresine', 'Fontane-Zurane-Gresine', '', 45.6333600, 10.0472000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84552, 'Greggio', 'Greggio', 'Greggio', 45.4514800, 8.3849400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84553, 'Greci', 'Greci', '', 41.2518200, 15.1691500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84554, 'Grazzano Badoglio', 'Grazzano Badoglio', 'Grazzano,Grazzano Badoglio,グラッツァーノ・バドーリオ', 45.0399600, 8.3110500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84555, 'Grazzanise', 'Grazzanise', '', 41.0897000, 14.0987800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84556, 'Gravina in Puglia', 'Gravina in Puglia', 'Gravina in Puglia', 40.8174800, 16.4191500, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84557, 'Gravellona Toce', 'Gravellona Toce', 'Gravellona,Gravellona Toce', 45.9285900, 8.4320900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84558, 'Gravellona', 'Gravellona', '', 45.3276600, 8.7641400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84559, 'Gravedona-San Gregorio', 'Gravedona-San Gregorio', 'Grabedona,Gravedona', 46.1463900, 9.3009400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84560, 'Cravagliana', 'Cravagliana', '', 45.8482700, 8.2018200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84561, 'Grauno', 'Grauno', 'Grauno,gurauno,グラウノ', 46.2303200, 11.2984700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84562, 'Gratacasolo', 'Gratacasolo', '', 45.8289700, 10.1291800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84563, 'Grassano', 'Grassano', 'Grassano', 40.6345700, 16.2779200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84564, 'Granze', 'Granze', 'Grance,Granica,Granze,ge lan ze,gurantsu~e,Гранце,Գրանցե,グランツェ,格兰泽', 45.1564900, 11.7147100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84565, 'Grantorto', 'Grantorto', 'Grantorto,gurantoruto,グラントルト', 45.6026800, 11.7317500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84566, 'Granozzo con Monticello', 'Granozzo con Monticello', 'Granozzo con Monticello', 45.3601600, 8.5733400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84567, 'Grandate', 'Grandate', '', 45.7671500, 9.0534900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84568, 'Gragnano Trebbiense', 'Gragnano Trebbiense', 'Gragnano Trebbiense', 45.0122500, 9.5713900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84569, 'Gragnano', 'Gragnano', 'Gragnano,Gran''jano,guranyano,Граньяно,グラニャーノ', 40.6890700, 14.5203600, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84570, 'Graglia', 'Graglia', 'Graglia,guraria,グラーリア', 45.5580000, 7.9789900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84571, 'Graffignano', 'Graffignano', 'Graffignano,guraffinyano,グラッフィニャーノ', 42.5753900, 12.2012100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84572, 'Gradoli', 'Gradoli', 'Gradoli', 42.6450200, 11.8558000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84573, 'Grado', 'Grado', 'Grado,Grau,Gravo,gurado,グラード', 45.6777400, 13.4032300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84574, 'Gradisca d''Isonzo', 'Gradisca d''Isonzo', 'Gradisca,Gradisca d''Isonzo,Gradisca d’Isonzo,Gradiscje dal Lusinc,Gradiska', 45.8925000, 13.5016700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84575, 'Gradara', 'Gradara', 'Gradara', 43.9385800, 12.7696500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84576, 'Gozzano', 'Gozzano', 'Gozzano', 45.7427300, 8.4365900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84577, 'Gottolengo', 'Gottolengo', 'Gottolengo,gottorengo,ゴットレンゴ', 45.2927800, 10.2685500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84578, 'Gossolengo', 'Gossolengo', 'Gossolengo', 45.0024800, 9.6179900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84579, 'Gosaldo', 'Gosaldo', 'Gosaldo', 46.2214200, 11.9557000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84580, 'Gorzegno', 'Gorzegno', 'Gorzegno', 44.5123600, 8.1348000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84581, 'Gorreto', 'Gorreto', 'Goreio,Gorreto', 44.6048500, 9.2912600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84582, 'Goro', 'Goro', 'Goro', 44.8515000, 12.2965100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84583, 'Gorno', 'Gorno', 'Gorno', 45.8624900, 9.8415500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84584, 'Gorle', 'Gorle', 'Gorle', 45.7012700, 9.7138200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84585, 'Gorla Maggiore', 'Gorla Maggiore', '', 45.6638800, 8.8953700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84586, 'Gorizia', 'Gorizia', 'Goerz,Gorica,Goricija,Gorizia,Gorycja,Gurize,Gurizze,Görz,QGO,goritsu~ia,Гориция,ゴリツィア', 45.9408800, 13.6216700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84587, 'Goriano Sicoli', 'Goriano Sicoli', 'Goriano Sicoli', 42.0801100, 13.7745900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84588, 'Gorgonzola', 'Gorgonzola', 'Gorgonzola,gorugonzora,ゴルゴンゾーラ', 45.5306900, 9.4053100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84589, 'Gorgoglione', 'Gorgoglione', 'Gorgoglione', 40.3953200, 16.1445600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84590, 'Gorga', 'Gorga', 'Gorga,ge er jia,goleuga,goruga,Горга,Գորգա,ゴルガ,戈尔加,고르가', 41.6546800, 13.1066300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84591, 'Gordona', 'Gordona', 'Gardona,Gordona,Gurduna,ge er duo na,gorudona,Гордона,Գոռդոնա,ゴルドーナ,戈尔多纳', 46.2917600, 9.3670000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84592, 'Gonzaga', 'Gonzaga', 'Gonzaga,gondzaga,gonzaga,გონძაგა,ゴンザーガ', 44.9519300, 10.8191300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84593, 'Gonars', 'Gonars', 'Gonars', 45.8974000, 13.2440200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84594, 'Golfo Aranci', 'Golfo Aranci', 'Golfo Aranci,Golfo degli Aranci', 40.9833300, 9.6333300, 'IT', '2017-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84595, 'Golasecca', 'Golasecca', 'Golasecca', 45.6982100, 8.6611200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84596, 'Goito', 'Goito', 'Goito,goito,ゴーイト', 45.2507600, 10.6612100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84597, 'Godo', 'Godo', '', 44.3917300, 12.0749500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84598, 'Godiasco', 'Godiasco', 'Godiasco', 44.8964500, 9.0566700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84599, 'Godega', 'Godega', 'Godega,Godega Sant Urbano,Godega di Sant''Urbano,Godeno di Sant''Urbano', 45.9285900, 12.3968700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84600, 'Glorenza', 'Glorenza', 'Clornum,Glarehnca,Glorenca,Glorenza,Glurns,ge luo lun zha,gurorentsu~a,Гларэнца,Глоренца,Գլորենցա,グロレンツァ,格洛伦扎', 46.6710500, 10.5568400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84601, 'Giussano', 'Giussano', 'Giuessan,Giussano,Giüssàn,Gluxianum,jussano,ジュッサーノ', 45.7000400, 9.2089000, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84602, 'Giussago', 'Giussago', 'Giussago', 45.2841700, 9.1399600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84603, 'Giurdignano', 'Giurdignano', 'Giurdignano', 40.1236700, 18.4315500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84604, 'Giungano', 'Giungano', 'Giungano', 40.3945000, 15.1079200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84605, 'Giulianova', 'Giulianova', 'Giulianova', 42.7538100, 13.9665000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84606, 'Giuliano Teatino', 'Giuliano Teatino', 'Giuliano Teanno,Giuliano Teatino', 42.3122000, 14.2808200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84607, 'Giuliano di Roma', 'Giuliano di Roma', 'Giuliano di Roma', 41.5393300, 13.2802800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84608, 'Giulianello', 'Giulianello', '', 41.6861000, 12.8791700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84609, 'Giugliano in Campania', 'Giugliano in Campania', 'Giuglian,Giugliano,Giugliano in Campania,Giugliàn,ジュリアーノ・イン・カンパーニア', 40.9284900, 14.2019700, 'IT', '2015-10-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84610, 'Giuggianello', 'Giuggianello', 'Giuggianello', 40.0938300, 18.3689400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84611, 'Gissi', 'Gissi', 'Gissi', 42.0180300, 14.5448400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84612, 'Giovinazzo', 'Giovinazzo', 'Dzhovinacco,Giovinazzo,Джовинаццо', 41.1850000, 16.6705400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84613, 'Giove', 'Giove', 'Giove', 42.5098800, 12.3301500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84614, 'Gioia Sannitica', 'Gioia Sannitica', 'Gioia Sannitica', 41.2996500, 14.4438100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84615, 'Gioia del Colle', 'Gioia del Colle', 'Dzhoja-del''-Kolle,Gioia del Colle,Gioja del Colle,Джоя-дель-Колле', 40.7996800, 16.9229800, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84616, 'Gioia dei Marsi', 'Gioia dei Marsi', 'Gioia de'' Marsi,Gioia dei Marsi', 41.9569700, 13.6905700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84617, 'Gioi', 'Gioi', 'Gioi', 40.2897000, 15.2180600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84618, 'Marina di Ginosa', 'Marina di Ginosa', 'Ginosa Marina,Marina di Ginosa', 40.4283300, 16.8800300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84619, 'Ginosa', 'Ginosa', 'Ginosa', 40.5769000, 16.7565500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84620, 'Ginestra degli Schiavoni', 'Ginestra degli Schiavoni', 'Ginestra degli Schiavoni', 41.2799200, 15.0437400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84621, 'Ginestra Fiorentina', 'Ginestra Fiorentina', '', 43.7093900, 11.0738400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84622, 'Ginestra', 'Ginestra', 'Dzhinestra,Genestrum,Ginestra,Jinestra,Xhinestra,Zhura,ji nei si te la,jinesutora,jynstra,Джинестра,Ջինեստրա,جينسترا,ジネストラ,吉内斯特拉', 40.9309200, 15.7349700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84623, 'Gildone', 'Gildone', 'Gildone', 41.5090100, 14.7402000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84624, 'Gignese', 'Gignese', '', 45.8639600, 8.5094300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84625, 'Giglio Castello', 'Giglio Castello', 'Giglio,Giglio Castello', 42.3648600, 10.9014000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84626, 'Giffoni Valle Piana', 'Giffoni Valle Piana', 'Giffoni Valle Piana', 40.7181100, 14.9423500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84627, 'Giavera del Montello', 'Giavera del Montello', 'Giavera,Giavera del Montello', 45.7937400, 12.1666700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84628, 'Giaveno', 'Giaveno', 'Giaven,Giaveno,javu~eno,ジャヴェーノ', 45.0443500, 7.3472200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84629, 'Giave', 'Giave', 'Giave', 40.4522400, 8.7517500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84630, 'Giarole', 'Giarole', 'Giarole', 45.0614800, 8.5673000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84631, 'Giano Vetusto', 'Giano Vetusto', 'Giano Vetusto', 41.2027200, 14.1934200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84632, 'Giano dell''Umbria', 'Giano dell''Umbria', 'Giano dell''Umbria', 42.8338400, 12.5777700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84633, 'Piano di Coreglia-Ghivizzano', 'Piano di Coreglia-Ghivizzano', '', 44.0333300, 10.5166700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84634, 'Ghislarengo', 'Ghislarengo', 'Ghislarengo', 45.5285600, 8.3851400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84635, 'Ghisalba', 'Ghisalba', 'Ghisalba', 45.5935400, 9.7576500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84636, 'Ghilarza', 'Ghilarza', 'Ghilarza', 40.1211900, 8.8361200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84637, 'Ghiffa', 'Ghiffa', 'Ghiffa,giffa,ギッファ', 45.9529800, 8.6043000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84638, 'Ghemme', 'Ghemme', '', 45.5986300, 8.4201300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84639, 'Ghedi', 'Ghedi', 'Gedi,Ghedi,gedi,Геди,ゲーディ', 45.4020400, 10.2768100, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84640, 'Gesualdo', 'Gesualdo', 'Dzezualdo,Dzhezual''do,Dzhezualdo,Gesualdo,Gesualdu,Iesualdum,Jezualdo,jesualdo,jezuarudo,Џезуалдо,Джезуалдо,Джезуальдо,Ջեզուալդո,ジェズアルド,제수알도', 41.0055400, 15.0726200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84641, 'Gessopalena', 'Gessopalena', 'Gessopalena', 42.0552100, 14.2736700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84642, 'Quartiano', 'Quartiano', '', 45.3580000, 9.4176000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84643, 'Gerosa', 'Gerosa', 'Dzhehroza,Dzheroza,Gerosa,Gerusa,Jeroza,jeroza,jie luo sa,Джероза,Джэроза,Ջերոզա,ジェローザ,杰罗萨', 45.8498000, 9.5716100, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84644, 'Gerola Alta', 'Gerola Alta', 'Gerola,Gerola Alta', 46.0600300, 9.5502500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84645, 'Germagnano', 'Germagnano', 'Dzhehrman''jana,Dzherman''jano,Gerinagnano,Germagnan,Germagnano,Germanianum,Jermaniano,jerumanyano,jie er ma ni ya nuo,Джерманьяно,Джэрманьяна,Ջերմանիանո,ジェルマニャーノ,杰尔马尼亚诺', 45.2631700, 7.4688600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84646, 'Gerenzago', 'Gerenzago', 'Gerenzago', 45.2063300, 9.3613700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84647, 'Gerano', 'Gerano', 'Gerano,jerano,ジェラーノ', 41.9347400, 12.9903400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84648, 'Gera Lario', 'Gera Lario', 'Gera', 46.1700300, 9.3673600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84649, 'Genzone', 'Genzone', 'Genzone', 45.1796200, 9.3482900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84650, 'Genzano di Roma', 'Genzano di Roma', 'Dzhencano-di-Roma,Genzano,Genzano di Roma,Дженцано-ди-Рома,ジェンツァーノ・ディ・ローマ', 41.7070600, 12.6890400, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84651, 'Genzano di Lucania', 'Genzano di Lucania', 'Genzano,Genzano di Lucania', 40.8458900, 16.0312400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84652, 'Genoa', 'Genoa', 'Cenova,Dzenova,Dženova,GOA,Genes,Genoa,Genova,Genovo,Genua,Genuja,Genès,Genúa,Gènova,Génova,Gênes,Janov,Xenova - Genova,Xénova - Genova,Zena,genua,jeno''a,jenoba,jenovu~a,jnwa,jnwt,re na ya,Ĝenovo,Ђенова,Генуа,Генуя,גנואה,جنوا,جنوة,जेनोआ,გენუა,ジェノヴァ,热那亚,제노바', 44.4047800, 8.9443900, 'IT', '2017-05-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84653, 'Genola', 'Genola', 'Genola', 44.5905300, 7.6611400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84654, 'Genivolta', 'Genivolta', 'Genivolta', 45.3325700, 9.8772600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84655, 'Genga', 'Genga', 'Genga,jenga,ジェンガ', 43.4303200, 12.9354900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84656, 'Genazzano', 'Genazzano', 'Genazzano,jenattsu~ano,ジェナッツァーノ', 41.8280700, 12.9719600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84657, 'Gemonio', 'Gemonio', '', 45.8787800, 8.6747800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84658, 'Gemona', 'Gemona', 'Gemona,Gemona del Friuli,Glemone', 46.2740500, 13.1223700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84659, 'Gemmano', 'Gemmano', 'Gemmano,Germmano', 43.9039300, 12.5809100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84660, 'Gazzuolo', 'Gazzuolo', 'Gazzuolo', 45.0623800, 10.5716100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84661, 'Gazzo', 'Gazzo', '', 45.5824100, 11.7072400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84662, 'Gazzo', 'Gazzo', '', 45.1796800, 10.8970600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84663, 'Gazzaniga', 'Gazzaniga', 'Gazzaniga', 45.7933900, 9.8297600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84664, 'Gazoldo degli Ippoliti', 'Gazoldo degli Ippoliti', 'Gazoldo,Gazoldo degli Ippoliti,Gazzoldo d''Ippoliti', 45.1999900, 10.5783900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84665, 'Gavorrano', 'Gavorrano', 'Gavorrano', 42.9252600, 10.9068100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84666, 'Gavoi', 'Gavoi', 'Gavoi', 40.1613000, 9.1946200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84667, 'Gavirate', 'Gavirate', '', 45.8370700, 8.7261900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84668, 'Gavignano', 'Gavignano', 'Gavignano,gavu~inyano,ガヴィニャーノ', 41.6989100, 13.0503200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84669, 'Gavi', 'Gavi', 'Gavi,gavu~i,ガーヴィ', 44.6862700, 8.8071700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84670, 'Gavello', 'Gavello', 'Gavello', 45.0246900, 11.9136800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84671, 'Gavardo-Sopraponte', 'Gavardo-Sopraponte', 'Gavardo,gavu~arudo,ガヴァルド', 45.5893900, 10.4425700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84672, 'Gattinara', 'Gattinara', 'Gacinara,Gatinaria,Gatinera,Gatinèra,Gattinara,gattinara,jia di na la,Гаттинара,Гаттінара,Гацінара,ガッティナーラ,加蒂纳拉', 45.6130900, 8.3646300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84673, 'Gassino Torinese', 'Gassino Torinese', 'Gassino,Gassino Torinese,Gasso,Gássino,ガッシーノ・トリネーゼ', 45.1290700, 7.8293400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84674, 'Garzeno', 'Garzeno', '', 46.1340900, 9.2496400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84675, 'Garlenda', 'Garlenda', 'Garlenda', 44.0332500, 8.0954600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84676, 'Garlasco', 'Garlasco', 'Garlasch,Garlasco,Garlascum,Garlasko,garurasuko,gharlaskw,jia er la si ke,Гарласко,Գարլասկո,غارلاسكو,ガルラスコ,加尔拉斯科', 45.1954000, 8.9231400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84677, 'Gargnano', 'Gargnano', 'Gargnano,garunyano,ガルニャーノ', 45.6858600, 10.6586900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84678, 'Gargazzone', 'Gargazzone', 'Gargaccone,Gargacconeh,Gargacone,Gargazon,Gargazzone,Gargezanum,garugattsu~one,jia er jia zuo nei,Гаргацоне,Гаргаццоне,Гаргаццонэ,Գարգացոնե,ガルガッツォーネ,加尔加佐内', 46.5845600, 11.2015600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84679, 'Garessio', 'Garessio', 'Garessio', 44.2070500, 8.0177800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84680, 'Gardone Val Trompia', 'Gardone Val Trompia', 'Gardone Val Trompia,ガルドーネ・ヴァル・トロンピア', 45.6913700, 10.1863500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84681, 'Gardone Riviera', 'Gardone Riviera', 'Gardone Riviera,ガルドーネ・リヴィエーラ', 45.6239600, 10.5668200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84682, 'Garda', 'Garda', 'Garda,garuda,Гарда,ガルダ', 45.5788900, 10.7176300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84683, 'Garbagnate Milanese', 'Garbagnate Milanese', 'Garbagnate Milanese,ガルバニャーテ・ミラネーゼ', 45.5743800, 9.0753700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84684, 'Garaguso', 'Garaguso', 'Garaguso', 40.5486600, 16.2282700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84685, 'Garadassi', 'Garadassi', 'Brintazzi', 44.7542900, 9.1539300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84686, 'Ganna', 'Ganna', '', 45.9021200, 8.8260600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84687, 'Gandino', 'Gandino', 'Gandino', 45.8108800, 9.8976700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84688, 'Ganda', 'Ganda', 'Enetal,Ganda,Ganda in Val Martello,Granda di Martello,Martell,Martello,maruterro,マルテッロ', 46.5545900, 10.7804200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84689, 'Gambolò', 'Gambolo', 'Gambolo,Gambolò', 45.2620900, 8.8582000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84690, 'Gambettola', 'Gambettola', 'Gambettola', 44.1174800, 12.3370500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84691, 'Gamberale', 'Gamberale', 'Gamberale', 41.9052900, 14.2084500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84692, 'Gambatesa', 'Gambatesa', 'Gambalesa,Gambatesa', 41.5086100, 14.9124000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84693, 'Gambassi Terme', 'Gambassi Terme', '', 43.5357600, 10.9516100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84694, 'Gambasca', 'Gambasca', 'Gambasca', 44.6295000, 7.3468600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84695, 'Gambarana', 'Gambarana', 'Gambarana', 45.0287400, 8.7628200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84696, 'Gambara', 'Gambara', 'Gambara,ganbara,ガンバラ', 45.2536600, 10.2943400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84697, 'Gamalero', 'Gamalero', 'Gamaleri,Gamalero', 44.8085000, 8.5411600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84698, 'Galzignano', 'Galzignano', '', 45.3079800, 11.7313400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84699, 'Galugnano', 'Galugnano', '', 40.2560100, 18.2147300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84700, 'Galtellì', 'Galtelli', 'Galtelli,Galtellì', 40.3845100, 9.6124100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84701, 'Galluccio', 'Galluccio', 'Galluccio,Galluccio vald,Gallucciu,Galluchcho,Gallutium,Galucho,gallucho,garrutcho,jia lu qiao,Галлуччо,Галучо,Գալուչո,ガッルッチョ,加卢乔,갈루초', 41.3523200, 13.9537200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84702, 'Gallo', 'Gallo', '', 44.7314400, 11.5528400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84703, 'Gallo Matese', 'Gallo Matese', '', 41.4645200, 14.2250200, 'IT', '2012-03-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84704, 'Gallipoli', 'Gallipoli', 'Gallipoli,Kaddhipuli,Галлиполи', 40.0559400, 17.9908800, 'IT', '2015-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84705, 'Gallio', 'Gallio', 'Galeum,Galio,Gallio,Gałio,garrio,jia liao,Галлио,Галліо,Գալիո,ガッリオ,加廖', 45.8850600, 11.5341700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84706, 'Gallinaro', 'Gallinaro', 'Gallinaro', 41.6550200, 13.7979900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84707, 'Galliera Veneta', 'Galliera Veneta', 'Galliera Veneta', 45.6675000, 11.8221700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84708, 'Gallicchio', 'Gallicchio', 'Gallicchio', 40.2923200, 16.1356100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84709, 'Gallicano nel Lazio', 'Gallicano nel Lazio', 'Gallicano nel Lazio,ガッリカーノ・ネル・ラーツィオ', 41.8643300, 12.8354300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84710, 'Gallicano', 'Gallicano', 'Gallicano', 44.0583300, 10.4420900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84711, 'Galliate', 'Galliate', 'Galliate', 45.4794200, 8.6981500, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84712, 'Gallese', 'Gallese', 'Gallese', 42.3737600, 12.3964600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84713, 'Gallarate', 'Gallarate', 'Gallarate,Галларате', 45.6601900, 8.7916400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84714, 'Galeata', 'Galeata', 'Galeata,gareata,ガレアータ', 43.9960700, 11.9105700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84715, 'Galbiate', 'Galbiate', 'Galbiate', 45.8163500, 9.3790200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84716, 'Galatone', 'Galatone', 'Galatone', 40.1467300, 18.0693700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84717, 'Galatina', 'Galatina', 'Aspedro,Galatina', 40.1741600, 18.1703200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84718, 'Gais', 'Gais', 'Cais,Gais,gaisu,ガイス', 46.8365800, 11.9493100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84719, 'Gaiole in Chianti', 'Gaiole in Chianti', 'Gaiole in Chianti,ガイオーレ・イン・キアンティ', 43.4669700, 11.4338600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84720, 'Gaiola', 'Gaiola', 'Gaiola,Gajola', 44.3355400, 7.4089600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84721, 'Gaibanella-Sant''Edigio', 'Gaibanella-Sant''Edigio', '', 44.7666700, 11.6500000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84722, 'Gaiba', 'Gaiba', 'Gaiba', 44.9457300, 11.4808700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84723, 'Gaiarine', 'Gaiarine', 'Gaiarine', 45.8808300, 12.4814200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84724, 'Gagliole', 'Gagliole', 'Gagliole', 43.2381200, 13.0678200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84725, 'Gagliano Aterno', 'Gagliano Aterno', 'Gagliano Aterno', 42.1259800, 13.7002300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84726, 'Galliano', 'Galliano', 'Gagliano,Galliano', 44.0172500, 11.2935300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84727, 'Gaglianico', 'Gaglianico', 'Gaglianico', 45.5371800, 8.0783900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84728, 'Gaggio Montano', 'Gaggio Montano', 'Gaggio Montano', 44.1958300, 10.9351800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84729, 'Gaggio', 'Gaggio', '', 44.6345800, 11.0133400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84730, 'Gaggiano', 'Gaggiano', 'Gaggiano,Oaggiano,gajjano,ガッジャーノ', 45.4048400, 9.0348800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84731, 'Gaeta', 'Gaeta', 'Gaeta,Gaete,Gaieta,Gaète,gaeta,Гаета,ガエータ', 41.2140800, 13.5708200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84732, 'Gaby', 'Gaby', 'Gaby', 45.7130000, 7.8822400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84733, 'Gabicce Mare', 'Gabicce Mare', '', 43.9647100, 12.7564100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84734, 'Gabiano', 'Gabiano', 'Gabian,Gabiano', 45.1571400, 8.1946900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84735, 'Futani', 'Futani', 'Futani', 40.1515600, 15.3236600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84736, 'Fusine', 'Fusine', '', 46.3758900, 12.1254700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84737, 'Fusine', 'Fusine', '', 46.1494900, 9.7497500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84738, 'Fusignano', 'Fusignano', 'Fusignano,fujinyano,フジニャーノ', 44.4665600, 11.9563600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84739, 'Furore', 'Furore', 'Furore,Фуроре', 40.6206100, 14.5490400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84740, 'Furci', 'Furci', 'Furci', 42.0074600, 14.5880200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84741, 'Fumone', 'Fumone', 'Fumone', 41.7346100, 13.2701500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84742, 'Fumane', 'Fumane', '', 45.5416000, 10.8854800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84743, 'Fucecchio', 'Fucecchio', 'Fucecchio,Fuchekkio,Фучеккио', 43.7329200, 10.7974900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84744, 'Fubine', 'Fubine', 'Fubin-i,Fubine', 44.9630500, 8.4281400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84745, 'Frugarolo', 'Frugarolo', 'Frugarolo,furugaroro,フルガローロ', 44.8392400, 8.6816500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84746, 'Frosolone', 'Frosolone', 'Frosolone', 41.6000600, 14.4457800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84747, 'Frosinone', 'Frosinone', 'Fresulone,Frosinone,Frozinone,QFR,furojinone,Фрозиноне,フロジノーネ', 41.6397600, 13.3410900, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84748, 'Frontone', 'Frontone', 'Frontone', 43.5147800, 12.7379100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84749, 'Frontino', 'Frontino', '', 43.7645600, 12.3767500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84750, 'Front', 'Front', 'Front,Fronta,furonto,フロント', 45.2794100, 7.6642500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84751, 'Frisanco', 'Frisanco', 'Frisanc,Frisanco', 46.2124600, 12.7262600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84752, 'Frisa', 'Frisa', 'Frisa', 42.2657200, 14.3762500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84753, 'Frigento', 'Frigento', 'Frigento', 41.0110300, 15.1002600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84754, 'Fresagrandinaria', 'Fresagrandinaria', 'Fresagrandinaria', 41.9790000, 14.6621100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84755, 'Fregona', 'Fregona', 'Fregona,Fregono', 46.0079500, 12.3386400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84756, 'Fregene', 'Fregene', '', 41.8505100, 12.1967100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84757, 'Fratta Todina', 'Fratta Todina', 'Fracta Tudertina,Frata Todina,Fratta,Fratta Todina,Fratta-Todina,frata twdyna,fu la ta tuo di na,peulatatodina,Фрата Тодина,Фратта-Тодина,Фратта-Тодіна,Ֆրատա Տոդինա,فراتا تودينا,フラッタ・トディーナ,弗拉塔托迪纳,프라타토디나', 42.8568400, 12.3636600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84758, 'Fratta Polesine', 'Fratta Polesine', 'Fratta,Fratta Polesine', 45.0281900, 11.6426500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84759, 'Frattaminore', 'Frattaminore', 'Frattaminore,furattaminore,フラッタミノーレ', 40.9558000, 14.2720100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84760, 'Frattamaggiore', 'Frattamaggiore', 'Frattamadzhore,Frattamaggiore,furattamajjore,Фраттамаджоре,フラッタマッジョーレ', 40.9414000, 14.2758800, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84761, 'Frasso Telesino', 'Frasso Telesino', 'Frasso Telesino', 41.1568200, 14.5278300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84762, 'Frasso Sabino', 'Frasso Sabino', 'Frasso Sabino', 42.2292700, 12.8065800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84763, 'Frassinoro', 'Frassinoro', 'Frasinoro,Frassinoro,Fraxinorium,frasynwrw,fu la xi nuo luo,furasshinoro,Фрасиноро,Фрассиноро,Фрассіноро,Ֆրասինորո,فراسينورو,フラッシノーロ,弗拉西诺罗', 44.2945100, 10.5711700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84764, 'Frassino', 'Frassino', 'Frassino', 44.5721100, 7.2753600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84765, 'Frassinetto', 'Frassinetto', 'Frassinej,Frassineto,Frassinetto,Frassinèj,furasshinetto,フラッシネット', 45.4383400, 7.6088600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84766, 'Frassineto Po', 'Frassineto Po', 'Frassineto Po', 45.1327100, 8.5352500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84767, 'Frassinello Monferrato', 'Frassinello Monferrato', 'Frassinello Olivola', 45.0332200, 8.3866600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84768, 'Frascati', 'Frascati', 'Frascati,furasukati,フラスカーティ', 41.8091000, 12.6794200, 'IT', '2015-07-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84769, 'Frascaro', 'Frascaro', 'Frascaro,Frasche,Frasché', 44.8257500, 8.5312700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84770, 'Francolise', 'Francolise', 'Francolise', 41.1850100, 14.0567200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84771, 'Francolino', 'Francolino', '', 44.8966200, 11.6570100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84772, 'Francavilla in Sinni', 'Francavilla in Sinni', 'Francavilla,Francavilla in Sinni,Francavilla sul Sinni', 40.0814200, 16.2041700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84773, 'Francavilla Fontana', 'Francavilla Fontana', 'Francavilla Fontana', 40.5312300, 17.5852200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84774, 'Francavilla d''Ete', 'Francavilla d''Ete', 'Francavilla d''Ete', 43.1883700, 13.5403300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84775, 'Francavilla al Mare', 'Francavilla al Mare', 'Francavilla al Mare', 42.4215800, 14.2821700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84776, 'Framura', 'Framura', 'Framua,Framura', 44.2094600, 9.5539900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84777, 'Fraine', 'Fraine', 'Fraine', 41.9062400, 14.4878800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84778, 'Fragneto Monforte', 'Fragneto Monforte', 'Fragneto Monforte', 41.2463400, 14.7634200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84779, 'Fragneto L''Abate', 'Fragneto L''Abate', 'Fragneto l''Abate', 41.2558000, 14.7838200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84780, 'Fragagnano', 'Fragagnano', 'Fragagnano', 40.4302000, 17.4755300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84781, 'Frabosa Soprana', 'Frabosa Soprana', 'Frabosa Soprana', 44.2909400, 7.8035300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84782, 'Foza', 'Foza', '', 45.8970300, 11.6305300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84783, 'Fossombrone', 'Fossombrone', 'Fossombrone', 43.6901700, 12.8117300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84784, 'Fossato di Vico', 'Fossato di Vico', 'Fossato,Fossato di Vico', 43.2964400, 12.7612100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84785, 'Fossano', 'Fossano', 'Fossan,Fossano', 44.5507700, 7.7192200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84786, 'San Vendemiano-Fossamerlo', 'San Vendemiano-Fossamerlo', '', 45.8918000, 12.3299200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84787, 'Fossalunga', 'Fossalunga', '', 45.6916000, 12.0532000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84788, 'Fossalto', 'Fossalto', 'Fossalto', 41.6729300, 14.5457300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84789, 'Fossalta di Portogruaro', 'Fossalta di Portogruaro', 'Fossalta,Fossalta di Portogruaro,Fossalte', 45.7932900, 12.9099800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84790, 'Fossalta di Piave', 'Fossalta di Piave', 'Fossalta,Fossalta Maggiore,Fossalta di Piave,フォッサルタ・ディ・ピアーヴェ', 45.6449700, 12.5090200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84791, 'Fossacesia', 'Fossacesia', 'Fossacesia', 42.2419800, 14.4833900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84792, 'Fossa', 'Fossa', 'Fossa', 42.2927300, 13.4877900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84793, 'Fosdinovo', 'Fosdinovo', 'Fosdinovo,fozudinovu~o,フォズディノーヴォ', 44.1332000, 10.0177800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84794, 'Fortunago', 'Fortunago', 'Fortunago', 44.9216000, 9.1847100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84795, 'Fortezza', 'Fortezza', 'Fortecca,Francisci Oppidum,Franzensfeste,forutettsu~a,fu er tai zha,Фортецца,フォルテッツァ,福尔泰扎', 46.7896300, 11.6099800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84796, 'Forte dei Marmi', 'Forte dei Marmi', 'Forte dei Marmi', 43.9638800, 10.1747800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84797, 'Fornovo San Giovanni', 'Fornovo San Giovanni', 'Fornovo San Giovanni,Fornovo di San Giovanni', 45.4974200, 9.6773900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84798, 'Fornovo di Taro', 'Fornovo di Taro', 'Fornoue,Fornova Di Taro,Fornova Tara,Fornova de Taro,Fornovo di Taro,Furnovo-Ditaro', 44.6946500, 10.1017800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84799, 'Forno di Zoldo', 'Forno di Zoldo', 'Forno di Zoldo', 46.3501000, 12.1791300, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84800, 'Forno Canavese', 'Forno Canavese', 'Forn,Forno Canavese,フォルノ・カナヴェーゼ', 45.3428700, 7.5895100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84801, 'Forni di Sotto', 'Forni di Sotto', 'Forni di Sotto,Fors Disot', 46.3937900, 12.6721000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84802, 'Forni di Sopra', 'Forni di Sopra', 'For Disore,Forni di Sopra,Fors Disore', 46.4202800, 12.5831200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84803, 'Forni Avoltri', 'Forni Avoltri', 'Forni Avoltri,Fors di Voltri', 46.5861500, 12.7751000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84804, 'Fornelli', 'Fornelli', 'Fornelli', 41.6067800, 14.1404100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84805, 'Fornaci di Barga', 'Fornaci di Barga', 'Catarozzo,Fornaci,Fornaci di Barga', 44.0489900, 10.4711100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84806, 'Fornaci', 'Fornaci', '', 45.6517000, 12.4373800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84807, 'Fornacette', 'Fornacette', '', 43.6702300, 10.5851200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84808, 'Fornacelle', 'Fornacelle', '', 43.9237700, 11.0352500, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84809, 'Formignana', 'Formignana', 'Formignana,Formignano', 44.8423000, 11.8593500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84810, 'Formigliana', 'Formigliana', 'Formigliana', 45.4292600, 8.2919300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84811, 'Formigine', 'Formigine', 'Formigine,Furmezen,Furmèżen,forumijine,フォルミージネ', 44.5726800, 10.8473700, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84812, 'Formigara', 'Formigara', 'Formigara', 45.2230700, 9.7707600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84813, 'Formicola', 'Formicola', 'Formicola', 41.2108400, 14.2346200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84814, 'Formia', 'Formia', 'Formia,forumia,フォルミア', 41.2563200, 13.6088800, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84815, 'Formello', 'Formello', 'Formello,forumerro,フォルメッロ', 42.0624600, 12.3943500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84816, 'Formazza', 'Formazza', 'Formazza', 46.3768900, 8.4257100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84817, 'Forlimpopoli', 'Forlimpopoli', 'Forlimpopoli,forurinpopori,フォルリンポーポリ', 44.1910700, 12.1287300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84818, 'Forlì del Sannio', 'Forli del Sannio', 'Forli del Sannio,Forlì del Sannio', 41.6959300, 14.1795200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84819, 'Forlì', 'Forli', 'FRL,Forli,Forlì,Forum Livii,foruri,Форли,フォルリ', 44.2217700, 12.0414400, 'IT', '2017-07-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84820, 'Forio', 'Forio', 'Forio,Forio d''Ischia,forio,フォリーオ', 40.7375700, 13.8600300, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84821, 'Forino', 'Forino', 'Forino', 40.8582900, 14.7325400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84822, 'Forenza', 'Forenza', 'Forenza', 40.8604100, 15.8545700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84823, 'Forcoli', 'Forcoli', '', 43.6037400, 10.7051400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84824, 'Forchia', 'Forchia', 'Forchia', 41.0314400, 14.5357300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84825, 'Forano', 'Forano', 'Forano,Foranu,Furrianum,forano,fu la nuo,polano,Форано,Ֆորանո,フォラーノ,福拉诺,포라노', 42.2976800, 12.5946900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84826, 'Foppolo', 'Foppolo', 'Foppolo', 46.0429700, 9.7577500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84827, 'Fonzaso', 'Fonzaso', 'Foncazo,Fonsaxo,Fonzaso,Fonzasum,feng zha suo,fontsu~azo,Фонцазо,Ֆոնցազո,フォンツァーゾ,丰扎索', 46.0164000, 11.7989700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84828, 'Fontignano', 'Fontignano', 'Fontignano', 43.0243600, 12.1919000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84829, 'Fontevivo', 'Fontevivo', 'Fontevivo', 44.8594200, 10.1728100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84830, 'Fontegreca', 'Fontegreca', 'Fontegreca', 41.4565300, 14.1838500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84831, 'Fontechiari', 'Fontechiari', '', 41.6678800, 13.6750400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84832, 'Fontecchio', 'Fontecchio', 'Fontecchio', 42.2302700, 13.6061300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84833, 'Fonteblanda', 'Fonteblanda', '', 42.5646300, 11.1732500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84834, 'Fontaniva', 'Fontaniva', 'Fontaniva', 45.6351600, 11.7538100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84835, 'Fontanile', 'Fontanile', 'Fontanile', 44.7529500, 8.4213400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84836, 'Fontanigorda', 'Fontanigorda', 'Fontanegorda,Fontanigorda', 44.5454000, 9.3054800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84837, 'Fontanetto Po', 'Fontanetto Po', 'Fontanetto Po', 45.1943600, 8.1920600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84838, 'Fontaneto D''Agogna', 'Fontaneto D''Agogna', 'Fontaneto d''Agogna', 45.6434700, 8.4787900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84839, 'Fontanelle', 'Fontanelle', 'Fontanelle', 45.8334500, 12.4662500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84840, 'Fontanellato', 'Fontanellato', '', 44.8818700, 10.1763100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84841, 'Fontanella', 'Fontanella', 'Fontanella', 45.4690300, 9.8024800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84842, 'Fontanelice', 'Fontanelice', 'Fontanelice', 44.2593200, 11.5585200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84843, 'Fontanarosa', 'Fontanarosa', 'Fontanarosa', 41.0181200, 15.0205500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84844, 'Collefontana-Fontana Liri Inferiore', 'Collefontana-Fontana Liri Inferiore', '', 41.6116600, 13.5494500, 'IT', '2014-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84845, 'Fontana Nuova-Bevia', 'Fontana Nuova-Bevia', '', 46.4115900, 10.9684300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84846, 'Monticelli-Fontana', 'Monticelli-Fontana', '', 45.4296500, 11.1372900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84847, 'Fonni', 'Fonni', 'Foni,Fonne,Fonni,Fonnis,Onne,feng ni,fon''ni,Фони,Фонни,Фонні,Ֆոննի,フォンニ,丰尼', 40.1193200, 9.2534700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84848, 'Fondo', 'Fondo', 'Fondo,Fondo in Val di Non,fondo,フォンド', 46.4388000, 11.1372300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84849, 'Fondi', 'Fondi', 'Fonda,Fondi,fondi,pwndy,Фонда,פונדי,フォンディ', 41.3578700, 13.4271800, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84850, 'Fombio', 'Fombio', 'Fombio,fonbio,フォンビオ', 45.1412600, 9.6804300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84851, 'Follonica', 'Follonica', 'Follonica,Follonika,Фоллоника', 42.9277900, 10.7645100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84852, 'Follina', 'Follina', 'Follina', 45.9535200, 12.1198500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84853, 'Foligno', 'Foligno', 'Foligno,Folin''o,forinyo,Фолиньо,フォリーニョ', 42.9548800, 12.7026800, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84854, 'Folignano', 'Folignano', 'Folignano', 42.8207000, 13.6327300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84855, 'Folgaria', 'Folgaria', 'Folgaria,forugaria,フォルガリーア', 45.9154300, 11.1682000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84856, 'Foiano di Val Fortore', 'Foiano di Val Fortore', 'Foiano,Foiano di Val Fortore', 41.3528300, 14.9763500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84857, 'Foiano della Chiana', 'Foiano della Chiana', 'Foiana della Chiana,Foiano,Foiano della Chiana,Fojano della Chiana', 43.2531800, 11.8164700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84858, 'Fognano', 'Fognano', '', 44.2050900, 11.7378200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84859, 'Foglizzo', 'Foglizzo', 'Foglizzo,Fojiss,forittsu~o,フォリッツォ', 45.2736100, 7.8208700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84860, 'Fogliano', 'Fogliano', 'Fogliano,Fogliano Redipuglia,Fogliano di Monfalcone,Fogliano di Redipuglia,Foian', 45.8655600, 13.4822200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84861, 'Foglianise', 'Foglianise', 'Figlianese,Foglianise', 41.1612700, 14.6711200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84862, 'Foggia', 'Foggia', 'FOG,Fodzha,Foggia,Fovea,byrwdja,fojja,fwdja,Фоджа,بيرودجا,فودجا,フォッジャ', 41.4584500, 15.5518800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84863, 'Fobello', 'Fobello', 'Fobello', 45.8900200, 8.1579900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84864, 'Flussio', 'Flussio', 'Flassin,Flussio', 40.2654500, 8.5381000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84865, 'Flumeri', 'Flumeri', 'Flumeri', 41.0762300, 15.1507200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84866, 'Florinas', 'Florinas', 'Fiolinas,Florinae,Florinas,fu luo li na si,furorinasu,Флоринас,Ֆլորինաս,フロリーナス,弗洛里纳斯', 40.6490000, 8.6654800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84867, 'Flero', 'Flero', 'Fleri,Flero,furero,フレーロ', 45.4825400, 10.1769400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84868, 'Flavon', 'Flavon', 'Flavon,furavu~on,フラヴォーン', 46.2980900, 11.0299300, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84869, 'Flaibano', 'Flaibano', 'Flaiban,Flaibano', 46.0583700, 12.9842400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84870, 'Fivizzano', 'Fivizzano', 'Fivizzano,fivu~ittsu~ano,フィヴィッツァーノ', 44.2378400, 10.1265000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84871, 'Fiumicino-Isola Sacra', 'Fiumicino-Isola Sacra', 'F''jumichino,Fiumicino,fiumichino,Фьюмичино,フィウミチーノ', 41.7709300, 12.2366200, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84872, 'Fiume Veneto', 'Fiume Veneto', 'Fiume Veneto,Vile di Flum', 45.9286500, 12.7381100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84873, 'Fiumana', 'Fiumana', '', 44.1432500, 11.9871900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84874, 'Fiumalbo-Dogana', 'Fiumalbo-Dogana', 'Fiumalbo', 44.1792500, 10.6472000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84875, 'Fiuggi', 'Fiuggi', 'Fiuggi,pywg''y,פיוג''י', 41.7978000, 13.2238600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84876, 'Fisciano', 'Fisciano', 'Fisciano', 40.7717500, 14.7945400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84877, 'Firenzuola', 'Firenzuola', 'Firenzuola', 44.1196800, 11.3818500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84878, 'Florence', 'Florence', 'FLR,Fflorens,Firenca,Firence,Firense,Firenz,Firenze,Firenzi,Florans,Floransa,Florenc,Florenca,Florence,Florenceje,Florenci,Florencia,Florencie,Florencij,Florencija,Florencja,Florenco,Florencėjė,Florens,Florensa,Florensiya,Florensya,Florenta,Florentia,Florentzia,Florenz,Florença,Florența,Florâns,Florència,Floréncia,Florénsa,Flórans,Flórens,Gorad Flarehncyja,Lungsod ng Florencia,Sciorenza,fei leng cui,firentsu~e,florensa,flwrans,flwrns,flwrnsa,flxrens,fu luo lun sa,peullolenseu,phlorens,phlorensa,pilenche,plorentsia,pyrnzh,Φλωρεντία,Горад Фларэнцыя,Фиренца,Флоренц,Флоренци,Флоренций,Флоренция,Флоренція,Ֆլորենցիա,פירנצה,פירענצע,فلورانس,فلورنس,فلورنسا,फ़्लोरेन्स,फ्लोरेन्स,ফ্লোরেন্স,ఫ్లోరెన్స్,ഫ്ലോറൻസ്,ฟลอเรนซ์,ཧྥུ་ལོ་རོན་ཟིའུ་ཡ།,ფლორენცია,フィレンツェ,佛罗伦萨,翡冷翠,플로렌스,피렌체', 43.7792500, 11.2462600, 'IT', '2017-06-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84879, 'Fiorenzuola d''Arda', 'Fiorenzuola d''Arda', 'Fiorenzuola d''Arda', 44.9243500, 9.9132900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84880, 'Fiorano', 'Fiorano', 'Fiorano Modenese,フィオラーノ・モデネーゼ', 44.5388900, 10.8116600, 'IT', '2015-07-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84881, 'Fino Mornasco', 'Fino Mornasco', 'Fino,Fino Mornasco', 45.7429000, 9.0499600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84882, 'Finale Ligure', 'Finale Ligure', 'Final-marina,Finale Ligure,O Fina,O Finâ', 44.1695200, 8.3436000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84883, 'Finale Emilia', 'Finale Emilia', 'Finale Emilia,Finale nell''Emilia', 44.8337300, 11.2937800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84884, 'Filottrano', 'Filottrano', 'Filottrano,firottorano,フィロットラーノ', 43.4355300, 13.3514100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84885, 'Filignano', 'Filignano', 'Filignano', 41.5457800, 14.0575700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84886, 'Filighera', 'Filighera', 'Filighera', 45.1749600, 9.3164600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84887, 'Filiano', 'Filiano', 'Filiano', 40.8104200, 15.7098400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84888, 'Filettole', 'Filettole', '', 43.8130700, 10.4023900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84889, 'Filetto', 'Filetto', 'Filetto,firetto,フィレット', 42.2293100, 14.2450100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84890, 'Filettino', 'Filettino', 'Filettino,Filettino Graziani', 41.8913100, 13.3253100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84891, 'Filacciano', 'Filacciano', 'Filacciano,firatchano,フィラッチャーノ', 42.2544500, 12.5988000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84892, 'Figline Valdarno', 'Figline Valdarno', 'Figline Valdarno', 43.6199500, 11.4719100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84893, 'Fiesso Umbertiano', 'Fiesso Umbertiano', 'Fiesso Umbertiano', 44.9607200, 11.6057600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84894, 'Fiesse', 'Fiesse', 'Fiesse,fiesse,フィエッセ', 45.2320700, 10.3241700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84895, 'Fiesole', 'Fiesole', 'Faesulae,Fiesole,Fiésole,fiezore,piesolle,フィエーゾレ,피에솔레', 43.8045500, 11.2948700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84896, 'Fiera di Primiero', 'Fiera di Primiero', 'Fiera di Primiero,Primeiro,フィエーラ・ディ・プリミエーロ', 46.1762100, 11.8287900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84897, 'Fiè Allo Sciliar', 'Fie Allo Sciliar', 'Fie allo Sciliar,Fiè allo Sciliar,Voels am Schlern,Vols,Völs am Schlern', 46.5167200, 11.5012800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84898, 'Fidenza', 'Fidenza', 'Fidency,Fidenza,San Donnino,Фиденцы', 44.8669400, 10.0603900, 'IT', '2015-08-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84899, 'Ficulle', 'Ficulle', 'Ficulle', 42.8319400, 12.0680100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84900, 'Ficarolo', 'Ficarolo', 'Ficarolo', 44.9542500, 11.4366200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84901, 'Fiavè', 'Fiave', 'Fiave,Fiavè,fiavu~e,フィアヴェ', 46.0045700, 10.8422500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84902, 'Trebbio', 'Trebbio', 'Fiastra', 43.0368500, 13.1539400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84903, 'Fiano Romano', 'Fiano Romano', 'Fiano Romano,フィアーノ・ロマーノ', 42.1553800, 12.5946700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84904, 'Fiano', 'Fiano', 'Fian,Fiano,fiano,フィアーノ', 45.2163100, 7.5260300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84905, 'Fiamignano', 'Fiamignano', 'Fiamignano', 42.2654600, 13.1241300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84906, 'Ferriere', 'Ferriere', 'Ferriere', 44.6438500, 9.4965700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84907, 'Ferrera Erbognone', 'Ferrera Erbognone', 'Ferrera Erbognone', 45.1145600, 8.8645400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84908, 'Ferrazzano', 'Ferrazzano', 'Ferrazzano', 41.5303300, 14.6722300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84909, 'Ferrara di Monte Baldo', 'Ferrara di Monte Baldo', 'Ferrara,Ferraro di Monte Baldo', 45.6740800, 10.8591100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84910, 'Ferrara', 'Ferrara', 'Ferrara,Ferrare,Феррара', 44.8380400, 11.6205700, 'IT', '2016-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84911, 'Ferrandina', 'Ferrandina', 'Ferrandina', 40.5008400, 16.4525800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84912, 'Ferrada', 'Ferrada', '', 44.4200800, 9.2101600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84913, 'Ferno', 'Ferno', 'Ferno,Fernum,fei er nuo,feruno,frnw,Ферно,Ֆերնո,فرنو,フェルノ,费尔诺', 45.6149600, 8.7569500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84914, 'Fermo', 'Fermo', 'Fermo,Firmum Picenum,ferumo,Фермо,フェルモ', 43.1629600, 13.7227400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84915, 'Fermignano', 'Fermignano', 'Fermignano,feruminyano,フェルミニャーノ', 43.6931100, 12.6543700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84916, 'Ferentino', 'Ferentino', 'Ferentino,Ферентино', 41.6911900, 13.2562000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84917, 'Ferentillo', 'Ferentillo', 'Ferentillo', 42.6202700, 12.7872600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84918, 'Fenestrelle', 'Fenestrelle', 'Fenestrehle,Fenestrele,Fenestrelle,Finis Terrae,Finistrelas,Finistrèlas,fei nei si te lei lai,fenesutorerre,Фенестреле,Фенестрелле,Фенестрэле,Ֆենեստրելլե,フェネストレッレ,费内斯特雷莱', 45.0359400, 7.0494100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84919, 'Feltre', 'Feltre', 'Feltre', 46.0208500, 11.9003100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84920, 'Felizzano', 'Felizzano', 'Felizzano,Flissan', 44.8993500, 8.4358400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84921, 'Felino', 'Felino', 'Felino,Filinum,fei li nuo,ferino,fylynw,Фелино,Феліно,Ֆելինո,فيلينو,フェリーノ,费利诺', 44.6990200, 10.2382800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84922, 'Feletto Umberto', 'Feletto Umberto', 'Feletto,Feletto Umberto', 46.1031700, 13.2219600, 'IT', '2012-02-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84923, 'Feletto', 'Feletto', 'Feletto,Flet,Flèt,feretto,フェレット', 45.3033600, 7.7448100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84924, 'Felegara', 'Felegara', '', 44.7218700, 10.1127300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84925, 'Favria', 'Favria', 'Favria,favuria,ファヴリア', 45.3309900, 7.6883400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84926, 'Favale di Malvaro', 'Favale di Malvaro', 'Fava,Favale di Malvaro,Favâ', 44.4516300, 9.2600000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84927, 'Fauglia', 'Fauglia', 'Fauglia', 43.5711000, 10.5138300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84928, 'Fascia', 'Fascia', 'Fascia', 44.5825500, 9.2213600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84929, 'Fasano', 'Fasano', 'Fasano,Fazano,Фазано', 40.8362500, 17.3600700, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84930, 'Farra di Soligo', 'Farra di Soligo', 'Farra,Farra di Soligo', 45.9052800, 12.1244400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84931, 'Farra d''Alpago', 'Farra d''Alpago', 'Farra,Farra d''Alpago', 46.1207900, 12.3587600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84932, 'Farnese', 'Farnese', 'Farnese,faruneze,ファルネーゼ', 42.5492600, 11.7263800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84933, 'Farini', 'Farini', 'Farini', 44.7126600, 9.5688700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84934, 'Farindola', 'Farindola', 'Farindola', 42.4429200, 13.8213700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84935, 'Fardella', 'Fardella', '', 40.1138100, 16.1697800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84936, 'Fara Vicentino', 'Fara Vicentino', '', 45.7436900, 11.5452900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84937, 'Fara San Martino', 'Fara San Martino', 'Fara San Martino', 42.0924800, 14.2089600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84938, 'Fara Novarese', 'Fara Novarese', 'Fara,Fara Novarese', 45.5544000, 8.4566400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84939, 'Fara in Sabina', 'Fara in Sabina', 'Fara,Fara in Sabina,Fara n Sabina,Fara sa Sabina,Fara-in-Sabina,fa la yi en sa bi na,palainsabina,Фара ин Сабина,Фара-ин-Сабина,Фара-ін-Сабіна,Ֆարա ին Սաբինա,ファーラ・イン・サビーナ,法拉伊恩萨比纳,파라인사비나', 42.2080700, 12.7296000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84940, 'Fara Gera d''Adda', 'Fara Gera d''Adda', '', 45.5565600, 9.5365600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84941, 'Fara Filiorum Petri', 'Fara Filiorum Petri', 'Fara Filiorum Petri', 42.2415200, 14.1802600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84942, 'Fanzolo', 'Fanzolo', 'Fanzolo,Fonzolo', 45.7121800, 11.9902300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84943, 'Fano Adriano', 'Fano Adriano', 'Fano Adriano', 42.5523000, 13.5376400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84944, 'Fano', 'Fano', 'Fano,Fanu,Fanum Fortunae,Фано', 43.8405200, 13.0166500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84945, 'Fanna', 'Fanna', 'Fane,Fanna', 46.1845500, 12.7516100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84946, 'Fanano', 'Fanano', 'Fanano', 44.2124500, 10.7966000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84947, 'Falzes', 'Falzes', 'Fal''ces,Falces,Falzes,Pfalzen,Phalanza,fa er ze si,farutsu~esu,Фалцес,Фальцес,Ֆալցես,ファルツェス,法尔泽斯', 46.8135900, 11.8830800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84948, 'Falzè di Piave', 'Falze di Piave', '', 45.8679600, 12.1789100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84949, 'Falvaterra', 'Falvaterra', 'Falvaterra', 41.5043800, 13.5234100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84950, 'Falmenta', 'Falmenta', 'Falmenta', 46.0730900, 8.5894400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84951, 'Fallo', 'Fallo', 'Fallo', 41.9383300, 14.3236200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84952, 'Falerone', 'Falerone', 'Falerone', 43.1042900, 13.4718900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84953, 'Faleria', 'Faleria', 'Faleria', 42.2258000, 12.4451800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84954, 'Falconara Marittima', 'Falconara Marittima', 'Falconara Alta,Falconara Marittima,ファルコナーラ・マリッティマ', 43.6255800, 13.3995400, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84955, 'Falcade Alto', 'Falcade Alto', 'Falcade', 46.3554900, 11.8571200, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84956, 'Fai della Paganella', 'Fai della Paganella', 'Fai della Paganella,ファーイ・デッラ・パガネッラ', 46.1780100, 11.0695000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84957, 'Faicchio', 'Faicchio', 'Faicchio', 41.2781600, 14.4774000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84958, 'Faiano', 'Faiano', '', 40.6625400, 14.9024400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84959, 'Fagnano Olona-Bergoro', 'Fagnano Olona-Bergoro', 'Fagnano,Fagnano Olona', 45.6697700, 8.8599400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84960, 'Faggiano', 'Faggiano', 'Faggiano', 40.4161600, 17.3886100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84961, 'Fagagna', 'Fagagna', 'Fagagna,Feagne', 46.1069800, 13.0936100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84962, 'Faeto', 'Faeto', 'Faeto,Fete,Fête', 41.3248900, 15.1604500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84963, 'Faenza', 'Faenza', 'Faenca,Faenza,faentsu~a,ファエンツァ', 44.2900700, 11.8794800, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84964, 'Faedo Valtellino', 'Faedo Valtellino', 'Faedo,Faedo Valtellino', 46.1529900, 9.9060500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84965, 'Faedis', 'Faedis', 'Faedis', 46.1493100, 13.3446300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84966, 'Fabro', 'Fabro', 'Fabro,Fabru,Fabrum,fa bu luo,fabrw,faburo,pabeulo,Фабро,Ֆաբրո,فابرو,ファブロ,法布罗,파브로', 42.8726700, 12.0154000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84967, 'Fabrica di Roma', 'Fabrica di Roma', '', 42.3344400, 12.2987300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84968, 'Fabriano', 'Fabriano', 'Fabriano,Fabrianum,faburiano,Фабриано,ファブリアーノ', 43.3394100, 12.9032700, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84969, 'Fabbrico', 'Fabbrico', 'Fabbrico', 44.8721400, 10.8089300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84970, 'Fabbriche di Vallico', 'Fabbriche di Vallico', 'Fabbriche,Fabbriche di Vallico,Fabbrichi di Vallicu,Fabbrike-di-Valliko,Fabricae Valici,Fabrike di Valiko,Fabrykeh-dzi-Valika,fa bu li kai di wa li ke,Фаббрике-ди-Валлико,Фаббрике-ді-Валліко,Фабрике ди Валико,Фабрыкэ-дзі-Валіка,Ֆաբրիկե դի Վալիկո,فیبرچے دی والکو,ファッブリケ・ディ・ヴァッリコ,法布里凯迪瓦利科', 43.9976500, 10.4279000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84971, 'Exilles', 'Exilles', 'Esille,Exilles,Isiles,Isìles,ejirresu,エジッレス', 45.0975400, 6.9292000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84972, 'Etroubles', 'Etroubles', 'Etroble,Etroubles,Étroubles', 45.8208200, 7.2313700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84973, 'Este', 'Este', 'Ateste,Ehste,Ehsteh,Este,ai si tai,asth  wntw,esute,Есте,Эсте,Эстэ,Էստե,استه، ونتو,エステ,埃斯泰', 45.2233800, 11.6637900, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84974, 'Esperia', 'Esperia', 'Esperia', 41.3823700, 13.6849100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84975, 'Esino Lario', 'Esino Lario', 'Esino Lario', 45.9943700, 9.3339900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84976, 'Esine', 'Esine', 'Esine,ejine,エージネ', 45.9251500, 10.2510200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84977, 'Esanatoglia', 'Esanatoglia', 'Esanatoglia', 43.2524800, 12.9493000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84978, 'Erula', 'Erula', 'Erula', 40.7924400, 8.9441800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84979, 'Erto', 'Erto', '', 46.2764000, 12.3714900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84980, 'Erli', 'Erli', 'Eril,Erli', 44.1371900, 8.1043000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84981, 'Ercolano', 'Ercolano', 'Ercolano,Gerkulanum,Resina,Геркуланум', 40.8078300, 14.3501200, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84982, 'Erchie', 'Erchie', 'Erchie', 40.4360900, 17.7361000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84983, 'Erbezzo', 'Erbezzo', 'Erbezzo', 45.6396000, 11.0005700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84984, 'Erbè', 'Erbe', 'Erbe,Erbè', 45.2423100, 10.9713500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84985, 'Erba', 'Erba', 'Erba,Herba,Incino,eruba,エルバ', 45.8088000, 9.2260900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84986, 'Eraclea', 'Eraclea', 'Eraclea,Grisolera,erakurea,エラクレーア', 45.5776600, 12.6732000, 'IT', '2014-04-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84987, 'Episcopia', 'Episcopia', 'Episcopia', 40.0748100, 16.0981800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84988, 'Envie', 'Envie', 'Envie', 44.6821000, 7.3720600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84989, 'Entracque', 'Entracque', 'Entracque,Entraque', 44.2402800, 7.3984700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84990, 'Enemonzo-Quinis', 'Enemonzo-Quinis', 'Denemonc,Enemonzo', 46.4083300, 12.8794400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84991, 'Endine', 'Endine', 'Endine,Endine Gaiano', 45.7898000, 9.9756100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84992, 'Empoli', 'Empoli', 'Empoli,enpori,Емполи,エンポリ', 43.7179500, 10.9475800, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84993, 'Emarese', 'Emarese', 'Emarese,Emarèse,Émarèse', 45.7248900, 7.6897600, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84994, 'Serre', 'Serre', 'Elva', 44.5403300, 7.0903200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84995, 'Elice', 'Elice', '', 42.5227900, 13.9707100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84996, 'Egna', 'Egna', 'Egna,Neumarkt,Villa D''Egna,enya,エーニャ', 46.3177700, 11.2733700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84997, 'Edolo', 'Edolo', 'Curtis Iduli,Edolo,edolo,edoro,Едоло,エードロ', 46.1779900, 10.3332200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84998, 'Eboli', 'Eboli', '', 40.6174700, 15.0569300, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(84999, 'Dusino', 'Dusino', '', 44.9256600, 7.9716500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85000, 'Duronia', 'Duronia', 'Duronia', 41.6578600, 14.4601500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85001, 'Durazzano', 'Durazzano', 'Durazzano', 41.0628600, 14.4494700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85002, 'Dumenza', 'Dumenza', 'Dumenza', 46.0208800, 8.7867400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85003, 'Duino', 'Duino', 'Devin,Duino,Vjoska Duina,du''ino,Вёска Дуіна,Дуино,দুইনো', 45.7734200, 13.6043600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85004, 'Dugenta', 'Dugenta', 'Dugenta', 41.1346800, 14.4535300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85005, 'Dueville', 'Dueville', '', 45.6355600, 11.5513500, 'IT', '2016-04-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85006, 'Dubino', 'Dubino', 'Dubino', 46.1670500, 9.4304900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85007, 'Dualchi', 'Dualchi', 'Dualchi', 40.2293500, 8.8972300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85008, 'Druogno', 'Druogno', 'Druogno', 46.1342100, 8.4327600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85009, 'Druento', 'Druento', 'Druent,Druento,doruento,ドルエント', 45.1330600, 7.5751200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85010, 'Dronero', 'Dronero', 'Drone,Dronero,Droné', 44.4647600, 7.3624200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85011, 'Dro', 'Dro', 'Dro,doro,Дро,ドロ', 45.9612100, 10.9120100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85012, 'Drena', 'Drena', 'Drena,dorena,ドレーナ', 45.9692600, 10.9454000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85013, 'Dragoni', 'Dragoni', 'Draco,Dragoni,Dragoni vald,de la ge ni,deulagoni,doragoni,Драгони,Драгоні,Դրագոնի,ドラゴーニ,德拉戈尼,드라고니', 41.2761900, 14.3036800, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85014, 'Dozza', 'Dozza', 'Dozza', 44.3619500, 11.6354700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85015, 'Dovera', 'Dovera', 'Dovera,dovu~era,ドヴェーラ', 45.3642800, 9.5444500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85016, 'Dovadola', 'Dovadola', 'Dovadola,dovu~adora,ドヴァードラ', 44.1221100, 11.8870700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85017, 'Dosson', 'Dosson', '', 45.6360500, 12.2540900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85018, 'Dossobuono', 'Dossobuono', 'Dossobuono', 45.3933300, 10.9105400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85019, 'Dosso', 'Dosso', '', 44.7680600, 11.3393800, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85020, 'Dosolo', 'Dosolo', 'Doesul,Dosolo,Doxolum,Dozolo,Dösul,dozoro,duo suo luo,dwzwlw,Дозоло,Դոզոլո,دوزولو,ドーゾロ,多索洛', 44.9525900, 10.6355000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85021, 'Dosimo', 'Dosimo', '', 45.1846900, 10.1036200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85022, 'Dorno', 'Dorno', '', 45.1535200, 8.9507600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85023, 'Dorio', 'Dorio', 'Dorio', 46.1002000, 9.3188300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85024, 'Dorgali', 'Dorgali', 'Dorgali', 40.2922100, 9.5870200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85025, 'Donzella', 'Donzella', 'Donzelia,Donzella', 44.9304700, 12.3311900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85026, 'Dongo', 'Dongo', 'Dongh,Dongo,Dono,Dungum,dong ge,dongo,Донго,Доно,Դոնգո,ドンゴ,东戈', 46.1299900, 9.2816900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85027, 'Domodossola', 'Domodossola', 'Domodossola,domodossora,ドモドッソラ', 46.1165000, 8.2931300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85028, 'Domicella', 'Domicella', 'Domicella', 40.8801900, 14.5871600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85029, 'Domegge di Cadore', 'Domegge di Cadore', 'Domegge,Domegge di Cadore', 46.4566600, 12.4072400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85030, 'Domaso', 'Domaso', 'Domaso', 46.1528400, 9.3315000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85031, 'Dolo', 'Dolo', 'Dolo,doro,ドーロ', 45.4252800, 12.0842900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85032, 'Dolcedo', 'Dolcedo', 'Dolcedo', 43.9073500, 7.9494300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85033, 'Dolceacqua', 'Dolceacqua', 'Dolceacqua', 43.8497500, 7.6237300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85034, 'Dolcè', 'Dolce', 'Dolce,Dolcè', 45.6006900, 10.8524800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85035, 'Dogna', 'Dogna', 'Dogna,Dogne', 46.4479300, 13.3150200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85036, 'Dogliola', 'Dogliola', 'Dogliola', 41.9423800, 14.6350700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85037, 'Dogliani', 'Dogliani', 'Dogliani', 44.5332600, 7.9451000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85038, 'Doberdò del Lago', 'Doberdo del Lago', 'Dobardo,Dobardò,Doberdo,Doberdo del Lago,Doberdò del Lago,ドベルド・デル・ラーゴ', 45.8444400, 13.5390800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85039, 'Dobbiaco', 'Dobbiaco', 'Dabjaka,Dobb''jako,Dobbiaco,Dobbiaco vald,Dobbiako,Dobbjako,Dobiako,Dobijako,Duplagum,Ntompiako,Toblach,dobbiako,duo bi ya ke,dwbyakw,twblak,Ντομπιάκο,Дабяка,Доббиако,Доббьяко,Доббяко,Добиако,Добијако,Դոբիակո,טובלאך,توبلاک,دوبياكو,ドッビアーコ,多比亚科', 46.7287800, 12.2222500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85040, 'Dizzasco-Biazzeno', 'Dizzasco-Biazzeno', 'Dizzasco', 45.9437800, 9.0997400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85041, 'Divignano', 'Divignano', 'Divignano', 45.6624700, 8.5998700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85042, 'Dimaro', 'Dimaro', 'Dimaro,dimaro,ディマーロ', 46.3257300, 10.8734200, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85043, 'Dignano', 'Dignano', 'Adinianum,Dignan,Dignano,Din''jano,Dinano,Dinjano,Dinyano,di ni ya nuo,dinyano,Диньяно,Диняно,Дињано,Діньяно,Դինյանո,ディニャーノ,迪尼亚诺', 46.0839200, 12.9400900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85044, 'Dicomano', 'Dicomano', 'Dicomano', 43.8926700, 11.5218200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85045, 'Diano San Pietro', 'Diano San Pietro', 'Diano San Pietro', 43.9295300, 8.0724900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85046, 'Diano Marina', 'Diano Marina', 'Diano Marina', 43.9108800, 8.0802900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85047, 'Diano d''Alba', 'Diano d''Alba', 'Diano,Diano d''Alba', 44.6529400, 8.0270400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85048, 'Diano Castello', 'Diano Castello', 'Diano Castello', 43.9242300, 8.0660200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85049, 'Desio', 'Desio', 'Dees,Desio,Dezio,dejio,Дезио,デージオ', 45.6183100, 9.2024900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85050, 'Desenzano del Garda', 'Desenzano del Garda', 'Desenzano,Desenzano del Garda,Desenzano sul Lago,Dezencano del'' Garda,Дезенцано дель Гарда,デゼンツァーノ・デル・ガルダ', 45.4712700, 10.5355900, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85051, 'Desana', 'Desana', 'Desana', 45.2691500, 8.3577700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85052, 'Dervio', 'Dervio', 'Dervio', 46.0769600, 9.3065900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85053, 'Deruta', 'Deruta', 'Deruta,deruta,デルータ', 42.9846500, 12.4176000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85054, 'Taio', 'Taio', 'Taio,Tajo,taio,ターイオ', 46.3213900, 11.0662400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85055, 'Denno', 'Denno', 'Denno,den''no,デンノ', 46.2742400, 11.0491300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85056, 'Demonte', 'Demonte', 'Demonte', 44.3164600, 7.2980800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85057, 'Dello', 'Dello', 'Dello,derro,デッロ', 45.4191600, 10.0762100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85058, 'Deliceto', 'Deliceto', 'Deliceto', 41.2228900, 15.3844700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85059, 'Delebio', 'Delebio', 'Alebium,Deleb''o,Delebi,Delebio,de lai bi ao,derebio,Делебио,Делебьо,Делебіо,Դելեբիո,デレービオ,德莱比奥', 46.1364800, 9.4615700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85060, 'Deiva Marina', 'Deiva Marina', 'Deiva,Deiva Marina,Déiva', 44.2193100, 9.5206400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85061, 'Dego', 'Dego', 'Dego,O De,O Dê', 44.4445500, 8.3076100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85062, 'Decima', 'Decima', '', 44.7104500, 11.2297800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85063, 'Dazio', 'Dazio', 'Dazio', 46.1612900, 9.6006400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85064, 'Darfo', 'Darfo', '', 45.8779400, 10.1811500, 'IT', '2012-03-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85065, 'Daone', 'Daone', 'Daone', 45.9472000, 10.6210700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85066, 'Danta', 'Danta', '', 46.5670000, 12.5205500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85067, 'Dambel', 'Dambel', 'Dambel,danberu,ダンベル', 46.4047100, 11.0930700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85068, 'Dalmine', 'Dalmine', 'Dal''mine,Dalmine,Дальмине', 45.6493300, 9.6061700, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85069, 'Dairago', 'Dairago', 'Dairago,dairago,ダイラーゴ', 45.5658000, 8.8626500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85070, 'Cutrofiano', 'Cutrofiano', 'Cutrofiano,Cutrufianu,Kutrofiana', 40.1261600, 18.2026000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85071, 'Cutigliano', 'Cutigliano', 'Cutigliano,Cutiglianu,Cutijan,Cutilianum,Kutil''jano,Kutilano,Kutiliano,Kutiljano,Kutyl''jana,ku di li ya nuo,kutiriano,Кутильяно,Кутиляно,Кутиљано,Кутыльяна,Кутільяно,Կուտիլիանո,クティリアーノ,库蒂利亚诺', 44.1005900, 10.7561700, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85072, 'Cusio', 'Cusio', 'Cusio', 45.9908900, 9.6017500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85073, 'Cusercoli', 'Cusercoli', '', 44.0451400, 12.0074000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85074, 'Cusano Mutri', 'Cusano Mutri', 'Cusano Mntri,Cusano Mutri', 41.3362400, 14.5101300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85075, 'Cusano Milanino', 'Cusano Milanino', 'Cusano Milanino,クザーノ・ミラニーノ', 45.5518700, 9.1837300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85076, 'Curtarolo', 'Curtarolo', 'Curtarolo', 45.5236600, 11.8369100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85077, 'Cursi', 'Cursi', 'Cursi,Kurze', 40.1484700, 18.3160500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85078, 'Curon Venosta', 'Curon Venosta', 'Curon,Curon Venosta,Curón,Graun,Graun im Vinschgau,クローン・ヴェノスタ', 46.8083200, 10.5426500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85079, 'Curno', 'Curno', 'Curdomo,Curno,kuruno,クルノ', 45.6887600, 9.6087200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85080, 'Curiglia', 'Curiglia', '', 46.0606500, 8.8048400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85081, 'Cupramontana', 'Cupramontana', 'Cupra Montana,Cupramontana,Kupra Montana,Kupramontana,ku pu la meng ta na,kupuramontana,Купра Монтана,Купрамонтана,Կուպրամոնտանա,クプラモンターナ,库普拉蒙塔纳', 43.4497500, 13.1131200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85082, 'Cupra Marittima', 'Cupra Marittima', 'Cupra Marittima', 43.0190500, 13.8617100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85083, 'Cupello', 'Cupello', 'Cupello', 42.0693600, 14.6705400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85084, 'Cuorgnè', 'Cuorgne', 'Corgne,Corgnè,Cuorgne,Cuorgnè,kuorunye,クオルニェ', 45.3934100, 7.6501500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85085, 'Cunico', 'Cunico', 'Cunico', 45.0405000, 8.0955400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85086, 'Cuneo', 'Cuneo', 'CUF,Coni,Koni,Kuneo,Кунео', 44.3907100, 7.5482800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85087, 'Cumignano sul Naviglio', 'Cumignano sul Naviglio', 'Cumignano sul Naviglio', 45.3545900, 9.8362100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85088, 'Cumiana', 'Cumiana', 'Cumian-a,Cumiana,kumiana,クミアーナ', 44.9762900, 7.3776100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85089, 'Cugnoli', 'Cugnoli', 'Cugnoli', 42.3069200, 13.9349000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85090, 'Cuglieri', 'Cuglieri', 'Cuglieri,Cullieri', 40.1880400, 8.5680600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85091, 'Cuggiono', 'Cuggiono', 'Cuggiono,kujjono,クッジョーノ', 45.5068300, 8.8155000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85092, 'Cuceglio', 'Cuceglio', 'Cuceglio,Cusele,kucherio,クチェーリオ', 45.3585300, 7.8158800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85093, 'Cuccurano', 'Cuccurano', '', 43.7931100, 12.9592700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85094, 'Cuccaro Vetere', 'Cuccaro Vetere', 'Cuccaro Vetere', 40.1640400, 15.3067700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85095, 'Crugnola', 'Crugnola', '', 45.7295500, 8.7452500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85096, 'Croviana', 'Croviana', 'Croviana,kurovu~iana,クロヴィアーナ', 46.3448000, 10.9031300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85097, 'Crova', 'Crova', 'Crova', 45.3306600, 8.2108300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85098, 'Crotta d''Adda', 'Crotta d''Adda', 'Crotta d''Adda', 45.1588800, 9.8568400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85099, 'Maglione-Crosa', 'Maglione-Crosa', 'Crosa,kuroza,クローザ', 45.6029700, 8.1493700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85100, 'Crone', 'Crone', 'Crone,Idro', 45.7374100, 10.4750300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85101, 'Crognaleto', 'Crognaleto', 'Crognaleto', 42.5877100, 13.4889000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85102, 'Crodo', 'Crodo', 'Crodo', 46.2172600, 8.3223800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85103, 'Crocetta del Montello', 'Crocetta del Montello', 'Crocetta Trevigiana,Crocetta de Montello,Crocetta del Montello,Croxeta del Montelo,Croxeta del Monteło,Crucicula Tarvisana,Krocheta del Montelo,Krochetta-Montello,Krochetta-del''-Montello,ke luo qie ta de er meng tai luo,Крочета дел Монтело,Крочетта-Монтелло,Крочетта-дель-Монтелло,Կրոչետա Մոնտելո,クロチェッタ・デル・モンテッロ,克罗切塔德尔蒙泰洛', 45.8366700, 12.0336100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85104, 'Crocefieschi', 'Crocefieschi', 'A Croxe,Crocefieschi', 44.5807700, 9.0236000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85105, 'Crissolo', 'Crissolo', 'Crissolo', 44.6995300, 7.1560200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85106, 'Crispiano', 'Crispiano', 'Crispiano', 40.6037900, 17.2329000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85107, 'Crevalcore', 'Crevalcore', 'Crevalcore', 44.7196600, 11.1476500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85108, 'Crevacuore', 'Crevacuore', 'Crevacuore', 45.6854800, 8.2440400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85109, 'Cretone', 'Cretone', 'Cretone', 42.0711600, 12.7036500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85110, 'Creto', 'Creto', '', 45.9411000, 10.6402700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85111, 'Cressa', 'Cressa', 'Cressa', 45.6476200, 8.5094200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85112, 'Crespino', 'Crespino', 'Crespino', 44.9852700, 11.8895800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85113, 'Crespina', 'Crespina', 'Crespina,Crispina,Krehspina,Krespina,kuresupina,Креспина,Креспіна,Крэспіна,Կրեսպինա,クレスピーナ', 43.5730400, 10.5643100, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85114, 'Crespiatica', 'Crespiatica', 'Crespiatica,kuresupiatika,クレスピアーティカ', 45.3513600, 9.5765900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85115, 'Crespellano', 'Crespellano', 'Crespellano', 44.5119600, 11.1322400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85116, 'Crespano del Grappa', 'Crespano del Grappa', 'Crespano del Grappa', 45.8279300, 11.8335800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85117, 'Crespadoro', 'Crespadoro', 'Crespadoro', 45.6201900, 11.2258900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85118, 'Crescentino', 'Crescentino', 'Crescentino', 45.1994100, 8.0863500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85119, 'Cremona', 'Cremona', 'Cremon-a,Cremona,Cremone,Crémone,Kremona,ke lei mo na,keulemona,kuremona,Кремона,クレモナ,克雷莫納,크레모나', 45.1332500, 10.0212900, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85120, 'Cremolino', 'Cremolino', 'Cremolino', 44.6367400, 8.5858400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85121, 'Cremeno', 'Cremeno', 'Cremeno', 45.9349200, 9.4709900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85122, 'Crema', 'Crema', 'Crema,Krema,kurema,Крема,クレーマ', 45.3626400, 9.6817600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85123, 'Credera', 'Credera', '', 45.3030100, 9.6549800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85124, 'Crecchio', 'Crecchio', 'Crecchio', 42.2977800, 14.3265600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85125, 'Creazzo', 'Creazzo', 'Casale Creazzo', 45.5315400, 11.4778900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85126, 'Craveggia', 'Craveggia', 'Craveggia', 46.1412400, 8.4890700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85127, 'Cravanzana', 'Cravanzana', 'Cravanzana', 44.5744800, 8.1273100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85128, 'Craco-Sant''Angelo', 'Craco-Sant''Angelo', 'Craco', 40.3799200, 16.4370800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85129, 'Cozzo', 'Cozzo', 'Cozzo', 45.1921300, 8.6111200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85130, 'Cozzana', 'Cozzana', '', 40.9202500, 17.2225900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85131, 'Covo', 'Covo', 'Covo,kovu~o,コーヴォ', 45.4990600, 9.7706800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85132, 'Courmayeur', 'Courmayeur', 'Cormaiore,Cormaire,Cort-Mayor,Courmayeur,Curia Maior,Kurmajor,kouleumaie-uleu,ku er ma ye wu er,kurumaiyuru,kwrmayr,Курмайор,Курмаёр,קורמאיור,کورمائر,კურმაიორი,クールマイユール,库尔马耶乌尔,코우르마이에우르', 45.7965900, 6.9689300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85133, 'Cottanello', 'Cottanello', 'Cottanello', 42.4081100, 12.6859200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85134, 'Cotignola', 'Cotignola', 'Cotignola,Cottignola,kotinyora,コティニョーラ', 44.3857200, 11.9385200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85135, 'Costiglione Saluzzo', 'Costiglione Saluzzo', 'Costigliole Saluzzo', 44.5645300, 7.4854300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85136, 'Costigliole d''Asti', 'Costigliole d''Asti', 'Costigliole,Costigliole d''Asti', 44.7851700, 8.1840500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85137, 'Costermano', 'Costermano', 'Costermano', 45.5860600, 10.7390000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85138, 'Costa Volpino', 'Costa Volpino', 'Costa Volpino', 45.8276800, 10.1007600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85139, 'Costa Valle Imagna', 'Costa Valle Imagna', 'Costa Valle Imagna', 45.8028000, 9.5041300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85140, 'Costa Sant''Abramo', 'Costa Sant''Abramo', '', 45.1666700, 9.9666700, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85141, 'Costarainera', 'Costarainera', 'A Costa,A Còsta,Costarainera', 43.8547700, 7.9410600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85142, 'Costanzana', 'Costanzana', 'Costanzana', 45.2374200, 8.3694300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85143, 'Costano', 'Costano', 'Costano', 43.0442000, 12.5341000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85144, 'Costa di Rovigo', 'Costa di Rovigo', 'Costa di Rovigo', 45.0518100, 11.6956000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85145, 'Costa di Mezzate', 'Costa di Mezzate', 'Costa di Mezzate,Costa di Monticelli', 45.6627800, 9.7955600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85146, 'Costacciaro', 'Costacciaro', 'Costacciaro', 43.3586600, 12.7126200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85147, 'Costabissara', 'Costabissara', 'Costabissara', 45.5825200, 11.4852900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85148, 'Cossombrato', 'Cossombrato', 'Cossombra,Cossombrato,Cossombrà', 44.9897600, 8.1389700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85149, 'Cossoine', 'Cossoine', 'Cossoine', 40.4306800, 8.7157800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85150, 'Cossignano', 'Cossignano', 'Cossignano', 42.9835500, 13.6902600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85151, 'Cossato', 'Cossato', 'Cossato', 45.5703200, 8.1847100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85152, 'Coseano', 'Coseano', 'Cosean,Coseano', 46.0963600, 13.0202800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85153, 'Corvaro', 'Corvaro', '', 42.2053800, 13.2649600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85154, 'Corvara in Badia', 'Corvara in Badia', 'Corvara,Corvara in Badia,Corvaria,Karvara-in-Badzija,Korvara-in-Badija,ke er wa la yi en ba di ya,Карвара-ін-Бадзія,Корвара-ин-Бадия,Корвара-ін-Бадія,コルヴァーラ・イン・バディーア,科尔瓦拉伊恩巴迪亚', 46.5503700, 11.8734200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85155, 'Corvara', 'Corvara', 'Corvara', 42.2751100, 13.8736300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85156, 'Cortona', 'Cortona', 'Cortona,Cortone,Kortona,Кортона', 43.2746700, 11.9853300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85157, 'Cortina d''Ampezzo', 'Cortina d''Ampezzo', 'Cortina Ampecanorum,Cortina d''Ampezzo,Cortina d’Ampezzo,Kortina d''Ampecco,Кортина д''Ампеццо,コルティーナ・ダンペッツォ', 46.5369000, 12.1390300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85158, 'Cortiglione', 'Cortiglione', 'Corgeli,Corgèli,Cortiglione', 44.8222500, 8.3579600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85159, 'Corteolona', 'Corteolona', 'Corteleona,Corteolona', 45.1578700, 9.3721500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85160, 'Cortemilia', 'Cortemilia', 'Cortemilia', 44.5804400, 8.1936700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85161, 'Cortemaggiore', 'Cortemaggiore', 'Cortemaggiore', 44.9918500, 9.9284400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85162, 'Corte Franca', 'Corte Franca', 'Corte Franca,コルテ・フランカ', 45.6299800, 9.9884600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85163, 'Corte de'' Cortesi', 'Corte de'' Cortesi', '', 45.2726500, 10.0073800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85164, 'Corte', 'Corte', '', 45.3083500, 12.0717400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85165, 'Cortazzone', 'Cortazzone', 'Cortazzone', 44.9791500, 8.0612300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85166, 'Cortanze', 'Cortanze', 'Cortanze', 45.0140400, 8.0887900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85167, 'Cortandone', 'Cortandone', 'Cortandone', 44.9591500, 8.0584300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85168, 'Cortaccia sulla Strada del Vino', 'Cortaccia sulla Strada del Vino', 'Kurtasch,Kurtatsch,Kurtatsch an der Weinstrasse', 46.3140100, 11.2238800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85169, 'Corsico', 'Corsico', 'Corsico,Korsiko,korushiko,Корсико,コルシコ', 45.4309900, 9.1109300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85170, 'Corropoli', 'Corropoli', 'Corropoli', 42.8272000, 13.8347100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85171, 'Corridonia', 'Corridonia', 'Corridonia', 43.2467700, 13.5069000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85172, 'Correzzola', 'Correzzola', 'Correzzola', 45.2354800, 12.0673900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85173, 'Correggio', 'Correggio', 'Coreggio,Coregio,Correggio,Correggio i Italia,Corrigium,Karehdzha,Knizectvi Correggio,Knížectví Correggio,Koredzho,Koredzo,Korredzho,ke lei jiao,korrejjo,kwrjw,kwrydjw,Карэджа,Кореджо,Коређо,Кореџо,Корреджо,كوريدجو,کورجو,コッレッジョ,科雷焦', 44.7673700, 10.7834500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85174, 'Corpolò', 'Corpolo', '', 44.0190500, 12.4526600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85175, 'Cornuda', 'Cornuda', 'Cornuda', 45.8315200, 12.0059800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85176, 'Corno Giovine', 'Corno Giovine', '', 45.1341500, 9.7576600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85177, 'Corno di Rosazzo', 'Corno di Rosazzo', 'Corno di Rosazzo,Cuar di Rosacis', 45.9911000, 13.4436800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85178, 'Corniglio', 'Corniglio', 'Corniglio', 44.4742500, 10.0900900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85179, 'Cornedo Vicentino', 'Cornedo Vicentino', 'Cornedo', 45.6162600, 11.3322500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85180, 'Cornate d''Adda', 'Cornate d''Adda', 'Cornate,Cornate d''Adda,コルナーテ・ダッダ', 45.6281100, 9.4737800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85181, 'Cornaredo', 'Cornaredo', 'Cornaredo,korunaredo,コルナレード', 45.5012800, 9.0268100, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85182, 'Cornale', 'Cornale', 'Cornale', 45.0434400, 8.9109600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85183, 'Cornalba', 'Cornalba', 'Cornalba', 45.8492700, 9.7459300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85184, 'Cornaiano', 'Cornaiano', 'Girlan', 46.4632900, 11.2811500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85185, 'Cormons', 'Cormons', 'Cormons,Cormòns', 45.9553100, 13.4668300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85186, 'Cormano', 'Cormano', 'Cormano,korumano,コルマーノ', 45.5491700, 9.1596400, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85187, 'Corleto Perticara', 'Corleto Perticara', '', 40.3821400, 16.0391700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85188, 'Corleto Monforte', 'Corleto Monforte', 'Corleto Monforte,Corletu Munfurti,Corletum,Karleta-Manforteh,Korleto Monforte,Korleto-Monforte,ke er lai tuo meng fu er tai,koleulletomonpoleute,kwrltw mwnfwrth,Карлета-Манфортэ,Корлето Монфорте,Корлето-Монфорте,Կորլետո Մոնֆորտե,کورلتو مونفورته,コルレート・モンフォルテ,科尔莱托蒙福尔泰,코를레토몬포르테', 40.4375600, 15.3801300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85189, 'Corio', 'Corio', 'Cheuri,Corio,korio,コーリオ', 45.3122200, 7.5335100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85190, 'Corinaldo', 'Corinaldo', 'Corinaldo,korinarudo,コリナルド', 43.6410700, 13.0600400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85191, 'Corigliano d''Otranto', 'Corigliano d''Otranto', 'Corigliano d''Otranto', 40.1592500, 18.2559800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85192, 'Coriano', 'Coriano', 'Coriano,koriano,コリアーノ', 43.9690700, 12.6005500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85193, 'Cori', 'Cori', 'Cora,Cori,Gorad Kory,Kori,ke li,koli,kori,Горад Коры,Кори,Корі,コーリ,科里,코리', 41.6435800, 12.9112100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85194, 'Corgeno', 'Corgeno', '', 45.7458800, 8.6879700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85195, 'Corfinio', 'Corfinio', 'Corfinio', 42.1214900, 13.8394000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85196, 'Coreglia Antelminelli', 'Coreglia Antelminelli', 'Coreglia Antelminelli,Coreja Antelmineli,Coreja Antelminełi,Corelia,Karehl''ja-Antehl''mineli,Korel''ja-Antel''minelli,Korela Antelmineli,Korelia Antelmineli,Korelja Antelmineli,ke lei li ya an tai er mi nei li,Карэлья-Антэльмінелі,Корелья-Антельминелли,Корелья-Антельмінеллі,Кореля Антелминели,Кореља Антелминели,Կորելիա Անտելմինելի,コレリア・アンテルミネッリ,科雷利亚安泰尔米内利', 44.0627800, 10.5242600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85197, 'Coredo', 'Coredo', 'Coredo,Coredum,Koredo,ke lei duo,koredo,Коредо,Կորեդո,コーレド,科雷多', 46.3490600, 11.0900100, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85198, 'Cordovado', 'Cordovado', 'Cordovado,Cordovat,Cordoyado', 45.8442500, 12.8853700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85199, 'Cordignano', 'Cordignano', 'Cordignano', 45.9493600, 12.4156700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85200, 'Cordenons', 'Cordenons', 'Cordenona,Cordenons', 45.9836000, 12.7003800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85201, 'Corcolle', 'Corcolle', 'Corcolle,Querquetula', 41.9042100, 12.7365400, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85202, 'Corciano', 'Corciano', 'Corciano', 43.1282100, 12.2868400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85203, 'Corchiano', 'Corchiano', 'Corchiano', 42.3449500, 12.3568800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85204, 'Corbola', 'Corbola', 'Corbola', 45.0027200, 12.0856700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85205, 'Corbetta', 'Corbetta', 'Corbetta,korubetta,コルベッタ', 45.4672300, 8.9186700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85206, 'Corbara', 'Corbara', 'Corbara', 40.7227800, 14.5918700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85207, 'Corbanese', 'Corbanese', '', 45.9457000, 12.2402700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85208, 'Corato', 'Corato', 'Corato,Korato,Корато', 41.1517100, 16.4114300, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85209, 'Corana', 'Corana', 'Corana', 45.0628900, 8.9695200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85210, 'Coppito', 'Coppito', '', 42.3673000, 13.3435800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85211, 'Copparo', 'Copparo', 'Copparo', 44.8926300, 11.8228700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85212, 'Copiano', 'Copiano', 'Copiano', 45.1975000, 9.3246200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85213, 'Copertino', 'Copertino', 'Copertino,Cupertinu', 40.2682100, 18.0543000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85214, 'Nuova Conza della Campania', 'Nuova Conza della Campania', 'Conza della Campania,Conza di Campania', 40.8586000, 15.3364500, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85215, 'Conversano', 'Conversano', 'Conversano,Konversano,Конверсано', 40.9683600, 17.1132900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85216, 'Contursi Terme', 'Contursi Terme', '', 40.6502600, 15.2416300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85217, 'Controne', 'Controne', 'Controne', 40.5101800, 15.2040400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85218, 'Controguerra', 'Controguerra', 'Controguerra', 42.8539800, 13.8177500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85219, 'Contrada', 'Contrada', '', 40.8681100, 14.7774700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85220, 'Contigliano', 'Contigliano', 'Contigliano,Contiglianu,Contilianum,Kontil''jano,Kontilano,Kontiljano,Kontilyano,kong di li ya nuo,kontilliano,kontiriano,Контильяно,Контиляно,Контиљано,Контільяно,Կոնտիլյանո,コンティリアーノ,孔蒂利亚诺,콘틸리아노', 42.4105800, 12.7720200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85221, 'Conselve', 'Conselve', 'Conselve', 45.2315400, 11.8749800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85222, 'Conselice', 'Conselice', '', 44.5116300, 11.8284800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85223, 'Conscio', 'Conscio', '', 45.6170100, 12.2821900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85224, 'Consandolo', 'Consandolo', '', 44.6560600, 11.7752400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85225, 'Configni', 'Configni', 'Configni', 42.4254300, 12.6443100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85226, 'Confienza', 'Confienza', 'Confienza', 45.3314800, 8.5588600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85227, 'Conegliano', 'Conegliano', 'Conegliano,Konel''jano,koneriano,Конельяно,コネリアーノ', 45.8880500, 12.3020100, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85228, 'Condove', 'Condove', 'Condove,Condòve,kondovu~e,コンドーヴェ', 45.1159100, 7.3085900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85229, 'Condino', 'Condino', 'Condino,kondino,コンディーノ', 45.8816700, 10.5936600, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85230, 'Concorezzo', 'Concorezzo', 'Concorezzo,Concorrezzo,Cuncuress,Cuncurèss,konkorettsu~o,コンコレッツォ', 45.5885400, 9.3339300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85231, 'Concordia sulla Secchia', 'Concordia sulla Secchia', 'Concordia,Concordia sulla Secchia', 44.9125800, 10.9880200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85232, 'Concordia Sagittaria', 'Concordia Sagittaria', 'Concordia,Concordia Sagittaria,Concuardie,コンコルディア・サジッターリア', 45.7611800, 12.8236200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85233, 'Conco', 'Conco', 'Conco,konko,コンコ', 45.8004300, 11.6096200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85234, 'Concerviano', 'Concerviano', 'Concerviano', 42.3221400, 12.9853400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85235, 'Conca della Campania', 'Conca della Campania', 'Conca della Campania', 41.3317400, 13.9914200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85236, 'Conca dei Marini', 'Conca dei Marini', 'Conca dei Marini,Konka dei Marini,Конка деи Марини', 40.6175400, 14.5731100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85237, 'Conca Casale', 'Conca Casale', 'Conca Casale', 41.4951200, 14.0068200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85238, 'Comun Nuovo', 'Comun Nuovo', 'Comun Nuovo', 45.6229100, 9.6620000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85239, 'Comunanza', 'Comunanza', 'Comunanza,Comunanza del Littorio', 42.9571900, 13.4134100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85240, 'Compiobbi', 'Compiobbi', 'Compiabbi,Compiobbi', 43.7848500, 11.3590900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85241, 'Compiano', 'Compiano', 'Compiano', 44.4960500, 9.6620700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85242, 'Como', 'Como', 'Com,Come,Como,Còm,Côme,Komo,Novum Comum,QCM,ke mo,komo,Комо,コモ,科莫', 45.8081900, 9.0832000, 'IT', '2016-04-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85243, 'Commessaggio', 'Commessaggio', 'Commessaggio', 45.0375400, 10.5453500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85244, 'Comiziano', 'Comiziano', 'Comiziano,komitsu~iano,コミツィアーノ', 40.9516300, 14.5512400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85245, 'Cizzago-Comezzano', 'Cizzago-Comezzano', '', 45.4688000, 9.9581600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85246, 'Comerio', 'Comerio', 'Cumer,Gomera,Komerio,ke mei liao,komerio,Комерио,Комеріо,Կոմերիո,コメーリオ,科梅廖', 45.8419100, 8.7420700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85247, 'Comeglians', 'Comeglians', 'Comeglians,Comelians', 46.5161400, 12.8661900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85248, 'Comeana', 'Comeana', '', 43.7933400, 11.0582500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85249, 'Comazzo', 'Comazzo', 'Comazzo,komattsu~o,コマッツォ', 45.4419000, 9.4627800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85250, 'Comacchio', 'Comacchio', 'Comacchio,Cumaculum,Komakio,Komakk''o,ke ma ji ao,komakkio,kwmachyw,kwmakyw,Комакио,Комаккьо,Կոմաքիո,كوماكيو,کوماچیو,コマッキオ,科马基奥', 44.6947800, 12.1819400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85251, 'Comabbio', 'Comabbio', 'Comabbio', 45.7735900, 8.6783300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85252, 'Colturano', 'Colturano', 'Colturan,Colturano,Culturano,Culturanum,Kol''turano,Kolturano,ke er tu la nuo,koruto~urano,Колтурано,Кольтурано,Կոլտուրանո,コルトゥラーノ,科尔图拉诺', 45.3815100, 9.3344300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85253, 'Colorno', 'Colorno', 'Colorno', 44.9257200, 10.3736100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85254, 'Colonnella', 'Colonnella', 'Colonnella', 42.8723000, 13.8698700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85255, 'Colonna', 'Colonna', 'Colonna,koron''na,コロンナ', 41.8345400, 12.7549500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85256, 'Colombaro-Timoline', 'Colombaro-Timoline', '', 45.6440500, 9.9941300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85257, 'Colombaro', 'Colombaro', '', 44.5515300, 10.8962800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85258, 'Cologno Monzese', 'Cologno Monzese', 'Cologno', 45.5300400, 9.2779500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85259, 'Cologno al Serio', 'Cologno al Serio', 'Cologno,Cologno al Serio,Cologno sul Serio', 45.5760400, 9.7089200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85260, 'Cologne', 'Cologne', 'Cologne,koronye,コローニェ', 45.5786200, 9.9418000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85261, 'Cologna Veneta', 'Cologna Veneta', 'Cologna Veronese', 45.3077700, 11.3803200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85262, 'Colobraro', 'Colobraro', 'Colobraro', 40.1884100, 16.4248000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85263, 'Colmurano', 'Colmurano', 'Colmurano', 43.1648500, 13.3590800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85264, 'Colloredo di Prato', 'Colloredo di Prato', 'Colloredo,Colloredo di Prato', 46.0512400, 13.1439400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85265, 'Collobiano', 'Collobiano', 'Collobiano', 45.3966500, 8.3475000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85266, 'Colli sul Velino', 'Colli sul Velino', 'Colli di Labro,Colli sul Velino', 42.4982800, 12.7815300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85267, 'Collio', 'Collio', 'Collio,korrio,コッリオ', 45.8108800, 10.3351100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85268, 'Colli del Tronto', 'Colli del Tronto', 'Colli del Tronto', 42.8769000, 13.7474500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85269, 'Colliano', 'Colliano', 'Colliano', 40.7229300, 15.2896900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85270, 'Colli a Volturno', 'Colli a Volturno', 'Colli a Volturno', 41.6003900, 14.1030100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85271, 'Collevecchio', 'Collevecchio', 'Collevecchio', 42.3336800, 12.5532900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85272, 'Colletorto', 'Colletorto', 'Colletorto', 41.6616500, 14.9677300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85273, 'Colle Santa Lucia', 'Colle Santa Lucia', 'Colle San Lucia,Colle Santa Lucia', 46.4485200, 12.0139900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85274, 'Colle Sannita', 'Colle Sannita', 'Colle Sannita', 41.3637400, 14.8345000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85275, 'Colle San Magno', 'Colle San Magno', 'Colle San Magno', 41.5501900, 13.6948500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85276, 'Collesalvetti', 'Collesalvetti', '', 43.5907300, 10.4752300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85277, 'Collepietro', 'Collepietro', 'Collepietro', 42.2208900, 13.7810100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85278, 'Collepepe', 'Collepepe', 'Collepepe,Collepeppe', 42.9154800, 12.3948600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85279, 'Collepasso', 'Collepasso', 'Collepasso,Collepassu', 40.0711500, 18.1622200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85280, 'Collepardo', 'Collepardo', 'Collepardo', 41.7641700, 13.3684600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85281, 'Collemeto', 'Collemeto', '', 40.2088500, 18.1028500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85282, 'Collelongo', 'Collelongo', 'Collelongo', 41.8865900, 13.5838000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85283, 'Colle Isarco', 'Colle Isarco', 'Colle Isarco,Gossensass,Gossensuss', 46.9385700, 11.4424500, 'IT', '2016-01-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85284, 'Collegno', 'Collegno', 'Colegn,Collegno,Kollen''o,korrenyo,Колленьо,コッレーニョ', 45.0787300, 7.5673500, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85285, 'Collegiove', 'Collegiove', 'Collegiove', 42.1750600, 13.0384400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85286, 'Colleferro', 'Colleferro', 'Colleferro,Kolleferro,korreferro,Коллеферро,コッレフェッロ', 41.7272200, 13.0048100, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85287, 'Colle di Val d''Elsa', 'Colle di Val d''Elsa', 'Colle Val d''Elsa,Colle di Val d''Elsa,Kole-dzi-Val''-d''Ehl''sa,Kolle-di-Val''-d''Ehl''sa,Коле-дзі-Валь-д''Эльса,Колле-ди-Валь-д''Эльса,コッレ・ディ・ヴァル・デルザ', 43.4210700, 11.1273900, 'IT', '2016-01-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85288, 'Colle di Tora', 'Colle di Tora', 'Colle di Tora', 42.2080900, 12.9474600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85289, 'Colledimezzo', 'Colledimezzo', 'Colledimezzo', 41.9860600, 14.3869000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85290, 'Colledimacine', 'Colledimacine', 'Colledimacine', 42.0037000, 14.2007900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85291, 'Colle di Fuori', 'Colle di Fuori', '', 41.8009100, 12.8068300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85292, 'Colledara', 'Colledara', 'Colledara', 42.5391800, 13.6755600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85293, 'Colle d''Anchise', 'Colle d''Anchise', 'Colle d''Anchise', 41.5098600, 14.5187300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85294, 'Collecorvino', 'Collecorvino', 'Collecorvino', 42.4602400, 14.0156400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85295, 'Collecchio', 'Collecchio', 'Collecchio', 44.7519700, 10.2154000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85296, 'Collazzone', 'Collazzone', 'Collazzone,Collazzuni,Collis Attonis,Kolacone,Kollaccone,ke la zuo nei,kollachone,korrattsu~one,kwlatswny,Колацоне,Коллаццоне,Կոլացոնե,كولاتسوني,コッラッツォーネ,科拉佐内,콜라초네', 42.9014700, 12.4358200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85297, 'Collarmele', 'Collarmele', 'Collarmele', 42.0603100, 13.6267000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85298, 'Collalto Sabino', 'Collalto Sabino', 'Collalto Sabino', 42.1352200, 13.0484100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85299, 'Collalbo', 'Collalbo', 'Collalbo,Lengmoos', 46.5398800, 11.4593300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85300, 'Collagna', 'Collagna', 'Collagna', 44.3469400, 10.2735000, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85301, 'Colico Piano', 'Colico Piano', 'Colico,Koliko,Колико', 46.1320500, 9.3771400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85302, 'Coli', 'Coli', 'Coli,kori,コーリ', 44.7458200, 9.4146800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85303, 'Colere', 'Colere', 'Colere', 45.9752200, 10.0835600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85304, 'Coldragone', 'Coldragone', '', 41.5545800, 13.6039900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85305, 'Colbordolo', 'Colbordolo', 'Colbordolo', 43.8200600, 12.7210500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85306, 'Colà', 'Cola', '', 45.4742800, 10.7425700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85307, 'Cogolo', 'Cogolo', 'Cogolo,Cogolo in Val di Pejo', 46.3525200, 10.6928200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85308, 'Cogollo del Cengio', 'Cogollo del Cengio', 'Cogollo del Cengio', 45.7839700, 11.4252700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85309, 'Cogoleto', 'Cogoleto', 'Cogoeuo,Cogoleto', 44.3899600, 8.6469200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85310, 'Cogne', 'Cogne', 'Cogne,Koni', 45.6074200, 7.3580300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85311, 'Coggiola', 'Coggiola', 'Coggiola,Cogiola,Coxula,Cògiola,Goggiola,Kadzhola,Kodzhola,Kojola,ke jiao la,kojjora,kwdjwla,Каджола,Коджола,Кођола,Կոջոլա,كودجولا,コッジョラ,科焦拉', 45.6864000, 8.1825200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85312, 'Codrongianos', 'Codrongianos', 'Codrongianos,Codrongianus', 40.6560300, 8.6814000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85313, 'Codroipo', 'Codroipo', 'Codroip,Codroipo,QOP', 45.9646900, 12.9798500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85314, 'Codogno', 'Codogno', 'Codogno,Codonio,kodonyo,コドーニョ', 45.1618700, 9.7021600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85315, 'Codognè', 'Codogne', 'Codogne,Codognè', 45.8604700, 12.4128400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85316, 'Codisotto', 'Codisotto', 'Cadisotto,Codisotto', 44.9827800, 10.7275000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85317, 'Codigoro', 'Codigoro', 'Codigoro', 44.8309300, 12.1107300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85318, 'Codevilla', 'Codevilla', 'Codevilla', 44.9635300, 9.0577300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85319, 'Codevigo', 'Codevigo', 'Codevigo', 45.2662800, 12.0996100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85320, 'Codemondo-Quaresimo', 'Codemondo-Quaresimo', '', 44.6908200, 10.5509800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85321, 'Codaruina', 'Codaruina', '', 40.9284700, 8.8239800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85322, 'Cocullo', 'Cocullo', 'Cocullo', 42.0328300, 13.7750000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85323, 'Cocquio', 'Cocquio', 'Cocquio-Trevisago', 45.8628800, 8.6882300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85324, 'Cocconato', 'Cocconato', 'Cocconato', 45.0864200, 8.0401900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85325, 'Coccaglio', 'Coccaglio', 'Cocai,Cocallium,Coccaglio,Cocài,Kokal''o,Kokalo,Kokkal''jo,Kokkal''o,ke ka liao,kokkario,Кокальо,Кокаљо,Коккальйо,Коккальо,Կոքալիո,コッカーリオ,科卡廖', 45.5639900, 9.9722400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85326, 'Coazze', 'Coazze', 'Coasse,Coazze,koattsu~e,コアッツェ', 45.0518100, 7.3006300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85327, 'Clusone', 'Clusone', 'Clauso,Clusone,kuruzone,クルゾーネ', 45.8866300, 9.9464600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85328, 'Clusane', 'Clusane', 'Clusane,Clusane sul Lago', 45.6624700, 10.0000500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85329, 'Cles', 'Cles', 'Cles,kuresu,クレス', 46.3629400, 11.0327600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85330, 'Claviere', 'Claviere', 'Clavier,Claviere,Clavieres,Clavieres Torinese,Clavière,Clavières,Clavièrès Torinese,kuravu~iere,クラヴィエーレ', 44.9392200, 6.7521300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85331, 'Clauzetto', 'Clauzetto', 'Clauset,Clausêt,Clauzetto', 46.2293100, 12.9166200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85332, 'Classe', 'Classe', '', 44.3795500, 12.2365400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85333, 'Cizzago', 'Cizzago', '', 45.4712800, 9.9500600, 'IT', '2012-03-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85334, 'Civitella San Paolo', 'Civitella San Paolo', 'Civitella San Paolo,チヴィテッラ・サン・パオロ', 42.1993500, 12.5745500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85335, 'Civitella Roveto', 'Civitella Roveto', 'Civitella Roveto', 41.9132900, 13.4239600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85336, 'Civitella Messer Raimondo', 'Civitella Messer Raimondo', 'Civitella Messer Raimondo', 42.0889300, 14.2170100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85337, 'Civitella Marittima', 'Civitella Marittima', 'Civitella,Civitella Marittima,Civitella Paganico', 42.9940800, 11.2811600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85338, 'Civitella in Val di Chiana', 'Civitella in Val di Chiana', 'Chivitela in Val di Kiana,Chivitela in Val di Kjana,Chivitella-in-Val''-di-K''jana,Chivitella-in-Val''-di-Kjana,Chyvitehla-in-Val''-dzi-Kjana,Civitela in Val de Chiana,Civitella,Civitella Val di Chiana,Civitella Vicecomitatus Vallis Ambrae,Civitella Vicecomitatūs Vallis Ambrae,Civitella della Chiana,Civitella in Val di Chiana,Civitella n Val di Chiana,Civitella sa Val di Chiana,qi wei tai la yi en wa er di ji ya na,Çiviteła in Val de Chiana,Чивитела ин Вал ди Киана,Чивитела ин Вал ди Кјана,Чивителла-ин-Валь-ди-Кьяна,Чивітелла-ін-Валь-ді-Кяна,Чывітэла-ін-Валь-дзі-Кяна,Չիվիտելլա ին Վալ դի Կիանա,チヴィテッラ・イン・ヴァル・ディ・キアーナ,奇维泰拉伊恩瓦尔迪基亚纳', 43.4173100, 11.7229000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85339, 'Civitella di Romagna', 'Civitella di Romagna', 'Civitella,Civitella di Romagna,チヴィテッラ・ディ・ロマーニャ', 44.0078500, 11.9439800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85340, 'Civitella del Tronto', 'Civitella del Tronto', 'Civitella del Tronto', 42.7729800, 13.6762600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85341, 'Civitella d''Agliano', 'Civitella d''Agliano', 'Civitella d''Agliano,チヴィテッラ・ダリアーノ', 42.6029600, 12.1862400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85342, 'Civitella Casanova', 'Civitella Casanova', 'Civitella Casanova', 42.3639100, 13.8851400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85343, 'Civitella Alfedena', 'Civitella Alfedena', 'Civitella Alfedena', 41.7653300, 13.9427100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85344, 'Civitavecchia', 'Civitavecchia', 'Chivitavekk''ja,Civitavecchia,chivu~itavu~ekkia,Чивитавеккья,チヴィタヴェッキア', 42.0932500, 11.7967400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85345, 'Civitaquana', 'Civitaquana', 'Civitaquana', 42.3257800, 13.9001200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85346, 'Civitanova del Sannio', 'Civitanova del Sannio', 'Civitanova del Sannio', 41.6682900, 14.4028500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85347, 'Civitanova Alta', 'Civitanova Alta', 'Civitanova,Civitanova Alta,Civitanova Marche,Civitanova Marche Alta', 43.3161900, 13.6797800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85348, 'Civitaluparella', 'Civitaluparella', 'Civitaluparella', 41.9449000, 14.3013500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85349, 'Civita d''Antino', 'Civita d''Antino', 'Civita d''Antino', 41.8862900, 13.4721500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85350, 'Civita Castellana', 'Civita Castellana', 'Civita Castellana,チーヴィタ・カステッラーナ', 42.2930400, 12.4088500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85351, 'Civitacampomarano', 'Civitacampomarano', '', 41.7803200, 14.6891900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85352, 'Cividate Camuno', 'Cividate Camuno', 'Cividate,Cividate Camuno,Civitas Camunorum,チヴィダーテ・カムーノ', 45.9408700, 10.2661000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85353, 'Cividate al Piano', 'Cividate al Piano', 'Cividate al Piano', 45.5546500, 9.8302400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85354, 'Cividale del Friuli', 'Cividale del Friuli', 'Cividale,Cividale d''Friu,Cividale del Friuli,Cividale d’Friu,Cividat,Cividât', 46.0901900, 13.4286100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85355, 'Civezzano', 'Civezzano', 'Chivecano,Chiveccano,Civezzano,Civitianum,chivu~ettsu~ano,qi wei zha nuo,Чивецано,Чивеццано,Չիվեցանո,チヴェッツァーノ,奇韦扎诺', 46.0913300, 11.1846800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85356, 'Civezza', 'Civezza', 'Civessa,Civezza,chivu~ettsu~a,Çivessa,チヴェッツァ', 43.8798200, 7.9516500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85357, 'Cittiglio', 'Cittiglio', 'Cittiglio', 45.8958700, 8.6655100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85358, 'Città Sant''Angelo', 'Citta Sant''Angelo', 'Citta Sant''Angelo,Città Sant''Angelo', 42.5125400, 14.0620300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85359, 'Cittareale', 'Cittareale', 'Chitareale,Chittareale,Chytarehale,Cittareale,Cittariali,Phalacrina,chitalealle,chittareare,qi ta lei ya lai,Читареале,Читтареале,Чытарэале,Չիտառեալե,チッタレアーレ,奇塔雷亚莱,치타레알레', 42.6162400, 13.1578800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85360, 'Cittaducale', 'Cittaducale', 'Cittaducale', 42.3866400, 12.9549700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85361, 'Città di Castello', 'Citta di Castello', 'Chita di Kastelo,Citta di Castello,Citti Di Castello,Città di Castello,Tifernum Tiberinum,Чита ди Кастело,チッタ・ディ・カステッロ', 43.4655600, 12.2375000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85362, 'Città della Pieve', 'Citta della Pieve', 'Chita dela Pieve,Citta della Pieve,Città della Pieve,Чита дела Пиеве', 42.9593400, 12.0069600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85363, 'Cittadella', 'Cittadella', 'Cittadella', 45.6452300, 11.7845300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85364, 'Citerna', 'Citerna', 'Chiterna,Citerna,Civitas Sobariae,chiteleuna,chiteruna,qi tai er na,tshytyrna,Çiterna,Читерна,Չիտերնա,تشيتيرنا,チテルナ,奇泰尔纳,치테르나', 43.4988200, 12.1137600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85365, 'Cisternino', 'Cisternino', 'Cisternino', 40.7432600, 17.4258700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85366, 'Cisterna di Latina', 'Cisterna di Latina', 'Cisterna', 41.5908000, 12.8280800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85367, 'Cisterna d''Asti', 'Cisterna d''Asti', 'Cisterna d''Asti', 44.8252500, 8.0007600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85368, 'Cison di Valmarino', 'Cison di Valmarino', 'Cison di Valmarino', 45.9669400, 12.1426700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85369, 'Cismon del Grappa', 'Cismon del Grappa', 'Cismon,Cismon del Grappa', 45.9202600, 11.7281600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85370, 'Cisliano', 'Cisliano', 'Cisliano,chizuriano,チズリアーノ', 45.4437100, 8.9869500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85371, 'Cislago', 'Cislago', 'Cislago', 45.6592800, 8.9727200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85372, 'Ciserano', 'Ciserano', 'Ciserano', 45.5879200, 9.6011500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85373, 'Cisano', 'Cisano', 'Cisano,Cisano sul Neva', 44.0856500, 8.1482900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85374, 'Cisano Bergamasco', 'Cisano Bergamasco', 'Cisano,Cisano Bergamasco', 45.7420000, 9.4714600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85375, 'Cirimido', 'Cirimido', 'Cirimido', 45.6997800, 9.0125400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85376, 'Cirigliano', 'Cirigliano', 'Cirigliano', 40.3937600, 16.1719400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85377, 'Ciriè', 'Cirie', 'Cirie,Ciriè,Cirié,chirie,cirie,ciriè,チリエ', 45.2348600, 7.6012500, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85378, 'Circello', 'Circello', 'Circello', 41.3545500, 14.8091000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85379, 'Cipressa', 'Cipressa', 'Cipressa,Çipressa', 43.8520500, 7.9314400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85380, 'Ciorlano', 'Ciorlano', 'Ciorlano', 41.4502200, 14.1583200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85381, 'Cinzano', 'Cinzano', 'Cinzano', 45.0952800, 7.9242700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85382, 'Cinto Caomaggiore', 'Cinto Caomaggiore', 'Cinto,Cinto Caomaggiore', 45.8275800, 12.7812600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85383, 'Cinte Tesino', 'Cinte Tesino', 'Cinte Tesino,チンテ・テジーノ', 46.0572600, 11.6143500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85384, 'Cintano', 'Cintano', 'Cintano,chintano,チンターノ', 45.4281200, 7.6882700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85385, 'Capanne-Prato-Cinquale', 'Capanne-Prato-Cinquale', 'Cinquale,Marina di Montignoso', 43.9972000, 10.1563600, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85386, 'Cinisello Balsamo', 'Cinisello Balsamo', 'Cinisello,Cinisello Balsamo,チニゼッロ・バルサモ', 45.5582300, 9.2149500, 'IT', '2015-08-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85387, 'Cinigiano', 'Cinigiano', 'Cinigiano', 42.8905900, 11.3919600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85388, 'Cingoli', 'Cingoli', 'Cingoli', 43.3757300, 13.2078700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85389, 'Cingia de'' Botti', 'Cingia de'' Botti', 'Cingia de'' Botti,Cingia de''Botti', 45.0850700, 10.2754800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85390, 'Cineto Romano', 'Cineto Romano', 'Cineto Romano,チネート・ロマーノ', 42.0501400, 12.9608000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85391, 'Cimolais', 'Cimolais', 'Cimolais', 46.2890000, 12.4379200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85392, 'Cimitile', 'Cimitile', 'Cimitile,chimitire,チミティーレ', 40.9423100, 14.5255800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85393, 'Cimego', 'Cimego', 'Cimego,chimego,チーメゴ', 45.9119000, 10.6133700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85394, 'Cimbergo', 'Cimbergo', 'Cimbergo,chinberugo,チンベルゴ', 46.0241000, 10.3656600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85395, 'Cimadolmo', 'Cimadolmo', 'Cimadolmo', 45.7852400, 12.3651000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85396, 'Cilavegna', 'Cilavegna', 'Cilavegna', 45.3106700, 8.7446900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85397, 'Cigole', 'Cigole', 'Cigole,chigore,チーゴレ', 45.3076000, 10.1897700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85398, 'Cigliano', 'Cigliano', 'Cigliano', 45.3080400, 8.0231600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85399, 'Cicognolo', 'Cicognolo', 'Cicognolo', 45.1676200, 10.1940700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85400, 'Ciciliano', 'Ciciliano', 'Ciciliano,chichiriano,チチリアーノ', 41.9599000, 12.9416300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85401, 'Cicerale', 'Cicerale', 'Cicerale', 40.3440400, 15.1295900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85402, 'Cicciano', 'Cicciano', 'Cicciano,chitchano,チッチャーノ', 40.9640200, 14.5348700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85403, 'Cicagna', 'Cicagna', 'Cicagna', 44.4071400, 9.2391700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85404, 'Cibiana', 'Cibiana', 'Cibiana di Cadore', 46.3885600, 12.2865800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85405, 'Ciano d''Enza', 'Ciano d''Enza', 'Ciano', 44.5998200, 10.4104000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85406, 'Sant''Andrea-Pizzone-Ciamprisco', 'Sant''Andrea-Pizzone-Ciamprisco', '', 41.1500000, 14.0333300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85407, 'Ciampino', 'Ciampino', 'Champino,Ciampino,chanpino,Чампино,チャンピーノ', 41.8006400, 12.6015800, 'IT', '2015-07-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85408, 'Chivasso', 'Chivasso', 'Chivasso,Civass,Clavassium,Kivasso,kivu~asso,Кивассо,キヴァッソ', 45.1909300, 7.8898100, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85409, 'Chiusi della Verna', 'Chiusi della Verna', 'Chiusi della Verna', 43.6974500, 11.9350400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85410, 'Chiusi', 'Chiusi', 'Chiusi,kiuji,キウージ', 43.0141800, 11.9479100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85411, 'Chiusdino', 'Chiusdino', 'Chiusdino,kiuzudino,キウズディーノ', 43.1545400, 11.0831000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85412, 'Chiusavecchia', 'Chiusavecchia', 'Chiusavecchia,Ciusavegia', 43.9672600, 7.9844300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85413, 'Chiusano di San Domenico', 'Chiusano di San Domenico', 'Chiusano di San Domenico,Chiusano di San Domenico vald,Chiusanu di San Duminicu,Clusanum,K''juzano-di-San-Domeniko,Kiuzano di San Domeniko,Kjuzano di San Domeniko,Kjuzano-di-San-Domeniko,ji wu sa nuo sheng duo mei ni ke,kiusanodisandomeniko,Киузано ди Сан Доменико,Кьюзано-ди-Сан-Доменико,Кюзано-ді-Сан-Доменіко,Кјузано ди Сан Доменико,Կիուզանո դի Սան Դոմենիկո,キウザーノ・ディ・サン・ドメーニコ,基乌萨诺圣多梅尼科,키우사노디산도메니코', 40.9331200, 14.9163400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85414, 'Chiusanico', 'Chiusanico', 'Chiusanico,Ciusanego', 43.9730300, 7.9918500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85415, 'Chiusaforte', 'Chiusaforte', 'Chiusaforte,Scluse', 46.4066300, 13.3055200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85416, 'Chiusa di Pesio', 'Chiusa di Pesio', 'Chiusa Pesio,Chiusa di Pesio', 44.3258800, 7.6743100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85417, 'Chiusa', 'Chiusa', 'Chiusa,Clusa,K''juza,Kiouza,Kiuza,Kjuza,Klausen,Tluses,ZAK,ji wu sa,kiuza,Κιούζα,Киуза,Кьюза,Кюза,Кјуза,Կիուզա,キウーザ,基乌萨', 46.6400100, 11.5657300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85418, 'Chiuro', 'Chiuro', 'Chiuro', 46.1672200, 9.9858400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85419, 'Chiuppano', 'Chiuppano', 'Chiuppano', 45.7630000, 11.4577700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85420, 'Chitignano', 'Chitignano', 'Chitignan,Chitignano,Chitignanu,Chitinianum,Kitin''jano,Kitinano,Kitinjano,Kitinyano,Kitynjana,ji di ni ya nuo,kitinyano,Китиньяно,Китиняно,Китињано,Кітыняна,Кітіньяно,Կիտինյանո,キティニャーノ,基蒂尼亚诺', 43.6616300, 11.8813500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85421, 'Chions', 'Chions', 'Chions,Cjons', 45.8454600, 12.7123200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85422, 'Chiomonte', 'Chiomonte', 'Chaumont,Chiomonte,Cimon,kiomonte,キオモンテ', 45.1190900, 6.9842000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85423, 'Chioggia', 'Chioggia', 'Chioggia,kiojja,キオッジャ', 45.2185700, 12.2777400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85424, 'Chieuti', 'Chieuti', 'Chieuti,Qefti', 41.8448600, 15.1668100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85425, 'Chieti', 'Chieti', 'Chieta,Chieti,K''eti,Teate,kieti,Кьети,キエーティ', 42.3482700, 14.1649400, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85426, 'Chiesina Uzzanese', 'Chiesina Uzzanese', 'Chiesina Uzzanese', 43.8389100, 10.7204400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85427, 'Chiesa in Valmalenco', 'Chiesa in Valmalenco', 'Chiesa,Chiesa di Valmalenco,Chiesa in Valmalenco,Ecclesia in Valle Malenci,K''eza-in-Val''malenko,Keza-in-Val''malenko,Kieza in Valmalenko,Kieza-in-Val''malenko,Kjeza in Valmalenko,Sgesa,ji ye sa yi en wa er ma lun ke,Киеза ин Валмаленко,Киеза-ин-Вальмаленко,Кьеза-ин-Вальмаленко,Кєза-ін-Вальмаленко,Кјеза ин Валмаленко,Կիեզա ին Վալմալենկո,キエーザ・イン・ヴァルマレンコ,基耶萨伊恩瓦尔马伦科', 46.2671500, 9.8490500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85428, 'Gionghi-Cappella', 'Gionghi-Cappella', '', 45.9368000, 11.2747800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85429, 'Chieri', 'Chieri', 'Cher,Chieri,kieri,キエーリ', 45.0105400, 7.8213300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85430, 'Chienes', 'Chienes', 'Chienes,Cluenes,K''enes,Kenes,Kienes,Kiens,Kjenes,ji ye nei si,kienesu,Кенес,Киенес,Кьенес,Кєнес,Кјенес,Կիենես,キエーネス,基耶内斯', 46.8068000, 11.8400200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85431, 'Chiavenna', 'Chiavenna', 'Chiavenna,Clavenna', 46.3206300, 9.3981600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85432, 'Chiavari', 'Chiavari', 'Chiavari,Ciaevai,Ciävai,Kiavari,Киавари', 44.3177100, 9.3224100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85433, 'Chiauci', 'Chiauci', 'Chiauci', 41.6779100, 14.3839300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85434, 'Chiaromonte', 'Chiaromonte', 'Chiaramonte,Chiaromonte', 40.1232300, 16.2144000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85435, 'Chiari', 'Chiari', 'Chiari,Clarium,kiari,キアーリ', 45.5376300, 9.9269900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85436, 'Chiaravalle', 'Chiaravalle', 'Chiaravalle,Chiaravalle Marche,kiaravu~arre,キアラヴァッレ', 43.6011400, 13.3251100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85437, 'Chiarano', 'Chiarano', 'Chiarano', 45.7295900, 12.5716600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85438, 'Chiaramonti', 'Chiaramonti', 'Chiaramonti,Claramons,K''jaramonti,Kiaramonti,Kjaramonti,Tzaramonte,ji ya la meng di,kiaramonti,Киарамонти,Кьярамонти,Кярамонті,Кјарамонти,Կիարամոնտի,キアラモンティ,基亚拉蒙蒂', 40.7482900, 8.8211400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85439, 'Chianni', 'Chianni', 'Chianni', 43.4815300, 10.6413300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85440, 'Chianciano Terme', 'Chianciano Terme', 'Bagni di Chianciano,Chianciano,Chianciano Bagni,Chianciano Terme,Il Bagno,キアンチャーノ・テルメ', 43.0418100, 11.8120500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85441, 'Chianche', 'Chianche', '', 41.0463200, 14.7890400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85442, 'Chiampo', 'Chiampo', '', 45.5474600, 11.2828500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85443, 'Chialamberto', 'Chialamberto', 'Chialamberto,Cialambert,Cialambèrt,kiaranberuto,キアランベルト', 45.3629500, 7.3436300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85444, 'Cheremule', 'Cheremule', 'Cheremule', 40.5045500, 8.7258200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85445, 'Cherasco', 'Cherasco', 'Cherasch,Cherasco', 44.6434500, 7.8581800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85446, 'Chatillon', 'Chatillon', 'Castiglion Dora,Chatillion,Chatillon,Châtillon', 45.7499100, 7.6166800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85447, 'Charvensod', 'Charvensod', 'Charvensod', 45.7202500, 7.3243300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85448, 'Champdepraz', 'Champdepraz', 'Champdepraz', 45.6852600, 7.6568100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85449, 'Chambave', 'Chambave', 'Chambave,Ciambave', 45.7442600, 7.5493100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85450, 'Cevo', 'Cevo', 'Cevo,chevu~o,チェーヴォ', 46.0808900, 10.3695200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85451, 'Ceva', 'Ceva', 'Ceva,Cheva,chevu~a,Чева,チェーヴァ', 44.3850500, 8.0276900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85452, 'Cetona', 'Cetona', 'Cetona,Chehtona,Chetona,Citonia,chetona,qie tuo na,Четона,Чэтона,Չետոնա,チェトーナ,切托纳,체토나', 42.9665500, 11.9026800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85453, 'Ceto', 'Ceto', 'Ceto,cheto,チェート', 46.0025900, 10.3519600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85454, 'Cetara', 'Cetara', 'Cetara,Chetara,Четара', 40.6475600, 14.7009100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85455, 'Coccanile-Cesta', 'Coccanile-Cesta', '', 44.9166700, 11.8666700, 'IT', '2015-11-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85456, 'Cessole', 'Cessole', 'Cessole', 44.6487700, 8.2443800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85457, 'Cessapalombo', 'Cessapalombo', 'Cessapalombo', 43.1082500, 13.2575800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85458, 'Cessalto', 'Cessalto', 'Cessalto', 45.7135600, 12.6130200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85459, 'Cesiomaggiore', 'Cesiomaggiore', 'Cesiomaggiore', 46.0867500, 11.9853900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85460, 'Cesio', 'Cesio', 'Cesio,Ceslo,Cexi', 44.0080300, 7.9751500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85461, 'Cesenatico', 'Cesenatico', 'Cesenatico,Chezenatiko,chezenatiko,Чезенатико,チェゼナーティコ', 44.1998700, 12.3991000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85462, 'Cesena', 'Cesena', 'Caesena,Cesena,Cesene,Chezena,Césène,Zisena,Zisèna,chezena,Чезена,チェゼーナ', 44.1391000, 12.2431500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85463, 'Cesarolo', 'Cesarolo', '', 45.7188400, 13.0155500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85464, 'Porto Cesareo', 'Porto Cesareo', 'Porto Cesareo,Porto Cesario', 40.2622800, 17.8989600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85465, 'Cesara', 'Cesara', 'Cesara', 45.8337900, 8.3677700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85466, 'Cesano Maderno', 'Cesano Maderno', 'Cesano,Cesano Maderno,チェザーノ・マデルノ', 45.6291500, 9.1518900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85467, 'Cesano', 'Cesano', 'Cesano', 42.0737500, 12.3371100, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85468, 'Cesana Torinese', 'Cesana Torinese', 'Cesana,Cesana Torinese,Cesanne,チェザーナ・トリネーゼ', 44.9534000, 6.7919900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85469, 'Cesa', 'Cesa', '', 43.3162400, 11.8126200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85470, 'Cesa', 'Cesa', 'Cesa', 40.9628700, 14.2308100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85471, 'Cervo', 'Cervo', 'Cervo,O Cervo,O Çervo', 43.9257200, 8.1152900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85472, 'Cervino', 'Cervino', 'Cervino', 41.0400100, 14.4240300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85473, 'Cervignano del Friuli', 'Cervignano del Friuli', 'Carvignan,Cervenianum,Cervignan Sarvignan,Cervignano,Cervignano del Friuli,Çarvignan', 45.8208200, 13.3392900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85474, 'Cervia', 'Cervia', 'Cervia,Chervia,cheruvu~ia,Червиа,チェルヴィア', 44.2620400, 12.3481200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85475, 'Cerveteri', 'Cerveteri', 'Caere,Cerveleri,Cerveteri,Cherveteri,cheruvu~eteri,Черветери,チェルヴェーテリ', 41.9908000, 12.0908200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85476, 'Cervesina', 'Cervesina', 'Cervesina', 45.0605400, 9.0167600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85477, 'Cervere', 'Cervere', 'Cervere', 44.6342800, 7.7888400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85478, 'Cerveno', 'Cerveno', 'Cervedo,Cerveno,cheruvu~eno,チェルヴェーノ', 46.0017600, 10.3283000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85479, 'Cervaro', 'Cervaro', 'Cervaro,Cervaro di Frosinone', 41.4827800, 13.9021800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85480, 'Cervara di Roma', 'Cervara di Roma', 'Cervara di Roma,チェルヴァーラ・ディ・ローマ', 41.9882200, 13.0679900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85481, 'Certosa di Pavia', 'Certosa di Pavia', 'Certosa di Pavia,Torre del Mangano,チェルトーザ・ディ・パヴィーア', 45.2542000, 9.1329000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85482, 'Certosa', 'Certosa', '', 46.7045000, 10.9108800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85483, 'Certaldo', 'Certaldo', 'Certaldo', 43.5476800, 11.0392400, 'IT', '2016-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85484, 'Cersosimo', 'Cersosimo', 'Cersosimo', 40.0470300, 16.3505900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85485, 'Cerro Maggiore', 'Cerro Maggiore', 'Cerro,Cerro Maggiore,チェッロ・マッジョーレ', 45.5936600, 8.9542800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85486, 'Cerro al Volturno', 'Cerro al Volturno', 'Cerro,Cerro a Volturno,Cerro al Volturno', 41.6541800, 14.1032100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85487, 'Cerrione', 'Cerrione', 'Cerrione', 45.4693300, 8.0684000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85488, 'Cerreto Sannita', 'Cerreto Sannita', 'Cerreto Sannita', 41.2829600, 14.5614700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85489, 'Cerreto Laziale', 'Cerreto Laziale', 'Cerreto Laziale,チェッレート・ラツィアーレ', 41.9433200, 12.9816900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85490, 'Cerreto Guidi', 'Cerreto Guidi', 'Cereto Guidi,Cerreto Guidi,Cerretu Guidi,Cerretum,Chehrehta-Gujdzi,Chereto Guidi,Chereto Gvidi,Cherreto-Guidi,Cherreto-Gujdi,Cherreto-Gvidi,qie lei tuo gui di,Черето Гвиди,Черето Гуиди,Черрето-Гвиди,Черрето-Гуйди,Черрето-Гуїді,Чэрэта-Гуйдзі,Չերետո Գվիդի,チェッレート・グイーディ,切雷托圭迪', 43.7585100, 10.8819100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85491, 'Cerreto di Spoleto', 'Cerreto di Spoleto', 'Cerreto,Cerreto di Spoleto,Cerretu di Spoletu,Cerretum Spoletinorum,Chehrehta-dzi-Spaleta,Chereto di Spoleto,Cherreto-di-Spoleto,cheletodiseupolleto,qie lei tuo di si bo lai tuo,tshrytw dy sbwlytw,Черето ди Сполето,Черрето-ди-Сполето,Черрето-ді-Сполето,Чэрэта-дзі-Спалета,Չերետո դի Սպոլետո,تشريتو دي سبوليتو,チェッレート・ディ・スポレート,切雷托迪斯波莱托,체레토디스폴레토', 42.8218800, 12.9203200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85492, 'Cerreto d''Esi', 'Cerreto d''Esi', 'Cerreto,Cerreto d''Esi,チェッレート・デージ', 43.3166800, 12.9877100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85493, 'Cerratina', 'Cerratina', '', 42.3900700, 14.1033800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85494, 'Cernusco sul Naviglio', 'Cernusco sul Naviglio', 'Cernusco,Cernusco sul Naviglio,チェルヌスコ・スル・ナヴィーリオ', 45.5252600, 9.3329700, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85495, 'Cernobbio', 'Cernobbio', 'Cernobbio,Cernobi,Cernobium,Chernobb''o,Chernobbio,Chernobio,cherunobbio,qie er nuo bi ao,Черноббьо,Черноббіо,Чернобио,Չերնոբիո,チェルノッビオ,切尔诺比奥', 45.8430700, 9.0719400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85496, 'Cermignano', 'Cermignano', 'Cermignano', 42.5913100, 13.7954000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85497, 'Cermes', 'Cermes', 'Cermes,Cerones,Chehrmes,Chermes,Tscherms,cherumesu,qie er mei si,Чермес,Чэрмес,Չերմես,チェルメス,切尔梅斯', 46.6327700, 11.1469600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85498, 'Cermenate', 'Cermenate', 'Cermenate', 45.7019800, 9.0836100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85499, 'Cerlongo', 'Cerlongo', 'Cerlongo,Cerlongo i Cerri', 45.2786200, 10.6498500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85500, 'Cerignola', 'Cerignola', 'Corignola', 41.2652300, 15.8955900, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85501, 'Ceriano Laghetto', 'Ceriano Laghetto', 'Ceriano,Ceriano Laghetto,チェリアーノ・ラゲット', 45.6292800, 9.0801700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85502, 'Ceriana', 'Ceriana', 'Ceriana,Çeriana', 43.8809100, 7.7747600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85503, 'Ceriale', 'Ceriale', 'Ceriale,O Ceja,O Çejâ', 44.0912800, 8.2289300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85504, 'Cergnago', 'Cergnago', 'Cergnago', 45.1982600, 8.7716400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85505, 'Cerfignano', 'Cerfignano', '', 40.0610700, 18.4429100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85506, 'Cerete Alto', 'Cerete Alto', 'Cerete', 45.8672900, 9.9946600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85507, 'Ceresole Reale', 'Ceresole Reale', 'Ceresole,Ceresole Reale,Ceresòle,チェレゾーレ・レアーレ', 45.4323500, 7.2350600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85508, 'Cereseto', 'Cereseto', 'Cereseto,Ciarzin', 45.0868500, 8.3181700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85509, 'Cerese', 'Cerese', 'Andes,Virgilio,vu~irujirio,ヴィルジーリオ', 45.1181400, 10.7887700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85510, 'Ceresara', 'Ceresara', 'Ceresara', 45.2622800, 10.5695800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85511, 'Ceres', 'Ceres', 'Cere,Ceres,cheresu,チェーレス', 45.3133600, 7.3896100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85512, 'Ceregnano', 'Ceregnano', 'Ceregnano', 45.0481100, 11.8679200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85513, 'Cerea', 'Cerea', 'Cerea', 45.1893600, 11.2166100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85514, 'Cercola', 'Cercola', 'Cercola,cherukora,チェルコラ', 40.8604300, 14.3573300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85515, 'Cercino', 'Cercino', 'Cercino', 46.1580900, 9.5081400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85516, 'Cerchio', 'Cerchio', 'Cerchio,Cerchiu,Cherk''o,Cherkio,Circulus,cheleukio,cherukio,chrkyw,qie er ji ao,tshrkyw,Черкио,Черкьо,Չերկիո,تشركيو,چرکیو,チェルキオ,切尔基奥,체르키오', 42.0635700, 13.6000600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85517, 'Cercepiccola', 'Cercepiccola', 'Cercepiccola', 41.4598200, 14.6648700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85518, 'Cercemaggiore', 'Cercemaggiore', 'Cercemaggiore', 41.4613000, 14.7240200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85519, 'Cerbaia', 'Cerbaia', '', 43.6851900, 11.1288900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85520, 'Cerasolo', 'Cerasolo', '', 43.9880500, 12.5298800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85521, 'Ceraso', 'Ceraso', 'Cerasa,Ceraso', 40.1943000, 15.2560600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85522, 'Cerano', 'Cerano', 'Cerano', 45.4091500, 8.7835100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85523, 'Ceprano', 'Ceprano', 'Ceprano', 41.5457200, 13.5147300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85524, 'Ceppaloni', 'Ceppaloni', 'Ceppaloni', 41.0452300, 14.7610200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85525, 'Ceparana-Carpena', 'Ceparana-Carpena', 'Ceparana,Cepparana', 44.1666700, 9.8833300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85526, 'Cepagatti', 'Cepagatti', 'Cepagalli,Cepagatti', 42.3650600, 14.0742400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85527, 'Centrale', 'Centrale', '', 45.7273700, 11.4803100, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85528, 'Centola', 'Centola', 'Centola', 40.0698000, 15.3119100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85529, 'Cento', 'Cento', 'Centas,Cento,Centum,Chento,chento,qin tuo,sntw  frara,tshntw,zntw,Čentas,Ченто,Չենտո,צנטו,تشنتو,سنتو، فرارا,チェント,琴托', 44.7309900, 11.2871600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85530, 'Centa San Nicolò', 'Centa San Nicolo', 'Centa San Nicolo,Centa San Nicolò,チェンタ・サン・ニコロ', 45.9693000, 11.2323800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85531, 'Centallo', 'Centallo', 'Centallo,Sental', 44.5015300, 7.5878300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85532, 'Cengio Alto', 'Cengio Alto', 'Cenge,Cengio,Cengë,chenjo,チェンジョ', 44.3844300, 8.1975800, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85533, 'Ceneselli', 'Ceneselli', 'Ceneseli,Ceneselli,Cenesellium,Cenesełi,Chenezeli,Chenezelli,chenezerri,qie nei sai li,Ченезели,Ченезелли,Ченезеллі,Չենեզելի,チェネゼッリ,切内塞利', 45.0137700, 11.3693600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85534, 'Cene', 'Cene', 'Cene', 45.7806200, 9.8265700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85535, 'Cencenighe Agordino', 'Cencenighe Agordino', '', 46.3518400, 11.9682300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85536, 'Cenaia', 'Cenaia', 'Cenaia,Cenaia Nuova,Cenaja Nuova', 43.6063700, 10.5357100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85537, 'Cembra', 'Cembra', 'Cembra', 46.1748900, 11.2217400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85538, 'Cellole', 'Cellole', 'Cellole', 41.2033800, 13.8533200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85539, 'Cellio', 'Cellio', 'Cej,Cellio,Cèj', 45.7550500, 8.3118500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85540, 'Cellino San Marco', 'Cellino San Marco', 'Cellino San Marco,Cellinu Santu Marcu,チェッリーノ・サン・マルコ', 40.4713300, 17.9642700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85541, 'Cellino Attanasio', 'Cellino Attanasio', 'Cellino,Cellino Attanasio', 42.5857400, 13.8605000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85542, 'Celle di San Vito', 'Celle di San Vito', '', 41.3259300, 15.1810400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85543, 'Cellere', 'Cellere', 'Cellere', 42.5102400, 11.7707900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85544, 'Celleno', 'Celleno', 'Celleno', 42.5603900, 12.1244200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85545, 'Celle Ligure', 'Celle Ligure', 'Celle Ligure,チェッレ・リーグレ', 44.3450900, 8.5468500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85546, 'Celle di Bulgheria', 'Celle di Bulgheria', 'Celle,Celle Bulgheria,Celle di Bulgheria', 40.0954000, 15.4032400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85547, 'Cellamare', 'Cellamare', 'Cellamare,Cellammare', 41.0196900, 16.9274100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85548, 'Celenza Valfortore', 'Celenza Valfortore', 'Celenza Valfortore', 41.5604800, 14.9789800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85549, 'Celenza sul Trigno', 'Celenza sul Trigno', 'Celenza sul Trigno', 41.8719800, 14.5789300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85550, 'Celano', 'Celano', 'Celano', 42.0807700, 13.5170000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85551, 'Ceglie Messapica', 'Ceglie Messapica', 'Ceglie Messapica,Céglie Messápica,チェーリエ・メッサピーカ', 40.6462000, 17.5166100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85552, 'Ceggia', 'Ceggia', 'Ceggia,chejja,チェッジャ', 45.6870000, 12.6422800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85553, 'Cedrasco', 'Cedrasco', 'Cedrasco', 46.1493200, 9.7680300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85554, 'Cedegolo', 'Cedegolo', 'Cedegolo,chedegoro,チェデーゴロ', 46.0739800, 10.3514100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85555, 'Cecina', 'Cecina', 'Cecina,Chechina,chechina,Чечина,チェーチナ', 43.3062100, 10.5172900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85556, 'Cecchini', 'Cecchini', '', 45.8655100, 12.6222000, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85557, 'Cecchina', 'Cecchina', 'Cecchina,Chekina,tshykyna,Чекина,تشيكينا', 41.7016100, 12.6497200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85558, 'Ceccano', 'Ceccano', 'Ceccano,Chekkano,Чеккано', 41.5723600, 13.3290100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85559, 'Cazzano Sant''Andrea', 'Cazzano Sant''Andrea', 'Cazzano Sant''Andrea', 45.8111800, 9.8849300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85560, 'Cazzago San Martino-Calino', 'Cazzago San Martino-Calino', 'Cazzago San Martino,カッツァーゴ・サン・マルティーノ', 45.5843400, 10.0232800, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85561, 'Cavriglia-Monastero', 'Cavriglia-Monastero', 'Cavriglia', 43.5202500, 11.4869300, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85562, 'Cavriana', 'Cavriana', 'Cavriana', 45.3476600, 10.5959800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85563, 'Cavriago', 'Cavriago', 'Capriago,Cavriago,Gavriago', 44.6945700, 10.5259100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85564, 'Cavour', 'Cavour', 'Cavour,ka wu er,kavuru,カヴール,卡武尔', 44.7928600, 7.3743800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85565, 'Cavolano-Schiavoi', 'Cavolano-Schiavoi', '', 45.9333300, 12.5000000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85566, 'Cavezzo', 'Cavezzo', 'Cavezzo', 44.8350000, 11.0289000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85567, 'Cavenago di Brianza', 'Cavenago di Brianza', 'Cavenago di Brianza,カヴェナーゴ・ディ・ブリアンツァ', 45.5829700, 9.4126100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85568, 'Cavenago d''Adda', 'Cavenago d''Adda', 'Cavenago d''Adda,カヴェナーゴ・ダッダ', 45.2825300, 9.5987200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85569, 'Cavedago', 'Cavedago', 'Cavedago,kavu~edago,カヴェダーゴ', 46.1848600, 11.0327700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85570, 'Cave', 'Cave', 'Cave,kavu~e,カーヴェ', 41.8168200, 12.9405500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85571, 'Cavazzo Carnico', 'Cavazzo Carnico', 'Cavazzo,Cavazzo Carnico,Cjavac', 46.3679300, 13.0407500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85572, 'Cavasso Nuovo', 'Cavasso Nuovo', 'Cavasso,Cavasso Nuovo,Cjavas', 46.1944100, 12.7719300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85573, 'Cavarzere', 'Cavarzere', 'Cavarzere,kavu~arutsu~ere,カヴァルツェレ', 45.1351800, 12.0845300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85574, 'Cavaria Con Premezzo', 'Cavaria Con Premezzo', 'Cavaria con Premezzo', 45.6924700, 8.8029900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85575, 'Cavargna', 'Cavargna', 'Cavargna', 46.0906800, 9.1120500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85576, 'Cavareno', 'Cavareno', 'Cavareno,kavu~areno,カヴァレーノ', 46.4078000, 11.1393400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85577, 'Cava Manara', 'Cava Manara', 'Cava Manara', 45.1401400, 9.1077400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85578, 'Cavallirio', 'Cavallirio', '', 45.6622700, 8.3969400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85579, 'Cavallino', 'Cavallino', 'Cavallino,Cavallinu', 40.3102000, 18.2022100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85580, 'Cavallermaggiore', 'Cavallermaggiore', 'Cavallermaggiore,Cavlimor', 44.7063900, 7.6869300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85581, 'Cavalese', 'Cavalese', 'Cavalese,kavu~areze,カヴァレーゼ', 46.2904800, 11.4586200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85582, 'Cavajon Veronese', 'Cavajon Veronese', 'Cavaion Veronese', 45.5400900, 10.7704800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85583, 'Cavaglià', 'Cavaglia', 'Cavaglia,Cavaglià,Cavaja,Cavajà', 45.4060200, 8.0916300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85584, 'Cava Dè Tirreni', 'Cava De Tirreni', 'Cava,Cava de'' Tirreni,Cava de''Tirreni,Cava dei Tirreni', 40.6995400, 14.7077300, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85585, 'Cavacurta', 'Cavacurta', 'Cavacurta,kavu~akuruta,カヴァクルタ', 45.1897700, 9.7418600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85586, 'Cautano', 'Cautano', 'Cautano', 41.1500900, 14.6442500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85587, 'Cattolica', 'Cattolica', 'Cattolica,kattorika,カットーリカ', 43.9618200, 12.7363100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85588, 'Catignano', 'Catignano', 'Catignano', 42.3469700, 13.9519000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85589, 'Ca'' Tiepolo', 'Ca'' Tiepolo', '', 44.9486100, 12.3391700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85590, 'Cataeggio', 'Cataeggio', 'Cataeggio,Cattaeggio', 46.2144700, 9.6378100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85591, 'Castropignano', 'Castropignano', 'Castropignano,Castropignanu,Castrum Pinianum,Kastrapinjana,Kastropin''jano,Kastropinano,Kastropinjano,Kastropinyano,ka si te luo pi ni ya nuo,kaseuteulopinyano,kastrwpynanw,kasutoropinyano,Кастрапіняна,Кастропиньяно,Кастропиняно,Кастропињано,Кастропіньяно,Կաստրոպինյանո,کاستروپینانو,カストロピニャーノ,卡斯特罗皮尼亚诺,카스트로피냐노', 41.6178800, 14.5585600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85592, 'Castronuovo di Sant''Andrea', 'Castronuovo di Sant''Andrea', 'Castronuovo di Sant''Andrea', 40.1890300, 16.1855900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85593, 'Castronno', 'Castronno', 'Castronno', 45.7479300, 8.8144200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85594, 'Castro dei Volsci', 'Castro dei Volsci', 'Castro de'' Volsci,Castro dei Volsci', 41.5082200, 13.4063000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85595, 'Castrocielo', 'Castrocielo', 'Castrocielo', 41.5273600, 13.6958800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85596, 'Castrocaro Terme', 'Castrocaro Terme', '', 44.1755600, 11.9495200, 'IT', '2012-03-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85597, 'Castro', 'Castro', 'Castro,kasutoro,カストロ', 45.8037800, 10.0659000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85598, 'Castrignano De'' Greci', 'Castrignano De'' Greci', 'Castrignano de'' Greci,Castrignano de''Greci', 40.1734200, 18.2964300, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85599, 'Castri di Lecce', 'Castri di Lecce', 'Castri di Lecce', 40.2736000, 18.2624000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85600, 'Castorano', 'Castorano', 'Castorano', 42.8977900, 13.7296700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85601, 'Casto', 'Casto', 'Casto,kasuto,カスト', 45.6948900, 10.3211700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85602, 'Castions di Strada', 'Castions di Strada', 'Castions di Strada,Cjasteons di Stradalte', 45.9124700, 13.1816700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85603, 'Castions', 'Castions', '', 45.9721800, 12.7996100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85604, 'Castione della Presolana', 'Castione della Presolana', 'Castione,Castione della Presolana', 45.9147100, 10.0554000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85605, 'Castino', 'Castino', 'Castino', 44.6178400, 8.1824400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85606, 'Castilenti', 'Castilenti', 'Castilenti', 42.5333400, 13.9171000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85607, 'Castignano', 'Castignano', 'Castignano', 42.9393500, 13.6251400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85608, 'Castiglion Fiorentino', 'Castiglion Fiorentino', 'Castiglion Fiorentino,Castiglione Fiorentino', 43.3430800, 11.9199500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85609, 'Castiglion Fibocchi', 'Castiglion Fibocchi', 'Castiglion Fibocchi,Castiglione Fibocchi', 43.5274200, 11.7615100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85610, 'Castiglione Olona', 'Castiglione Olona', 'Castiglione Olona', 45.7525600, 8.8727800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85611, 'Castiglione Messer Raimondo', 'Castiglione Messer Raimondo', 'Castiglione Messer Raimondo', 42.5319400, 13.8795300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85612, 'Castiglione Messer Marino', 'Castiglione Messer Marino', 'Castiglione Messer Marino', 41.8683300, 14.4499600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85613, 'Castiglione in Teverina', 'Castiglione in Teverina', 'Castiglione in Teverina,カスティリオーネ・イン・テヴェリーナ', 42.6507600, 12.2030500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85614, 'Castiglione d''Orcia', 'Castiglione d''Orcia', 'Castiglione d''Orcia,カスティリオーネ・ドルチャ', 43.0046000, 11.6145100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85615, 'Castiglione d''Intelvi', 'Castiglione d''Intelvi', 'Castiglione d''Intelvi', 45.9575100, 9.0898700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85616, 'Castiglione di Garfagnana', 'Castiglione di Garfagnana', 'Castiglione di Garfagnana', 44.1524800, 10.4121200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85617, 'Castiglione delle Stiviere', 'Castiglione delle Stiviere', 'Castiglione delle Stiviere,カスティリオーネ・デッレ・スティヴィエーレ', 45.3902000, 10.4861900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85618, 'Castiglione della Pescaia', 'Castiglione della Pescaia', 'Castiglione della Pescaia', 42.7685400, 10.8774600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85619, 'Castiglione del Lago', 'Castiglione del Lago', 'Castiglione del Lago', 43.1245700, 12.0398200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85620, 'Castiglione dei Pepoli', 'Castiglione dei Pepoli', 'Castiglione de ''Pepoli,Castiglione de ''Pépoli,Castiglione dei Pepoli', 44.1428000, 11.1602800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85621, 'Castiglione del Genovesi', 'Castiglione del Genovesi', '', 40.7236700, 14.8479600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85622, 'Castiglione d''Adda', 'Castiglione d''Adda', 'Castiglione d''Adda,カスティリオーネ・ダッダ', 45.2170200, 9.6927900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85623, 'Castiglione', 'Castiglione', 'Castiglione,Castiglione Chiavarese,O Castiggion', 44.2753900, 9.5168700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85624, 'Castiglione a Casauria', 'Castiglione a Casauria', 'Castigghiuni a Casauria,Castiglione a Casauria,Castiglione a Casauria vald,Castilio Piscariae,Kastil''jone-a-Kazaurija,Kastil''one a Kazaurija,Kastil''one-a-Kazaurija,Kastilione a Kazauria,Kastilone a Kazaurija,Kastyl''joneh-a-Kazauryja,ka si di liao nei ya ka shao li ya,kaseutillioneakasaulia,kastlywny a kazawrya,kastylywnh akazawrya,Кастильоне а Казаурия,Кастильоне-а-Казаурия,Кастиљоне а Казаурија,Кастыльёнэ-а-Казаўрыя,Кастільйоне-а-Казаурія,Կաստիլիոնե ա Կազաուրիա,كاستليوني آ كازاوريا,کاستیلیونه آکازاوریا,カスティリオーネ・ア・カザウリア,卡斯蒂廖内亚卡绍里亚,카스틸리오네아카사우리아', 42.2360100, 13.8983200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85625, 'Castenedolo', 'Castenedolo', 'Castenedolo,kasutenedoro,カステネードロ', 45.4743000, 10.2913100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85626, 'Castenaso', 'Castenaso', 'Castenaso', 44.5139800, 11.4684200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85627, 'Castel Volturno', 'Castel Volturno', 'Castel Volturno', 41.0328800, 13.9435400, 'IT', '2015-08-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85628, 'Castel Vittorio', 'Castel Vittorio', 'Castel Vittorio,Castelvittorio', 43.9275200, 7.6747100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85629, 'Castel Viscardo', 'Castel Viscardo', '', 42.7535900, 12.0007200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85630, 'Castelvetro Piacentino', 'Castelvetro Piacentino', 'Castelvetro Piacentino', 45.1022300, 9.9904100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85631, 'Castelvetro di Modena', 'Castelvetro di Modena', 'Castelvetro,Castelvetro di Modena', 44.5042200, 10.9466600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85632, 'Castelvetere sul Calore', 'Castelvetere sul Calore', 'Castelvetere di Calore,Castelvetere sul Calore', 40.9298000, 14.9864000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85633, 'Castelvetere in Val Fortore', 'Castelvetere in Val Fortore', 'Castelvetere in Val Fortore', 41.4425700, 14.9411800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85634, 'Castelverrino', 'Castelverrino', 'Castelverrino', 41.7671300, 14.3975600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85635, 'Castelverde', 'Castelverde', 'Castelverde', 45.1875300, 9.9969300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85636, 'Castelvenere', 'Castelvenere', 'Castelvenere', 41.2344500, 14.5475000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85637, 'Castelvecchio Subequo', 'Castelvecchio Subequo', 'Castelvecchio Subequo,Castelvecchio in Subequo,Castelvécchio in Subéquo', 42.1288100, 13.7286800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85638, 'Castelvecchio Calvisio', 'Castelvecchio Calvisio', 'Castelvecchio Calvisio', 42.3113400, 13.6872000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85639, 'Casteltodino', 'Casteltodino', '', 42.6666700, 12.5000000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85640, 'Castelseprio', 'Castelseprio', 'Castelseprio', 45.7137200, 8.8616100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85641, 'Castelsardo', 'Castelsardo', 'Caltheddu,Casteddu Sardu,Castelsardo,Castrum Sardum,Kastel''sardo,Kastelsardo,ka si tai er sa er duo,kastl sardw,kasuterusarudo,Кастелсардо,Кастельсардо,کاستل ساردو,カステルサルド,卡斯泰尔萨尔多', 40.9125600, 8.7145300, 'IT', '2015-06-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85642, 'Castelsaraceno', 'Castelsaraceno', 'Castelsaraceno', 40.1621300, 15.9928100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85643, 'Castel San Vincenzo', 'Castel San Vincenzo', 'Castel San Vincenzo', 41.6554300, 14.0617800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85644, 'Castel Sant''Elia', 'Castel Sant''Elia', 'Castel Sant''Elia', 42.2511200, 12.3703200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85645, 'Castelsantangelo sul Nera', 'Castelsantangelo sul Nera', 'Castelsantangelo,Castelsantangelo sul Nera', 42.8937900, 13.1546200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85646, 'Castel Sant''Angelo', 'Castel Sant''Angelo', 'Castel Sant''Angelo,カステル・サンタンジェロ', 42.3937300, 13.0273800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85647, 'Castel San Pietro Terme', 'Castel San Pietro Terme', 'Castel San Pietro Terme,Castel San Pietro dell''Emilia', 44.3985400, 11.5854600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85648, 'Castel San Pietro Romano', 'Castel San Pietro Romano', 'Castel San Pietro Romano,カステル・サン・ピエトロ・ロマーノ', 41.8457200, 12.8948900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85649, 'Castel San Niccolò', 'Castel San Niccolo', 'Castel San Niccolo,Castel San Niccolò,Castrum Sancti Nicolai,Kastehl''-San-Nikola,Kastel San Nikolo,Kastel''-San-Nikkolo,ka si tai er sheng ni ke er ao,Кастел Сан Николо,Кастель-Сан-Никколо,Кастель-Сан-Нікколо,Кастэль-Сан-Нікола,Կաստել Սան Նիքոլո,カステル・サン・ニッコロ,卡斯泰尔圣尼科尔奥', 43.7444500, 11.7091300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85650, 'Castel San Lorenzo', 'Castel San Lorenzo', 'Castel San Lorenzo', 40.4197900, 15.2252300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85651, 'Castel San Giovanni', 'Castel San Giovanni', 'Castel San Giovanni', 45.0601400, 9.4378400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85652, 'Castel San Giorgio', 'Castel San Giorgio', 'Castel San Giorgio', 40.7819800, 14.7009000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85653, 'Castelrotto', 'Castelrotto', 'Castelrotto,Castrum Ruptum,Kastelruth,kasuterurotto,カステルロット', 46.5666200, 11.5609800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85654, 'Castel Ritaldi', 'Castel Ritaldi', 'Castel Ritaldi,Castel Ritaldi e San Giovanni', 42.8224700, 12.6742000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85655, 'Castelraimondo', 'Castelraimondo', 'Castelraimondo', 43.2085300, 13.0548600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85656, 'Castelpoto', 'Castelpoto', 'Castelpoto', 41.1406600, 14.7006900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85657, 'Castelplanio', 'Castelplanio', 'Castelplanio,kasuterupuranio,カステルプラーニオ', 43.4942000, 13.0818000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85658, 'Castelpizzuto', 'Castelpizzuto', 'Castelpizzuto', 41.5212800, 14.2920500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85659, 'Castelpetroso', 'Castelpetroso', 'Castelpetroso', 41.5602700, 14.3463700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85660, 'Castelpagano', 'Castelpagano', 'Castelpagano', 41.4017700, 14.8071100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85661, 'Castelnuovo Scrivia', 'Castelnuovo Scrivia', 'Castelnuovo Scrivia', 44.9793200, 8.8824600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85662, 'Castelnuovo Rangone', 'Castelnuovo Rangone', 'Castelnuovo Rangone', 44.5493500, 10.9335000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85663, 'Castelnuovo Parano', 'Castelnuovo Parano', 'Castelnuovo Parano', 41.3791200, 13.7562100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85664, 'Castelnuovo Nigra', 'Castelnuovo Nigra', 'Castelneuv Nigra,Castelnuovo Nigra,カステルヌオーヴォ・ニグラ', 45.4381600, 7.6946100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85665, 'Castelnuovo Don Bosco', 'Castelnuovo Don Bosco', 'Castelneuv Don Bosch,Castelneuv Don Bòsch,Castelnuova,Castelnuovo Don Bosco,Castelnuovo d''Asti,Castrum Novum Astensium,Kastehl''nuova-Don-Boska,Kastel''nuovo-Don-Bosko,Kastelnuovo Don Bosko,bao si gao xin bao,kastlnwfw dwn bwskw,Кастелнуово Дон Боско,Кастельнуово-Дон-Боско,Кастэльнуова-Дон-Боска,Կաստելնուովո Դոն Բոսկո,كاستلنوفو دون بوسكو,カステルヌオーヴォ・ドン・ボスコ,鮑思高新堡', 45.0407700, 7.9638900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85666, 'Castelnuovo di Val di Cecina', 'Castelnuovo di Val di Cecina', 'Castelnuovo Val di Cecina,Castelnuovo di Val di Cecina', 43.2114800, 10.9041300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85667, 'Castelnuovo di Porto', 'Castelnuovo di Porto', 'Castelnuovo di Porto,カステルヌオーヴォ・ディ・ポルト', 42.1228000, 12.5104300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85668, 'Castelnuovo Magra', 'Castelnuovo Magra', 'Castarno,Castarnò,Castelnuovo Magra', 44.0995700, 10.0171500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85669, 'Castelnuovo di Garfagnana', 'Castelnuovo di Garfagnana', 'Castelnuovo di Garfagnana', 44.1126000, 10.4051800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85670, 'Castelnuovo di Farfa', 'Castelnuovo di Farfa', 'Castelnuovo di Farfa', 42.2319300, 12.7430800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85671, 'Castelnuovo di Conza', 'Castelnuovo di Conza', 'Castelnuovo di Conza', 40.8206200, 15.3187500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85672, 'Castelnuovo dei Sabbioni', 'Castelnuovo dei Sabbioni', 'Castelnuovo,Castelnuovo de''Sabbioni', 43.5409300, 11.4523400, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85673, 'Castelnuovo della Daunia', 'Castelnuovo della Daunia', 'Castelnuovo della Daunia', 41.5813900, 15.1179600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85674, 'Castelnuovo Cilento', 'Castelnuovo Cilento', 'Castelnuovo Cilento,Castiedde Nuove,Castièddë Nuòvë', 40.2184600, 15.1780200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85675, 'Castelnuovo Bormida', 'Castelnuovo Bormida', 'Castelnuovo Bormida', 44.7423600, 8.5506000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85676, 'Castelnuovo Bocca d''Adda', 'Castelnuovo Bocca d''Adda', 'Castelnuovo Bocca d''Adda,カステルヌオーヴォ・ボッカ・ダッダ', 45.1114700, 9.8635900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85677, 'Castelnuovo Berardenga', 'Castelnuovo Berardenga', 'Castelnuovo Berardenga,カステルヌオーヴォ・ベラルデンガ', 43.3454800, 11.5003900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85678, 'Castelnuovo', 'Castelnuovo', 'Castelnovo,Castelnuovo,kasuterunuovu~o,カステルヌオーヴォ', 46.0541200, 11.4891600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85679, 'Castelnuovo Calcea', 'Castelnuovo Calcea', 'Castelneuv Brusa,Castelneuv Brusà', 44.7868800, 8.2842100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85680, 'Castelnovo ne''Monti', 'Castelnovo ne''Monti', 'Castelnovo ne Monti,Castelnovo ne'' Monti,Castelnovo ne''Monti,Castelnovo né Monti,Castelnuovo ne'' Monti', 44.4355600, 10.4032900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85681, 'Castelnovo di Sotto', 'Castelnovo di Sotto', 'Castelnovo di Sotto,Castelnuovo di sotto', 44.8125300, 10.5669400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85682, 'Castelnovetto', 'Castelnovetto', 'Castelnovetto', 45.2543800, 8.6114200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85683, 'Castelmezzano', 'Castelmezzano', '', 40.5283200, 16.0458500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85684, 'Castel Mella', 'Castel Mella', 'Castel Mella,カステル・メッラ', 45.4991300, 10.1455300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85685, 'Castelmauro', 'Castelmauro', 'Castelmauro', 41.8284600, 14.7106600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85686, 'Castelmassa', 'Castelmassa', 'Castelmassa', 45.0182600, 11.3150500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85687, 'Campomolino', 'Campomolino', 'Castelmagno', 44.4088300, 7.2119200, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85688, 'Castel Maggiore', 'Castel Maggiore', 'Castel Maggiore,Kastel Madzhore,Кастел Маджоре', 44.5770700, 11.3607100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85689, 'Castel Madama', 'Castel Madama', 'Castel Madama,カステル・マダーマ', 41.9735000, 12.8678200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85690, 'Castelluccio Valmaggiore', 'Castelluccio Valmaggiore', 'Castelluccio,Castelluccio Valmaggiore', 41.3429000, 15.1994400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85691, 'Castelluccio Superiore', 'Castelluccio Superiore', 'Castelluccio Superiore', 40.0100300, 15.9718400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85692, 'Castellucchio', 'Castellucchio', 'Castellucchio', 45.1503800, 10.6487500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85693, 'Castello Tesino', 'Castello Tesino', 'Castello Tesino,カステッロ・テジーノ', 46.0630200, 11.6324700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85694, 'Castello di Godego', 'Castello di Godego', 'Castello di Godego', 45.6927000, 11.8799800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85695, 'Castello Molina di Fiemme', 'Castello Molina di Fiemme', 'Castello,Castello di Fiemmo', 46.2824100, 11.4334800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85696, 'Castello di Annone', 'Castello di Annone', 'Castel d''Anon,Castello Annone,Castello d''Annone,Castello di Annone', 44.8794400, 8.3170100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85697, 'Castello dell''Acqua', 'Castello dell''Acqua', 'Castello dell''Acqua', 46.1454900, 10.0158200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85698, 'Aviano-Castello', 'Aviano-Castello', 'Aviano-Castello,Castello,Castello d''Aviano', 46.0675900, 12.5832400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85699, 'Castello d''Argile', 'Castello d''Argile', 'Castel d''Argile,Castello d''Argile', 44.6779700, 11.2971500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85700, 'Castello', 'Castello', '', 45.5695400, 10.5086100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85701, 'Castelliri', 'Castelliri', 'Castelliri', 41.6776400, 13.5397800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85702, 'Castellino del Biferno', 'Castellino del Biferno', 'Castellino del Biferno', 41.7016000, 14.7317900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85703, 'Castellina Marittima', 'Castellina Marittima', 'Castellina Marittima', 43.4130100, 10.5759400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85704, 'Castellina in Chianti', 'Castellina in Chianti', 'Castellina in Chianti,カステッリーナ・イン・キアンティ', 43.4643800, 11.2895000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85705, 'Castelli Calepio', 'Castelli Calepio', 'Calepio,Castelli Calepio', 45.6131600, 9.8854000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85706, 'Castelli', 'Castelli', 'Casteddi,Castella,Castelli,Kasteli,Kastelli,ka si tai li,kaseutelli,kastly,kastyly,kasuterri,Кастели,Кастелли,Кастеллі,Կաստելի,كاستيلي,کاستلی,カステッリ,卡斯泰利,카스텔리', 42.4847600, 13.7120100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85707, 'Castelletto Uzzone', 'Castelletto Uzzone', 'Castelletto Uzzone,Castelletto Uzzone Soprano,Castelletto Uzzone Sottano', 44.4952700, 8.1877200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85708, 'Castelletto Sopra Ticino', 'Castelletto Sopra Ticino', 'Castelletto,Castelletto Ticino,Castelletto sopra Ticino', 45.7200200, 8.6336200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85709, 'Castelleone', 'Castelleone', 'Castelleone', 45.2957900, 9.7609100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85710, 'Castellazzo Novarese', 'Castellazzo Novarese', 'Castellazzo Novarese', 45.5133700, 8.4869300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85711, 'Castellazzo Bormida', 'Castellazzo Bormida', 'Castellazzo Bormida,El Castlass,Ël Castlass', 44.8435300, 8.5790000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85712, 'Castell''Azzara', 'Castell''Azzara', 'Castell''Azzara,Castell''Azzaru', 42.7727500, 11.6979400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85713, 'Castell''Arquato', 'Castell''Arquato', 'Castell''Arquato', 44.8545100, 9.8732600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85714, 'Castellaro', 'Castellaro', 'Castellaro,O Castella,O Castellâ', 43.8643600, 7.8688100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85715, 'Castellar Guidobono', 'Castellar Guidobono', 'Castellar,Castellar Guidobono', 44.9048300, 8.9483500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85716, 'Castellarano', 'Castellarano', 'Castellarano', 44.5182500, 10.7372700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85717, 'Castellanza', 'Castellanza', 'Castellanza', 45.6107900, 8.8961600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85718, 'Castellaneta', 'Castellaneta', 'Castellaneta', 40.6279400, 16.9329000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85719, 'Castellana', 'Castellana', 'Castellana Grotte,カステッラーナ・グロッテ', 40.8864300, 17.1654900, 'IT', '2015-06-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85720, 'Castellamonte', 'Castellamonte', 'Castellamonte,Castlamont,kasuterramonte,カステッラモンテ', 45.3826700, 7.7088600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85721, 'Castellammare di Stabia', 'Castellammare di Stabia', 'Castellammare,Castellammare di Stabia,Estabia,Estàbia,Kastelamare di Stabija,Stabiae,Stabie,Кастеламаре ди Стабија', 40.7021100, 14.4868500, 'IT', '2015-06-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85722, 'Castellalto', 'Castellalto', 'Castellalto', 42.6770500, 13.8210100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85723, 'Castell''Alfero', 'Castell''Alfero', 'Castel Alfe,Castel Alfè,Castell''Alfero', 44.9850500, 8.2230900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85724, 'Castellafiume', 'Castellafiume', 'Castellafiume', 41.9891300, 13.3344000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85725, 'Castelguidone', 'Castelguidone', 'Castelguidone', 41.8225800, 14.5228600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85726, 'Castelguglielmo', 'Castelguglielmo', 'Castelguglielmo', 45.0253900, 11.5369000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85727, 'Castel Guelfo di Bologna', 'Castel Guelfo di Bologna', 'Castel Guelfo,Castel Guelfo di Bologna', 44.4316600, 11.6759100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85728, 'Castelgrande', 'Castelgrande', 'Castelgrande', 40.7863900, 15.4310900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85729, 'Castelgomberto', 'Castelgomberto', 'Castelgomberto', 45.5826700, 11.3900700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85730, 'Castel Goffredo', 'Castel Goffredo', 'Castel Goffredo', 45.2940300, 10.4730000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85731, 'Castel Giorgio', 'Castel Giorgio', 'Castel Giorgio', 42.7069700, 11.9771700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85732, 'Castel Gandolfo', 'Castel Gandolfo', '', 41.7487500, 12.6497500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85733, 'Castel Gabbiano', 'Castel Gabbiano', 'Castel Gabbiano', 45.4684700, 9.7176500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85734, 'Castel Frentano', 'Castel Frentano', '', 42.1987500, 14.3564300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85735, 'Castelfranco Veneto', 'Castelfranco Veneto', 'Castelfranco Veneto', 45.6714600, 11.9275500, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85736, 'Castelfranco in Miscano', 'Castelfranco in Miscano', 'Castelfranco in Miscano', 41.3007200, 15.0860700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85737, 'Castelfranco Emilia', 'Castelfranco Emilia', 'Castelfranco Emilia,Castelfranco d''Emilia,Castelfranco dell''Emilia', 44.5944500, 11.0497900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85738, 'Castelfranco di Sotto', 'Castelfranco di Sotto', 'Castelfranco,Castelfranco di Sotto', 43.7036800, 10.7463000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85739, 'Castelfranco di Sopra', 'Castelfranco di Sopra', 'Castelfranco,Castelfranco de Sora,Castelfranco di Sopra,Castelfrancu di Supra,Castrum Francum Superius,Kastehl''franka-dzi-Sopra,Kastel''franko-di-Sopra,Kastelfranko di Sopra,ka si tai er fu lan ke di suo pu la,Кастелфранко ди Сопра,Кастельфранко-ди-Сопра,Кастельфранко-ді-Сопра,Кастэльфранка-дзі-Сопра,Կաստելֆրանկո դի Սոպրա,カステルフランコ・ディ・ソプラ,卡斯泰尔夫兰科迪索普拉', 43.6215600, 11.5588500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85740, 'Castelfranci', 'Castelfranci', 'Castelfranci,Castrum de Francis,Kastel''franchi,Kastelfranchi,Kastelfranki,ka si tai er fu lan qi,kaseutelpeulanchi,kasuterufuranchi,Кастелфранки,Кастелфранчи,Кастельфранчи,Кастельфранчі,Կաստելֆրանչի,カステルフランチ,卡斯泰尔夫兰奇,카스텔프란치', 40.9306600, 15.0433100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85741, 'Castelforte', 'Castelforte', 'Castelforte,Castelforti,Castrum Forte,Kastel''forte,Kastelforte,ka si tai er fu er tai,kaseutelpoleute,kasuteruforute,Кастелфорте,Кастельфорте,Կաստելֆորտե,カステルフォルテ,卡斯泰尔福尔泰,카스텔포르테', 41.2939200, 13.8306100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85742, 'Castelfondo', 'Castelfondo', 'Castelfondo,kasuterufondo,カステルフォンド', 46.4562300, 11.1178500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85743, 'Castelfiorentino', 'Castelfiorentino', 'Castelfiorentino', 43.6096300, 10.9677200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85744, 'Castelfidardo', 'Castelfidardo', '', 43.4591600, 13.5504400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85745, 'Castel di Tora', 'Castel di Tora', 'Castel di Tora', 42.2139200, 12.9707300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85746, 'Castel di Sangro', 'Castel di Sangro', 'Castel di Sangro', 41.7839200, 14.1065300, 'IT', '2015-06-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85747, 'Castel di Ieri', 'Castel di Ieri', 'Castel di Ieri', 42.1135300, 13.7420000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85748, 'Casteldidone', 'Casteldidone', 'Casteldidone', 45.0706800, 10.4058100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85749, 'Castel di Casio', 'Castel di Casio', 'Castel d Chesi,Castel di Casio,Castèl d Chèsi', 44.1627600, 11.0350500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85750, 'Castel del Rio', 'Castel del Rio', '', 44.2134600, 11.5040900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85751, 'Castel del Piano', 'Castel del Piano', 'Castel del Piano', 42.8922800, 11.5390300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85752, 'Castel del Monte', 'Castel del Monte', '', 42.3654400, 13.7259200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85753, 'Castel del Giudice', 'Castel del Giudice', 'Castel del Giudice,Castel du Giudici,Castel dû Giudici,Castellum Iudicis,Kastehl''-dehl''-Dzhudzicheh,Kastel del Dzhudiche,Kastel''-del''-Dzhudiche,ka si tai er de er zhu di qie,kaseuteldeljudiche,Кастел дел Ђудиче,Кастел дел Джудиче,Кастель-дель-Джудиче,Кастель-дель-Джудіче,Кастэль-дэль-Джудзічэ,Կաստել դել Ջուդիչե,カステル・デル・ジューディチェ,卡斯泰尔德尔朱迪切,카스텔델주디체', 41.8548800, 14.2315500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85754, 'Casteldelfino', 'Casteldelfino', 'Casteldelfino,Chateaudauphin,Châteaudauphin', 44.5900200, 7.0702600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85755, 'Castel d''Ario', 'Castel d''Ario', 'Castel d''Ario', 45.1879800, 10.9744900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85756, 'Castel d''Aiano', 'Castel d''Aiano', 'Castel d''Aiano', 44.2775100, 11.0009700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85757, 'Castelcucco', 'Castelcucco', 'Castelcucco', 45.8302400, 11.8829600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85758, 'Castel Condino', 'Castel Condino', 'Castel Condino,Castello,Castello Condino,カステル・コンディーノ', 45.9143900, 10.6027700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85759, 'Castelcivita', 'Castelcivita', 'Castelcivita', 40.4936700, 15.2335400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85760, 'Castel Chiodato', 'Castel Chiodato', '', 42.0561700, 12.6976400, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85761, 'Castel Campagnano', 'Castel Campagnano', 'Castel Campagnano,Castel Campagnanu,Castrum Campanianum,Kastehl''-Kampan''ano,Kastel Kampanano,Kastel Kampanjano,Kastel Kampanyano,Kastel''-Kampan''jano,ka si tai er kan pa ni ya nuo,kaseutelkampanyano,Кастел Кампаняно,Кастел Кампањано,Кастель-Кампаньяно,Кастэль-Кампаньано,Կաստել Կամպանյանո,カステル・カンパニャーノ,卡斯泰尔坎帕尼亚诺,카스텔캄파냐노', 41.1824000, 14.4530000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85762, 'Castelbottaccio', 'Castelbottaccio', 'Castelbottaccio', 41.7532900, 14.7061600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85763, 'Castel Bolognese', 'Castel Bolognese', 'Castel Bolognese,カステル・ボロニェーゼ', 44.3198100, 11.7990300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85764, 'Castelbello-Ciardes - Kastelbell-Tschars', 'Castelbello-Ciardes - Kastelbell-Tschars', '', 46.6283200, 10.9066600, 'IT', '2012-02-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85765, 'Castelbellino', 'Castelbellino', 'Castelbellino,kasuteruberrino,カステルベッリーノ', 43.4867600, 13.1446700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85766, 'Castel Baronia', 'Castel Baronia', 'Castel Baronia', 41.0483200, 15.1888400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85767, 'Castelbaldo', 'Castelbaldo', 'Castelbaldo', 45.1222600, 11.4551700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85768, 'Castegnato', 'Castegnato', 'Castegnato,kasutenyato,カステニャート', 45.5612900, 10.1144900, 'IT', '2015-01-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85769, 'Casteggio', 'Casteggio', '', 45.0139600, 9.1252800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85770, 'Castano Primo', 'Castano Primo', 'Castano,Castano Primo,カスターノ・プリーモ', 45.5517500, 8.7756200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85771, 'Castagnole Monferrato', 'Castagnole Monferrato', 'Castagnole Monferrato', 44.9586400, 8.3050700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85772, 'Castagnole delle Lanze', 'Castagnole delle Lanze', 'Castagnole', 44.7498800, 8.1496600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85773, 'Castagnole', 'Castagnole', '', 45.6885200, 12.1826000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85774, 'Castagnito', 'Castagnito', 'Castagnito', 44.7547200, 8.0319500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85775, 'Castagneto Po', 'Castagneto Po', 'Castagne,Castagneto Po,Castagné,カスタニェート・ポー', 45.1585400, 7.8863900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85776, 'Castagneto Carducci', 'Castagneto Carducci', 'Castagneto,Castagneto Carducci,カスタニェート・カルドゥッチ', 43.1607300, 10.6109200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85777, 'Castagnaro', 'Castagnaro', 'Castagnaro', 45.1179500, 11.4091100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85778, 'Cassolnovo', 'Cassolnovo', 'Cassolnovo', 45.3610600, 8.8123000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85779, 'Cassino', 'Cassino', 'Cassino,Kassino,kasshino,Кассино,カッシーノ', 41.4858100, 13.8283500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85780, 'Cassine', 'Cassine', 'Cassine', 44.7516600, 8.5287200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85781, 'Cassinasco', 'Cassinasco', 'Cassinasco', 44.6897700, 8.3034500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85782, 'Cassina de'' Pecchi', 'Cassina de'' Pecchi', 'Cassina de'' Pecchi,Cassina de''Pecchi,カッシーナ・デ・ペッキ', 45.5163700, 9.3597500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85783, 'Cassiglio', 'Cassiglio', 'Cassiglio', 45.9667900, 9.6121500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85784, 'Cassano Spinola', 'Cassano Spinola', 'Cassano,Cassano Spinola', 44.7655700, 8.8622800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85785, 'Cassano delle Murge', 'Cassano delle Murge', 'Cassano,Cassano delle Murge', 40.8911200, 16.7653100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85786, 'Cassano d''Adda', 'Cassano d''Adda', 'Cassano d''Adda,Kasano d''Ada,Касано д''Ада,カッサーノ・ダッダ', 45.5263700, 9.5152800, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85787, 'Cassacco', 'Cassacco', 'Cassacco,Cjassa', 46.1734500, 13.1923600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85788, 'Caspoggio', 'Caspoggio', 'Caspoggio', 46.2642400, 9.8616500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85789, 'Casperia', 'Casperia', 'Casperia', 42.3386900, 12.6701700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85790, 'Casorzo', 'Casorzo', 'Casorzo', 45.0216500, 8.3384300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85791, 'Casoria', 'Casoria', 'Casoria,kazoria,カゾーリア', 40.9075100, 14.2930000, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85792, 'Casorezzo', 'Casorezzo', 'Casorezzo,kazorettsu~o,カゾレッツォ', 45.5226500, 8.9018600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85793, 'Casorate Sempione', 'Casorate Sempione', 'Casorate Sempione', 45.6707900, 8.7451300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85794, 'Casorate Primo', 'Casorate Primo', 'Casorate Primo,Casoratum,Casuraa,Kazorate Primo,Kazorate-Primo,ka suo la tai pu li mo,kaswrat brymw,Казорате Примо,Казорате-Примо,Կազորատե Պրիմո,كاسورات بريمو,カゾラーテ・プリーモ,卡索拉泰普里莫', 45.3114200, 9.0170300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85795, 'Casoni', 'Casoni', '', 45.7594300, 11.8104500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85796, 'Casoli', 'Casoli', '', 42.6172300, 13.9791000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85797, 'Casoli', 'Casoli', 'Casoli', 42.1138000, 14.2899500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85798, 'Casole d''Elsa', 'Casole d''Elsa', 'Casole d''Elsa,カーゾレ・デルザ', 43.3411500, 11.0479400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85799, 'Casola Valsenio', 'Casola Valsenio', 'Casola Valsenio,カゾーラ・ヴァルセーニオ', 44.2244300, 11.6248700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85800, 'Casola in Lunigiana', 'Casola in Lunigiana', 'Casola in Lunigiana,カーゾラ・イン・ルニジャーナ', 44.2004500, 10.1767900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85801, 'Casola di Napoli', 'Casola di Napoli', 'Casola ''e Napule,Casola di Napoli,カーゾラ・ディ・ナーポリ', 40.6978000, 14.5300600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85802, 'Casnigo', 'Casnigo', 'Casnigo', 45.8130700, 9.8687800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85803, 'Casarile', 'Casarile', 'Casarile,kazarire,カザリーレ', 45.3168300, 9.1038300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85804, 'Casirate d''Adda', 'Casirate d''Adda', 'Casirate d''Adda', 45.4953500, 9.5693200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85805, 'Casine', 'Casine', '', 43.6316500, 13.1442500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85806, 'Casina', 'Casina', 'Casina,Casma', 44.5098200, 10.4995100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85807, 'Caserta', 'Caserta', 'CTJ,Caserta,Caserte,Kazerta,kazeruta,Казерта,カゼルタ', 41.0726200, 14.3323100, 'IT', '2015-08-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85808, 'Pieve al Toppo', 'Pieve al Toppo', '', 43.4076100, 11.7968600, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85809, 'Caselle Torinese', 'Caselle Torinese', 'Caseli,Caselle,Caselle Torinese,カゼッレ・トリネーゼ', 45.1745800, 7.6429000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85810, 'Caselle Lurani', 'Caselle Lurani', 'Caselle Lurani,カゼッレ・ルラーニ', 45.2804400, 9.3601600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85811, 'Caselle in Pittari', 'Caselle in Pittari', 'Caselle in Pittari', 40.1731900, 15.5431100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85812, 'Caselle', 'Caselle', '', 45.7496500, 11.9800400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85813, 'Casella', 'Casella', 'Casella', 44.5352300, 9.0008000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85814, 'Caselette', 'Caselette', 'Caselette,Casellette,Caslette,Caslëtte,kazerette,カゼレッテ', 45.1097500, 7.4858200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85815, 'Casei', 'Casei', 'Casei Gerola', 45.0075600, 8.9267500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85816, 'Cascinette d''Ivrea', 'Cascinette d''Ivrea', '', 45.4801600, 7.9056200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85817, 'Cascina', 'Cascina', 'Cascina', 43.6755700, 10.5549400, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85818, 'Casciana Terme', 'Casciana Terme', 'Bagni di Casciana,Casciana Terme,Casciana Termi,Castrum ad Aquas,Kasana Terme,Kashana Terme,Kashana-Terme,Kashiana-Terme,Kashyjana-Tehrmeh,ka xia na tai er mei,Кашана Терме,Кашана-Терме,Кашиана-Терме,Кашыяна-Тэрмэ,Кашіана-Терме,Կաշանա Տերմե,カシャーナ・テルメ,卡夏纳泰尔梅', 43.5266800, 10.6181200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85819, 'Cascia', 'Cascia', 'Cascia,Cassia,Castrum Cassiae,Cássia,Kasa,Kasha,Kashija,ka xia,kasha,kashia,kasia,Каша,Кашія,Կաշա,كاشا,カーシア,卡夏,카시아', 42.7179000, 13.0169700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85820, 'Cascano', 'Cascano', '', 41.2323200, 13.9692700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85821, 'Casazza', 'Casazza', 'Casazza,Cassazza', 45.7485500, 9.9062700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85822, 'Casatisma', 'Casatisma', 'Casatisma', 45.0456900, 9.1309900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85823, 'Casatenovo', 'Casatenovo', 'Casatenaovo,Casatenovo,Casatenuovo', 45.6951400, 9.3133800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85824, 'Casasco', 'Casasco', 'Casasco', 44.8273400, 9.0056500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85825, 'Casarsa della Delizia', 'Casarsa della Delizia', 'Casarsa,Casarsa della Delizia,Cjasarse', 45.9509100, 12.8425000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85826, 'Casargo', 'Casargo', 'Casargo', 46.0395000, 9.3871700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85827, 'Casapulla', 'Casapulla', 'Casapulla', 41.0766500, 14.2892700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85828, 'Casaprota', 'Casaprota', 'Casaprota', 42.2517700, 12.8042800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85829, 'Casape', 'Casape', 'Casape,kazape,カザーペ', 41.9070200, 12.8857900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85830, 'Casanova Elvo', 'Casanova Elvo', 'Casanova Elvo', 45.4002000, 8.2941300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85831, 'Casanova', 'Casanova', '', 41.1925400, 13.9634400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85832, 'Casandrino', 'Casandrino', 'Casandrino,kazandorino,カザンドリーノ', 40.9284500, 14.2474400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85833, 'Semonte-Casamorcia', 'Semonte-Casamorcia', '', 43.3682600, 12.5306400, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85834, 'Casamassima', 'Casamassima', 'Casamassima,Cassamassima', 40.9565300, 16.9207500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85835, 'Casamassella', 'Casamassella', '', 40.1142400, 18.4510000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85836, 'Casamarciano', 'Casamarciano', 'Casamarciano,kazamaruchano,カザマルチャーノ', 40.9319100, 14.5532400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85837, 'Casalzuigno', 'Casalzuigno', 'Casalzuigno', 45.9050800, 8.7088300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85838, 'Casalvolone', 'Casalvolone', 'Casalvolone', 45.3996600, 8.4647200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85839, 'Casalvieri', 'Casalvieri', 'Casalvieri', 41.6332900, 13.7136300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85840, 'Casal Velino', 'Casal Velino', 'Casal Velino', 40.1903400, 15.1113700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85841, 'Casalvecchio di Puglia', 'Casalvecchio di Puglia', 'Casalvecchio di Puglia', 41.5947000, 15.1099900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85842, 'Casaluce', 'Casaluce', 'Casaluce,Fertilia', 40.9978500, 14.1967100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85843, 'Casalserugo', 'Casalserugo', 'Casalis Domini Hugonis,Casalserugo,Kazal''serugo,Kazalserugo,ka sa er sai lu ge,kazaruserugo,Казалсеруго,Казальсеруго,Կազալսերուգո,カザルセルーゴ,卡萨尔塞鲁戈', 45.3154900, 11.9123200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85844, 'Casalromano', 'Casalromano', 'Casalromano', 45.1980800, 10.3664000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85845, 'Casalpusterlengo', 'Casalpusterlengo', 'Casalis Pistorum,Casalpusterlengo', 45.1792100, 9.6483400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85846, 'Casaloldo', 'Casaloldo', 'Casaloldo,Casaloldo il Palazzio', 45.2543600, 10.4769100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85847, 'Casalnuovo Monterotaro', 'Casalnuovo Monterotaro', 'Casalnuovo Monterotaro', 41.6194200, 15.1041100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85848, 'Casalnuovo di Napoli', 'Casalnuovo di Napoli', 'Casalnuovo,Casalnuovo di Napoli,カザルヌオーヴォ・ディ・ナポーリ', 40.9096900, 14.3420500, 'IT', '2015-08-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85849, 'Casalnoceto', 'Casalnoceto', 'Casalnoceto', 44.9132600, 8.9837600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85850, 'Casalmoro', 'Casalmoro', 'Casalmoro', 45.2611500, 10.4111800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85851, 'Casalmorano', 'Casalmorano', 'Casale Maurani,Casalmorano,Casalmorano vald,Casalmuran,Kazal''morano,Kazalmorano,ka sa er mo la nuo,kazarumorano,Казалморано,Казальморано,Կազալմորանո,カザルモラーノ,卡萨尔莫拉诺', 45.2876600, 9.8986000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85852, 'Casalmaiocco', 'Casalmaiocco', '', 45.3523800, 9.3708800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85853, 'Casalmaggiore', 'Casalmaggiore', 'Casalis Maior,Casalmaggiore,kazarumajjore,カザルマッジョーレ', 44.9898100, 10.4205500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85854, 'Casalino', 'Casalino', 'Casalino', 45.3583600, 8.5239300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85855, 'Casalincontrada', 'Casalincontrada', 'Casalincontrada', 42.2974400, 14.1351100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85856, 'Casali', 'Casali', 'Annunziata,Casali', 41.3781200, 13.7547900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85857, 'Casalgrasso', 'Casalgrasso', 'Casalgrass,Casalgrasso', 44.8183400, 7.6249800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85858, 'Casalgrande', 'Casalgrande', 'Casalgrande', 44.5846600, 10.7355000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85859, 'Casalfiumanese', 'Casalfiumanese', 'Casale Fiumanese', 44.2968600, 11.6240200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85860, 'Casaletto Spartano', 'Casaletto Spartano', 'Casaletto,Casaletto Spartano', 40.1513400, 15.6205800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85861, 'Casaletto Ceredano', 'Casaletto Ceredano', 'Casaletto Ceredano', 45.3183100, 9.6170100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85862, 'Casale sul Sile', 'Casale sul Sile', 'Casale sul Sile', 45.5963800, 12.3265500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85863, 'Casaleone', 'Casaleone', 'Casaleone', 45.1682100, 11.1940100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85864, 'Casale Monferrato', 'Casale Monferrato', 'Casal,Casale,Casale Monferrato', 45.1333800, 8.4525000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85865, 'Casale Marittimo', 'Casale Marittimo', 'Casale Marittimo', 43.2972700, 10.6165800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85866, 'Casaleggio Novara', 'Casaleggio Novara', 'Casaleggio Novara', 45.4879300, 8.4930700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85867, 'Casale di Scodosia', 'Casale di Scodosia', 'Casale di Scodosia', 45.1922500, 11.4744200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85868, 'Casale Corte Cerro', 'Casale Corte Cerro', 'Casale Corte Cerro', 45.9154500, 8.4140700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85869, 'Casalecchio di Reno', 'Casalecchio di Reno', 'Casalacc'',Casalecchio di Reno,Casalàcc’', 44.4756300, 11.2749500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85870, 'Casalduni', 'Casalduni', 'Casalduni', 41.2608000, 14.6953200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85871, 'Casal di Principe', 'Casal di Principe', 'Casal di Principe', 41.0099600, 14.1301300, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85872, 'Casalciprano', 'Casalciprano', 'Casalciprano', 41.5803700, 14.5283500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85873, 'Casalbuttano', 'Casalbuttano', 'Casalbuttano ed Uniti', 45.2518700, 9.9616700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85874, 'Casalbuono', 'Casalbuono', 'Casalbuono', 40.2142500, 15.6871700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85875, 'Casalborgone', 'Casalborgone', 'Casalborgon,Casalborgone,kazaruborugone,カザルボルゴーネ', 45.1304500, 7.9404300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85876, 'Casalbore', 'Casalbore', 'Casalbore', 41.2337300, 15.0075200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85877, 'Casalbordino-Miracoli', 'Casalbordino-Miracoli', 'Casalbordino', 42.1535400, 14.5991200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85878, 'Casalattico', 'Casalattico', 'Casalattico', 41.6221300, 13.7256300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85879, 'Casalanguida', 'Casalanguida', 'Casalanguida', 42.0375200, 14.4961300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85880, 'Casacanditella', 'Casacanditella', 'Casacanditella', 42.2464300, 14.2004000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85881, 'Casacalenda', 'Casacalenda', 'Casacalenda', 41.7382400, 14.8473400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85882, 'Carzago Riviera', 'Carzago Riviera', '', 45.5244000, 10.4605200, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85883, 'Carvico', 'Carvico', 'Carvico', 45.7019300, 9.4858000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85884, 'Carunchio', 'Carunchio', 'Carunchio', 41.9176100, 14.5268300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85885, 'Carugate', 'Carugate', 'Carugate,karugate,カルガーテ', 45.5498300, 9.3404400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85886, 'Cartignano', 'Cartignano', 'Cartignano', 44.4783300, 7.2857300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85887, 'Carsoli', 'Carsoli', 'Carsoli', 42.0988200, 13.0885600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85888, 'Carrù', 'Carru', 'Carru,Carrù,Caru,Carù', 44.4796700, 7.8723600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85889, 'Carrosio', 'Carrosio', 'Carrosio', 44.6577600, 8.8312600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85890, 'Carro', 'Carro', 'Carro,Carrum,Kara,Karo,Karro,O Caero,O Cäro,ka luo,karro,Кара,Каро,Карро,Կարո,カッロ,卡罗', 44.2721500, 9.6088800, 'IT', '2015-11-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85891, 'Carrara', 'Carrara', 'Apuania,Carara,Carrara,Carrare,Karrara,karrara,Каррара,カッラーラ', 44.0792600, 10.0978900, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85892, 'Carpinone', 'Carpinone', 'Carpinone', 41.5900300, 14.3243600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85893, 'Carpino', 'Carpino', 'Carpino', 41.8445000, 15.8571200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85894, 'Carpineto Sinello', 'Carpineto Sinello', 'Carpineto Sinello', 42.0104400, 14.5041800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85895, 'Carpineto Romano', 'Carpineto Romano', 'Carpineto Romano,カルピネート・ロマーノ', 41.6047000, 13.0841000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85896, 'Carpineto della Nora', 'Carpineto della Nora', 'Carpineto della Nora', 42.3336500, 13.8606200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85897, 'Carpineti', 'Carpineti', 'Carpineti', 44.4557400, 10.5178000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85898, 'Carpignano Sesia', 'Carpignano Sesia', 'Carpignano,Carpignano Sesia', 45.5334100, 8.4173400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85899, 'Carpignano Salentino', 'Carpignano Salentino', 'Carpignano Salentino', 40.1953700, 18.3382600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85900, 'Carpiano', 'Carpiano', 'Carpiano,karupiano,カルピアーノ', 45.3402700, 9.2740100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85901, 'Carpi Centro', 'Carpi Centro', 'Carpi,Cherp,Chèrp,Karpi,karupi,Карпи,カルピ', 44.7823700, 10.8777000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85902, 'Carpesica', 'Carpesica', '', 45.9533500, 12.2912600, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85903, 'Carpenedolo', 'Carpenedolo', 'Carpenedolo,karupenedoro,カルペネードロ', 45.3616900, 10.4312400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85904, 'Carpegna', 'Carpegna', 'Carpegna', 43.7811000, 12.3354300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85905, 'Carpasio', 'Carpasio', 'Carpasio,Carpaxe', 43.9602400, 7.8663100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85906, 'Carpaneto Piacentino', 'Carpaneto Piacentino', 'Carpaneto,Carpaneto Piacentino', 44.9135500, 9.7870300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85907, 'Carovilli', 'Carovilli', 'Carovilli', 41.7134800, 14.2940300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85908, 'Carovigno', 'Carovigno', 'Carovigno,Carvignu,karovu~inyo,カロヴィーニョ', 40.7062600, 17.6584700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85909, 'Carosino', 'Carosino', 'Carosino', 40.4653800, 17.3985700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85910, 'Carona', 'Carona', 'Carona,Caruna,Karona,ka luo na,karona,Карона,Կարոնա,カローナ,卡罗纳', 46.0214900, 9.7849400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85911, 'Carnate', 'Carnate', 'Carnaa,Carnate,karunate,カルナーテ', 45.6484300, 9.3781300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85912, 'Carnago', 'Carnago', 'Carnago', 45.7220700, 8.8342300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85913, 'Carmignano di Brenta', 'Carmignano di Brenta', 'Carmignano di Brenta', 45.6257800, 11.7059900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85914, 'Carmignano', 'Carmignano', 'Carmignano,karuminyano,カルミニャーノ', 43.8102700, 11.0149400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85915, 'Carmiano', 'Carmiano', 'Carmiano,Carmianu', 40.3440400, 18.0419500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85916, 'Carmagnola', 'Carmagnola', 'Carmagnola,Carmagnole,Carmagnòla,Karman''ola,karumanyora,Карманьола,カルマニョーラ', 44.8496300, 7.7203200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85917, 'Carlino', 'Carlino', 'Carlino,Cjarlins', 45.8032100, 13.1887400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85918, 'Carlazzo', 'Carlazzo', 'Carlasc,Carlazium,Carlazzo,Karlacco,Karlaco,ka er la zuo,karurattsu~o,Карлацо,Карлаццо,Կարլացո,カルラッツォ,卡尔拉佐', 46.0422200, 9.1649800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85919, 'Carlantino', 'Carlantino', 'Carlandine,Carlandìnë,Carlantino', 41.5938800, 14.9768100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85920, 'Carisolo', 'Carisolo', 'Carisolo,karizoro,カリゾーロ', 46.1688000, 10.7588700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85921, 'Carisio', 'Carisio', 'Carisio', 45.4101700, 8.1996200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85922, 'Carinola', 'Carinola', 'Carinola', 41.1877500, 13.9824000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85923, 'Carimate', 'Carimate', 'Carimate', 45.7065900, 9.1075100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85924, 'Carignano', 'Carignano', 'Carignan,Carignano,karinyano,カリニャーノ', 44.9059900, 7.6725300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85925, 'Carife', 'Carife', 'Carife', 41.0266700, 15.2104400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85926, 'Cargeghe', 'Cargeghe', 'Cargeghe,Gargheghe', 40.6689400, 8.6152100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85927, 'Caresana', 'Caresana', 'Caresana', 45.2214200, 8.5048000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85928, 'Carenno', 'Carenno', 'Carenno', 45.8015500, 9.4630100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85929, 'Carema', 'Carema', '', 45.5840100, 7.8087900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85930, 'Corneno-Galliano-Carella Mariaga', 'Corneno-Galliano-Carella Mariaga', '', 45.8166700, 9.2666700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85931, 'Cardito', 'Cardito', 'Cardito,karudito,カルディート', 40.9459000, 14.2995200, 'IT', '2015-08-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85932, 'Cardano', 'Cardano', 'Kardaun', 46.4933600, 11.3929500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85933, 'Carcoforo', 'Carcoforo', 'Carcoforo', 45.9085800, 8.0496700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85934, 'Carceri', 'Carceri', 'Carceri', 45.1950800, 11.6211500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85935, 'Carcare', 'Carcare', 'Cancre,Carcare', 44.3546500, 8.2903900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85936, 'Carbonera', 'Carbonera', 'Carbonera', 45.6918200, 12.2825500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85937, 'Carbone', 'Carbone', 'Carbone', 40.1422700, 16.0884600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85938, 'Carbonara di Po', 'Carbonara di Po', 'Carbonara,Carbonara di Po', 45.0353700, 11.2292300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85939, 'Carbonara al Ticino', 'Carbonara al Ticino', 'Carbonara al Ticino', 45.1637400, 9.0649000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85940, 'Carbognano', 'Carbognano', 'Carbognano', 42.3302400, 12.2645700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85941, 'Caravonica', 'Caravonica', 'Caironega,Cairònega,Caravonica', 43.9930300, 7.9580500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85942, 'Caravino', 'Caravino', 'Caravin,Caravino,karavu~ino,カラヴィーノ', 45.3995000, 7.9602000, 'IT', '2015-05-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85943, 'Caravate', 'Caravate', 'Caravate', 45.8786200, 8.6543100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85944, 'Caravaggio', 'Caravaggio', 'Caravaggio,Careas,Careàs,Carraca,Karavago,Karavaĝo,karavu~ajjo,カラヴァッジョ', 45.4962700, 9.6416500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85945, 'Carate Brianza', 'Carate Brianza', 'Carate,Carate Brianza,カラーテ・ブリアンツァ', 45.6757400, 9.2372300, 'IT', '2015-07-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85946, 'Carassai', 'Carassai', 'Carassai', 43.0330300, 13.6876100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85947, 'Carasco', 'Carasco', 'Carasco', 44.3497500, 9.3456700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85948, 'Carapelle Calvisio', 'Carapelle Calvisio', 'Carapelle Calvisio', 42.2990800, 13.6864300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85949, 'Carapelle', 'Carapelle', 'Carapelle', 41.3636500, 15.6938400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85950, 'Carano', 'Carano', '', 41.2052600, 13.9097200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85951, 'Caramanico Terme', 'Caramanico Terme', 'Caramanico,Caramanico Terme', 42.1559300, 14.0048000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85952, 'Caraglio', 'Caraglio', 'Caraglio,Caraj', 44.4172500, 7.4328100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85953, 'Capurso', 'Capurso', 'Capurso', 41.0459800, 16.9216800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85954, 'Capua', 'Capua', 'Capoue,Capua,Capua Nova,Càpua,Cápua,Kapua,Kapuja,ka pu a,kabwa,kapua,kapwa,Капуа,Капуя,Կապուա,קפואה,كابوا,کاپوآ,کاپوا,კაპუა,カプア,卡普阿,카푸아', 41.1051900, 14.2126900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85955, 'Capriolo', 'Capriolo', 'Capriolo,kapurioro,カプリオーロ', 45.6333300, 9.9318900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85956, 'Caprino Veronese', 'Caprino Veronese', 'Caprino Veronese', 45.6048900, 10.7951800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85957, 'Caprino', 'Caprino', 'Caprino,Caprino Bergamasco', 45.7490300, 9.4923500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85958, 'Capriglia Irpina', 'Capriglia Irpina', '', 40.9603200, 14.7772400, 'IT', '2012-03-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85959, 'Caprie', 'Caprie', 'Caprie,Chiavrie,Ciavrie,kapurie,カプリエ', 45.1194400, 7.3329400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85960, 'Capriati A Volturno', 'Capriati A Volturno', 'Capriati a Volturno', 41.4680100, 14.1460200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85961, 'Capriate San Gervasio', 'Capriate San Gervasio', '', 45.6125800, 9.5287500, 'IT', '2006-01-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85962, 'Capriate San Gervasio', 'Capriate San Gervasio', '', 45.6128100, 9.5297400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85963, 'Capriana', 'Capriana', 'Capriana,kapuriana,カプリアーナ', 46.2628100, 11.3380100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85964, 'Capri', 'Capri', 'Capreae,Capri,Enez Capri,Insula Capri,Isla de Capri,Isula e Capri,Kapri,Kapris,PRJ,Vostrau Kapry,ka pri,ka pu li dao,kabry,kapeuli seom,kapry,kapuri dao,kypry,Κάπρι,Востраў Капры,Капри,Капрі,קאפרי,كابري,کاپری,کیپری,กาปรี,კაპრი,カプリ島,卡普里岛,카프리 섬', 40.5507300, 14.2426300, 'IT', '2015-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85965, 'Caprese Michelangelo', 'Caprese Michelangelo', 'Caprese,Caprese Michelangelo,Capresi Michelangelu,Caprexe Michelangelo,Caprexe Michełangeło,Castrum de Caprise,Kaprehzeh-Mikelandzhehla,Kapreze Mikelandzelo,Kapreze Mikelandzhelo,Kapreze-Mikelandzelas,Kapreze-Mikelandzhelo,Kaprezė-Mikelandželas,ka pu lei sai mi kai lang ji luo,kabryzy mykylanjylw,kaprzh myklanjlw,Капрезе Микеланджело,Капрезе Микеланџело,Капрезе-Микеланджело,Капрезе-Мікеланджело,Капрэзэ-Мікеланджэла,Կապրեզե Միքելանջելո,קפרזה מיכלאנגלו,كابريزي ميكيلانجيلو,کاپرزه میکلانجلو,カプレーゼ・ミケランジェロ,卡普雷塞米开朗基罗', 43.6403100, 11.9854600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85966, 'Caprarola', 'Caprarola', 'Caprarola,kapurarora,カプラローラ', 42.3230800, 12.2384800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85967, 'Caprarica di Lecce', 'Caprarica di Lecce', 'Caprarica,Caprarica di Lecce,Kraparaka', 40.2606000, 18.2442600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85968, 'Capranica Prenestina', 'Capranica Prenestina', 'Capranica Prenestina,カプラーニカ・プレネスティーナ', 41.8628500, 12.9507700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85969, 'Capranica', 'Capranica', 'Capranica,kapuranika,カプラーニカ', 42.2584900, 12.1727800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85970, 'Capralba', 'Capralba', 'Capralba', 45.4435200, 9.6441700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85971, 'Capraia Isola', 'Capraia Isola', '', 43.0506400, 9.8429800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85972, 'Capracotta', 'Capracotta', 'Capracotta', 41.8332600, 14.2658100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85973, 'Cappelle sul Tavo', 'Cappelle sul Tavo', 'Cappelle sul Tavo', 42.4770900, 14.1073500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85974, 'Cappella Maggiore', 'Cappella Maggiore', 'Cappella Maggiore', 45.9722200, 12.3585500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85975, 'Cappella de'' Picenardi', 'Cappella de'' Picenardi', 'Cappella de'' Pic,Cappella de'' Picenardi,Cappella de''Picenardi', 45.1585700, 10.2299800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85976, 'Cappadocia', 'Cappadocia', '', 42.0075500, 13.2780600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85977, 'Caposele', 'Caposele', 'Caposel,Caposele,Caposels', 40.8155300, 15.2233700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85978, 'Caporciano', 'Caporciano', 'Caporciano', 42.2500100, 13.6745500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85979, 'Capoliveri', 'Capoliveri', 'Capoliveri,kaporivu~eri,カポリーヴェリ', 42.7456900, 10.3775300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85980, 'Capodrise', 'Capodrise', 'Capodrise', 41.0426800, 14.3060700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85981, 'Capo di Ponte', 'Capo di Ponte', 'Capo di Ponte,カーポ・ディ・ポンテ', 46.0300000, 10.3428300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85982, 'Capodimonte', 'Capodimonte', 'Capodimonte', 42.5478000, 11.9065700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85983, 'Capodarco', 'Capodarco', 'Capodarco,Capodarso', 43.1898500, 13.7593500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85984, 'Capitignano', 'Capitignano', 'Capitignano', 42.5204100, 13.3012200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85985, 'Capistrello', 'Capistrello', 'Capistrello', 41.9722300, 13.3961600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85986, 'Capestrano', 'Capestrano', '', 42.2680700, 13.7677900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85987, 'Capergnanica', 'Capergnanica', 'Capergnanica,Capernanica di Sotto', 45.3386900, 9.6447500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85988, 'Capena', 'Capena', 'Capena,kapena,カペーナ', 42.1424700, 12.5451300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85989, 'Capannori', 'Capannori', 'Capannori,Kapannori,Капаннори', 43.8417100, 10.5727100, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85990, 'Capannoli', 'Capannoli', 'Capannoli,Capannoli Val d''Era', 43.5885600, 10.6732800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85991, 'Capalbio', 'Capalbio', 'Capalbio', 42.4534200, 11.4217500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85992, 'Capaccio', 'Capaccio', 'Capaccio,Capaccio-Paestum', 40.4243500, 15.0798100, 'IT', '2015-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85993, 'Caorso', 'Caorso', 'Caorso', 45.0491100, 9.8745700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85994, 'Caorle', 'Caorle', 'Caorle,Caprulae,Cjaurlis,kaorure,カオルレ', 45.5965600, 12.8758000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85995, 'Canzo', 'Canzo', 'Cantius,Canz,Canzo', 45.8486700, 9.2706300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85996, 'Canzano', 'Canzano', 'Canzano', 42.6456400, 13.8041000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85997, 'Cantù', 'Cantu', '', 45.7409600, 9.1308400, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85998, 'Cantoira', 'Cantoira', 'Cantoira,Cantòira,kantoira,カントーイラ', 45.3401400, 7.3845000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(85999, 'Cantiano', 'Cantiano', 'Cantiano', 43.4708200, 12.6286800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86000, 'Cantalupo nel Sannio', 'Cantalupo nel Sannio', 'Cantalupo del Sannio', 41.5218200, 14.3929200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86001, 'Cantalupo Ligure', 'Cantalupo Ligure', 'Cantalupo Ligure', 44.7181100, 9.0457500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86002, 'Cantalupo in Sabina', 'Cantalupo in Sabina', 'Cantalupo,Cantalupo Sabino,Cantalupo in Sabina', 42.3068900, 12.6451300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86003, 'Cantalice', 'Cantalice', 'Cantalice', 42.4645800, 12.9046100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86004, 'Cantagallo', 'Cantagallo', 'Cantagallo,Cantagallo vald,Cantagallus,Cantagalo,Cantagało,Kantagallo,Kantagalo,kan ta jia luo,kantagarro,Кантагалло,Кантагало,カンタガッロ,坎塔加洛', 44.0220500, 11.0797100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86005, 'Cansano', 'Cansano', 'Cansano', 42.0035000, 14.0134100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86006, 'Olgiate Molgora', 'Olgiate Molgora', 'Olgiate Calco,Olgiate Molgora', 45.7302800, 9.4033500, 'IT', '2012-08-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86007, 'Canosa Sannita', 'Canosa Sannita', 'Canosa Sannita', 42.2962900, 14.3051400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86008, 'Canosa di Puglia', 'Canosa di Puglia', 'Canosa de Pulla,Canosa di Puglia', 41.2195400, 16.0676800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86009, 'Cannole', 'Cannole', 'Cannole,Kannula', 40.1659200, 18.3645600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86010, 'Cannobio', 'Cannobio', 'Cannobio,Kannobio,Каннобио', 46.0623300, 8.6962800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86011, 'Canneto sull''Oglio', 'Canneto sull''Oglio', 'Canneto,Canneto sull''Oglio', 45.1516300, 10.3828200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86012, 'Canneto Pavese', 'Canneto Pavese', 'Canneto Pavese', 45.0504600, 9.2787600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86013, 'Cannero Riviera', 'Cannero Riviera', 'Cannero,Cannero Riviera', 46.0220000, 8.6793300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86014, 'Cannara', 'Cannara', 'Cannara', 42.9954000, 12.5820200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86015, 'Cannalonga', 'Cannalonga', 'Cannalonga', 40.2446100, 15.2932500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86016, 'Canna', 'Canna', 'Canna,Kana,Kanna,kan na,kan''na,Кана,Канна,Կաննա,カンナ,坎纳', 40.0948400, 16.5037800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86017, 'Canischio', 'Canischio', 'Canis-cio,Canischio,kanisukio,カニスキオ', 45.3748500, 7.5962100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86018, 'Canino', 'Canino', 'Caninium,Canino,Caninu,Kanino,ka ni nuo,kanino,Канино,Каніно,Կանինո,カニーノ,卡尼诺,카니노', 42.4659200, 11.7529400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86019, 'Caneva', 'Caneva', 'Caneva,Caneva di Sacile,Cjanive', 45.9707800, 12.4526100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86020, 'Canepina', 'Canepina', 'Canepina', 42.3831500, 12.2317900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86021, 'Canelli', 'Canelli', 'Canej,Canelli', 44.7208400, 8.2928200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86022, 'Canegrate', 'Canegrate', 'Canegrate,kanegurate,カネグラーテ', 45.5682500, 8.9268900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86023, 'Candiolo', 'Candiolo', 'Candieul,Candiolo,kandioro,カンディオーロ', 44.9585800, 7.5981200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86024, 'Candide', 'Candide', 'Comelico Superiore', 46.5891300, 12.5147600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86025, 'Candida', 'Candida', '', 40.9414800, 14.8723000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86026, 'Candiana', 'Candiana', 'Candiana,Candianum,Kand''ana,Kandiana,kan di ya na,kandiana,Кандиана,Кандьана,Кандіана,Կանդիանա,カンディアーナ,坎迪亚纳', 45.2218400, 11.9925600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86027, 'Candia Lomellina', 'Candia Lomellina', 'Candia,Candia Lomellina', 45.1767000, 8.5955000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86028, 'Candia Canavese', 'Candia Canavese', 'Candia,Candia Canavese,カンディア・カナヴェーゼ', 45.3273400, 7.8842900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86029, 'Candelo', 'Candelo', 'Candelo', 45.5409300, 8.1065900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86030, 'Candela', 'Candela', 'Candela,Kandela,kan de la,kandella,kandera,kandla,qndlh,Кандела,קנדלה,کاندلا,カンデラ,坎德拉,칸델라', 41.1360100, 15.5153700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86031, 'Cancello-Arnone', 'Cancello-Arnone', 'Cancello,Cancello e Arnone,Cancello ed Arnone', 41.0734000, 14.0254200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86032, 'Cancellara', 'Cancellara', 'Cancellara', 40.7306800, 15.9247000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86033, 'Canazei', 'Canazei', 'Canazei,Canazei di Fassa,Cianacei,kanatsu~ei,カナツェーイ', 46.4762700, 11.7692900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86034, 'Canaro', 'Canaro', 'Canaro', 44.9339400, 11.6754100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86035, 'Canal San Bovo', 'Canal San Bovo', '', 46.1566700, 11.7299800, 'IT', '2016-10-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86036, 'Canale Monterano', 'Canale Monterano', 'Canale Monterano,カナーレ・モンテラーノ', 42.1359800, 12.1028400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86037, 'Canale d''Agordo', 'Canale d''Agordo', 'Canale d''Agordo,Forno di Canale', 46.3569300, 11.9142900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86038, 'Canale', 'Canale', 'Canal,Canale', 44.7953200, 7.9937300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86039, 'Camugnano', 'Camugnano', 'Camugnano', 44.1711000, 11.0882800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86040, 'Camucia-Monsigliolo', 'Camucia-Monsigliolo', '', 43.2592600, 11.9711400, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86041, 'Campo Tures', 'Campo Tures', 'Campo Tures,Kampo Toures,Kampo Tures,Kampo-Tures,Sand in Taufers,Taufers,Tufers,kan bo tu lei si,Κάμπο Τούρες,Кампо Турес,Кампо-Турес,Կամպո Տուրես,カンポ・トゥーレス,坎波图雷斯', 46.9084400, 11.9603600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86042, 'Campotosto', 'Campotosto', 'Campotosto', 42.5588400, 13.3679900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86043, 'Campo Tizzoro', 'Campo Tizzoro', '', 44.0399400, 10.8523700, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86044, 'Campospinoso', 'Campospinoso', 'Campospinoso', 45.0940300, 9.2458500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86045, 'Camposanto', 'Camposanto', 'Camposanto', 44.7900900, 11.1404900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86046, 'Camposano', 'Camposano', 'Camposano,kanpozano,カンポザーノ', 40.9524200, 14.5299100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86047, 'Campo San Martino', 'Campo San Martino', 'Campo San Martino', 45.5486800, 11.8280900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86048, 'Camposampiero', 'Camposampiero', 'Campo San Piero,Camposampiero', 45.5636800, 11.9353400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86049, 'Camporotondo di Fiastrone', 'Camporotondo di Fiastrone', 'Camporotondo di Fiastrone', 43.1320300, 13.2663200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86050, 'Camporosso', 'Camporosso', 'Camporosso', 43.8131000, 7.6282900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86051, 'Camporgiano', 'Camporgiano', 'Camporgiano', 44.1592700, 10.3330000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86052, 'Campora', 'Campora', 'Campora', 40.3054100, 15.2923600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86053, 'Camponogara', 'Camponogara', 'Camponogara,kanponogara,カンポノガーラ', 45.3795400, 12.0863800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86054, 'Campomorone', 'Campomorone', 'Campomon,Campomorone', 44.5095400, 8.8850200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86055, 'Campomarino', 'Campomarino', 'Campomarino,Kemarini', 41.9569200, 15.0354600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86056, 'Campomaggiore', 'Campomaggiore', 'Campomaggiore', 40.5659000, 16.0725000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86057, 'Campolongo al Torre', 'Campolongo al Torre', 'Campolongo Tapogliano,Campolongo al Torre,Cjamplunc,Cjamplunc de Tor,Kampolongo-Tapol''jano,Камполонго-Тапольяно,カンポロンゴ・アル・トッレ', 45.8638900, 13.3966700, 'IT', '2012-03-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86058, 'Campo Ligure', 'Campo Ligure', 'Campo,Campo Ligure', 44.5365800, 8.6989600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86059, 'Campolieto', 'Campolieto', 'Campolieto', 41.6333600, 14.7669400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86060, 'Campoli del Monte Taburno', 'Campoli del Monte Taburno', 'Campoli del Monte Taburno', 41.1307400, 14.6464900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86061, 'Campoli Appennino', 'Campoli Appennino', 'Campoli Appennino', 41.7353900, 13.6832600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86062, 'Campoleone', 'Campoleone', 'Campoleone,Casale Campoleone', 41.6457000, 12.6482600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86063, 'Campolattaro', 'Campolattaro', 'Campolattaro', 41.2869300, 14.7304300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86064, 'Campo Jemini', 'Campo Jemini', '', 41.6271600, 12.5125800, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86065, 'Campogalliano', 'Campogalliano', 'Campogalliano,kanpogarriano,カンポガッリアーノ', 44.6887400, 10.8470500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86066, 'Campoformido', 'Campoformido', 'Campoformido,Campoformio,Campofórmio,Cjampfuarmit,kanpoforumido,カンポフォルミド', 46.0195200, 13.1575000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86067, 'Campofilone', 'Campofilone', 'Campofilone', 43.0810000, 13.8215300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86068, 'Campodoro', 'Campodoro', 'Campodoro', 45.4894700, 11.7526800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86069, 'Campodolcino', 'Campodolcino', 'Campodolcino', 46.4029000, 9.3518500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86070, 'Campo di Trens', 'Campo di Trens', 'Campo di Trens,Campus Torrentis,Freienfeld,Kampo di Trens,Kampo nti Trens,Kampo-di-Trens,kan bo di te lun si,Κάμπο ντι Τρενς,Кампо ди Тренс,Кампо-ди-Тренс,Кампо-ді-Тренс,Կամպո դի Տրենս,カンポ・ディ・トレンス,坎波迪特伦斯', 46.8741200, 11.4860500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86071, 'Campodipietra', 'Campodipietra', 'Campodipietra', 41.5574000, 14.7444500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86072, 'Campo di Giove', 'Campo di Giove', 'Campo di Giove', 42.0101300, 14.0394100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86073, 'Campo di Carne', 'Campo di Carne', 'Casale Campo di Carne', 41.5526500, 12.6411400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86074, 'Campodenno', 'Campodenno', 'Campodenno,kanpoden''no,カンポデンノ', 46.2579100, 11.0331700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86075, 'Campodarsego', 'Campodarsego', 'Campodarsego', 45.4981500, 11.9219400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86076, 'Campochiaro', 'Campochiaro', 'Campochiaro', 41.4482700, 14.5082800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86077, 'Campobasso', 'Campobasso', 'Campobass,Campobasso,Campubbassu,Campus Bassus,Kampobasso,QPB,kanpobasso,Кампобассо,カンポバッソ', 41.5594700, 14.6673700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86078, 'Campli', 'Campli', 'Campli', 42.7267900, 13.6869200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86079, 'Campitello di Fassa', 'Campitello di Fassa', '', 46.4757900, 11.7411000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86080, 'Campitello', 'Campitello', '', 45.0875000, 10.6063200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86081, 'Campi Salentina', 'Campi Salentina', 'Campi Salentina', 40.3974700, 18.0214100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86082, 'Campione', 'Campione', 'Campione,Campione d''Italia,Campione d’Italia,Italiae Campilionum,カンピョーネ・ディターリア', 45.9681800, 8.9718100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86083, 'Campiglia Marittima', 'Campiglia Marittima', 'Campiglia,Campiglia Marittima,カンピーリア・マリッティマ', 43.0600100, 10.6145300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86084, 'Campiglia dei Berici', 'Campiglia dei Berici', '', 45.3354600, 11.5421000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86085, 'Campiglia Cervo', 'Campiglia Cervo', 'Campiglia Cervo', 45.6629000, 7.9996700, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86086, 'Campi Bisenzio', 'Campi Bisenzio', 'Campi Bisenzio,Campo Bisenzio,Campo Bisénzio,カンピ・ビゼンツィオ', 43.8245000, 11.1302700, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86087, 'Campertogno', 'Campertogno', 'Campertogno', 45.7987700, 8.0321200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86088, 'Campello sul Clitunno', 'Campello sul Clitunno', 'Campello,Campello sul Clitunno,Campellu supra lu Clitunnu,Campellus ad Clitumnum,Kampello-sul''-Klitunno,Kampelo sul Klitunno,Kampelo sul Klituno,Klitunnodagy Kampello,kambylw swl klytwnw,kampellosulkeullitunno,ke li tong nuo he pan kan pei luo,Кампелло-суль-Клитунно,Кампелло-суль-Клітунно,Кампело сул Клитуно,Клитуннодағы Кампелло,Կամպելո սուլ Կլիտուննո,كامبيلو سول كليتونو,カンペッロ・スル・クリトゥンノ,克利通诺河畔坎佩洛,캄펠로술클리툰노', 42.8268500, 12.7693100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86089, 'Campegine', 'Campegine', 'Campegine', 44.7808500, 10.5283600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86090, 'Camparada', 'Camparada', 'Camparada,kanparada,カンパラーダ', 45.6548900, 9.3232800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86091, 'Campanarello', 'Campanarello', '', 41.0471700, 14.9141800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86092, 'Campalto', 'Campalto', '', 45.4806200, 12.2874700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86093, 'Campagnola Emilia', 'Campagnola Emilia', 'Campagnola Emilia', 44.8392500, 10.7650700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86094, 'Campagnola', 'Campagnola', '', 45.2786600, 11.9990200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86095, 'Campagnatico', 'Campagnatico', 'Campagnacito,Campagnatico', 42.8828300, 11.2739400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86096, 'Campagnano di Roma', 'Campagnano di Roma', 'Campagnano di Roma,カンパニャーノ・ディ・ローマ', 42.1357000, 12.3735800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86097, 'Campagna Lupia', 'Campagna Lupia', 'Campagna Lupia,カンパーニャ・ルーピア', 45.3538100, 12.0972700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86098, 'Campagna', 'Campagna', 'Campagna,kanpanya,カンパーニャ', 40.6666100, 15.1063800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86099, 'Camogli', 'Camogli', 'Camoggi,Camogli,Kamoli,Камоли', 44.3494500, 9.1548700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86100, 'Camisano Vicentino', 'Camisano Vicentino', 'Camisano,Camisano Vicentino', 45.5215600, 11.7081700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86101, 'Camisano', 'Camisano', 'Camisano', 45.4448400, 9.7452600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86102, 'Camino', 'Camino', 'Camin,Camino', 45.1572300, 8.2937600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86103, 'Camigliano', 'Camigliano', 'Camigliano,Camiglianu,Camilianum,Cammigliano,Kamil''jano,Kamilano,Kamiliano,Kamiljano,ka mi li ya nuo,kamilliano,kamiriano,Камильяно,Камиляно,Камиљано,Камільяно,Կամիլիանո,カミリアーノ,卡米利亚诺,카밀리아노', 41.1811600, 14.2097800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86104, 'Camerota', 'Camerota', 'Camerota', 40.0326200, 15.3704800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86105, 'Camerino', 'Camerino', 'Camerino,kamerino,カメリーノ', 43.1386600, 13.0678500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86106, 'Cameri', 'Cameri', 'Cameri', 45.5015900, 8.6624500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86107, 'Camerata Picena', 'Camerata Picena', 'Camerata Picena,カメラータ・ピチェーナ', 43.5775800, 13.3519600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86108, 'Camerata Nuova', 'Camerata Nuova', 'Camerata Nuova,カメラータ・ヌオーヴァ', 42.0180000, 13.1097000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86109, 'Camerata Cornello', 'Camerata Cornello', 'Camerata Cornello', 45.8995600, 9.6556900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86110, 'Camerano', 'Camerano', 'Camerano,kamerano,カメラーノ', 43.5277400, 13.5525700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86111, 'Camburzano', 'Camburzano', 'Camburzano', 45.5439300, 8.0022600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86112, 'Cambiano', 'Cambiano', 'Cambiagn,Cambiano,kanbiano,カンビアーノ', 44.9711300, 7.7744700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86113, 'Cambiago', 'Cambiago', 'Cambiago,kanbiago,カンビアーゴ', 45.5803500, 9.4352800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86114, 'Camalò', 'Camalo', '', 45.7532400, 12.1716500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86115, 'Camairago', 'Camairago', 'Camairago,kamairago,カマイラーゴ', 45.2052700, 9.7274600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86116, 'Camaiore', 'Camaiore', 'Camaiore,Kamajore,Камайоре', 43.9426500, 10.2975400, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86117, 'Calvizzano', 'Calvizzano', 'Calvizzano,karuvu~ittsu~ano,カルヴィッツァーノ', 40.9078200, 14.1858100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86118, 'Calvisano', 'Calvisano', 'Calvisano,Calvisii Forum,karuvu~izano,カルヴィザーノ', 45.3452900, 10.3426600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86119, 'Calvignano', 'Calvignano', 'Calvignano', 44.9830600, 9.1687600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86120, 'Calvi dell''Umbria', 'Calvi dell''Umbria', '', 42.4042100, 12.5677100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86121, 'Calvera', 'Calvera', 'Calvera', 40.1487100, 16.1436200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86122, 'Calvenzano', 'Calvenzano', 'Calvenzano', 45.4962100, 9.5995300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86123, 'Calvene', 'Calvene', 'Calvene', 45.7661500, 11.5114600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86124, 'Calvello', 'Calvello', '', 40.4748200, 15.8509200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86125, 'Calvatone', 'Calvatone', 'Betriacum,Calvatone', 45.1269700, 10.4405700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86126, 'Calvanico', 'Calvanico', 'Calvanico', 40.7761600, 14.8269700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86127, 'Caluso', 'Caluso', 'Caluso,karuzo,カルーゾ', 45.3046600, 7.8910100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86128, 'Calusco d''Adda', 'Calusco d''Adda', 'Calusco d''Adda,Kalusko d''Ada,Калуско д''Ада', 45.6884100, 9.4710900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86129, 'Caltrano', 'Caltrano', 'Caltrano', 45.7734600, 11.4557000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86130, 'Calto', 'Calto', 'Calto,karuto,カルト', 44.9907200, 11.3585400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86131, 'Caltignaga', 'Caltignaga', 'Caltignaga,karutinyaga,カルティニャーガ', 45.5208800, 8.5861600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86132, 'Caltana', 'Caltana', '', 45.4827800, 12.0300200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86133, 'Calolziocorte', 'Calolziocorte', 'Calolzio,Calolziocorte,Corte,Kalolciokorte', 45.7953800, 9.4376500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86134, 'Calò', 'Calo', '', 45.6790800, 9.2630900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86135, 'Calliano', 'Calliano', 'Calliano,karriano,カッリアーノ', 45.9329900, 11.0950300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86136, 'Calliano', 'Calliano', 'Calian,Calliano,karriano,カッリアーノ', 45.0079800, 8.2566100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86137, 'Calizzano', 'Calizzano', 'Calizzano,Carizan', 44.2361200, 8.1181700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86138, 'Calitri', 'Calitri', 'Calitri', 40.9256900, 15.4039300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86139, 'Calimera', 'Calimera', 'Calimera,Kalimera', 40.2494800, 18.2798200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86140, 'Calice al Cornoviglio', 'Calice al Cornoviglio', 'Calice,Calice Cornoviglio,Calice al Cornoviglio', 44.2432600, 9.8367100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86141, 'Calestano', 'Calestano', 'Calestano', 44.6022400, 10.1236300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86142, 'Calenzano', 'Calenzano', 'Calenzano', 43.8544700, 11.1660800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86143, 'Calendasco', 'Calendasco', 'Calendasco', 45.0865900, 9.5964700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86144, 'Caldonazzo', 'Caldonazzo', 'Caldonatium,Caldonazo,Caldonazzo,Kal''donacco,Kaldonaco,ka er duo na zuo,karudonattsu~o,Калдонацо,Кальдонаццо,Կալդոնացո,カルドナッツォ,卡尔多纳佐', 45.9936700, 11.2642600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86145, 'Caldogno-Rettorgole-Cresole', 'Caldogno-Rettorgole-Cresole', 'Caldogno,Kaldon''o,karudonyo,Калдоньо,カルドーニョ', 45.6078000, 11.5028000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86146, 'Caldes', 'Caldes', 'Caldes,karudesu,カルデス', 46.3668600, 10.9403700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86147, 'Calderara di Reno', 'Calderara di Reno', 'Calderara di Reno', 44.5630700, 11.2711100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86148, 'Caldarola', 'Caldarola', 'Caldarola', 43.1428200, 13.2236700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86149, 'Caldaro sulla Strada del Vino', 'Caldaro sulla Strada del Vino', 'Kaltern,Kaltern an der Weinstrasse', 46.4132600, 11.2461600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86150, 'Calcio', 'Calcio', 'Calcio,karucho,カルチョ', 45.5082600, 9.8490200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86151, 'Calcinelli', 'Calcinelli', '', 43.7539800, 12.9195900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86152, 'Calcinato', 'Calcinato', 'Calcinato,karuchinato,カルチナート', 45.4573900, 10.4094900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86153, 'Calcinate', 'Calcinate', 'Calcinate,karuchinate,カルチナーテ', 45.6197500, 9.7984300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86154, 'Calcinaia', 'Calcinaia', 'Calcinaia,Calcinaja', 43.6835200, 10.6165300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86155, 'Calciano', 'Calciano', 'Calciano', 40.5880200, 16.1923800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86156, 'Calci', 'Calci', 'Calci', 43.7259700, 10.5179100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86157, 'Calcata Nuova', 'Calcata Nuova', 'Calcata,karukata,カルカータ', 42.2195200, 12.4261700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86158, 'Calcara', 'Calcara', '', 44.5469600, 11.1336600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86159, 'Calavino', 'Calavino', 'Calavino,karavu~ino,カラヴィーノ', 46.0460600, 10.9840200, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86160, 'Calascio', 'Calascio', 'Calascio', 42.3259500, 13.6969900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86161, 'Calangianus', 'Calangianus', 'Calangianus', 40.9202700, 9.1934300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86162, 'Calamandrana', 'Calamandrana', 'Calamandran-a,Calamandrana', 44.7376700, 8.3372600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86163, 'Calalzo di Cadore', 'Calalzo di Cadore', 'Calalzo di Cadore', 46.4464300, 12.3817600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86164, 'Cala Gonone', 'Cala Gonone', 'Cala Gonone,Cala di Gonone,Porto Gonone,Porto di Gonone', 40.2808600, 9.6297100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86165, 'Calabritto', 'Calabritto', 'Calabritto', 40.7834200, 15.2228500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86166, 'Caivano', 'Caivano', 'Caivano,Kajvano,kaivu~ano,Кайвано,カイヴァーノ', 40.9575300, 14.3059100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86167, 'Cairo Montenotte', 'Cairo Montenotte', 'Cairi,Cairo Montenotte,カイロ・モンテノッテ', 44.3979000, 8.2777500, 'IT', '2015-11-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86168, 'Caira', 'Caira', 'Caira,Cairo,Cáira', 41.5333300, 13.8166700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86169, 'Cairate', 'Cairate', 'Cairate', 45.6875000, 8.8680700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86170, 'Cairano', 'Cairano', 'Cairano', 40.8955200, 15.3706900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86171, 'Caiazzo', 'Caiazzo', 'Caiatia,Caiazzo', 41.1843500, 14.3594600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86172, 'Caianello', 'Caianello', 'Caianello', 41.3050900, 14.0851600, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86173, 'Cagnano Varano', 'Cagnano Varano', 'Cagnano Varano,Gagnano Varano', 41.8283200, 15.7720300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86174, 'Caglio', 'Caglio', 'Caglio', 45.8714600, 9.2371900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86175, 'Cagli', 'Cagli', 'Cagli,kari,カーリ', 43.5477100, 12.6522900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86176, 'Caggiano', 'Caggiano', 'Caggiano', 40.5624000, 15.4962900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86177, 'Caerano di San Marco', 'Caerano di San Marco', 'Caerano di San Marco', 45.7816000, 11.9985100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86178, 'Cadoneghe', 'Cadoneghe', 'Cadoneghe', 45.4428200, 11.9274900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86179, 'Ca'' di Sola', 'Ca'' di Sola', '', 44.5298600, 10.9544800, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86180, 'Cadine', 'Cadine', '', 46.0896000, 11.0684700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86181, 'Caderzone Terme', 'Caderzone Terme', 'Cadarcion,Cadersonium,Caderzone,Kadehrconeh-Tehrmeh,Kadercone,Kadercone Terme,Kadercone-Terme,ka de er zuo nei,kaderutsu~one・terume,Кадерцоне,Кадерцоне Терме,Кадерцоне-Терме,Кадэрцонэ-Тэрмэ,Կադերցոնե,カデルツォーネ・テルメ,卡德尔佐内', 46.1294500, 10.7561900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86182, 'Cadelbosco di Sotto', 'Cadelbosco di Sotto', '', 44.8014100, 10.6157800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86183, 'Cadelbosco di Sopra', 'Cadelbosco di Sopra', 'Cadelbosco,Cadelbosco di Sopra', 44.7657300, 10.5989800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86184, 'Ca'' degli Oppi', 'Ca'' degli Oppi', '', 45.2955000, 11.1302900, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86185, 'Cadè-Gaida', 'Cade-Gaida', '', 44.7385000, 10.5158000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86186, 'Cabella Ligure', 'Cabella Ligure', 'Cabella Ligure', 44.6749100, 9.0960700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86187, 'Buttrio', 'Buttrio', 'Buri,Buttrio', 46.0109800, 13.3335400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86188, 'Buttigliera Alta', 'Buttigliera Alta', 'Butiera,Buttigliera Alta,ブッティリエーラ・アルタ', 45.0683600, 7.4325400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86189, 'Buttapietra', 'Buttapietra', 'Buttapietra', 45.3411000, 10.9991500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86190, 'Buti', 'Buti', 'Buti', 43.7285700, 10.5845000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86191, 'Busto Garolfo', 'Busto Garolfo', 'Busto Garolfo,ブスト・ガロルフォ', 45.5480900, 8.8829800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86192, 'Busto Arsizio', 'Busto Arsizio', 'Ansizio,Busto Arsizio,Bustum Arsitium,bu si tuo-a xi qi ao,布斯托-阿西齊奧', 45.6112800, 8.8491400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86193, 'Bussoleno', 'Bussoleno', 'Bussoleno,Bussolin,bussoreno,ブッソレーノ', 45.1397000, 7.1443200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86194, 'Bussolengo', 'Bussolengo', 'Bussolengo', 45.4690300, 10.8537100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86195, 'Busso', 'Busso', 'Busso', 41.5541300, 14.5610300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86196, 'Bussi sul Tirino', 'Bussi sul Tirino', 'Bussi sul Tirino', 42.2132100, 13.8251100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86197, 'Busseto', 'Busseto', 'Busseto,busseto,ブッセート', 44.9794000, 10.0433100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86198, 'Buscoldo', 'Buscoldo', '', 45.0943000, 10.6958100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86199, 'Buscate', 'Buscate', 'Buscate,busukate,ブスカーテ', 45.5435300, 8.8129700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86200, 'Busca', 'Busca', 'Busca', 44.5162500, 7.4766200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86201, 'Busano', 'Busano', 'Busan,Busano,buzano,ブザーノ', 45.3313700, 7.6572700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86202, 'Busana', 'Busana', 'Busana', 44.3688600, 10.3233900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86203, 'Busalla', 'Busalla', 'Busalla', 44.5706000, 8.9454500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86204, 'Busachi', 'Busachi', 'Busache,Busachi,Busachis,Buzaki,bu sa ji,buzaki,bwsachy,Бузаки,Бузакі,Բուզակի,بوساچی,ブザーキ,布萨基', 40.0342200, 8.8884800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86205, 'Buronzo', 'Buronzo', 'Buronzo', 45.4801800, 8.2662800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86206, 'Burolo', 'Burolo', 'Bureul,Burolo,buroro,ブローロ', 45.4811600, 7.9339200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86207, 'Buriasco', 'Buriasco', 'Buriasch,Buriasco,buriasuko,ブリアスコ', 44.8722200, 7.4120000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86208, 'Burgos', 'Burgos', 'Burgos', 40.3908100, 8.9955800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86209, 'Burano', 'Burano', '', 45.4854800, 12.4169600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86210, 'Buonconvento', 'Buonconvento', 'Boncunventu,Bonus Conventus,Buonconvento,Buonkanventa,Buonkonvento,bo en kong wen tuo,buonkon''vu~ento,buonkonbento,bwnwkwnwntw,Буонканвента,Буонконвенто,Բուոնկոնվենտո,بونوکونونتو,ブオンコンヴェント,博恩孔文托,부온콘벤토', 43.1331400, 11.4836300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86211, 'Buonalbergo', 'Buonalbergo', 'Buonalbergo', 41.2223600, 14.9779900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86212, 'Buonabitacolo', 'Buonabitacolo', 'Buonabitacolo', 40.2685500, 15.6211900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86213, 'Bulzi', 'Bulzi', 'Bulzi', 40.8466600, 8.8302600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86214, 'Bultei', 'Bultei', 'Bultei', 40.4572000, 9.0636700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86215, 'Buia', 'Buia', '', 46.2122200, 13.1169100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86216, 'Buglio in Monte', 'Buglio in Monte', 'Boei,Buglio,Buglio in Monte,Bul''jo-in-Monte,Bul''o in Monte,Bul''o-in-Monte,Bulio in Monte,Bulium,Böi,bu liao yin meng tai,Бульйо-ін-Монте,Бульо ин Монте,Бульо-ин-Монте,Բուլիո ին Մոնտե,ブーリオ・イン・モンテ,布廖因蒙泰', 46.1833600, 9.6754200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86217, 'Budrio', 'Budrio', 'Budrio', 44.5374500, 11.5343900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86218, 'Budoia', 'Budoia', 'Budoia,Budoio,Buduee,Budòio', 46.0445300, 12.5342900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86219, 'Buddusò', 'Budduso', 'Budduso,Buddusò', 40.5772300, 9.2583900, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86220, 'Bucine', 'Bucine', 'Bucine', 43.4768500, 11.6139900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86221, 'Buccino', 'Buccino', 'Buccino', 40.6367000, 15.3811600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86222, 'Bucciano', 'Bucciano', 'Bucciano', 41.0775600, 14.5689800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86223, 'Bucchianico', 'Bucchianico', 'Bucchianico,Rucchianico,Rucchiánico', 42.3036800, 14.1837700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86224, 'Bubbio', 'Bubbio', 'Bubbio,Bubi', 44.6634400, 8.2951400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86225, 'Brusson', 'Brusson', 'Brechon,Brjuson,Brjusson,Brusso,Brusson,Brussone,Bryuson,brwswn  walh daywsta,bu lu song,buryuson,Брюсон,Брюссон,Բրյուսոն,بروسون، واله دائوستا,ブリュソン,布鲁松', 45.7592600, 7.7289900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86226, 'Brusnengo', 'Brusnengo', 'Brusnengo', 45.5901100, 8.2521900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86227, 'Brusciano', 'Brusciano', 'Brusciano,burushano,ブルシャーノ', 40.9223700, 14.4238600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86228, 'Brusasco', 'Brusasco', 'Brusasco-Cavagnolo,Cavagneul,Cavagnolo,kavu~anyoro,カヴァニョーロ', 45.1549900, 8.0610700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86229, 'Bruno', 'Bruno', 'Brun,Bruno', 44.7926200, 8.4397300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86230, 'Brunico', 'Brunico', 'Brunech,Bruneck,Brunico,Bruniko,Brunopolis,buruniko,Брунико,ブルーニコ', 46.7994200, 11.9342900, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86231, 'Brunate', 'Brunate', 'Brunate,Брунате', 45.8209600, 9.0986900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86232, 'Bruna', 'Bruna', '', 42.8207100, 12.6885100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86233, 'Brumano', 'Brumano', 'Brumano', 45.8546300, 9.5006400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86234, 'Bruino', 'Bruino', 'Bruin,Bruino,buruino,ブルイーノ', 45.0150600, 7.4775400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86235, 'Brugnera', 'Brugnera', 'Brugnera,Brugnere', 45.8994700, 12.5417800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86236, 'Brugnato', 'Brugnato', 'Brigne,Brignê,Brugnato', 44.2367100, 9.7249600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86237, 'Brugine', 'Brugine', 'Bruxene,Brùxene', 45.2969600, 11.9920000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86238, 'Brugherio', 'Brugherio', 'Brugerio,Brugherio,burugerio,Бругерио,ブルゲーリオ', 45.5530100, 9.2990700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86239, 'Brosso', 'Brosso', 'Bross,Brosso,Bròss,burosso,ブロッソ', 45.4918000, 7.8022500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86240, 'Brossasco', 'Brossasco', 'Brossasco', 44.5677800, 7.3645400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86241, 'Bronzolo', 'Bronzolo', 'Branzoll,Bronzolo,burontsu~oro,ブロンツォーロ', 46.4034600, 11.3207800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86242, 'Broni', 'Broni', 'Broni,Comiliomagus', 45.0639400, 9.2599300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86243, 'Brivio', 'Brivio', 'Brivio', 45.7372500, 9.4424900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86244, 'Brittoli', 'Brittoli', 'Brittoli', 42.3151800, 13.8602600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86245, 'Grand Brissogne', 'Grand Brissogne', 'Brissogne', 45.7256600, 7.3926000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86246, 'Brissago-Valtravaglia', 'Brissago-Valtravaglia', 'Brissago-Valtravaglia', 45.9492100, 8.7459000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86247, 'Brisighella', 'Brisighella', 'Brisighella,bryzyglh,burijigerra,בריזיגלה,ブリジゲッラ', 44.2222800, 11.7735800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86248, 'Brinzio', 'Brinzio', 'Brinzio,Campo di Fiori', 45.8891400, 8.7868300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86249, 'Brindisi Montagna', 'Brindisi Montagna', 'Brindisi Montagna', 40.6095200, 15.9397700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86250, 'Brindisi', 'Brindisi', 'BDS,Brindisi,Brindizi,Brinnese,Brundisium,Brìndisi,brindisi,burindiji,Бриндизи,ब्रिंडिसि,ブリンディジ', 40.6321500, 17.9360700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86251, 'Brignano Gera d''Adda', 'Brignano Gera d''Adda', 'Brignano Gera d''Adda', 45.5432400, 9.6442400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86252, 'Brignano', 'Brignano', '', 44.8145700, 9.0400500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86253, 'Briga Novarese', 'Briga Novarese', 'Briga Novarese', 45.7293100, 8.4558600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86254, 'Brienno', 'Brienno', 'Brienno', 45.9117500, 9.1314200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86255, 'Bricherasio', 'Bricherasio', 'Bricheras,Bricherasio,burikerajio,ブリケラージオ', 44.8232800, 7.3030000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86256, 'Brez', 'Brez', 'Brez,buretsu,ブレツ', 46.4322000, 11.1057800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86257, 'Bresso', 'Bresso', 'Bresso,buresso,Брессо,ブレッソ', 45.5379200, 9.1892100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86258, 'Bressanvido', 'Bressanvido', 'Bressanvido', 45.6465100, 11.6343700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86259, 'Bressanone', 'Bressanone', 'Bresanona,Bressanone,Brixen,Brixen in Suedtirol,Brixen in Südtirol,Brixino,buressanone,Брессаноне,ブレッサノーネ', 46.7150300, 11.6559800, 'IT', '2016-01-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86260, 'Bressana', 'Bressana', 'Bressana,Bressana Bottarone', 45.0780700, 9.1311900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86261, 'Brescia', 'Brescia', 'BRZ,Brescia,Bresha,Breshija,Bresia,Bressia,Brixia,Bréscia,QBS,bryshya,bu lei xi ya,bureshia,Бреша,Брешия,بريشيا,ブレシア,布雷西亚', 45.5355800, 10.2147200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86262, 'Brescello', 'Brescello', 'Brescello', 44.8953100, 10.5126900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86263, 'Brentonico', 'Brentonico', 'Brentonico,burentoniko,ブレントーニコ', 45.8191000, 10.9550800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86264, 'Breno', 'Breno', 'Breno,bureno,ブレーノ', 45.9588900, 10.3064800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86265, 'Brenna', 'Brenna', 'Brena,Brenna,Brèna,brna  lmbardy,bu lun na,buren''na,Бренна,Բրենա,برنا، لمباردی,ブレンナ,布伦纳', 45.7433800, 9.1865700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86266, 'Brendola', 'Brendola', 'Brendola', 45.4784900, 11.4394700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86267, 'Breme', 'Breme', 'Braem,Breme,Bremetum,Bräm,brymy,bu lei mei,bureme,Бреме,Բրեմե,بريمي,ブレーメ,布雷梅', 45.1275600, 8.6256400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86268, 'Brembio', 'Brembio', 'Brembio,burenbio,ブレンビオ', 45.2123400, 9.5724400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86269, 'Brembilla', 'Brembilla', 'Brembila,Brembilla,bu lun bi la,burenbirra,Брембилла,Брембілла,Բրեմբիլլա,ブレンビッラ,布伦比拉', 45.8215400, 9.5967900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86270, 'Brembate', 'Brembate', 'Brembate', 45.6046800, 9.5548000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86271, 'Breia', 'Breia', 'Breia', 45.7649700, 8.3055200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86272, 'Breguzzo', 'Breguzzo', 'Bondo Breguzzo,Breguzzo,bureguttsu~o,ブレグッツォ', 46.0067900, 10.6976100, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86273, 'Breganze', 'Breganze', 'Breganze', 45.7048900, 11.5607400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86274, 'Breda', 'Breda', 'Breda,Breda di Piave', 45.7225000, 12.3308300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86275, 'Brebbia', 'Brebbia', 'Brebbia', 45.8298300, 8.6504200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86276, 'Braone', 'Braone', 'Braone,buraone,ブラオーネ', 45.9901100, 10.3417800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86277, 'Brandizzo', 'Brandizzo', 'Brandiss,Brandizzo,burandittsu~o,ブランディッツォ', 45.1770600, 7.8358100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86278, 'Pregola', 'Pregola', 'Brallo di Pregola,Pregola', 44.7506900, 9.2822300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86279, 'Bracigliano', 'Bracigliano', 'Bracigliano', 40.8188000, 14.7077200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86280, 'Bracciano', 'Bracciano', 'Bracciano,Brachchano,buratchano,Браччано,ブラッチャーノ', 42.1027100, 12.1656500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86281, 'Braccagni', 'Braccagni', 'Braccagni,Ostera Braccagni', 42.8728500, 11.0726600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86282, 'Bra', 'Bra', 'Bra,bura,Бра,ブラ', 44.6977600, 7.8512800, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86283, 'Bozzolo', 'Bozzolo', 'Bozzolo', 45.1032400, 10.4798800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86284, 'Bozzole', 'Bozzole', 'Bozzole', 45.0693400, 8.6056100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86285, 'Bovolone', 'Bovolone', 'Bovolone', 45.2614200, 11.1178600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86286, 'Bovolenta', 'Bovolenta', 'Bovolenta,Bovołenta,Bubulenta,bo wo lun ta,bovu~orenta,Боволента,Բովոլենտա,ボヴォレンタ,博沃伦塔', 45.2689200, 11.9357600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86287, 'Marchesino-Bovo', 'Marchesino-Bovo', '', 45.3666700, 11.0000000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86288, 'Bovisio-Masciago', 'Bovisio-Masciago', 'Bovisio,Bovisio-Masciago,Bovisio-Masciago Milanese,Bovísio-Masciago Milanese,bovu~ijio=mashago,ボヴィージオ＝マシャーゴ', 45.6101900, 9.1530100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86289, 'Bovino', 'Bovino', 'Bovino,Bovinum,Buvinu,bo wei nuo,bovu~ino,bwfynw,Бовино,Бовіно,Բովինո,بوفينو,ボヴィーノ,博维诺', 41.2491600, 15.3394800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86290, 'Boville Ernica', 'Boville Ernica', 'Boville Ernica', 41.6425200, 13.4727000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86291, 'Bovezzo', 'Bovezzo', 'Bovezzo,bovu~ettsu~o,ボヴェッツォ', 45.5899800, 10.2418400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86292, 'Boves', 'Boves', 'Boves,Bueves,Buèves', 44.3298500, 7.5473300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86293, 'Bovegno', 'Bovegno', 'Bovegno,bovu~enyo,ボーヴェニョ', 45.7912100, 10.2701200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86294, 'Bottrighe', 'Bottrighe', '', 45.0255200, 12.0823600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86295, 'Bottidda', 'Bottidda', 'Bottida,Bottidda', 40.3924200, 9.0103900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86296, 'Botticino', 'Botticino', 'Botticino,bottichino,ボッティチーノ', 45.5297200, 10.3108500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86297, 'Bottanuco', 'Bottanuco', 'Bottanuco', 45.6393100, 9.5090300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86298, 'Botrugno', 'Botrugno', 'Botrugno,Butrugnu', 40.0635900, 18.3225400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86299, 'Bossolasco', 'Bossolasco', 'Bossolasco', 44.5281800, 8.0499300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86300, 'Bosisio Parini', 'Bosisio Parini', 'Bosisio Parini,Boxisium,Boziz''o-Parini,Bozizio Parini,Bozizio-Parini,Busis,Bùsis,bo xi xiao pa li ni,Бозизьо-Парини,Бозізіо-Парині,Բոզիզիո Պարինի,ボジージオ・パリーニ,博西肖帕里尼', 45.8007500, 9.2900000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86301, 'Bosentino-Migazzone', 'Bosentino-Migazzone', 'Bosentino,bozentino,ボゼンティーノ', 46.0018000, 11.2231800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86302, 'Boscotrecase', 'Boscotrecase', 'Boscotrecase,bosukotorekaze,ボスコトレカーゼ', 40.7729600, 14.4618500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86303, 'Boscoreale', 'Boscoreale', 'Boscoreale,Boskoreale,Buscuriali,Nemus Regale,Vuoscoriale,bo si ke lei ya lai,boseukolealle,bosukoreare,bwskwryalh,Боскореале,Բոսկորեալե,بوسکورئاله,ボスコレアーレ,博斯科雷亚莱,보스코레알레', 40.7727400, 14.4811800, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86304, 'Bosconero', 'Bosconero', 'Boschneir,Boschnèir,Bosconero,bosukonero,ボスコネーロ', 45.2663000, 7.7657800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86305, 'Bosco Marengo', 'Bosco Marengo', 'Bosch Marengh,Bosco Marengo,Bòsch Marengh,ボスコ・マレンゴ', 44.8237300, 8.6800800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86306, 'Bosco Chiesanuova', 'Bosco Chiesanuova', 'Bosco Chiesanuova', 45.6210300, 11.0322400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86307, 'Bosco', 'Bosco', '', 45.4433700, 11.7953000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86308, 'Bosco Mesola', 'Bosco Mesola', 'Bosco,Bosco Mesola,Bosco Mèsola', 44.8763900, 12.2313900, 'IT', '2015-04-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86309, 'Boschetto', 'Boschetto', '', 45.1659100, 10.0265600, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86310, 'Bosaro', 'Bosaro', 'Bosaro', 44.9987800, 11.7647100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86311, 'Bosa', 'Bosa', 'Bosa', 40.2992700, 8.4982700, 'IT', '2015-06-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86312, 'Borzonasca', 'Borzonasca', 'Borsonasca,Borzonasca', 44.4200200, 9.3885100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86313, 'Borzano', 'Borzano', '', 44.6036000, 10.6367500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86314, 'Borutta', 'Borutta', 'Borutta', 40.5223600, 8.7435200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86315, 'Bortigiadas', 'Bortigiadas', 'Bortigiadas', 40.8916700, 9.0435200, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86316, 'Bortigali', 'Bortigali', 'Bortigali', 40.2826800, 8.8394600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86317, 'Borso del Grappa', 'Borso del Grappa', 'Borso,Borso del Grappa', 45.8102500, 11.7736700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86318, 'Borriana', 'Borriana', 'Baryjana,Borian-a,Boriana,Borriana,bo li ya na,borriana,bwryana,Барыяна,Борриана,Борріана,Բորիանա,بوريانا,ボッリアーナ,博里亚纳', 45.5078100, 8.0386000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86319, 'Borrello', 'Borrello', 'Borrello', 41.9173000, 14.3053500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86320, 'Borore', 'Borore', 'Borore', 40.2157600, 8.8036500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86321, 'Boroneddu', 'Boroneddu', 'Boroneddu', 40.1126200, 8.8702300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86322, 'Borno', 'Borno', 'Borno,boruno,ボルノ', 45.9474800, 10.2024300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86323, 'Bornasco', 'Bornasco', 'Bornasco', 45.2665700, 9.2179500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86324, 'Bormio', 'Bormio', 'Aquae Bormiae,Bormio,Бормио', 46.4671700, 10.3700800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86325, 'Borgo Vercelli', 'Borgo Vercelli', 'Borgo Vercelli', 45.3568000, 8.4646000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86326, 'Borgo Velino', 'Borgo Velino', 'Borgo Velino', 42.4050800, 13.0565000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86327, 'Borgo Val di Taro', 'Borgo Val di Taro', 'Borgo Val di Taro,Borgotaro', 44.4889900, 9.7690600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86328, 'Borgo Tossignano', 'Borgo Tossignano', 'Borgo Tossignano,Borgo di Tossignano', 44.2823300, 11.5965900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86329, 'Borgo Ticino', 'Borgo Ticino', 'Borgo Ticino', 45.6893100, 8.6044800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86330, 'Borgosesia', 'Borgosesia', 'Borgosesia', 45.7204500, 8.2746600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86331, 'Borgosatollo', 'Borgosatollo', 'Borgosatollo,borugosatorro,ボルゴサトッロ', 45.4769000, 10.2403000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86332, 'Borgo Santa Maria', 'Borgo Santa Maria', '', 43.8758200, 12.8023500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86333, 'Borgo San Martino', 'Borgo San Martino', 'Borgo San Martino', 45.0925900, 8.5237300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86334, 'Borgo San Lorenzo', 'Borgo San Lorenzo', 'Borgo San Lorenzo', 43.9554800, 11.3856100, 'IT', '2014-01-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86335, 'Borgo San Giacomo', 'Borgo San Giacomo', 'Borgo San Giacomo,ボルゴ・サン・ジャーコモ', 45.3479800, 9.9681700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86336, 'Borgo San Dalmazzo', 'Borgo San Dalmazzo', 'Borgo San Dalmazzo', 44.3378500, 7.4931000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86337, 'Borgo Sabotino-Foce Verde', 'Borgo Sabotino-Foce Verde', '', 41.4166700, 12.8333300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86338, 'Borgorose', 'Borgorose', 'Borgocollefegato,Borgorose', 42.1907700, 13.2328200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86339, 'Borgoricco-San Michele delle Badesse-Sant''Eufemia', 'Borgoricco-San Michele delle Badesse-Sant''Eufemia', 'Borgoricco', 45.5352000, 11.9411100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86340, 'Borgoratto Mormorolo', 'Borgoratto Mormorolo', 'Borgoratto,Borgoratto Mormorolo', 44.9288900, 9.1940200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86341, 'Borgoratto Alessandrino', 'Borgoratto Alessandrino', 'Borgorat,Borgoratto Alessandrino', 44.8362500, 8.5385400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86342, 'Borgo Priolo', 'Borgo Priolo', 'Borgo Priolo', 44.9663200, 9.1483500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86343, 'Borgo Podgora', 'Borgo Podgora', 'Podgora', 41.5146200, 12.8538300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86344, 'Borgo Pace', 'Borgo Pace', 'Borgo Pace', 43.6580800, 12.2931700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86345, 'Borgonuovo', 'Borgonuovo', 'Borgo Nuovo,Borgonuova', 44.4355700, 11.2706900, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86346, 'Borgonovo Valtidone', 'Borgonovo Valtidone', 'Borgonovo Val Tidone', 45.0143600, 9.4434600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86347, 'Borgone Susa', 'Borgone Susa', 'Borgon,Borgone Susa,ボルゴーネ・スーザ', 45.1233400, 7.2364100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86348, 'Borgomasino', 'Borgomasino', 'Borghmasin,Borgomasino,borugomajino,ボルゴマジーノ', 45.3620500, 7.9881100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86349, 'Borgomaro', 'Borgomaro', 'Borgomaro', 43.9753000, 7.9440800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86350, 'Borgomanero', 'Borgomanero', 'Borgomanero', 45.6987300, 8.4623000, 'IT', '2017-06-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86351, 'Borgomale', 'Borgomale', 'Borgomale,Borgomale Priosa', 44.6203400, 8.1322400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86352, 'Borgolavezzaro', 'Borgolavezzaro', '', 45.3191800, 8.6993100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86353, 'Borgo Grappa', 'Borgo Grappa', '', 41.4021200, 12.9605300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86354, 'Borgofranco d''Ivrea', 'Borgofranco d''Ivrea', 'Borghfranch,Borgofranco,Borgofranco d''Ivrea,ボルゴフランコ・ディヴレーア', 45.5163600, 7.8586500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86355, 'Fosso Ghiaia', 'Fosso Ghiaia', '', 44.3552500, 12.2543000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86356, 'Borgoforte', 'Borgoforte', 'Borchfort,Borchfòrt,Borgoforte,bo er ge fu er tai,borugoforute,Боргофорте,Բորգոֆորտե,ボルゴフォルテ,博尔戈福尔泰', 45.0518500, 10.7501800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86357, 'Borgo di Terzo', 'Borgo di Terzo', 'Borgo di Terzo', 45.7207800, 9.8909600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86358, 'Borgo d''Ale', 'Borgo d''Ale', 'Borgo d''Ale', 45.3495800, 8.0519800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86359, 'Borgo a Mozzano', 'Borgo a Mozzano', 'Borgo a Mozzano', 43.9794600, 10.5448900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86360, 'Borgo a Buggiano', 'Borgo a Buggiano', 'Buggiano', 43.8752200, 10.7348200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86361, 'Borgo', 'Borgo', '', 46.0511900, 11.4575600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86362, 'Borgiallo', 'Borgiallo', 'Borgial,Borgiallo,borujarro,ボルジャッロ', 45.4175800, 7.6698400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86363, 'Borghi', 'Borghi', 'Borghi,borugi,ボルギ', 44.0322300, 12.3561800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86364, 'Borghetto Santo Spirito', 'Borghetto Santo Spirito', 'Borghetto Santo Spirito', 44.1118700, 8.2412900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86365, 'Borghetto Lodigiano', 'Borghetto Lodigiano', 'Borghetto Lodigiano,ボルゲット・ロディジャーノ', 45.2132600, 9.4994600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86366, 'Borghetto di Vara', 'Borghetto di Vara', 'Borghetto di Vara', 44.2236800, 9.7211800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86367, 'Borghetto d''Arroscia', 'Borghetto d''Arroscia', 'Borghettio d''Arroscia,Borghettio d''Arróscia,Borghetto,Borghetto d''Arroscia', 44.0567200, 7.9807600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86368, 'Borghetto', 'Borghetto', '', 43.5980000, 13.2920500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86369, 'Fornace Zarattini', 'Fornace Zarattini', 'Borgata Zarattini,Case Zaratini', 44.4166700, 12.1333300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86370, 'Borgaro Torinese', 'Borgaro Torinese', 'Borgaro Torinese,Borghi,ボルガロ・トリネーゼ', 45.1512200, 7.6554300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86371, 'Borgagne', 'Borgagne', '', 40.2410800, 18.3766100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86372, 'Boretto', 'Boretto', 'Boretto', 44.9015700, 10.5514700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86373, 'Borello', 'Borello', '', 44.0584600, 12.1799300, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86374, 'Bore', 'Bore', '', 44.7186600, 9.7920700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86375, 'Bordolano', 'Bordolano', 'Bordolano', 45.2917000, 9.9873100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86376, 'Bordighera', 'Bordighera', '', 43.7806400, 7.6645100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86377, 'Borca', 'Borca', 'Borca,Borca di Cadore', 46.4345200, 12.2223000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86378, 'Borbona', 'Borbona', 'Barbona,Borbona', 42.5093900, 13.1320600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86379, 'Bonorva', 'Bonorva', 'Bonorva', 40.4183900, 8.7683100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86380, 'Bono', 'Bono', 'Bono', 40.4138700, 9.0318700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86381, 'Bonnanaro', 'Bonnanaro', 'Bonnanaro', 40.5326500, 8.7638900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86382, 'Bonito', 'Bonito', 'Bonetus,Bonito,Bonitu,bo ni tuo,bonito,bwnytw  kampanya,Бонито,Боніто,Բոնիտո,بونیتو، کامپانیا,ボニート,博尼托,보니토', 41.0985700, 15.0007100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86383, 'Bonferraro', 'Bonferraro', '', 45.1838000, 11.0120100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86384, 'Bonefro', 'Bonefro', 'Bonefro', 41.7050700, 14.9343900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86385, 'Bonea', 'Bonea', 'Bonea', 41.0731200, 14.6168300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86386, 'Bondeno', 'Bondeno', '', 44.9356900, 10.8603500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86387, 'Bondeno', 'Bondeno', 'Bondeno', 44.8894400, 11.4154200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86388, 'Bonavigo', 'Bonavigo', 'Bonavigo,bonavu~igo,ボナヴィーゴ', 45.2583100, 11.2794400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86389, 'Bonavicina', 'Bonavicina', '', 45.2442600, 11.1841900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86390, 'Bonate Sopra', 'Bonate Sopra', 'Bonate Sopra', 45.6817900, 9.5595600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86391, 'Bonassola', 'Bonassola', 'Bonasseua,Bonassola', 44.1832300, 9.5842200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86392, 'Bonarcado', 'Bonarcado', 'Bonarcado,Bonàrcado', 40.0983600, 8.6553400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86393, 'Santo Stefano-Bonaldo', 'Santo Stefano-Bonaldo', '', 45.3671800, 11.3319900, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86394, 'Bomporto', 'Bomporto', 'Bomporto', 44.7338900, 11.0366700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86395, 'Bomba', 'Bomba', '', 42.0334300, 14.3665600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86396, 'Bomarzo', 'Bomarzo', 'Bomarco,Bomarzo,Bomarzu,Polymartium,bo ma er zuo,bomaleucho,bomarutsu~o,Бомарцо,Բոմարցո,ボマルツォ,博马尔佐,보마르초', 42.4827300, 12.2503700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86397, 'Bolzano Vicentino', 'Bolzano Vicentino', 'Bolzano Vicentino', 45.6022100, 11.6219800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86398, 'Bolzano Novarese', 'Bolzano Novarese', 'Bolzano Novarese', 45.7626600, 8.4424800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86399, 'Bolzano', 'Bolzano', 'BZO,Bal''cana,Bauzanum,Bocen,Bocenas,Boceno,Bol''cano,Bolcano,Bolcāno,Bolzan,Bolzano,Bolzanu,Bolzán,Bozen,Bozen-Bolzano,Bozn,Bulsaun,Buzzanu,Mpoltzano,bo er cha nuo,borutsu~ano,bwlznw,Μπολτζάνο,Бальцана,Болцано,Больцано,Боцен,בולצנו,ボルツァーノ,波尔查诺', 46.4906700, 11.3398200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86400, 'Bolsena', 'Bolsena', 'Bolsena,Bolsena jaerv,Bolsena järv,Bolsenas ezers,Bolsenasjoen,Bolsenasjön,Bolsēnas ezers,Lac de Bolsena,Lacus Volsiniensis,Lago Bolsena,Lago de Bolsena,Lago di Bolsena,Lagu di Bolsena,Lake Bolsena,Mar fan Bolsena,Ozero Bol''sena,Tasik Bolsena,bo sai na hu,borusena hu,Озеро Больсена,אגם בולסנה,ボルセーナ湖,博赛纳湖', 42.6432600, 11.9851400, 'IT', '2016-04-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86401, 'Bolotana', 'Bolotana', 'Bolotana', 40.3244000, 8.9610900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86402, 'Bolognola', 'Bolognola', 'Bolognola', 42.9931900, 13.2268000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86403, 'Bolognano', 'Bolognano', 'Bolognano', 42.2181400, 13.9601100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86404, 'Bologna', 'Bologna', 'BLQ,Baljon''ja,Bologna,Bologne,Bolon''ja,Bolona,Bolonha,Bolonia,Bolonija,Bolonja,Bolonjo,Bolonya,Boloņa,Boloňa,Bononia,Bulaggna,Bulogna,Bulåggna,bo luo ni ya,bollonya,boronya,bwlwnya,bwlwnyh,Балёнья,Болонья,Болоня,Болоња,בולוניה,بولونيا,ボローニャ,博洛尼亚,볼로냐', 44.4938100, 11.3387500, 'IT', '2016-12-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86405, 'Bollengo', 'Bollengo', 'Bolengh,Bollengo,borrengo,ボッレンゴ', 45.4716200, 7.9413300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86406, 'Bollate', 'Bollate', 'Bollate,borrate,ボッラーテ', 45.5464700, 9.1205400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86407, 'Bolano', 'Bolano', 'Bolan,Bolano', 44.1877000, 9.8948800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86408, 'Bojano', 'Bojano', 'Boiano,Bojano,boviani,Бояно,ბოვიანი', 41.4853000, 14.4707500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86409, 'Bogliasco', 'Bogliasco', 'Boggiasco,Bogliasco,Bogliasco Pieve', 44.3807000, 9.0692600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86410, 'Boffalora Sopra Ticino', 'Boffalora Sopra Ticino', 'Boffalora,Boffalora Ticino,Boffalora sopra Ticino,ボッファローラ・ソプラ・ティチーノ', 45.4673500, 8.8309500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86411, 'Boffalora d''Adda', 'Boffalora d''Adda', 'Boffalora d''Adda,ボッファローラ・ダッダ', 45.3585100, 9.4962800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86412, 'Bocenago', 'Bocenago', 'Bocenago,bochenago,ボチェナーゴ', 46.1185800, 10.7588400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86413, 'Boccioleto', 'Boccioleto', 'Boccioleto,botchoreto,ボッチョレート', 45.8304700, 8.1128200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86414, 'Bobbio Pellice', 'Bobbio Pellice', 'Beubi,Bobbio,Bobbio Pellice,ボッビオ・ペッリーチェ', 44.8085400, 7.1169100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86415, 'Bobbio', 'Bobbio', 'Bobbio,Bobi,Bobium,bo bi ao,bobbio,bwbyw,Боббио,Боббіо,بوبيو,بوبیو,ボッビオ,博比奥', 44.7683200, 9.3841500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86416, 'Darfo Boario Terme', 'Darfo Boario Terme', '', 45.8915000, 10.1887900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86417, 'Blera', 'Blera', 'Biede,Blera,Блера', 42.2729300, 12.0301600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86418, 'Bitti', 'Bitti', 'Bitti', 40.4795600, 9.3840300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86419, 'Bitritto', 'Bitritto', 'Bitritto,bitoritto,ビトリット', 41.0433600, 16.8268200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86420, 'Bitonto', 'Bitonto', 'Bitonto,bitonto,ビトント', 41.1100600, 16.6908600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86421, 'Bitetto', 'Bitetto', 'Bitetto,bitetto,ビテット', 41.0414600, 16.7480600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86422, 'Bistagno', 'Bistagno', 'Bistagn,Bistagno', 44.6605900, 8.3716300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86423, 'Bisenti', 'Bisenti', 'Bisenti', 42.5288300, 13.7995000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86424, 'Bisegna', 'Bisegna', 'Bisegna', 41.9211300, 13.7576000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86425, 'Bisceglie', 'Bisceglie', 'Bisceglie,Bishell''e,bisherie,Бишеллье,ビシェーリエ', 41.2426400, 16.5010400, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86426, 'Bisaccia', 'Bisaccia', 'Bisaccia,Nuova Bisaccia,Nuova Bisáccia', 41.0092300, 15.3769900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86427, 'Birori', 'Birori', 'Birori', 40.2659300, 8.8157000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86428, 'Bionaz', 'Bionaz', 'Bionaz', 45.8735600, 7.4231000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86429, 'Bioglio-Portula-Andrè', 'Bioglio-Portula-Andre', 'Bioglio', 45.6151600, 8.1360200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86430, 'Binasco', 'Binasco', 'Binasco,binasuko,ビナスコ', 45.3310200, 9.0944000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86431, 'Gabbioneta', 'Gabbioneta', '', 45.2162700, 10.2202700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86432, 'Bigolino', 'Bigolino', '', 45.8666900, 12.0169300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86433, 'Bientina', 'Bientina', 'Bientina', 43.7082600, 10.6211600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86434, 'Bienno', 'Bienno', 'Bienno,bien''no,ビエンノ', 45.9352600, 10.2923200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86435, 'Biella', 'Biella', 'B''ella,Biella,Bugella,bierra,Бьелла,ビエッラ', 45.5630400, 8.0579600, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86436, 'Bidonì', 'Bidoni', 'Bidoni,Bidonì', 40.1130500, 8.9364300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86437, 'Bicinicco', 'Bicinicco', 'Bicinicco,Bicinicco di Sotto,Bicinins', 45.9321100, 13.2530000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86438, 'Biccari', 'Biccari', 'Biccari', 41.3973600, 15.1964400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86439, 'Bibione', 'Bibione', 'Bibione,Бибионе', 45.6356500, 13.0361600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86440, 'Bibbona', 'Bibbona', 'Bibbona,bibbona,ビッボーナ', 43.2682200, 10.5951000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86441, 'Bibbiena', 'Bibbiena', '', 43.6987600, 11.8147400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86442, 'Bibbiano', 'Bibbiano', 'Bibbiano', 44.6629200, 10.4739100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86443, 'Bibano', 'Bibano', '', 45.9075100, 12.4326600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86444, 'Biassono', 'Biassono', 'Biassono,biassono,ビアッソーノ', 45.6286400, 9.2712400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86445, 'Bianzone', 'Bianzone', 'Bianzone', 46.1866500, 10.1093400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86446, 'Bianzè', 'Bianze', 'Bianse,Biansé,Bianze,Bianzè,biantsu~e,ビアンツェ', 45.3075100, 8.1220200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86447, 'Biandronno', 'Biandronno', 'Biandronno', 45.8128100, 8.7088200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86448, 'Biandrate', 'Biandrate', 'Biandrate', 45.4527100, 8.4640200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86449, 'Bevilacqua', 'Bevilacqua', 'Bevilacqua,bevu~irakkua,ベヴィラックア', 45.2324900, 11.3949600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86450, 'Bevagna', 'Bevagna', 'Bevagna', 42.9374800, 12.6148800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86451, 'Beura', 'Beura', 'Beura Cardezza,Beura-Cardezza,Béura Cardezza', 46.0796400, 8.2982600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86452, 'Bettona', 'Bettona', 'Betona,Bettona,Vettona,bei tuo na,betona,bettona,btwna,bytwna,Бетона,Беттона,Բետոնա,بتونا,بيتونا,ベットーナ,贝托纳,베토나', 43.0112400, 12.4869800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86453, 'Bettolle', 'Bettolle', 'Bettolle', 43.2067600, 11.8036500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86454, 'Bettola', 'Bettola', 'Bettola', 44.7782600, 9.6085700, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86455, 'Bessude', 'Bessude', 'Bessude', 40.5544900, 8.7275300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86456, 'Besozzo', 'Besozzo', 'Besozzo,Besozzo Inferiore,Besozzo Superiore', 45.8488900, 8.6651700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86457, 'Besnate', 'Besnate', 'Besnate', 45.6985800, 8.7673400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86458, 'Besenzone', 'Besenzone', 'Besenzone', 44.9868900, 9.9560400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86459, 'Besenello', 'Besenello', 'Besenello,bezenerro,ベゼネッロ', 45.9435600, 11.1090800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86460, 'Besate', 'Besate', 'Besate,bezate,ベザーテ', 45.3129600, 8.9696400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86461, 'Besano', 'Besano', 'Besan,Besano,Besano vald,Besanonum,Bezano,bei sa nuo,bezano,bsanw,byzanw,Безано,Բեզանո,بسانو,بيزانو,ベザーノ,贝萨诺', 45.8894900, 8.8906800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86462, 'Besana in Brianza', 'Besana in Brianza', 'Besana,Besana Brianza,Besana in Brianza,Besàna,ベザーナ・イン・ブリアンツァ', 45.7023500, 9.2947000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86463, 'Berzo Inferiore', 'Berzo Inferiore', 'Berzo Inferiore,Bezzo Inferiore,ベルツォ・インフェリオーレ', 45.9302700, 10.2769600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86464, 'Berzo', 'Berzo', 'Berzo Demo,ベルツォ・デーモ', 46.0928700, 10.3330300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86465, 'Berzano di San Pietro', 'Berzano di San Pietro', 'Bersan,Bersan San Pe,Bersan San Pè,Berzano San Pietro,Berzano di San Pietro', 45.0941800, 7.9535200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86466, 'Bertonico', 'Bertonico', 'Bertonico,berutoniko,ベルトーニコ', 45.2330700, 9.6680600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86467, 'Bertiolo', 'Bertiolo', 'Bertiolo,Bertiul', 45.9446300, 13.0560600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86468, 'Bertinoro', 'Bertinoro', 'Bartnora,Bartnòra,Bertinoro,berutinoro,ベルティノーロ', 44.1487400, 12.1365000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86469, 'Bersezio', 'Bersezio', '', 44.3803100, 6.9688500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86470, 'Berra', 'Berra', 'Berra,berra,ベッラ', 44.9765600, 11.9772700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86471, 'Bernate Ticino', 'Bernate Ticino', 'Bernate Ticino,ベルナーテ・ティチーノ', 45.4787300, 8.8183400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86472, 'Bernalda', 'Bernalda', 'Bernalda', 40.4126100, 16.6891900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86473, 'Berlingo', 'Berlingo', 'Berlingo,beruringo,ベルリンゴ', 45.5028100, 10.0343600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86474, 'Bergeggi', 'Bergeggi', '', 44.2483300, 8.4440200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86475, 'Bergantino', 'Bergantino', 'Bergantino', 45.0614500, 11.2523700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86476, 'Bergamo', 'Bergamo', 'Bergam,Bergame,Bergamo,Berghem,Bergomum,Bèrgam,Bèrghem,Bérgamo,Bérghem,bei er jia mo,bergamo,berugamo,byrghamw,Бергамо,بيرغامو,बेर्गमो,ベルガモ,贝尔加莫', 45.6960100, 9.6672100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86477, 'Bereguardo', 'Bereguardo', 'Bereguardo', 45.2570600, 9.0273500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86478, 'Berchidda', 'Berchidda', 'Berchidda', 40.7847600, 9.1651000, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86479, 'Berceto', 'Berceto', '', 44.5089900, 9.9910400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86480, 'Berbenno di Valtellina', 'Berbenno di Valtellina', 'Berbenno,Berbenno Valtellina,Berbenno di Valtellina', 46.1664100, 9.7473400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86481, 'Bentivoglio', 'Bentivoglio', 'BQY,Bentivoglio', 44.6369000, 11.4173700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86482, 'Benna', 'Benna', 'Benna,ben''na,ベンナ', 45.5152800, 8.1240900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86483, 'Benevento', 'Benevento', 'Benevent,Benevento,Beneventum,Beneviento,Benewent,Bénévent,QBV,benevu~ento,Беневенто,ბენევენტო,ベネヴェント', 41.1307000, 14.7781600, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86484, 'Benevello', 'Benevello', 'Benevello', 44.6298100, 8.1050700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86485, 'Bene Vagienna', 'Bene Vagienna', 'Bene Vagienna', 44.5426800, 7.8272600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86486, 'Benetutti', 'Benetutti', 'Benetutti', 40.4568900, 9.1675400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86487, 'Belvedere Ostrense', 'Belvedere Ostrense', 'Belvedere Ostrense,ベルヴェデーレ・オストレンセ', 43.5789600, 13.1672400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86488, 'Belvedere Langhe', 'Belvedere Langhe', 'Belvedere Langhe', 44.4936100, 7.9738700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86489, 'Beltiglio-San Giovanni', 'Beltiglio-San Giovanni', 'Beltiglio,Beltiglio di Ceppaloni', 41.0623900, 14.7527300, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86490, 'Belmonte Piceno', 'Belmonte Piceno', 'Belmonte Piceno,ベルモンテ・ピチェーノ', 43.0917500, 13.5393800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86491, 'Belmonte in Sabina', 'Belmonte in Sabina', 'Belmonte in Sabina', 42.3148200, 12.8917800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86492, 'Belmonte del Sannio', 'Belmonte del Sannio', 'Belmonte del Sannio', 41.8235200, 14.4233300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86493, 'Belmonte Castello', 'Belmonte Castello', 'Belmonte Castello', 41.5774200, 13.8158100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86494, 'Belluno', 'Belluno', 'BLX,Bellune,Belluno,Bellunum,Belun,berruno,Беллуно,ベッルーノ', 46.1426200, 12.2156000, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86495, 'Bellosguardo', 'Bellosguardo', 'Bellosguardo', 40.4222200, 15.3121900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86496, 'Bellona', 'Bellona', 'Bellona', 41.1605200, 14.2331300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86497, 'Bellocchi', 'Bellocchi', '', 43.7956400, 13.0056500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86498, 'Bellinzago Novarese', 'Bellinzago Novarese', 'Bellinzago,Bellinzago Novarese', 45.5687700, 8.6432300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86499, 'Bellegra', 'Bellegra', 'Bellegra,berregura,ベッレグラ', 41.8816600, 13.0286100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86500, 'Bellante', 'Bellante', 'Bellante', 42.7442100, 13.8023400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86501, 'Bellano', 'Bellano', 'Bellano', 46.0442600, 9.3073400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86502, 'Bellagio', 'Bellagio', 'Beladzho,Belajo,Belladzhio,Belladzho,Bellagio,Bellagiu,Bellas,Bellasium,bei la jiao,bel la co,bellajo,berrajo,blajw,Беладжо,Белађо,Белладжио,Белладжо,Բելաջո,בלאגו,بلاجو,เบลลาโจ,ベッラージョ,贝拉焦,벨라조', 45.9877200, 9.2618200, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86503, 'Bella Farnia', 'Bella Farnia', '', 41.3678000, 12.9760200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86504, 'Bella', 'Bella', 'Bella,berra,ベッラ', 40.7605900, 15.5410100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86505, 'Belgirate', 'Belgirate', 'Belgirate', 45.8412300, 8.5706400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86506, 'Belgioioso', 'Belgioioso', 'Belgioioso', 45.1593300, 9.3134700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86507, 'Belforte del Chienti', 'Belforte del Chienti', 'Belforte,Belforte sul Chienti', 43.1642600, 13.2432300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86508, 'Belforte', 'Belforte', 'Belforte all''Isauro', 43.7167600, 12.3757500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86509, 'Belfiore', 'Belfiore', 'Belfiore,berufiore,ベルフィオーレ', 45.3818900, 11.2108500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86510, 'Beinette', 'Beinette', 'Beinette,beinette,ベイネッテ', 44.3639400, 7.6446400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86511, 'Beinasco', 'Beinasco', 'Beinasch,Beinasco,beinasuko,ベイナスコ', 45.0247200, 7.5856400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86512, 'Begliano', 'Begliano', '', 45.8198400, 13.4658600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86513, 'Bedonia', 'Bedonia', 'Bedonia', 44.5040000, 9.6348900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86514, 'Bazzano', 'Bazzano', 'Bazzano', 44.5017600, 11.0867500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86515, 'Progetto Case Bazzano', 'Progetto Case Bazzano', '', 42.3364300, 13.4441000, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86516, 'Baveno', 'Baveno', 'Baveno', 45.9081800, 8.5003300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86517, 'Baunei', 'Baunei', 'Baunei', 40.0313200, 9.6637400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86518, 'Bauladu', 'Bauladu', 'Bauladu', 40.0205500, 8.6719200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86519, 'Battipaglia', 'Battipaglia', 'Battipaglia', 40.6086100, 14.9820900, 'IT', '2015-08-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86520, 'Battaglia Terme', 'Battaglia Terme', 'Battaglia,Battaglia Terme', 45.2853100, 11.7837500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86521, 'Bastiglia', 'Bastiglia', 'Bastiglia,basutiria,バスティリア', 44.7269700, 10.9986000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86522, 'Bastida de'' Dossi', 'Bastida de'' Dossi', 'Bastida de'' Dossi,Bastida de''Dossi,Bastida dei Dossi', 45.0397600, 8.9215500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86523, 'Bastia umbra', 'Bastia umbra', '', 43.0642500, 12.5461200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86524, 'Bassignana', 'Bassignana', 'Bassignana', 45.0011000, 8.7329100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86525, 'Bassiano', 'Bassiano', 'Bassiano,basshiano,バッシアーノ', 41.5515400, 13.0273200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86526, 'Bassano Romano', 'Bassano Romano', 'Bassano Romano,Bassano di Sutri,バッサーノ・ロマーノ', 42.2222800, 12.1878500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86527, 'Bassano in Teverina', 'Bassano in Teverina', 'Bassano in Teverina', 42.4644400, 12.3075200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86528, 'Bassano del Grappa', 'Bassano del Grappa', 'Basan,Basano del Grapa,Bassano,Bassano-del''-Grappa,Bassianus,basanw dl ghraba,Басано дел Грапа,Бассано-дель-Граппа,باسانو دل غرابا,バッサーノ・デル・グラッパ', 45.7665600, 11.7273900, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86529, 'Bassano Bresciano', 'Bassano Bresciano', 'Bassano Bresciano,バッサーノ・ブレシャーノ', 45.3282700, 10.1286900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86530, 'Basilicanova', 'Basilicanova', 'Basilicano,Basilicanova', 44.6980400, 10.3523100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86531, 'Basiliano', 'Basiliano', 'Basilian,Basiliano', 46.0141700, 13.0700000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86532, 'Baselice', 'Baselice', 'Baselice', 41.3929600, 14.9736300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86533, 'Baselga di Pinè', 'Baselga di Pine', 'Baselga,Baselga di Pine,Baselga di Pinè,バゼルガ・ディ・ピネ', 46.1325000, 11.2464800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86534, 'Basciano', 'Basciano', 'Basciano', 42.5963900, 13.7356100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86535, 'Baschi', 'Baschi', 'Baschi,Baski,Castrum Baschi,baseuki,basky,basuki,Баски,Баскі,Բասկի,باسكي,バスキ,바스키', 42.6732400, 12.2176200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86536, 'Bascapè', 'Bascape', 'Bascape,Bascapè,Baskape,Баскапе', 45.3059800, 9.3139700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86537, 'Barzanò', 'Barzano', 'Barzano,Barzanò', 45.7325700, 9.3136000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86538, 'Barzana', 'Barzana', 'Barzana', 45.7334000, 9.5684200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86539, 'Giacciano con Baruchella', 'Giacciano con Baruchella', '', 45.0671800, 11.4504000, 'IT', '2012-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86540, 'Barrea', 'Barrea', 'Barrea', 41.7554300, 13.9909500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86541, 'Baronissi', 'Baronissi', 'Baronissi', 40.7481700, 14.7738000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86542, 'Barni', 'Barni', 'Barni', 45.9111100, 9.2659200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86543, 'Barletta', 'Barletta', 'Barletta,baruretta,Барлетта,バルレッタ', 41.3142900, 16.2816500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86544, 'Barlassina', 'Barlassina', 'Barlassina,barurasshina,バルラッシーナ', 45.6555800, 9.1287800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86545, 'Barisciano', 'Barisciano', 'Barisciano', 42.3246500, 13.5903600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86546, 'Barile', 'Barile', 'Barile,Barilli', 40.9432700, 15.6716700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86547, 'Baricella', 'Baricella', 'Baricella,Barichela,Barichella,Barisella,ba li qie la,baricherra,barysla,barytshla,Баричела,Баричелла,Բարիչելլա,باريتشلا,باریسلا,バリチェッラ,巴里切拉', 44.6482000, 11.5380000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86548, 'Bari', 'Bari', 'BRI,Bari,Baris,Barium,Bary,Mpari,ba li,bali,bari,bary,Μπάρι,Μπαρι,Бари,Барі,בארי,باري,باری,बरि,बारी,বারি,ბარი,バーリ,巴里,바리', 41.1114800, 16.8554000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86549, 'Barghe', 'Barghe', 'Barghe,baruge,バルゲ', 45.6783300, 10.4077500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86550, 'Barge', 'Barge', 'Barge', 44.7278600, 7.3228300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86551, 'Bargagli', 'Bargagli', 'Bargaggi,Bargagli', 44.4475000, 9.0937200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86552, 'Barga', 'Barga', 'Barga', 44.0731000, 10.4778900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86553, 'Barete', 'Barete', 'Barete', 42.4500900, 13.2806100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86554, 'Bareggio', 'Bareggio', 'Bareggio,barejjo,バレッジョ', 45.4792700, 8.9978900, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86555, 'Bardonecchia', 'Bardonecchia', 'Bardonecchia,Bardoneche,Bardonecia,Bardonèche,barudonekkia,バルドネッキア', 45.0746200, 6.6988800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86556, 'Bardolino', 'Bardolino', 'Bardolino,barudorino,バルドリーノ', 45.5411400, 10.7329800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86557, 'Bardineto', 'Bardineto', 'Bardineto,Berdenei,Berdënei', 44.1897200, 8.1352900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86558, 'Bardi', 'Bardi', 'Bardi', 44.6313800, 9.7290700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86559, 'Bard', 'Bard', 'Bard', 45.6093600, 7.7449100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86560, 'Barco', 'Barco', '', 44.6883300, 10.4958200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86561, 'Barcis', 'Barcis', 'Barcis', 46.1907100, 12.5606800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86562, 'Barbona', 'Barbona', 'Barbona', 45.1033900, 11.7048600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86563, 'Barbianello', 'Barbianello', 'Barbianello', 45.0757100, 9.2060200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86564, 'Barberino Val d''Elsa', 'Barberino Val d''Elsa', 'Barberino Val d''Elsa', 43.5398700, 11.1717800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86565, 'Barberino di Mugello', 'Barberino di Mugello', 'Barberino,Barberino di Mugello', 43.9993000, 11.2367600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86566, 'Barbarasco', 'Barbarasco', '', 44.2415000, 9.9457100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86567, 'Barbarano Vicentino', 'Barbarano Vicentino', 'Barbarano Vicentino,バルバラーノ・ヴィチェンティーノ', 45.4091200, 11.5434200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86568, 'Barbarano Romano', 'Barbarano Romano', 'Barbarano Romano', 42.2490800, 12.0677400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86569, 'Barbania', 'Barbania', 'Barbania,Barbanià,barubania,バルバニーア', 45.2914300, 7.6345000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86570, 'Baranzate', 'Baranzate', 'Baranzate,baranzate,バランザーテ', 45.5271700, 9.1172400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86571, 'Barano d''Ischia', 'Barano d''Ischia', 'Barano,Barano d''Ischia,バラーノ・ディスキア', 40.7147200, 13.9252200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86572, 'Baranello', 'Baranello', 'Baranello', 41.5272200, 14.5580000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86573, 'Baragiano', 'Baragiano', 'Baragiano', 40.6800100, 15.5939800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86574, 'Baone', 'Baone', 'Baone', 45.2417400, 11.6846300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86575, 'Banzi', 'Banzi', '', 40.8606300, 16.0097600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86576, 'Banari', 'Banari', 'Banari', 40.5705600, 8.7005200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86577, 'Balzola', 'Balzola', 'Balzola', 45.1835800, 8.4027700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86578, 'Balzo', 'Balzo', '', 42.8419900, 13.3323400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86579, 'Balvano', 'Balvano', 'Balvano', 40.6495300, 15.5134500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86580, 'Balsorano Nuovo', 'Balsorano Nuovo', 'Balsorano,Balsorano Nuovo', 41.8088100, 13.5606900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86581, 'Balocco', 'Balocco', 'Balocco,barokko,バロッコ', 45.4558900, 8.2806800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86582, 'Balmuccia', 'Balmuccia', 'Balmuccia,barumutchia,バルムッチア', 45.8187800, 8.1408000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86583, 'Balme', 'Balme', 'Balme', 45.3019200, 7.2193700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86584, 'Ballabio', 'Ballabio', 'Ballabio,Ballabio Inferiore,Ballabio Superiore', 45.8962900, 9.4229400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86585, 'Balestrino', 'Balestrino', 'Balestrino,Barestin', 44.1242600, 8.1706400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86586, 'Baldissero Torinese', 'Baldissero Torinese', 'Baldissero Torinese,Baudse,Baudsé,バルディッセーロ・トリネーゼ', 45.0683700, 7.8127400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86587, 'Baldichieri d''Asti', 'Baldichieri d''Asti', 'Baldichieri d''Asti,Baodiche,Baodichè,Baodiché', 44.9059500, 8.0916300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86588, 'Balangero', 'Balangero', 'Balange,Balangero,Balangé,baranjero,バランジェーロ', 45.2698800, 7.5188400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86589, 'Baiso', 'Baiso', 'Baiso', 44.4966800, 10.6008300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86590, 'Baiano', 'Baiano', '', 40.9514200, 14.6165000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86591, 'Baia', 'Baia', '', 41.3036600, 14.2501600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86592, 'Bagolino', 'Bagolino', 'Bagolino,Bagolinum,Baguli,Bagulì,ba ge li nuo,bagorino,Баголино,Баголіно,Բագոլինո,バゴリーノ,巴戈利诺', 45.8251900, 10.4618300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86593, 'Bagno Roselle', 'Bagno Roselle', 'Terme di Roselle', 42.8111400, 11.1385900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86594, 'Bagnoregio', 'Bagnoregio', 'Bagnoregio,Bagnoregiu,Balneoregium,Ban''oredzhio,Ban''oredzho,Banyorejo,ba ni ao lei jiao,banyolejo,banyorejo,Баньореджио,Баньореджо,Бањоређо,Բանյորեջո,バニョレージョ,巴尼奥雷焦,바뇨레조', 42.6284500, 12.0896900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86595, 'Bagnone', 'Bagnone', 'Bagnone,banyone,バニョーネ', 44.3149400, 9.9950700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86596, 'Bagnolo San Vito', 'Bagnolo San Vito', 'Bagnolo San Vito,バニョーロ・サン・ヴィート', 45.0889200, 10.8774700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86597, 'Bagnolo Piemonte', 'Bagnolo Piemonte', 'Bagnolo,Bagnolo Piemonte', 44.7603400, 7.3139200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86598, 'Bagnolo Mella', 'Bagnolo Mella', 'Bagnolo Mella,バニョーロ・メッラ', 45.4276500, 10.1863800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86599, 'Bagnolo in Piano', 'Bagnolo in Piano', 'Bagnolo,Bagnolo in Piano', 44.7643700, 10.6735800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86600, 'Bagnolo del Salento', 'Bagnolo del Salento', 'Bagnolo,Bagnolo del Salenio,Bagnolo del Salento', 40.1490800, 18.3520800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86601, 'Bagnolo Cremasco', 'Bagnolo Cremasco', 'Bagnolo Cremasco', 45.3611700, 9.6129600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86602, 'Bagnolo', 'Bagnolo', '', 45.2723800, 10.8908100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86603, 'Bagnoli Irpino', 'Bagnoli Irpino', 'Bagnoli Irpino', 40.8310300, 15.0717300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86604, 'Bagnoli di Sopra', 'Bagnoli di Sopra', 'Bagnoli,Bagnoli di Sopra', 45.1866700, 11.8843300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86605, 'Bagnoli del Trigno', 'Bagnoli del Trigno', 'Bagnoli del Trigno', 41.7021700, 14.4586100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86606, 'Bagnoli', 'Bagnoli', 'Ban''oli,Баньоли', 40.8132200, 14.1680700, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86607, 'Bagno a Ripoli', 'Bagno a Ripoli', 'Bagno a Ripoli,バーニョ・ア・リーポリ', 43.7511500, 11.3225200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86608, 'Bagni di Tivoli', 'Bagni di Tivoli', 'Acque Albule,Acque Albule Bagni,Bagni,Bagni Acque Albule,Bagni Albule,Bagni di Tivoli', 41.9500000, 12.7166700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86609, 'Rabbi Fonti', 'Rabbi Fonti', '', 46.3988600, 10.8495100, 'IT', '2012-12-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86610, 'Bagni di Lucca', 'Bagni di Lucca', 'Bagni di Lucca,バーニ・ディ・ルッカ', 44.0051300, 10.5531000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86611, 'Bagnasco', 'Bagnasco', 'Bagnasco', 44.3041200, 8.0452200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86612, 'Bagnarola', 'Bagnarola', '', 45.8669000, 12.8588600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86613, 'Bagnara di Romagna', 'Bagnara di Romagna', 'Bagnara ''e Rumagna,Bagnara di Romagna,バニャーラ・ディ・ロマーニャ', 44.3893000, 11.8272600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86614, 'Bagnacavallo', 'Bagnacavallo', 'Bagnacavallo,banyakavu~arro,バニャカヴァッロ', 44.4140200, 11.9781300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86615, 'Badia Tedalda', 'Badia Tedalda', 'Badia Tebalda,Badia Tedalda', 43.7088700, 12.1842500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86616, 'Badia Polesine', 'Badia Polesine', 'Badia Polesine', 45.0950800, 11.4944300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86617, 'Badia Pavese', 'Badia Pavese', 'Badia Pavese', 45.1208700, 9.4686600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86618, 'Badia Calavena', 'Badia Calavena', 'Badia Calavena,バディーア・カラヴェーナ', 45.5646300, 11.1519700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86619, 'Badia', 'Badia', 'Abbatia Ladinorum,Abtei,Abtei-Badia,Badia,Badija,ba di ya,badia,Бадия,Бадія,バディーア,巴迪亚', 46.6081600, 11.8963000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86620, 'Badesi', 'Badesi', 'Badesi', 40.9646000, 8.8823500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86621, 'Badalucco', 'Badalucco', 'Badalucco,Baeuco,Bäuco', 43.9168300, 7.8458400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86622, 'Bacoli', 'Bacoli', 'Bacoli,Bauli,bakori,バーコリ', 40.7967200, 14.0734900, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86623, 'Baceno', 'Baceno', 'Baceno', 46.2606200, 8.3187400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86624, 'Azzone', 'Azzone', 'Azzone', 45.9790300, 10.1128400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86625, 'Azzate', 'Azzate', 'Azzate', 45.7780300, 8.7941400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86626, 'Azzano Decimo', 'Azzano Decimo', 'Azzan,Azzano Decimo', 45.9093700, 12.6642000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86627, 'Azzanello', 'Azzanello', 'Azzanello', 45.3131200, 9.9197300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86628, 'Azeglio', 'Azeglio', 'Azeglio,azerrio,アゼッリオ', 45.4228300, 7.9922200, 'IT', '2015-05-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86629, 'Aymavilles', 'Aymavilles', 'Aymaville,Aymavilles', 45.7013000, 7.2468300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86630, 'Avio', 'Avio', 'Avio,avu~io,アーヴィオ', 45.7339600, 10.9393800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86631, 'Avigliano Umbro', 'Avigliano Umbro', 'Avigliano', 42.6530300, 12.4257100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86632, 'Avigliano', 'Avigliano', 'Avigliano,Avigliano Lucana', 40.7329100, 15.7200400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86633, 'Avigliana', 'Avigliana', 'Avigliana,Vian-a,avu~iriana,アヴィリアーナ', 45.0797800, 7.3964700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86634, 'Aviano', 'Aviano', 'AVB,Aviano', 46.0705600, 12.5947200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86635, 'Avezzano', 'Avezzano', 'Aveccano,Avezzano,Авеццано', 42.0289600, 13.4264100, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86636, 'Avetrana', 'Avetrana', 'Avetrana', 40.3507000, 17.7326000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86637, 'Aversa', 'Aversa', 'Aversa,Averza,avu~erusa,Аверса,アヴェルサ', 40.9725900, 14.2074500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86638, 'Averara', 'Averara', 'Averara', 45.9884700, 9.6316000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86639, 'Avellino', 'Avellino', 'Abellinum,Avellino,QVN,avu~errino,Авеллино,アヴェッリーノ', 40.9149400, 14.7910300, 'IT', '2015-08-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86640, 'Avella', 'Avella', 'Avella', 40.9599500, 14.6008700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86641, 'Avelengo', 'Avelengo', 'Avelenga,Avelengo,Hafling,Haflinga,a wei lun ge,avu~erengo,Авеленга,Авеленго,Ավելենգո,アヴェレンゴ,阿韦伦戈', 46.6455700, 11.2241900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86642, 'Austis', 'Austis', 'Austis', 40.0712200, 9.0887800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86643, 'Ausonia', 'Ausonia', 'Ausona Nova,Ausonia,Auzonia,Auzonija,ao suo ni ya,ausonia,auzonia,Аузония,Аузонија,Аузонія,Աուզոնիա,アウゾーニア,奥索尼亚,아우소니아', 41.3580800, 13.7498300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86644, 'Auronzo', 'Auronzo', 'Auronzo,Auronzo di Cadore', 46.5592000, 12.4245600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86645, 'Aurisina', 'Aurisina', 'Aurisina,Duino-Aurisina,Nabrazina,Nabražina,Nabresina,Nabrezina,Nabrežina,do~uino=aurijina,Аурисина,ドゥイーノ＝アウリジーナ', 45.7496800, 13.6734500, 'IT', '2016-07-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86646, 'Aurigo', 'Aurigo', 'Aorigo,Aurigo', 43.9828100, 7.9234200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86647, 'Aurelia', 'Aurelia', '', 42.1391000, 11.7871300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86648, 'Aulla', 'Aulla', 'Aulla,aurra,アウッラ', 44.2063200, 9.9785300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86649, 'Auletta', 'Auletta', 'Auletta', 40.5611600, 15.4231300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86650, 'Auditore', 'Auditore', 'Auditore', 43.8212400, 12.5716500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86651, 'Attimis', 'Attimis', 'Atimis,Attimis,Datimis', 46.1902200, 13.3112700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86652, 'Attigliano', 'Attigliano', 'Attigliano', 42.5150500, 12.2945500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86653, 'Atripalda', 'Atripalda', 'Atripalda', 40.9186700, 14.8272100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86654, 'Atri', 'Atri', 'Atri', 42.5764200, 13.9889900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86655, 'Atrani', 'Atrani', 'Atrani,Атрани', 40.6361700, 14.6093300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86656, 'Atina', 'Atina', 'Atina', 41.6200400, 13.7990500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86657, 'Atessa', 'Atessa', 'Atessa', 42.0701800, 14.4504900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86658, 'Atena Lucana', 'Atena Lucana', 'Atena,Atena Lucana,Atena Lucano', 40.4546400, 15.5563300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86659, 'Atella', 'Atella', 'Atella', 40.8785500, 15.6522600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86660, 'Ateleta', 'Ateleta', 'Ateleta', 41.8543500, 14.1980600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86661, 'Asti', 'Asti', 'Ast,Asti,Hasta Pompeia,asuti,Асти,アスティ', 44.9016200, 8.2075100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86662, 'Asso', 'Asso', '', 45.8606100, 9.2673000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86663, 'Assisi', 'Assisi', 'Asis,Asis - Assisi,Asisium,Asizi,Asizo,Assis,Assise,Assisi,Assizi,Asyz,Asyż,Asís,Asís - Assisi,asshiji,Асизи,Ассизи,אסיזי,アッシジ', 43.0667100, 12.6210900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86664, 'Asolo', 'Asolo', 'Asolo', 45.7885400, 11.9170100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86665, 'Asola', 'Asola', 'Ansula,Asola', 45.2201800, 10.4121400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86666, 'Asiago', 'Asiago', 'Asiago,ajiago,アジアーゴ', 45.8758800, 11.5122300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86667, 'Ascrea', 'Ascrea', 'Ascrea', 42.1976300, 12.9945700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86668, 'Ascoli Satriano', 'Ascoli Satriano', 'Ascoli Satriano', 41.2036500, 15.5664600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86669, 'Ascoli Piceno', 'Ascoli Piceno', 'Ascoli,Ascoli Piceno,Askoli Picheno,Askoli-Picheno,QNO,Асколи Пичено,Асколи-Пичено,アスコリ・ピチェーノ', 42.8535100, 13.5739500, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86670, 'Asciano', 'Asciano', 'Asano,Aschiano,Asciano,Ascianu,Ascianum,Ashano,a xia nuo,ashano,asiano,Асчиано,Ашано,Աշանո,アシャーノ,阿夏诺,아시아노', 43.2323200, 11.5665500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86671, 'Ascea', 'Ascea', 'Ascea', 40.1408200, 15.1858300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86672, 'Arzignano', 'Arzignano', 'Arcin''jano,Arzignano,Арциньяно', 45.5202700, 11.3344600, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86673, 'Arzergrande', 'Arzergrande', 'Arzergrande', 45.2727800, 12.0484000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86674, 'Arzene', 'Arzene', 'Arzene,Darzin', 45.9996500, 12.8503400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86675, 'Arzano', 'Arzano', 'Arzano,arutsu~ano,アルツァーノ', 40.9095900, 14.2651900, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86676, 'Arzachena', 'Arzachena', 'Arzachena,Santa Maria d''Arsachena', 41.0762000, 9.3905500, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86677, 'Arvier', 'Arvier', 'Arvie,Arvier,Arviè', 45.7020500, 7.1626700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86678, 'Artogne', 'Artogne', 'Artogne,arutonye,アルトーニェ', 45.8543700, 10.1664600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86679, 'Artena', 'Artena', 'Artena,arutena,アルテーナ', 41.7412600, 12.9066700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86680, 'Artegna', 'Artegna', 'Artegna,Dartigne', 46.2392900, 13.1539900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86681, 'Arta Terme', 'Arta Terme', 'Arta,Arta Terme,Darte', 46.4802100, 13.0204000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86682, 'Arsoli', 'Arsoli', 'Arsoli,arusori,アルソリ', 42.0415800, 13.0160600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86683, 'Arsita', 'Arsita', 'Arsita', 42.5026600, 13.7851600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86684, 'Arsiero', 'Arsiero', 'Arsiero', 45.8042200, 11.3558200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86685, 'Arsiè', 'Arsie', 'Arsie,Arsiè', 45.9821100, 11.7579400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86686, 'Arsago Seprio', 'Arsago Seprio', 'Arsago,Arsago Seprio', 45.6876400, 8.7350900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86687, 'Arrone', 'Arrone', 'Arone,Arro,Arrone,Arruni,a luo nei,alone,arrone,arwny,Ароне,Арроне,Արոնե,أروني,アッローネ,阿罗内,아로네', 42.5826600, 12.7671400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86688, 'Arre', 'Arre', 'Ara,Are,Arre,arre,Аре,Арре,Արե,アッレ', 45.2174800, 11.9285800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86689, 'Arquata Scrivia', 'Arquata Scrivia', 'Arquata,Arquata Scrivia,Arquata Serivia', 44.6883000, 8.8868200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86690, 'Arquata del Tronto', 'Arquata del Tronto', 'Arquata del Tronto,アルクアータ・デル・トロント', 42.7717000, 13.2938900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86691, 'Arquà Petrarca', 'Arqua Petrarca', 'Arkua Petrarka,Arkua-Petrarka,Arkva Petrarka,Arqua,Arqua Petrarca,Arquata,Arquà Petrarca,a er ku a pei te la er ka,Арква Петрарка,Аркуа-Петрарка,Արկուա Պետրարկա,アルクァ・ペトラルカ,阿尔库阿佩特拉尔卡', 45.2691100, 11.7204500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86692, 'Arpino', 'Arpino', 'Arpino,ארפינו', 41.6470500, 13.6115500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86693, 'Arpaise', 'Arpaise', 'Arpaise', 41.0297700, 14.7438700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86694, 'Arpaia', 'Arpaia', 'Arpaia', 41.0367800, 14.5517500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86695, 'Arosio', 'Arosio', 'Arosio', 45.7193300, 9.2081600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86696, 'Arona', 'Arona', 'Arona,Арона', 45.7589000, 8.5571500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86697, 'Arola', 'Arola', 'Arola', 45.8086700, 8.3580800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86698, 'Arola-Preazzano', 'Arola-Preazzano', '', 40.6333300, 14.4333300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86699, 'Arnesano', 'Arnesano', 'Arnesano,Arnesanu', 40.3367900, 18.0914500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86700, 'Arnara', 'Arnara', 'Arnara', 41.5845200, 13.3884000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86701, 'Armento', 'Armento', 'Armento', 40.3066000, 16.0655000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86702, 'Armeno', 'Armeno', 'Armeno', 45.8207800, 8.4455700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86703, 'Arluno', 'Arluno', 'Arluno,aruruno,アルルーノ', 45.5034400, 8.9422200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86704, 'Arlena di Castro', 'Arlena di Castro', 'Arlena di Castro', 42.4655900, 11.8209000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86705, 'Arignano', 'Arignano', 'Argnan,Arignano,arinyano,アリニャーノ', 45.0396600, 7.9018900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86706, 'Arienzo', 'Arienzo', 'Arienzo San Felice', 41.0273400, 14.4977000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86707, 'Arielli', 'Arielli', 'Arielli', 42.2600300, 14.3100400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86708, 'Ariccia', 'Ariccia', 'Ariccia,Aricia,aritcha,アリッチャ', 41.7206300, 12.6723000, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86709, 'Ariano', 'Ariano', 'Ariano Polesine,Ariano Polesino,Ariano Polésino,Ariano nel Polesine', 44.9460400, 12.1244800, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86710, 'Ariano Irpino-Martiri', 'Ariano Irpino-Martiri', 'Ariano Irpino,Ariano di Puglia', 41.1602400, 15.1062500, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86711, 'Ari', 'Ari', 'Ari,ari,アーリ', 42.2896700, 14.2585600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86712, 'Argenta', 'Argenta', 'Ardzhenta,Argenta,Argentea,Arjenta,a er zhen ta,argnta,arjnta,arujenta,Аргента,Арджента,Арђента,Արջենտա,آرگنتا,أرجنتا,アルジェンタ,阿尔真塔', 44.6139700, 11.8354700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86713, 'Argelato', 'Argelato', 'Argelato', 44.6400900, 11.3435900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86714, 'Argegno', 'Argegno', 'Argegno', 45.9421800, 9.1263500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86715, 'Arezzo', 'Arezzo', 'Arecco,Arezzo,Ареццо', 43.4627600, 11.8806800, 'IT', '2015-08-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86716, 'Arese', 'Arese', 'Arese,areze,アレーゼ', 45.5504800, 9.0774100, 'IT', '2015-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86717, 'Arenzano', 'Arenzano', 'Arensen,Arenzano', 44.4052100, 8.6831500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86718, 'Arena Po', 'Arena Po', 'Arena Po', 45.0942700, 9.3631200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86719, 'Ardesio', 'Ardesio', 'Ardesio', 45.9361300, 9.9295000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86720, 'Ardenno', 'Ardenno', 'Ardenno', 46.1671400, 9.6472900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86721, 'Ardea', 'Ardea', 'Ardea,Ardea i Italia,Ardeja,Ardėja,a er dai ya,aleudea,ardya,arudea,Ардеа,Ардея,Արդեա,آردئا,آردیا، اٹلی,أرديا,アルデーア,阿尔代亚,아르데아', 41.6074200, 12.5415800, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86722, 'Ardauli', 'Ardauli', 'Ardauli', 40.0843600, 8.9122800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86723, 'Ardara', 'Ardara', 'Ardara', 40.6214000, 8.8098700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86724, 'Arcugnano-Torri', 'Arcugnano-Torri', 'Arcugnano,arukunyano,アルクニャーノ', 45.4957900, 11.5477000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86725, 'Arcore', 'Arcore', 'Arcore,Arculi,arukore,アルコレ', 45.6267500, 9.3245400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86726, 'Arconate', 'Arconate', 'Arconate,arukonate,アルコナーテ', 45.5413400, 8.8489100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86727, 'Arcole', 'Arcole', 'Arcole,arukore,アルコレ', 45.3612500, 11.2875000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86728, 'Arcola', 'Arcola', 'Arcoa,Arcola,Arcòa', 44.1177800, 9.9117500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86729, 'Arco', 'Arco', 'Arco,Arko,aruko,Арко,アルコ', 45.9177200, 10.8867200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86730, 'Arcidosso', 'Arcidosso', 'Arcidosso', 42.8716200, 11.5359900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86731, 'Archi', 'Archi', '', 42.0913500, 14.3827000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86732, 'Arcevia', 'Arcevia', 'Arcevia,aruchevu~ia,アルチェーヴィア', 43.5017700, 12.9450000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86733, 'Arceto', 'Arceto', '', 44.6176200, 10.7246100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86734, 'Arcene', 'Arcene', 'Arcene,aruchene,アルチェネ', 45.5771700, 9.6146100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86735, 'Arce', 'Arce', 'Arce,Arche,Arci,Arx,a er qie,aleuche,aruche,Арче,Արչե,アルチェ,阿尔切,아르체', 41.5778700, 13.5857100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86736, 'Arcade', 'Arcade', '', 45.7842800, 12.2197200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86737, 'Arborio', 'Arborio', 'Arborio,Arboro,aruborio,アルボーリオ', 45.4958600, 8.3875500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86738, 'Arba', 'Arba', 'Arba,Darbe,aruba,アルバ', 46.1461100, 12.7900900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86739, 'Aradeo', 'Aradeo', 'Aradeo', 40.1292100, 18.1295100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86740, 'Aquino', 'Aquino', 'Akuino,Akvinas,Akvino,Akwin,Aquino,Aquinu,Aquinum,a kui nuo,akuino,akwino,akwyynw,akynw,Аквино,Акуїно,Ակվինո,آکوئینو,أكينو,アクイーノ,阿奎诺,아퀴노', 41.4938800, 13.7052000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86741, 'Aquilonia', 'Aquilonia', 'Akuilonija,Akvilonia,Akvilonija,Aquilonia,Carbonaria,a kui luo ni ya,akuironia,akwillonia,akwylwnya  aytalya,Аквилония,Аквилонија,Акуїлонія,Ակվիլոնիա,آکویلونیا، ایتالیا,アクイローニア,阿奎洛尼亚,아퀼로니아', 40.9868800, 15.4751000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86742, 'Aquileia', 'Aquileia', 'Akvileja,Akwileja,Aquilee,Aquileia,Aquileja,Aquilée,Oglej,akuireia,Аквилея,אקוויליה,アクイレイア', 45.7683000, 13.3677900, 'IT', '2016-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86743, 'Aquara', 'Aquara', 'Aquara', 40.4439100, 15.2538600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86744, 'Aprilia', 'Aprilia', 'Aprilia,Aprilia i Lazio,Aprilija,Aprília,QZR,a pu li li ya,abrylya,apeulillia,apriliya,aprylya,apuriria,Априлия,Априлија,Апрілія,Ապրիլիա,אפריליה,آپریلیا,أبريليا,अप्रिलिया,アプリーリア,阿普里利亞,아프릴리아', 41.5945200, 12.6541900, 'IT', '2015-08-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86745, 'Apricena', 'Apricena', 'Apricena', 41.7862900, 15.4439400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86746, 'Apricale', 'Apricale', 'Apricale,Brigar', 43.8803300, 7.6599300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86747, 'Aprica', 'Aprica', 'Aprica,aprika,Априка', 46.1522000, 10.1488400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86748, 'Appignano del Tronto', 'Appignano del Tronto', 'Appignano del Tronto,アッピニャーノ・デル・トロント', 42.8980500, 13.6622000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86749, 'Appignano', 'Appignano', '', 43.3627600, 13.3476800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86750, 'Appiano Gentile', 'Appiano Gentile', 'Appiano,Appiano Gentile', 45.7349900, 8.9810300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86751, 'San Michele', 'San Michele', 'Sankt Michael', 46.4547200, 11.2617800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86752, 'Apollosa', 'Apollosa', 'Apollosa', 41.0915600, 14.6962500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86753, 'Apiro', 'Apiro', 'Apiro', 43.3929000, 13.1304500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86754, 'Apice Vecchio', 'Apice Vecchio', 'Apice', 41.1201200, 14.9310400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86755, 'Apecchio', 'Apecchio', 'Apecchio', 43.5591400, 12.4216300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86756, 'Aosta', 'Aosta', 'AOT,Aosta,Aoste,Aouta,Aoûta,Augusta Praetoria,aoseuta,aosuta,Аоста,אאוסטה,アオスタ,아오스타', 45.7376400, 7.3172200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86757, 'Anzola d''Ossola', 'Anzola d''Ossola', 'Anzola d''Ossola', 45.9889700, 8.3453100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86758, 'Anzola dell''Emilia', 'Anzola dell''Emilia', 'Anzola,Anzola d''Emilia,Anzola dell''Emilia', 44.5419700, 11.2054800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86759, 'Anzio', 'Anzio', 'Ancio,Antium,Anzio,antsu~io,Анцио,Анціо,アンツィオ', 41.4526300, 12.6215700, 'IT', '2015-08-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86760, 'Bannio', 'Bannio', '', 45.9839700, 8.1461100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86761, 'Anzi', 'Anzi', '', 40.5166200, 15.9245700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86762, 'Anzano di Puglia', 'Anzano di Puglia', 'Anzano di Puglia', 41.1216200, 15.2868800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86763, 'Anzano del Parco', 'Anzano del Parco', 'Ancano del Parko,Ancano-del''-Parko,Anzan,Anzano del Parco,Anzanum,an zha nuo de er pa er ke,Анцано дел Парко,Анцано-дель-Парко,Անցանո դել Պարկո,アンツァーノ・デル・パルコ,安扎诺德尔帕尔科', 45.7700600, 9.1975200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86764, 'Anversa degli Abruzzi', 'Anversa degli Abruzzi', 'Anversa,Anversa degli Abruzzi', 41.9947800, 13.8037900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86765, 'Antronapiana', 'Antronapiana', '', 46.0609100, 8.1151900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86766, 'Antrodoco', 'Antrodoco', 'Antrodoco,Antrodocu,Antrodoko,Interocrium,an te luo duo ke,anteulodoko,antorodoko,antrwdwkw,Антродоко,Անտրոդոկո,آنترودوکو,アントロドーコ,安特罗多科,안트로도코', 42.4149800, 13.0767300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86767, 'Anticoli Corrado', 'Anticoli Corrado', 'Anticoli Corrado,アンティーコリ・コッラード', 42.0080100, 12.9904900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86768, 'Antey-Saint-Andrè', 'Antey-Saint-Andre', 'Antei Sant''Andrea,Antey-Saint-Andre,Antey-Saint-Andrè,Antey-Saint-André', 45.8060300, 7.5866600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86769, 'Anterivo', 'Anterivo', 'Altaripa,Altrei,Antehryva,Anterivo,an tai li wo,antelibo,anterivu~o,Αλτρέι,Антериво,Антэрыва,Անտերիվո,アンテリーヴォ,安泰里沃,안테리보', 46.2781000, 11.3666500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86770, 'Antella', 'Antella', '', 43.7277400, 11.3223300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86771, 'Antegnate', 'Antegnate', 'Antegnate', 45.4864800, 9.7914600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86772, 'Annone Veneto', 'Annone Veneto', 'Annone Veneto,Danon', 45.7896500, 12.6864600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86773, 'Annone di Brianza', 'Annone di Brianza', 'Annone di Brianza,Annone-di-Brianca,Annonum,Anon,Anone di Brijanca,Anonne-di-Brianza,an nuo nei di bu li ya en zha,Анноне-ди-Брианца,Анноне-ді-Бріанца,Аноне ди Бријанца,Анонне-ди-Брианза,Անոնե դի Բրիանցա,アンノーネ・ディ・ブリアンツァ,安诺内迪布里亚恩扎', 45.8021600, 9.3311900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86774, 'Annicco', 'Annicco', 'Anigum,Aniko,Annicco,Annicco vald,Annikko,Nich,an ni ke,an''nikko,Анико,Анникко,Аннікко,Անիքո,アンニッコ,安尼科', 45.2434400, 9.8790500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86775, 'Anitrella-Chiaiamari', 'Anitrella-Chiaiamari', 'Anitrella', 41.6382500, 13.5483500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86776, 'Anguillara Veneta', 'Anguillara Veneta', 'Anguillara,Anguillara Veneta,Capitello', 45.1424900, 11.8846100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86777, 'Anguillara Sabazia', 'Anguillara Sabazia', 'Anguillara,Anguillara Sabazia,Anquillara Sabazia,アングイッラーラ・サバーツィア', 42.0792000, 12.2836800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86778, 'Angri', 'Angri', 'Angri', 40.7381500, 14.5707000, 'IT', '2015-08-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86779, 'Angolo Terme', 'Angolo Terme', 'Angolo,Angolo Terme,アンゴロ・テルメ', 45.8916800, 10.1496300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86780, 'Anghiari', 'Anghiari', 'Anghiari', 43.5410400, 12.0583200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86781, 'Angera', 'Angera', 'Angera', 45.7755500, 8.5786100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86782, 'Anfo', 'Anfo', 'Amfum,Anf,Anfa,Anfo,an fu,anfo,Анфа,Анфо,Անֆո,アンフォ,安福', 45.7657500, 10.4938200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86783, 'Anela', 'Anela', 'Anela', 40.4417600, 9.0574300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86784, 'Anduins', 'Anduins', '', 46.2331100, 12.9582900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86785, 'Andria', 'Andria', 'Andria,Andrija,andoria,Андрия,アンドリア', 41.2311700, 16.2979700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86786, 'Andretta-Mattinella', 'Andretta-Mattinella', 'Andretta', 40.9374200, 15.3248500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86787, 'Andreis', 'Andreis', 'Andreis,Andrers', 46.2014600, 12.6144800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86788, 'Andrate', 'Andrate', 'Andra,Andrate,Andrà,andorate,アンドラーテ', 45.5263300, 7.8814500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86789, 'Andorno Cacciorna', 'Andorno Cacciorna', 'Andorno Cacciorna,Andorno Micca', 45.6105400, 8.0558900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86790, 'Andezeno', 'Andezeno', 'Andezeno,Andzen,andezeno,アンデゼーノ', 45.0337600, 7.8660700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86791, 'Andalo', 'Andalo', 'Andalo,andaro,アンダロ', 46.1664900, 11.0043200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86792, 'Ancona', 'Ancona', 'AOI,Ancona,Ancone,Anconn-a,Ancône,Ankona,an ke na,ankona,Анкона,アンコーナ,安科纳', 43.5942000, 13.5033700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86793, 'Anchione', 'Anchione', 'Anchiano,Anchione', 43.8261200, 10.7584400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86794, 'Ancarano', 'Ancarano', 'Ancarano', 42.8376700, 13.7466200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86795, 'Anagni', 'Anagni', 'Anagni,Anagnia', 41.7435000, 13.1554200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86796, 'Anacapri', 'Anacapri', 'Anacapri,anakapuri,アナカプリ', 40.5517000, 14.2122500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86797, 'Ampezzo', 'Ampezzo', 'Ampezzo,Dimpec,Dimpeç', 46.4145900, 12.7963400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86798, 'Amorosi', 'Amorosi', 'Amorosi', 41.2027300, 14.4659800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86799, 'Ameno', 'Ameno', 'Ameno', 45.7889700, 8.4400000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86800, 'Amelia', 'Amelia', 'Amelia,Amelija,Ameria,a mei li ya,amellia,ameria,amylya,amylya  ambrya,Амелиа,Амелия,Амелија,Амелія,Ամելիա,أميليا,امیلیا، امبریا,アメーリア,阿梅利亚,아멜리아', 42.5517700, 12.4207600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86801, 'Ameglia', 'Ameglia', 'Amegia,Ameglia', 44.0708900, 9.9660000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86802, 'Ambra', 'Ambra', '', 43.4146500, 11.6029100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86803, 'Amatrice', 'Amatrice', 'Amatrice,amatoriche,アマトリーチェ', 42.6266400, 13.2950900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86804, 'Amaseno', 'Amaseno', 'Amaseno', 41.4670500, 13.3345700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86805, 'Amaro', 'Amaro', 'Amaro,Damar', 46.3736700, 13.0936800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86806, 'Amandola', 'Amandola', 'Amandola,amandora,アマンドラ', 42.9782600, 13.3545300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86807, 'Amalfi', 'Amalfi', 'Amalfi,Amalfis,a ma er fei,amarufi,Амалфи,אמאלפי,アマルフィ,阿马尔菲', 40.6349000, 14.6023800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86808, 'Alzano Lombardo', 'Alzano Lombardo', 'Alzano,Alzano Lombardo,Alzano Maggiore,アルツァーノ・ロンバルド', 45.7368100, 9.7263800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86809, 'Alvito', 'Alvito', 'Al''vito,Albetum,Alvets,Alvito,Alvėts,a er wei tuo,albito,alwytw  lazyw,aruvu~ito,Алвито,Альвито,Альвіто,Ալվիտո,الویتو، لازیو,アルヴィート,阿尔维托,알비토', 41.6900200, 13.7479500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86810, 'Alvignano', 'Alvignano', 'Alvignano', 41.2442700, 14.3367100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86811, 'Alviano', 'Alviano', 'Al''viano,Al''vjano,Alviano,Alvianu,Alvijano,Castrum Alvianum,a er wei ya nuo,albiano,alfyanw,alwyanw,aruvu~iano,Алвиано,Алвијано,Альвиано,Альвяно,Ալվիանո,ألفيانو,الویانو,アルヴィアーノ,阿尔维亚诺,알비아노', 42.5908400, 12.2977500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86812, 'Altopascio', 'Altopascio', 'Altopascio', 43.8161800, 10.6766800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86813, 'Altino', 'Altino', 'Altino,arutino,アルティーノ', 42.0995400, 14.3326700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86814, 'Altidona', 'Altidona', 'Altidona,arutidona,アルティドーナ', 43.1078700, 13.7961700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86815, 'Altedo', 'Altedo', '', 44.6705700, 11.4901900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86816, 'Altavilla Vicentina', 'Altavilla Vicentina', 'Altavilla Vicentina,アルタヴィッラ・ヴィチェンティーナ', 45.5132900, 11.4687700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86817, 'Altavilla Silentina', 'Altavilla Silentina', 'Altavilla,Altavilla Silentina', 40.5301200, 15.1315300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86818, 'Altavilla Irpina', 'Altavilla Irpina', 'Altavilla Irpina', 41.0061900, 14.7809300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86819, 'Altare', 'Altare', 'Al''tare,Altare,Arta,Artâ,a er ta lei,altary,arutare,Алтаре,Альтаре,التاری,アルターレ,阿尔塔雷', 44.3356600, 8.3341100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86820, 'Altamura', 'Altamura', 'Altamura,arutamura,Алтамура,アルタムーラ', 40.8266400, 16.5495200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86821, 'Alseno', 'Alseno', 'Alseno', 44.8975900, 9.9640500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86822, 'Alpignano', 'Alpignano', 'Alpignan,Alpignano,arupinyano,アルピニャーノ', 45.0934600, 7.5239200, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86823, 'Alpette', 'Alpette', 'Alpette,Alpëtte,arupette,アルペッテ', 45.4091700, 7.5779500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86824, 'Almese-Rivera', 'Almese-Rivera', 'Almeis,Almese,Almèis,arumeze,アルメーゼ', 45.1191500, 7.4011100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86825, 'Almenno San Salvatore', 'Almenno San Salvatore', 'Almenno San Salvatore,アルメンノ・サン・サルヴァトーレ', 45.7497100, 9.5969900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86826, 'Almenno San Bartolomeo', 'Almenno San Bartolomeo', 'Almenno San Bartolomeo,アルメンノ・サン・バルトロメーオ', 45.7391200, 9.5808200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86827, 'Almè', 'Alme', 'Alme,Almè,Lme,Lmé,arume,アルメ', 45.7388300, 9.6155800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86828, 'Allumiere', 'Allumiere', 'Allumiere,arrumiere,アッルミエーレ', 42.1575100, 11.9036100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86829, 'Allerona', 'Allerona', 'Alerona,Allerona,Lerona,a lai luo na,allelona,alyrwna,arrerona,Алерона,Аллерона,Ալերոնա,أليرونا,الیرونا,アッレローナ,阿莱罗纳,알레로나', 42.8117400, 11.9745100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86830, 'Alleghe', 'Alleghe', 'Alege,Aleghe,Aleguae,Allege,Alleghe,a lai gai,alygy,arrege,Алеге,Аллеге,Ալեգհե,الیگی,アッレゲ,阿莱盖', 46.4071800, 12.0233600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86831, 'Alife', 'Alife', 'Alife,Alifi,Allifae,a li fei,allipe,alyf  kampanya,arife,Алифе,Аліфе,Ալիֆե,الیف، کامپانیا,アリーフェ,阿利费,알리페', 41.3261200, 14.3340300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86832, 'Alice Superiore', 'Alice Superiore', 'Ales,Alice Superiore,Àles,アーリチェ・スペリオーレ', 45.4606600, 7.7792200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86833, 'Alice Castello', 'Alice Castello', 'Alice Castello,アーリチェ・カステッロ', 45.3686000, 8.0732000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86834, 'Aliano', 'Aliano', 'Aliano,Alianu,Alianum,Alijana,Alijano,Allano,a li ya nuo,alyanw,ariano,Алиано,Алијано,Аліано,Аліяна,Ալիանո,אליאנו,أليانو,الیانو,アリアーノ,阿利亚诺', 40.3135900, 16.2298400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86835, 'Alghero', 'Alghero', 'AHO,Alghero,Alguer,Alguer - Alghero,Alguero,Alighera,L''Alguer,arugero,l''Alguer,アルゲーロ', 40.5596900, 8.3195300, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86836, 'Alfonsine', 'Alfonsine', 'Alfonsine,arufonshine,アルフォンシーネ', 44.5076800, 12.0374300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86837, 'Alfiano Natta', 'Alfiano Natta', 'Alfian,Alfiano Natta,アルフィアーノ・ナッタ', 45.0486000, 8.2073000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86838, 'Alfedena', 'Alfedena', 'Alfedena', 41.7354500, 14.0350000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86839, 'Alfano', 'Alfano', 'Alfano,Arfano,arufano,アルファーノ', 40.1768700, 15.4245000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86840, 'Alezio', 'Alezio', 'Alezio', 40.0622600, 18.0571200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86841, 'Alessandria', 'Alessandria', 'Alesandrija,Alessandria,Alessandrija,Alexandria,Alexandrie,Lissandria,QAL,aressandoria,aressandoria xian,Алесандрия,Алессандрия,Алессандрія,アレッサンドリア,アレッサンドリア県', 44.9092400, 8.6100700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86842, 'Aldeno', 'Aldeno', 'Aldeno,arudeno,アルデーノ', 45.9775800, 11.0927600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86843, 'Albuzzano', 'Albuzzano', 'Al''buccano,Albucano,Albucianum,Albuessan,Albuzzano,Albüssan,a er bu zha nuo,albwzanw,arubuttsu~ano,Албуцано,Альбуццано,Ալբուցանո,ألبوزانو,البوزانو,アルブッツァーノ,阿尔布扎诺', 45.1871900, 9.2738300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86844, 'Albonese', 'Albonese', 'Albonese', 45.2928500, 8.7061500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86845, 'Albizzate', 'Albizzate', 'Albizzate', 45.7269800, 8.8031200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86846, 'Albisola Marina', 'Albisola Marina', 'Albissola Marina,アルビッソラ・マリーナ', 44.3307900, 8.5096000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86847, 'Albino', 'Albino', 'Albino,arubino,Албино,アルビーノ', 45.7644400, 9.7990400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86848, 'Albinea', 'Albinea', 'Albinea,Албинеа', 44.6285900, 10.6102400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86849, 'Albignasego', 'Albignasego', 'Albignasego', 45.3470500, 11.8678100, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86850, 'Albignano', 'Albignano', '', 45.5005400, 9.4929900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86851, 'Albiate', 'Albiate', 'Albiaa,Albiate,arubiate,アルビアーテ', 45.6553700, 9.2503500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86852, 'Albiano d''Ivrea', 'Albiano d''Ivrea', 'Albian,Albiano d''Ivrea,アルビアーノ・ディヴレーア', 45.4342400, 7.9478900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86853, 'Albiano', 'Albiano', 'Albiano,arubiano,アルビアーノ', 46.1445100, 11.1945900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86854, 'Albiano Magra', 'Albiano Magra', '', 44.1757400, 9.9161900, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86855, 'Albettone', 'Albettone', 'Albettone', 45.3581100, 11.5843000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86856, 'Alberona', 'Alberona', 'Alberona', 41.4322500, 15.1230400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86857, 'Alberobello', 'Alberobello', 'Al''berobello,Alberobelas,Alberobello,Alberobellu,Alberobelo,Almperompelo,Silva Alborelli,a er bei luo bei luo,alberobelo,albrwblw,albyrwbylw,aruberoberro,Αλμπερομπέλο,Алберобело,Альберобелло,Ալբերոբելլո,אלברובלו,آلبروبلو,ألبيروبيلو,ალბერობელო,アルベロベッロ,阿尔贝罗贝洛', 40.7844800, 17.2361800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86858, 'Albareto', 'Albareto', 'Albareto,Albareto di Borgo Val di Taro,Albareto di Val di Taro', 44.4469200, 9.7022800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86859, 'Albenga', 'Albenga', 'ALL,Albemga,Albenga,Arbenga', 44.0499700, 8.2182900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86860, 'Albaredo', 'Albaredo', 'Albaredo,Albaredo per San Marco', 46.1029300, 9.5904600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86861, 'Albaredo d''Adige', 'Albaredo d''Adige', 'Albaredo d''Adige,アルバレード・ダーディジェ', 45.3185900, 11.2784300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86862, 'Albaredo', 'Albaredo', '', 45.6672500, 12.0109500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86863, 'Albano Vercellese', 'Albano Vercellese', 'Albano,Albano Vercellese,アルバーノ・ヴェルチェッレーゼ', 45.4261600, 8.3809300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86864, 'Albano Sant''Alessandro', 'Albano Sant''Alessandro', 'Albano,Albano Sant''Alessandro,アルバーノ・サンタレッサンドロ', 45.6876200, 9.7665100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86865, 'Albano Laziale', 'Albano Laziale', 'Albano,Albano Laziale,アルバーノ・ラツィアーレ', 41.7274800, 12.6590000, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86866, 'Albano di Lucania', 'Albano di Lucania', 'Albano di Lucania', 40.5861400, 16.0371200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86867, 'Albanella', 'Albanella', 'Albanella', 40.4794300, 15.1145400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86868, 'Alba', 'Alba', 'Al''bom,Alba,aruba,Альбом,アルバ', 44.6999000, 8.0347000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86869, 'Alatri', 'Alatri', 'Alatri,Алатри', 41.7318700, 13.3412000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86870, 'Alassio', 'Alassio', 'Alassio,Arasce', 44.0039300, 8.1671300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86871, 'Alanno', 'Alanno', 'Alanno', 42.2955200, 13.9708400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86872, 'Alagna Valsesia', 'Alagna Valsesia', 'Alagna,Alagna Valsesia,アラーニャ・ヴァルセージア', 45.8518200, 7.9375200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86873, 'Alagna', 'Alagna', 'Alagna', 45.1691700, 8.8894700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86874, 'Ala di Stura', 'Ala di Stura', 'Ala,Ala de Stura,Ala di Stura,Ala dë Stura,Alo di Stura,アーラ・ディ・ストゥーラ', 45.3149200, 7.3034500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86875, 'Alà dei Sardi', 'Ala dei Sardi', 'Ala dei Sardi,Alà dei Sardi', 40.6500700, 9.3278300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86876, 'Ala', 'Ala', 'Ala,ara,アーラ', 45.7607200, 11.0045800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86877, 'Airuno', 'Airuno', 'Airuno,Airunum,Ajruno,Iroegn,Irögn,a yi lu nuo,airuno,ayranw,Аируно,Айруно,Աիրունո,ایرانو,アイルーノ,阿伊鲁诺', 45.7535200, 9.4276500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86878, 'Airole', 'Airole', 'Aireur,Airole', 43.8709200, 7.5541400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86879, 'Airola', 'Airola', 'Airola', 41.0587100, 14.5592400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86880, 'Airasca', 'Airasca', 'Airasca,airasuka,アイラスカ', 44.9171900, 7.4832200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86881, 'Ailoche', 'Ailoche', 'Alloche', 45.6981200, 8.2213300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86882, 'Ailano', 'Ailano', 'Ailano,Allana', 41.3900100, 14.2053600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86883, 'Aiello del Sabato', 'Aiello del Sabato', 'Aiello del Sabato,Ajello d''''o Sabbato', 40.8884700, 14.8212300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86884, 'Aiello del Friuli', 'Aiello del Friuli', 'Aello-del''-Friuli,Aelo del Friuli,Agellum,Aiello,Aiello del Friuli,Ajelo del Frijuli,Ajelo del Friuli,Ajelo del'' Friuli-Venecija-Dzhuli,Dael,a ye luo de er fu liu li,aylw dl frywly,Аелло-дель-Фриули,Айело дел Фриули,Айело дель Фриули-Венеция-Джули,Аєлло-дель-Фріулі,Ајело дел Фријули,Աելո դել Ֆրիուլի,ایلو دل فریولی,アイエッロ・デル・フリウーリ,阿耶洛德尔夫留利', 45.8727600, 13.3603800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86885, 'Aielli', 'Aielli', 'Aielli', 42.0814600, 13.5911300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86886, 'Aidomaggiore', 'Aidomaggiore', 'Aidomaggiore', 40.1714700, 8.8567900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86887, 'Agugliaro', 'Agugliaro', 'Agguliaro,Agugliaro', 45.3251000, 11.5849600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86888, 'Agugliano', 'Agugliano', 'Agugliano,aguriano,アグリアーノ', 43.5436800, 13.3857400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86889, 'Agropoli', 'Agropoli', 'Agropoli,Agruopulo', 40.3492300, 14.9906700, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86890, 'Agrate Brianza', 'Agrate Brianza', 'Agrate,Agrate Brianza,アグラーテ・ブリアンツァ', 45.5743100, 9.3479300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86891, 'Agosta', 'Agosta', 'Agosta,agosuta,アーゴスタ', 41.9813300, 13.0349900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86892, 'Agordo', 'Agordo', 'Agordo', 46.2820100, 12.0360800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86893, 'Agnone', 'Agnone', 'Agnone', 41.8104300, 14.3752400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86894, 'Agnadello', 'Agnadello', 'Agnadel,Agnadello,anyaderro,アニャデッロ', 45.4451600, 9.5540800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86895, 'Agna', 'Agna', 'Agna', 45.1705100, 11.9562500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86896, 'Agliè', 'Aglie', 'Aglie,Agliè,Aje,Ajé,arie,アリエ', 45.3680000, 7.7680000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86897, 'Agliana', 'Agliana', 'Agliana,ariana,アリアーナ', 43.9024600, 11.0053100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86898, 'Aggius', 'Aggius', 'Adzhus,Agdzhus,Agghju,Aggius,Aggiuse vald,Ajus,a zhu si,ajjusu,ajyws,Агджус,Аджус,Ађус,Աջուս,اجیوس,アッジュス,阿朱斯', 40.9299500, 9.0651700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86899, 'Agerola', 'Agerola', 'Adzherola,Agerola,ajerora,Аджерола,アジェーロラ', 40.6377100, 14.5388400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86900, 'Agazzano', 'Agazzano', 'Agazzano', 44.9472600, 9.5187500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86901, 'Afragola', 'Afragola', 'Afragola,Afravola,afuragora,Афрагола,アフラゴーラ', 40.9229800, 14.3093500, 'IT', '2015-08-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86902, 'Affile', 'Affile', 'Affile,affire,アッフィーレ', 41.8843500, 13.0985300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86903, 'Affi', 'Affi', 'Affi,Alla,Alli,affi,アッフィ', 45.5529700, 10.7864000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86904, 'Adro', 'Adro', '', 45.6205900, 9.9615900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86905, 'Adria', 'Adria', 'Adria,Adrija,Адрия', 45.0544500, 12.0559900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86906, 'Adelfia', 'Adelfia', 'Adelfia,aderufia,アデルフィア', 41.0033000, 16.8720800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86907, 'Acuto', 'Acuto', 'Acuto,akuto,アクート', 41.7910700, 13.1744600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86908, 'Acqui Terme', 'Acqui Terme', 'Acqui,Acqui Citta,Acqui Città,Acqui Terme,Aich,Àich,アックイ・テルメ', 44.6755200, 8.4693400, 'IT', '2015-07-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86909, 'Acquaviva Picena', 'Acquaviva Picena', 'Acquaviva Picena,アックアヴィーヴァ・ピチェーナ', 42.9403700, 13.8222700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86910, 'Acquaviva d''Isernia', 'Acquaviva d''Isernia', 'Acquaviva d''Isernia', 41.6713200, 14.1477000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86911, 'Acquaviva delle Fonti', 'Acquaviva delle Fonti', 'Acquaviva delle Fonti,アックアヴィーヴァ・デッレ・フォンティ', 40.8970400, 16.8433000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86912, 'Acquaviva Collecroce', 'Acquaviva Collecroce', 'Acquaviva Collecroce', 41.8662400, 14.7473300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86913, 'Acquaviva', 'Acquaviva', '', 43.1156600, 11.8624900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86914, 'Acquasparta', 'Acquasparta', 'Acquasparta', 42.6891500, 12.5427500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86915, 'Acquasanta Terme', 'Acquasanta Terme', 'Acquasanta,Acquasanta Terme,アックアサンタ・テルメ', 42.7708400, 13.4141800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86916, 'Acquapendente', 'Acquapendente', 'Acquapendente', 42.7425900, 11.8682700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86917, 'Acquanegra sul Chiese', 'Acquanegra sul Chiese', 'Acquanegra,Acquanegra sul Chiese', 45.1640400, 10.4332300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86918, 'Acquanegra Cremonese', 'Acquanegra Cremonese', 'Acquanegra,Acquanegra Cremonese', 45.1686400, 9.8907400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86919, 'Acqualagna', 'Acqualagna', 'Acqualagna', 43.6260600, 12.6759600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86920, 'Acquafredda', 'Acquafredda', 'Acquafredda,akkuafuredda,アックアフレッダ', 45.3069700, 10.4134300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86921, 'Acquafondata', 'Acquafondata', 'Acquafondata', 41.5428200, 13.9528100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86922, 'Acilia-Castel Fusano-Ostia Antica', 'Acilia-Castel Fusano-Ostia Antica', '', 41.7633700, 12.3307800, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86923, 'Acerra', 'Acerra', 'Acerra,Acerrae,acherra,アチェッラ', 40.9447700, 14.3714000, 'IT', '2015-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86924, 'Acerno', 'Acerno', 'Acerno,Acernu,Acernum,Acherno,Acierno,a qie er nuo,acheleuno,acheruno,asrnw,Ачерно,Աչերնո,اسرنو,アチェルノ,阿切尔诺,아체르노', 40.7377100, 15.0569500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86925, 'Acerenza', 'Acerenza', 'Acerenza', 40.7938600, 15.9380800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86926, 'Accumoli', 'Accumoli', 'Accumoli', 42.6947600, 13.2476100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86927, 'Acciano', 'Acciano', 'Acciano', 42.1767700, 13.7178300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86928, 'Accettura', 'Accettura', 'Accettura', 40.4910200, 16.1579800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86929, 'Acceglio', 'Acceglio', 'Acceglio', 44.4746300, 6.9909200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86930, 'Accadia', 'Accadia', 'Accadia', 41.1576800, 15.3310000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86931, 'Abriola', 'Abriola', '', 40.5074800, 15.8131000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86932, 'Abetone', 'Abetone', 'Abetone', 44.1459500, 10.6640700, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86933, 'Abbiategrasso', 'Abbiategrasso', 'Abbiategrasso,Albiatum,abbiategurasso,Аббиатеграссо,アッビアテグラッソ', 45.3982100, 8.9167800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86934, 'Abbazia Pisani', 'Abbazia Pisani', 'Abbazia,Abbazia Pisani', 45.6127000, 11.8542900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86935, 'Abbateggio', 'Abbateggio', 'Abbateggio', 42.2242100, 14.0100100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86936, 'Abbasanta', 'Abbasanta', 'Abbasanta', 40.1281200, 8.8176000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86937, 'Abbadia San Salvatore', 'Abbadia San Salvatore', 'Abbadia San Salvadore,Abbadia San Salvatore,アッバディーア・サン・サルヴァトーレ', 42.8812000, 11.6722000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86938, 'Abbadia Lariana', 'Abbadia Lariana', 'Abbadia Lariana', 45.8994700, 9.3351800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86939, 'Abano Terme', 'Abano Terme', 'Abano,Abano Terme,Abano-Terme,Абано Терме,Абано-Терме,アーバノ・テルメ', 45.3575300, 11.7872500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86940, 'Li Punti-San Giovanni', 'Li Punti-San Giovanni', '', 40.7633800, 8.4890000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86941, 'Tergu', 'Tergu', 'Tergu', 40.8665200, 8.7146700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86942, 'San Martino dei Mulini', 'San Martino dei Mulini', '', 44.0318200, 12.4639600, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86943, 'Gatteo-Sant''Angelo', 'Gatteo-Sant''Angelo', 'Gati,Gatteo,Gatì', 44.1119400, 12.3913900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86944, 'San Mauro a Mare', 'San Mauro a Mare', '', 44.1636700, 12.4463100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86945, 'Gatteo a Mare', 'Gatteo a Mare', '', 44.1706900, 12.4354900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86946, 'Sala', 'Sala', '', 44.1563800, 12.3834000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86947, 'Bagnarola', 'Bagnarola', '', 44.1623200, 12.3428000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86948, 'Pisignano', 'Pisignano', '', 44.2378700, 12.2684100, 'IT', '2014-05-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86949, 'Rivazzurra', 'Rivazzurra', '', 44.0418600, 12.6089400, 'IT', '2013-11-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86950, 'Lido Adriano', 'Lido Adriano', '', 44.4167300, 12.3055200, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86951, 'Marina Romea', 'Marina Romea', '', 44.5149400, 12.2711300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86952, 'Santo Stefano-Carraie', 'Santo Stefano-Carraie', '', 44.3152500, 12.1857300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86953, 'Glorie', 'Glorie', '', 44.4699400, 12.0770700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86954, 'Lido degli Estensi', 'Lido degli Estensi', '', 44.6663900, 12.2500000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86955, 'Lido di Pomposa-Lido degli Scacchi', 'Lido di Pomposa-Lido degli Scacchi', '', 44.7066700, 12.2361100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86956, 'Serravalle', 'Serravalle', '', 44.9653200, 12.0466400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86957, 'Scardovari', 'Scardovari', '', 44.8976500, 12.4546200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86958, 'Aurisina Cave', 'Aurisina Cave', '', 45.7539800, 13.6593100, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86959, 'Capriva del Friuli', 'Capriva del Friuli', 'Capriva del Friuli,Caprive', 45.9409300, 13.5142200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86960, 'San Lorenzo Isontino', 'San Lorenzo Isontino', 'San Laurinc di Mosse,San Lorenzo Isontino,San Lorenzo di Mossa', 45.9302000, 13.5251700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86961, 'Ruda', 'Ruda', 'Ruda,Rude', 45.8398600, 13.4017700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86962, 'Visco', 'Visco', 'Visc,Visco', 45.8919400, 13.3486100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86963, 'Sevegliano', 'Sevegliano', '', 45.8874900, 13.3054100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86964, 'San Vito al Torre', 'San Vito al Torre', 'San Vit de Tor,San Vito al Torre,Sant Vit de Tor,Sant Vît de Tor', 45.8958700, 13.3758800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86965, 'Medea', 'Medea', 'Medea,Migjee', 45.9175100, 13.4244400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86966, 'Chiopris', 'Chiopris', '', 45.9266700, 13.4041700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86967, 'Terzo d''Aquileia', 'Terzo d''Aquileia', '', 45.7999400, 13.3417700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86968, 'San Canzian d''Isonzo', 'San Canzian d''Isonzo', '', 45.7975000, 13.4663900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86969, 'Pavia di Udine', 'Pavia di Udine', 'Pavia d''Udine,Pavia di Udine,Pavie', 45.9950200, 13.3036700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86970, 'Bagnaria Arsa', 'Bagnaria Arsa', '', 45.8838300, 13.2856200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86971, 'Pertegada', 'Pertegada', '', 45.7217900, 13.0437900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86972, 'Camino al Tagliamento', 'Camino al Tagliamento', 'Camino al Tagliamento,Cjamin dal Tiliment', 45.9276700, 12.9448900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86973, 'Puia-Villanova', 'Puia-Villanova', '', 45.8622200, 12.5713900, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86974, 'Prata di Sotto', 'Prata di Sotto', '', 45.8907300, 12.5959100, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86975, 'Meduna di Livenza', 'Meduna di Livenza', 'Meduna di Livenza,Medune', 45.8172000, 12.6282800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86976, 'Gorgo al Monticano', 'Gorgo al Monticano', 'Gorgo al Monticano', 45.7913900, 12.5500000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86977, 'Piavon', 'Piavon', '', 45.7642900, 12.5267300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86978, 'Corbolone', 'Corbolone', '', 45.7496200, 12.6696900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86979, 'Pramaggiore Blessaglia', 'Pramaggiore Blessaglia', '', 45.8052800, 12.7250000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86980, 'Pramaggiore', 'Pramaggiore', 'Pramaggiore,Pramaior', 45.8150000, 12.7388900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86981, 'Gruaro-Bagnara', 'Gruaro-Bagnara', '', 45.8416700, 12.8511100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86982, 'Summaga', 'Summaga', '', 45.7740600, 12.7979200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86983, 'San Giorgio al Tagliamento-Pozzi', 'San Giorgio al Tagliamento-Pozzi', '', 45.7963900, 12.9636100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86984, 'Crepaldo', 'Crepaldo', '', 45.5949500, 12.6965500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86985, 'Pero', 'Pero', '', 45.7063500, 12.3486700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86986, 'Candelù', 'Candelu', '', 45.7349900, 12.3722400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86987, 'Ormelle', 'Ormelle', 'Ormelle', 45.7778000, 12.4242900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86988, 'San Polo di Piave', 'San Polo di Piave', 'San Polo di Piave', 45.7896900, 12.3928700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86989, 'Lutrano', 'Lutrano', '', 45.8141500, 12.4731600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86990, 'Maserada sul Piave', 'Maserada sul Piave', 'Maserada sul Piave', 45.7519500, 12.3177300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86991, 'Santa Maria', 'Santa Maria', '', 45.9911500, 12.2299200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86992, 'Covolo-Levada', 'Covolo-Levada', '', 45.8482800, 12.0051500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86993, 'Santa Lucia di Piave', 'Santa Lucia di Piave', 'Santa Lucia di Piave', 45.8615900, 12.2939000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86994, 'Mareno di Piave', 'Mareno di Piave', 'Mareno di Piave', 45.8457200, 12.3370300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86995, 'Francenigo', 'Francenigo', '', 45.9079900, 12.5034700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86996, 'Colle Umberto', 'Colle Umberto', 'Colle Umberto', 45.9423800, 12.3422800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86997, 'Cosniga-Zoppè', 'Cosniga-Zoppe', '', 45.8875000, 12.3602800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86998, 'Orsago', 'Orsago', 'Orsago', 45.9296500, 12.4271200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(86999, 'Ciano', 'Ciano', '', 45.8238900, 12.0541700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87000, 'Selva del Montello', 'Selva del Montello', '', 45.7883500, 12.1435000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87001, 'Povegliano', 'Povegliano', 'Povegliano', 45.7594700, 12.2094400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87002, 'Falzè-Signoressa', 'Falze-Signoressa', '', 45.7502800, 12.1072200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87003, 'Falze', 'Falze', '', 45.7438100, 12.0926000, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87004, 'Ponzano', 'Ponzano', 'Ponzano Veneto,ポンツァーノ・ヴェーネト', 45.7154100, 12.2044400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87005, 'Mignagola', 'Mignagola', '', 45.6886800, 12.3215400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87006, 'Casacorba', 'Casacorba', '', 45.6594400, 12.0388900, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87007, 'Padernello', 'Padernello', '', 45.6815200, 12.1268500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87008, 'Fossò', 'Fosso', 'Fosso,Fossò,fosso,フォッソ', 45.3858000, 12.0462700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87009, 'Fiesso d''Artico', 'Fiesso d''Artico', 'Fiesso d''Artico,Fiesso d’Artico,フィエッソ・ダルティコ', 45.4213900, 12.0294400, 'IT', '2012-03-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87010, 'Marano', 'Marano', '', 45.4634500, 12.1171500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87011, 'Dese', 'Dese', '', 45.5296200, 12.3036300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87012, 'San Liberale', 'San Liberale', '', 45.5477800, 12.3413900, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87013, 'Trivignano', 'Trivignano', '', 45.5319700, 12.1868700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87014, 'Peseggia-Gardigiano', 'Peseggia-Gardigiano', '', 45.5616700, 12.1794400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87015, 'Torreselle', 'Torreselle', '', 45.6302600, 12.0225000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87016, 'Badoere', 'Badoere', '', 45.6342000, 12.0851800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87017, 'Sant''Alberto', 'Sant''Alberto', '', 45.6130600, 12.1347200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87018, 'Lughignano', 'Lughignano', '', 45.6253300, 12.3247800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87019, 'Casier', 'Casier', 'Casier', 45.6422900, 12.2932800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87020, 'Biancade', 'Biancade', '', 45.6486700, 12.3575300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87021, 'Stigliano', 'Stigliano', '', 45.5236200, 12.0437700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87022, 'Veternigo', 'Veternigo', '', 45.5176500, 12.0579300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87023, 'Caselle', 'Caselle', '', 45.4862800, 12.0060800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87024, 'Spinea-Orgnano', 'Spinea-Orgnano', 'Spinea,supinea,スピネーア', 45.4910700, 12.1550000, 'IT', '2015-08-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87025, 'Sambruson', 'Sambruson', '', 45.4103900, 12.1031100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87026, 'Campolongo Maggiore Liettoli', 'Campolongo Maggiore Liettoli', '', 45.3394400, 12.0241700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87027, 'Vallonga', 'Vallonga', '', 45.2724800, 12.0786000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87028, 'Cercivento', 'Cercivento', 'Cercivento,Curcuvint,Çurçuvint', 46.5274500, 12.9921900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87029, 'Sutrio', 'Sutrio', 'Sudri,Sutrio', 46.5120600, 12.9932500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87030, 'Pieria-Prato Carnico', 'Pieria-Prato Carnico', '', 46.5203700, 12.8032800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87031, 'Granvilla', 'Granvilla', '', 46.5675500, 12.6893300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87032, 'Sant''Anna', 'Sant''Anna', '', 45.1661000, 12.2735500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87033, 'Bortolot', 'Bortolot', '', 46.3860800, 12.1737100, 'IT', '2013-02-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87034, 'Castion', 'Castion', '', 46.1214700, 12.2350700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87035, 'Trichiana', 'Trichiana', 'Trichiana', 46.0813000, 12.1409100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87036, 'Limana', 'Limana', 'Limana', 46.1003900, 12.1855200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87037, 'Lamosano', 'Lamosano', '', 46.1727600, 12.3869100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87038, 'Soccher-Paiane-Casan-Arsie', 'Soccher-Paiane-Casan-Arsie', '', 46.1812000, 12.3100100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87039, 'Valle di Cadore', 'Valle di Cadore', 'Valle di Cadore', 46.4180600, 12.3343100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87040, 'Col San Martino', 'Col San Martino', '', 45.9002000, 12.1157500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87041, 'Savogna', 'Savogna', 'Savogna,Savogne', 46.1584600, 13.5308900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87042, 'Clodig', 'Clodig', '', 46.1562000, 13.5939900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87043, 'Merso di Sopra', 'Merso di Sopra', '', 46.1238900, 13.5280600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87044, 'Prepotto', 'Prepotto', 'Prepot,Prepotto', 46.0452200, 13.4792100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87045, 'Dolegna del Collio', 'Dolegna del Collio', '', 46.0309400, 13.4788500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87046, 'Orsaria', 'Orsaria', '', 46.0386200, 13.3824700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87047, 'Pradamano', 'Pradamano', 'Pradaman,Pradamano', 46.0339100, 13.3022300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87048, 'Basaldella', 'Basaldella', '', 46.0252700, 13.2171800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87049, 'Reana del Roiale', 'Reana del Roiale', '', 46.1373300, 13.2232000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87050, 'Basiliano-Vissandone', 'Basiliano-Vissandone', '', 46.0227800, 13.0930600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87051, 'Bressa', 'Bressa', '', 46.0344600, 13.1472400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87052, 'Passons', 'Passons', '', 46.0688900, 13.1891700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87053, 'Colugna', 'Colugna', '', 46.0910000, 13.2028200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87054, 'Pagnacco', 'Pagnacco', 'Pagna,Pagnacco', 46.1146200, 13.1837700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87055, 'Colloredo di Monte Albano', 'Collofedo di Monte Albano', '', 46.1647200, 13.1386100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87056, 'Colloredo di Monte Albano-Lauzzana', 'Colloredo di Monte Albano-Lauzzana', '', 46.1586100, 13.1227800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87057, 'Montenars', 'Montenars', 'Montenars', 46.2511100, 13.1694400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87058, 'Isola', 'Isola', '', 46.2557300, 13.1790600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87059, 'Bordano', 'Bordano', 'Bordan,Bordano', 46.3152800, 13.1052900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87060, 'Chiaulis', 'Chiaulis', '', 46.3887700, 12.9915500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87061, 'Preone', 'Preone', 'Preon,Preone', 46.3941100, 12.8664500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87062, 'Forgaria nel Friuli', 'Forgaria nel Friuli', '', 46.2203600, 12.9747000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87063, 'San Giacomo', 'San Giacomo', '', 46.1731100, 12.9834400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87064, 'Tramonti di Sotto', 'Tramonti di Sotto', 'Tramonc Disot,Tramonti di Sotto,Tramonç Disot', 46.2847500, 12.7964400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87065, 'Marsure', 'Marsure', '', 46.0940300, 12.5952800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87066, 'San Martino al Tagliamento', 'San Martino al Tagliamento', 'San Martin dal Tiliment,San Martino al Tagliamento', 46.0169700, 12.8698900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87067, 'Ramuscello', 'Ramuscello', '', 45.8810500, 12.8846000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87068, 'Claut', 'Claut', 'Claut', 46.2685500, 12.5144000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87069, 'Bocco', 'Bocco', '', 44.3511100, 9.3033300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87070, 'Leivi', 'Leivi', '', 44.3534400, 9.3107400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87071, 'San Salvatore', 'San Salvatore', '', 44.3309800, 9.3547900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87072, 'Cogorno', 'Cogorno', 'Cogorno', 44.3207400, 9.3711700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87073, 'Moraro', 'Moraro', 'Morar,Moraro,Morâr', 45.9297100, 13.4957500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87074, 'Campolongo al Torre-Cavenzano', 'Campolongo al Torre-Cavenzano', '', 45.8630600, 13.3894400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87075, 'Sottoselva', 'Sottoselva', '', 45.9113400, 13.3241600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87076, 'Motta Camastra', 'Motta Camastra', 'Motta Camastra', 37.8943100, 15.1700800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87077, 'Brusaporto', 'Brusaporto', 'Brusaporto', 45.6714000, 9.7604100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87078, 'Viganella', 'Viganella', 'Vicanella,Viganela,Viganella,fyjanyla,vu~iganerra,wei jia nei la,Виганелла,Віганела,Віганелла,Վիգանելլա,فيجانيلا,ヴィガネッラ,维加内拉', 46.0517300, 8.1937400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87079, 'Fratte Rosa', 'Fratte Rosa', 'Fratterosa', 43.6334600, 12.9023600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87080, 'San Bartolomeo al Mare', 'San Bartolomeo al Mare', '', 43.9231200, 8.1048200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87081, 'Cloz', 'Cloz', '', 46.4162000, 11.0858900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87082, 'Verbania', 'Verbania', 'Verbanija,Вербания', 45.9213600, 8.5518300, 'IT', '2012-12-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87083, 'Vacchereccia', 'Vacchereccia', '', 43.5609900, 11.5013100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87084, 'Pieve Emanuele', 'Pieve Emanuele', '', 45.3505200, 9.2026800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87085, 'Osio Sotto', 'Osio Sotto', '', 45.6160800, 9.5890500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87086, 'Scanzo-Rosciate', 'Scanzo-Rosciate', '', 45.7107800, 9.7350500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87087, 'Bedizzole', 'Bedizzole', '', 45.5103800, 10.4232700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87088, 'Lumezzane', 'Lumezzane', '', 45.6478900, 10.2648700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87089, 'Mazzano', 'Mazzano', '', 45.5200800, 10.3538700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87090, 'Beccacivetta-Azzano', 'Beccacivetta-Azzano', '', 45.3743500, 10.9613300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87091, 'Noventa', 'Noventa', '', 45.4142900, 11.9510100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87092, 'Castelnuovo del Garda', 'Castelnuovo del Garda', 'Castelnuovo di Garda', 45.4387800, 10.7597800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87093, 'Romano d''Ezzelino', 'Romano d''Ezzelino', '', 45.7790200, 11.7665700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87094, 'Saonara', 'Saonara', 'Sabonaria,Saonara,saonara,shao na la,Саонара,Սաոնարա,サオナーラ,绍纳拉', 45.3652900, 11.9848100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87095, 'Mediglia', 'Mediglia', '', 45.3953700, 9.3316500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87096, 'Buccinasco', 'Buccinasco', '', 45.4070300, 9.1083000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87097, 'Monte Argentario', 'Monte Argentario', 'Manteh-Ardzhehntarya,Mons Argentarius,Monte Ardzhentario,Monte Arjentario,Monte-Ardzhentario,Munti Argintario,meng tai ya er zhen ta liao,montealeujentalio,mwnth arjntaryw,Мантэ-Арджэнтарыа,Монте Арджентарио,Монте-Арджентарио,Монте-Арджентаріо,Մոնտե Արջենտարիո,مونته آرجنتاریو,モンテ・アルジェンターリオ,蒙泰亚尔真塔廖,몬테아르젠타리오', 42.4345200, 11.1195400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87098, 'Guidonia Montecelio', 'Guidonia Montecelio', 'Guidonia', 41.9936200, 12.7223800, 'IT', '2012-09-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87099, 'Cervinara', 'Cervinara', '', 41.0204200, 14.6144400, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87100, 'Montoro Superiore', 'Montoro Superiore', '', 40.8169900, 14.7984100, 'IT', '2014-01-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87101, 'Lamezia Terme', 'Lamezia Terme', 'Lamezia,Lamezia Terme,SUF', 38.9625500, 16.3093800, 'IT', '2015-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87102, 'Cardano al Campo', 'Cardano al Campo', '', 45.6488700, 8.7693300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87103, 'Caronno Pertusella', 'Caronno Pertusella', '', 45.5977700, 9.0463400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87104, 'Cassano Magnago', 'Cassano Magnago', '', 45.6720600, 8.8269100, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87105, 'Gerenzano', 'Gerenzano', '', 45.6396700, 9.0010400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87106, 'Uboldo', 'Uboldo', '', 45.6152700, 9.0039400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87107, 'Pero', 'Pero', '', 45.5101700, 9.0870400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87108, 'Pessano Con Bornago', 'Pessano Con Bornago', '', 45.5493700, 9.3814500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87109, 'Settimo Milanese', 'Settimo Milanese', '', 45.4777100, 9.0557400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87110, 'Cassola', 'Cassola', '', 45.7336000, 11.7994000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87111, 'Pieve a Nievole', 'Pieve a Nievole', '', 43.8811900, 10.7999000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87112, 'Albisola Superiore', 'Albisola Superiore', '', 44.3388900, 8.5104600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87113, 'Arcisate', 'Arcisate', '', 45.8557800, 8.8682300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87114, 'Basiglio', 'Basiglio', '', 45.3591700, 9.1585500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87115, 'Bussero', 'Bussero', 'Busero,Bussero,Busserum,Bussor,bu sai luo,bussero,Бусеро,Буссеро,Բուսերո,ブッセロ,布塞罗', 45.5340700, 9.3720500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87116, 'Verano Brianza', 'Verano Brianza', '', 45.6886800, 9.2245400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87117, 'Treviolo', 'Treviolo', '', 45.6736800, 9.6119500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87118, 'Concesio', 'Concesio', '', 45.6051800, 10.2169700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87119, 'Pino Torinese', 'Pino Torinese', '', 45.0395500, 7.7771200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87120, 'San Cipriano d''Aversa', 'San Cipriano d''Aversa', '', 40.9988100, 14.1317300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87121, 'San Felice A Cancello', 'San Felice A Cancello', '', 41.0170200, 14.4873600, 'IT', '2015-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87122, 'San Nicola la Strada', 'San Nicola la Strada', '', 41.0523700, 14.3333400, 'IT', '2015-08-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87123, 'Crispano', 'Crispano', '', 40.9525100, 14.2899300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87124, 'Pollena Trocchia', 'Pollena Trocchia', '', 40.8513400, 14.3791100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87125, 'Quarto', 'Quarto', 'Kvarto,Кварто', 40.8782200, 14.1435200, 'IT', '2015-08-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87126, 'Tremestieri Etneo', 'Tremestieri Etneo', '', 37.5649400, 15.0786300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87127, 'Santena', 'Santena', '', 44.9462400, 7.7730300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87128, 'Vinovo', 'Vinovo', '', 44.9467400, 7.6325200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87129, 'San Pietro in Cariano', 'San Pietro in Cariano', '', 45.5175100, 10.8862400, 'IT', '2015-05-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87130, 'Ozzano dell''Emilia', 'Ozzano dell''Emilia', '', 44.4442700, 11.4755200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87131, 'Casagiove', 'Casagiove', '', 41.0712400, 14.3116300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87132, 'Frignano', 'Frignano', '', 40.9981100, 14.1791300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87133, 'Orta di Atella', 'Orta di Atella', '', 40.9644100, 14.2685400, 'IT', '2015-08-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87134, 'San Marcellino', 'San Marcellino', '', 40.9900100, 14.1758300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87135, 'Teverola', 'Teverola', '', 40.9956100, 14.2076300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87136, 'Casavatore', 'Casavatore', '', 40.8992100, 14.2766300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87137, 'Volla', 'Volla', '', 40.8736300, 14.3408500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87138, 'Santa Maria La Carità', 'Santa Maria La Carita', '', 40.7161100, 14.5098400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87139, 'Trecase', 'Trecase', '', 40.7694100, 14.4377300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87140, 'Sant''Egidio del Monte Albino', 'Sant''Egidio del Monte Albino', '', 40.7387100, 14.5945400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87141, 'Bellizzi', 'Bellizzi', '', 40.6198100, 14.9468500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87142, 'Alba Adriatica', 'Alba Adriatica', '', 42.8317600, 13.9259000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87143, 'Valderice', 'Valderice', '', 38.0400500, 12.6150500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87144, 'Gravina di Catania', 'Gravina di Catania', '', 37.5608500, 15.0629200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87145, 'Sant''Agata Li Battiati', 'Sant''Agata Li Battiati', '', 37.5574500, 15.0799900, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87146, 'Lusciano', 'Lusciano', '', 40.9700100, 14.1904300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87147, 'Parete', 'Parete', '', 40.9589100, 14.1619300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87148, 'Piedimonte Matese', 'Piedimonte Matese', '', 41.3508200, 14.3680300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87149, 'Cesano Boscone', 'Cesano Boscone', 'Boscone', 45.4420700, 9.0944500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87150, 'Cesate', 'Cesate', '', 45.5958700, 9.0757400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87151, 'Carrara San Giorgio', 'Carrara San Giorgio', '', 45.2925900, 11.8184100, 'IT', '2013-02-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87152, 'Porto Viro', 'Porto Viro', '', 45.0267800, 12.2175400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87153, 'Tor Lupara', 'Tor Lupara', '', 41.9977100, 12.6181400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87154, 'Bernareggio', 'Bernareggio', '', 45.6477800, 9.4050500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87155, 'Brozolo', 'Brozolo', '', 45.1169500, 8.0719300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87156, 'Campiglione', 'Campiglione', '', 44.8028400, 7.3242200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87157, 'Magliano Alfieri', 'Magliano Alfieri', '', 44.7692400, 8.0701400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87158, 'Moiola', 'Moiola', '', 44.3211300, 7.3897300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87159, 'Mombarcaro', 'Mombarcaro', '', 44.4676400, 8.0882400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87160, 'Mombasiglio', 'Mombasiglio', '', 44.3666300, 7.9679400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87161, 'Monasterolo Casotto', 'Monasterolo Casotto', '', 44.3282300, 7.9432400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87162, 'Montaldo di Mondovì', 'Montaldo di Mondovi', '', 44.3217300, 7.8671400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87163, 'Rocca De'' Baldi', 'Rocca De'' Baldi', '', 44.4236300, 7.7611400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87164, 'Coassolo Torinese', 'Coassolo Torinese', '', 45.2977500, 7.4604100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87165, 'Inverso Pinasca', 'Inverso Pinasca', 'l''Envers de Pinacha,l''Invers ed Pinasca,l''Invers ëd Pinasca,l''Ënvers de Pinacha', 44.9456400, 7.2184100, 'IT', '2013-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87166, 'Priero', 'Priero', '', 44.3760400, 8.0933400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87167, 'Roascio', 'Roascio', '', 44.4171400, 8.0223400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87168, 'Rocchetta Belbo', 'Rocchetta Belbo', '', 44.6360400, 8.1753400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87169, 'Roddi', 'Roddi', '', 44.6796400, 7.9754400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87170, 'Roddino', 'Roddino', '', 44.5738400, 8.0191400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87171, 'Rodello', 'Rodello', '', 44.6285400, 8.0568400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87172, 'Sale delle Langhe', 'Sale delle Langhe', '', 44.3952300, 8.0801400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87173, 'San Benedetto Belbo', 'San Benedetto Belbo', '', 44.4901400, 8.0578400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87174, 'Sinio', 'Sinio', '', 44.6003400, 8.0199400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87175, 'Mompantero', 'Mompantero', '', 45.1474400, 7.0430100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87176, 'Pinasca-Dubbione', 'Pinasca-Dubbione', 'Pinacha', 44.9426400, 7.2291200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87177, 'Pramollo', 'Pramollo', 'Praamol,Praamòl,Pramol,Pramola,Pramollo,Pramolo,Pramòl,Pratum Molle,pu la mo luo,puramorro,Прамола,Прамолло,Պրամոլո,プラモッロ,普拉莫洛', 44.9081400, 7.1907100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87178, 'Prarostino', 'Prarostino', 'Prarostin,Prustin', 44.8663400, 7.2676200, 'IT', '2013-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87179, 'Belveglio', 'Belveglio', '', 44.8301200, 8.3286400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87180, 'Cantarana', 'Cantarana', '', 44.9024500, 8.0275300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87181, 'Capriglio', 'Capriglio', '', 45.0035500, 8.0089300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87182, 'Castel Boglione', 'Castel Boglione', '', 44.7219500, 8.3799400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87183, 'Castellero', 'Castellero', '', 44.9253500, 8.0738300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87184, 'Castelletto Molina', 'Castelletto Molina', '', 44.7512500, 8.4332400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87185, 'Cellarengo', 'Cellarengo', '', 44.8643500, 7.9453300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87186, 'Roure', 'Roure', '', 45.0021400, 7.1316100, 'IT', '2013-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87187, 'Salza di Pinerolo', 'Salza di Pinerolo', '', 44.9400400, 7.0524100, 'IT', '2013-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87188, 'San Raffaele Cimena', 'San Raffaele Cimena', '', 45.1466500, 7.8493200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87189, 'Traves', 'Traves', '', 45.2679500, 7.4308100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87190, 'Val della Torre', 'Val della Torre', '', 45.1551500, 7.4450100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87191, 'Cinaglio', 'Cinaglio', '', 44.9752500, 8.1000300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87192, 'Coazzolo', 'Coazzolo', '', 44.7282400, 8.1451400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87193, 'Corsione', 'Corsione', '', 45.0009500, 8.1452300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87194, 'Ferrere', 'Ferrere', '', 44.8760500, 7.9942100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87195, 'Maranzana', 'Maranzana', '', 44.7603500, 8.4784500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87196, 'Maretto', 'Maretto', '', 44.9448500, 8.0341300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87197, 'Mombaruzzo', 'Mombaruzzo', '', 44.7714500, 8.4482400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87198, 'Mombercelli', 'Mombercelli', '', 44.8178500, 8.2947400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87199, 'Monale', 'Monale', '', 44.9375500, 8.0724300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87200, 'Monastero Bormida', 'Monastero Bormida', '', 44.6485400, 8.3266400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87201, 'Verrua Savoia', 'Verrua Savoia', '', 45.1567500, 8.0922300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87202, 'Montabone', 'Montabone', '', 44.6987500, 8.3906400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87203, 'Montafia', 'Montafia', '', 44.9892500, 8.0246300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87204, 'Montaldo Scarampi', 'Montaldo Scarampi', '', 44.8303500, 8.2590400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87205, 'Piovà Massaia', 'Piova Massaia', '', 45.0551500, 8.0501300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87206, 'Quaranti', 'Quaranti', '', 44.7509500, 8.4491400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87207, 'Refrancore', 'Refrancore', '', 44.9363500, 8.3408400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87208, 'Roatto', 'Roatto', '', 44.9520500, 8.0269300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87209, 'Robella', 'Robella', '', 45.1016500, 8.1019300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87210, 'Rocca d''Arazzo', 'Rocca d''Arazzo', '', 44.8720500, 8.2846400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87211, 'Agrate Conturbia', 'Agrate Conturbia', '', 45.6754700, 8.5597300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87212, 'Castelspina', 'Castelspina', '', 44.8061500, 8.5831500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87213, 'Cella Monte', 'Cella Monte', '', 45.0740500, 8.3915400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87214, 'Conzano', 'Conzano', '', 45.0200900, 8.4555400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87215, 'Oviglio', 'Oviglio', '', 44.8612500, 8.4877400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87216, 'Pleyne', 'Pleyne', '', 44.5806300, 7.0171200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87217, 'Briaglia', 'Briaglia', '', 44.3958300, 7.8757400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87218, 'Briga Alta', 'Briga Alta', '', 44.0827300, 7.7494400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87219, 'Camerana', 'Camerana', '', 44.4240400, 8.1414400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87220, 'Caprauna', 'Caprauna', '', 44.1160300, 7.9549500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87221, 'Chiesa di Macra', 'Chiesa di Macra', '', 44.4828300, 7.1806200, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87222, 'Saint-Denis', 'Saint-Denis', '', 45.7525600, 7.5553100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87223, 'Verrayes', 'Verrayes', '', 45.7632600, 7.5346000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87224, 'Aquila di Arroscia', 'Aquila di Arroscia', '', 44.0859300, 8.0052500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87225, 'Monastero di Vasco', 'Monastero di Vasco', '', 44.3403300, 7.8226400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87226, 'Cosio di Arroscia', 'Cosio di Arroscia', '', 44.0774300, 7.8324400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87227, 'Diano Arentino', 'Diano Arentino', '', 43.9496200, 8.0415500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87228, 'Mendatica', 'Mendatica', '', 44.0771300, 7.8056400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87229, 'Montezemolo', 'Montezemolo', '', 44.3770300, 8.1411400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87230, 'Monticello d''Alba', 'Monticello d''Alba', '', 44.7189400, 7.9426300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87231, 'Niella Tanaro', 'Niella Tanaro', '', 44.4057300, 7.9279400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87232, 'Ostana', 'Ostana', 'Astana,Augustana,Ostan-a,Ostana,ao si ta na,osutana,Астана,Остана,Օստանա,オスターナ,奥斯塔纳', 44.6926300, 7.1894200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87233, 'Perlo', 'Perlo', '', 44.3318300, 8.0855400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87234, 'Pontechianale', 'Pontechianale', '', 44.6212300, 7.0300200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87235, 'Rittana', 'Rittana', '', 44.3510300, 7.3984300, 'IT', '2013-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87236, 'Roccabruna', 'Roccabruna', '', 44.4745300, 7.3437300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87237, 'Cosseria', 'Cosseria', '', 44.3677400, 8.2348500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87238, 'Giusvalla', 'Giusvalla', '', 44.4479400, 8.3941500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87239, 'Magliolo', 'Magliolo', '', 44.1925300, 8.2493500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87240, 'Mallare', 'Mallare', '', 44.2893400, 8.2969500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87241, 'Scagnello', 'Scagnello', '', 44.3333300, 7.9864400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87242, 'Torre Mondovì', 'Torre Mondovi', '', 44.3528300, 7.8996400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87243, 'Valloriate', 'Valloriate', '', 44.3376300, 7.3739300, 'IT', '2013-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87244, 'Agliano Terme', 'Agliano Terme', '', 44.7902500, 8.2504400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87245, 'Mioglia', 'Mioglia', '', 44.4921400, 8.4143500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87246, 'Plodio', 'Plodio', '', 44.3539400, 8.2472500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87247, 'Rialto', 'Rialto', '', 44.2265300, 8.2613500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87248, 'Casarza Ligure', 'Casarza Ligure', '', 44.2718800, 9.4470400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87249, 'Davagna', 'Davagna', '', 44.4658500, 9.0866600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87250, 'Orero', 'Orero', '', 44.4083500, 9.2670700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87251, 'Beverino', 'Beverino', '', 44.1976600, 9.7853700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87252, 'Camerano Casasco', 'Camerano Casasco', '', 44.9916500, 8.0910300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87253, 'Incisa Scapaccino', 'Incisa Scapaccino', '', 44.8080500, 8.3758400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87254, 'Isola d''Asti', 'Isola d''Asti', '', 44.8331500, 8.1802400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87255, 'Passerano Marmorito', 'Passerano Marmorito', '', 45.0558500, 8.0187300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87256, 'Rondanina', 'Rondanina', '', 44.5632500, 9.2180600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87257, 'Rovegno', 'Rovegno', '', 44.5767500, 9.2791700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87258, 'Carezzano Maggiore', 'Carezzano Maggiore', '', 44.8070500, 8.9005500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87259, 'Cassinelle-Concentrico', 'Cassinelle-Concentrico', '', 44.6015400, 8.5634500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87260, 'Castelletto Merli', 'Castelletto Merli', '', 45.0739500, 8.2401300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87261, 'Cerrina', 'Cerrina', '', 45.1213500, 8.2138300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87262, 'Coniolo Bricco', 'Coniolo Bricco', '', 45.1481600, 8.3709300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87263, 'Lozza', 'Lozza', '', 45.7756700, 8.8577300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87264, 'Malgesso', 'Malgesso', '', 45.8278700, 8.6755300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87265, 'Masciago Primo', 'Masciago Primo', '', 45.9177800, 8.7811300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87266, 'Mesenzana', 'Mesenzana', '', 45.9515800, 8.7645300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87267, 'Montegrino Valtravaglia', 'Montegrino Valtravaglia', '', 45.9739800, 8.7674300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87268, 'Orino', 'Orino', '', 45.8814800, 8.7156300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87269, 'Saltrio', 'Saltrio', '', 45.8734700, 8.9243600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87270, 'Morbello', 'Morbello', '', 44.6050400, 8.5107500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87271, 'Odalengo Piccolo', 'Odalengo Piccolo', '', 45.0716500, 8.2060300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87272, 'Pozzol Groppo', 'Pozzol Groppo', '', 44.8780600, 9.0298500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87273, 'San Giorgio Monferrato', 'San Giorgio Monferrato', '', 45.1073500, 8.4161400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87274, 'Bizzarone', 'Bizzarone', '', 45.8342800, 8.9427400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87275, 'Blessagno', 'Blessagno', '', 45.9590800, 9.0975400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87276, 'Blevio', 'Blevio', '', 45.8421800, 9.1051400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87277, 'Bulgarograsso', 'Bulgarograsso', '', 45.7470800, 9.0064400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87278, 'Cadorago-Caslino al Piano', 'Cadorago-Caslino al Piano', '', 45.7272800, 9.0378400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87279, 'Carate Urio', 'Carate Urio', 'Caraa e UEri,Caràa e Üri', 45.8717800, 9.1221400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87280, 'Carbonate', 'Carbonate', '', 45.6850700, 8.9381400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87281, 'Caslino d''Erba', 'Caslino d''Erba', '', 45.8389900, 9.2255400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87282, 'Casnate Con Bernate', 'Casnate Con Bernate', '', 45.7562800, 9.0726400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87283, 'Castelnuovo Bozzente', 'Castelnuovo Bozzente', '', 45.7645800, 8.9435400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87284, 'Ayas', 'Ayas', '', 45.8150600, 7.6891100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87285, 'Challand-Saint-Anselme', 'Challand-Saint-Anselme', '', 45.7145600, 7.7345100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87286, 'Challand-Saint-Victor', 'Challand-Saint-Victor', '', 45.6904600, 7.7047100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87287, 'Chamois', 'Chamois', 'Camosium,Chamoues,Chamouès,Samua,Shamoa,Shamua,ka mo yi si,shamowa,shamwyys,Шамоа,Шамуа,Շամուա,شاموئیس,シャモワ,卡莫伊斯', 45.8388600, 7.6187100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87288, 'Champorcher', 'Champorcher', '', 45.6237600, 7.6215100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87289, 'Petit Fenis', 'Petit Fenis', '', 45.7511500, 7.4639100, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87290, 'Introd', 'Introd', '', 45.6930600, 7.1824000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87291, 'Merone', 'Merone', 'Meron,Merone,Meronum,Meròn,mei luo nei,merone,Мероне,Մերոնե,メローネ,梅罗内', 45.7871800, 9.2440400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87292, 'Moltrasio', 'Moltrasio', '', 45.8599800, 9.0984400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87293, 'Montorfano', 'Montorfano', '', 45.7863800, 9.1437400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87294, 'Nesso', 'Nesso', '', 45.9123800, 9.1567400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87295, 'Prelà Castello', 'Prela Castello', '', 43.9400600, 7.9440900, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87296, 'Borgo di Ranzo', 'Borgo di Ranzo', '', 44.0596300, 8.0149500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87297, 'Andora', 'Andora', '', 43.9551400, 8.1412100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87298, 'Arnasco', 'Arnasco', '', 44.0782300, 8.1074500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87299, 'Borgio', 'Borgio', '', 44.1590600, 8.3083200, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87300, 'Bormida', 'Bormida', '', 44.2781300, 8.2323500, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87301, 'San Siro', 'San Siro', 'Fanum Sancti Syri,San Sir,San Siro,San-Sira,San-Siro,Siro,Сан-Сиро,Сан-Сіра,Сан-Сіро,Սան Սիրո,サン・シーロ', 46.0657300, 9.2687700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87302, 'Moconesi', 'Moconesi', '', 44.4206500, 9.2097700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87303, 'Pieve di Zignago', 'Pieve di Zignago', 'Zignago', 44.2779000, 9.7457300, 'IT', '2012-02-24', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87304, 'Bodio Lomnago', 'Bodio Lomnago', '', 45.7886700, 8.7508300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87305, 'Brezzo di Bedero', 'Brezzo di Bedero', '', 45.9783800, 8.7174300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87306, 'Cadegliano-Viconago', 'Cadegliano-Viconago', 'Cadegliano Viconago,Cadelianum Viconagum,Carian Viconagh,Kadel''jano-Vikonago,Kadeliano Vikonago,ka de li ya nuo-wei ke na ge,kaderiano=vu~ikonago,Кадельяно-Виконаго,Кадельяно-Віконаго,Կադելիանո Վիկոնագո,カデリアーノ＝ヴィコナーゴ,卡德利亚诺-维科纳戈', 45.9594800, 8.8434300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87307, 'Castelveccana', 'Castelveccana', 'Castrum Veccana,Kastel''vekkana,Kastelvekana,ka si tai er wei ka na,kasuteruvu~ekkana,Кастелвекана,Кастельвеккана,Կաստելվեքանա,カステルヴェッカーナ,卡斯泰尔韦卡纳', 45.9479800, 8.6663300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87308, 'Novedrate', 'Novedrate', '', 45.6980800, 9.1207400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87309, 'Ossuccio', 'Ossuccio', 'Asucha,Ausacium,Ossuchcho,Ossusc,Usuec,Usüc,ao su qiao,ossutcho,Асуча,Оссуччо,Օսուչո,オッスッチョ,奥苏乔', 45.9695800, 9.1797400, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87310, 'Parè', 'Pare', '', 45.8108800, 9.0087400, 'IT', '2015-11-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87311, 'Peglio', 'Peglio', '', 46.1603900, 9.2947400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87312, 'Plesio', 'Plesio', 'Piees,Pies,Piées', 46.0474200, 9.2288200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87313, 'Sala Comacina', 'Sala Comacina', '', 45.9641800, 9.1660400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87314, 'San Bartolomeo Val Cavargna', 'San Bartolomeo Val Cavargna', 'San Bartulume,San Bartulumé', 46.0834900, 9.1491300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87315, 'San Fermo della Battaglia', 'San Fermo della Battaglia', 'San Fermo,San-Fermo-della-Battal''ja,Vergosia,sheng fei er mo de la ba ta li ya,Сан-Фермо-делла-Батталья,Սան Ֆերմո դելա Բաթալիա,サン・フェルモ・デッラ・バッターリア,圣费尔莫德拉巴塔利亚', 45.8086800, 9.0474400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87316, 'San Nazzaro Val Cavargna', 'San Nazzaro Val Cavargna', 'San Nazar', 46.0893900, 9.1274300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87317, 'Solbiate', 'Solbiate', '', 45.7896800, 8.9331400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87318, 'Stazzona', 'Stazzona', '', 46.1387900, 9.2752400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87319, 'Veniano', 'Veniano', '', 45.7162900, 8.9850100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87320, 'Gornate Olona', 'Gornate Olona', '', 45.7415700, 8.8599400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87321, 'Oggiona-Santo Stefano', 'Oggiona-Santo Stefano', '', 45.7042700, 8.8165300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87322, 'Bema', 'Bema', '', 46.1081900, 9.5641400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87323, 'Cino', 'Cino', '', 46.1584300, 9.4853400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87324, 'Sernio', 'Sernio', '', 46.2242000, 10.2052600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87325, 'Tresivio', 'Tresivio', '', 46.1756900, 9.9425500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87326, 'Veddasca', 'Veddasca', '', 46.0705800, 8.7987300, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87327, 'Albavilla', 'Albavilla', '', 45.8003800, 9.1850400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87328, 'Beregazzo con Figliaro', 'Beregazzo con Figliaro', '', 45.7806800, 8.9441400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87329, 'Bregnano', 'Bregnano', '', 45.6977800, 9.0593400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87330, 'Casasco Intelvi', 'Casasco Intelvi', '', 45.9436800, 9.0757400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87331, 'Assago', 'Assago', '', 45.4088700, 9.1256500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87332, 'Basiano', 'Basiano', '', 45.5824800, 9.4632500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87333, 'Bellusco', 'Bellusco', '', 45.6195800, 9.4190500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87334, 'Consiglio di Rumo', 'Consiglio di Rumo', '', 46.1429900, 9.2933400, 'IT', '2014-01-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87335, 'Cremia', 'Cremia', '', 46.0864900, 9.2711400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87336, 'Faggeto Lario', 'Faggeto Lario', '', 45.8587800, 9.1589400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87337, 'Faloppio', 'Faloppio', 'Falopio,Falopp,Faloppio,Faloppium,Falòpp,fa luo pi ao,faroppio,Фалопио,Фалоппио,Фалоппіо,Ֆալոփիո,ファロッピオ,法洛皮奥', 45.8096800, 8.9643400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87338, 'Gironico al Piano', 'Gironico al Piano', 'Gironico', 45.8013800, 9.0031400, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87339, 'Grandola ed Uniti', 'Grandola ed Uniti', 'Grandola,Grandola e Unii,Grandola ed Owniti,Grandola-ed-Unici,Grandola-ed-Uniti,Grandola-ehd-Uniti,Grandolla et Municipia Coniuncta,Grandoła e Unìi,Grandula,ge lan duo la ai du ni di,Грандола-ед-Унити,Грандола-ед-Уніті,Грандола-ед-Уніці,Грандола-эд-Унити,Գրանդոլա եդ Ունիտի,グランドラ・エドゥニーティ,格兰多拉埃杜尼蒂', 46.0248800, 9.2127400, 'IT', '2013-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87340, 'Mezzegra', 'Mezzegra', 'Meccegra,Meccehgra,Mecegra,Medzegra,Mejegra,Mezegra,mei ze ge la,mettsu~egura,Медзегра,Мецегра,Меццегра,Меццэгра,Մեձեգրա,メッツェグラ,梅泽格拉', 45.9816800, 9.2051400, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87341, 'Nobile-Monguzzo', 'Nobile-Monguzzo', '', 45.7801800, 9.2302400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87342, 'Montemezzo', 'Montemezzo', '', 46.1787900, 9.3709400, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87343, 'Pellio Intelvi', 'Pellio Intelvi', '', 45.9798800, 9.0586400, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87344, 'Pianello del Lario', 'Pianello del Lario', '', 46.1027900, 9.2769400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87345, 'Schignano', 'Schignano', '', 45.9297800, 9.1021400, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87346, 'Trezzone', 'Trezzone', '', 46.1715900, 9.3518400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87347, 'Valbrona', 'Valbrona', '', 45.8773800, 9.2988400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87348, 'Val Rezzo', 'Val Rezzo', 'Val Rezz', 46.0726800, 9.1118300, 'IT', '2013-08-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87349, 'Castione Andevenno', 'Castione Andevenno', 'Castiun,Castrum Sthiliconis,Kast''one-Andevenno,Kastione Andeveno,ka si di ao nei ya en de wen nuo,Кастионе Андевено,Кастьоне-Андевенно,Կաստիոնե Անդևենո,カスティオーネ・アンデヴェンノ,卡斯蒂奥内亚恩德文诺', 46.1727900, 9.8002500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87350, 'Pozzo d''Adda', 'Pozzo d''Adda', '', 45.5725800, 9.5029500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87351, 'Pozzuolo Martesana', 'Pozzuolo Martesana', '', 45.5139800, 9.4562500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87352, 'Renate', 'Renate', '', 45.7243800, 9.2799400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87353, 'Roncello', 'Roncello', '', 45.6023800, 9.4549500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87354, 'Bedulita', 'Bedulita', '', 45.7913800, 9.5516500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87355, 'Canonica d''Adda', 'Canonica d''Adda', '', 45.5756800, 9.5416500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87356, 'Carobbio degli Angeli', 'Carobbio degli Angeli', '', 45.6651800, 9.8291600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87357, 'Cenate Sopra', 'Cenate Sopra', '', 45.7129800, 9.8221600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87358, 'Cenate di Sotto', 'Cenate di Sotto', '', 45.6989800, 9.8263600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87359, 'Moio de'' Calvi', 'Moio de'' Calvi', '', 45.9517900, 9.7007500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87360, 'Mozzo', 'Mozzo', '', 45.6986800, 9.6086500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87361, 'Palazzago', 'Palazzago', '', 45.7529800, 9.5336500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87362, 'Pedrengo', 'Pedrengo', '', 45.6959800, 9.7349500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87363, 'Peia', 'Peia', '', 45.7994900, 9.8992600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87364, 'Pianico', 'Pianico', '', 45.8098900, 10.0430600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87365, 'Piario', 'Piario', '', 45.8964900, 9.9272600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87366, 'Piazzolo', 'Piazzolo', '', 45.9797900, 9.6705500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87367, 'Pognano', 'Pognano', '', 45.5863800, 9.6399600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87368, 'Ponteranica', 'Ponteranica', '', 45.7324800, 9.6517500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87369, 'Fara Olivana', 'Fara Olivana', '', 45.4950800, 9.7490600, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87370, 'Foresto Sparso', 'Foresto Sparso', '', 45.6908800, 9.9200600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87371, 'Isola di Fondra', 'Isola di Fondra', '', 45.9785900, 9.7473500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87372, 'Locatello', 'Locatello', '', 45.8351800, 9.5340500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87373, 'Oltressenda Alta', 'Oltressenda Alta', '', 45.9151900, 9.9448600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87374, 'San Paolo d''Argon', 'San Paolo d''Argon', '', 45.6883800, 9.8022600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87375, 'Spinone al Lago', 'Spinone al Lago', '', 45.7647600, 9.9215700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87376, 'Rota d''Imagna', 'Rota d''Imagna', '', 45.8308800, 9.5122500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87377, 'Sant''Omobono Terme', 'Sant''Omobono Terme', '', 45.8083800, 9.5362500, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87378, 'Taleggio', 'Taleggio', '', 45.8933900, 9.5648500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87379, 'Ubiale Clanezzo', 'Ubiale Clanezzo', '', 45.7836800, 9.6193500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87380, 'Scano al Brembo', 'Scano al Brembo', '', 45.7185800, 9.6090500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87381, 'Valgoglio', 'Valgoglio', '', 45.9748900, 9.9135500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87382, 'Torre de'' Roveri', 'Torre de'' Roveri', '', 45.6971800, 9.7632600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87383, 'Valleve', 'Valleve', '', 46.0281900, 9.7437500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87384, 'Vilminore di Scalve', 'Vilminore di Scalve', '', 45.9981900, 10.0937600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87385, 'Bione', 'Bione', '', 45.6727900, 10.3388700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87386, 'Brione', 'Brione', '', 45.6422800, 10.1484600, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87387, 'Verdellino', 'Verdellino', '', 45.6010800, 9.6080500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87388, 'Viadanica', 'Viadanica', '', 45.6846800, 9.9614600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87389, 'Vigano San Martino', 'Vigano San Martino', '', 45.7260800, 9.8961600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87390, 'Costa di Serina', 'Costa di Serina', 'Costa Serina', 45.8326800, 9.7416500, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87391, 'Algua', 'Algua', '', 45.8258400, 9.7222500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87392, 'Agnosine', 'Agnosine', '', 45.6496900, 10.3526700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87393, 'Alfianello', 'Alfianello', '', 45.2669800, 10.1481700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87394, 'Idro', 'Idro', '', 45.7360900, 10.4733700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87395, 'Lodrino', 'Lodrino', '', 45.7196900, 10.2776700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87396, 'Lozio', 'Lozio', '', 45.9856900, 10.2609600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87397, 'Manerba del Garda', 'Manerba del Garda', '', 45.5498800, 10.5522800, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87398, 'Corvino San Quirico', 'Corvino San Quirico', '', 45.0108600, 9.1624500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87399, 'Inverno e Monteleone', 'Inverno e Monteleone', '', 45.1978700, 9.3852600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87400, 'Montecalvo Versiggia', 'Montecalvo Versiggia', '', 44.9720600, 9.2853600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87401, 'Mornico Losana', 'Mornico Losana', '', 45.0101600, 9.2061600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87402, 'Collebeato', 'Collebeato', '', 45.5811800, 10.2101700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87403, 'Corteno Golgi', 'Corteno Golgi', '', 46.1662000, 10.2434600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87404, 'Erbusco', 'Erbusco', '', 45.5986800, 9.9718600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87405, 'Incudine', 'Incudine', '', 46.2203000, 10.3587600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87406, 'Irma', 'Irma', '', 45.7712900, 10.2845700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87407, 'Santa Margherita di Staffora', 'Santa Margherita di Staffora', '', 44.7715400, 9.2400600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87408, 'Casa Ponte', 'Casa Ponte', '', 44.8777700, 9.1650900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87409, 'Mombelli', 'Mombelli', '', 44.8686600, 9.2343600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87410, 'Longhena', 'Longhena', '', 45.4376800, 10.0596700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87411, 'Losine', 'Losine', '', 45.9834900, 10.3161600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87412, 'Malegno', 'Malegno', '', 45.9507900, 10.2740600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87413, 'Milzano', 'Milzano', '', 45.2735800, 10.1992700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87414, 'Ome', 'Ome', 'Homi,Ome,Ome vald,ao mei,ome,Óme,Оме,Օմե,オーメ,奥梅', 45.6272800, 10.1213700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87415, 'Cappella Cantone', 'Cappella Cantone', '', 45.2465700, 9.8382600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87416, 'Casale Cremasco', 'Casale Cremasco', '', 45.4318700, 9.7141600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87417, 'Corte de'' Cortesi con Cignone', 'Corte de'' Cortesi con Cignone', '', 45.2731700, 10.0078700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87418, 'Gadesco-Pieve Delmona', 'Gadesco-Pieve Delmona', '', 45.1576700, 10.1156700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87419, 'Polpenazze del Garda', 'Polpenazze del Garda', '', 45.5511800, 10.5048800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87420, 'Prevalle', 'Prevalle', '', 45.5513800, 10.4220700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87421, 'Persico Dosimo', 'Persico Dosimo', '', 45.1858700, 10.1051700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87422, 'Urago d''Oglio', 'Urago d''Oglio', '', 45.5159800, 9.8696600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87423, 'Bagnaria', 'Bagnaria', '', 44.8272600, 9.1225600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87424, 'Montescano', 'Montescano', '', 45.0319600, 9.2836600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87425, 'Mottella', 'Mottella', '', 45.1638200, 10.8443600, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87426, 'Bastida Pancarana', 'Bastida Pancarana', '', 45.0860600, 9.0851500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87427, 'La Valle - Wengen', 'La Valle - Wengen', '', 46.6576300, 11.9239900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87428, 'Bleggio Superiore', 'Bleggio Superiore', '', 46.0248000, 10.8383700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87429, 'Bresimo', 'Bresimo', '', 46.4118100, 10.9681700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87430, 'Cimoneri', 'Cimoneri', '', 45.9842600, 11.0715500, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87431, 'Commezzadura', 'Commezzadura', '', 46.3217100, 10.8395700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87432, 'Fierozzo', 'Fierozzo', '', 46.1113100, 11.3184800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87433, 'Garniga Nuova', 'Garniga Nuova', '', 46.0031000, 11.0873800, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87434, 'Giovo', 'Giovo', '', 46.1558100, 11.1527800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87435, 'Lona-Lases', 'Lona-Lases', '', 46.1442100, 11.2195800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87436, 'Montagne', 'Montagne', '', 46.0585000, 10.7512700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87437, 'Redavalle', 'Redavalle', '', 45.0379600, 9.2022500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87438, 'Robecco Pavese', 'Robecco Pavese', '', 45.0483600, 9.1501500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87439, 'Roncaro', 'Roncaro', '', 45.2281700, 9.2754500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87440, 'Rovescala', 'Rovescala', '', 45.0069600, 9.3458600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87441, 'Sant''Alessio Con Vialone', 'Sant''Alessio Con Vialone', '', 45.2223700, 9.2260500, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87442, 'Santa Maria della Versa', 'Santa Maria della Versa', '', 44.9875700, 9.2997600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87443, 'Pieve di Bono', 'Pieve di Bono', '', 45.9422000, 10.6402700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87444, 'Rumo', 'Rumo', '', 46.4414100, 11.0185700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87445, 'Sagron Mis', 'Sagron Mis', '', 46.1947100, 11.9432000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87446, 'Sant''Orsola Terme', 'Sant''Orsola Terme', '', 46.1088100, 11.3023800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87447, 'Terragnolo', 'Terragnolo', '', 45.8783000, 11.1546800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87448, 'Vigo di Ton', 'Vigo di Ton', '', 46.2653100, 11.0879800, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87449, 'Trambileno', 'Trambileno', '', 45.8689000, 11.0733800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87450, 'Torre de'' Negri', 'Torre de'' Negri', '', 45.1496600, 9.3345600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87451, 'Torricella Verzate', 'Torricella Verzate', '', 45.0199600, 9.1735600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87452, 'Valfloriana', 'Valfloriana', '', 46.2497100, 11.3430800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87453, 'Vallarsa', 'Vallarsa', '', 45.7828000, 11.1178800, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87454, 'Villa-Agnedo', 'Villa-Agnedo', '', 46.0542100, 11.5283900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87455, 'Brentino Belluno', 'Brentino Belluno', '', 45.6568900, 10.8936800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87456, 'Brenzone', 'Brenzone', '', 45.6998900, 10.7605800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87457, 'Lavagno', 'Lavagno', '', 45.4386900, 11.1340900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87458, 'Travacò Siccomario', 'Travaco Siccomario', '', 45.1490600, 9.1596500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87459, 'Velezzo Lomellina', 'Velezzo Lomellina', '', 45.1633600, 8.7372400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87460, 'Verretto', 'Verretto', '', 45.0397600, 9.1131500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87461, 'Verrua Po', 'Verrua Po', '', 45.1068600, 9.1753500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87462, 'Gerre de'' Caprioli', 'Gerre de'' Caprioli', '', 45.0904200, 10.0508500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87463, 'Zeccone', 'Zeccone', '', 45.2578700, 9.2011500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87464, 'Zenevredo', 'Zenevredo', '', 45.0539100, 9.3266700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87465, 'Pedemonte', 'Pedemonte', '', 45.9084000, 11.3085900, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87466, 'Ripalta Arpina', 'Ripalta Arpina', '', 45.3018700, 9.7289600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87467, 'Ripalta Guerina', 'Ripalta Guerina', '', 45.3060700, 9.7039600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87468, 'San Daniele Po', 'San Daniele Po', '', 45.0672700, 10.1763700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87469, 'San Pietro Valdastico', 'San Pietro Valdastico', '', 45.8867000, 11.3615900, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87470, 'Velo d''Astico', 'Velo d''Astico', '', 45.7884000, 11.3676900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87471, 'Pieve di Coriano', 'Pieve di Coriano', '', 45.0338800, 11.1078000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87472, 'Ponti sul Mincio', 'Ponti sul Mincio', '', 45.4120800, 10.6850800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87473, 'Redondesco', 'Redondesco', '', 45.1663800, 10.5122800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87474, 'Serravalle a Po', 'Serravalle a Po', '', 45.0663800, 11.0818000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87475, 'Bersone', 'Bersone', '', 45.9444000, 10.6331700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87476, 'Bolbeno', 'Bolbeno', '', 46.0326000, 10.7378700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87477, 'Brione', 'Brione', '', 45.8948800, 10.5897500, 'IT', '2017-01-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87478, 'Massanzago-Ca'' Baglioni-San Dono', 'Massanzago-Ca'' Baglioni-San Dono', '', 45.5563000, 12.0073100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87479, 'Megliadino San Fidenzio', 'Megliadino San Fidenzio', '', 45.2173900, 11.5160000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87480, 'Cagnò', 'Cagno', '', 46.3943100, 11.0411700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87481, 'Villanova', 'Villanova', '', 45.4889000, 11.9747100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87482, 'Vò', 'Vo', 'Vo''', 45.3282900, 11.6415000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87483, 'Papozze', 'Papozze', 'Papocce,Papoce,Papoxia,Papoze,pa bo ze,papottsu~e,Папоце,Папоцце,Պապոցե,パポッツェ,帕波泽', 44.9857800, 12.0309200, 'IT', '2012-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87484, 'Lisignago', 'Lisignago', '', 46.1606100, 11.1876800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87485, 'Malosco', 'Malosco', 'Maloska,Malosko,Maluscum,ma luo si ke,marosuko,Малоска,Малоско,Մալոսկո,マロスコ,马洛斯科', 46.4361100, 11.1462700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87486, 'Nanno', 'Nanno', '', 46.3148100, 11.0474700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87487, 'Nogaredo', 'Nogaredo', '', 45.9130000, 11.0238800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87488, 'Ossana', 'Ossana', '', 46.3065100, 10.7375700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87489, 'Ronzo-Chienis', 'Ronzo-Chienis', '', 45.8896000, 10.9500800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87490, 'Pelugo', 'Pelugo', '', 46.0885000, 10.7238700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87491, 'Fiumicello', 'Fiumicello', '', 45.7920200, 13.4096400, 'IT', '2007-05-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87492, 'Sarnonico', 'Sarnonico', '', 46.4194100, 11.1417700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87493, 'Segonzano', 'Segonzano', '', 46.1902100, 11.2598800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87494, 'Sfruz', 'Sfruz', '', 46.3396100, 11.1237700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87495, 'Smarano', 'Smarano', '', 46.3431100, 11.1097700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87496, 'Reana del Rojale', 'Reana del Rojale', '', 46.1432200, 13.2465300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87497, 'Soraga', 'Soraga', 'Soraga Di Fassa,Sorega,Sorèga', 46.3946200, 11.6661900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87498, 'Sover', 'Sover', '', 46.2217100, 11.3156800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87499, 'Tenna', 'Tenna', '', 46.0157000, 11.2642800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87500, 'Terzolas', 'Terzolas', '', 46.3611100, 10.9258700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87501, 'Torcegno', 'Torcegno', '', 46.0743100, 11.4497900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87502, 'Varena', 'Varena', '', 46.3067100, 11.4582800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87503, 'Zuclo', 'Zuclo', '', 46.0343000, 10.7510700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87504, 'Angiari', 'Angiari', '', 45.2231800, 11.2768000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87505, 'Boschi Sant''Anna', 'Boschi Sant''Anna', '', 45.2176800, 11.3562000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87506, 'Cerro Veronese', 'Cerro Veronese', '', 45.5744900, 11.0415900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87507, 'Colognola ai Colli', 'Colognola ai Colli', '', 45.4336900, 11.1842900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87508, 'Grancona', 'Grancona', '', 45.4218900, 11.4516000, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87509, 'Roveredo di Guà', 'Roveredo di Gua', '', 45.2730900, 11.4442000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87510, 'Roverè Veronese', 'Rovere Veronese', '', 45.5932900, 11.0699900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87511, 'Stazione Valmozzola', 'Stazione Valmozzola', '', 44.5787900, 9.9429000, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87512, 'Lugo di Vicenza', 'Lugo di Vicenza', '', 45.7455000, 11.5286900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87513, 'San Gregorio nelle Alpi', 'San Gregorio nelle Alpi', '', 46.1039100, 12.0267000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87514, 'San Nicolò Comelico', 'San Nicolo Comelico', 'San Nicolo Comelico,San Nicolò Comelico', 46.5825300, 12.5273000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87515, 'Monfumo', 'Monfumo', '', 45.8308000, 11.9203000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87516, 'Portico e San Benedetto', 'Portico e San Benedetto', '', 44.0264600, 11.7815300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87517, 'Villagrande', 'Villagrande', '', 43.8413600, 12.3599400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87518, 'Monte Grimano Terme', 'Monte Grimano Terme', '', 43.8676600, 12.4712500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87519, 'Terrassa Padovana', 'Terrassa Padovana', 'Terasa Padovana,Terassa Padovana,Terrarsa,Terrassa-Padovana,tai la sa pa duo wa na,Террасса-Падована,Տերասա Պադովանա,テッラッサ・パドヴァーナ,泰拉萨帕多瓦纳', 45.2440900, 11.9027100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87520, 'Valle e Castello', 'Valle e Castello', '', 43.0374000, 13.0874200, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87521, 'Fluminata', 'Fluminata', '', 42.9438300, 13.1348000, 'IT', '2016-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87522, 'Castel di Lama', 'Castel di Lama', '', 42.8643500, 13.7192900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87523, 'Cortino', 'Cortino', '', 42.6218600, 13.5077400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87524, 'Zeri', 'Zeri', 'Cehry,Ceri,Dzeri,Jeri,Silva Cerri,cheli,ze li,zeri,zry,Дзери,Цери,Цері,Цэры,Ձերի,زری,ゼーリ,泽里,체리', 44.3537500, 9.7631800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87525, 'San Romano in Garfagnana', 'San Romano in Garfagnana', '', 44.1694500, 10.3469000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87526, 'Caminata', 'Caminata', '', 44.9103600, 9.3081600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87527, 'Cerignale', 'Cerignale', '', 44.6778500, 9.3507700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87528, 'Sambuca Pistoiese', 'Sambuca Pistoiese', '', 44.1043500, 10.9996100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87529, 'Capraia e Limite', 'Capraia e Limite', '', 43.7453500, 10.9834200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87530, 'Tavarnelle Val di Pesa', 'Tavarnelle Val di Pesa', '', 43.5618400, 11.1715200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87531, 'Gazzola', 'Gazzola', '', 44.9600600, 9.5489600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87532, 'Frazione Chiesa', 'Frazione Chiesa', '', 45.6940500, 8.2122800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87533, 'Callabiana - Chiesa', 'Callabiana - Chiesa', '', 45.6313700, 8.0972200, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87534, 'Montegioco', 'Montegioco', '', 44.8420500, 8.9627500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87535, 'Calvignasco', 'Calvignasco', '', 45.3259700, 9.0277500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87536, 'Sardigliano', 'Sardigliano', '', 44.7524000, 8.8957500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87537, 'Nibionno', 'Nibionno', '', 45.7464800, 9.2689400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87538, 'Palazzo Pignano', 'Palazzo Pignano', '', 45.3900700, 9.5695600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87539, 'Terranova dei Passerini', 'Terranova dei Passerini', '', 45.2152700, 9.6618600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87540, 'Capriata d''Orba', 'Capriata d''Orba', '', 44.7278500, 8.6908500, 'IT', '2016-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87541, 'Campo nell''Elba', 'Campo nell''Elba', 'Marina di Campo', 42.7480200, 10.2333200, 'IT', '2007-09-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87542, 'Montemignaio', 'Montemignaio', '', 43.7398500, 11.6188300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87543, 'Isola del Giglio', 'Isola del Giglio', 'Dzhil''o,Dzilijas,Džilijas,Giglio,Giglio Island,Giglio saar,Igilium,Illa del Giglio,Isla del Giglio,Isula di u Gigliu,Isula du Gigghiu,Izola-del''-Dzhil''jo,Tzilio,Vostrau Dzhylia,ji liao dao,Ìsula dû Gigghiu,Τζίλιο,Ізола-дель-Джильйо,Востраў Джыліа,Джильо,イーゾラ・デル・ジリオ,吉廖島', 42.3579100, 10.9072400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87544, 'Tresana', 'Tresana', '', 44.2542500, 9.9128800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87545, 'Pontey', 'Pontey', '', 45.7388600, 7.5883100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87546, 'Rhemes-Saint-Georges', 'Rhemes-Saint-Georges', '', 45.6522600, 7.1544000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87547, 'Castelbianco', 'Castelbianco', '', 44.1142300, 8.0751500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87548, 'Giustenice', 'Giustenice', '', 44.1729300, 8.2430500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87549, 'Larciano', 'Larciano', '', 43.8336500, 10.8900100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87550, 'Onzo', 'Onzo', '', 44.0701300, 8.0522500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87551, 'Orco Feglino', 'Orco Feglino', '', 44.2202300, 8.3245500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87552, 'Roccavignale', 'Roccavignale', '', 44.3612400, 8.1905500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87553, 'Osteria dei Cacciatori-Stella', 'Osteria dei Cacciatori-Stella', '', 44.4304400, 8.4712000, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87554, 'Broccostella', 'Broccostella', '', 41.6997200, 13.6353100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87555, 'Vendone', 'Vendone', '', 44.0769300, 8.0711500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87556, 'Vezzi Portio', 'Vezzi Portio', '', 44.2293300, 8.3650500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87557, 'Avegno', 'Avegno', '', 44.3828500, 9.1579700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87558, 'Tribogna', 'Tribogna', '', 44.4165500, 9.1955700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87559, 'Molino Vecchio-Scapitola-Baio', 'Molino Vecchio-Scapitola-Baio', '', 44.5555500, 9.0681600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87560, 'Carrodano', 'Carrodano', '', 44.2415500, 9.6557800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87561, 'Cosio Valtellino', 'Cosio Valtellino', '', 46.1350900, 9.5516400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87562, 'Forcola', 'Forcola', '', 46.1585900, 9.6603400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87563, 'Menarola', 'Menarola', '', 46.2992900, 9.3612400, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87564, 'Castel di Sasso', 'Castel di Sasso', '', 41.1924200, 14.2777300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87565, 'Castel Morrone', 'Castel Morrone', '', 41.1210200, 14.3547300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87566, 'Samolaco', 'Samolaco', 'Samolako,Samolegh,Summus Lacus,sa mo la ke,samorako,Самолако,Սամոլակո,サモーラコ,萨莫拉科', 46.2424900, 9.3940400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87567, 'Isolaccia', 'Isolaccia', '', 46.4890100, 10.2940500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87568, 'Valdisotto', 'Valdisotto', '', 46.4344100, 10.3569500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87569, 'Val Masino', 'Val Masino', '', 46.2151900, 9.6380400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87570, 'Marmentino', 'Marmentino', '', 45.7549900, 10.2846700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87571, 'Monticelli Brusati', 'Monticelli Brusati', '', 45.6347800, 10.1002600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87572, 'Muscoline', 'Muscoline', '', 45.5624900, 10.4618700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87573, 'Ossimo Superiore', 'Ossimo Superiore', '', 45.9461900, 10.2305600, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87574, 'Paisco Loveno', 'Paisco Loveno', '', 46.0791000, 10.2925600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87575, 'Pertica Alta', 'Pertica Alta', '', 45.7423900, 10.3441700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87576, 'Pertica Bassa', 'Pertica Bassa', '', 45.7533900, 10.3724700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87577, 'Pezzaze', 'Pezzaze', '', 45.7762900, 10.2359700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87578, 'Preseglie', 'Preseglie', '', 45.6682900, 10.3967700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87579, 'Provaglio d''Iseo', 'Provaglio d''Iseo', '', 45.6353800, 10.0446600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87580, 'Provaglio Val Sabbia', 'Provaglio Val Sabbia', '', 45.6887900, 10.4339700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87581, 'Puegnago sul Garda', 'Puegnago sul Garda', '', 45.5667900, 10.5097700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87582, 'Remedello', 'Remedello', '', 45.2783800, 10.3719800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87583, 'Rodengo-Saiano', 'Rodengo-Saiano', '', 45.5995800, 10.1071700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87584, 'Gardola', 'Gardola', '', 45.7418000, 10.7187100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87585, 'Trebbio', 'Trebbio', '', 45.7128900, 10.4613700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87586, 'Vallio Terme', 'Vallio Terme', '', 45.6097900, 10.3973700, 'IT', '2012-12-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87587, 'Valvestino', 'Valvestino', '', 45.7606900, 10.5954700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87588, 'Albaredo Arnaboldi', 'Albaredo Arnaboldi', '', 45.1066600, 9.2429600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87589, 'Castelletto di Branduzzo', 'Castelletto di Branduzzo', '', 45.0693600, 9.0984500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87590, 'Lettere', 'Lettere', '', 40.7049100, 14.5449400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87591, 'Sovramonte', 'Sovramonte', '', 46.0586100, 11.7866000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87592, 'Paderno del Grappa', 'Paderno del Grappa', '', 45.8286000, 11.8577000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87593, 'Saint-Christophe', 'Saint-Christophe', '', 45.7540600, 7.3472000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87594, 'Saint Marcel', 'Saint Marcel', '', 45.7314600, 7.4482000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87595, 'Saint-Nicolas', 'Saint-Nicolas', 'Fanum Sancti Nicolai Augustensium,Sen Nikola,Sen-Nikola,sa yi en te-ni ke la si,san=nikora,Сен Никола,Сен-Никола,Сен-Нікола,Սեն Նիկոլա,سینٹ-نکولس، اوستا ویلی,サン＝ニコラ,萨伊恩特-尼科拉斯', 45.7165600, 7.1667000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87596, 'Ville Sur Sarre', 'Ville Sur Sarre', '', 45.7333900, 7.2585700, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87597, 'Valsavarenche', 'Valsavarenche', '', 45.5918600, 7.2100000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87598, 'Valtournenche', 'Valtournenche', '', 45.8760700, 7.6243000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87599, 'Bajardo', 'Bajardo', '', 43.9040200, 7.7253400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87600, 'Ceranesi', 'Ceranesi', '', 44.5056300, 8.8934300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87601, 'Roè Volciano', 'Roe Volciano', '', 45.6119900, 10.4885700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87602, 'Soiano', 'Soiano', '', 45.5277800, 10.5126700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87603, 'Aldino', 'Aldino', '', 46.3658100, 11.3550800, 'IT', '2015-08-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87604, 'Andriano', 'Andriano', '', 46.5176200, 11.2313700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87605, 'Venticano', 'Venticano', '', 41.0472200, 14.9119400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87606, 'Barbiano - Barbian', 'Barbiano - Barbian', '', 46.6033200, 11.5213800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87607, 'Braies', 'Braies', 'Braies,Prags', 46.7202300, 12.1333900, 'IT', '2013-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87608, 'Brennero - Brenner', 'Brennero - Brenner', '', 46.9381300, 11.4424700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87609, 'Caines - Kuens', 'Caines - Kuens', '', 46.7000200, 11.1698700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87610, 'Cornedo All''Isarco', 'Cornedo All''Isarco', 'Karneid', 46.4899000, 11.4064700, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87611, 'Cortina sulla Strada del Vino', 'Cortina sulla Strada del Vino', 'Cortina sulla Strada del Vino,Kurtinig an der Weinstrasse', 46.2694100, 11.2218800, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87612, 'Funes - Villnoess', 'Funes - Villnoess', '', 46.6428200, 11.6782800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87613, 'Magrè sulla Strada del Vino', 'Magre sulla Strada del Vino', 'Margreid an der Weinstrasse', 46.2879100, 11.2106800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87614, 'Proves - Proveis', 'Proves - Proveis', '', 46.4766100, 11.0224700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87615, 'Racines - Ratschings', 'Racines - Ratschings', '', 46.8818300, 11.3782700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87616, 'Rasun Anterselva - Rasen-Antholz', 'Rasun Anterselva - Rasen-Antholz', 'Antholz,Rasun Anterselva', 46.7785300, 12.0472900, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87617, 'Renon - Ritten', 'Renon - Ritten', '', 46.5415200, 11.4572800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87618, 'Rodengo - Rodeneck', 'Rodengo - Rodeneck', '', 46.7795300, 11.6904800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87619, 'San Martino in Badia', 'San Martino in Badia', 'San Martino in Badia,St. Martin in Thurn', 46.6815300, 11.8980900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87620, 'Senales', 'Senales', 'Schnals', 46.7060200, 10.9084600, 'IT', '2012-02-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87621, 'Tirolo', 'Tirolo', '', 46.6910200, 11.1542700, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87622, 'Ultimo - Ulten', 'Ultimo - Ulten', 'Ulten,Ultimo', 46.5483200, 11.0041700, 'IT', '2016-11-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87623, 'Prati', 'Prati', 'Pfitsch', 46.9000300, 11.4650700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87624, 'Valle Aurina - Ahrntal', 'Valle Aurina - Ahrntal', '', 46.9962300, 11.9798800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87625, 'Valle di Casies - Gsies', 'Valle di Casies - Gsies', 'Gsieser Tal', 46.7683300, 12.1793900, 'IT', '2016-03-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87626, 'Vandoies - Vintl', 'Vandoies - Vintl', '', 46.8151300, 11.7206800, 'IT', '2012-02-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87627, 'Verano - Voeran', 'Verano - Voeran', '', 46.6047200, 11.2260700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87628, 'Villandro - Villanders', 'Villandro - Villanders', '', 46.6308200, 11.5370800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87629, 'Vallada Agordina', 'Vallada Agordina', '', 46.3644200, 11.9339900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87630, 'Cavaso del Tomba', 'Cavaso del Tomba', '', 45.8607100, 11.8984000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87631, 'Capitignano', 'Capitignano', '', 40.7185100, 14.9046500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87632, 'Montecorvino Pugliano', 'Montecorvino Pugliano', '', 40.6792100, 14.9447500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87633, 'Balsorano', 'Balsorano', '', 41.8098200, 13.5598000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87634, 'Lucoli', 'Lucoli', '', 42.2909300, 13.3379900, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87635, 'Villagrande', 'Villagrande', '', 42.2953300, 13.2999900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87636, 'Imposte', 'Imposte', '', 42.6863400, 13.5282900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87637, 'Isole Tremiti', 'Isole Tremiti', '', 42.1208500, 15.5042400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87638, 'Calvisi', 'Calvisi', '', 39.1273900, 16.3059000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87639, 'Conflenti', 'Conflenti', '', 39.0716900, 16.2845000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87640, 'Africo Nuovo', 'Africo Nuovo', '', 38.0506700, 16.1332000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87641, 'Fiumara', 'Fiumara', 'Caenesium,F''jumara,Fiumara,Fjumara,Sciumara i Muru,fei wu ma la,fiumara,fywmara,Фиумара,Фьюмара,Фюмара,Фјумара,Ֆիումարա,فيومارا,フィウマーラ,菲乌马拉', 38.2126700, 15.6936900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87642, 'Roghudi', 'Roghudi', 'Roghudi,Roghudi Nuovo', 37.9249900, 15.7653700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87643, 'Fondachelli-Fantina', 'Fondachelli-Fantina', '', 37.9847600, 15.1751900, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87644, 'Terme', 'Terme', '', 38.1358600, 15.1565800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87645, 'Maniace', 'Maniace', '', 37.8830600, 14.7980800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87646, 'Valledoria', 'Valledoria', '', 40.9286700, 8.8232100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87647, 'Camandona', 'Camandona', '', 45.6441700, 8.0997200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87648, 'Cerreto Castello', 'Cerreto Castello', '', 45.5644600, 8.1608200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87649, 'Curino', 'Curino', '', 45.6271700, 8.2362200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87650, 'Mezzana Mortigliengo', 'Mezzana Mortigliengo', '', 45.6265700, 8.1895200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87651, 'Selve Marcone', 'Selve Marcone', '', 45.6197600, 8.0874200, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87652, 'Soprana', 'Soprana', '', 45.6394700, 8.1989200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87653, 'Vallanzengo', 'Vallanzengo', '', 45.6032700, 8.1504200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87654, 'Veglio', 'Veglio', '', 45.6405700, 8.1141200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87655, 'Castello di Brianza', 'Castello di Brianza', 'Castell de Brianza,Castrum Brigantiae,Kastello-di-Brianca,Kastelo di Brjanca,ka si tai luo di bu li ya en zha,Кастелло-ди-Брианца,Кастелло-ді-Бріанца,Кастело ди Брјанца,Կաստելլո դի Բրիանցա,カステッロ・ディ・ブリアンツァ,卡斯泰洛迪布里亚恩扎', 45.7592800, 9.3453500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87656, 'Colle Brianza', 'Colle Brianza', '', 45.7623800, 9.3643500, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87657, 'Garbagnate Monastero', 'Garbagnate Monastero', '', 45.7733800, 9.3014400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87658, 'Monticello Brianza', 'Monticello Brianza', '', 45.7094800, 9.3156400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87659, 'Castiraga Vidardo', 'Castiraga Vidardo', '', 45.2572700, 9.4045600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87660, 'Jonadi', 'Jonadi', '', 38.6298800, 16.0610000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87661, 'Antrona Schieranco', 'Antrona Schieranco', '', 46.0603800, 8.1146100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87662, 'Brovello-Carpugnino', 'Brovello-Carpugnino', 'Bravela-Karpun''ina,Brovel e Carpignin,Brovello-Karpun''ino,Brovelo Karpunino,Brovelo-Karpunino,Bruellum-Carpuninum,Bruvel-Campugnin,Bruvél-Campugnin,bu luo wei luo-ka er pu ni nuo,burovu~erro=karupunino,Бравела-Карпуньіна,Бровелло-Карпуньино,Бровелло-Карпуньїно,Бровело-Карпунино,Բրովելո Կարպունինո,ブロヴェッロ＝カルプニーノ,布罗韦洛-卡尔普尼诺', 45.8424700, 8.5317300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87663, 'Calasca-Castiglione', 'Calasca-Castiglione', '', 46.0208100, 8.2145100, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87664, 'Cavaglio-Spoccia', 'Cavaglio-Spoccia', '', 46.0710800, 8.6307200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87665, 'Madonna del Sasso', 'Madonna del Sasso', '', 45.7921700, 8.3695200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87666, 'Montescheno', 'Montescheno', '', 46.0665800, 8.2319200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87667, 'Oggebbio', 'Oggebbio', '', 45.9908800, 8.6466300, 'IT', '2013-08-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87668, 'San Bernardino Verbano', 'San Bernardino Verbano', '', 45.9563800, 8.5192200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87669, 'Valstrona', 'Valstrona', '', 45.9076700, 8.3432200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87670, 'Montemale di Cuneo', 'Montemale di Cuneo', '', 44.4374300, 7.3753300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87671, 'Monterosso Grana', 'Monterosso Grana', '', 44.4082300, 7.3229300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87672, 'Murello', 'Murello', '', 44.7521400, 7.6009300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87673, 'Paroldo', 'Paroldo', '', 44.4320400, 8.0724400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87674, 'Perletto', 'Perletto', '', 44.5993400, 8.2130400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87675, 'Pianfei', 'Pianfei', '', 44.3720300, 7.7114300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87676, 'Pocapaglia', 'Pocapaglia', '', 44.7152400, 7.8829300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87677, 'Polonghera', 'Polonghera', '', 44.8023400, 7.5957200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87678, 'Torre Bormida', 'Torre Bormida', '', 44.5627400, 8.1544400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87679, 'Torre San Giorgio', 'Torre San Giorgio', '', 44.7357400, 7.5281300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87680, 'Verduno', 'Verduno', '', 44.6661400, 7.9307400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87681, 'Vezza d''Alba', 'Vezza d''Alba', '', 44.7627400, 8.0079300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87682, 'Villar San Costanzo', 'Villar San Costanzo', '', 44.4847300, 7.3822300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87683, 'Albugnano', 'Albugnano', '', 45.0775500, 7.9711300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87684, 'Antignano', 'Antignano', '', 44.8453500, 8.1349400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87685, 'San Martino Alfieri', 'San Martino Alfieri', '', 44.8179500, 8.1099400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87686, 'San Paolo Solbrito', 'San Paolo Solbrito', '', 44.9506500, 7.9707300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87687, 'Soglio', 'Soglio', '', 44.9962500, 8.0784300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87688, 'Tigliole', 'Tigliole', '', 44.8862500, 8.0766300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87689, 'Vaglio Serra', 'Vaglio Serra', '', 44.7963500, 8.3389400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87690, 'Viarigi', 'Viarigi', '', 44.9805500, 8.3571400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87691, 'Vinchio', 'Vinchio', '', 44.8109500, 8.3209400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87692, 'Alice Bel Colle', 'Alice Bel Colle', '', 44.7260500, 8.4507400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87693, 'Altavilla Monferrato', 'Altavilla Monferrato', '', 44.9935500, 8.3759400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87694, 'Avolasca', 'Avolasca', '', 44.8031500, 8.9654500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87695, 'Belforte Monferrato', 'Belforte Monferrato', '', 44.6250500, 8.6612500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87696, 'Bergamasco', 'Bergamasco', '', 44.8272500, 8.4547400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87697, 'Berzano di Tortona', 'Berzano di Tortona', '', 44.8766600, 8.9510800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87698, 'Borghetto di Borbera', 'Borghetto di Borbera', '', 44.7294500, 8.9434600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87699, 'Bosio', 'Bosio', '', 44.6497500, 8.7928500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87700, 'Carpeneto', 'Carpeneto', '', 44.6783500, 8.6055500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87701, 'Casal Cermelli', 'Casal Cermelli', '', 44.8349500, 8.6249500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87702, 'Casaleggio Boiro', 'Casaleggio Boiro', '', 44.6335500, 8.7304500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87703, 'Costa Vescovato', 'Costa Vescovato', '', 44.8161500, 8.9269500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87704, 'Cuccaro Monferrato', 'Cuccaro Monferrato', '', 44.9936500, 8.4575400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87705, 'Fraconalto', 'Fraconalto', '', 44.5910500, 8.8784600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87706, 'Francavilla Bisio', 'Francavilla Bisio', '', 44.7346500, 8.7312500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87707, 'Fresonara', 'Fresonara', '', 44.7829500, 8.6861500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87708, 'Gavazzana', 'Gavazzana', '', 44.7758500, 8.8859500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87709, 'Grondona', 'Grondona', '', 44.6964500, 8.9654600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87710, 'Masio', 'Masio', '', 44.8696500, 8.4077400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87711, 'Molino dei Torti', 'Molino dei Torti', '', 45.0242600, 8.8936500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87712, 'Mombello Monferrato', 'Mombello Monferrato', '', 45.1328500, 8.2503300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87713, 'Momperone', 'Momperone', '', 44.8384500, 9.0342500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87714, 'Moncestino', 'Moncestino', '', 45.1546500, 8.1614300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87715, 'Montacuto', 'Montacuto', '', 44.7664500, 9.1049600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87716, 'Montaldeo', 'Montaldeo', '', 44.6671500, 8.7301500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87717, 'Montechiaro d''Acqui', 'Montechiaro d''Acqui', '', 44.5944400, 8.3786500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87718, 'Montemarzino', 'Montemarzino', '', 44.8483500, 8.9936500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87719, 'Morsasco', 'Morsasco', '', 44.6653500, 8.5508500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87720, 'Odalengo Grande', 'Odalengo Grande', '', 45.1092200, 8.1674800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87721, 'Olivola', 'Olivola', '', 45.0372500, 8.3678400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87722, 'Orsara Bormida', 'Orsara Bormida', '', 44.6901500, 8.5627500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87723, 'Pietra Marazzi', 'Pietra Marazzi', '', 44.9426500, 8.6685400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87724, 'Piovera', 'Piovera', '', 44.9584500, 8.7359500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87725, 'Ponzano Monferrato', 'Ponzano Monferrato', '', 45.0848500, 8.2655300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87726, 'Ricaldone', 'Ricaldone', '', 44.7323500, 8.4681400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87727, 'Rosignano Monferrato', 'Rosignano Monferrato', '', 45.0805500, 8.3997400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87728, 'Sant''Agata Fossili', 'Sant''Agata Fossili', '', 44.7847500, 8.9211500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87729, 'Sezzadio', 'Sezzadio', '', 44.7848500, 8.5725500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87730, 'Solonghello', 'Solonghello', '', 45.1290500, 8.2832300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87731, 'Treville', 'Treville', '', 45.0968500, 8.3595400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87732, 'Arnad', 'Arnad', '', 45.6472600, 7.7170100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87733, 'Fontainemore', 'Fontainemore', '', 45.6474600, 7.8595200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87734, 'Hone', 'Hone', '', 45.6135600, 7.7385100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87735, 'Agra', 'Agra', '', 46.0366800, 8.7683300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87736, 'Azzio', 'Azzio', '', 45.8846800, 8.7085300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87737, 'Barasso', 'Barasso', '', 45.8404800, 8.7568300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87738, 'Bedero Valcuvia', 'Bedero Valcuvia', '', 45.9108800, 8.7955300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87739, 'Brenta', 'Brenta', '', 45.8941800, 8.6837300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87740, 'Brusimpiano', 'Brusimpiano', '', 45.9446800, 8.8895300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87741, 'Caronno Varesino', 'Caronno Varesino', '', 45.7357700, 8.8317300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87742, 'Castello Cabiaglio', 'Castello Cabiaglio', '', 45.8935800, 8.7576300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87743, 'Clivio', 'Clivio', '', 45.8627800, 8.9308300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87744, 'Cuasso al Monte', 'Cuasso al Monte', '', 45.9147800, 8.8792300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87745, 'Cugliate-Fabiasco', 'Cugliate-Fabiasco', '', 45.9456800, 8.8186300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87746, 'Cunardo', 'Cunardo', '', 45.9342800, 8.8077300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87747, 'Daverio', 'Daverio', '', 45.7779700, 8.7734300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87748, 'Duno', 'Duno', '', 45.9139800, 8.7376300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87749, 'Gorla Minore', 'Gorla Minore', 'Gorla Minor,Gorla Minore,Gorla-Minore,Gòrla Minor,ge er la mi nuo lei,Горла-Миноре,Горла-Міноре,Գոռլա Մինորե,ゴルラ・ミノーレ,戈尔拉米诺雷', 45.6411700, 8.9026400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87750, 'Jerago Con Orago', 'Jerago Con Orago', '', 45.7046700, 8.7959300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87751, 'Leggiuno', 'Leggiuno', '', 45.8758800, 8.6206300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87752, 'Varano Borghi', 'Varano Borghi', '', 45.7740700, 8.7040300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87753, 'Albese Con Cassano', 'Albese Con Cassano', '', 45.7948800, 9.1636400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87754, 'Alserio', 'Alserio', '', 45.7788800, 9.2001400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87755, 'Cavallasca', 'Cavallasca', 'Cavalasca,Kavalaska,Kavallaska,ka wa la si ka,kavu~arrasuka,Каваласка,Кавалласка,Կավալասկա,カヴァッラスカ,卡瓦拉斯卡', 45.8095800, 9.0328400, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87756, 'Corrido', 'Corrido', 'Corid o Coret,Corid o Corét', 46.0475800, 9.1355400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87757, 'Fenegrò', 'Fenegro', '', 45.7015700, 8.9996400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87758, 'Laino', 'Laino', '', 45.9844800, 9.0754400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87759, 'Lasnigo', 'Lasnigo', '', 45.8819800, 9.2664400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87760, 'Albosaggia', 'Albosaggia', '', 46.1474900, 9.8540500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87761, 'Briosco', 'Briosco', '', 45.7100800, 9.2406400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87762, 'Cassinetta di Lugagnano', 'Cassinetta di Lugagnano', '', 45.4224700, 8.9060400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87763, 'Cogliate', 'Cogliate', '', 45.6459700, 9.0788400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87764, 'Correzzana', 'Correzzana', '', 45.6665800, 9.3075500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87765, 'Dresano', 'Dresano', 'Darexanum,Dresan,Drezano,de lei sa nuo,dorezano,Дрезано,Դրեզանո,ドレザーノ,德雷萨诺', 45.3729700, 9.3578500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87766, 'Gessate', 'Gessate', '', 45.5483800, 9.4377500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87767, 'Gudo Visconti', 'Gudo Visconti', '', 45.3740700, 9.0001400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87768, 'Lazzate', 'Lazzate', '', 45.6720700, 9.0842400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87769, 'Lesmo', 'Lesmo', '', 45.6485800, 9.3073500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87770, 'Macherio', 'Macherio', '', 45.6397400, 9.2739400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87771, 'Masate', 'Masate', '', 45.5670800, 9.4641500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87772, 'Mesero', 'Mesero', '', 45.5022700, 8.8554400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87773, 'Mezzago', 'Mezzago', '', 45.6289800, 9.4448500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87774, 'San Vittore Olona', 'San Vittore Olona', '', 45.5857700, 8.9413400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87775, 'Sulbiate', 'Sulbiate', '', 45.6404700, 9.4276200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87776, 'Veduggio Con Colzano', 'Veduggio Con Colzano', '', 45.7338800, 9.2702400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87777, 'Vizzolo Predabissi', 'Vizzolo Predabissi', '', 45.3558700, 9.3481500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87778, 'Adrara San Rocco', 'Adrara San Rocco', '', 45.7157800, 9.9590600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87779, 'Ambivere', 'Ambivere', '', 45.7195800, 9.5501500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87780, 'Aviatico', 'Aviatico', '', 45.7975800, 9.7714500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87781, 'Barbata', 'Barbata', '', 45.4749800, 9.7773600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87782, 'Bianzano', 'Bianzano', '', 45.7730900, 9.9181600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87783, 'Boltiere', 'Boltiere', '', 45.6008800, 9.5784500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87784, 'Bonate Sotto', 'Bonate Sotto', '', 45.6681800, 9.5586500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87785, 'Bossico', 'Bossico', '', 45.8283900, 10.0450600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87786, 'Chignolo d''Isola', 'Chignolo d''Isola', '', 45.6675800, 9.5276500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87787, 'Colzate', 'Colzate', '', 45.8171900, 9.8561500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87788, 'Corna Imagna', 'Corna Imagna', '', 45.8306800, 9.5448500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87789, 'Entratico', 'Entratico', '', 45.7077800, 9.8731600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87790, 'Filago', 'Filago', '', 45.6375800, 9.5563500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87791, 'Fiorano al Serio', 'Fiorano al Serio', '', 45.8001800, 9.8427600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87792, 'Fonteno', 'Fonteno', '', 45.7585900, 10.0185600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87793, 'Fuipiano Valle Imagna', 'Fuipiano Valle Imagna', '', 45.8542800, 9.5284500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87794, 'Gandellino', 'Gandellino', '', 45.9910900, 9.9461500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87795, 'Gaverina Terme', 'Gaverina Terme', '', 45.7557800, 9.8866600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87796, 'Gorlago', 'Gorlago', '', 45.6740800, 9.8229600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87797, 'Madone', 'Madone', '', 45.6502800, 9.5501500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87798, 'Premolo', 'Premolo', '', 45.8701900, 9.8746600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87799, 'Presezzo', 'Presezzo', '', 45.6920800, 9.5703500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87800, 'Riva di Solto', 'Riva di Solto', '', 45.7741800, 10.0394100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87801, 'Castelcovati', 'Castelcovati', '', 45.5019800, 9.9459600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87802, 'Borgo San Siro', 'Borgo San Siro', '', 45.2350600, 8.9133400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87803, 'Castana', 'Castana', '', 45.0267600, 9.2724600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87804, 'Chignolo Po', 'Chignolo Po', '', 45.1481700, 9.4815600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87805, 'Costa de'' Nobili', 'Costa de'' Nobili', '', 45.1321700, 9.3788600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87806, 'Frascarolo', 'Frascarolo', '', 45.0466600, 8.6820400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87807, 'Golferenzo', 'Golferenzo', '', 44.9610600, 9.3059600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87808, 'Magherno', 'Magherno', '', 45.2235700, 9.3293500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87809, 'Marcignago', 'Marcignago', 'Marchin''jago,Marciniacum,Marsgna,Marsgnà,ma er qi ni ya ge,marsyghnaghw,maruchinyago,Марчиньяго,Մարչինյագո,مارسيغناغو,マルチニャーゴ,马尔奇尼亚戈', 45.2530600, 9.0793500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87810, 'Marzano', 'Marzano', '', 45.2479700, 9.2950500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87811, 'Campagnola Cremasca', 'Campagnola Cremasca', '', 45.3984700, 9.6694600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87812, 'Casaletto Vaprio', 'Casaletto Vaprio', '', 45.4081700, 9.6287600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87813, 'Cella Dati', 'Cella Dati', '', 45.0952700, 10.2214800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87814, 'Derovere', 'Derovere', '', 45.1099700, 10.2479800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87815, 'Drizzona', 'Drizzona', '', 45.1421700, 10.3502800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87816, 'Malagnino', 'Malagnino', '', 45.1347700, 10.1147700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87817, 'Spinadesco', 'Spinadesco', 'Spinadesch,Spinadesco vald,Spinadescum,Spinadesko,si pi na de si ke,supinadesuko,Спинадеско,Спінадеско,Սպինադեսկո,スピナデスコ,斯皮纳德斯科', 45.1491700, 9.9263700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87818, 'Castelbelforte', 'Castelbelforte', '', 45.2120800, 10.8924900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87819, 'Motteggiana', 'Motteggiana', 'Motegiana,Mottedzhana,Muntichiana,Munticiana,Munticiàna,mo tai gu na,mottejjana,Моттеджана,Մոթեջանա,モッテッジャーナ,莫泰贾纳', 45.0330700, 10.7626900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87820, 'Cunevo', 'Cunevo', '', 46.2864100, 11.0345700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87821, 'Daiano', 'Daiano', '', 46.3016100, 11.4490800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87822, 'Dorsino', 'Dorsino', '', 46.0727000, 10.8973700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87823, 'Isera', 'Isera', '', 45.8876000, 11.0091800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87824, 'Ronchi Valsugana', 'Ronchi Valsugana', '', 46.0684100, 11.4351900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87825, 'Rivoli Veronese', 'Rivoli Veronese', '', 45.5724900, 10.8117800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87826, 'Selva di Progno', 'Selva di Progno', '', 45.6113900, 11.1379900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87827, 'Alonte', 'Alonte', '', 45.3658900, 11.4271000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87828, 'Altissimo', 'Altissimo', '', 45.6142900, 11.2518900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87829, 'Asigliano Veneto', 'Asigliano Veneto', '', 45.3046900, 11.4464000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87830, 'Brogliano', 'Brogliano', '', 45.5891900, 11.3654900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87831, 'Campolongo sul Brenta', 'Campolongo sul Brenta', '', 45.8271000, 11.7008000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87832, 'Carrè', 'Carre', '', 45.7488000, 11.4577900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87833, 'Enego', 'Enego', '', 45.9416100, 11.7055000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87834, 'Mason Vicentino', 'Mason Vicentino', '', 45.7186000, 11.6068000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87835, 'Montecchio Precalcino', 'Montecchio Precalcino', '', 45.6657000, 11.5636000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87836, 'Montegalda', 'Montegalda', '', 45.4460900, 11.6750000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87837, 'Mossano', 'Mossano', '', 45.4195100, 11.5538200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87838, 'Mussolente', 'Mussolente', '', 45.7792000, 11.8062000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87839, 'Pove del Grappa', 'Pove del Grappa', '', 45.7982000, 11.7299000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87840, 'Sarego', 'Sarego', '', 45.4076900, 11.4019000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87841, 'Alano di Piave', 'Alano di Piave', '', 45.9068100, 11.9084000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87842, 'Altivole', 'Altivole', '', 45.7537000, 11.9562000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87843, 'Segusino', 'Segusino', '', 45.9170100, 11.9556000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87844, 'Cartura', 'Cartura', '', 45.2683900, 11.8568100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87845, 'Urbana', 'Urbana', '', 45.1927800, 11.4449000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87846, 'Vighizzolo d''Este', 'Vighizzolo d''Este', '', 45.1762900, 11.6247100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87847, 'Villafranca Padovana', 'Villafranca Padovana', '', 45.4918900, 11.7935000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87848, 'Arquà Polesine', 'Arqua Polesine', '', 45.0100800, 11.7398100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87849, 'Castelnovo Bariano', 'Castelnovo Bariano', '', 45.0273800, 11.2876000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87850, 'Frassinelle Polesine', 'Frassinelle Polesine', '', 44.9951800, 11.6988100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87851, 'Solignano', 'Solignano', '', 44.6130600, 9.9754800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87852, 'Capolona', 'Capolona', '', 43.5668500, 11.8637400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87853, 'Montecreto', 'Montecreto', '', 44.2459600, 10.7176000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87854, 'San Prospero', 'San Prospero', '', 44.7896700, 11.0221000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87855, 'Voghiera', 'Voghiera', '', 44.7555800, 11.7518200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87856, 'Ragoli', 'Ragoli', '', 46.0542300, 10.7785500, 'IT', '2016-11-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87857, 'Barchi', 'Barchi', '', 43.6728000, 12.9282300, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87858, 'Casteldelci', 'Casteldelci', '', 43.7911600, 12.1551400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87859, 'Montefelcino', 'Montefelcino', '', 43.7347600, 12.8339600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87860, 'Gualdo', 'Gualdo', '', 43.0658500, 13.3432800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87861, 'Maltignano', 'Maltignano', '', 42.8322500, 13.6879900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87862, 'Monte Vidon Combatte', 'Monte Vidon Combatte', '', 43.0489500, 13.6311900, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87863, 'Smerillo', 'Smerillo', '', 43.0051500, 13.4449800, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87864, 'Comano', 'Comano', '', 44.2933500, 10.1310900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87865, 'Giuncugnano', 'Giuncugnano', 'Dzhunkun''jano,Dzhunkunjana,Dzhunkunjano,Giuncugnanu,Iuncunianum,Junkunyano,junkunyano,zhun ku ni ya nuo,Джункуньяно,Джункуняна,Джункуняно,Ջունկունյանո,ジュンクニャーノ,准库尼亚诺', 44.2105500, 10.2471900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87866, 'Montescudaio', 'Montescudaio', '', 43.3260300, 10.6260200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87867, 'Valtopina', 'Valtopina', '', 43.0567400, 12.7530700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87868, 'Arcinazzo Romano', 'Arcinazzo Romano', '', 41.8797200, 13.1143900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87869, 'Canterano', 'Canterano', '', 41.9432200, 13.0380900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87870, 'Jenne', 'Jenne', '', 41.8888200, 13.1695900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87871, 'Montelibretti', 'Montelibretti', '', 42.1355300, 12.7386800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87872, 'Ponzano Romano', 'Ponzano Romano', '', 42.2569300, 12.5704700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87873, 'Rocca Canterano', 'Rocca Canterano', '', 41.9565200, 13.0217900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87874, 'Rocca Santo Stefano', 'Rocca Santo Stefano', '', 41.9105200, 13.0237900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87875, 'Roccagorga', 'Roccagorga', '', 41.5251100, 13.1551000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87876, 'Coreno Ausonio', 'Coreno Ausonio', '', 41.3473500, 13.7764800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87877, 'Bairo', 'Bairo', '', 45.3860600, 7.7553200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87878, 'Baldissero Canavese', 'Baldissero Canavese', '', 45.4102600, 7.7442200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87879, 'Angrogna', 'Angrogna', 'Angreugna,Angruenha', 44.8435400, 7.2242200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87880, 'Rivalta Bormida', 'Rivalta Bormida', '', 44.7097500, 8.5517500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87881, 'Rivarone', 'Rivarone', '', 44.9768600, 8.7156500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87882, 'Rocca Grimalda', 'Rocca Grimalda', '', 44.6714500, 8.6484500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87883, 'Spineto Scrivia', 'Spineto Scrivia', '', 44.8373500, 8.8737500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87884, 'Tagliolo Monferrato', 'Tagliolo Monferrato', '', 44.6383500, 8.6658500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87885, 'Tassarolo', 'Tassarolo', '', 44.7281100, 8.7716400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87886, 'Terzo', 'Terzo', '', 44.6704500, 8.4216400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87887, 'Vignole Borbera', 'Vignole Borbera', '', 44.7081900, 8.8902600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87888, 'Villadeati', 'Villadeati', '', 45.0722500, 8.1679300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87889, 'Villamiroglio', 'Villamiroglio', '', 45.1345500, 8.1710300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87890, 'Villaromagnano', 'Villaromagnano', '', 44.8496500, 8.8877500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87891, 'Visone', 'Visone', '', 44.6618400, 8.5007500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87892, 'Volpeglino', 'Volpeglino', '', 44.8929600, 8.9594500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87893, 'Allein', 'Allein', '', 45.8072300, 7.2726200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87894, 'Avise', 'Avise', '', 45.7088600, 7.1399000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87895, 'Donnas', 'Donnas', '', 45.6028600, 7.7749100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87896, 'Doues', 'Doues', '', 45.8191600, 7.3060000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87897, 'Gignod', 'Gignod', '', 45.7799600, 7.2964000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87898, 'Jovencan', 'Jovencan', '', 45.7148600, 7.2726000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87899, 'Nus', 'Nus', '', 45.7402600, 7.4666000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87900, 'Ollomont', 'Ollomont', '', 45.8497600, 7.3106000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87901, 'Perloz', 'Perloz', '', 45.6138600, 7.8081100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87902, 'Pont-Bozet', 'Pont-Bozet', '', 45.6072600, 7.6864100, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87903, 'Valgrisenche', 'Valgrisenche', '', 45.6303600, 7.0640000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87904, 'Villeneuve', 'Villeneuve', '', 45.7020100, 7.2068200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87905, 'Armo', 'Armo', '', 44.0877300, 7.9154500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87906, 'Boissano', 'Boissano', '', 44.1358300, 8.2215500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87907, 'Calice Ligure', 'Calice Ligure', '', 44.2049300, 8.2953500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87908, 'Casanova Lerrone', 'Casanova Lerrone', '', 44.0321300, 8.0471500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87909, 'Castelvecchio di Rocca Barbena', 'Castelvecchio di Rocca Barbena', '', 44.1298300, 8.1166500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87910, 'Massimino', 'Massimino', '', 44.2995300, 8.0713400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87911, 'Tovo San Giacomo', 'Tovo San Giacomo', '', 44.1759300, 8.2704500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87912, 'Mele', 'Mele', '', 44.4457300, 8.7488900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87913, 'Savignone', 'Savignone', '', 44.5643500, 8.9872600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87914, 'Bardello', 'Bardello', '', 45.8359700, 8.6968300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87915, 'Bisuschio', 'Bisuschio', '', 45.8714800, 8.8684300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87916, 'Bregano', 'Bregano', '', 45.8257800, 8.6877300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87917, 'Brunello', 'Brunello', 'Brunadellum,Brunell,Brunello,Brunello vald,Brunelo,bu lu nei luo,burunerro,Брунелло,Բրունելո,ブルネッロ,布鲁内洛', 45.7649700, 8.7953300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87918, 'Buguggiate', 'Buguggiate', 'Bueguegiaa,Bugudzhate,Bugujate,Buguzatum,Bügügiaa,bu gu gu tai,bugujjate,Бугуджате,Բուգուջատե,ブグッジャーテ,布古贾泰', 45.7822700, 8.8106300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87919, 'Cadrezzate', 'Cadrezzate', '', 45.7992700, 8.6433300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87920, 'Cantello', 'Cantello', '', 45.8224800, 8.8959300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87921, 'Casale Litta', 'Casale Litta', '', 45.7678700, 8.7413300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87922, 'Cazzago Brabbia', 'Cazzago Brabbia', '', 45.7958800, 8.7348300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87923, 'Cremenaga', 'Cremenaga', '', 45.9893800, 8.8033300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87924, 'Crosio della Valle', 'Crosio della Valle', '', 45.7599700, 8.7704300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87925, 'Cuveglio', 'Cuveglio', 'Cueei,Cuvelium,Cüéi,Kuatro-Kastela,Kuvel''jo,Kuvel''o,Kuvelio,Kuvelo,ku wei liao,kuvu~erio,Куатро-Кастела,Кувельйо,Кувельо,Кувељо,Կուվելիո,クヴェーリオ,库韦廖', 45.9060800, 8.7333300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87926, 'Cuvio', 'Cuvio', '', 45.8961800, 8.7341300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87927, 'Ferrera di Varese', 'Ferrera di Varese', '', 45.9327800, 8.7891300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87928, 'Galliate Lombardo', 'Galliate Lombardo', '', 45.7848700, 8.7704300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87929, 'Germignaga', 'Germignaga', '', 45.9912800, 8.7240300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87930, 'Grantola', 'Grantola', '', 45.9491800, 8.7743300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87931, 'Inarzo', 'Inarzo', '', 45.7857800, 8.7356300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87932, 'Luvinate', 'Luvinate', '', 45.8395800, 8.7719300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87933, 'Marchirolo', 'Marchirolo', '', 45.9478800, 8.8334300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87934, 'Monvalle', 'Monvalle', 'Monvale,Monvall,Monvalle,Monvallum,meng wa lai,mon''vu~arre,Монвалле,Մոնվալե,モンヴァッレ,蒙瓦莱', 45.8581000, 8.6308800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87935, 'Morazzone', 'Morazzone', '', 45.7644700, 8.8281300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87936, 'Sangiano', 'Sangiano', '', 45.8750800, 8.6333300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87937, 'Albiolo', 'Albiolo', '', 45.8055800, 8.9392400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87938, 'Alzate Brianza', 'Alzate Brianza', '', 45.7697800, 9.1820400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87939, 'Capiago-Intimiano-Olmeda', 'Capiago-Intimiano-Olmeda', '', 45.7689800, 9.1276400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87940, 'Carugo', 'Carugo', '', 45.7084800, 9.1968400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87941, 'Cassina Rizzardi', 'Cassina Rizzardi', '', 45.7522800, 9.0245400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87942, 'Castelmarte', 'Castelmarte', '', 45.8323800, 9.2330400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87943, 'Cerano d''Intelvi', 'Cerano d''Intelvi', '', 45.9444700, 9.0876700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87944, 'Colonno', 'Colonno', 'Culonn,Culònn', 45.9576800, 9.1529400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87945, 'Cucciago', 'Cucciago', 'Cusciagh,Cutiacum,Kuchago,Kuchchago,Kuchchiago,ku qia ge,kutchago,Кучаго,Куччаго,Куччиаго,Կուչագո,クッチャーゴ,库恰戈', 45.7392800, 9.0929400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87946, 'Cusino', 'Cusino', 'Cusin,Cùsin', 46.0748900, 9.1526400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87947, 'Dosso del Liro', 'Dosso del Liro', '', 46.1639900, 9.2729400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87948, 'Figino Serenza', 'Figino Serenza', '', 45.7104800, 9.1311400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87949, 'Guanzate', 'Guanzate', '', 45.7275800, 9.0198400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87950, 'Lambrugo', 'Lambrugo', '', 45.7587800, 9.2395400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87951, 'Limido Comasco', 'Limido Comasco', '', 45.6891700, 8.9798400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87952, 'Lipomo', 'Lipomo', '', 45.7928800, 9.1202400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87953, 'Longone al Segrino', 'Longone al Segrino', '', 45.8142800, 9.2514400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87954, 'Luisago', 'Luisago', '', 45.7628800, 9.0354400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87955, 'Magreglio', 'Magreglio', '', 45.9209800, 9.2626400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87956, 'Proserpio', 'Proserpio', '', 45.8282800, 9.2455400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87957, 'Mantello', 'Mantello', '', 46.1524900, 9.4889400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87958, 'Montagna in Valtellina', 'Montagna in Valtellina', '', 46.1784900, 9.9029500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87959, 'Ponte in Valtellina', 'Ponte in Valtellina', '', 46.1750000, 9.9778500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87960, 'San Giacomo Filippo', 'San Giacomo Filippo', '', 46.3376900, 9.3712400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87961, 'Spriana', 'Spriana', '', 46.2203000, 9.8642500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87962, 'Talamona', 'Talamona', '', 46.1384900, 9.6129400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87963, 'Tartano', 'Tartano', '', 46.1055400, 9.6786400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87964, 'Tovo di Sant''Agata', 'Tovo di Sant''Agata', '', 46.2450500, 10.2467000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87965, 'Vervio', 'Vervio', '', 46.2528500, 10.2405600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87966, 'Aicurzio', 'Aicurzio', '', 45.6399800, 9.4149500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87967, 'Albairate', 'Albairate', '', 45.4195700, 8.9374400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87968, 'Bellinzago Lombardo', 'Bellinzago Lombardo', '', 45.5420700, 9.4459500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87969, 'Bubbiano', 'Bubbiano', '', 45.3272700, 9.0145500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87970, 'Burago di Molgora', 'Burago di Molgora', '', 45.5964800, 9.3816500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87971, 'Busnago', 'Busnago', '', 45.6164800, 9.4637500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87972, 'Grezzago', 'Grezzago', '', 45.5910800, 9.4972500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87973, 'Ronco Briantino', 'Ronco Briantino', '', 45.6662800, 9.4053500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87974, 'San Giorgio Su Legnano', 'San Giorgio Su Legnano', '', 45.5737700, 8.9137400, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87975, 'Settala', 'Settala', '', 45.4535700, 9.3871500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87976, 'Sovico', 'Sovico', '', 45.6459800, 9.2627500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87977, 'Vedano al Lambro', 'Vedano al Lambro', '', 45.6087800, 9.2678500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87978, 'Zelo Surrigone', 'Zelo Surrigone', '', 45.3876700, 8.9850400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87979, 'Adrara San Martino', 'Adrara San Martino', '', 45.7022800, 9.9489600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87980, 'Arzago d''Adda', 'Arzago d''Adda', '', 45.4813700, 9.5641500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87981, 'Azzano San Paolo', 'Azzano San Paolo', '', 45.6579800, 9.6730500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87982, 'Bagnatica', 'Bagnatica', '', 45.6608800, 9.7810600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87983, 'Bariano', 'Bariano', '', 45.5125800, 9.7036600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87984, 'Berbenno', 'Berbenno', '', 45.8147800, 9.5710500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87985, 'Berzo San Fermo', 'Berzo San Fermo', '', 45.7193800, 9.9031600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87986, 'Bolgare', 'Bolgare', '', 45.6324200, 9.8141200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87987, 'Cavernago', 'Cavernago', '', 45.6252800, 9.7655600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87988, 'Chiuduno', 'Chiuduno', '', 45.6506800, 9.8494600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87989, 'Cortenuova', 'Cortenuova', '', 45.5389800, 9.7878600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87990, 'Credaro', 'Credaro', '', 45.6605800, 9.9310600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87991, 'Dossena', 'Dossena', '', 45.8802900, 9.6967500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87992, 'Fino del Monte', 'Fino del Monte', '', 45.8926900, 9.9940600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87993, 'Gandosso', 'Gandosso', '', 45.6588800, 9.8888600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87994, 'Grassobbio', 'Grassobbio', '', 45.6568800, 9.7256500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87995, 'Grone', 'Grone', '', 45.7272200, 9.9088500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87996, 'Isso', 'Isso', '', 45.4767800, 9.7586600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87997, 'Levate', 'Levate', '', 45.6251800, 9.6241500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87998, 'Lurano', 'Lurano', '', 45.5656800, 9.6401600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(87999, 'Montello', 'Montello', '', 45.6720800, 9.8056600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88000, 'Morengo', 'Morengo', '', 45.5314800, 9.7058600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88001, 'Mornico al Serio', 'Mornico al Serio', '', 45.5913800, 9.8092600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88002, 'Ranzanico', 'Ranzanico', '', 45.7883900, 9.9350600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88003, 'Rogno', 'Rogno', '', 45.8565900, 10.1321600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88004, 'Roncobello', 'Roncobello', '', 45.9556900, 9.7523500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88005, 'Roncola', 'Roncola', '', 45.7686800, 9.5606500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88006, 'Songavazzo', 'Songavazzo', '', 45.8794900, 9.9895600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88007, 'Suisio', 'Suisio', '', 45.6570800, 9.5022500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88008, 'Terno d''Isola', 'Terno d''Isola', '', 45.6854800, 9.5309500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88009, 'Villa d''Adda', 'Villa d''Adda', '', 45.7139800, 9.4616500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88010, 'Villa d''Ogna', 'Villa d''Ogna', '', 45.9046900, 9.9308500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88011, 'Barbariga', 'Barbariga', '', 45.4050800, 10.0543700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88012, 'Brandico', 'Brandico', '', 45.4541800, 10.0526700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88013, 'Caino', 'Caino', '', 45.6093900, 10.3131700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88014, 'Calvagese della Riviera', 'Calvagese della Riviera', '', 45.5392200, 10.4460500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88015, 'Capovalle', 'Capovalle', '', 45.7533900, 10.5444700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88016, 'Capriano del Colle', 'Capriano del Colle', '', 45.4747800, 10.1322700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88017, 'Castrezzato', 'Castrezzato', '', 45.5112800, 9.9808600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88018, 'Cellatica', 'Cellatica', '', 45.5819800, 10.1801700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88019, 'Corzano', 'Corzano', '', 45.4437800, 10.0073700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88020, 'Gianico', 'Gianico', '', 45.8655900, 10.1748600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88021, 'Maclodio', 'Maclodio', '', 45.4777800, 10.0421700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88022, 'Montirone', 'Montirone', '', 45.4463800, 10.2287700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88023, 'Niardo', 'Niardo', '', 45.9759900, 10.3332600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88024, 'Nuvolera', 'Nuvolera', '', 45.5321800, 10.3691700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88025, 'Polaveno', 'Polaveno', '', 45.6614800, 10.1239600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88026, 'Pontoglio', 'Pontoglio', '', 45.5693800, 9.8534600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88027, 'Roncadelle', 'Roncadelle', '', 45.5271800, 10.1540700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88028, 'San Zeno Naviglio', 'San Zeno Naviglio', '', 45.4925800, 10.2184700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88029, 'Trenzano', 'Trenzano', '', 45.4772800, 10.0106600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88030, 'Zone', 'Zone', '', 45.7633900, 10.1158600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88031, 'Battuda', 'Battuda', '', 45.2746600, 9.0780500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88032, 'Borgarello', 'Borgarello', 'Borgarello,Bulgarellum,Burgare,Burgaré,bo er jia lei luo,borugarerro,bwrgharylw,Боргарелло,Բորգարելլո,بورغاريلو,ボルガレッロ,博尔加雷洛', 45.2406600, 9.1405500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88033, 'Bosnasco', 'Bosnasco', '', 45.0640000, 9.3569200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88034, 'Casanova Lonati', 'Casanova Lonati', '', 45.0944600, 9.2134500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88035, 'Castello d''Agogna', 'Castello d''Agogna', '', 45.2345600, 8.6871400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88036, 'Linarolo', 'Linarolo', '', 45.1623600, 9.2699500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88037, 'Lirio', 'Lirio', '', 44.9944600, 9.2565600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88038, 'Monticelli Pavese', 'Monticelli Pavese', '', 45.1110700, 9.5127600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88039, 'Nicorvo', 'Nicorvo', '', 45.2856600, 8.6679400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88040, 'Oliva Gessi', 'Oliva Gessi', '', 45.0059700, 9.1731700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88041, 'Pinarolo Po', 'Pinarolo Po', 'Pinariolum Viqueriorum,Pinaroe,Pinarolo Po,Pinarolo-Po,Pinarö,bynarwlw bw,pi na luo luo bo,Пинароло-По,Пінароло-По,Պինարոլո Պո,بينارولو بو,ピナローロ・ポー,皮纳罗洛波', 45.0698600, 9.1672500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88042, 'Sommo', 'Sommo', '', 45.1331600, 9.0865500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88043, 'Spessa', 'Spessa', '', 45.1135600, 9.3485600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88044, 'Torre d''Arese', 'Torre d''Arese', '', 45.2427700, 9.3173500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88045, 'Torrevecchia Pia', 'Torrevecchia Pia', '', 45.2819700, 9.2963500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88046, 'Trivolzio', 'Trivolzio', '', 45.2584600, 9.0427500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88047, 'Valle Salimbene', 'Valle Salimbene', '', 45.1719600, 9.2344500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88048, 'Villa Biscossi', 'Villa Biscossi', '', 45.0906600, 8.7871500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88049, 'Vistarino', 'Vistarino', '', 45.2107700, 9.3082500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88050, 'Bonemerse', 'Bonemerse', '', 45.1136700, 10.0774700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88051, 'Ca'' d''Andrea', 'Ca'' d''Andrea', '', 45.1195700, 10.2774800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88052, 'Casaletto di Sopra', 'Casaletto di Sopra', '', 45.4191800, 9.7825600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88053, 'Castelvisconti', 'Castelvisconti', '', 45.3053700, 9.9410700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88054, 'Chieve', 'Chieve', '', 45.3404700, 9.6164600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88055, 'Corte de'' Frati', 'Corte de'' Frati', '', 45.2184700, 10.1018700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88056, 'Cremosano', 'Cremosano', '', 45.3946700, 9.6382600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88057, 'Fiesco', 'Fiesco', '', 45.3373700, 9.7778600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88058, 'Gombito', 'Gombito', '', 45.2618700, 9.7285600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88059, 'Martignana di Po', 'Martignana di Po', '', 45.0110700, 10.3797800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88060, 'Monte Cremasco', 'Monte Cremasco', '', 45.3722400, 9.5728800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88061, 'Pianengo', 'Pianengo', '', 45.4021700, 9.6947600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88062, 'Pieranica', 'Pieranica', '', 45.4261700, 9.6102600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88063, 'Quintano', 'Quintano', '', 45.4204700, 9.6185600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88064, 'Ricengo', 'Ricengo', '', 45.4056700, 9.7239600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88065, 'Borgofranco sul Po', 'Borgofranco sul Po', '', 45.0465800, 11.2093000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88066, 'Felonica', 'Felonica', 'Felonica,Felonika,Felònica,Fenonica,fei luo ni ka,feronika,flwnycha,Фелоника,Фелоніка,Ֆելոնիկա,فلونیچا,フェローニカ,费洛尼卡', 44.9789800, 11.3537000, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88067, 'Mariana Mantovana', 'Mariana Mantovana', '', 45.1928800, 10.4868800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88068, 'Schivenoglia', 'Schivenoglia', '', 44.9949800, 11.0730000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88069, 'Villa Poma', 'Villa Poma', 'Mulum,Vila Poma,Villa-Poma,Viła Poma,Vìla Póma,wei la bo ma,Вилла-Пома,Вілла-Пома,Վիլա Պոմա,ヴィッラ・ポーマ,维拉波马', 45.0023800, 11.1145000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88070, 'Amblar', 'Amblar', '', 46.3954100, 11.1467700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88071, 'Bieno', 'Bieno', '', 46.0815100, 11.5560900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88072, 'Bondo', 'Bondo', '', 46.0003000, 10.6919700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88073, 'Bondone', 'Bondone', '', 45.8064900, 10.5502700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88074, 'Calceranica al Lago', 'Calceranica al Lago', '', 46.0046000, 11.2436800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88075, 'Carano', 'Carano', '', 46.2915100, 11.4397800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88076, 'Carzano', 'Carzano', '', 46.0709100, 11.4937900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88077, 'Cavedine', 'Cavedine', '', 45.9952000, 10.9735800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88078, 'Cavizzana', 'Cavizzana', '', 46.3672100, 10.9581700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88079, 'Cis', 'Cis', '', 46.3984100, 11.0032700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88080, 'Don', 'Don', '', 46.3893100, 11.1364700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88081, 'Faedo', 'Faedo', '', 46.1924100, 11.1612800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88082, 'Faver', 'Faver', '', 46.1813100, 11.2372800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88083, 'Fornace', 'Fornace', '', 46.1180500, 11.2075100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88084, 'Frassilongo', 'Frassilongo', '', 46.0899100, 11.2971800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88085, 'Giustino', 'Giustino', '', 46.1513000, 10.7677700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88086, 'Cantalupa', 'Cantalupa', 'Cantaluva,Chantaloba,Kantalupa,kan ta lu pa,kantarupa,Канталупа,Կանտալուպա,カンタルーパ,坎塔卢帕', 44.9459400, 7.3303200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88087, 'Cercenasco', 'Cercenasco', '', 44.8620400, 7.4982200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88088, 'Chiesanuova', 'Chiesanuova', '', 45.4174500, 7.6555200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88089, 'Chiusa di San Michele', 'Chiusa di San Michele', '', 45.1042400, 7.3271100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88090, 'Ciconio', 'Ciconio', '', 45.3302500, 7.7585200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88091, 'Colleretto Castelnuovo', 'Colleretto Castelnuovo', '', 45.4223600, 7.6798100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88092, 'Colleretto Giacosa', 'Colleretto Giacosa', '', 45.4328600, 7.7985200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88093, 'Cossano Canavese', 'Cossano Canavese', '', 45.3877600, 7.9915200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88094, 'Fiorano Canavese', 'Fiorano Canavese', '', 45.4677600, 7.8337200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88095, 'Givoletto', 'Givoletto', '', 45.1622500, 7.4964200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88096, 'Grosso', 'Grosso', '', 45.2564500, 7.5573200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88097, 'Pratiglione', 'Pratiglione', '', 45.3527500, 7.5960200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88098, 'Ribordone', 'Ribordone', '', 45.4325500, 7.5023100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88099, 'Salerano Canavese', 'Salerano Canavese', '', 45.4580600, 7.8511200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88100, 'San Didero', 'San Didero', '', 45.1354400, 7.2130100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88101, 'San Germano Chisone', 'San Germano Chisone', '', 44.9020400, 7.2366200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88102, 'Pila', 'Pila', 'Pila,Pilla,Pyla,pira,Пила,Піла,Պիլա,ピーラ', 45.7699700, 8.0812200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88103, 'Rossa', 'Rossa', '', 45.8332700, 8.1243200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88104, 'Salasco', 'Salasco', 'Salasch', 45.3255600, 8.2642300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88105, 'Bogogno', 'Bogogno', '', 45.6630700, 8.5347300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88106, 'Briona', 'Briona', '', 45.5424700, 8.4797300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88107, 'Colazza', 'Colazza', '', 45.7925700, 8.5003300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88108, 'Comignago', 'Comignago', '', 45.7148700, 8.5640300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88109, 'Soriso', 'Soriso', '', 45.7403700, 8.4095300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88110, 'Veruno', 'Veruno', '', 45.6888700, 8.5286300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88111, 'Aisone', 'Aisone', '', 44.3139200, 7.2196300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88112, 'Albaretto della Torre', 'Albaretto della Torre', '', 44.5962400, 8.0646400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88113, 'Succivo', 'Succivo', '', 40.9680100, 14.2556300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88114, 'Pietraroja', 'Pietraroja', '', 41.3478200, 14.5496300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88115, 'Sant''Angelo A Cupolo', 'Sant''Angelo A Cupolo', '', 41.0691200, 14.8037400, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88116, 'Casamicciola Terme', 'Casamicciola Terme', '', 40.7466100, 13.9120200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88117, 'Castello di Cisterna', 'Castello di Cisterna', '', 40.9159400, 14.4111700, 'IT', '2015-08-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88118, 'San Vitaliano', 'San Vitaliano', '', 40.9244200, 14.4746300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88119, 'Scisciano', 'Scisciano', '', 40.9066300, 14.4745100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88120, 'Cassano Irpino', 'Cassano Irpino', '', 40.8704200, 15.0259500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88121, 'Cesinali', 'Cesinali', '', 40.8971100, 14.8277400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88122, 'Moschiano', 'Moschiano', '', 40.8731100, 14.6559400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88123, 'Sant''Angelo All''Esca', 'Sant''Angelo All''Esca', '', 41.0066200, 14.9930500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88124, 'Sperone', 'Sperone', '', 40.9525100, 14.6052400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88125, 'Cagnano Amiterno', 'Cagnano Amiterno', '', 42.4574400, 13.2278900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88126, 'Villa Sant''Angelo', 'Villa Sant''Angelo', '', 42.2704300, 13.5371000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88127, 'Liscia', 'Liscia', '', 41.9552400, 14.5553200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88128, 'Tufara', 'Tufara', '', 41.4820300, 14.9465400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88129, 'Castelluccio dei Sauri', 'Castelluccio dei Sauri', '', 41.3046000, 15.4756100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88130, 'Binetto', 'Binetto', '', 41.0234300, 16.7098800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88131, 'Poggiorsini', 'Poggiorsini', '', 40.9140300, 16.2560500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88132, 'Brienza', 'Brienza', '', 40.4775100, 15.6292700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88133, 'Figline Vegliaturo', 'Figline Vegliaturo', '', 39.2251900, 16.3303000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88134, 'Santa Maria del Cedro', 'Santa Maria del Cedro', '', 39.7462000, 15.8363800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88135, 'Amato', 'Amato', 'Amato,Amatu,Amatum,a ma tuo,amato,amatw,Амато,اماتو,アマート,阿马托', 38.9417900, 16.4622000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88136, 'Belcastro', 'Belcastro', '', 39.0179900, 16.7864100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88137, 'Feroleto Antico', 'Feroleto Antico', '', 38.9623900, 16.3878000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88138, 'Jacurso', 'Jacurso', '', 38.8464900, 16.3798000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88139, 'Sellia Marina', 'Sellia Marina', '', 38.8859900, 16.7493100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88140, 'Bova', 'Bova', '', 37.9950700, 15.9319000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88141, 'Furnari', 'Furnari', '', 38.1043600, 15.1235800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88142, 'Gualtieri Sicaminò', 'Gualtieri Sicamino', '', 38.1626700, 15.3169900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88143, 'Motta d''Affermo', 'Motta d''Affermo', '', 37.9809600, 14.3033700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88144, 'Roccafiorita', 'Roccafiorita', '', 37.9308600, 15.2673900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88145, 'Savoca', 'Savoca', '', 37.9532600, 15.3400900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88146, 'Camporotondo Etneo', 'Camporotondo Etneo', '', 37.5656500, 15.0031900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88147, 'San Pietro Clarenza', 'San Pietro Clarenza', '', 37.5688500, 15.0228900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88148, 'Valverde', 'Valverde', '', 37.5769500, 15.1241900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88149, 'Mazzarrone', 'Mazzarrone', '', 37.0883400, 14.5612800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88150, 'Ragalna', 'Ragalna', '', 37.6345500, 14.9469800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88151, 'Desulo', 'Desulo', '', 40.0146200, 9.2306100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88152, 'Villaperuccio', 'Villaperuccio', '', 39.1118300, 8.6700400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88153, 'Villa Sant''Antonio', 'Villa Sant''Antonio', '', 39.8591500, 8.9015300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88154, 'Donato', 'Donato', '', 45.5262600, 7.9096200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88155, 'Magnano', 'Magnano', '', 45.4633600, 8.0030200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88156, 'Piatto', 'Piatto', '', 45.5898600, 8.1353200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88157, 'Ronco Biellese', 'Ronco Biellese', '', 45.5784600, 8.0907200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88158, 'Sagliano Micca', 'Sagliano Micca', '', 45.6257600, 8.0433200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88159, 'Sostegno', 'Sostegno', '', 45.6528700, 8.2698200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88160, 'Tavigliano', 'Tavigliano', '', 45.6220600, 8.0517200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88161, 'Valdengo', 'Valdengo', '', 45.5670600, 8.1383200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88162, 'Villanova Biellese', 'Villanova Biellese', '', 45.4815600, 8.1943200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88163, 'Bulciago', 'Bulciago', '', 45.7505800, 9.2853400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88164, 'Calco', 'Calco', '', 45.7241800, 9.4125500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88165, 'Cassago Brianza', 'Cassago Brianza', 'Cassagh,Cassiciacum,Kasago Brjanca,Kassago-Brianca,ka sa ge bu li ya en zha,Касаго Брјанца,Кассаго-Брианца,Кассаго-Бріанца,Կասագո Բրիանցա,カッサーゴ・ブリアンツァ,卡萨戈布里亚恩扎', 45.7380800, 9.2934400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88166, 'Civate', 'Civate', '', 45.8280800, 9.3429400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88167, 'Cortenova', 'Cortenova', '', 46.0002900, 9.3845400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88168, 'Costa Masnaga', 'Costa Masnaga', '', 45.7696300, 9.2763200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88169, 'Erve', 'Erve', '', 45.8215800, 9.4528500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88170, 'Garlate', 'Garlate', '', 45.8120800, 9.3996400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88171, 'Imbersago', 'Imbersago', '', 45.7058800, 9.4444500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88172, 'Parlasco', 'Parlasco', '', 46.0178900, 9.3449400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88173, 'Pasturo', 'Pasturo', 'Pastur,Pasturium,Pasturo,pa si tu luo,pasuto~uro,Пастуро,Պաստուրո,パストゥーロ,帕斯图罗', 45.9516800, 9.4441400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88174, 'Perego', 'Perego', 'Pelegum,Peregh,Perego,pei lei ge,perego,Перего,Պերեգո,ペーレゴ,佩雷戈', 45.7375800, 9.3629500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88175, 'Perledo', 'Perledo', '', 46.0152900, 9.2956000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88176, 'Pescate', 'Pescate', 'Pescaa,Pescatum,Peskate,pei si ka tai,pesukate,Пескате,Պեսկատե,ペスカーテ,佩斯卡泰', 45.8334800, 9.3939500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88177, 'Rogeno', 'Rogeno', 'Rodzheno,Rogen,Rogenum,Rojeno,Rògen,luo jie nuo,rojeno,Роджено,Ռոջենո,ロージェノ,罗杰诺', 45.7823800, 9.2740400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88178, 'Santa Maria Hoè', 'Santa Maria Hoe', '', 45.7442800, 9.3744500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88179, 'Sirtori', 'Sirtori', 'Sirtol,Sirtori,Sirturi,shirutori,xi er tuo li,Сиртори,Сірторі,Սիրտորի,シルトリ,西尔托里', 45.7365800, 9.3308500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88180, 'Suello', 'Suello', 'Sueell,Suehllo,Suello,Suellum,Süèll,su ai luo,suerro,Суелло,Суэлло,Սուելլո,スエッロ,苏埃洛', 45.8167800, 9.3115400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88181, 'Valgreghentino', 'Valgreghentino', '', 45.7792800, 9.4134500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88182, 'Verderio Inferiore', 'Verderio Inferiore', '', 45.6655800, 9.4334500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88183, 'Verderio Superiore', 'Verderio Superiore', '', 45.6677800, 9.4403500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88184, 'Casaletto Lodigiano', 'Casaletto Lodigiano', '', 45.2933700, 9.3619400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88185, 'Cervignano d''Adda', 'Cervignano d''Adda', '', 45.3738700, 9.4240500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88186, 'Graffignana', 'Graffignana', '', 45.2064700, 9.4543600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88187, 'Mairago', 'Mairago', '', 45.2517700, 9.5783600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88188, 'Ospedaletto Lodigiano', 'Ospedaletto Lodigiano', '', 45.1687700, 9.5786600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88189, 'Pieve Fissiraga', 'Pieve Fissiraga', '', 45.2632700, 9.4583600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88190, 'San Martino in Strada', 'San Martino in Strada', '', 45.2749700, 9.5263600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88191, 'Sordio', 'Sordio', '', 45.3421700, 9.3638500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88192, 'Valera Fratta', 'Valera Fratta', '', 45.2571700, 9.3361500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88193, 'Villanova del Sillaro', 'Villanova del Sillaro', 'Villanova del Sillaro', 45.2379700, 9.4818600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88194, 'Montegridolfo', 'Montegridolfo', '', 43.8582600, 12.6899500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88195, 'Castelsilano', 'Castelsilano', '', 39.2691000, 16.7674100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88196, 'Filandari', 'Filandari', '', 38.6150800, 16.0314000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88197, 'Stefanaconi', 'Stefanaconi', 'Stefanacuni,Stefanakoni,Stephanaculum,si tai fa na ke ni,sutefanakoni,Стефанакони,Стефанаконі,Ստեֆանակոնի,ステファナーコニ,斯泰法纳科尼', 38.6778800, 16.1242000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88198, 'Arizzano', 'Arizzano', '', 45.9573800, 8.5829200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88199, 'Aurano', 'Aurano', '', 46.0003800, 8.5882200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88200, 'Cambiasca', 'Cambiasca', '', 45.9623800, 8.5446200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88201, 'Quarna Sotto', 'Quarna Sotto', '', 45.8691700, 8.3633200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88202, 'Seppiana', 'Seppiana', '', 46.0582800, 8.2166100, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88203, 'Vignone', 'Vignone', '', 45.9611800, 8.5637200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88204, 'Villette', 'Villette', '', 46.1318800, 8.5342200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88205, 'Bibiana', 'Bibiana', '', 44.7989400, 7.2882200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88206, 'Bruzolo', 'Bruzolo', '', 45.1409300, 7.1946300, 'IT', '2014-01-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88207, 'Cafasse', 'Cafasse', '', 45.2486500, 7.5188200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88208, 'Castagnole Piemonte', 'Castagnole Piemonte', '', 44.8981400, 7.5661200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88209, 'Castiglione Torinese', 'Castiglione Torinese', '', 45.1190500, 7.8071200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88210, 'Chianocco', 'Chianocco', '', 45.1485400, 7.1698100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88211, 'Chiaverano', 'Chiaverano', '', 45.4988600, 7.9026200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88212, 'Frossasco', 'Frossasco', '', 44.9217600, 7.3712500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88213, 'Garzigliana', 'Garzigliana', '', 44.8372400, 7.3744200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88214, 'Giaglione', 'Giaglione', '', 45.1391900, 7.0153400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88215, 'Gravere', 'Gravere', '', 45.1253400, 7.0175100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88216, 'Isolabella', 'Isolabella', 'Insula Bella,Isolabela,Izalabela,Izolabella,izoraberra,yi suo la bei la,Ізалабела,Ізолабелла,Изолабелла,Իզոլաբելլա,イゾラベッラ,伊索拉贝拉', 44.9064500, 7.9090300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88217, 'Issiglio', 'Issiglio', '', 45.4462600, 7.7532200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88218, 'La Cassa', 'La Cassa', '', 45.1803500, 7.5163200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88219, 'Levone', 'Levone', '', 45.3166500, 7.6063200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88220, 'Lugnacco', 'Lugnacco', '', 45.4450600, 7.7821200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88221, 'Lusigliè', 'Lusiglie', '', 45.3184500, 7.7646200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88222, 'Macello', 'Macello', '', 44.8511400, 7.3980200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88223, 'Mattie', 'Mattie', '', 45.1181400, 7.1151100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88224, 'Meugliano', 'Meugliano', '', 45.4902600, 7.7794200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88225, 'Mombello di Torino', 'Mombello di Torino', '', 45.0457500, 7.9208300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88226, 'Monastero di Lanzo', 'Monastero di Lanzo', '', 45.3018500, 7.4397100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88227, 'Moncenisio', 'Moncenisio', '', 45.2040400, 6.9846100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88228, 'Montaldo Torinese', 'Montaldo Torinese', '', 45.0653500, 7.8502300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88229, 'Pecco', 'Pecco', '', 45.4520600, 7.7774200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88230, 'Perosa Canavese', 'Perosa Canavese', '', 45.3970600, 7.8308200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88231, 'Pertusio', 'Pertusio', '', 45.3556500, 7.6415200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88232, 'Piobesi Torinese', 'Piobesi Torinese', '', 44.9329400, 7.6101200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88233, 'Piscina', 'Piscina', '', 44.9187400, 7.4253200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88234, 'Piverone', 'Piverone', '', 45.4455700, 8.0074500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88235, 'Porte', 'Porte', '', 44.8871400, 7.2698200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88236, 'Rivarossa', 'Rivarossa', '', 45.2495400, 7.7195300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88237, 'Roletto', 'Roletto', '', 44.9244400, 7.3323200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88238, 'Rorà', 'Rora', '', 44.7921400, 7.1990200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88239, 'Rosta', 'Rosta', '', 45.0679500, 7.4651200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88240, 'Rueglio', 'Rueglio', '', 45.4682600, 7.7546200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88241, 'San Carlo Canavese', 'San Carlo Canavese', '', 45.2445500, 7.6057200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88242, 'San Colombano Belmonte', 'San Colombano Belmonte', '', 45.3822500, 7.6210100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88243, 'Strambinello', 'Strambinello', '', 45.4230600, 7.7699200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88244, 'Usseaux', 'Usseaux', 'Ocelum ad Clusonem Fluvium,Owsso,Ucaus,Usa,Uso,Usseaus,Usseauso,Usseu,Usso,Uçaus,usseauzu,wu sai ya wu ke xi,Уса,Усо,Уссо,Ուսսո,ウッセアウズ,乌塞亚乌克西', 45.0489400, 7.0285100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88245, 'Vallo Torinese', 'Vallo Torinese', '', 45.2235500, 7.4963200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88246, 'Villanova Canavese', 'Villanova Canavese', '', 45.2435500, 7.5521200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88247, 'Vische', 'Vische', '', 45.3356600, 7.9448200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88248, 'Asigliano Vercellese', 'Asigliano Vercellese', '', 45.2614600, 8.4085300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88249, 'Caresanablot', 'Caresanablot', '', 45.3573600, 8.3920300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88250, 'San Giacomo Vercellese', 'San Giacomo Vercellese', '', 45.4981600, 8.3267300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88251, 'Cervatto', 'Cervatto', '', 45.8829700, 8.1623200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88252, 'Rassa', 'Rassa', '', 45.7682100, 8.0120800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88253, 'Riva Valdobbia', 'Riva Valdobbia', 'La Riva,Ripa Sessitum,Riva Valdobia,Riva-Val''dobbija,Ryva-Val''dobija,li wa wa er duo bi ya,Рива-Вальдоббия,Рива-Вальдоббія,Рыва-Вальдобія,Ռիվա Վալդոբիա,リーヴァ・ヴァルドッビア,里瓦瓦尔多比亚', 45.8309700, 7.9566100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88254, 'Scopa', 'Scopa', '', 45.7929700, 8.1140200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88255, 'Vocca', 'Vocca', '', 45.8326900, 8.1958000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88256, 'Barengo', 'Barengo', '', 45.5759700, 8.5140300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88257, 'Boca', 'Boca', '', 45.6789700, 8.4087300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88258, 'Casalbeltrame', 'Casalbeltrame', '', 45.4380600, 8.4665300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88259, 'Cavaglietto', 'Cavaglietto', '', 45.6021700, 8.5021300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88260, 'Cavaglio D''Agogna', 'Cavaglio D''Agogna', '', 45.6131700, 8.4861300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88261, 'Cureggio', 'Cureggio', '', 45.6748700, 8.4597300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88262, 'Dormelletto', 'Dormelletto', '', 45.7362700, 8.5666300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88263, 'Gargallo', 'Gargallo', '', 45.7287700, 8.4253300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88264, 'Maggiora', 'Maggiora', '', 45.6893700, 8.4223300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88265, 'Mandello Vitta', 'Mandello Vitta', '', 45.4956700, 8.4598300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88266, 'Miasino', 'Miasino', '', 45.8019700, 8.4297200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88267, 'Nibbiola', 'Nibbiola', '', 45.3723600, 8.6567400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88268, 'Pisano', 'Pisano', '', 45.7956700, 8.5148700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88269, 'Alto', 'Alto', '', 44.1086300, 8.0021500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88270, 'Baldissero d''Alba', 'Baldissero d''Alba', '', 44.7618400, 7.9086300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88271, 'Barolo', 'Barolo', '', 44.6109400, 7.9428400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88272, 'Battifollo', 'Battifollo', '', 44.3198300, 8.0109400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88273, 'Canosio', 'Canosio', '', 44.4558300, 7.0827200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88274, 'Castelletto Stura', 'Castelletto Stura', '', 44.4438300, 7.6392300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88275, 'Castelnuovo di Ceva', 'Castelnuovo di Ceva', '', 44.3536300, 8.1289400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88276, 'Cavallerleone', 'Cavallerleone', '', 44.7401400, 7.6639300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88277, 'Cerreto Langhe', 'Cerreto Langhe', 'Cerretto Langhe', 44.5748400, 8.0979400, 'IT', '2016-10-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88278, 'Cervasca', 'Cervasca', '', 44.3809300, 7.4712300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88279, 'Clavesana', 'Clavesana', '', 44.4833400, 7.9108400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88280, 'Cossano Belbo', 'Cossano Belbo', '', 44.6688400, 8.1986400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88281, 'Farigliano', 'Farigliano', '', 44.5120400, 7.9142400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88282, 'Frabosa Sottana', 'Frabosa Sottana', '', 44.3023300, 7.7975400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88283, 'Guarene', 'Guarene', '', 44.7400400, 8.0351400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88284, 'Igliano', 'Igliano', '', 44.4429400, 8.0133400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88285, 'Lagnasco', 'Lagnasco', '', 44.6250400, 7.5548300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88286, 'Lequio Berria', 'Lequio Berria', '', 44.6058400, 8.0981400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88287, 'Macra', 'Macra', '', 44.5001300, 7.1795200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88288, 'Marmora', 'Marmora', '', 44.4583300, 7.0940200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88289, 'Marsaglia', 'Marsaglia', '', 44.4528400, 7.9799400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88290, 'Monasterolo di Savigliano', 'Monasterolo di Savigliano', '', 44.6863400, 7.6195300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88291, 'Montaldo Roero', 'Montaldo Roero', '', 44.7683400, 7.9248300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88292, 'Montanera', 'Montanera', '', 44.4622300, 7.6656300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88293, 'Neviglie', 'Neviglie', '', 44.6919400, 8.1168400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88294, 'Oncino', 'Oncino', '', 44.6768300, 7.1903200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88295, 'Pagno', 'Pagno', '', 44.6117300, 7.4257200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88296, 'Pezzolo Valle Uzzone', 'Pezzolo Valle Uzzone', '', 44.5387400, 8.1939400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88297, 'Piozzo', 'Piozzo', '', 44.5138400, 7.8925400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88298, 'Priocca', 'Priocca', '', 44.7862400, 8.0642400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88299, 'Prunetto', 'Prunetto', '', 44.4889400, 8.1437400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88300, 'Rifreddo', 'Rifreddo', '', 44.6507300, 7.3464200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88301, 'Roaschia', 'Roaschia', '', 44.2702300, 7.4557300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88302, 'Roburent', 'Roburent', '', 44.3063300, 7.8922400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88303, 'Rocca Cigliè', 'Rocca Ciglie', '', 44.4452300, 7.9509400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88304, 'Roccasparvera', 'Roccasparvera', '', 44.3421300, 7.4415300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88305, 'Sale San Giovanni', 'Sale San Giovanni', '', 44.3991400, 8.0779400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88306, 'Santo Stefano Roero', 'Santo Stefano Roero', '', 44.7884400, 7.9409300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88307, 'Serralunga d''Alba', 'Serralunga d''Alba', '', 44.6100400, 7.9994400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88308, 'Somano', 'Somano', '', 44.5353400, 8.0078400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88309, 'Torresina', 'Torresina', '', 44.4336400, 8.0367400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88310, 'Treiso', 'Treiso', '', 44.6897400, 8.0881400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88311, 'Trezzo Tinella', 'Trezzo Tinella', '', 44.6770400, 8.1075400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88312, 'Valmala', 'Valmala', '', 44.5442300, 7.3460300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88313, 'Vicoforte', 'Vicoforte', '', 44.3639300, 7.8626400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88314, 'Villanova Solaro', 'Villanova Solaro', '', 44.7299400, 7.5744300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88315, 'Vottignasco', 'Vottignasco', '', 44.5641300, 7.5791300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88316, 'Aramengo', 'Aramengo', '', 45.1008500, 8.0000300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88317, 'Azzano d''Asti', 'Azzano d''Asti', '', 44.8734500, 8.2668400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88318, 'Buttigliera d''Asti', 'Buttigliera d''Asti', '', 45.0217500, 7.9510300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88319, 'Calosso', 'Calosso', '', 44.7399400, 8.2271400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88320, 'Castelnuovo Belbo', 'Castelnuovo Belbo', '', 44.8011000, 8.4123600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88321, 'Castel Rocchero', 'Castel Rocchero', '', 44.7183500, 8.4153400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88322, 'Celle Enomondo', 'Celle Enomondo', '', 44.8568500, 8.1237300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88323, 'Cerreto d''Asti', 'Cerreto d''Asti', '', 45.0521500, 8.0351300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88324, 'Cerro Tanaro', 'Cerro Tanaro', '', 44.8733500, 8.3587400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88325, 'Chiusano d''Asti', 'Chiusano d''Asti', '', 44.9866500, 8.1185300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88326, 'Frinco', 'Frinco', '', 45.0040500, 8.1719300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88327, 'Grana', 'Grana', '', 44.9983500, 8.2994400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88328, 'Loazzolo', 'Loazzolo', '', 44.6690400, 8.2584400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88329, 'Moasca', 'Moasca', '', 44.7635500, 8.2783400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88330, 'Moransengo', 'Moransengo', '', 45.1148500, 8.0252300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88331, 'Olmo Gentile', 'Olmo Gentile', '', 44.5857400, 8.2469400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88332, 'Penango', 'Penango', '', 45.0329500, 8.2517400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88333, 'Pino d''Asti', 'Pino d''Asti', '', 45.0574500, 7.9862300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88334, 'Portacomaro', 'Portacomaro', '', 44.9566500, 8.2580400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88335, 'Revigliasco d''Asti', 'Revigliasco d''Asti', '', 44.8575500, 8.1604400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88336, 'Roccaverano', 'Roccaverano', 'Rakaverana,Rocavran,Rocha Uverani,Rokkaverano,luo ka wei la nuo,rokkavu~erano,rwkafyranw,Ракаверана,Роккаверано,Ռոքավերանո,روكافيرانو,ロッカヴェラーノ,罗卡韦拉诺', 44.5922400, 8.2721400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88337, 'Rocchetta Palafea', 'Rocchetta Palafea', '', 44.7074400, 8.3453400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88338, 'Rocchetta Tanaro', 'Rocchetta Tanaro', '', 44.8586500, 8.3456400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88339, 'San Giorgio Scarampi', 'San Giorgio Scarampi', '', 44.6109400, 8.2424400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88340, 'San Marzano Oliveto', 'San Marzano Oliveto', '', 44.7544500, 8.2953400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88341, 'Scurzolengo', 'Scurzolengo', '', 44.9648500, 8.2791400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88342, 'Sessame', 'Sessame', '', 44.6706400, 8.3368400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88343, 'Settime', 'Settime', '', 44.9617500, 8.1143300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88344, 'Tonengo', 'Tonengo', '', 45.1176500, 8.0021300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88345, 'Viale', 'Viale', '', 45.0001500, 8.0499300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88346, 'Vigliano d''Asti', 'Vigliano d''Asti', '', 44.8340500, 8.2291400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88347, 'Albera Ligure', 'Albera Ligure', '', 44.7015900, 9.0672000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88348, 'Alzano Scrivia', 'Alzano Scrivia', '', 45.0180600, 8.8806500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88349, 'Basaluzzo', 'Basaluzzo', '', 44.7688500, 8.7048500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88350, 'Camagna Monferrato', 'Camagna Monferrato', '', 45.0176500, 8.4297400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88351, 'Carbonara Scrivia', 'Carbonara Scrivia', '', 44.8491500, 8.8697500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88352, 'Carentino', 'Carentino', '', 44.8288500, 8.4713400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88353, 'Carrega Ligure', 'Carrega Ligure', '', 44.6187900, 9.1756400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88354, 'Cartosio', 'Cartosio', '', 44.5902400, 8.4206500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88355, 'Castellania', 'Castellania', '', 44.7984500, 8.9303500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88356, 'Castelletto d''Erro', 'Castelletto d''Erro', '', 44.6259700, 8.3944200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88357, 'Castelletto d''Orba', 'Castelletto d''Orba', '', 44.6845500, 8.7039500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88358, 'Castelletto Monferrato', 'Castelletto Monferrato', '', 44.9811500, 8.5645400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88359, 'Cavatore', 'Cavatore', '', 44.6309900, 8.4527600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88360, 'Cerreto Grue', 'Cerreto Grue', '', 44.8425500, 8.9303500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88361, 'Denice', 'Denice', '', 44.5988400, 8.3331500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88362, 'Dernice', 'Dernice', '', 44.7666000, 9.0500100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88363, 'Garbagna', 'Garbagna', '', 44.7804500, 8.9978600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88364, 'Gremiasco', 'Gremiasco', '', 44.7962500, 9.1068600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88365, 'Grognardo', 'Grognardo', '', 44.6303400, 8.4926500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88366, 'Melazzo', 'Melazzo', '', 44.6439400, 8.4249500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88367, 'Merana', 'Merana', '', 44.5188400, 8.2982400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88368, 'Monleale', 'Monleale', '', 44.8843500, 8.9739500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88369, 'Montaldo Bormida', 'Montaldo Bormida', '', 44.6826500, 8.5878500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88370, 'Montecastello', 'Montecastello', '', 44.9494500, 8.6857500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88371, 'Mornese', 'Mornese', '', 44.6392500, 8.7561500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88372, 'Ispani', 'Ispani', '', 40.0873000, 15.5582700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88373, 'Pareto', 'Pareto', 'Parehta,Parej,Pareto,Paretum,Parèj,barytw,pa lei tuo,pareto,Парето,Парэта,Պարետո,باريتو,パレート,帕雷托', 44.5164400, 8.3818500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88374, 'Parodi Ligure', 'Parodi Ligure', '', 44.6697500, 8.7586500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88375, 'Pasturana', 'Pasturana', '', 44.7508500, 8.7492500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88376, 'Prasco', 'Prasco', '', 44.6393800, 8.5516700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88377, 'Crevoladossola', 'Crevoladossola', '', 46.1485800, 8.2974200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88378, 'Germagno', 'Germagno', '', 45.8925700, 8.3877200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88379, 'Loreglia', 'Loreglia', '', 45.9068700, 8.3713200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88380, 'Romallo', 'Romallo', '', 46.3972100, 11.0661700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88381, 'Samone', 'Samone', '', 46.0816100, 11.5225900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88382, 'San Lorenzo in Banale', 'San Lorenzo in Banale', '', 46.0766000, 10.9084700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88383, 'Scurelle', 'Scurelle', '', 46.0645100, 11.5056900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88384, 'Spera', 'Spera', '', 46.0703100, 11.5089900, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88385, 'Spiazzo', 'Spiazzo', '', 46.1036000, 10.7393700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88386, 'Strembo', 'Strembo', '', 46.1203000, 10.7508700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88387, 'Telve di Sopra', 'Telve di Sopra', '', 46.0713100, 11.4717900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88388, 'Terres', 'Terres', '', 46.3099100, 11.0230700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88389, 'Valda', 'Valda', '', 46.2072100, 11.2648800, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88390, 'Villa Rendena', 'Villa Rendena', '', 46.0627000, 10.7125000, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88391, 'Caldiero', 'Caldiero', '', 45.4143900, 11.1773900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88392, 'Cazzano di Tramigna', 'Cazzano di Tramigna', '', 45.4730900, 11.2028900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88393, 'Isola Rizza', 'Isola Rizza', '', 45.2922800, 11.1990000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88394, 'Mezzane di Sotto', 'Mezzane di Sotto', '', 45.4819900, 11.1272900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88395, 'Roverchiara', 'Roverchiara', '', 45.2679900, 11.2451000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88396, 'San Pietro di Morubio', 'San Pietro di Morubio', '', 45.2424800, 11.2270000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88397, 'Sorgà', 'Sorga', '', 45.2132800, 10.9798900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88398, 'Velo Veronese', 'Velo Veronese', '', 45.6066900, 11.0951900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88399, 'Cartigliano', 'Cartigliano', '', 45.7130000, 11.6956000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88400, 'Gambellara', 'Gambellara', '', 45.4597900, 11.3400900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88401, 'Gambugliano', 'Gambugliano', '', 45.5879900, 11.4385900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88402, 'Laghi', 'Laghi', '', 45.8245000, 11.2724900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88403, 'Nogarole Vicentino', 'Nogarole Vicentino', '', 45.5601900, 11.2882900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88404, 'Rotzo', 'Rotzo', '', 45.8619000, 11.3961900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88405, 'San Germano dei Berici', 'San Germano dei Berici', '', 45.4017900, 11.4713000, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88406, 'Sovizzo', 'Sovizzo', '', 45.5266900, 11.4461000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88407, 'Zugliano', 'Zugliano', '', 45.7298000, 11.5239900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88408, 'Rocca Pietore', 'Rocca Pietore', 'Roca Pietore,Rocca Pectoris,Roka Pietore,Roka-Petoreh,Rokka-P''etore,Rokka-Petore,luo ka pi ye tuo lei,Рока Пиеторе,Рока-Петорэ,Рокка-Пьеторе,Рокка-Пєторе,Ռոքա Պիետորե,ロッカ・ピエートレ,罗卡皮耶托雷', 46.4339200, 11.9767900, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88409, 'Tambre', 'Tambre', 'Tamber,Tambre,Tanbre,tan bu lei,tanbure,Тамбре,Տամբրե,タンブレ,坦布雷', 46.1263200, 12.4194100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88410, 'Boara Pisani', 'Boara Pisani', 'Boara Pizani,Boara-Pizani,Boaria,bo a la pi sa ni,Боара-Пизани,Боара-Пізані,Բոարա Պիզանի,ボアーラ・ピザーニ,博阿拉皮萨尼', 45.1080900, 11.7827100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88411, 'Cervarese Santa Croce', 'Cervarese Santa Croce', '', 45.4243900, 11.6879000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88412, 'Masi', 'Masi', 'Gorad Mazi,Maxi,Mazi,maji,Горад Мазі,Мази,Мазі,Մազի,マージ', 45.1088800, 11.4892100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88413, 'San Giorgio delle Pertiche', 'San Giorgio delle Pertiche', '', 45.5410000, 11.8940100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88414, 'Bagnolo di Po', 'Bagnolo di Po', '', 45.0154800, 11.5009100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88415, 'Canda', 'Canda', '', 45.0360800, 11.5033100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88416, 'Majano', 'Majano', '', 46.1875200, 13.0616200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88417, 'Treppo Carnico', 'Treppo Carnico', '', 46.5332300, 13.0429200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88418, 'Farra d''Isonzo', 'Farra d''Isonzo', '', 45.9080200, 13.5165400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88419, 'San Pietro in Cerro', 'San Pietro in Cerro', '', 45.0213700, 9.9498700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88420, 'Zerba', 'Zerba', '', 44.6655100, 9.2879500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88421, 'San Possidonio', 'San Possidonio', '', 44.8740200, 10.9808700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88422, 'Predappio', 'Predappio', '', 44.1031600, 11.9841300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88423, 'Cartoceto', 'Cartoceto', '', 43.7656600, 12.8834600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88424, 'Mercatino Conca', 'Mercatino Conca', '', 43.8701600, 12.4911500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88425, 'Monte Porzio', 'Monte Porzio', '', 43.6911600, 13.0468600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88426, 'Serrungarina', 'Serrungarina', '', 43.7466600, 12.8748600, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88427, 'Barbara', 'Barbara', '', 43.5803600, 13.0273600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88428, 'Castelleone di Suasa', 'Castelleone di Suasa', '', 43.6081600, 12.9779600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88429, 'Poggio San Marcello', 'Poggio San Marcello', '', 43.5111600, 13.0736700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88430, 'Force', 'Force', '', 42.9609500, 13.4876800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88431, 'Monteleone di Fermo', 'Monteleone di Fermo', '', 43.0478500, 13.5294800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88432, 'Filattiera', 'Filattiera', '', 44.3300500, 9.9330800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88433, 'Careggine', 'Careggine', '', 44.1199500, 10.3254000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88434, 'Fosciandora', 'Fosciandora', '', 44.1149500, 10.4585000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88435, 'Villa Collemandina', 'Villa Collemandina', '', 44.1585500, 10.3976000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88436, 'Orciano Pisano', 'Orciano Pisano', '', 43.4944400, 10.5115100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88437, 'Semproniano', 'Semproniano', '', 42.7292300, 11.5413400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88438, 'Lisciano Niccone', 'Lisciano Niccone', 'Lepsana,Liscianu Nicconi,Lishano Nikone,Lishano-Nikkone,Lishiano-Nikkone,Lishyjana-Nikoneh,li xia nuo ni ke nei,lisianonikone,lyshanw nykwny,Лишано Никоне,Лишано-Никконе,Лишиано-Никконе,Лішыяна-Ніконэ,Лішіано-Нікконе,Լիշանո Նիքոնե,ليشانو نيكوني,リシャーノ・ニッコーネ,利夏诺尼科内,리시아노니코네', 43.2468400, 12.1430500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88439, 'Villa San Giovanni in Tuscia', 'Villa San Giovanni in Tuscia', '', 42.2788200, 12.0534600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88440, 'Montenero Sabino', 'Montenero Sabino', '', 42.2812300, 12.8135800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88441, 'Campodimele', 'Campodimele', '', 41.3882200, 13.5308100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88442, 'Torre Caietani', 'Torre Caietani', 'Torre Cajetani', 41.7867200, 13.2652000, 'IT', '2016-09-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88443, 'Trivigliano', 'Trivigliano', '', 41.7757200, 13.2723000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88444, 'Carinaro', 'Carinaro', '', 40.9829100, 14.2196300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88445, 'Castello del Matese', 'Castello del Matese', '', 41.3667200, 14.3777300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88446, 'Curti', 'Curti', '', 41.0761600, 14.2803900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88447, 'Piana di Monte Verna', 'Piana di Monte Verna', '', 41.1671200, 14.3337300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88448, 'Villa di Briano', 'Villa di Briano', '', 41.0000100, 14.1607300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88449, 'Falciano del Massico', 'Falciano del Massico', '', 41.1627100, 13.9481200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88450, 'Casapesenna', 'Casapesenna', '', 40.9915100, 14.1361300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88451, 'Calvi', 'Calvi', '', 41.0716200, 14.8652400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88452, 'San Nazzaro', 'San Nazzaro', '', 41.0517200, 14.8572400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88453, 'San Nicola Manfredi', 'San Nicola Manfredi', 'Fanum Sancti Nicolai Manfredi,San Nikola Manfredi,San-Nikola-Manfredi,sannikollamanpeuledi,sheng ni ke la man fu lei di,Сан Никола Манфреди,Сан-Никола-Манфреди,Сан-Нікола-Манфреді,Սան Նիկոլա Մանֆրեդի,サン・ニコーラ・マンフレーディ,圣尼科拉曼夫雷迪,산니콜라만프레디', 41.0751000, 14.8243000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88454, 'Carbonara di Nola', 'Carbonara di Nola', '', 40.8744100, 14.5788400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88455, 'Massa di Somma', 'Massa di Somma', '', 40.8455100, 14.3751300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88456, 'Montella', 'Montella', '', 40.8437200, 15.0178500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88457, 'Pago del Vallo di Lauro', 'Pago del Vallo di Lauro', '', 40.8972100, 14.6076400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88458, 'Roccabascerana', 'Roccabascerana', '', 41.0184200, 14.7168400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88459, 'Tufo', 'Tufo', '', 41.0126200, 14.8178400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88460, 'Vallesaccarda', 'Vallesaccarda', '', 41.0631200, 15.2520500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88461, 'Felitto', 'Felitto', '', 40.3735100, 15.2430600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88462, 'Bugnara', 'Bugnara', '', 42.0238300, 13.8614100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88463, 'Morino', 'Morino', '', 41.8644200, 13.4570000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88464, 'Rivisondoli', 'Rivisondoli', '', 41.8702300, 14.0667100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88465, 'Castel Castagna', 'Castel Castagna', '', 42.5429400, 13.7164000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88466, 'Roccamorice', 'Roccamorice', '', 42.2127400, 14.0253100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88467, 'Palmoli', 'Palmoli', '', 41.9394400, 14.5814200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88468, 'Rocca San Giovanni', 'Rocca San Giovanni', '', 42.2460400, 14.4616200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88469, 'Castro', 'Castro', '', 40.0070200, 18.4257300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88470, 'Gagliato', 'Gagliato', '', 38.6757800, 16.4606100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88471, 'Settingiano', 'Settingiano', '', 38.9113900, 16.5139000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88472, 'Campo Calabro', 'Campo Calabro', 'Campum Magdalenae,Kampo Kalabro,Kampo-Kalabro,U Campu,kambw kalabrw,kan bo ka la bu luo,Кампо Калабро,Кампо-Калабро,Կամպո Կալաբրո,كامبو كالابرو,カンポ・カーラブロ,坎波卡拉布罗', 38.2160700, 15.6591900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88473, 'Maropati', 'Maropati', '', 38.4417800, 16.0975000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88474, 'Oppido Mamertina', 'Oppido Mamertina', '', 38.2933700, 15.9839000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88475, 'Riace', 'Riace', '', 38.4182800, 16.4812100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88476, 'San Pietro di Caridà', 'San Pietro di Carida', '', 38.5236800, 16.1353000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88477, 'Sant''Agata del Bianco', 'Sant''Agata del Bianco', '', 38.0924200, 16.0825100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88478, 'Buseto Palizzolo', 'Buseto Palizzolo', '', 38.0033900, 12.7091100, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88479, 'Trappeto', 'Trappeto', '', 38.0687500, 13.0379400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88480, 'Blufi', 'Blufi', '', 37.7520500, 14.0729600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88481, 'Alì Terme', 'Ali Terme', '', 38.0050600, 15.4226900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88482, 'Graniti', 'Graniti', '', 37.8898600, 15.2245900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88483, 'Limina', 'Limina', '', 37.9407600, 15.2711900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88484, 'Pace del Mela', 'Pace del Mela', '', 38.1799700, 15.3062900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88485, 'Rometta', 'Rometta', '', 38.1700700, 15.4142900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88486, 'Esporlatu', 'Esporlatu', '', 40.3845600, 8.9898300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88487, 'Viddalba', 'Viddalba', '', 40.9125900, 8.8900900, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88488, 'Golfo Aranci', 'Golfo Aranci', '', 41.0064800, 9.6145300, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88489, 'Budoni', 'Budoni', '', 40.7046700, 9.7038400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88490, 'Villanova Tulo', 'Villanova Tulo', '', 39.7799500, 9.2142400, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88491, 'Ollastra', 'Ollastra', '', 39.9509500, 8.7342300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88492, 'Casapinta', 'Casapinta', '', 45.6156600, 8.1959200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88493, 'Castelletto Cervo', 'Castelletto Cervo', '', 45.5213600, 8.2254200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88494, 'Dorzano', 'Dorzano', '', 45.4260600, 8.0985200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88495, 'Gifflenga', 'Gifflenga', '', 45.4930600, 8.2322300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88496, 'Miagliano', 'Miagliano', '', 45.6134600, 8.0447200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88497, 'Muzzano', 'Muzzano', '', 45.5607600, 7.9889200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88498, 'Ponderano', 'Ponderano', '', 45.5384600, 8.0559200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88499, 'Quaregna', 'Quaregna', '', 45.5811600, 8.1637200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88500, 'Roppolo', 'Roppolo', '', 45.4205600, 8.0697200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88501, 'Rosazza', 'Rosazza', '', 45.6757600, 7.9771200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88502, 'Ternengo', 'Ternengo', '', 45.5889600, 8.1137200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88503, 'Viverone', 'Viverone', '', 45.4272600, 8.0494200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88504, 'Zubiena', 'Zubiena', '', 45.4926600, 7.9955200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88505, 'Zumaglia', 'Zumaglia', '', 45.5938600, 8.0894200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88506, 'Barzago', 'Barzago', '', 45.7554800, 9.3142400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88507, 'Barzio', 'Barzio', '', 45.9434900, 9.4669400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88508, 'Cassina Valsassina', 'Cassina Valsassina', '', 45.9320900, 9.4789400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88509, 'Cernusco Lombardone', 'Cernusco Lombardone', '', 45.6908800, 9.3992500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88510, 'Cesana Brianza', 'Cesana Brianza', 'Chezana Brijanca,Chezana-Brianca,San Fermu,Sezana,qie sa na bu li ya en zha,Чезана Бријанца,Чезана-Брианца,Чезана-Бріанца,Չեզանա Բրիանցա,チェザーナ・ブリアンツァ,切萨纳布里亚恩扎', 45.8167800, 9.2995400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88511, 'Crandola Valsassina', 'Crandola Valsassina', '', 46.0232900, 9.3791400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88512, 'Cremella', 'Cremella', 'Crimela,Kremela,Kremella,ke lei mei la,kuremerra,Кремела,Кремелла,Կրեմելլա,クレメッラ,克雷梅拉', 45.7385800, 9.3006400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88513, 'Dolzago', 'Dolzago', 'Dol''cago,Dolcago,Dulciacum,Dulzagh,Dulzàgh,dorutsu~ago,duo er zha ge,Долцаго,Дольцаго,Դոլցագո,ドルツァーゴ,多尔扎戈', 45.7669800, 9.3393400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88514, 'Ello', 'Ello', '', 45.7856800, 9.3653400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88515, 'Introzzo', 'Introzzo', '', 46.0811900, 9.3409400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88516, 'Margno', 'Margno', '', 46.0309900, 9.3816400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88517, 'Montevecchia', 'Montevecchia', '', 45.7054800, 9.3808500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88518, 'Primaluna', 'Primaluna', '', 45.9837900, 9.4376400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88519, 'Sirone', 'Sirone', 'Siron,Sirone,Sironum,shirone,xi luo nei,Сироне,Сіроне,Սիրոնե,シローネ,西罗内', 45.7726800, 9.3221400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88520, 'Vendrogno', 'Vendrogno', '', 46.0343900, 9.3294400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88521, 'Vestreno', 'Vestreno', '', 46.0832900, 9.3248400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88522, 'Viganò', 'Vigano', '', 45.7246800, 9.3249400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88523, 'Abbadia Cerreto', 'Abbadia Cerreto', '', 45.3121700, 9.5941600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88524, 'Borgo San Giovanni', 'Borgo San Giovanni', '', 45.2778700, 9.4349600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88525, 'Caselle Landi', 'Caselle Landi', '', 45.1025700, 9.7955700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88526, 'Cornovecchio', 'Cornovecchio', '', 45.1366700, 9.7993700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88527, 'Galgagnano', 'Galgagnano', '', 45.3579700, 9.4453500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88528, 'Livraga', 'Livraga', '', 45.1922700, 9.5464600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88529, 'Maccastorna', 'Maccastorna', '', 45.1466700, 9.8545700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88530, 'Marudo', 'Marudo', '', 45.2529700, 9.3771600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88531, 'Massalengo-Motta Vigana', 'Massalengo-Motta Vigana', '', 45.2649700, 9.4901600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88532, 'Merlino', 'Merlino', '', 45.4333700, 9.4298500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88533, 'Mulazzano', 'Mulazzano', '', 45.3723700, 9.3976500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88534, 'Salerano sul Lambro', 'Salerano sul Lambro', '', 45.2965700, 9.3851500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88535, 'San Rocco al Porto', 'San Rocco al Porto', '', 45.0819700, 9.6971700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88536, 'Santo Stefano Lodigiano', 'Santo Stefano Lodigiano', '', 45.1185700, 9.7352700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88537, 'Somaglia', 'Somaglia', '', 45.1494700, 9.6334600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88538, 'Mondaino', 'Mondaino', '', 43.8579600, 12.6684500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88539, 'Monte Colombo', 'Monte Colombo', '', 43.9201600, 12.5523500, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88540, 'Brognaturo', 'Brognaturo', '', 38.6012800, 16.3414000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88541, 'Joppolo', 'Joppolo', '', 38.5833800, 15.8970900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88542, 'Zungri', 'Zungri', '', 38.6566800, 15.9840900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88543, 'Bee', 'Bee', '', 45.9632800, 8.5754200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88544, 'Caprezzo', 'Caprezzo', '', 45.9819800, 8.5628200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88545, 'Ceppo Morelli', 'Ceppo Morelli', '', 45.9711400, 8.0668800, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88546, 'Cossogno', 'Cossogno', '', 45.9640800, 8.5096200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88547, 'Gurro', 'Gurro', '', 46.0849800, 8.5677200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88548, 'Intragna', 'Intragna', '', 45.9946800, 8.5739200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88549, 'Massiola', 'Massiola', '', 45.9124700, 8.3201200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88550, 'Montecrestese', 'Montecrestese', '', 46.1644800, 8.3262100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88551, 'Nonio', 'Nonio', '', 45.8457700, 8.3775200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88552, 'Premia', 'Premia', '', 46.2680700, 8.3383000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88553, 'Toceno', 'Toceno', '', 46.1446800, 8.4690200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88554, 'Trasquera', 'Trasquera', '', 46.2133800, 8.2127100, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88555, 'Trontano', 'Trontano', '', 46.1224800, 8.3332200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88556, 'Zuni', 'Zuni', '', 41.2172200, 14.1308200, 'IT', '2012-02-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88557, 'Letino', 'Letino', '', 41.4530200, 14.2554200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88558, 'Pastorano', 'Pastorano', '', 41.1808200, 14.1982300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88559, 'Coreglia Ligure', 'Coreglia Ligure', '', 44.3877500, 9.2609700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88560, 'Casciago', 'Casciago', '', 45.8324800, 8.7833300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88561, 'Cassano Valcuvia', 'Cassano Valcuvia', '', 45.9323800, 8.7684300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88562, 'Bene Lario', 'Bene Lario', '', 46.0289800, 9.1841400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88563, 'Binago', 'Binago', '', 45.7821800, 8.9223400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88564, 'Cabiate', 'Cabiate', '', 45.6741800, 9.1737400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88565, 'Cagno', 'Cagno', '', 45.8110800, 8.9173300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88566, 'Ramponio Verna', 'Ramponio Verna', '', 45.9969800, 9.0663300, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88567, 'Rodero', 'Rodero', '', 45.8239800, 8.9152300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88568, 'Ronago', 'Ronago', '', 45.8322800, 8.9836400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88569, 'San Fedele Intelvi', 'San Fedele Intelvi', '', 45.9676800, 9.0807400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88570, 'Senna Comasco', 'Senna Comasco', '', 45.7629800, 9.1110400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88571, 'Sorico', 'Sorico', '', 46.1725900, 9.3840400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88572, 'Tavernerio', 'Tavernerio', 'Tabernarium,Tavarnee,Tavernerio,ta wei er nei liao,tavu~erunerio,Тавернерио,Тавернеріо,Տավերներիո,タヴェルネーリオ,塔韦尔内廖', 45.8006800, 9.1405400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88573, 'Turate', 'Turate', '', 45.6572700, 9.0042400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88574, 'Valmorea', 'Valmorea', 'Val''morea,Val''moreja,Vallis Morea,Valmorea,falmwrya,vu~arumorea,wa er mo lei ya,Вальмореа,Вальморея,Վալմորեա,فالموريا,ヴァルモレーア,瓦尔莫雷亚', 45.8151800, 8.9306400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88575, 'Vercana', 'Vercana', '', 46.1594900, 9.3351400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88576, 'Zelbio', 'Zelbio', '', 45.9045800, 9.1805400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88577, 'Andalo Valtellino', 'Andalo Valtellino', '', 46.1359900, 9.4738400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88578, 'Caiolo', 'Caiolo', '', 46.1499900, 9.8145500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88579, 'Colorina', 'Colorina', '', 46.1536900, 9.7293500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88580, 'Lanzada', 'Lanzada', '', 46.2693000, 9.8692500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88581, 'Lovero', 'Lovero', '', 46.2314000, 10.2285600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88582, 'Noviglio', 'Noviglio', 'Novej,Novil''jo,Novil''o,Novilio,Novilium,novu~irio,nuo wei liao,Новильо,Новільйо,Նովիլիո,ノヴィーリオ,诺维廖', 45.3590700, 9.0521500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88583, 'Caponago', 'Caponago', '', 45.5664700, 9.3758500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88584, 'Cerro al Lambro', 'Cerro al Lambro', '', 45.3299700, 9.3390500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88585, 'Cusago', 'Cusago', '', 45.4499700, 9.0374400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88586, 'Blello', 'Blello', '', 45.8377800, 9.5710500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88587, 'Pregnana Milanese', 'Pregnana Milanese', '', 45.5159700, 9.0070400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88588, 'Bracca', 'Bracca', '', 45.8226700, 9.7078400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88589, 'Branzi', 'Branzi', '', 46.0024900, 9.7593500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88590, 'Brembate di Sopra', 'Brembate di Sopra', '', 45.7166800, 9.5794500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88591, 'Castel Rozzone', 'Castel Rozzone', '', 45.5522800, 9.6198500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88592, 'Torre Pallavicina', 'Torre Pallavicina', 'Toreh-Palavichyna,Torre-Pallavichina,Tur Palaisina,Turris Pallavicinorum,tuo lei pa la wei qi na,Торре-Паллавичина,Торре-Паллавічина,Торэ-Палавічына,Տորե Պալավիչինա,トッレ・パッラヴィチーナ,托雷帕拉维奇纳', 45.4463800, 9.8770600, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88593, 'Onore', 'Onore', '', 45.8915900, 10.0107600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88594, 'Osio Sopra', 'Osio Sopra', '', 45.6290800, 9.5846500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88595, 'Pagazzano', 'Pagazzano', '', 45.5342800, 9.6711600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88596, 'Paladina', 'Paladina', '', 45.7306800, 9.6058500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88597, 'Pontirolo Nuovo', 'Pontirolo Nuovo', '', 45.5691800, 9.5693500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88598, 'Pradalunga', 'Pradalunga', '', 45.7458800, 9.7822500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88599, 'Ranica', 'Ranica', '', 45.7232800, 9.7133500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88600, 'Solza', 'Solza', '', 45.6786800, 9.4907500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88601, 'Azzano Mella', 'Azzano Mella', '', 45.4545800, 10.1171700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88602, 'Ono San Pietro', 'Ono San Pietro', '', 46.0168900, 10.3283600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88603, 'Paitone', 'Paitone', '', 45.5520800, 10.4022700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88604, 'Cecima', 'Cecima', '', 44.8506600, 9.0803600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88605, 'Ceranova', 'Ceranova', '', 45.2602700, 9.2431500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88606, 'Ceretto Lomellina', 'Ceretto Lomellina', '', 45.2449600, 8.6724400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88607, 'Cigognola', 'Cigognola', '', 45.0327600, 9.2448600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88608, 'Cura Carpignano', 'Cura Carpignano', '', 45.2124700, 9.2556500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88609, 'Galliavola', 'Galliavola', '', 45.0975600, 8.8188500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88610, 'Ruino', 'Ruino', '', 44.9114500, 9.2755300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88611, 'Pizzale', 'Pizzale', '', 45.0385600, 9.0499500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88612, 'Rea', 'Rea', '', 45.1133600, 9.1546500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88613, 'Imer', 'Imer', '', 46.1493100, 11.7891900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88614, 'Nave San Rocco', 'Nave San Rocco', '', 46.1677100, 11.1050800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88615, 'Pieve di Ledro', 'Pieve di Ledro', 'P''eve-di-Ledro,Peve-di-Ledro,Peveh-dzi-Ledra,Pieve di Ledro,pi ye wei di lai de luo,Певэ-дзі-Ледра,Пьеве-ди-Ледро,Пєве-ді-Ледро,Պիևե դի Լեդրո,ピエーヴェ・ディ・レードロ,皮耶韦迪莱德罗', 45.8884800, 10.7312400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88616, 'Pomarolo', 'Pomarolo', '', 45.9281000, 11.0430800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88617, 'Praso', 'Praso', '', 45.9500000, 10.6362700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88618, 'Prezzo', 'Prezzo', '', 45.9347000, 10.6329700, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88619, 'Banchette', 'Banchette', '', 45.4535600, 7.8563200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88620, 'Barone Canavese', 'Barone Canavese', '', 45.3257600, 7.8734200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88621, 'Lombriasco', 'Lombriasco', '', 44.8409400, 7.6359300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88622, 'Lusernetta', 'Lusernetta', 'Lusernetta,Lusernëtta,Luzerneta', 44.8031400, 7.2467200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88623, 'Maglione', 'Maglione', '', 45.3466600, 8.0133200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88624, 'Marentino', 'Marentino', '', 45.0536800, 7.8760900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88625, 'Meana di Susa', 'Meana di Susa', 'Meana,Meana di Suza,Meana-di-Suza,Meana-dzi-Suza,Means,Mediana,Méans,mei ya na di su sa,Меана-дзі-Суза,Меана-ди-Суза,Меана-ді-Суза,Մեանա դի Սուզա,メアーナ・ディ・スーザ,梅亚纳迪苏萨', 45.1220400, 7.0647100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88626, 'Mezzenile', 'Mezzenile', '', 45.2948500, 7.3956100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88627, 'Osasco', 'Osasco', '', 44.8494400, 7.3430200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88628, 'Osasio', 'Osasio', '', 44.8714400, 7.6080200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88629, 'San Pietro Val Lemina', 'San Pietro Val Lemina', '', 44.9065400, 7.3109200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88630, 'San Sebastiano da Po', 'San Sebastiano da Po', '', 45.1675500, 7.9572300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88631, 'San Secondo di Pinerolo', 'San Secondo di Pinerolo', '', 44.8664400, 7.2984200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88632, 'Torrazza Piemonte', 'Torrazza Piemonte', '', 45.2153500, 7.9767300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88633, 'Torre Canavese', 'Torre Canavese', '', 45.3920600, 7.7598200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88634, 'Trausella', 'Trausella', '', 45.4899600, 7.7631200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88635, 'Vaie', 'Vaie', '', 45.1023400, 7.2894100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88636, 'Varisella', 'Varisella', '', 45.2083500, 7.4838100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88637, 'Vialfrè', 'Vialfre', '', 45.3807600, 7.8182200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88638, 'Vidracco', 'Vidracco', '', 45.4306600, 7.7574200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88639, 'Villarbasse', 'Villarbasse', '', 45.0451400, 7.4684200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88640, 'Villar Dora', 'Villar Dora', '', 45.1146500, 7.3835200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88641, 'Civiasco', 'Civiasco', '', 45.8078600, 8.2938600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88642, 'Guardabosone', 'Guardabosone', '', 45.7018700, 8.2493200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88643, 'Moncrivello', 'Moncrivello', '', 45.3323600, 7.9955200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88644, 'Garbagna Novarese', 'Garbagna Novarese', '', 45.3887600, 8.6612400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88645, 'Gattico', 'Gattico', '', 45.7071700, 8.5200300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88646, 'Massino Visconti', 'Massino Visconti', '', 45.8241700, 8.5413300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88647, 'Nebbiuno', 'Nebbiuno', '', 45.8077400, 8.5259300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88648, 'Oleggio Castello', 'Oleggio Castello', '', 45.7488700, 8.5271300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88649, 'Pettenasco', 'Pettenasco', '', 45.8165700, 8.4070200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88650, 'Arguello', 'Arguello', '', 44.5827400, 8.1108400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88651, 'Barbaresco', 'Barbaresco', '', 44.7232400, 8.0819400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88652, 'Bastia Mondovì', 'Bastia Mondovi', '', 44.4419400, 7.8944400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88653, 'Bergolo', 'Bergolo', '', 44.5478400, 8.1831400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88654, 'Bernezzo', 'Bernezzo', '', 44.3853300, 7.4363300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88655, 'Bonvicino', 'Bonvicino', '', 44.5035400, 8.0175400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88656, 'Bosia', 'Bosia', '', 44.6024400, 8.1473400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88657, 'Brondello', 'Brondello', '', 44.6007300, 7.4059200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88658, 'Camo', 'Camo', '', 44.6950400, 8.1943400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88659, 'Caramagna Piemonte', 'Caramagna Piemonte', '', 44.7822400, 7.7394300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88660, 'Cardè', 'Carde', '', 44.7444400, 7.4776200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88661, 'Castellar', 'Castellar', '', 44.6212300, 7.4374300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88662, 'Castellinaldo', 'Castellinaldo', '', 44.7748400, 8.0297400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88663, 'Castellino Tanaro', 'Castellino Tanaro', '', 44.4278400, 7.9812400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88664, 'Castiglione Falletto', 'Castiglione Falletto', '', 44.6225400, 7.9753400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88665, 'Castiglione Tinella', 'Castiglione Tinella', '', 44.7253400, 8.1901400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88666, 'Grinzane Cavour', 'Grinzane Cavour', '', 44.6533400, 7.9950400, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88667, 'Ceresole Alba', 'Ceresole Alba', '', 44.7997400, 7.8224300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88668, 'Cigliè', 'Ciglie', '', 44.4365300, 7.9265400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88669, 'Cissone', 'Cissone', '', 44.5631400, 8.0304400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88670, 'Corneliano d''Alba', 'Corneliano d''Alba', '', 44.7361400, 7.9572300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88671, 'Faule', 'Faule', '', 44.8062400, 7.5851200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88672, 'Feisoglio', 'Feisoglio', '', 44.5437400, 8.1049400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88673, 'Gottasecca', 'Gottasecca', '', 44.4601400, 8.1675400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88674, 'Govone', 'Govone', '', 44.8044500, 8.0940400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88675, 'Isasca', 'Isasca', '', 44.5876300, 7.3816200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88676, 'Lequio Tanaro', 'Lequio Tanaro', '', 44.5599400, 7.8821400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88677, 'Lisio', 'Lisio', '', 44.3071300, 7.9787400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88678, 'Mosso', 'Mosso', '', 45.6500700, 8.1376200, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88679, 'Spadola', 'Spadola', 'Spadola,Spatula,Spàtula,si pa duo la,supadora,Спадола,Սպադոլա,スパードラ,斯帕多拉', 38.6037800, 16.3370000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88680, 'Cavagnolo', 'Cavagnolo', '', 45.1517500, 8.0490300, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88681, 'Scena - Schenna', 'Scena - Schenna', '', 46.6901200, 11.1862700, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88682, 'Albinia', 'Albinia', '', 42.5027800, 11.2102700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88683, 'Cantagrillo-Casalguidi', 'Cantagrillo-Casalguidi', '', 43.8693700, 10.9138600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88684, 'Sambuca', 'Sambuca', '', 43.5734400, 11.2140700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88685, 'Luco Mugello', 'Luco Mugello', '', 44.0003200, 11.3961100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88686, 'Castellina Scalo', 'Castellina Scalo', '', 43.4047600, 11.2090800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88687, 'Mercatale', 'Mercatale', '', 43.6367700, 11.2279000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88688, 'Porto Cervo', 'Porto Cervo', 'Porto Chervo,Порто Черво', 41.1406300, 9.5326700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88689, 'Fulgatore-Torretta', 'Fulgatore-Torretta', '', 37.9497700, 12.6930300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88690, 'La California', 'La California', '', 43.2693800, 10.5431300, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88691, 'Stiava', 'Stiava', '', 43.8972000, 10.3179800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88692, 'Chiassa-Tregozzano', 'Chiassa-Tregozzano', '', 43.5125100, 11.8913400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88693, 'Orentano', 'Orentano', '', 43.7790700, 10.6593900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88694, 'Aci Trezza', 'Aci Trezza', 'Achi-Trecca,Ачи-Трецца', 37.5638500, 15.1613600, 'IT', '2011-09-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88695, 'Torre San Giovanni', 'Torre San Giovanni', '', 39.8900100, 18.1115900, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88696, 'Tortoreto Lido', 'Tortoreto Lido', '', 42.7995600, 13.9420500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88697, 'Tonnarella', 'Tonnarella', '', 38.1253900, 15.1134800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88698, 'Povo', 'Povo', '', 46.0669800, 11.1550300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88699, 'Torvaianica', 'Torvaianica', '', 41.6211200, 12.4619700, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88700, 'Ospedaletto', 'Ospedaletto', '', 45.5046200, 10.8421200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88701, 'Castromediano', 'Castromediano', '', 40.3280300, 18.1787700, 'IT', '2014-01-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88702, 'Giorgilorio', 'Giorgilorio', '', 40.3868300, 18.1487300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88703, 'Sieci', 'Sieci', '', 43.7884700, 11.3944500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88704, 'Monticelli Terme', 'Monticelli Terme', '', 44.7288100, 10.3944400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88705, 'Montemerlo', 'Montemerlo', '', 45.3803300, 11.7081500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88706, 'Vambolieri', 'Vambolieri', '', 37.5741700, 15.1601900, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88707, 'Rastignano-Carteria di Sesto', 'Rastignano-Carteria di Sesto', '', 44.4362300, 11.3569500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88708, 'Trebbo', 'Trebbo', '', 44.5562900, 11.3190100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88709, 'Cazzago-Ex Polo', 'Cazzago-Ex Polo', '', 45.4415900, 12.0740600, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88710, 'Cadenabbia', 'Cadenabbia', 'Kadenabbija,Каденаббия', 45.9886100, 9.2361500, 'IT', '2016-11-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88711, 'Trinità d''Agultu', 'Trinita d''Agultu', '', 40.9858900, 8.9137700, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88712, 'Oscano', 'Oscano', '', 43.1586300, 12.3377600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88713, 'Corrubbio', 'Corrubbio', '', 45.4868500, 10.9035900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88714, 'Civesio', 'Civesio', '', 45.3955600, 9.2668000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88715, 'Noverasco-Sporting Mirasole', 'Noverasco-Sporting Mirasole', '', 45.3954400, 9.2142700, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88716, 'Fizzonasco', 'Fizzonasco', '', 45.3724100, 9.1906600, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88717, 'Chiaravalle', 'Chiaravalle', '', 45.4173100, 9.2398500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88718, 'Caleppio', 'Caleppio', '', 45.4343600, 9.3825000, 'IT', '2014-01-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88719, 'Vigonzone', 'Vigonzone', '', 45.2735000, 9.3098000, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88720, 'Novegro-Tregarezzo-San Felice', 'Novegro-Tregarezzo-San Felice', '', 45.4677800, 9.2812200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88721, 'Lisanza', 'Lisanza', '', 45.7392600, 8.5985200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88722, 'Focene', 'Focene', '', 41.8136700, 12.2135400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88723, 'Passoscuro', 'Passoscuro', '', 41.9020900, 12.1572300, 'IT', '2015-11-06', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88724, 'Marina San Nicola', 'Marina San Nicola', '', 41.9310200, 12.1202400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88725, 'Marina di Cerveteri', 'Marina di Cerveteri', '', 41.9799700, 12.0529500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88726, 'Granarolo', 'Granarolo', '', 44.3585900, 11.9345900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88727, 'Ara Nova', 'Ara Nova', '', 41.9330000, 12.2398000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88728, 'Calerno', 'Calerno', '', 44.7487500, 10.4860300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88729, 'Vitinia', 'Vitinia', '', 41.7912400, 12.4081000, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88730, 'Avane', 'Avane', '', 43.7904900, 10.4098200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88731, 'Donoratico', 'Donoratico', '', 43.1692700, 10.5674400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88732, 'Lodrone-Darzo', 'Lodrone-Darzo', '', 45.8296200, 10.5356000, 'IT', '2014-05-10', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88733, 'Acitrezza', 'Acitrezza', '', 37.5596000, 15.1599000, 'IT', '2010-05-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88734, 'Caselle', 'Caselle', '', 45.4134000, 10.8957000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88735, 'Pianello Vallesina', 'Pianello Vallesina', '', 43.4881700, 13.1618800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88736, 'Nova Siri Scalo', 'Nova Siri Scalo', '', 40.1317700, 16.6359300, 'IT', '2014-05-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88737, 'Carruba', 'Carruba', '', 37.6906200, 15.1881500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88738, 'Marcelli', 'Marcelli', '', 43.4920400, 13.6254500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88739, 'Monti', 'Monti', '', 44.2486400, 10.0085400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88740, 'Lu Bagnu', 'Lu Bagnu', '', 40.9018400, 8.6855500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88741, 'Montalbano', 'Montalbano', '', 40.7782700, 17.4815700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88742, 'Valgatara', 'Valgatara', '', 45.5346700, 10.9119100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88743, 'Fratta Terme', 'Fratta Terme', '', 44.1415700, 12.1021300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88744, 'Triscina', 'Triscina', '', 37.5871700, 12.7891200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88745, 'Sant''Angelo', 'Sant''Angelo', '', 40.6984100, 13.8931600, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88746, 'Marina di Vasto', 'Marina di Vasto', '', 42.0937300, 14.7268300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88747, 'Lavinio', 'Lavinio', '', 41.5035000, 12.5897300, 'IT', '2012-09-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88748, 'Lisiera', 'Lisiera', '', 45.5784800, 11.6117800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88749, 'Sandrà', 'Sandra', 'Sandra di Castelnuovo del Garda,Sandrà di Castelnuovo del Garda', 45.4606700, 10.7868600, 'IT', '2017-05-09', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88750, 'Villa Adriana', 'Villa Adriana', '', 41.9549900, 12.7721600, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88751, 'Trodica', 'Trodica', '', 43.2745800, 13.5936900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88752, 'Valle Santa', 'Valle Santa', '', 41.9453200, 12.3197100, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88753, 'Riscone', 'Riscone', 'Reischach', 46.7768500, 11.9514900, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88754, 'San Teodoro', 'San Teodoro', '', 44.4145800, 8.9100000, 'IT', '2012-02-15', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88755, 'Ried', 'Ried', '', 46.9299300, 11.5241400, 'IT', '2011-02-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88756, 'Monasterolo', 'Monasterolo', '', 45.2354900, 7.5082100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88757, 'Tuturano', 'Tuturano', '', 40.5447400, 17.9475400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88758, 'Baggiovara', 'Baggiovara', '', 44.6041600, 10.8625600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88759, 'Bastardo', 'Bastardo', '', 42.8714400, 12.5594300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88760, 'Ponte San Marco', 'Ponte San Marco', '', 45.4768600, 10.4131500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88761, 'Vidalengo', 'Vidalengo', '', 45.5223500, 9.6412800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88762, 'Musestre', 'Musestre', '', 45.5886400, 12.3724900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88763, 'Pianoconte', 'Pianoconte', '', 38.4743200, 14.9285700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88764, 'Bornato', 'Bornato', '', 45.5936800, 10.0409000, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88765, 'Caulonia Marina', 'Caulonia Marina', '', 38.3467900, 16.4635300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88766, 'Cavalcaselle', 'Cavalcaselle', '', 45.4369500, 10.7265200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88767, 'Arbizzano-Santa Maria', 'Arbizzano-Santa Maria', '', 45.4948900, 10.9383100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88768, 'Massa Finalese', 'Massa Finalese', '', 44.8524000, 11.2142900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88769, 'Roncanova', 'Roncanova', '', 45.1431800, 11.1034900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88770, 'Santa Lucia', 'Santa Lucia', '', 41.3040900, 14.0793700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88771, 'Grottola', 'Grottola', '', 41.3170800, 14.0412100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88772, 'Torchiati', 'Torchiati', '', 40.8183700, 14.8016500, 'IT', '2014-12-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88773, 'Castelletto', 'Castelletto', '', 44.4401500, 11.0647800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88774, 'Praticello di Gattatico', 'Praticello di Gattatico', '', 44.8048600, 10.4746100, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88775, 'Casale di Mezzani', 'Casale di Mezzani', '', 44.9153400, 10.4301500, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88776, 'Calderino', 'Calderino', '', 44.4577400, 11.1992700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88777, 'San Polo', 'San Polo', '', 44.8895700, 10.3568500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88778, 'Santo Stefano', 'Santo Stefano', '', 46.2086500, 13.1262600, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88779, 'Cras', 'Cras', '', 46.1740300, 13.6228700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88780, 'Vico', 'Vico', '', 46.4241900, 12.5839800, 'IT', '2012-02-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88781, 'Caseo', 'Caseo', '', 44.9436900, 9.2750400, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88782, 'Tagliuno', 'Tagliuno', '', 45.6425500, 9.9086400, 'IT', '2012-02-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88783, 'Terraverde-Corte Palasio', 'Terraverde-Corte Palasio', '', 45.3155200, 9.5616200, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88784, 'Villa Fornace', 'Villa Fornace', '', 44.9719400, 9.2521500, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88785, 'Miola di Pinè', 'Miola di Pine', '', 46.1266800, 11.2485000, 'IT', '2012-03-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88786, 'Roata Rossi', 'Roata Rossi', '', 44.4438300, 7.5257200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88787, 'Cancello ed Arnone', 'Cancello ed Arnone', '', 41.0730100, 14.0271400, 'IT', '2013-07-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88788, 'Castrocaro Terme e Terra del Sole', 'Castrocaro Terme e Terra del Sole', '', 44.1867600, 11.9606800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88789, 'Bellaria-Igea Marina', 'Bellaria-Igea Marina', '', 44.1425500, 12.4715400, 'IT', '2015-07-21', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88790, 'Ca'' Savio', 'Ca'' Savio', '', 45.4537500, 12.4572900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88791, 'Marconia', 'Marconia', '', 40.3635500, 16.6882300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88792, 'Corpo Reno', 'Corpo Reno', '', 44.7559100, 11.3079400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88793, 'Montepaone Lido', 'Montepaone Lido', '', 38.7295100, 16.5424100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88794, 'Priula-Colfosco', 'Priula-Colfosco', '', 45.8199800, 12.2584700, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88795, 'Sambuceto', 'Sambuceto', '', 42.4216800, 14.1874700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88796, 'Villanova', 'Villanova', '', 41.9635700, 12.7563300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88797, 'Arcavacata', 'Arcavacata', '', 39.3584600, 16.2084400, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88798, 'Cona', 'Cona', 'Koni', 44.8058300, 11.7069000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88799, 'Basilicagoiano', 'Basilicagoiano', '', 44.7054500, 10.4045700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88800, 'Ponte Felcino', 'Ponte Felcino', '', 43.1304900, 12.4491400, 'IT', '2012-09-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88801, 'Margine Coperta-Traversagna', 'Margine Coperta-Traversagna', '', 43.8797700, 10.7573300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88802, 'Marina di Ardea-Tor San Lorenzo', 'Marina di Ardea-Tor San Lorenzo', '', 41.5543900, 12.5411500, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88803, 'Trestina', 'Trestina', '', 43.3659700, 12.2370100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88804, 'Villalba', 'Villalba', '', 41.9538700, 12.7293800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88805, 'Marco Simone', 'Marco Simone', '', 41.9554400, 12.6477500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88806, 'Rablà', 'Rabla', 'Rabla,Rabland,Rablà', 46.6704400, 11.0645800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88807, 'Latina Scalo', 'Latina Scalo', '', 41.5315700, 12.9456700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88808, 'San Mamete', 'San Mamete', '', 46.0250500, 9.0536400, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88809, 'San Bernardo', 'San Bernardo', '', 46.4008800, 10.8444500, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88810, 'Tornimparte', 'Tornimparte', '', 42.2900700, 13.3009200, 'IT', '2013-12-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88811, 'La Pigna-Pigna Bassa', 'La Pigna-Pigna Bassa', '', 42.8332400, 13.6344600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88812, 'Piane di Morro', 'Piane di Morro', '', 42.8231700, 13.6530000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88813, 'Villaseta', 'Villaseta', '', 37.2987700, 13.5591900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88814, 'Osteno', 'Osteno', 'Cin e Osten,Cin e Ostén', 46.0066800, 9.0838500, 'IT', '2013-08-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88815, 'Osteria Nuova', 'Osteria Nuova', '', 42.0372100, 12.3092400, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88816, 'Sezze Scalo', 'Sezze Scalo', '', 41.4970100, 13.0425700, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88817, 'San Giacomo', 'San Giacomo', '', 46.1601900, 10.0253200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88818, 'Centobuchi', 'Centobuchi', '', 42.8952100, 13.8480900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88819, 'Mantignano-Ugnano', 'Mantignano-Ugnano', '', 43.7820000, 11.1695800, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88820, 'Cortoghiana', 'Cortoghiana', '', 39.2117700, 8.4654800, 'IT', '2017-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88821, 'Cerbara', 'Cerbara', '', 43.4991300, 12.2111300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88822, 'Lesna', 'Lesna', '', 45.0541800, 7.6203100, 'IT', '2016-11-22', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88823, 'Pedemonte', 'Pedemonte', '', 45.5030200, 10.9186500, 'IT', '2015-05-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88824, 'San Nicolò', 'San Nicolo', '', 45.0568500, 9.6054000, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88825, 'Tre Fontane', 'Tre Fontane', '', 37.5698900, 12.7242300, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88826, 'Lido dei Pini', 'Lido dei Pini', '', 41.5366000, 12.5897600, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88827, 'Corsanico-Bargecchia', 'Corsanico-Bargecchia', '', 43.9082800, 10.3062100, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88828, 'Bassone', 'Bassone', '', 45.4511000, 10.8944900, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88829, 'Carraia', 'Carraia', '', 43.8953400, 11.1819000, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88830, 'Poggetto', 'Poggetto', '', 43.8279000, 11.0384700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88831, 'Catena', 'Catena', 'Catena di Quarrata', 43.8425400, 11.0165800, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88832, 'Santa Lucia', 'Santa Lucia', '', 41.9824000, 12.6562500, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88833, 'Fossoli', 'Fossoli', '', 44.8216000, 10.8897700, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88834, 'San Bartolomeo', 'San Bartolomeo', '', 44.6740200, 10.5394100, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88835, 'San Marco', 'San Marco', '', 40.2674000, 14.9389700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88836, 'San Vigilio', 'San Vigilio', 'San Vigilio,Sankt Vigil', 46.6988400, 11.9310400, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88837, 'Marina di Casal Velino', 'Marina di Casal Velino', '', 40.1766500, 15.1221800, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88838, 'Scarlino Scalo', 'Scarlino Scalo', '', 42.9399200, 10.8376600, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88839, 'Ponte Pattoli', 'Ponte Pattoli', '', 43.1780700, 12.4284200, 'IT', '2014-01-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88840, 'Cologna Spiaggia', 'Cologna Spiaggia', '', 42.7215200, 13.9831100, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88841, 'Santa Maria Apparente', 'Santa Maria Apparente', '', 43.2966100, 13.6922300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88842, 'Sant''Andrea Ionio Marina', 'Sant''Andrea Ionio Marina', '', 38.6200100, 16.5492700, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88843, 'Mezzate', 'Mezzate', '', 45.4438500, 9.2945200, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88844, 'San Bovio-San Felice', 'San Bovio-San Felice', '', 45.4628200, 9.3126300, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88845, 'Fontana delle Monache', 'Fontana delle Monache', '', 44.1138600, 10.2794300, 'IT', '2014-01-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88846, 'Montignano-Marzocca', 'Montignano-Marzocca', '', 43.6745100, 13.2909300, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88847, 'Centinarola', 'Centinarola', '', 43.8311700, 12.9896200, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88848, 'Fenile', 'Fenile', '', 43.8412600, 12.9674700, 'IT', '2014-01-19', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88849, 'Weather Station', 'Weather Station', '', 37.9613600, 16.0997000, 'IT', '2014-02-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88850, 'Cavallino', 'Cavallino', '', 45.4745600, 12.5485500, 'IT', '2014-05-04', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88851, 'Cropani Marina', 'Cropani Marina', '', 38.9237600, 16.8108000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88852, 'Roccelletta', 'Roccelletta', '', 38.8112600, 16.5982000, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88853, 'San Paolo', 'San Paolo', 'San Paolo', 41.1247600, 16.7925800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88854, 'Monterusciello', 'Monterusciello', 'Monterusciello', 40.8687400, 14.0827600, 'IT', '2015-08-08', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88855, 'Romano Banco', 'Romano Banco', 'Romano Banco', 45.4230900, 9.1070700, 'IT', '2015-08-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88856, 'Casa Santa', 'Casa Santa', 'Casa Santa', 38.0251400, 12.5484000, 'IT', '2015-08-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88857, 'Arpino', 'Arpino', 'Arpino', 40.8888200, 14.3201500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88858, 'Paolo VI', 'Paolo VI', 'Paolo VI', 40.5221800, 17.2740100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88859, 'Breo', 'Breo', 'Breo', 44.3986500, 7.8190300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88860, 'Progresso', 'Progresso', 'Progresso', 44.5689200, 11.3642000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88861, 'Mejaniga', 'Mejaniga', 'Mejaniga', 45.4576800, 11.9064400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88862, 'La Massimina-Casal Lumbroso', 'La Massimina-Casal Lumbroso', 'La Massimina-Casal Lumbroso', 41.8733200, 12.3569400, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88863, 'Chiugiana-La Commenda', 'Chiugiana-La Commenda', 'Chiugiana-La Commenda', 43.0982300, 12.3081800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88864, 'San Zeno-San Giuseppe', 'San Zeno-San Giuseppe', 'San Zeno-San Giuseppe', 45.7572700, 11.7620800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88865, 'Piazza', 'Piazza', 'Piazza', 45.5093300, 10.4240800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88866, 'Spicchio-Sovigliana', 'Spicchio-Sovigliana', 'Spicchio-Sovigliana', 43.7301600, 10.9392100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88867, 'Ponte Cingoli', 'Ponte Cingoli', 'Ponte Cingoli', 45.5975100, 10.1068700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88868, 'Piattoni-Villa Sant''Antonio', 'Piattoni-Villa Sant''Antonio', 'Piattoni-Villa Sant''Antonio', 42.8663000, 13.7112000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88869, 'Fiesso', 'Fiesso', 'Fiesso', 45.4195400, 12.0337800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88870, 'Canalicchio', 'Canalicchio', 'Canalicchio', 37.5409700, 15.0964500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88871, 'Colombiera-Molicciara', 'Colombiera-Molicciara', 'Colombiera-Molicciara', 44.0875000, 10.0103700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88872, 'Belvedere', 'Belvedere', 'Belvedere', 45.6900100, 11.7718000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88873, 'Selcetta', 'Selcetta', 'Selcetta', 41.7652900, 12.4753300, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88874, 'Andreotta', 'Andreotta', 'Andreotta', 39.3075000, 16.2177000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88875, 'Casano-Dogana-Isola', 'Casano-Dogana-Isola', 'Casano-Dogana-Isola', 44.0756500, 10.0338100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88876, 'Ciaculli', 'Ciaculli', 'Ciaculli', 38.0753000, 13.4071900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88877, 'Vill''Albese', 'Vill''Albese', 'Vill''Albese', 45.7968400, 9.1885900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88878, 'Sala', 'Sala', 'Sala', 40.8553600, 14.8734300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88879, 'Villatora', 'Villatora', 'Villatora', 45.3876800, 11.9673600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88880, 'Pontasserchio', 'Pontasserchio', 'Pontasserchio', 43.7795300, 10.4167300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88881, 'Veggia-Villalunga', 'Veggia-Villalunga', 'Veggia-Villalunga', 44.5607000, 10.7562100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88882, 'Quadrivio', 'Quadrivio', 'Quadrivio', 40.6249400, 15.1035300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88883, 'Mandriola-Sant''Agostino', 'Mandriola-Sant''Agostino', 'Mandriola-Sant''Agostino', 45.3692600, 11.8510100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88884, 'Gerbole', 'Gerbole', 'Gerbole', 45.0011500, 7.5067000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88885, 'Lancusi-Penta-Bolano', 'Lancusi-Penta-Bolano', 'Lancusi-Penta-Bolano', 40.7612500, 14.7852400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88886, 'Pedemonte', 'Pedemonte', 'Pedemonte', 44.5030700, 8.9261400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88887, 'Frescada', 'Frescada', 'Frescada', 45.6287800, 12.2367100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88888, 'San Donnino', 'San Donnino', 'San Donnino', 43.7954700, 11.1465400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88889, 'Caselle', 'Caselle', 'Caselle', 45.4112900, 11.8166300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88890, 'Piazza del Galdo-Sant''Angelo', 'Piazza del Galdo-Sant''Angelo', 'Piazza del Galdo-Sant''Angelo', 40.7739000, 14.7169600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88891, 'Lanzara', 'Lanzara', 'Lanzara', 40.7747300, 14.6761900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88892, 'Airali', 'Airali', 'Airali', 44.8167000, 7.2515700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88893, 'Vado Centro', 'Vado Centro', 'Vado Centro', 44.2685700, 8.4322500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88894, 'Eremo', 'Eremo', 'Eremo', 45.1311900, 10.7427100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88895, 'San Nicolò a Tordino', 'San Nicolo a Tordino', 'San Nicolo a Tordino,San Nicolò a Tordino', 42.6964800, 13.7970800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88896, 'Villa Raspa', 'Villa Raspa', 'Villa Raspa', 42.4554200, 14.1845700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88897, 'Canova-San Zeno', 'Canova-San Zeno', 'Canova-San Zeno', 45.7211600, 9.4003000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88898, 'Santa Margherita', 'Santa Margherita', 'Santa Margherita', 45.6339100, 9.2301300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88899, 'Setteville', 'Setteville', 'Setteville', 41.9437500, 12.6512200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88900, 'Pagliare', 'Pagliare', 'Pagliare', 42.8690600, 13.7690600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88901, 'Rometta Marea', 'Rometta Marea', 'Rometta Marea', 38.2326400, 15.4095500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88902, 'Piazzola', 'Piazzola', 'Piazzola', 40.8726500, 14.5001600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88903, 'Roveleto', 'Roveleto', 'Roveleto,Roveleto di Cadeo', 44.9633200, 9.8539000, 'IT', '2016-01-07', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88904, 'Colle Verde', 'Colle Verde', 'Colle Verde', 41.9769400, 12.6185500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88905, 'San Martino Bassa', 'San Martino Bassa', 'San Martino Bassa', 42.5182700, 14.1304500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88906, 'Regoledo', 'Regoledo', 'Regoledo', 46.1331900, 9.5459700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88907, 'Ciconia', 'Ciconia', 'Ciconia', 42.7335600, 12.1340000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88908, 'Strà-Montanara-Pieve', 'Stra-Montanara-Pieve', 'Stra-Montanara-Pieve,Strà-Montanara-Pieve', 45.4236700, 11.1574900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88909, 'Valle Martella', 'Valle Martella', 'Valle Martella', 41.8782700, 12.7467700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88910, 'Sant''Antonio', 'Sant''Antonio', 'Sant''Antonio', 40.6362600, 14.8984500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88911, 'Torretta-Scalzapecora', 'Torretta-Scalzapecora', 'Torretta-Scalzapecora', 40.9101500, 14.1345600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88912, 'Tivolille Pasquali-Merenzata', 'Tivolille Pasquali-Merenzata', 'Tivolille Pasquali-Merenzata', 39.2795300, 16.2073800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88913, 'Torelli-Torrette', 'Torelli-Torrette', 'Torelli-Torrette', 40.9077700, 14.7518400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88914, 'Piazza-Tralia-Pendolo', 'Piazza-Tralia-Pendolo', 'Piazza-Tralia-Pendolo', 40.6735100, 14.5045500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88915, 'San Rocco', 'San Rocco', 'San Rocco', 43.8231600, 10.8612100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88916, 'Villa Rosa', 'Villa Rosa', 'Villa Rosa', 42.8505900, 13.9201500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88917, 'Rogoredo-Valaperta-Rimoldo', 'Rogoredo-Valaperta-Rimoldo', 'Rogoredo-Valaperta-Rimoldo', 45.6769500, 9.3327700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88918, 'Su Planu', 'Su Planu', 'Su Planu', 39.2548700, 9.1066000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88919, 'Genio Civile', 'Genio Civile', 'Genio Civile', 41.5480700, 12.6916100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88920, 'Carobbio', 'Carobbio', 'Carobbio', 45.6642400, 9.8302700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88921, 'Borgo Stazione', 'Borgo Stazione', 'Borgo Stazione', 43.2846100, 13.6442000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88922, 'Capaccio Scalo', 'Capaccio Scalo', 'Capaccio Scalo', 40.4553100, 15.0089100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88923, 'Piazza Roma', 'Piazza Roma', 'Piazza Roma', 40.7043400, 14.5430000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88924, 'Npp 23 (Parco Leonardo)', 'Npp 23 (Parco Leonardo)', 'Npp 23 (Parco Leonardo)', 41.8003500, 12.3002800, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88925, 'Toscanella', 'Toscanella', 'Toscanella', 44.3824800, 11.6396500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88926, 'Lunetta-Frassino', 'Lunetta-Frassino', 'Lunetta-Frassino', 45.1601600, 10.8205900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88927, 'Vighignolo', 'Vighignolo', 'Vighignolo', 45.4954200, 9.0430800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88928, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 42.4275300, 14.1581600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88929, 'Osteria Grande', 'Osteria Grande', 'Osteria Grande', 44.4284500, 11.5218000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88930, 'Roè', 'Roe', 'Roe,Roè', 45.6257600, 10.4996000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88931, 'Laghetto', 'Laghetto', 'Laghetto', 41.9673400, 12.6560900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88932, 'Chianchitta-Trappitello', 'Chianchitta-Trappitello', 'Chianchitta-Trappitello', 37.8298400, 15.2507700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88933, 'Onè', 'One', 'One,Onè', 45.7837400, 11.8740400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88934, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 43.8829600, 10.7030700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88935, 'San Brancato', 'San Brancato', 'San Brancato', 40.2582200, 16.2566100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88936, 'Bojon-Lova', 'Bojon-Lova', 'Bojon-Lova', 45.3398100, 12.0828200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88937, 'Grunuovo-Campomaggiore San Luca', 'Grunuovo-Campomaggiore San Luca', 'Grunuovo-Campomaggiore San Luca', 41.2722800, 13.8068400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88938, 'Mercatale-San Quirico', 'Mercatale-San Quirico', 'Mercatale-San Quirico', 44.0442600, 11.1516300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88939, 'Bolladello-Peveranza', 'Bolladello-Peveranza', 'Bolladello-Peveranza', 45.6864900, 8.8451700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88940, 'Castelnuovo Vomano', 'Castelnuovo Vomano', 'Castelnuovo Vomano', 42.6293300, 13.8500300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88941, 'Valcanneto', 'Valcanneto', 'Valcanneto', 41.9507800, 12.1573400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88942, 'San Floriano-Olmi', 'San Floriano-Olmi', 'San Floriano-Olmi', 45.6734900, 12.3303900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88943, 'Fossignano', 'Fossignano', 'Fossignano', 41.5922600, 12.5633300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88944, 'Parco Scizzo-Parchitello', 'Parco Scizzo-Parchitello', 'Parco Scizzo-Parchitello', 41.0745700, 16.9932900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88945, 'Budrio', 'Budrio', 'Budrio', 44.0991600, 12.3403300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88946, 'Manoppello Scalo', 'Manoppello Scalo', 'Manoppello Scalo', 42.3076200, 14.0536300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88947, 'Solarolo', 'Solarolo', 'Solarolo', 45.5504700, 10.5548900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88948, 'Garino', 'Garino', 'Garino', 44.9732500, 7.6172800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88949, 'Annunziata', 'Annunziata', 'Annunziata', 41.1210000, 14.3651800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88950, 'Villa d''Agri', 'Villa d''Agri', 'Villa d''Agri', 40.3542600, 15.8277000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88951, 'Torre Caracciolo', 'Torre Caracciolo', 'Torre Caracciolo', 40.8755100, 14.1785900, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88952, 'Piazza Caduti', 'Piazza Caduti', 'Piazza Caduti', 45.7051300, 9.5025100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88953, 'Campo Limpido-Favale', 'Campo Limpido-Favale', 'Campo Limpido-Favale', 41.9673200, 12.7701600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88954, 'Marina di Davoli', 'Marina di Davoli', 'Marina di Davoli', 38.6636100, 16.5482500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88955, 'Crocetta-Nogarè', 'Crocetta-Nogare', 'Crocetta-Nogare,Crocetta-Nogarè', 45.8270700, 12.0301300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88956, 'Mombretto', 'Mombretto', 'Mombretto', 45.4239000, 9.3650600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88957, 'Antessano', 'Antessano', 'Antessano', 40.7329300, 14.7774400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88958, 'Bormida-Genepro', 'Bormida-Genepro', 'Bormida-Genepro', 44.3905100, 8.1995200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88959, 'San Giacomo', 'San Giacomo', 'San Giacomo', 46.4562400, 11.3336500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88960, 'Bellante Stazione', 'Bellante Stazione', 'Bellante Stazione', 42.7065000, 13.8395300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88961, 'San Vigilio', 'San Vigilio', 'San Vigilio', 45.6080800, 10.1944200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88962, 'Levata', 'Levata', 'Levata', 45.1251800, 10.7679400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88963, 'Lido di Fermo', 'Lido di Fermo', 'Lido di Fermo', 43.2055600, 13.7846700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88964, 'Parmezzana Calzana', 'Parmezzana Calzana', 'Parmezzana Calzana', 45.6335000, 10.0954000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88965, 'Cascine-La Croce', 'Cascine-La Croce', 'Cascine-La Croce', 43.7288500, 10.6147100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88966, 'Casette d''Ete', 'Casette d''Ete', 'Casette d''Ete', 43.2538500, 13.6831900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88967, 'Taverna', 'Taverna', 'Taverna', 39.4304000, 16.2309000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88968, 'Pieve', 'Pieve', 'Pieve', 45.5392400, 11.8293000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88969, 'Vigliano-Bettolino', 'Vigliano-Bettolino', 'Vigliano-Bettolino', 45.4327200, 9.3442200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88970, 'Prato Perillo', 'Prato Perillo', 'Prato Perillo', 40.3969000, 15.5250300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88971, 'Castelnovo', 'Castelnovo', 'Castelnovo', 45.6155700, 11.4593800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88972, 'Cava-Cuculera Nobile', 'Cava-Cuculera Nobile', 'Cava-Cuculera Nobile', 38.8938300, 16.6222600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88973, 'Colombella', 'Colombella', 'Colombella', 43.1526200, 12.4823900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88974, 'Roteglia', 'Roteglia', 'Roteglia', 44.4841700, 10.6883200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88975, 'Carrubazza-Motta', 'Carrubazza-Motta', 'Carrubazza-Motta', 37.5532300, 15.1081900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88976, 'San Bartolomeo', 'San Bartolomeo', 'San Bartolomeo', 41.4826500, 13.8574700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88977, 'S.P. in Palazzi', 'S.P. in Palazzi', 'S.P. in Palazzi', 43.3277600, 10.5088100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88978, 'Starza Vecchia', 'Starza Vecchia', 'Starza Vecchia', 40.8903500, 14.4013800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88979, 'Cerza', 'Cerza', 'Cerza', 37.5429700, 15.1051000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88980, 'Ravina', 'Ravina', 'Ravina', 46.0394400, 11.1121500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88981, 'Valleggia', 'Valleggia', 'Valleggia', 44.2808000, 8.4296700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88982, 'Monticello', 'Monticello', 'Monticello', 45.7124400, 9.3148100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88983, 'Chiesa', 'Chiesa', 'Chiesa', 45.6901100, 9.9128200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88984, 'Capezzano-Cologna', 'Capezzano-Cologna', 'Capezzano-Cologna', 40.7151800, 14.7736400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88985, 'Ceresane-Curanuova', 'Ceresane-Curanuova', 'Ceresane-Curanuova', 45.5243500, 8.0070800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88986, 'Marzanello', 'Marzanello', 'Marzanello', 41.3144700, 14.1161100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88987, 'Limidi', 'Limidi', 'Limidi', 44.7642700, 10.9200200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88988, 'Stazione-Fornola', 'Stazione-Fornola', 'Stazione-Fornola', 44.1298400, 9.8915900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88989, 'Stella', 'Stella', 'Stella', 42.8869800, 13.8094800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88990, 'Pratole', 'Pratole', 'Pratole', 40.6258000, 14.9256500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88991, 'San Pietro', 'San Pietro', 'San Pietro', 40.8239800, 14.7847600, 'IT', '2014-04-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88992, 'Ponticella', 'Ponticella', 'Ponticella', 44.4544600, 11.3785100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88993, 'Le Rughe', 'Le Rughe', 'Le Rughe', 42.0688500, 12.3762400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88994, 'Pascarola', 'Pascarola', 'Pascarola', 40.9764300, 14.3050000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88995, 'Ferriera', 'Ferriera', 'Ferriera', 45.0838200, 7.4301700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88996, 'San Damaso', 'San Damaso', 'San Damaso', 44.6010200, 10.9737300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88997, 'Laghetto', 'Laghetto', 'Laghetto', 41.8562800, 12.7249800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88998, 'Chef-Lieu', 'Chef-Lieu', 'Chef-Lieu', 45.7509100, 7.3537200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(88999, 'San Francesco', 'San Francesco', 'San Francesco', 43.7748300, 11.4484200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89000, 'Torchione-Moia', 'Torchione-Moia', 'Torchione-Moia', 46.1548600, 9.8599600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89001, 'Vighizzolo', 'Vighizzolo', 'Vighizzolo', 45.4352400, 10.3550700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89002, 'Brognoligo-Costalunga', 'Brognoligo-Costalunga', 'Brognoligo-Costalunga', 45.4486900, 11.2937900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89003, 'Coperchia', 'Coperchia', 'Coperchia', 40.7200500, 14.7665400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89004, 'Casali-San Potito', 'Casali-San Potito', 'Casali-San Potito', 40.7639000, 14.6750100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89005, 'Bolognano-Vignole', 'Bolognano-Vignole', 'Bolognano-Vignole', 45.9119600, 10.9049700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89006, 'Taggì', 'Taggi', 'Taggi,Taggì', 45.4607000, 11.8186500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89007, 'Grignano Polesine', 'Grignano Polesine', 'Grignano Polesine', 45.0435000, 11.7468200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89008, 'Trecella', 'Trecella', 'Trecella', 45.5149800, 9.4790500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89009, 'Praticello', 'Praticello', 'Praticello', 44.8043600, 10.4731000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89010, 'Passirana', 'Passirana', 'Passirana', 45.5479200, 9.0441200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89011, 'Lamie di Olimpie-Selva', 'Lamie di Olimpie-Selva', 'Lamie di Olimpie-Selva', 40.8171400, 17.3347800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89012, 'Moiano', 'Moiano', 'Moiano', 40.6517200, 14.4660100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89013, 'Cantalupo', 'Cantalupo', 'Cantalupo', 45.5781300, 8.9826100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89014, 'San Pietro', 'San Pietro', 'San Pietro', 45.4420900, 11.1296800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89015, 'Albuccione', 'Albuccione', 'Albuccione', 41.9524500, 12.6987300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89016, 'Sinigo', 'Sinigo', 'Sinigo', 46.6348800, 11.1792600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89017, 'Mussotto', 'Mussotto', 'Mussotto', 44.7176600, 8.0340400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89018, 'Robegano', 'Robegano', 'Robegano', 45.5425300, 12.1192400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89019, 'Cintolese', 'Cintolese', 'Cintolese', 43.8460600, 10.8264400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89020, 'Settimo', 'Settimo', 'Settimo', 39.3915800, 16.2399800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89021, 'Fogliano', 'Fogliano', 'Fogliano', 44.6475100, 10.6450500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89022, 'Talponada', 'Talponada', 'Talponada', 45.7035100, 12.4905300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89023, 'Rilievo', 'Rilievo', 'Rilievo', 37.9163800, 12.5405800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89024, 'Gallo-Tre Re-Mezzana Corti', 'Gallo-Tre Re-Mezzana Corti', 'Gallo-Tre Re-Mezzana Corti', 45.1256300, 9.1222700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89025, 'Osigo', 'Osigo', 'Osigo', 45.8753200, 9.2955900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89026, 'Romito Magra', 'Romito Magra', 'Romito Magra', 44.0983800, 9.9318000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89027, 'Casarea', 'Casarea', 'Casarea', 40.8882800, 14.3634900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89028, 'Castelminio', 'Castelminio', 'Castelminio', 45.6449300, 11.9873400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89029, 'Gaggino', 'Gaggino', 'Gaggino', 45.8078700, 8.9642700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89030, 'Riozzo', 'Riozzo', 'Riozzo', 45.3462200, 9.3216800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89031, 'Fornaci', 'Fornaci', 'Fornaci', 45.0281600, 7.5986900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89032, 'Vidardo', 'Vidardo', 'Vidardo', 45.2566700, 9.4024100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89033, 'Borgo Santa Maria Immacolata', 'Borgo Santa Maria Immacolata', 'Borgo Santa Maria Immacolata', 42.6117200, 14.0455300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89034, 'Cappone', 'Cappone', 'Cappone', 43.8307100, 12.7445800, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89035, 'Meledo', 'Meledo', 'Meledo', 45.4382100, 11.4156000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89036, 'Zona 179', 'Zona 179', 'Zona 179', 41.0031300, 15.6186800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89037, 'Pionca', 'Pionca', 'Pionca', 45.4659100, 11.9623200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89038, 'Stazione', 'Stazione', 'Stazione', 43.5004600, 13.1514900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89039, 'Poggio dei Pini', 'Poggio dei Pini', 'Poggio dei Pini', 39.1471700, 8.9713900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89040, 'Lucino', 'Lucino', 'Lucino', 45.7835000, 9.0434000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89041, 'Pezzano-Filetta', 'Pezzano-Filetta', 'Pezzano-Filetta', 40.6977300, 14.8697100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89042, 'Piano dei Geli', 'Piano dei Geli', 'Piano dei Geli', 38.0991900, 13.2747800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89043, 'Scannabue-Cascine Capri', 'Scannabue-Cascine Capri', 'Scannabue-Cascine Capri', 45.3930600, 9.5930200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89044, 'Monte Migliore-La Selvotta', 'Monte Migliore-La Selvotta', 'Monte Migliore-La Selvotta', 41.7206000, 12.5020600, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89045, 'Caldine', 'Caldine', 'Caldine', 43.8283400, 11.3044200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89046, 'Manesseno', 'Manesseno', 'Manesseno', 44.4781600, 8.9278400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89047, 'Giammoro', 'Giammoro', 'Giammoro', 38.2037200, 15.3066600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89048, 'Piediripa', 'Piediripa', 'Piediripa', 43.2775100, 13.4871200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89049, 'Asciano', 'Asciano', 'Asciano', 43.7515900, 10.4650600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89050, 'Santa Maria di Non', 'Santa Maria di Non', 'Santa Maria di Non', 45.5132200, 11.8536400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89051, 'Guardavalle Marina', 'Guardavalle Marina', 'Guardavalle Marina', 38.4795700, 16.5765600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89052, 'Osteria Nuova', 'Osteria Nuova', 'Osteria Nuova', 44.5845700, 11.2373900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89053, 'Gerbido', 'Gerbido', 'Gerbido', 45.0444900, 7.6140800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89054, 'Selino Basso', 'Selino Basso', 'Selino Basso', 45.8102900, 9.5349500, 'IT', '2016-11-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89055, 'Longara', 'Longara', 'Longara', 44.5711000, 11.3038600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89056, 'San Gregorio', 'San Gregorio', 'San Gregorio', 45.3428600, 11.2993300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89057, 'Capriano', 'Capriano', 'Capriano', 45.7229800, 9.2552600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89058, 'Galta', 'Galta', 'Galta', 45.3909500, 12.0234000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89059, 'Montan-Angelin-Arensod', 'Montan-Angelin-Arensod', 'Montan-Angelin-Arensod', 45.7282000, 7.2764700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89060, 'Maugeri', 'Maugeri', 'Maugeri', 37.5860800, 15.1178500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89061, 'Montedecoro', 'Montedecoro', 'Montedecoro', 41.0277200, 14.4177400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89062, 'Dodici Morelli', 'Dodici Morelli', 'Dodici Morelli', 44.7923400, 11.2912400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89063, 'Carchitti', 'Carchitti', 'Carchitti', 41.7868800, 12.8295500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89064, 'Carrara-Pontenuovo', 'Carrara-Pontenuovo', 'Carrara-Pontenuovo', 41.5404500, 12.9546800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89065, 'Area Produttiva', 'Area Produttiva', 'Area Produttiva', 41.6821100, 12.5069700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89066, 'Formica', 'Formica', 'Formica', 44.4683800, 11.0133700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89067, 'Baganzola', 'Baganzola', 'Baganzola', 44.8551300, 10.3070600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89068, 'Villa Raverio', 'Villa Raverio', 'Villa Raverio', 45.6918900, 9.2623900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89069, 'Saint Maurice', 'Saint Maurice', 'Saint Maurice', 45.7177100, 7.2554700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89070, 'Fabrizio', 'Fabrizio', 'Fabrizio', 39.6393900, 16.5566600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89071, 'Pizzano', 'Pizzano', 'Pizzano', 44.3550000, 11.4149900, 'IT', '2015-11-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89072, 'Bandito', 'Bandito', 'Bandito', 44.7228200, 7.8240300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89073, 'Villa Musone', 'Villa Musone', 'Villa Musone', 43.4462400, 13.6031200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89074, 'Bivio Santa Cecilia', 'Bivio Santa Cecilia', 'Bivio Santa Cecilia', 40.5222400, 15.0001800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89075, 'Penitro', 'Penitro', 'Penitro', 41.2732800, 13.6926200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89076, 'Zoccorino-Vergo', 'Zoccorino-Vergo', 'Zoccorino-Vergo', 45.6973500, 9.2537700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89077, 'Pedalino', 'Pedalino', 'Pedalino', 37.0232000, 14.5811600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89078, 'Alpo', 'Alpo', 'Alpo', 45.3768700, 10.9197900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89079, 'Banzano', 'Banzano', 'Banzano', 40.8433800, 14.8018200, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89080, 'Millepini', 'Millepini', 'Millepini', 45.4696700, 9.3376300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89081, 'Tagliaferro', 'Tagliaferro', 'Tagliaferro', 44.9785000, 7.6643000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89082, 'Mulino', 'Mulino', 'Mulino', 44.4925700, 11.0466700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89083, 'Città Giardino', 'Citta Giardino', 'Citta Giardino,Città Giardino', 37.1044400, 15.2117200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89084, 'Piano Maglio-Blandino', 'Piano Maglio-Blandino', 'Piano Maglio-Blandino', 38.0579300, 13.3090900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89085, 'Bodio', 'Bodio', 'Bodio', 45.7898900, 8.7514600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89086, 'Arino', 'Arino', 'Arino', 45.4385400, 12.0544300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89087, 'Sant''Angelo in Villa-Giglio', 'Sant''Angelo in Villa-Giglio', 'Sant''Angelo in Villa-Giglio', 41.6621700, 13.4287100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89088, 'Sant''Agata Martesana', 'Sant''Agata Martesana', 'Sant''Agata Martesana', 45.5222000, 9.3838200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89089, 'Santa Monica-Cella', 'Santa Monica-Cella', 'Santa Monica-Cella', 43.9576500, 12.6884600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89090, 'Gallo', 'Gallo', 'Gallo', 43.7863600, 12.7133400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89091, 'Pomaretto', 'Pomaretto', 'Pomaretto', 45.1519400, 8.0466100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89092, 'Villa San Giuseppe', 'Villa San Giuseppe', 'Villa San Giuseppe', 42.8686200, 13.7448100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89093, 'Geromina', 'Geromina', 'Geromina', 45.5364500, 9.5754000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89094, 'Roreto', 'Roreto', 'Roreto', 44.6693200, 7.8342300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89095, 'Amodio-Massariola', 'Amodio-Massariola', 'Amodio-Massariola', 40.8887200, 14.0909100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89096, 'Faella', 'Faella', 'Faella', 43.6265200, 11.5184400, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89097, 'San Tommaso Tre Archi', 'San Tommaso Tre Archi', 'San Tommaso Tre Archi', 43.2277100, 13.7750300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89098, 'Capezzano Inferiore', 'Capezzano Inferiore', 'Capezzano Inferiore', 40.7006700, 14.7730100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89099, 'Marcellina', 'Marcellina', 'Marcellina', 39.7657800, 15.8231100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89100, 'Fornase', 'Fornase', 'Fornase', 45.4758600, 12.1627300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89101, 'Nocera Scalo', 'Nocera Scalo', 'Nocera Scalo', 39.0157600, 16.1204000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89102, 'Tonengo-Casale', 'Tonengo-Casale', 'Tonengo-Casale', 45.2860900, 7.9396400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89103, 'Onigo', 'Onigo', 'Onigo', 45.8570100, 11.9907300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89104, 'Mairano', 'Mairano', 'Mairano', 45.3101900, 9.3590700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89105, 'Sferracavallo', 'Sferracavallo', 'Sferracavallo', 42.7263100, 12.0956900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89106, 'Villa Ceccolini', 'Villa Ceccolini', 'Villa Ceccolini', 43.8648100, 12.8360500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89107, 'Pasta', 'Pasta', 'Pasta', 45.0113100, 7.5524300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89108, 'Villaggio del Pino-Le Ginestre', 'Villaggio del Pino-Le Ginestre', 'Villaggio del Pino-Le Ginestre', 37.5829200, 15.0037700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89109, 'San Cipriano-S.Barbara-Centinale', 'San Cipriano-S.Barbara-Centinale', 'San Cipriano-S.Barbara-Centinale', 43.5686300, 11.4846700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89110, 'Piana San Raffaele', 'Piana San Raffaele', 'Piana San Raffaele', 45.1529000, 7.8501300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89111, 'San Michele Tiorre', 'San Michele Tiorre', 'San Michele Tiorre', 44.6853000, 10.2631700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89112, 'Piano di Conca', 'Piano di Conca', 'Piano di Conca', 43.8941300, 10.2949300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89113, 'Montelera', 'Montelera', 'Montelera', 45.1542900, 7.4429000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89114, 'Casco', 'Casco', 'Casco', 45.7107800, 9.8248300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89115, 'Gello', 'Gello', 'Gello', 43.7540200, 10.4238600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89116, 'Drubiaglio-Grangia', 'Drubiaglio-Grangia', 'Drubiaglio-Grangia', 45.0955200, 7.4194000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89117, 'Stazione', 'Stazione', 'Stazione', 43.9146000, 11.0141400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89118, 'Colle Campano-Scrima', 'Colle Campano-Scrima', 'Colle Campano-Scrima', 41.6236400, 13.4633600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89119, 'Barbisano', 'Barbisano', 'Barbisano', 45.8822400, 12.1863200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89120, 'Malavicina', 'Malavicina', 'Malavicina', 45.2991200, 10.7867700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89121, 'Colli di Enea', 'Colli di Enea', 'Colli di Enea', 41.6555400, 12.4903500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89122, 'Tregasio', 'Tregasio', 'Tregasio', 45.6777100, 9.2880600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89123, 'Macchia', 'Macchia', 'Macchia', 40.6535300, 14.9787900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89124, 'Moniego', 'Moniego', 'Moniego', 45.5612600, 12.0870500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89125, 'Gabbio-Cereda-Ramate', 'Gabbio-Cereda-Ramate', 'Gabbio-Cereda-Ramate', 45.9095900, 8.4211300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89126, 'Buffalora-Bettole', 'Buffalora-Bettole', 'Buffalora-Bettole', 45.4968100, 10.2751800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89127, 'Materdomini', 'Materdomini', 'Materdomini', 40.6557100, 17.9594900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89128, 'Macine-Borgo Loreto', 'Macine-Borgo Loreto', 'Macine-Borgo Loreto', 43.4861100, 13.0872500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89129, 'Ottava', 'Ottava', 'Ottava', 40.7852500, 8.4754300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89130, 'San Vincenzo', 'San Vincenzo', 'San Vincenzo', 44.7387800, 11.4366800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89131, 'Villa Ciambra', 'Villa Ciambra', 'Villa Ciambra', 38.0612900, 13.3200000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89132, 'Baratte', 'Baratte', 'Baratte', 45.1116000, 7.2364300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89133, 'Metato', 'Metato', 'Metato', 43.7735200, 10.3710600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89134, 'Acconia', 'Acconia', 'Acconia', 38.8358500, 16.2653000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89135, 'Quattro Strade', 'Quattro Strade', 'Quattro Strade', 45.6955000, 9.3768100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89136, 'Bottega', 'Bottega', 'Bottega', 43.8452300, 12.7499900, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89137, 'Valenzatico', 'Valenzatico', 'Valenzatico', 43.8668000, 10.9649700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89138, 'Savonera', 'Savonera', 'Savonera', 45.1136800, 7.6150600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89139, 'Matinella', 'Matinella', 'Matinella', 40.5015800, 15.0669200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89140, 'Castello', 'Castello', 'Castello', 45.9498000, 8.6756600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89141, 'Montano', 'Montano', 'Montano', 45.7942300, 9.0221800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89142, 'San Pierino', 'San Pierino', 'San Pierino', 43.7142300, 10.8137400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89143, 'Borghetto-Melara', 'Borghetto-Melara', 'Borghetto-Melara', 44.0985200, 9.9907300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89144, 'San Biagio', 'San Biagio', 'San Biagio', 45.3751800, 11.7371300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89145, 'Domio', 'Domio', 'Domio', 45.6104900, 13.8310300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89146, 'Canonica', 'Canonica', 'Canonica', 45.6558700, 9.2874900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89147, 'Savarna-Conventello', 'Savarna-Conventello', 'Savarna-Conventella', 44.5071700, 12.1062100, 'IT', '2017-01-23', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89148, 'Sala al Barro', 'Sala al Barro', 'Sala al Barro', 45.8205700, 9.3622000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89149, 'Cà Dè Fabbri', 'Ca De Fabbri', 'Ca De Fabbri,Cà Dè Fabbri', 44.6196200, 11.4550300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89150, 'Litta Parodi-Cascinagrossa', 'Litta Parodi-Cascinagrossa', 'Litta Parodi-Cascinagrossa', 44.8733600, 8.7124600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89151, 'Bertipaglia', 'Bertipaglia', 'Bertipaglia', 45.3159400, 11.8854700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89152, 'San Donato', 'San Donato', 'San Donato', 43.7029800, 10.7875400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89153, 'Padiglione', 'Padiglione', 'Padiglione', 43.8518000, 12.7212900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89154, 'Villair-Amerique', 'Villair-Amerique', 'Villair-Amerique', 45.7479300, 7.3898200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89155, 'Brenno Useria', 'Brenno Useria', 'Brenno Useria', 45.8614800, 8.8780100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89156, 'Torrion Quartara', 'Torrion Quartara', 'Torrion Quartara', 45.4181900, 8.6147200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89157, 'Campagnola', 'Campagnola', 'Campagnola', 45.3583300, 11.0495600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89158, 'Bastia', 'Bastia', 'Bastia', 45.3860900, 11.6519600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89159, 'Borgo Melano', 'Borgo Melano', 'Borgo Melano', 45.0157800, 7.5765600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89160, 'Santo Stefano', 'Santo Stefano', 'Santo Stefano', 39.3473400, 16.1989800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89161, 'Albareto', 'Albareto', 'Albareto', 44.6896400, 10.9671300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89162, 'San Giovanni', 'San Giovanni', 'San Giovanni', 37.7353800, 15.1588700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89163, 'San Giovanni-San Bernardino', 'San Giovanni-San Bernardino', 'San Giovanni-San Bernardino', 44.7929700, 9.6087100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89164, 'Caniezza', 'Caniezza', 'Caniezza', 45.8527400, 11.8990000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89165, 'Dragonea', 'Dragonea', 'Dragonea', 40.6791700, 14.7109400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89166, 'Bivio di Capanelle', 'Bivio di Capanelle', 'Bivio di Capanelle', 42.1196200, 12.5939500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89167, 'San Biagio', 'San Biagio', 'San Biagio', 45.0994200, 10.8472800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89168, 'La Rotta', 'La Rotta', 'La Rotta', 43.6585000, 10.6783700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89169, 'Sesto Cremonese', 'Sesto Cremonese', 'Sesto Cremonese', 45.1756800, 9.9144000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89170, 'Maresso', 'Maresso', 'Maresso', 45.6875500, 9.3559300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89171, 'Campanella-Gianforma', 'Campanella-Gianforma', 'Campanella-Gianforma', 36.9263000, 14.8336000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89172, 'Fonte Umano-San Martino Alta', 'Fonte Umano-San Martino Alta', 'Fonte Umano-San Martino Alta', 42.5208400, 14.1076000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89173, 'Ponton dell''Elce', 'Ponton dell''Elce', 'Ponton dell''Elce', 42.0227000, 12.2350500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89174, 'Pagliarone', 'Pagliarone', 'Pagliarone', 40.6300600, 14.9132500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89175, 'Guidomandri Marina', 'Guidomandri Marina', 'Guidomandri Marina', 38.0452800, 15.4630300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89176, 'Sciarborasca', 'Sciarborasca', 'Sciarborasca', 44.4018200, 8.6154100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89177, 'Cavallina', 'Cavallina', 'Cavallina', 43.9835300, 11.2314700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89178, 'Sasi', 'Sasi', 'Sasi', 37.9021700, 12.8878800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89179, 'Cuasso al Piano', 'Cuasso al Piano', 'Cuasso al Piano', 45.8945400, 8.8795100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89180, 'Salvo Marina', 'Salvo Marina', 'Salvo Marina', 42.0703700, 14.7659700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89181, 'Battaglione-Bagnara', 'Battaglione-Bagnara', 'Battaglione-Bagnara', 45.1163800, 10.0672600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89182, 'Ca'' Rainati', 'Ca'' Rainati', 'Ca'' Rainati', 45.7576400, 11.8511300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89183, 'Tabiago-Cibrone', 'Tabiago-Cibrone', 'Tabiago-Cibrone', 45.7563900, 9.2668400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89184, 'Bagno', 'Bagno', 'Bagno', 44.6554500, 10.7588100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89185, 'Gavarno-Tribulina', 'Gavarno-Tribulina', 'Gavarno-Tribulina', 45.7173400, 9.7751200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89186, 'Stazione Montalto-Coretto', 'Stazione Montalto-Coretto', 'Stazione Montalto-Coretto', 39.4072000, 16.2431300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89187, 'Tronca', 'Tronca', 'Tronca', 39.2461700, 17.1058200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89188, 'Ariano', 'Ariano', 'Ariano', 40.6566800, 15.0248100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89189, 'Grignano', 'Grignano', 'Grignano', 45.6181900, 9.5423500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89190, 'Velasca', 'Velasca', 'Velasca', 45.6316500, 9.3551900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89191, 'Cavino', 'Cavino', 'Cavino', 45.5170900, 11.8846600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89192, 'Asparetto', 'Asparetto', 'Asparetto', 45.2199100, 11.1826300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89193, 'Locara', 'Locara', 'Locara', 45.4120700, 11.3326200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89194, 'Zorlesco', 'Zorlesco', 'Zorlesco', 45.2003500, 9.6160300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89195, 'Oltre Brenta', 'Oltre Brenta', 'Oltre Brenta', 45.4120700, 11.9980300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89196, 'Cepina', 'Cepina', 'Cepina', 46.4360900, 10.3571300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89197, 'Lamie', 'Lamie', 'Lamie', 41.0336400, 16.8755900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89198, 'Pineta', 'Pineta', 'Pineta', 46.4399400, 11.3472700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89199, 'Fénis', 'Fenis', 'Chez Croiset,Fenis,Fénis', 45.7346900, 7.4954400, 'IT', '2015-09-14', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89200, 'Casette Verdini', 'Casette Verdini', 'Casette Verdini', 43.2510400, 13.4015600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89201, 'Pozzale-Case Nuove', 'Pozzale-Case Nuove', 'Pozzale-Case Nuove', 43.6958400, 10.9565100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89202, 'San Giuseppe le Prata-Cotropagno', 'San Giuseppe le Prata-Cotropagno', 'San Giuseppe le Prata-Cotropagno', 41.6778800, 13.3966400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89203, 'San Biagio', 'San Biagio', 'San Biagio', 43.5159700, 13.4964300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89204, 'San Michele dei Mucchietti', 'San Michele dei Mucchietti', 'San Michele dei Mucchietti', 44.5084700, 10.7472600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89205, 'Casola', 'Casola', 'Casola', 41.0951300, 14.3817200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89206, 'Pagliare', 'Pagliare', 'Pagliare', 42.6437200, 13.9517100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89207, 'Laura', 'Laura', 'Laura', 40.4322000, 14.9888600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89208, 'Case Campoli-Panetta', 'Case Campoli-Panetta', 'Case Campoli-Panetta', 41.6729600, 13.4717000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89209, 'Pontegradella', 'Pontegradella', 'Pontegradella', 44.8381300, 11.6628000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89210, 'Montesolaro', 'Montesolaro', 'Montesolaro', 45.7210000, 9.1176000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89211, 'Quaderni', 'Quaderni', 'Quaderni', 45.3291500, 10.7895100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89212, 'Gorgo della Chiesa', 'Gorgo della Chiesa', 'Gorgo della Chiesa', 45.7874700, 12.5627000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89213, 'Castelceriolo', 'Castelceriolo', 'Castelceriolo', 44.9172300, 8.6938400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89214, 'San Martino', 'San Martino', 'San Martino', 45.9080700, 12.3413200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89215, 'Girardi-Bellavista-Terrazze', 'Girardi-Bellavista-Terrazze', 'Girardi-Bellavista-Terrazze', 42.1026600, 12.5796000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89216, 'Venegazzù', 'Venegazzu', 'Venegazzu,Venegazzù', 45.7793400, 12.0914800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89217, 'Saletto', 'Saletto', 'Saletto', 45.4740000, 11.8604200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89218, 'Palazzolo', 'Palazzolo', 'Palazzolo', 37.5622400, 14.9298700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89219, 'Vergnasco', 'Vergnasco', 'Vergnasco', 45.4880300, 8.0855300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89220, 'San Nicola', 'San Nicola', 'San Nicola', 40.6105500, 8.9884100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89221, 'Selva', 'Selva', 'Selva', 42.1144200, 14.3442500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89222, 'Cologna-Caraverio', 'Cologna-Caraverio', 'Cologna-Caraverio', 45.7561100, 9.3457900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89223, 'Pratissolo', 'Pratissolo', 'Pratissolo', 44.6041600, 10.6740000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89224, 'San Fedele-Lusignano', 'San Fedele-Lusignano', 'San Fedele-Lusignano', 44.0455900, 8.1807800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89225, 'Premenugo', 'Premenugo', 'Premenugo', 45.4679000, 9.3845800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89226, 'San Martino in Trignano', 'San Martino in Trignano', 'San Martino in Trignano', 42.7412500, 12.6683600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89227, 'Figino', 'Figino', 'Figino', 45.4926100, 9.0777900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89228, 'Abbazia', 'Abbazia', 'Abbazia', 45.7480000, 9.8420500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89229, 'Belvedere-Piano Tavola', 'Belvedere-Piano Tavola', 'Belvedere-Piano Tavola', 37.5295500, 14.9878600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89230, 'Cinzano', 'Cinzano', 'Cinzano', 44.6930700, 7.9210300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89231, 'Manzolino', 'Manzolino', 'Manzolino', 44.5957700, 11.0998200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89232, 'Fraviano', 'Fraviano', 'Fraviano', 46.2969100, 10.6919700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89233, 'Baraggia', 'Baraggia', 'Baraggia', 45.8551600, 8.9088500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89234, 'Cavoni-Ginestreto', 'Cavoni-Ginestreto', 'Cavoni-Ginestreto', 39.4521200, 16.2626700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89235, 'Piangaiano', 'Piangaiano', 'Piangaiano', 45.7887700, 9.9946100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89236, 'Pulce', 'Pulce', 'Pulce', 44.4490900, 11.4115300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89237, 'Castelletto', 'Castelletto', 'Castelletto', 45.3315000, 10.2333500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89238, 'Villaguattera', 'Villaguattera', 'Villaguattera', 45.4440900, 11.8176700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89239, 'La Botte', 'La Botte', 'La Botte', 41.9817600, 12.7677500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89240, 'Niviano', 'Niviano', 'Niviano', 44.9402700, 9.6287800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89241, 'Strada', 'Strada', 'Strada', 43.4033700, 13.2207700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89242, 'Mandrogne', 'Mandrogne', 'Mandrogne', 44.8630800, 8.7467600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89243, 'Bellavista', 'Bellavista', 'Bellavista', 43.4419700, 11.1605100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89244, 'Carifi-Torello-Priscoli', 'Carifi-Torello-Priscoli', 'Carifi-Torello-Priscoli', 40.7913600, 14.7321200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89245, 'San Jacopo al Girone', 'San Jacopo al Girone', 'San Jacopo al Girone', 43.7695600, 11.3403200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89246, 'Folzano', 'Folzano', 'Folzano', 45.4958700, 10.2065000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89247, 'Piegolelle-San Bartolomeo', 'Piegolelle-San Bartolomeo', 'Piegolelle-San Bartolomeo', 40.6858300, 14.8231200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89248, 'Cavazzona', 'Cavazzona', 'Cavazzona', 44.5732600, 11.1190300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89249, 'Villanova', 'Villanova', 'Villanova', 43.7392600, 12.9352900, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89250, 'Via Lippia', 'Via Lippia', 'Via Lippia', 43.0861100, 12.4810600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89251, 'Torre Colonna-Sperone', 'Torre Colonna-Sperone', 'Torre Colonna-Sperone', 38.0298600, 13.5737700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89252, 'La Forma', 'La Forma', 'La Forma', 41.8344900, 13.0909200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89253, 'Ronco', 'Ronco', 'Ronco', 45.5961100, 10.1353100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89254, 'Campocavallo', 'Campocavallo', 'Campocavallo', 43.4612000, 13.4967900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89255, 'Camnago-Boscone', 'Camnago-Boscone', 'Camnago-Boscone', 45.8047200, 8.9793400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89256, 'San Pietro Belvedere', 'San Pietro Belvedere', 'San Pietro Belvedere', 43.5701100, 10.6660400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89257, 'Piane', 'Piane', 'Piane', 43.0970300, 13.4950200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89258, 'Prato di Coppola', 'Prato di Coppola', 'Prato di Coppola', 41.4175000, 12.8815700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89259, 'Ramiola', 'Ramiola', 'Ramiola', 44.7005500, 10.0911000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89260, 'Casalazzara', 'Casalazzara', 'Casalazzara', 41.6229900, 12.5763400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89261, 'Villanova', 'Villanova', 'Villanova', 42.3825100, 14.1233800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89262, 'Riva', 'Riva', 'Riva', 44.8925200, 7.3818900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89263, 'Piazza', 'Piazza', 'Piazza', 44.3859700, 7.8316300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89264, 'San Bartolomeo', 'San Bartolomeo', 'San Bartolomeo', 41.8140900, 12.9174500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89265, 'Moncucco', 'Moncucco', 'Moncucco', 45.3103200, 9.0392000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89266, 'Raffa', 'Raffa', 'Raffa', 45.5704700, 10.5296200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89267, 'Mantegazza', 'Mantegazza', 'Mantegazza', 45.5094600, 8.9732100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89268, 'Felina', 'Felina', 'Felina', 44.4547800, 10.4606700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89269, 'Zona Industriale', 'Zona Industriale', 'Zona Industriale', 43.2615500, 13.4883400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89270, 'Villaggio del Sole', 'Villaggio del Sole', 'Villaggio del Sole', 45.6139800, 9.1072500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89271, 'San Paolo', 'San Paolo', 'San Paolo,St. Pauls', 46.4720700, 11.2602100, 'IT', '2016-04-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89272, 'Arlate', 'Arlate', 'Arlate', 45.7236300, 9.4424200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89273, 'Madonna Dell''Albero', 'Madonna Dell''Albero', 'Madonna Dell''Albero', 44.3811500, 12.2004400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89274, 'Country Park', 'Country Park', 'Country Park', 40.8823400, 14.0778600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89275, 'Cereda-Cozza Cornedo', 'Cereda-Cozza Cornedo', 'Cereda-Cozza Cornedo', 45.6018100, 11.3674000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89276, 'Pianura Vomano', 'Pianura Vomano', 'Pianura Vomano', 42.6302800, 13.9154800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89277, 'Ponterio-Pian di Porto', 'Ponterio-Pian di Porto', 'Ponterio-Pian di Porto', 42.8076900, 12.4102400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89278, 'Sam Marino', 'Sam Marino', 'Sam Marino', 44.8073800, 10.9143800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89279, 'Gorzano', 'Gorzano', 'Gorzano', 44.5162600, 10.8798300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89280, 'Agliandroni-Paternella', 'Agliandroni-Paternella', 'Agliandroni-Paternella', 38.1328000, 13.0688400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89281, 'Villanova', 'Villanova', 'Villanova', 45.6402700, 9.3918700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89282, 'Villa Fontana', 'Villa Fontana', 'Villa Fontana', 44.4945500, 11.6088500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89283, 'Figliaro', 'Figliaro', 'Figliaro', 45.7799200, 8.9446600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89284, 'Monte Caminetto', 'Monte Caminetto', 'Monte Caminetto', 42.0665000, 12.4735800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89285, 'Bubano', 'Bubano', 'Bubano', 44.4134100, 11.7823100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89286, 'Costaroni', 'Costaroni', 'Costaroni', 42.0781900, 12.5371200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89287, 'Colleranesco', 'Colleranesco', 'Colleranesco', 42.7211200, 13.9373200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89288, 'Ballò', 'Ballo', 'Ballo,Ballò', 45.4558100, 12.0712400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89289, 'Negrone', 'Negrone', 'Negrone', 45.7102800, 9.7581100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89290, 'Rio Salso-Case Bernardi', 'Rio Salso-Case Bernardi', 'Rio Salso-Case Bernardi', 43.8343900, 12.6903100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89291, 'Rivotorto', 'Rivotorto', 'Rivotorto', 43.0440600, 12.6206900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89292, 'Rettifilo-Vannullo', 'Rettifilo-Vannullo', 'Rettifilo-Vannullo', 40.4512500, 15.0279400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89293, 'Villa d''Asolo', 'Villa d''Asolo', 'Villa d''Asolo', 45.7719300, 11.8998100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89294, 'Osteria del Gatto', 'Osteria del Gatto', 'Osteria del Gatto', 43.2850400, 12.7450400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89295, 'Musci', 'Musci', 'Musci', 40.8786100, 14.3660000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89296, 'Monti d''Arena-Bosco Caggione', 'Monti d''Arena-Bosco Caggione', 'Monti d''Arena-Bosco Caggione', 40.3551000, 17.3643200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89297, 'Lodetto', 'Lodetto', 'Lodetto', 45.5509900, 10.0317500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89298, 'Cunettone-Villa', 'Cunettone-Villa', 'Cunettone-Villa', 45.5878900, 10.5175600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89299, 'Monticello di Fara', 'Monticello di Fara', 'Monticello di Fara', 45.4289600, 11.3904200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89300, 'Valle di Vado', 'Valle di Vado', 'Valle di Vado', 44.2618300, 8.4139700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89301, 'Lavinaio-Monterosso', 'Lavinaio-Monterosso', 'Lavinaio-Monterosso', 37.6409700, 15.1046200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89302, 'Sant''Apollinare', 'Sant''Apollinare', 'Sant''Apollinare', 45.0411500, 11.8253300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89303, 'Valmadonna', 'Valmadonna', 'Valmadonna', 44.9744400, 8.6114600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89304, 'Carrozziere', 'Carrozziere', 'Carrozziere', 37.0376000, 15.2719500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89305, 'Montebonello', 'Montebonello', 'Montebonello', 43.8302700, 11.4865500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89306, 'Monte San Giovanni', 'Monte San Giovanni', 'Monte San Giovanni', 44.4201400, 11.1717000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89307, 'Nigoline-Bonomelli', 'Nigoline-Bonomelli', 'Nigoline-Bonomelli', 45.6290800, 9.9868200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89308, 'San Vito al Mantico', 'San Vito al Mantico', 'San Vito al Mantico', 45.4716300, 10.8924300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89309, 'Sabbionara', 'Sabbionara', 'Sabbionara', 45.7415200, 10.9574000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89310, 'Riccò', 'Ricco', 'Ricco,Riccò', 44.7005000, 10.1209500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89311, 'Uggia-Pazzera-Bizzarrino', 'Uggia-Pazzera-Bizzarrino', 'Uggia-Pazzera-Bizzarrino', 43.8343400, 10.8315400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89312, 'Castelmassimo', 'Castelmassimo', 'Castelmassimo', 41.6638900, 13.3806300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89313, 'Tavernelle', 'Tavernelle', 'Tavernelle', 45.5149800, 11.4486000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89314, 'Villapinta', 'Villapinta', 'Villapinta', 46.1750800, 9.6795000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89315, 'Poianella', 'Poianella', 'Poianella', 45.6304100, 11.6285300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89316, 'Casale', 'Casale', 'Casale', 41.2197200, 14.0023100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89317, 'Tetti Neirotti', 'Tetti Neirotti', 'Tetti Neirotti', 45.0533800, 7.5407700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89318, 'Borgo', 'Borgo', 'Borgo', 40.8402200, 14.7836400, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89319, 'Caprara', 'Caprara', 'Caprara', 44.7752100, 10.5115800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89320, 'Cerello-Battuello', 'Cerello-Battuello', 'Cerello-Battuello', 45.4471600, 8.9310500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89321, 'Bancali', 'Bancali', 'Bancali', 40.7354900, 8.4632800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89322, 'Sambughe', 'Sambughe', 'Sambughe', 45.5940100, 12.2182400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89323, 'Fossa', 'Fossa', 'Fossa', 44.9230400, 11.0235600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89324, 'Ghiare-Madonna', 'Ghiare-Madonna', 'Ghiare-Madonna', 44.8077000, 8.3740400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89325, 'Vigardolo', 'Vigardolo', 'Vigardolo', 45.6059900, 11.5885600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89326, 'Manera', 'Manera', 'Manera', 45.6734600, 9.0405800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89327, 'Quattro Strade', 'Quattro Strade', 'Quattro Strade', 43.7093600, 10.6582400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89328, 'Roggione', 'Roggione', 'Roggione', 45.1837800, 9.8073900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89329, 'Giovenzano', 'Giovenzano', 'Giovenzano', 45.2732200, 9.1160500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89330, 'Vadue', 'Vadue', 'Vadue', 39.2806000, 16.2287500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89331, 'Campiglione', 'Campiglione', 'Campiglione', 43.1763000, 13.6704300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89332, 'San Michele', 'San Michele', 'San Michele', 43.6621800, 12.9979700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89333, 'Casa del Diavolo', 'Casa del Diavolo', 'Casa del Diavolo', 43.1876200, 12.4492300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89334, 'Villanova', 'Villanova', 'Villanova', 44.6889300, 10.9174300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89335, 'Forche', 'Forche', 'Forche', 44.6364600, 10.5731600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89336, 'Barbiano', 'Barbiano', 'Barbiano', 44.3895000, 11.8865000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89337, 'Novagli', 'Novagli', 'Novagli', 45.3868800, 10.4387400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89338, 'Boscochiaro', 'Boscochiaro', 'Boscochiaro', 45.1365800, 12.1218200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89339, 'Villaggio Residenziale', 'Villaggio Residenziale', 'Villaggio Residenziale', 45.5282600, 9.4673700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89340, 'Costa-Barco', 'Costa-Barco', 'Costa-Barco', 45.5833700, 10.0390700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89341, 'Franche', 'Franche', 'Franche', 40.6717500, 14.5213900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89342, 'Berzantina', 'Berzantina', 'Berzantina', 44.1578600, 10.9808300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89343, 'Fanano', 'Fanano', 'Fanano', 43.9429600, 12.7482800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89344, 'La Rosa', 'La Rosa', 'La Rosa', 40.6067400, 17.9520700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89345, 'San Vito-Cerreto', 'San Vito-Cerreto', 'San Vito-Cerreto', 44.0230000, 10.1721200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89346, 'Guinzano', 'Guinzano', 'Guinzano', 45.2567800, 9.1586900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89347, 'Fornole', 'Fornole', 'Fornole', 42.5421800, 12.4557600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89348, 'Campofiorenzo-California', 'Campofiorenzo-California', 'Campofiorenzo-California', 45.6676800, 9.3170800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89349, 'Montelarco', 'Montelarco', 'Montelarco', 42.1633900, 12.4839800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89350, 'Borgo Massano', 'Borgo Massano', 'Borgo Massano', 43.8249500, 12.6796100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89351, 'Sfaranda', 'Sfaranda', 'Sfaranda', 38.0581500, 14.8314700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89352, 'Valle San Bartolomeo', 'Valle San Bartolomeo', 'Valle San Bartolomeo', 44.9501700, 8.6404000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89353, 'Sacca', 'Sacca', 'Sacca', 45.8995300, 10.2200800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89354, 'Cannizzaro-Favara', 'Cannizzaro-Favara', 'Cannizzaro-Favara', 38.0616300, 13.2716700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89355, 'Regolelli', 'Regolelli', 'Regolelli', 42.2931500, 12.3513100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89356, 'Rotta', 'Rotta', 'Rotta', 45.1624200, 9.1456400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89357, 'Squillace Lido', 'Squillace Lido', 'Squillace Lido', 38.7778100, 16.5700700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89358, 'Mazara II', 'Mazara II', 'Mazara II', 37.6814600, 12.6007400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89359, 'Le Forna', 'Le Forna', 'Le Forna', 40.9247500, 12.9689600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89360, 'Mimosa-Poggio Verde-Nuova Comunità', 'Mimosa-Poggio Verde-Nuova Comunita', 'Mimosa-Poggio Verde-Nuova Comunita,Mimosa-Poggio Verde-Nuova Comunità', 41.5387100, 14.6687900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89361, 'Capriglia', 'Capriglia', 'Capriglia', 40.7321600, 14.7603500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89362, 'Sant''Andrea', 'Sant''Andrea', 'Sant''Andrea', 44.0332800, 12.4189300, 'IT', '2014-04-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89363, 'Fantasina', 'Fantasina', 'Fantasina', 45.5732500, 10.1779000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89364, 'Monte San Marino', 'Monte San Marino', 'Monte San Marino', 41.7120000, 13.3119900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89365, 'Marina', 'Marina', 'Marina', 39.9385700, 16.6058500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89366, 'Giacalone', 'Giacalone', 'Giacalone', 38.0327600, 13.2369500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89367, 'Spinimbecco', 'Spinimbecco', 'Spinimbecco', 45.1439800, 11.3720200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89368, 'Monte', 'Monte', 'Monte', 45.7148900, 8.8222200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89369, 'Tombelle', 'Tombelle', 'Tombelle', 45.3984500, 11.9821300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89370, 'Pievedizio', 'Pievedizio', 'Pievedizio', 45.4606200, 10.0877100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89371, 'Fuorni', 'Fuorni', 'Fuorni', 40.6406300, 14.8492500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89372, 'Barberi', 'Barberi', 'Barberi', 42.4407200, 14.0426800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89373, 'Sant''Antonio', 'Sant''Antonio', 'Sant''Antonio', 44.3658600, 10.8364600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89374, 'Bosco Ex Parmigiano', 'Bosco Ex Parmigiano', 'Bosco Ex Parmigiano', 45.1069700, 10.0387000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89375, 'Campochiesa', 'Campochiesa', 'Campochiesa', 44.0706900, 8.1971200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89376, 'Pietre', 'Pietre', 'Pietre', 40.7004800, 14.6199300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89377, 'Quattro Strade', 'Quattro Strade', 'Quattro Strade', 43.7414800, 11.0807000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89378, 'Masseria Vecchia Ovest', 'Masseria Vecchia Ovest', 'Masseria Vecchia Ovest', 40.8896600, 14.0657300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89379, 'Rosegaferro', 'Rosegaferro', 'Rosegaferro', 45.3436100, 10.8085400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89380, 'Colle Mainello', 'Colle Mainello', 'Colle Mainello', 41.8697500, 12.7876700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89381, 'Sant''Albino', 'Sant''Albino', 'Sant''Albino', 43.0709800, 11.8068400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89382, 'Lido', 'Lido', 'Lido', 40.1912800, 16.7069200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89383, 'Cantinella', 'Cantinella', 'Cantinella', 39.6645800, 16.4491200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89384, 'Casone', 'Casone', 'Casone', 45.4981800, 8.8763500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89385, 'Sant''Antonio', 'Sant''Antonio', 'Sant''Antonio', 44.7588700, 8.0699600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89386, 'Prata Centro', 'Prata Centro', 'Prata Centro', 46.3084700, 9.3962500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89387, 'Martelli-Laganosa', 'Martelli-Laganosa', 'Martelli-Laganosa', 38.6793000, 16.5354900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89388, 'Chiesino-Collodi', 'Chiesino-Collodi', 'Chiesino-Collodi', 43.6795400, 10.6110600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89389, 'Ricca', 'Ricca', 'Ricca', 44.6612700, 8.0452700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89390, 'Prato', 'Prato', 'Prato', 44.7158900, 10.7479700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89391, 'Foresta', 'Foresta', 'Foresta', 39.0993900, 16.8128700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89392, 'Solara', 'Solara', 'Solara', 44.7716300, 11.0928700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89393, 'Villa', 'Villa', 'Villa', 44.7460600, 7.9006600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89394, 'Cellore', 'Cellore', 'Cellore', 45.4864600, 11.1783100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89395, 'San Rocco', 'San Rocco', 'San Rocco', 44.3965300, 7.4723000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89396, 'Isca Marina', 'Isca Marina', 'Isca Marina', 38.6034100, 16.5573300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89397, 'Lacugnano', 'Lacugnano', 'Lacugnano', 43.0947500, 12.3315000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89398, 'Il Romito', 'Il Romito', 'Il Romito', 43.6490800, 10.6453800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89399, 'Gabella', 'Gabella', 'Gabella', 43.7236000, 10.4972600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89400, 'Colubro', 'Colubro', 'Colubro', 41.7350600, 12.8672600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89401, 'Borgo', 'Borgo', 'Borgo', 44.7088700, 7.9622200, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89402, 'Petrosino', 'Petrosino', 'Petrosino', 37.8839200, 14.7991200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89403, 'Badile', 'Badile', 'Badile', 45.3506100, 9.1270500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89404, 'Belverde', 'Belverde', 'Belverde', 43.3482000, 11.3076300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89405, 'Furato', 'Furato', 'Furato', 45.5146800, 8.8806300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89406, 'Gliaca', 'Gliaca', 'Gliaca', 38.1631700, 14.8476800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89407, 'Bivio San Polo', 'Bivio San Polo', 'Bivio San Polo', 41.9741800, 12.8299300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89408, 'Borgo Fornari-Pieve', 'Borgo Fornari-Pieve', 'Borgo Fornari-Pieve', 44.5893300, 8.9367100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89409, 'Marocchi', 'Marocchi', 'Marocchi', 44.9420100, 7.8188800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89410, 'Pian di Mugnone', 'Pian di Mugnone', 'Pian di Mugnone', 43.8181000, 11.2958500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89411, 'Spartimento', 'Spartimento', 'Spartimento', 40.8910500, 14.4723600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89412, 'Montalbano', 'Montalbano', 'Montalbano', 43.9587900, 12.7164600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89413, 'Garbagnate', 'Garbagnate', 'Garbagnate', 45.7702700, 9.2984800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89414, 'Villafranca', 'Villafranca', 'Villafranca', 44.0329700, 8.1052500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89415, 'Campo', 'Campo', 'Campo', 43.7081100, 10.4770300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89416, 'Brongio', 'Brongio', 'Brongio', 45.7653500, 9.3125100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89417, 'Armetta', 'Armetta', 'Armetta', 41.8128000, 12.6878200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89418, 'Provezze', 'Provezze', 'Provezze', 45.6313900, 10.0728700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89419, 'Gavarno Rinnovata', 'Gavarno Rinnovata', 'Gavarno Rinnovata', 45.7245400, 9.7631800, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89420, 'Sant''Andrea', 'Sant''Andrea', 'Sant''Andrea', 45.6466400, 11.8963900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89421, 'Viadana', 'Viadana', 'Viadana', 45.3718900, 10.3363200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89422, 'Casate', 'Casate', 'Casate', 45.4920300, 8.8277600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89423, 'Ludriano', 'Ludriano', 'Ludriano', 45.4484600, 9.9327600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89424, 'Triginto', 'Triginto', 'Triginto', 45.4022300, 9.3251200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89425, 'Argine', 'Argine', 'Argine', 44.7749400, 10.6343200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89426, 'Val di Cava', 'Val di Cava', 'Val di Cava', 43.6383200, 10.6489600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89427, 'Costa Lambro', 'Costa Lambro', 'Costa Lambro', 45.6853100, 9.2472800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89428, 'Cartiera-Stazione', 'Cartiera-Stazione', 'Cartiera-Stazione', 41.6564200, 13.2408600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89429, 'Osteria', 'Osteria', 'Osteria', 43.5495000, 13.0218800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89430, 'Malche-Santa Croce-Serroni', 'Malche-Santa Croce-Serroni', 'Malche-Santa Croce-Serroni', 40.7092500, 14.9066800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89431, 'Pradelle', 'Pradelle', 'Pradelle', 45.2831500, 10.8708300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89432, 'Valli', 'Valli', 'Valli', 45.2234200, 12.1899000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89433, 'Pennisi', 'Pennisi', 'Pennisi', 37.6494500, 15.1238500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89434, 'Campese', 'Campese', 'Campese', 45.8058000, 11.7128900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89435, 'Moggio di Sotto', 'Moggio di Sotto', 'Moggio di Sotto', 46.4065100, 13.1950700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89436, 'San Pietro in Volta', 'San Pietro in Volta', 'San Pietro in Volta', 45.3154200, 12.3151800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89437, 'Lambrinia', 'Lambrinia', 'Lambrinia', 45.1583100, 9.5275000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89438, 'Novoledo', 'Novoledo', 'Novoledo', 45.6464700, 11.5095200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89439, 'Ozzano Taro', 'Ozzano Taro', 'Ozzano Taro', 44.7096900, 10.1408600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89440, 'Mantiglia di Ardea', 'Mantiglia di Ardea', 'Mantiglia di Ardea', 41.6768500, 12.6145300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89441, 'Stazione Masotti', 'Stazione Masotti', 'Stazione Masotti', 43.9098400, 10.8538600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89442, 'Badia al Pino', 'Badia al Pino', 'Badia al Pino', 43.4042400, 11.7722800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89443, 'Caldierino-Rota', 'Caldierino-Rota', 'Caldierino-Rota', 45.4161600, 11.1569600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89444, 'Crispi Cavour', 'Crispi Cavour', 'Crispi Cavour', 45.5819000, 11.5011300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89445, 'Puginate', 'Puginate', 'Puginate', 45.7109500, 9.0577200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89446, 'Rosario', 'Rosario', 'Rosario', 39.2910400, 16.2312500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89447, 'Ardole San Marino', 'Ardole San Marino', 'Ardole San Marino', 45.1563300, 10.1054600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89448, 'Terradura', 'Terradura', 'Terradura', 45.3229000, 11.8242500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89449, 'Pezzan', 'Pezzan', 'Pezzan', 45.6934100, 12.0961600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89450, 'Ronco', 'Ronco', 'Ronco', 45.5266800, 9.3592100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89451, 'Bora Bassa', 'Bora Bassa', 'Bora Bassa', 44.0463600, 12.1806600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89452, 'San Defendente', 'San Defendente', 'San Defendente', 44.3908800, 7.4909100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89453, 'Madrano-Canzolino', 'Madrano-Canzolino', 'Madrano-Canzolino', 46.0844000, 11.2173600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89454, 'Fane', 'Fane', 'Fane', 45.5790400, 10.9642500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89455, 'Alberi', 'Alberi', 'Alberi', 44.7483700, 10.3304500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89456, 'Capitan Loreto', 'Capitan Loreto', 'Capitan Loreto', 43.0173100, 12.6475000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89457, 'Nosadello', 'Nosadello', 'Nosadello', 45.4026800, 9.5304700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89458, 'Stazione di Allerona', 'Stazione di Allerona', 'Stazione di Allerona', 42.7855000, 12.0372600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89459, 'Padiglione', 'Padiglione', 'Padiglione', 43.4690000, 13.4626100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89460, 'Passaggio', 'Passaggio', 'Passaggio', 43.0223900, 12.5078100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89461, 'Salino', 'Salino', 'Salino', 42.7857100, 13.9140000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89462, 'Vaccheria', 'Vaccheria', 'Vaccheria', 44.7270000, 8.0429500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89463, 'Villassio', 'Villassio', 'Villassio', 45.8631300, 9.8446600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89464, 'Camilleri-Vallelata', 'Camilleri-Vallelata', 'Camilleri-Vallelata', 41.5984800, 12.6173800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89465, 'Vigliatore 2', 'Vigliatore 2', 'Vigliatore 2', 38.1222100, 15.1306600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89466, 'Santa Corinna', 'Santa Corinna', 'Santa Corinna', 45.3401800, 9.0887800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89467, 'Isoverde', 'Isoverde', 'Isoverde', 44.5294100, 8.8604900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89468, 'Capirro', 'Capirro', 'Capirro', 41.2540300, 16.4224200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89469, 'Pilastro', 'Pilastro', 'Pilastro', 44.6825400, 10.2887900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89470, 'Molella', 'Molella', 'Molella', 41.2600900, 13.0622100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89471, 'Cascinare', 'Cascinare', 'Cascinare', 43.2643400, 13.7118100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89472, 'Bargano', 'Bargano', 'Bargano', 45.2403100, 9.4468900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89473, 'Molino-Mozzi-Bittarelli', 'Molino-Mozzi-Bittarelli', 'Molino-Mozzi-Bittarelli', 45.6125400, 11.2350000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89474, 'San Vito', 'San Vito', 'San Vito', 45.4187500, 11.9621100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89475, 'San Giovanni-Patoni', 'San Giovanni-Patoni', 'San Giovanni-Patoni', 41.7722300, 13.2751000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89476, 'Amato', 'Amato', 'Amato', 38.3735500, 15.9609700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89477, 'Cerquotti-Madonna del Piano', 'Cerquotti-Madonna del Piano', 'Cerquotti-Madonna del Piano', 41.6419400, 13.2131600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89478, 'Pasteria-Lapide', 'Pasteria-Lapide', 'Pasteria-Lapide', 37.8101200, 15.2281800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89479, 'Badalasco', 'Badalasco', 'Badalasco', 45.5421700, 9.5549400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89480, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 40.7540500, 14.5897400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89481, 'Barone', 'Barone', 'Barone', 38.8522500, 16.6392700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89482, 'Duomo', 'Duomo', 'Duomo', 45.5324000, 10.0211800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89483, 'Prepezzano', 'Prepezzano', 'Prepezzano', 40.7275400, 14.8912300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89484, 'Gaiano', 'Gaiano', 'Gaiano', 44.7239100, 10.1726700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89485, 'Sassacci', 'Sassacci', 'Sassacci', 42.3234200, 12.4410800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89486, 'Tavo', 'Tavo', 'Tavo', 45.5006600, 11.8607900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89487, 'Canavaccio', 'Canavaccio', 'Canavaccio', 43.6937600, 12.6986300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89488, 'Cendon', 'Cendon', 'Cendon', 45.6380400, 12.3250500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89489, 'Favari-Avatanei', 'Favari-Avatanei', 'Favari-Avatanei', 44.9123500, 7.7995000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89490, 'Stradella', 'Stradella', 'Stradella', 45.1724500, 10.8732700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89491, 'Santa Croce Scuole', 'Santa Croce Scuole', 'Santa Croce Scuole', 44.7628100, 10.8494400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89492, 'Forette', 'Forette', 'Forette', 45.3422100, 10.9446000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89493, 'Buso', 'Buso', 'Buso', 45.0649100, 11.8477200, 'IT', '2017-05-27', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89494, 'Poggio Ellera', 'Poggio Ellera', 'Poggio Ellera', 42.1138000, 12.3717400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89495, 'San Zeno', 'San Zeno', 'San Zeno', 45.6338100, 10.7304600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89496, 'Belforte', 'Belforte', 'Belforte', 45.0809700, 10.5615600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89497, 'Faraldo-Nocelleto', 'Faraldo-Nocelleto', 'Faraldo-Nocelleto', 40.7799200, 14.7636300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89498, 'Montalto', 'Montalto', 'Montalto', 43.4991200, 11.6638000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89499, 'Casalini', 'Casalini', 'Casalini', 40.7377700, 17.4706200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89500, 'Bettola', 'Bettola', 'Bettola', 45.3317300, 9.0208000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89501, 'Porto d''Adda', 'Porto d''Adda', 'Porto d''Adda', 45.6624100, 9.4756300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89502, 'Villa San Filippo', 'Villa San Filippo', 'Villa San Filippo', 43.2598100, 13.5933700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89503, 'Cimbro', 'Cimbro', 'Cimbro', 45.7357000, 8.7205000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89504, 'Cassino d''Alberi', 'Cassino d''Alberi', 'Cassino d''Alberi', 45.3920800, 9.3909000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89505, 'Torrazza dei Mandelli', 'Torrazza dei Mandelli', 'Torrazza dei Mandelli', 45.5662900, 9.3992100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89506, 'Bulgorello', 'Bulgorello', 'Bulgorello', 45.7243300, 9.0552400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89507, 'Cascina Elisa', 'Cascina Elisa', 'Cascina Elisa', 45.6042500, 8.7997800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89508, 'Villaggio Montegrappa', 'Villaggio Montegrappa', 'Villaggio Montegrappa', 45.5464300, 11.6142800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89509, 'Brozzo', 'Brozzo', 'Brozzo', 45.7201900, 10.2309200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89510, 'Leone-Santa Elisabetta', 'Leone-Santa Elisabetta', 'Leone-Santa Elisabetta', 46.7316600, 11.6494400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89511, 'Brezza', 'Brezza', 'Brezza', 41.1107300, 14.1120100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89512, 'Borgo Lotti', 'Borgo Lotti', 'Borgo Lotti', 41.7641400, 12.5550000, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89513, 'Pugliano', 'Pugliano', 'Pugliano', 40.6787600, 14.9454300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89514, 'Strada', 'Strada', 'Strada', 43.7445200, 11.7100700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89515, 'Ronchi di Campanile', 'Ronchi di Campanile', 'Ronchi di Campanile', 45.4579000, 11.7748300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89516, 'Agrate', 'Agrate', 'Agrate', 45.6754000, 8.5606500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89517, 'San Giacomo', 'San Giacomo', 'San Giacomo', 45.5937900, 10.4768900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89518, 'Cipolleto', 'Cipolleto', 'Cipolleto', 43.3239300, 12.5768800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89519, 'Pontelangorino', 'Pontelangorino', 'Pontelangorino', 44.8608700, 12.1486400, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89520, 'San Maurizio', 'San Maurizio', 'San Maurizio', 45.6034900, 8.2869500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89521, 'Laxolo', 'Laxolo', 'Laxolo', 45.8087100, 9.5998300, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89522, 'Calozzo', 'Calozzo', 'Calozzo', 46.1005500, 9.2753100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89523, 'Stravignino', 'Stravignino', 'Stravignino', 45.7746900, 10.2383800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89524, 'La Place', 'La Place', 'La Place', 45.6541400, 7.6841400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89525, 'San Nico', 'San Nico', 'San Nico', 39.6690600, 16.4318200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89526, 'Arci-Empolitana', 'Arci-Empolitana', 'Arci-Empolitana', 41.9476600, 12.8250200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89527, 'Orzignano', 'Orzignano', 'Orzignano', 43.7740800, 10.4238200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89528, 'Colle del Pino', 'Colle del Pino', 'Colle del Pino', 41.7424600, 12.4964400, 'IT', '2016-12-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89529, 'Fellegara', 'Fellegara', 'Fellegara', 44.6105200, 10.6970000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89530, 'Colle Spina', 'Colle Spina', 'Colle Spina', 41.7820500, 12.8472300, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89531, 'Azzano', 'Azzano', 'Azzano', 45.9809600, 9.2028400, 'IT', '2016-02-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89532, 'Giavenale', 'Giavenale', 'Giavenale', 45.7000600, 11.4000200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89533, 'Pianello', 'Pianello', 'Pianello', 43.6262000, 13.1306800, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89534, 'Arlesega', 'Arlesega', 'Arlesega', 45.4612600, 11.7194200, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89535, 'Santa Fiora', 'Santa Fiora', 'Santa Fiora', 43.5598900, 12.1127100, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89536, 'Calmasino', 'Calmasino', 'Calmasino', 45.5209900, 10.7520600, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89537, 'Pitelli', 'Pitelli', 'Pitelli', 44.0945800, 9.8849000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89538, 'San Prospero', 'San Prospero', 'San Prospero', 44.7762800, 10.4009700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89539, 'Cominio', 'Cominio', 'Cominio', 42.3124800, 13.4325000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89540, 'Case Nuove', 'Case Nuove', 'Case Nuove', 45.6099800, 10.3941600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89541, 'Beregazzo', 'Beregazzo', 'Beregazzo', 45.7701900, 8.9586900, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89542, 'Navedano', 'Navedano', 'Navedano', 45.7552400, 9.0947000, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89543, 'Maccoli-Perrillo', 'Maccoli-Perrillo', 'Maccoli-Perrillo', 41.0876200, 14.8058500, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89544, 'Tonnara di Bonagia', 'Tonnara di Bonagia', 'Bonagia,Tonnara di Bonagia', 38.0630900, 12.5943400, 'IT', '2016-01-05', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89545, 'Sant''Antonio', 'Sant''Antonio', 'Sant''Antonio', 45.4043400, 10.3555700, 'IT', '2014-04-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89546, 'Prosto', 'Prosto', 'Prosto', 46.3294600, 9.4209400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89547, 'Paquier', 'Paquier', 'Paquier', 45.8787900, 7.6257500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89548, 'Casale', 'Casale', 'Casale', 44.9166500, 10.4316900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89549, 'Rifiano', 'Rifiano', 'Rifiano', 46.7028700, 11.1805700, 'IT', '2014-04-18', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89550, 'Nava', 'Nava', 'Nava', 45.7621900, 9.3630800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89551, 'Tettorosso', 'Tettorosso', 'Tettorosso', 44.4728400, 7.3429100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89552, 'Livera', 'Livera', 'Livera', 45.6123900, 8.1057100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89553, 'Chiesa', 'Chiesa', 'Chiesa', 45.5636000, 10.4620200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89554, 'Braglia', 'Braglia', 'Braglia', 44.9844600, 12.0337700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89555, 'Agliano', 'Agliano', 'Agliano', 44.7916400, 8.2512400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89556, 'Codogna-Cardano', 'Codogna-Cardano', 'Codogna-Cardano', 46.0276900, 9.2099200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89557, 'Era', 'Era', 'Era', 46.2442200, 9.3951500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89558, 'Sottocastello', 'Sottocastello', 'Sottocastello', 45.6672000, 10.3941600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89559, 'Occagno', 'Occagno', 'Occagno', 45.9290100, 9.0987000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89560, 'Calchera-Frontale', 'Calchera-Frontale', 'Calchera-Frontale', 45.8341500, 9.5115500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89561, 'Vescovado', 'Vescovado', 'Vescovado', 43.1695300, 11.3919800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89562, 'Villa', 'Villa', 'Villa', 46.7459100, 11.7624300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89563, 'Verla', 'Verla', 'Verla', 46.1579300, 11.1533100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89564, 'Villandro', 'Villandro', 'Foyandrum,Vilandra,Vilandro,Villanders,Villandro,vu~irrandoro,wei lan de luo,Виландро,Вилландро,Віландра,Вілландро,Վիլանդրո,ヴィッランドロ,维兰德罗', 46.6308600, 11.5380800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89565, 'Pederiva', 'Pederiva', 'Pederiva', 45.4225400, 11.4656800, 'IT', '2017-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89566, 'Sant''Elena Irpina', 'Sant''Elena Irpina', 'Sant''Elena Irpina', 41.0374100, 14.8893100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89567, 'Castione', 'Castione', 'Castione', 46.1728700, 9.8003200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89568, 'San Nicola', 'San Nicola', 'San Nicola', 38.2119900, 15.6938100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89569, 'Barbiano', 'Barbiano', 'Barbiano', 46.6041200, 11.5212000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89570, 'Camoneone', 'Camoneone', '', 45.7854700, 9.5691000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89571, 'Castelletto Po', 'Castelletto Po', 'Castelletto Po', 45.0690300, 9.1005600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89572, 'Crava', 'Crava', 'Crava', 44.4300100, 7.7449300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89573, 'Capriglia', 'Capriglia', 'Capriglia', 40.9597200, 14.7782000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89574, 'Bedero', 'Bedero', 'Bedero', 45.9777600, 8.7185200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89575, 'Rocchetta Nuova', 'Rocchetta Nuova', 'Rocchetta Nuova', 41.6237500, 14.0857400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89576, 'Fornaci', 'Fornaci', 'Fornaci', 45.1987200, 9.6779400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89577, 'Lassolaz', 'Lassolaz', 'Lassolaz', 45.7385100, 7.5888300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89578, 'San Giorgio', 'San Giorgio', 'San Giorgio', 45.1077800, 8.4142100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89579, 'Berriat', 'Berriat', 'Berriat', 45.7072900, 7.6761700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89580, 'Feglino', 'Feglino', 'Feglino', 44.2184900, 8.3243600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89581, 'Bivio Mortola', 'Bivio Mortola', 'Bivio Mortola', 41.3955700, 13.8966300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89582, 'Mure', 'Mure', 'Mure', 45.7341900, 11.6106500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89583, 'Valzemola', 'Valzemola', 'Valzemola', 44.3639300, 8.1737600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89584, 'Villa', 'Villa', 'Villa', 46.7797700, 11.6904700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89585, 'Borgo', 'Borgo', 'Borgo', 44.4052700, 7.9383900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89586, 'Prati', 'Prati', 'Prati', 44.3829000, 9.3756700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89587, 'Evangelisti-Rubino', 'Evangelisti-Rubino', 'Evangelisti-Rubino', 37.9841200, 15.1732400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89588, 'Lases', 'Lases', 'Lases', 46.1456000, 11.2193200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89589, 'Rivalta', 'Rivalta', 'Rivalta', 45.6571400, 10.8933600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89590, 'Monasterolo', 'Monasterolo', 'Monasterolo', 45.7632700, 9.9313800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89591, 'Montale', 'Montale', 'Montale', 44.2061900, 9.9447000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89592, 'Colla-Muggiasca', 'Colla-Muggiasca', 'Colla-Muggiasca', 45.9834300, 9.6227700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89593, 'Centro Urbano', 'Centro Urbano', 'Centro Urbano', 40.8198600, 15.3195300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89594, 'Vignola', 'Vignola', 'Vignola', 46.0881500, 9.2745600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89595, 'San Michele', 'San Michele', 'San Michele', 40.6202300, 14.5501800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89596, 'Dosso-Ville', 'Dosso-Ville', 'Dosso-Ville', 45.7525100, 10.2739700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89597, 'Gonte', 'Gonte', 'Gonte', 45.9951900, 8.6498200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89598, 'Villanuova', 'Villanuova', 'Villanuova', 45.4424500, 9.8669000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89599, 'Cadipietra', 'Cadipietra', 'Cadipietra', 46.9957600, 11.9802600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89600, 'Fontanella-Ozino', 'Fontanella-Ozino', 'Fontanella-Ozino', 45.6196300, 8.1692700, 'IT', '2014-04-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89601, 'Plan d''Introd', 'Plan d''Introd', 'Plan d''Introd', 45.6920300, 7.1832800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89602, 'Covelo', 'Covelo', 'Covelo', 45.9791900, 11.0697100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89603, 'Sirta', 'Sirta', 'Sirta', 46.1582300, 9.6610900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89604, 'San Zenone', 'San Zenone', 'San Zenone', 45.6416900, 10.1468500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89605, 'Sachet', 'Sachet', 'Sachet', 46.3698200, 11.9312900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89606, 'La Villa', 'La Villa', 'La Villa', 45.2671300, 7.4310900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89607, 'Canneto', 'Canneto', 'Canneto', 45.0511600, 9.2810100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89608, 'Piano', 'Piano', 'Piano', 44.3168000, 8.1663900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89609, 'San Genesio', 'San Genesio', 'San Genesio', 46.6580000, 11.9245600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89610, 'Melia', 'Melia', 'Melia', 37.9038400, 15.2749900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89611, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 44.1730200, 8.2442400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89612, 'Rossi', 'Rossi', 'Rossi', 44.0002900, 8.0588400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89613, 'Mornico', 'Mornico', 'Mornico', 45.0106200, 9.2092600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89614, 'San Giuseppe', 'San Giuseppe', 'San Giuseppe', 45.1470100, 7.0427100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89615, 'Coassolo', 'Coassolo', 'Coassolo', 45.2983800, 7.4613600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89616, 'Santa Maria dei Sabbioni', 'Santa Maria dei Sabbioni', 'Santa Maria dei Sabbioni', 45.2438600, 9.8392700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89617, 'Fleccia-Chianavasso', 'Fleccia-Chianavasso', 'Fleccia-Chianavasso', 44.9467000, 7.2147400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89618, 'Piccarello', 'Piccarello', 'Piccarello', 44.4839200, 8.9659500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89619, 'Moscheri', 'Moscheri', 'Moscheri', 45.8687500, 11.0738300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89620, 'Lanvario', 'Lanvario', 'Lanvario', 45.6397000, 8.1985600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89621, 'San Giovanni', 'San Giovanni', 'San Giovanni', 44.3936700, 8.4970100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89622, 'Gallo', 'Gallo', 'Gallo', 41.4649900, 14.2251900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89623, 'Santino', 'Santino', 'Santino', 45.9560600, 8.5191400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89624, 'Camerano', 'Camerano', 'Camerano', 44.9911800, 8.0896500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89625, 'Chiesa Nuova', 'Chiesa Nuova', 'Chiesa Nuova', 44.3697600, 9.3116100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89626, 'Villa d''Oneta', 'Villa d''Oneta', 'Villa d''Oneta', 45.8707400, 9.8192900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89627, 'Lemna', 'Lemna', 'Lemna', 45.8580800, 9.1598600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89628, 'Villa-Nabian', 'Villa-Nabian', 'Villa-Nabian', 45.6897000, 7.7047000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89629, 'Casavecchia', 'Casavecchia', 'Casavecchia', 44.5275600, 8.6215700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89630, 'Quincod', 'Quincod', 'Quincod', 45.7151300, 7.7349500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89631, 'Caines', 'Caines', 'Caines', 46.6979400, 11.1712200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89632, 'Santa Marta', 'Santa Marta', 'Santa Marta', 44.5040100, 8.8926800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89633, 'Zoppè di Cadore', 'Zoppe di Cadore', 'Zoppe di Cadore,Zoppè di Cadore', 46.3858300, 12.1736800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89634, 'San Rocco', 'San Rocco', 'San Rocco', 45.0094500, 9.1619100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89635, 'Ariola', 'Ariola', 'Ariola', 40.6279500, 15.4345300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89636, 'Cedessano', 'Cedessano', 'Cedessano', 45.6885800, 10.4339500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89637, 'Meiern', 'Meiern', 'Meiern', 46.5650300, 10.7827000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89638, 'Roapiana', 'Roapiana', 'Roapiana', 44.3407900, 7.8232900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89639, 'Antagnod', 'Antagnod', 'Antagnod', 45.8148400, 7.6893100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89640, 'Fontanafredda', 'Fontanafredda', 'Fontanafredda', 45.2915900, 11.6617200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89641, 'Molino-Pera', 'Molino-Pera', 'Molino-Pera', 44.4880300, 8.3089900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89642, 'Valentino', 'Valentino', 'Valentino', 45.1555800, 8.0939100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89643, 'Don', 'Don', 'Don', 46.2214400, 11.9559800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89644, 'Aurogna', 'Aurogna', 'Aurogna', 46.1714700, 9.3553600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89645, 'Servo', 'Servo', 'Servo', 46.0584400, 11.7865700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89646, 'Chiesa', 'Chiesa', 'Chiesa', 44.0778700, 8.1089100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89647, 'Longhi', 'Longhi', 'Longhi', 45.9074400, 11.3113200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89648, 'Borgo', 'Borgo', 'Borgo', 45.6388200, 8.1150800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89649, 'Mongnod', 'Mongnod', 'Mongnod', 45.8054900, 7.5680600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89650, 'La Pieve-Molino', 'La Pieve-Molino', 'La Pieve-Molino', 43.7372500, 11.6203300, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89651, 'Brovello', 'Brovello', 'Brovello', 45.8424600, 8.5318900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89652, 'Pontestazzemese', 'Pontestazzemese', 'Pontestazzemese', 43.9966500, 10.2943900, 'IT', '2014-05-29', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89653, 'Centrale', 'Centrale', 'Centrale', 46.1611800, 11.3029300, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89654, 'Barquedo', 'Barquedo', 'Barquedo', 45.7428300, 8.4963000, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89655, 'Montariolo', 'Montariolo', 'Montariolo', 44.9957500, 8.7753900, 'IT', '2016-05-26', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89656, 'Ferriere', 'Ferriere', 'Ferriere', 44.4430200, 9.1367500, 'IT', '2014-05-28', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89657, 'Serone', 'Serone', 'Serone', 46.1562700, 9.5817100, 'IT', '2016-05-30', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89658, 'Saint-Rhémy', 'Saint-Rhemy', 'Saint Rhemy', 45.8355300, 7.1839300, 'IT', '2016-05-03', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89659, 'Corigliano Scalo', 'Corigliano Scalo', 'Corigliano Scalo', 39.6271300, 16.5136800, 'IT', '2014-05-01', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89660, 'Ghiaie', 'Ghiaie', 'Ghiaie', 45.6820500, 9.5812100, 'IT', '2014-05-11', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89661, 'Sciaves', 'Sciaves', 'Sciaves', 46.7685900, 11.6660700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89662, 'Voltago', 'Voltago', 'Voltago', 46.2725200, 12.0064000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89663, 'Verano', 'Verano', 'Verana,Verano,Verano - Voeran,Veranum,Voeran,Vöran,vu~erano,wei la nuo,Верана,Верано,Վերանո,ヴェラーノ,韦拉诺', 46.6044200, 11.2256500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89664, 'Sant''Orsola', 'Sant''Orsola', 'Sant''Orsola', 46.1090100, 11.3020100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89665, 'Grizzana', 'Grizzana', 'Grizzana', 44.2580600, 11.1555700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89666, 'San Romano', 'San Romano', 'San Romano', 44.1704400, 10.3461800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89667, 'Villa', 'Villa', 'Villa', 44.7189500, 7.9413900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89668, 'Campolongo Maggiore', 'Campolongo Maggiore', '', 45.3235200, 12.0439100, 'IT', '2014-05-13', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89669, 'Atina Inferiore', 'Atina Inferiore', 'Atina Inferiore', 41.6270500, 13.7925800, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89670, 'Passo Ripe', 'Passo Ripe', 'Passo Ripe', 43.6556700, 13.1219600, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89671, 'Ponte di Nanto', 'Ponte di Nanto', 'Ponte di Nanto', 45.4242700, 11.5940000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89672, 'San Lorenzo di Rovetta', 'San Lorenzo di Rovetta', 'San Lorenzo di Rovetta', 45.8797100, 9.9753700, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89673, 'Santa Caterina dello Ionio Marina', 'Santa Caterina dello Ionio Marina', 'Santa Caterina dello Ionio Marina', 38.5273600, 16.5707100, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89674, 'Loreto Stazione', 'Loreto Stazione', 'Loreto Stazione', 43.4479200, 13.6201600, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89675, 'Progetto Case Coppito 3', 'Progetto Case Coppito 3', 'Progetto Case Coppito 3', 42.3698100, 13.3197300, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89676, 'Canove di Roana', 'Canove di Roana', 'Canove di Roana', 45.8635000, 11.4735000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89677, 'Natile Nuovo', 'Natile Nuovo', 'Natile Nuovo', 38.1858300, 16.0852700, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89678, 'Piazzolla', 'Piazzolla', 'Piazzolla', 40.8896400, 14.5157900, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89679, 'Progetto Case Sassa Nsi', 'Progetto Case Sassa Nsi', 'Progetto Case Sassa Nsi', 42.3656000, 13.3150900, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89680, 'Scalo di Baragiano', 'Scalo di Baragiano', 'Scalo di Baragiano', 40.6950000, 15.5750800, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89681, 'Poggiridenti Piano', 'Poggiridenti Piano', 'Poggiridenti Piano', 46.1699100, 9.9267100, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89682, 'Pie'' Falcade', 'Pie'' Falcade', 'Pie'' Falcade', 46.3566000, 11.8720700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89683, 'Marina', 'Marina', 'Marina', 39.4633000, 15.9812200, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89684, 'Taverna Ravindola', 'Taverna Ravindola', 'Taverna Ravindola', 41.5228300, 14.1259100, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89685, 'Borgata Marina', 'Borgata Marina', 'Borgata Marina', 39.9713600, 16.6209100, 'IT', '2014-05-16', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89686, 'Baruchella', 'Baruchella', 'Baruchella', 45.0660100, 11.4520800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89687, 'Spigno Saturnia Inferiore', 'Spigno Saturnia Inferiore', 'Spigno Saturnia Inferiore', 41.3114600, 13.7368500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89688, 'Castelbello', 'Castelbello', 'Castelbello', 46.6288500, 10.9071900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89689, 'Vauda Canavese Superiore', 'Vauda Canavese Superiore', 'Vauda Canavese Superiore', 45.2794700, 7.6194500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89690, 'Pozzaglio', 'Pozzaglio', 'Pozzaglio', 45.1999900, 10.0534500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89691, 'Marciano', 'Marciano', 'Marciano', 43.3065100, 11.7917100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89692, 'Ubiale', 'Ubiale', 'Ubiale', 45.7835000, 9.6165000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89693, 'Villa', 'Villa', 'Villa', 46.3305900, 9.4842600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89694, 'Paderno', 'Paderno', 'Paderno', 45.8279100, 11.8560500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89695, 'Botta', 'Botta', 'Botta', 45.8322200, 9.5325700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89696, 'Velo', 'Velo', 'Velo', 45.7898300, 11.3672500, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89697, 'Villa-Borgo', 'Villa-Borgo', 'Villa-Borgo', 44.6986500, 7.9348600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89698, 'Canistro Inferiore', 'Canistro Inferiore', 'Canistro Inferiore', 41.9410100, 13.4119400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89699, 'Vilminore', 'Vilminore', 'Vilminore', 45.9979500, 10.0953100, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89700, 'Prignano', 'Prignano', 'Prignano', 44.4379000, 10.6911800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89701, 'San Fidenzio', 'San Fidenzio', 'San Fidenzio', 45.2162200, 11.5180200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89702, 'Ponte di Castegnero', 'Ponte di Castegnero', 'Ponte di Castegnero', 45.4367200, 11.6006900, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89703, 'Piano di Mommio', 'Piano di Mommio', 'Piano di Mommio', 43.9095400, 10.2743500, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89704, 'Padule-San Marco', 'Padule-San Marco', 'Padule-San Marco', 43.3288000, 12.6094200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89705, 'Orvieto Scalo', 'Orvieto Scalo', 'Orvieto Scalo', 42.7208800, 12.1340200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89706, 'Chianchitta-Pallio', 'Chianchitta-Pallio', 'Chianchitta-Pallio', 37.8210800, 15.2531700, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89707, 'Marina di Altidona', 'Marina di Altidona', 'Marina di Altidona', 43.1060200, 13.8345400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89708, 'Meano', 'Meano', 'Meano', 46.1245700, 11.1176100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89709, 'Villapiana Lido', 'Villapiana Lido', 'Villapiana Lido', 39.8120300, 16.4882000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89710, 'Preara-Moraro-Levà Nord', 'Preara-Moraro-Leva Nord', 'Preara-Moraro-Leva Nord,Preara-Moraro-Levà Nord', 45.6799600, 11.5428600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89711, 'Codiverno', 'Codiverno', 'Codiverno', 45.4758300, 11.9455600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89712, 'Rocca Imperiale Marina', 'Rocca Imperiale Marina', 'Rocca Imperiale Marina', 40.0996200, 16.6133600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89713, 'Bisaccia Nuova', 'Bisaccia Nuova', 'Bisaccia Nuova', 41.0096000, 15.3554600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89714, 'Neive-Borgonovo', 'Neive-Borgonovo', 'Neive-Borgonovo', 44.7239700, 8.1178000, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89715, 'Ariano', 'Ariano', '', 44.9460400, 12.1244800, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89716, 'Piedimonte San Germano Alta', 'Piedimonte San Germano Alta', 'Piedimonte San Germano Alta', 41.5044600, 13.7490900, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89717, 'Falerna Scalo', 'Falerna Scalo', 'Falerna Scalo', 38.9728500, 16.1529400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89718, 'San Venanzio', 'San Venanzio', 'San Venanzio', 44.7451700, 11.4372700, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89719, 'Gazzolo-Volpino', 'Gazzolo-Volpino', 'Gazzolo-Volpino', 45.3753600, 11.3131900, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89720, 'Fabro Scalo', 'Fabro Scalo', 'Fabro Scalo', 42.8760500, 12.0462400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89721, 'Villanova del Ghebbo Canton', 'Villanova del Ghebbo Canton', 'Villanova del Ghebbo Canton', 45.0593300, 11.6431400, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89722, 'Saponara Marittima', 'Saponara Marittima', 'Saponara Marittima', 38.2312100, 15.4262100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89723, 'Arbia', 'Arbia', 'Arbia', 43.2934200, 11.4097800, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89724, 'Piane di Montegiorgio', 'Piane di Montegiorgio', 'Piane di Montegiorgio', 43.1158700, 13.5666900, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89725, 'Orbetello Scalo', 'Orbetello Scalo', 'Orbetello Scalo', 42.4486600, 11.2493600, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89726, 'Molinetto', 'Molinetto', 'Molinetto', 45.4940900, 10.3588800, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89727, 'Marotta', 'Marotta', 'Marotta', 43.7989300, 13.0945200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89728, 'Calvi Risorta', 'Calvi Risorta', 'Calvi Risorta', 41.2159800, 14.1309200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89729, 'Leporano Marina', 'Leporano Marina', 'Leporano Marina', 40.3786000, 17.3096000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89730, 'Tortora Marina', 'Tortora Marina', 'Tortora Marina', 39.9229300, 15.7694300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89731, 'Santa Maria la Stella', 'Santa Maria la Stella', 'Santa Maria la Stella', 37.6234900, 15.1207100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89732, 'Colleverde II', 'Colleverde II', 'Colleverde II', 41.9753300, 12.6319100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89733, 'Chiusi Scalo', 'Chiusi Scalo', 'Chiusi Scalo', 42.9961300, 11.9541200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89734, 'Cetraro Marina', 'Cetraro Marina', 'Cetraro Marina', 39.5170100, 15.9346000, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89735, 'Venetico Marina', 'Venetico Marina', 'Venetico Marina', 38.2192800, 15.3664800, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89736, 'Orte Scalo', 'Orte Scalo', 'Orte Scalo', 42.4348300, 12.4078300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89737, 'Corcagnano', 'Corcagnano', 'Corcagnano', 44.7210300, 10.3027100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89738, 'Due Carrare', 'Due Carrare', 'Due Carrare', 45.2915100, 11.8240200, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89739, 'Licinella-Torre di Paestum', 'Licinella-Torre di Paestum', 'Licinella-Torre di Paestum', 40.4065600, 14.9976400, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89740, 'Torvaianica Alta', 'Torvaianica Alta', 'Torvaianica Alta', 41.6316200, 12.4976500, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89741, 'Gerbole-Zucche', 'Gerbole-Zucche', 'Gerbole-Zucche', 44.9860500, 7.5167100, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89742, 'Nucleo Industriale di Bazzano', 'Nucleo Industriale di Bazzano', 'Nucleo Industriale di Bazzano', 42.3362300, 13.4675500, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89743, 'Ponte a Poppi', 'Ponte a Poppi', 'Ponte a Poppi', 43.7317100, 11.7666300, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89744, 'Muzza di Cornegliano Laudense', 'Muzza di Cornegliano Laudense', 'Muzza di Cornegliano Laudense', 45.2846200, 9.4716600, 'IT', '2014-05-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89745, 'Poasco-Sorigherio', 'Poasco-Sorigherio', 'Poasco-Sorigherio', 45.4031000, 9.2309200, 'IT', '2014-05-17', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89746, 'Vago', 'Vago', '', 45.4198600, 11.1302000, 'IT', '2016-03-02', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89747, 'Ca'' Morosini', 'Ca'' Morosini', '', 45.1126600, 11.6189000, 'IT', '2016-05-25', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89748, 'Dimaro-Folgarida', 'Dimaro-Folgarida', '', 46.3317600, 10.8720000, 'IT', '2016-11-12', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89749, 'Mappano', 'Mappano', 'Mapan,Mappano Torinese', 45.1483300, 7.7077800, 'IT', '2017-07-20', 110);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89752, 'Yallahs', 'Yallahs', 'Yallahs,Yallahs Bay,Yallahs Village', 17.8748000, -76.5624500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89753, 'Williamsfield', 'Williamsfield', '', 18.0666700, -77.4666700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89754, 'Wakefield', 'Wakefield', '', 18.4121100, -77.7218300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89755, 'Ulster Spring', 'Ulster Spring', '', 18.3148200, -77.5206700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89756, 'Trinity Ville', 'Trinity Ville', '', 17.9607600, -76.5142700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89757, 'Stony Hill', 'Stony Hill', '', 18.0791600, -76.7847300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89758, 'Spanish Town', 'Spanish Town', 'Hispanurbo,Saint Jago de la Vega,Spanis Taoun,Spanis Taunas,Spanish Town,Spanish-Taun,Spaniš Taunas,sbanysh tawn,seupaenisitaun,xi ban ya zhen,Σπάνις Τάουν,Спаниш-Таун,سبانيش تاون,سپینش ٹاؤن,スパニッシュ・タウン,西班牙鎮,스패니시타운', 17.9910700, -76.9574200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89759, 'Southfield', 'Southfield', '', 17.8878000, -77.6671300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89760, 'Siloah', 'Siloah', 'Siloah,Village of Shiloah', 18.1670900, -77.7034800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89761, 'Seaforth', 'Seaforth', 'Seaforth,Seaforth Village', 17.9357800, -76.4573000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89762, 'Savanna-la-Mar', 'Savanna-la-Mar', 'Sav,Sav-la-Mar,Savanna-la-Mar,Savannah la Mar', 18.2189500, -78.1332000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89763, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 18.0533600, -77.6983600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89764, 'Sandy Bay', 'Sandy Bay', 'Sandy Bay,Sandy Bay Village', 18.4485400, -78.0732100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89765, 'Saint Ann’s Bay', 'Saint Ann''s Bay', 'Saint Ann''s Bay,Saint Ann’s Bay,Santa Gloria,St Ann''s Bay', 18.4358100, -77.2009800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89766, 'Runaway Bay', 'Runaway Bay', 'Runaway Bay,Runaway Bay Settlement,Runaway Bay Village,Runaway Village,Runnaway-Bay', 18.4596200, -77.3357000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89767, 'Rocky Point', 'Rocky Point', 'Rocky Point', 17.7740000, -77.2610700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89768, 'Rock Spring', 'Rock Spring', '', 18.3012300, -77.5525900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89769, 'Riversdale', 'Riversdale', '', 18.1658600, -76.9641700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89770, 'Richmond', 'Richmond', 'Richmond,Richmond Village', 18.2547800, -76.8879900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89771, 'Race Course', 'Race Course', 'Race Course', 17.8401900, -77.2822300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89772, 'Porus', 'Porus', 'Porus', 18.0353500, -77.4116600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89773, 'Port Royal', 'Port Royal', 'Port Royal,Port-Rojal,bwrt rwyal,luo ya er gang,poteuloyeol,pwrt rwyal,Порт-Ройал,Порт-Роял,بورت رويال,پورت رویال,ポート・ロイヤル,罗亚尔港,포트로열', 17.9371200, -76.8408100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89774, 'Portmore', 'Portmore', 'Portmore', 17.9503200, -76.8821500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89775, 'Port Maria', 'Port Maria', 'Port Maria', 18.3684900, -76.8894600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89776, 'Port Antonio', 'Port Antonio', 'POT,Port Antonio,Port-Antonio,Saint Francois,an dong ni ao gang,Πορτ Αντόνιο,Порт-Антонио,پورٹ انتونیو,安東尼奧港', 18.1761500, -76.4509000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89777, 'Point Hill', 'Point Hill', '', 18.0898800, -77.1075900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89778, 'Petersfield', 'Petersfield', '', 18.2615800, -78.0711700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89779, 'Oracabessa', 'Oracabessa', 'Oracabessa', 18.4031900, -76.9464100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89780, 'Old Harbour Bay', 'Old Harbour Bay', '', 17.9091800, -77.0971800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89781, 'Old Harbour', 'Old Harbour', 'Old Harbor,Old Harbour', 17.9414400, -77.1089800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89782, 'Ocho Rios', 'Ocho Rios', 'Las Chorreras,OCJ,Ocho Rios,Ocho Ríos,Ocho-Rios,Otso Rios,ao qiao li ao si,awtshw ryws,ocho・riosu,Ότσο Ρίος,Очо-Риос,Очо-Ріос,أوتشو ريوس,オーチョ・リオス,奧喬里奧斯', 18.4025000, -77.1048000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89783, 'New Kingston', 'New Kingston', '', 18.0074700, -76.7831900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89784, 'Negril', 'Negril', 'Gorad Negryl,NEG,Negril,Negril Harbour,neguriru,nei ge li er,Горад Негрыл,Негрил,ネグリル,內格里爾', 18.2684400, -78.3481000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89785, 'Nain', 'Nain', '', 17.9652600, -77.6052800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89786, 'Morant Bay', 'Morant Bay', 'Morant,Morant Bay', 17.8814500, -76.4092700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89787, 'Moore Town', 'Moore Town', 'Moore Town,More Town', 18.0776700, -76.4257700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89788, 'Montego Bay', 'Montego Bay', 'Bahia Montego,Bahía Montego,MBJ,Mantica Bahia,Montego,Montego Bay,Montego Bejus,Montego Bėjus,Montego-Bej,Montenko Bey,Monteqo-Bey,mamtego be,meng te ge bei,montegobei,mwntgwby,mwntyghw bay,mwntygw byy,Μοντέγκο Μπέυ,Монтего-Бей,מונטיגו ביי,مونتيغو باي,مونتگوبی,مونٹیگو بے,माँटेगो बे,モンテゴ・ベイ,蒙特哥貝,몬테고베이', 18.4711600, -77.9188300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89789, 'Moneague', 'Moneague', 'Moneague', 18.2755600, -77.1117700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89790, 'Mona Heights', 'Mona Heights', '', 18.0137500, -76.7518600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89791, 'Mocho', 'Mocho', '', 18.0400000, -77.3300000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89792, 'May Pen', 'May Pen', 'May Pen', 17.9645400, -77.2451500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89793, 'Mavis Bank', 'Mavis Bank', 'Mari Bank,Mavis Bank', 18.0333300, -76.6666700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89794, 'Maroon Town', 'Maroon Town', 'Camperdown,Maroon Town', 18.3446400, -77.7954400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89795, 'Mandeville', 'Mandeville', 'MVJ,Mandevil'',Mandeville,Мандевиль', 18.0416800, -77.5071400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89796, 'Manchioneal', 'Manchioneal', '', 18.0444400, -76.2773500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89797, 'Malvern', 'Malvern', '', 17.9666700, -77.7000000, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89798, 'Maggotty', 'Maggotty', 'Maggotty', 18.1606900, -77.7634900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89799, 'Lucea', 'Lucea', 'Lucea', 18.4509500, -78.1735600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89800, 'Lluidas Vale', 'Lluidas Vale', 'Lluidas Vale,Luidas Vale', 18.1258700, -77.1482300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89801, 'Lionel Town', 'Lionel Town', 'Lionel Town', 17.8100700, -77.2406100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89802, 'Linstead', 'Linstead', '', 18.1368300, -77.0317100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89803, 'Lacovia', 'Lacovia', 'Lacovia', 18.0721000, -77.7505900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89804, 'Kingston', 'Kingston', 'KIN,Kin''nkston,Kingston,jing si dui,kingseuteon,kingusuton,kyngstwn,Κίνγκστον,Кингстон,کینگستون,キングストン,京斯敦,킹스턴', 17.9970200, -76.7935800, 'JM', '2015-06-03', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89805, 'Kellits', 'Kellits', 'Kellets,Kellits', 18.1618400, -77.2704900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89806, 'Islington', 'Islington', '', 18.3092200, -76.8548200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89807, 'Hope Bay', 'Hope Bay', 'Hope,Hope Bay', 18.1988200, -76.5653900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89808, 'Hayes', 'Hayes', 'Hayes', 17.8756900, -77.2371100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89809, 'Half Way Tree', 'Half Way Tree', 'Half Way Tree', 18.0124800, -76.7992800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89810, 'Gordon Town', 'Gordon Town', '', 18.0357800, -76.7178300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89811, 'Golden Grove', 'Golden Grove', '', 17.9336100, -76.2725400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89812, 'Gayle', 'Gayle', 'Gayle,Gayle Village', 18.3264200, -77.0097100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89813, 'Falmouth', 'Falmouth', 'Falmouth', 18.4935800, -77.6558700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89814, 'Ewarton', 'Ewarton', '', 18.1833300, -77.0853600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89815, 'Easington', 'Easington', '', 17.9239700, -76.5882400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89816, 'Duncans', 'Duncans', 'Duncans', 18.4680000, -77.5363300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89817, 'Discovery Bay', 'Discovery Bay', 'Discovery Bay,Dry Harbor,Dry Harbour,Puerto Bueno', 18.4587300, -77.3999700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89818, 'Darliston', 'Darliston', 'Darlingston,Darliston', 18.2373100, -77.9762600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89819, 'Dalvey', 'Dalvey', 'Dalvey,Dalvy', 17.9118400, -76.2486400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89820, 'Constant Spring', 'Constant Spring', 'Constant Spring', 18.0507800, -76.7937200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89821, 'Coleyville', 'Coleyville', '', 18.2078300, -77.5075400, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89822, 'Chapelton', 'Chapelton', 'Chapelton', 18.0833300, -77.2666700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89823, 'Cascade', 'Cascade', '', 18.3974700, -78.1033700, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89824, 'Cambridge', 'Cambridge', 'Cambridge,Cambridge Station', 18.3132600, -77.9025200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89825, 'Bull Savanna', 'Bull Savanna', '', 17.8867800, -77.5902200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89826, 'Buff Bay', 'Buff Bay', 'Buff Bay', 18.2328700, -76.6611800, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89827, 'Bog Walk', 'Bog Walk', '', 18.1020500, -77.0054100, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89828, 'Bluefields', 'Bluefields', 'Bluefields', 18.1660200, -78.0270200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89829, 'Black River', 'Black River', '', 18.0263600, -77.8487300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89830, 'Bethel Town', 'Bethel Town', '', 18.2950300, -77.9511200, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89831, 'Bath', 'Bath', 'Bath,The Bath', 17.9482000, -76.3491600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89832, 'Bamboo', 'Bamboo', 'Bamboo,Excellent Town', 18.3921600, -77.2642900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89833, 'Balaclava', 'Balaclava', 'Balaclava', 18.1722800, -77.6437500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89834, 'Mt Peto', 'Mt Peto', 'Axe Adze,Axe and Adze,Mount Peto,Mt Peto', 18.3637000, -78.0373600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89835, 'Annotto Bay', 'Annotto Bay', 'Annatto Bay,Annotta Bay,Annotto Bay', 18.2717000, -76.7652300, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89836, 'Anchovy', 'Anchovy', 'Anchovy,Anchovy Station', 18.4103000, -77.9316600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89837, 'Alligator Pond', 'Alligator Pond', 'Alligator Pond,Alligator Pond Bay,Alligator Pond Village', 17.8700200, -77.5666700, 'JM', '2012-01-16', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89838, 'Alexandria', 'Alexandria', '', 18.3076800, -77.3533500, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89839, 'Albert Town', 'Albert Town', 'Albert Town', 18.2943400, -77.5423900, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89840, 'Limit', 'Limit', '', 18.1528700, -77.4712100, 'JM', '2011-11-12', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89841, 'Quickstep', 'Quickstep', '', 18.2624000, -77.6458600, 'JM', '2017-03-14', 111);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89980, 'Shingū', 'Shingu', 'Schingu,Shingu,Shingui,Shingū,Sing,Singu,Singu-chhi,Singû-chhī,Singū,shynghw,shyngw  wakayama,singu si,xin gong,xin gong shi,Синг,Сингу,Сінґу,Шингу,شينغو,شینگو، واکایاما,新宮,新宮市,신구 시', 33.7333300, 135.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89981, 'Atsugi', 'Atsugi', 'Acugi,Atsugi,Atsugicho,Atsugichō,Atsuki,Atugi,Atugi-chhi,Atugi-chhī,NJA,asseugi si,atswghy,atswgy  kanagawa,hou mu,hou mu ding,hou mu shi,xa sungi,Атсуги,Ацуги,Ацуґі,آتسوگی، کاناگاوا,أتسوغي,اتسوگی، کاناگاوا,อะสึงิ,厚木,厚木市,厚木町,아쓰기 시', 35.4427200, 139.3693100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89982, 'Akashi', 'Akashi', 'Akashi,Akasi,Akasi-chhi,Akasi-chhī,Akasis,Akasyi,Akaşi,Akašis,akashy,akashy  hywgw,akasi si,ming shi,ming shi shi,xa ka chi,Акаси,Акаши,Акаші,آکاشی,آکاشی، هیوگو,أكاشي,อะกะชิ,明石,明石市,아카시 시', 34.6552400, 135.0068700, 'JP', '2017-07-28', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89983, 'Zushi', 'Zushi', 'Zushi,dou zi,zushi,ずし,ズシ,逗子', 35.2948300, 139.5781200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89984, 'Zentsujichó', 'Zentsujicho', 'Zentsujicho,Zentsujichó,shan tong si,shan tong si ding,善通寺,善通寺町', 34.2269900, 133.7779100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89985, 'Zama', 'Zama', 'Dzama,Sama,Zama,Zama-chhi,Zama-chhī,jama si,sa ma,zama,zama  kanagawa,zuo jian,zuo jian shi,Дзама,Зама,زاما,زاما، کاناگاوا,ซะมะ,座間,座間市,자마 시', 35.4879000, 139.3910100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89986, 'Yuza', 'Yuza', 'Yusa,Yusamachi,Yuza,Yuzamachi,you zuo,遊佐', 39.0157300, 139.9290900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89987, 'Gero', 'Gero', 'Gero,Gero-chhi,Gero-chhī,Qero,gelo si,ghyrw,grw  gyfw,kea roa,xia lu,xia lu shi,Геро,Ґеро,غيرو,گرو، گیفو,เกะโระ,下呂,下呂市,게로 시', 35.8000000, 137.2333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89988, 'Yukuhashi', 'Yukuhashi', 'Jukukhashi,Jukukhasi,Yukihashi,Yukuhashi,Yukuhasi-chhi,Yukuhasi-chhī,Yukuhasyi,xing qiao,xing qiao shi,yukuhasi si,ywkhashy  fwkwka,ywkwhashy,ywkwhashy  fwkwywka,Юкухаси,Юкухаші,Юкуҳаши,يوكوهاشي,یوکحاشی، فوکوکا,یوکوهاشی، فوکوئوکا,行橋,行橋市,유쿠하시 시', 33.7287300, 130.9830000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89989, 'Yūki', 'Yuki', 'Juki,Yuki,Yuki-chhi,Yuki-chhī,Yūki,jie cheng,jie cheng shi,yky  abaraky,yuki,yuki si,ywky,ywky  aybaraky,Юки,Юкі,يوكي,یوکی، ایباراکی,یکی، اباراکی,ยูกิ,結城,結城市,유키 시', 36.3000000, 139.8833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89990, 'Yugawara', 'Yugawara', 'Yugawara', 35.1500000, 139.0666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89991, 'Yudomari', 'Yudomari', 'Judomari,Yudomari,Yutomari,Юдомари', 30.2347000, 130.4794200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89992, 'Yoshino-chō', 'Yoshino-cho', 'ji ye ting,吉野町', 34.3961100, 135.8576800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89993, 'Yoshikawa', 'Yoshikawa', 'Esikava,Yoshikawa,ji chuan,Есикава,吉川', 35.8923200, 139.8418400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89994, 'Yoshii', 'Yoshii', '', 36.2500000, 138.9833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89995, 'Yoshida-kasugachō', 'Yoshida-kasugacho', 'Yoshida,Yoshida-kasugacho,Yoshida-kasugachō,ji tian chun ri ding,吉田春日町', 37.6833300, 138.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89996, 'Yorii', 'Yorii', 'Yorii,ji ju,寄居', 36.1156700, 139.1942900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89997, 'Yono', 'Yono', '', 35.8833300, 139.6333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89998, 'Yonakuni', 'Yonakuni', 'Jonaguni,Yonaguni,Yonakuni,Йонагуни', 24.4666700, 123.0000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89999, 'Yonago', 'Yonago', 'Jonagas,Jonago,YGJ,Yonago,Yonago-chhi,Yonago-chhī,ionago,mi zi,mi zi shi,yonago si,ywnaghw,ywnaghw  twtwry,ywnagw  twtwry,Ёнаго,Јонаго,Йонаго,Йонаґо,يوناغو,يوناغو، توتوري,یوناگو، توتوری,یوناگو، توتٹوری,იონაგო,米子,米子市,요나고 시', 35.4333300, 133.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90000, 'Yokosuka', 'Yokosuka', 'Gorad Iakosuka,Jokosuka,Yokosuka,Yokosuka-chhi,Yokosuka-chhī,heng xu he,heng xu he shi,yoa koa suk a,yokoseuka si,ywkwska  knagwa,ywkwswka,ywkwswka  kanagawa,ywqwswqh,Ёкосука,Јокосука,Горад Іакосука,Йокосука,יוקוסוקה,يوكوسوكا,یوکوسوکا، کاناگاوا,یوکوسکا، کناگوا,โยะโกะซุกะ,იოკოსუკა,横須賀,横須賀市,橫須賀市,요코스카 시', 35.2836100, 139.6672200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90001, 'Yokohama', 'Yokohama', 'Iokogama,Jokohama,Jokohamo,Jokokhama,YOK,Yokohama,Yokohama-shi,Yokohamashi,heng bang,heng bang shi,heng bin shi,yoa koa ha ma,yokohama,yokohama si,yokohamashi,ywkwhama,ywqwhmh,Јокохама,Иокогама,יוקוהמה,يوكوهاما,โยะโกะฮะมะ,იოკოჰამა,よこはま,よこはまし,ヨコハマ,ヨコハマシ,横浜,横浜市,横滨市,요코하마 시', 35.4333300, 139.6500000, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90002, 'Yokkaichi', 'Yokkaichi', 'Gorad Jokaici,Jokaichi,Jokkaichi,Jokkaiti,Yokkaichi,Yokkaiti,Yokkaiti-chhi,Yokkaiti-chhī,Yokkaitsi,si ri,si ri shi shi,yk ki chi,yoskaichi si,ywkaychy  myh,ywkaytshy,ywkychy  myy,Ёккаичи,Јокаичи,Горад Ёкаіці,Йокаичи,Йоккаити,Йоккаичи,Йоккаїті,يوكايتشي,یوکایچی، میه,یوکای‌ایچی، میه,یوکیچی، مئی,ยกไกชิ,四日,四日市市,욧카이치 시', 34.9666700, 136.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90003, 'Youkaichi', 'Youkaichi', 'Yokaichicho,Yokkaichi,Yōkaichichō', 35.1162600, 136.1976800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90004, 'Yawata', 'Yawata', 'Jauata,Javata,Jaŭata,Yahata,Yahatanosho,Yahatanoshō,Yahatasho,Yahatashō,Yavata,Yawata-chhi,Yawata-chhī,ba fan,ba fan shi,yawata,yawata si,yawata  kywtw,Явата,ياواتا,یاواتا، کیوتو,یوتا، کیوٹو,იავატა,八幡,八幡市,야와타 시', 34.8700900, 135.7027000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90005, 'Honmachi', 'Honmachi', 'Honmachi,Jacushiro,Jacusiro,Jacuširo,Jatsushiro,Yatsushiro,Yatsusiro,Yatsuşiro,Yatusiro,Yatusiro-chhi,Yatusiro-chhī,ba dai shi,ben ding,honmachi,iatsusiro,yasseusilo si,yatswshyrw,yatswshyrw  kwmamwtw,Јацуширо,Ятсуширо,Яцусиро,Яцушіро,ياتسوشيرو,یاتسوشیرو، کوماموتو,یتسھیرو، کمموٹو,იაცუსირო,ほんまち,ホンマチ,八代市,本町,야쓰시로 시', 32.5043900, 130.5995200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90006, 'Yatsuomachi-higashikumisaka', 'Yatsuomachi-higashikumisaka', 'Yatsuo,Yatsuomachi-higashikumisaka,ba wei ding dong ge ban,八尾町東葛坂', 36.5666700, 137.1333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90007, 'Yasugichō', 'Yasugicho', 'Yasugi,Yasugicho,Yasugichō,an lai ding,安来町', 35.4214600, 133.2422400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90008, 'Yashiro', 'Yashiro', '', 34.9166700, 134.9666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90009, 'Yashio-shi', 'Yashio-shi', 'Yashio,ba chao,ba chao shi,八潮,八潮市', 35.8225500, 139.8390500, 'JP', '2013-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90010, 'Yao', 'Yao', 'Jao,Yao,Yaocho,Yaochō,ba wei,ba wei shi,Яо,八尾,八尾市', 34.6166700, 135.6000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90011, 'Yanai', 'Yanai', 'Janai,Yanai,liu jing,Янаи,柳井', 33.9666700, 132.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90012, 'Yanagawa', 'Yanagawa', 'Janagava,Yanagawa,Yanagawa-chhi,Yanagawa-chhī,liu chuan,liu chuan shi,yanagawa si,yanagawa  fwkwywka,yanaghawa,Янагава,Янаґава,ياناغاوا,یاناگاوا، فوکوئوکا,یانہگوا، فوکوکا,柳川,柳川市,야나가와 시', 33.1666700, 130.4000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90013, 'Yamato-Takada', 'Yamato-Takada', 'Takada,Takadacho,Takadachō,Yamato-Takada,da he gao tian,大和高田', 34.5166700, 135.7500000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90014, 'Yamazakichō-nakabirose', 'Yamazakicho-nakabirose', 'Yamasaki,Yamazakicho-nakabirose,Yamazakichō-nakabirose,shan qi ding zhong guang lai,山崎町中広瀬', 35.0000000, 134.5500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90015, 'Yamaguchi', 'Yamaguchi', 'Jamaguci,Jamaguti,Jamaguči,Yamaguchi,Yamaguchi-shi,Yamaguchishi,Yamaguti,shan kou,shan kou shi,yamaghwtshy,yamaguchi,yamaguchi si,yamaguchishi,Ямагути,ياماغوتشي,やまぐち,やまぐちし,ヤマグチ,ヤマグチシ,山口,山口市,야마구치 시', 34.1833300, 131.4666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90016, 'Yamaga', 'Yamaga', 'Jamaga,Yamaga,Yamaga-chhi,Yamaga-chhī,shan lu,shan lu shi,yamaga,yamaga si,yamaga  kwmamwtw,yamagha,Ямага,Ямаґа,ياماغا,یاماگا، کوماموتو,یمگا، کمموٹو,やまが,ヤマガ,山鹿,山鹿市,야마가 시', 33.0166700, 130.6891100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90017, 'Yaizu', 'Yaizu', 'Jaidzu,Jaizu,Jajdzu,Yaidu,Yaisu,Yaizu,Yaizu Mati,Yaizu-chhi,Yaizu-chhī,shao jin,shao jin shi,yaijeu si,yayzw,yayzw  shyzwywka,yyzw  shzwka,Јаизу,Яидзу,Яизу,Яйдзу,يايزو,یایزو، شیزوئوکا,ییزو، شزوکا,焼津,焼津市,燒津市,야이즈 시', 34.8687700, 138.3195200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90018, 'Yaita', 'Yaita', 'Jaita,Yaita,Yaita-chhi,Yaita-chhī,shi ban,shi ban shi,yaita si,yayta,yayta  twchygy,Яита,Яїта,يايتا,یایتا، توچیگی,ییٹا، توچگی,矢板,矢板市,야이타 시', 36.8000000, 139.9333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90019, 'Yabu', 'Yabu', 'Yabu,yang fu,yang fu shi,養父,養父市', 35.4030400, 134.7711800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90020, 'Wakimachi', 'Wakimachi', 'Waki,Wakimachi,xie ding,脇町', 34.0666700, 134.1500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90021, 'Wajima', 'Wajima', 'NTQ,Vadzima,Wajima,Wajima-shi,Wajimazakimachi,Wazima,Wazima-chhi,Wazima-chhī,lun dao,lun dao qi ding,lun dao shi,wajima si,wajyma,wajyma  ayshykawa,Вадзима,Вадзіма,Ваҷима,واجيما,واجیما، ایشیکاوا,輪島,輪島崎町,輪島市,와지마 시', 37.4045800, 136.8991200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90022, 'Utsunomiya', 'Utsunomiya', 'Ucunomija,Utsunomiya,Utsunomiya-shi,Utsunomiyashi,usseunomiya si,utsunomiya,utsunomiyashi,yu dou gong,yu dou gong shi,Уцуномия,うつのみや,うつのみやし,ウツノミヤ,ウツノミヤシ,宇都宮,宇都宮市,우쓰노미야 시', 36.5666700, 139.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90023, 'Uto', 'Uto', 'Udo,Uto,yu tu,宇土', 32.6833300, 130.6666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90024, 'Usuki', 'Usuki', 'Usuki,Usuki-chhi,Usuki-chhī,awswky,awswky  awyyta,jiu chu,jiu chu shi,useuki si,Усуки,Усукі,أوسوكي,اوسوکی، اوئیتا,臼杵,臼杵市,우스키 시', 33.1234200, 131.8040100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90025, 'Ushibukamachi', 'Ushibukamachi', 'Ushibuka,Ushibukamachi,Usibuka,niu shen ding,ushibukamachi,うしぶかまち,ウシブカマチ,牛深町', 32.2014200, 130.0217100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90026, 'Ureshinomachi-shimojuku', 'Ureshinomachi-shimojuku', 'Ureshino,Ureshinomachi-shimojuku,xi ye ding xia su,嬉野町下宿', 33.1135800, 130.0029200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90027, 'Urayasu', 'Urayasu', 'Urajasu,Urayasu,Urayasu-chhi,Urayasu-chhī,awrayasw  chyba,pu an shi,ulayaseu si,xu ra yasu,ywrayasw  chyba,ywraysw,Ураясу,Урајасу,اورایاسو، چیبا,يورايسو,یورایاسو، چیبا,อุระยะซุ,浦安市,우라야스 시', 35.6705600, 139.8886100, 'JP', '2012-01-19', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90028, 'Uozu', 'Uozu', 'Oozu,Owatsu,Owoju,Uodzu,Uosu,Uozo,Uozu,Uozu-chhi,Uozu-chhī,awywzw  twyama,uojeu si,yu jin,yu jin shi,ywzw,Уодзу,Уозу,Ուոձու,اوئوزو، تویاما,يوزو,魚津,魚津市,우오즈 시', 36.8000000, 137.4000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90029, 'Umi', 'Umi', 'Umi,yu mei,宇美', 33.5682600, 130.5100900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90030, 'Ujiie', 'Ujiie', '', 36.6833300, 139.9666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90031, 'Uji', 'Uji', 'Udyi,Udzhi,Udzi,Udzis,Udži,Udžis,Ugi,Uji,Uji-cho,Uji-chō,Uzi-chhi,Uzi-chhī,Uĝi,awjy  kywtw,uji,uji si,xu ci,yu zhi,yu zhi shi,ywjy,Уджі,Удзи,Уџи,Уҷи,Үжи,اوجی، کیوتو,يوجي,উজি,อุจิ,宇治,宇治市,우지 시', 34.8904400, 135.8032500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90032, 'Uenohara', 'Uenohara', 'Owenohara,Uehnokhara,Uenohara,Uenohara-chhi,Uenohara-chhī,Uenokhara,awynwhara  yamanashy,shang ye yuan,shang ye yuan shi,uenohala si,xu xea noa ha ra,ywynwhwra,Уенохара,Уеноҳара,Уэнохара,Ուենոհարա,اوئنوهارا، یاماناشی,يوينوهورا,อุเอะโนะฮะระ,上野原,上野原市,우에노하라 시', 35.6166700, 139.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90033, 'Ueno-ebisumachi', 'Ueno-ebisumachi', 'Ueno,Ueno-ebisumachi,shang ye hui mei xu ding,上野恵美須町', 34.7585600, 136.1310800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90034, 'Uekimachi-mōno', 'Uekimachi-mono', 'Ueki,Uekimachi-mono,Uekimachi-mōno,uekimachimouno,zhi mu ding wu wei,うえきまちもうの,ウエキマチモウノ,植木町舞尾', 32.8996400, 130.6889800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90035, 'Ueda', 'Ueda', 'Oweda,Ueda,Ueda  Nagano,Ueda-chhi,Ueda-chhī,Uehda,awyda  naganw,shang tian,shang tian shi,ueda si,ywyda,Уеда,Уэда,Ուեդա,اوئدا، ناگانو,يويدا,上田,上田市,우에다 시', 36.4026500, 138.2816100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90036, 'Ube', 'Ube', 'UBJ,Ube,Ube-chhi,Ube-chhī,Ubi,Ubė,awbh  yamagwchy,ube si,xu bea,yu bu,yu bu shi,ywby,Убе,ابے، یاماگوچی,اوبه، یاماگوچی,يوبي,อุเบะ,宇部,宇部市,우베 시', 33.9430600, 131.2511100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90037, 'Tsuyama', 'Tsuyama', 'Cujama,Tsujama,Tsuyama,Tuyama,Tuyama-chhi,Tuyama-chhī,jin shan,jin shan shi,sseuyama si,tswyama,tswyama  awkayama,Тсуяма,Цуяма,Цујама,تسوياما,تسویاما، اوکایاما,津山,津山市,쓰야마 시', 35.0521500, 133.9988500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90038, 'Tsushima', 'Tsushima', 'Cusima,Tsushima,Tsushima cho,Tsushima chō,jin dao,Цусима,津島', 35.1666700, 136.7166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90039, 'Tsurusaki', 'Tsurusaki', 'Tsurusaki,he qi,鶴崎', 33.2452800, 131.6916500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90040, 'Tsuruoka', 'Tsuruoka', 'Curuoka,Tsuruoka,Turuoka,Turuoka-chhi,Turuoka-chhī,he gang,he gang shi,sseuluoka si,tswrwawka  yamagata,tswrwka,Тсуруока,Цуруока,تسورواوکا، یاماگاتا,تسوروكا,鶴岡,鶴岡市,쓰루오카 시', 38.7216700, 139.8216700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90041, 'Tsurugi-asahimachi', 'Tsurugi-asahimachi', 'Tsurugi,Tsurugi-asahimachi,he lai chao ri ding,鶴来朝日町', 36.4500000, 136.6333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90042, 'Tsuruga', 'Tsuruga', 'Curuga,Tsuruga,Turuga,Turuga-chhi,Turuga-chhī,dui he,dui he shi,dun he shi,sseuluga si,tswrwga  fwkwyy,tswrwgha,Тсуруга,Цуруга,Цуруґа,تسوروغا,تسوروگا، فوکوئی,敦賀,敦賀市,쓰루가 시', 35.6454700, 136.0558000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90043, 'Tsuma', 'Tsuma', 'Tsuma,Tuma', 32.1000000, 131.4000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90044, 'Tsukumiura', 'Tsukumiura', 'Tsukumi,Tsukumiura,Tukumi,jin jiu jian pu,津久見浦', 33.0753900, 131.8690700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90045, 'Tsukawaki', 'Tsukawaki', 'Kusu,Tsukawaki,zhong xie,塚脇', 33.2766800, 131.1562800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90046, 'Tsuiki', 'Tsuiki', 'Chikujo,Chikujō,Tsuiki', 33.6730700, 131.0377600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90047, 'Tsubata', 'Tsubata', 'Tsubata,jin fan,津幡', 36.6701200, 136.7403000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90048, 'Tsubame', 'Tsubame', 'Cubame,Cubameh,Tsubame,Tsubame-chhi,Tsubame-chhī,Tsubamemachi,sseubame si,tswbamh  nygata,tswbamy,yan,yan shi,Тсубаме,Цубаме,Цубамэ,تسوبامه، نیگاتا,تسوبامي,燕,燕市,쓰바메 시', 37.6645000, 138.9251800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90049, 'Tsu', 'Tsu', 'Cu,Tsu,Tsu-shi,Tsushi,Tu,jin,jin shi,sseu si,tsu,tsushi,Цу,つ,つし,ツ,ツシ,津,津市,쓰 시', 34.7333300, 136.5166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90050, 'Toyota', 'Toyota', 'Koromo,Tojoota khot,Tojota,Toyoda,Toyota,Toyota i Aichi,Toyota-chhi,Toyota-chhī,doyota si,feng tian shi,li tian,li tian shi,thoa yoa ta,twywta,twywta  aychy,Тойота,Тоёота хот,Тоёта,Тојота,تويوتا,تویوتا، آیچی,ٹویوٹا، ایچی,ٹویوٹہ,โทะโยะตะ,丰田市,豊田,豊田市,도요타 시', 35.0833300, 137.1500000, 'JP', '2012-02-18', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90051, 'Toyoshina', 'Toyoshina', '', 36.2999100, 137.9010800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90052, 'Toyooka', 'Toyooka', 'TJH,Tojoka,Tojooka,Toyo''oka,Toyooka,Toyooka-chhi,Toyooka-chhī,doyooka si,feng gang shi,li gang,li gang shi,twywawka  hywgw,twywka,Тойока,Тоёока,טויואוקה,تويوكا,تویواوکا، هیوگو,豊岡,豊岡市,豐岡市,도요오카 시', 35.5400800, 134.8203800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90053, 'Toyonaka', 'Toyonaka', 'li zhong,豊中', 34.7824400, 135.4693200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90054, 'Toyokawa', 'Toyokawa', 'Tojokava,Toyokawa,Toyokawa-chhi,Toyokawa-chhī,doyokawa si,feng chuan shi,li chuan,li chuan shi,thoa yoa kawa,twywkawa  aychy,twywkawa  aytshy,Тойокава,Тоёкава,Тојокава,تويوكاوا، آيتشي,تویوکاوا، آیچی,ٹویوکاوہ,โทะโยะกะวะ,豊川,豊川市,豐川市,도요카와 시', 34.8166700, 137.4000000, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90055, 'Toyohashi', 'Toyohashi', 'Toekhasi,Tojohashi,Tojokhashi,Tojokhasi,Toyohashi,Toyohashi-shi,Toyohasi,Toyohasi-chhi,Toyohasi-chhī,Toyohasyi,Toyohaşi,doyohasi si,feng qiao shi,li qiao,li qiao shi,thoa yoa ha chi,twywhashy  aychy,twywhashy  aytshy,Тоехаси,Тойохасі,Тойохаши,Тоёхаси,Тоёҳаши,Тојохаши,تويوهاشي، آيتشي,تویوهاشی، آیچی,โทะโยะฮะชิ,豊橋,豊橋市,豐橋市,도요하시 시', 34.7666700, 137.3833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90056, 'Toyohama', 'Toyohama', '', 34.7093300, 136.9342500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90057, 'Toyama', 'Toyama', 'TOY,Tojama,Toyama,Toyama-shi,Toyamashi,fu shan,fu shan shi,toyama,toyamashi,Тояма,とやま,とやまし,トヤマ,トヤマシ,富山,富山市', 36.7000000, 137.2166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90058, 'Tottori', 'Tottori', 'Lungsod ng Tottori,TTJ,Totori,Totoris,Tottori,Tottori-chhi,Tottori-chhī,Tottori-shi,Tottori-su,Tottori-sṳ,Toturi,dostoli si,niao qu,niao qu shi,tht toa ri,twtwry,twtwry  twtwry,Тотори,Тоттори,Тотторі,توتوري,توتوری,توتوری، توتوری,ทตโตะริ,鳥取,鳥取市,돗토리 시', 35.5000000, 134.2333300, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89750, 'Saint Helier', 'Saint Helier', 'JER,Saint Helier,Saint-Helier,Saint-Hélier,Sent-Khel''er,St Helier,St. Helier,Сент-Хельер', 49.1880400, -2.1049100, 'JE', '2015-03-14', 113);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89751, 'Le Hocq', 'Le Hocq', '', 49.1682300, -2.0617800, 'JE', '2015-11-26', 113);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89842, 'Zaḩar', 'Zahar', 'Zahar,Zaḩar,zhr,زحر', 32.5655800, 35.7865600, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89843, 'Yarqā', 'Yarqa', 'Yarqa,Yarqā,Yerqa,yrqa,يرقا', 31.9758300, 35.6963800, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89844, 'Waqqāş', 'Waqqas', 'Wakkas,Waqqas,Waqqāş,wqas,وقاص', 32.5417900, 35.6049600, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89845, 'Petra', 'Petra', 'Alji,Aljī,El-Gi,Elchi,Elji,Petra,Wadi Musa,Wādī Mūsá,btra,wady mwsy,Петра,بترا,وادي موسى', 30.3209600, 35.4789500, 'JO', '2017-01-04', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89846, 'Wādī as Sīr', 'Wadi as Sir', 'Wadi Al Seer,Wadi Sir,Wadi as Sayr,Wadi as Sir,Wadi es Sir,Wadi es Sīr,Wādī as Sayr,Wādī as Sīr,wady alsyr,وادي السير', 31.9545000, 35.8183100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89847, 'Umm Qays', 'Umm Qays', 'Gadara,Gader,Gādēr,Mukes,Mukus,Um Qeis,Umm Kajs,Umm Qays,Umm Qeis,am qys,Умм Кайс,أم قيس', 32.6532000, 35.6841400, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89848, 'Umm as Summāq', 'Umm as Summaq', 'Um el Semmaq,Um es Summaq,Um es Summāq,Umm as Summaq,Umm as Summaq ath Thani,Umm as Summāq,Umm as Summāq ath Thānī', 31.8854200, 35.8543000, 'JO', '2016-03-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89849, 'Umm ar Raşāş', 'Umm ar Rasas', 'Um el Resas,Um er Risas,Um er Rişāş,Umm ar Rasas,Umm ar Raşāş,Umm er Risas,Umm er Riṣāṣ,am alrsas,أم الرصاص', 31.5122500, 35.9183700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89850, 'Umm al Qiţţayn', 'Umm al Qittayn', 'Um el Quttein,Umm al Qittayn,Umm al Qiţţayn,Umm el Quttein,am alqtyn,أم القطين,أم القطّين', 32.3144900, 36.6282600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89851, 'Umm al Jimāl', 'Umm al Jimal', 'Khirbat Um el Jimal,Khirbat Um el Jimāl,Khirbat Umm al Jimal,Khirbat Umm al Jimāl,Umm al Jimal,Umm al Jimāl,Umm el Djimal,Umm el Jimal,Umm el Jimâl,am aljmal,أم الجمال', 32.3286300, 36.3678800, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89852, 'Umm al Basātīn', 'Umm al Basatin', 'Um el Hanafish,Umm al Basatin,Umm al Basātīn,Umm al Hanafish,Umm al Ḩanāfīsh,Umm el Hanafish,am albsatyn,أم البساتين', 31.8247500, 35.8759000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89853, 'Adhruḩ', 'Adhruh', 'Adhruh,Adhruḩ,Adruh,Aḑruḩ,Udhruh,Udhruḩ,adhrh,أذرح', 30.3307000, 35.5965900, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89854, 'Tibnah', 'Tibnah', 'Tibna,Tibnah,Tibne,Tibni,tbnt,تبنة', 32.4754800, 35.7303000, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89855, 'Sūf', 'Suf', 'Suf,Sūf', 32.3137200, 35.8371300, 'JO', '2015-12-06', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89856, 'Ash Shūnah al Janūbīyah', 'Ash Shunah al Janubiyah', 'Ash Shunah,Ash Shunah al Janubiyah,Ash Shūnah,Ash Shūnah al Janūbīyah,El Shun,El Shune,Shuna,Shuna Janubiya,Shuna al Janubiya,Shunat Nimrin,Shunet Nimrin,Shûna,Shūnat Nimrīn,Shūnet Nimrīn,alshwnt aljnwbyt,الشونة الجنوبية', 31.8915000, 35.6178000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89857, 'Sammā ar Rawsān', 'Samma ar Rawsan', 'As Samma,Aş Şammā,Es Samma,Sama,Sama ar Rusan,Samma,Samma ar Rawsan,Sammā,Sammā ar Rawsān,Samā,Samā ar Rūsān,sma alrwsan,سما الروسان', 32.6366900, 35.8270900, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89858, 'Şammā', 'Samma', 'Samma,Sammeh,sma,Şammā,صما', 32.5719200, 35.6879800, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89859, 'Samā as Sirḩān', 'Sama as Sirhan', 'Qaryat Sama,Qaryat Samā,Sama,Sama as Sirhan,Samā,Samā as Sirḩān,sma alsrhan,سما السرحان', 32.4685900, 36.2436300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89860, 'Sāl', 'Sal', 'Sal,Sāl,sal,سال', 32.5699400, 35.9129200, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89861, 'Sakib', 'Sakib', 'Sakib,sakb,ساكب', 32.2833000, 35.8094600, 'JO', '2017-03-17', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89862, 'Şakhrah', 'Sakhrah', 'Sakhra,Sakhrah,skhrt,Şakhrah,صخرة', 32.3705500, 35.8432700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89863, 'Saḩam al Kaffārāt', 'Saham al Kaffarat', 'Saham,Saham al Kaffarat,Saḩam,Saḩam al Kaffārāt,shm alkfarat,سحم الكفارات', 32.6976300, 35.7762000, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89864, 'Saḩāb', 'Sahab', 'Sahab,Sakhab,Saḩāb,Sehab,shab,Сахаб,سحاب', 31.8703200, 36.0047900, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89865, 'Şabḩā', 'Sabha', 'Sabha,Sabhah,sbha,Şabḩah,Şabḩā,صبحا', 32.3269600, 36.5015900, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89866, 'Rujm ash Shāmī al Gharbī', 'Rujm ash Shami al Gharbi', 'Rujm ash Shami,Rujm ash Shami al Gharbi,Rujm ash Shāmī,Rujm ash Shāmī al Gharbī,Rujm el Shami,Rujm esh Shami,Rujm esh Shāmī,rjm alshamy alghrby,رجم الشامي الغربي', 31.8369300, 36.0049200, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89867, 'Rehab', 'Rehab', 'Irhab,Irḩāb,Rahab,Rahāb,Rihab,Riḩāb,arhab,ارحاب', 32.3234100, 36.0908700, 'JO', '2017-01-24', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89868, 'Raymūn', 'Raymun', 'Raymun,Raymūn,Reimun,Reimūn,Rimon', 32.2833900, 35.8253200, 'JO', '2015-12-06', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89869, 'Qumaym', 'Qumaym', 'Qumaym,Qumeim,qmym,قميم', 32.5710800, 35.7346700, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89870, 'Qafqafā', 'Qafqafa', 'Qafqafa,Qafqafā,qfqfa,قفقفا', 32.3488100, 35.9382400, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89871, 'Nā‘ūr', 'Na`ur', 'Na`ur,Nā‘ūr,ناعور', 31.8743600, 35.8246700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89872, 'Mulayḩ', 'Mulayh', 'Meleih,Mulayh,Mulayḩ,Muleih,Muleiḥ,mlyh,مليح', 31.5851700, 35.8071600, 'JO', '2016-09-09', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89873, 'Al Mughayyir', 'Al Mughayyir', 'Al Mughayyir,Mughaiyir,Mughayyir,almghyr,mghyr,المغير,مغيّر', 31.4063400, 35.7708300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89874, 'Malkā', 'Malka', 'Malka,Malkah,Malkā,Malqa,Malqá,Melka,mlka,mlkt,ملكا,ملكة', 32.6749600, 35.7492300, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89875, 'Mā‘īn', 'Ma`in', 'Ma`ain,Ma`in,Ma`on,Mā‘ain,Mā‘on,Mā‘īn,ماعين', 31.6800200, 35.7320000, 'JO', '2016-09-09', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89876, 'Ma’dabā', 'Ma''daba', 'Ma''daba,Madaba,Madeba,Ma’dabā,Medeba,Meideva,Meidevā,Mādabā,Mādeba,madba,mhafzt madba,mydbʼ,Мадаба,מידבא,مأدبا,مادبا,محافظة مادبا', 31.7159900, 35.7939200, 'JO', '2016-10-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89877, 'Ma''an', 'Ma''an', 'Ahamant,MPQ,Ma''an,Ma`an,Ma‘ān,معان', 30.1962400, 35.7340500, 'JO', '2014-02-02', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89878, 'Kurayyimah', 'Kurayyimah', 'Kareime,Kereime,Kuraiyima,Kuraymah,Kurayyimah,Kureima,Kureiyima,Quraymah,krymt,كريمة', 32.2763900, 35.5993800, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89879, 'Kufrinjah', 'Kufrinjah', 'Kefrenji,Kefrenjy,Kufrinja,Kufrinjah,Kufrinje,Kufrinji,Kufrinjī,kfrnjt,كفرنجة', 32.2975500, 35.7021200, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89880, 'Al Fayşalīyah', 'Al Faysaliyah', 'Al Faysaliyah,Al Fayşalīyah,Kefeir el Wekhyan,Kufayr al Wakhyan,Kufayr al Wakhyān,Kufeir el Wakhyan,Kufeir el Wakhyān,alfyslyt,الفيصلية', 31.7490900, 35.7692200, 'JO', '2016-09-09', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89881, 'Kitim', 'Kitim', 'Kitim,ktm,كتم', 32.4396200, 35.8959700, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89882, 'Bīrayn', 'Birayn', 'Bi''rayn,Birayn,Birein,Bi’rayn,Bīrayn,Bīrein,Khirbat Bi''rayn,Khirbat Birein,Khirbat Bi’rayn,Khirbat Bīrein,byryn,بيرين', 32.0994300, 35.9578300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89883, 'Al Murayghah', 'Al Murayghah', 'Al Murayghah,Khirbat al Murayghah,Khirbat el Mureigha,Khirbet el Mureigha,almryght,المريغة', 30.0952600, 35.5231400, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89884, 'Kharjā', 'Kharja', 'Kharja,Kharjā,Kherja,khrja,خرجا', 32.6592000, 35.8872500, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89885, 'Kafr Sawm', 'Kafr Sawm', 'Kafr Sawm,Kufr Saum,Kufr Som,Kufr as Sawm,kfr swm,كفر سوم', 32.6799500, 35.8028500, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89886, 'Kafr Asad', 'Kafr Asad', 'Kafr Asad,Kufr Asad,Kufr Esad,kfr asd,kfrasd,كفر أسد,كفرأسد', 32.5934100, 35.7136800, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89887, 'Kafr Abīl', 'Kafr Abil', 'Kafr Abil,Kafr Abīl,Kefr Abil,Kufr Abil,Kufr Abîl,kfr abyl,كفر آبيل,كفر أبيل', 32.4173600, 35.6627600, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89888, 'Juraynah', 'Juraynah', 'Jarima,Jereine,Juraynah,Jureina,Qaryat el Jureina,jrynt,جرينة', 31.7600000, 35.7946600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89889, 'Judita', 'Judita', 'Jedeita,Judayta,Judaytā,Judeita,Judeitta,Judita,jdyta,جديتا', 32.4079200, 35.7080200, 'JO', '2013-10-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89890, 'Jāwā', 'Jawa', 'Jawa,Jāwā', 31.8524700, 35.9392800, 'JO', '2012-01-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89891, 'Jarash', 'Jarash', 'Djerash,Dzherash,Gerasa,Jarash,Jerasa,Jerash,grs,jrsh,Джераш,גרש,جرش', 32.2808200, 35.8992900, 'JO', '2015-01-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89892, '‘Izrā', '`Izra', '`Azra,`Izra,‘Azrā,‘Izrā', 31.1588900, 35.6927800, 'JO', '2012-01-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89893, '‘Irjān', '`Irjan', 'Irjan,Irjān,`Irjan,عرجان,‘Irjān', 32.3951200, 35.7327700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89894, 'Irbid', 'Irbid', 'Arbela,Arbēla,Gorad Irbid,Irbid,Irbidas,QIR,arbd,ileubideu,irubido,yi er bi de,İrbid,Ірбід,Горад Ірбід,Ирбид,Ирбид қаласы,Իրբիդ,אירביד,إربد,اربد,イルビド,伊爾比德,이르비드', 32.5555600, 35.8500000, 'JO', '2015-01-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89895, 'Ḩisbān', 'Hisban', 'Hesban,Heshbon,Hisban,Husban,hsban,حسبان,Ḩisbān', 31.7981900, 35.8098600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89896, 'Ḩawshā', 'Hawsha', 'Hausha,Hawsha,Hosha,hwsha,حوشا,Ḥaushā,Ḩawshā', 32.4514400, 36.0990300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89897, 'Ḩātim', 'Hatim', 'Hatem,Hatim,hatm,حاتم,Ḩātim', 32.6450000, 35.7781200, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89898, 'Ḩalāwah', 'Halawah', 'Halawa,Halawah,hlawt,حلاوة,Ḥalāwa,Ḩalāwah', 32.3846400, 35.6614700, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89899, 'Ḩakamā', 'Hakama', 'Hakama,Hakamah,Hakema,hkma,حكما,Ḩakamah,Ḩakamā', 32.5934500, 35.8829200, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89900, 'Fuqū‘', 'Fuqu`', 'Faqqu`,Faqqū‘,Faqu,Faqū,Fuqu`,Fuqū‘,فقوع', 31.3680500, 35.7022000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89901, 'Dhībān', 'Dhiban', 'Dhiban,Dhībān,Diban,Diboun,dhyban,ذيبان', 31.4985600, 35.7839000, 'JO', '2016-09-09', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89902, 'Dayr Yūsuf', 'Dayr Yusuf', 'Dayr Yusuf,Dayr Yūsuf,Deir Yusuf,Deir Yūsuf,dyr ywsf,دير يوسف', 32.4893400, 35.7950500, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89903, 'Dayr ‘Allā', 'Dayr `Alla', 'Dayr `Alla,Dayr ‘Allā,Deir `Alla,Deir ‘Alla,دير علا', 32.1957100, 35.6216100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89904, 'Dayr Abī Sa‘īd', 'Dayr Abi Sa`id', 'Dayr Abi Sa`id,Dayr Abu Sa`id,Dayr Abī Sa‘īd,Dayr Abū Sa‘īd,Deir Abu Sa`id,Deir Abu Sa‘īd,دير أبي سعيد', 32.4981200, 35.6852100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89905, 'Buşayrā', 'Busayra', 'Al Busayrah,Al Buşayrah,Busayra,Busayrah,Buseira,Buşayrah,Buşayrā,El Buseira,El Busera,bsyra,بصيرا', 30.7318000, 35.6098300, 'JO', '2016-02-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89906, 'Burmā', 'Burma', 'Burma,Burmā,brma,برما', 32.2193000, 35.7850700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89907, 'Bayt Yāfā', 'Bayt Yafa', 'Bayt Yafa,Bayt Yāfā,Beit Yafa,Beit Yāfā,byt yafa,بيت يافا', 32.5223700, 35.7848200, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89908, 'Bayt Īdis', 'Bayt Idis', 'Bayt Idis,Bayt Īdis,Beit Idis,Beit Īdis,byt ayds,بيت إيدس,بيت ايدس', 32.4377500, 35.6976500, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89909, 'Balīlā', 'Balila', 'Balila,Balīlā,blyla,بليلا', 32.3932500, 35.9403000, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89910, 'Bal‘amā', 'Bal`ama', 'Bal`ama,Bal`amah,Bal‘amah,Bal‘amā,Bel`ama,Bel‘ama,بلعما', 32.2364900, 36.0881100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89911, 'Zarqa', 'Zarqa', 'Az Zarqa'',Az Zarqā’,Ehz-Zarka,Kalaat el Zerka,QZA,Qal''at az Zarqa'',Qal‘at az Zarqā’,Zarka,Zarqa,Zerka,jaleuka,zaruka,zha er ka,Зарка,Эз-Зарка,الزرقاء,زرقاء,ザルカ,扎尔卡,자르카', 32.0727500, 36.0879600, 'JO', '2013-04-21', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89912, 'Muthallath al Azraq', 'Muthallath al Azraq', 'Al Azraq,Azraq,Azraq Ashikah,Azraq Shishan,Azraq ash Shishan,Azraq ash Shīshān,Azraq esh Shishan,Azraq esh Shīshān,Muthallath al Azraq,mthlth alazrq,مثلث الأزرق', 31.8326900, 36.8148700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89913, 'Al Azraq ash Shamālī', 'Al Azraq ash Shamali', 'Al Azraq ash Shamali,Al Azraq ash Shamālī,Azrak,Azraq Druze,Azraq ad Duruz,Azraq ad Durūz,Azraq ed Druz,Azraq ed Drūz,Azraq ed Duruz,Azraq ed Durūz,alazrq alshmaly,Азрак,الأزرق الشمالي', 31.8820900, 36.8301700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89914, '‘Ayy', '`Ayy', 'Aiy,Khirbat `Ai,Khirbat `Aiy,Khirbat ‘Ai,Khirbat ‘Aiy,`Ai,`Aie,`Ayy,عي,‘Ai,‘Aie,‘Ayy', 31.1337100, 35.6437500, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89915, '‘Ayn Jannah', '`Ayn Jannah', '`Ain Janna,`Ain Jenne,`Ayn Jana,`Ayn Janna,`Ayn Jannah,عين جنة,‘Ain Janna,‘Ain Jenne,‘Ayn Jannah,‘Ayn Jannā,‘Ayn Janā', 32.3346600, 35.7637000, 'JO', '2015-09-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89916, '‘Ayn al Bāshā', '`Ayn al Basha', 'Ein al Basha,`Ain el Basha,`Ayn al Basha,عين الباشا,‘Ain el Bāsha,‘Ayn al Bāshā', 32.0572600, 35.8310900, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89917, 'Ayl', 'Ayl', 'Ail,Ayl,Aïl,Iyl,ayl,Īyl,ايل', 30.2058800, 35.5362700, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89918, 'Aydūn', 'Aydun', 'Aidun,Aidūn,Aydun,Aydūn,Eidun,Eidūn,aydwn,ايدون', 32.5103100, 35.8544400, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89919, 'Aţ Ţurrah', 'At Turrah', 'At Turrah,Aţ Ţurrah,Et Turra,Eṭ Ṭurra,Turra,altrt,الطرة', 32.6368000, 35.9900400, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89920, 'Aţ Ţayyibah', 'At Tayyibah', 'At Tayyibah,At Tibah,Aţ Ţayyibah,Aţ Ţībah,Et Taiyiba,Et Taiyibe,Eṭ Ṭaiyiba,Taibe,Taiyiba,Tayyibah,altybt,Ţayyibah,الطيبة', 32.5438800, 35.7186000, 'JO', '2015-09-06', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89921, 'Aţ Ţayyibah', 'At Tayyibah', 'At Tayyibah,Aţ Ţayyibah,Khanzira,Khanzire,Khanzîra,Khanzīre,Khinzirah,Khinzīrah,altybt- khnzyrt,الطيبة- خنزيرة', 31.0567200, 35.6016800, 'JO', '2015-10-05', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89922, 'Aţ Ţayyibah', 'At Tayyibah', 'At Tayyibah,Aţ Ţayyibah,Et Taiyiba,Et Taiyibe,Taiyiba,altybt,الطيبة', 30.2512500, 35.4657000, 'JO', '2017-01-04', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89923, 'Aţ Ţafīlah', 'At Tafilah', 'At Tafila,At Tafilah,Aţ Ţafīlah,Aṭ Ṭafīla,El Tafile,Et Tafila,Et Tafīla,Tafila,Tafile,Tafileh,Tafīla,Tofel,Tophel,Tufailah,altfylt,Тафила,الطفيلة', 30.8375200, 35.6044200, 'JO', '2013-10-13', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89924, 'Aş Şubayḩī', 'As Subayhi', 'As Subayhi,Aş Şubayḩī,Es Subeihi,Sebehi,Subeihi,alsbyhy,الصبيحي', 32.1484400, 35.7053500, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89925, 'As Salţ', 'As Salt', 'Al-Salt,As Salt,As Salţ,As-Sal''t,Es Salt,Ramoth Gil`ad,Rāmoth Gil‘ād,Salt,alslt,Ас-Сальт,السلط', 32.0391700, 35.7272200, 'JO', '2015-01-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89926, 'Safi', 'Safi', 'As Safi,As Safiyah,Aş Şāfiyah,Aş Şāfī,El Safie,El Safieh,Es Safiye,Es Sāfiye,Es-Safi,Safa,Safi,Sāfī,alsafy,ghwralsafy,Сафи,الصافي,غورالصافي', 31.0360800, 35.4654400, 'JO', '2013-10-15', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89927, 'Ash Shūnah ash Shamālīyah', 'Ash Shunah ash Shamaliyah', 'Ash Shunah,Ash Shunah ash Shamaliyah,Ash Shūnah,Ash Shūnah ash Shamālīyah,Khirbat Shuna,Khirbat Shūna,Khirbat ash Shunah,Khirbat ash Shūnah,Khirbat esh Shuma,Khirbat esh Shuna,Khirbat esh Shūma,Shuna,Shuna Shamaliya,Shuna esh Shamaliya,Shūna,alshwnt alshmalyt,الشونة الشمالية', 32.6202300, 35.6145100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89928, 'Ash Shawbak', 'Ash Shawbak', 'Ash Shawbak,Esh Shobek,Shaubak,Shaubak Fort,Shawbak Fort,Shobak,Shobek,alshwbk,Шобак,الشوبك', 30.5213400, 35.5713500, 'JO', '2017-01-04', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89929, 'Ash Shajarah', 'Ash Shajarah', 'Ash Shajarah,Esh Shajara,Shajara,Shajarah,alshjrt,الشجرة', 32.6429900, 35.9420600, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89930, 'Ar Ruwayshid', 'Ar Ruwayshid', 'Ar Ruwayshid,alrwyshd,الرويشد', 32.5015200, 38.2040500, 'JO', '2015-09-06', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89931, 'Ar Ruşayfah', 'Ar Rusayfah', 'Ar Rusayfah,Ar Ruşayfah,Er Refeia,Er Ruseifa,Reseife,Ruseifa,alrsyft,الرصيفة', 32.0172700, 36.0327100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89932, 'Ar Ramthā', 'Ar Ramtha', 'Ar Ramtha,Ar Ramthā,El Remteh,Er Remtha,Ramtha,alrmtha,الرمثا', 32.5587300, 36.0081600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89933, 'Ar Rabbah', 'Ar Rabbah', 'Ar Rabbah,El Rebbe,Er Rabba,Rabba', 31.2692300, 35.7382900, 'JO', '2012-01-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89934, '‘Anjarah', '`Anjarah', '`Anjara,`Anjarah,‘Anjara,‘Anjarah', 32.3063000, 35.7565300, 'JO', '2015-09-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89935, 'Amman', 'Amman', '''Amman,AMM,Ama,Aman,Amanas,Amani,Amano,Amans,Amman,Ammana,Ammon,Ammán,Ammān,Ammāna,Amàn,Amán,Amã,Gorad Aman,Philadelphia,Rabbah,Rabbath Ammon,am''man,am''mana,aman,amana,amani,amman,an man,anman,xam man,yamman,ʻmʼn,ʿman,ʿmʾn,Αμμάν,Аман,Амман,Аммон,Горад Аман,Ամման,אמאן,עמאן,ئاممان,امان,عمان,عمان شہر,عمّان,عَمّان,عەممان,ܥܡܐܢ,अम्मान,আম্মান,ਅਮਾਨ,அம்மான்,ಅಮ್ಮಾನ್,അമ്മാൻ,อัมมาน,ཨམ་མན།,ამანი,አማን,‘Ammān,アンマン,安曼,암만', 31.9552200, 35.9450300, 'JO', '2016-01-21', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89936, 'Ḩayy al Quwaysimah', 'Hayy al Quwaysimah', 'Al Quwaysimah,El Quweisima,El Quweisme,Hayy al Quwaysimah,hy alqwysmt,حي القويسمة,Ḩayy al Quwaysimah', 31.9103700, 35.9497500, 'JO', '2016-05-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89937, 'Al Quwayrah', 'Al Quwayrah', 'El Quweira,alqwyrt,القويرة', 29.8004500, 35.3116000, 'JO', '2015-04-15', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89938, 'Al Qaţrānah', 'Al Qatranah', 'Al Qatrana,Al Qatranah,Al Qaţrāna,Al Qaţrānah,El Qatrana,El Qatrāna,Qatrani,alqtrant,القطرانة', 31.2508300, 36.0493200, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89939, 'Al Qaşr', 'Al Qasr', 'Al Qasr,Al Qaşr,El Qaser,El Qaşer,Qasr,Qaşr,alqsr,القصر', 31.3140700, 35.7439300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89940, 'Ghawr al Mazra‘ah', 'Ghawr al Mazra`ah', 'Al Mazra`,Al Mazra`a,Al Mazra`ah,Al Mazra‘,Al Mazra‘a,Al Mazra‘ah,El Mazra`,El Mazra`a,El Mazra‘,El Mazra‘a,El Mezra`,El Mezra‘,El Mezre`,El Mezre‘,Ghawr al Mazra`ah,Ghawr al Mazra‘ah,Mazra`,Mazra‘,Mezra,Mezraa,غور المزرعة', 31.2658600, 35.5167400, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89941, 'Al Mazār ash Shamālī', 'Al Mazar ash Shamali', 'Al Mazar,Al Mazar ash Shamali,Al Mazār,Al Mazār ash Shamālī,El Mazar,El Mazār,Mazar,Mazâr,almzar alshmaly,المزار الشمالي', 32.4722800, 35.7987000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89942, 'Al Mazār al Janūbī', 'Al Mazar al Janubi', 'Al Mazar,Al Mazar al Janubi,Al Mazār,Al Mazār al Janūbī,El Mazar,El Mazār,Mazar,Mazâr,almzar aljnwby,المزار الجنوبي', 31.0672200, 35.6948600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89943, 'Al Maşţabah', 'Al Mastabah', 'Al Mastabah,Al Maşţabah,El Mastaba,Mastaba,almstbt,المصطبة', 32.1843400, 35.8558800, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89944, 'Manshīyat Banī Ḩasan', 'Manshiyat Bani Hasan', 'Al Manshiyah,Al Manshīyah,El Manshiya,El Manshīya,Manshiyat Bani Hasan,Manshīyat Banī Ḩasan,mnshyt bny hsn,منشية بني حسن', 32.3706600, 36.0793300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89945, 'Mafraq', 'Mafraq', 'Al Mafraq,Al-Mafrak,Ehl''-Mafrak,El-Fedein,Kalat el Mafrak,Mafrak,Mafrakas,Mafraq,OMF,Qal`at al Mafraq,Qal`at el Mafraq,Qal‘at al Mafraq,Qal‘at el Mafraq,almfrq,ma fu la ke,mafuraku,mapeulakeu,mfrq,mprq,shhr almfrq,Эль-Мафрак,מפרק,المفرق,شهر المفرق,مفرق,マフラク,馬弗拉克,마프라크', 32.3428900, 36.2080400, 'JO', '2014-05-28', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89946, '‘Allān', '`Allan', '`Allan,علان,‘Allān', 32.1181500, 35.7435100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89947, 'Al Kittah', 'Al Kittah', 'Al Kitta,Al Kittah,Al Kittā,El Kitta,El-Kitte,Kitta', 32.2768500, 35.8411400, 'JO', '2015-12-06', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89948, 'Al Karāmah', 'Al Karamah', 'Al Karamah,Al Karāmah,El Karama,El Karamah,El Karameh,El Karāma,Karama Camp,Karameh Camp,Keramah,Kersam,alkramt,الكرامة', 31.9543900, 35.5803300, 'JO', '2016-10-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89949, 'Qīr Moāv', 'Qir Moav', 'Al Karak,Ehl''-Karak,El Kerak,Karak,Kerak,Kir Moab,Эль-Карак', 31.1824800, 35.6999900, 'JO', '2010-06-24', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89950, 'Al Juwayyidah', 'Al Juwayyidah', 'Al Juwaydah,Al Juwayyidah,El Joweide,El Juweiyida,Juweiyida,aljwydt,الجويدة', 31.8873200, 35.9321200, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89951, 'Al Jubayhah', 'Al Jubayhah', 'Al Jubayhah,El Jebeihe,El Jubeiha,Jubeiha,aljbyht,الجبيهة', 32.0107100, 35.8980200, 'JO', '2016-03-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89952, 'Al Jīzah', 'Al Jizah', 'Al Jizah,Al Jīzah,Jiza,Jizah,Jize,Jîza,Jīzah,Jīze,Ziza,aljyzt,jyzt,الجيزة,جيزة', 31.6989300, 35.9553000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89953, 'Al Jafr', 'Al Jafr', 'Al Jafr,El Jafr,aljfr,الجفر', 30.3184000, 36.1777500, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89954, 'Al Ḩusaynīyah', 'Al Husayniyah', 'Al Husayniyah,Al Ḩusaynīyah,El Huseiniya,Rujm as Sakhri,Rujm aş Şakhrī,Rujm el-Sekheri,Rujm es Sakhri,Rujm es Ṣakhrī,alhsynyt,الحسينية', 31.0260600, 35.7229400, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89955, 'Al Ḩişn', 'Al Hisn', 'Al Hisn,Al Ḩişn,El Husn,Husn,alhsn,الحصن', 32.4826800, 35.8846600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89956, 'Al Hāshimīyah', 'Al Hashimiyah', 'Al Hashimiyah,Al Hāshimīyah,El Hashimiya,El Hāshimiya,alhashmyt,الهاشمية', 32.1290100, 36.1213000, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89957, 'Al Ḩasā', 'Al Hasa', 'Al Hasa,Al Ḩasā,alhsa,الحسا', 30.8213100, 35.9749900, 'JO', '2016-02-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89958, 'Al Ḩamrā’', 'Al Hamra''', 'Al Hamra'',Al Ḩamrā’,El Hamra,El Ḥamra,الحمراء', 32.4401700, 36.1526500, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89959, 'Al Fuḩayş', 'Al Fuhays', 'Al Fuhays,Al Fuḩayş,El Fuheis,Feheis,Fuheis,Fuḥeiṣ,alfhys,الفحيص', 32.0046800, 35.7808800, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89960, 'Ḩayy al Bunayyāt', 'Hayy al Bunayyat', 'Al Bunayyat,Al Bunayyat ash Shamaliyah,Al Bunayyāt,Al Bunayyāt ash Shamālīyah,Buneiyat,Buneiyāt,El Buneiyat North,El Buneiyat Shamaliah,Hayy al Bunayyat,hy albnyat,حي البنيات,Ḩayy al Bunayyāt', 31.8960300, 35.8846500, 'JO', '2016-03-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89961, 'Al ‘Arīḑ', 'Al `Arid', 'Al `Arid,Al ‘Arīḑ,El `Arid,El ‘Arīd,العريض', 31.5583900, 35.6573600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89962, 'Aqaba', 'Aqaba', 'AQJ,Akaba,Akabe,Al-''Aqabah,Al-‘Aqabah,Aqaba,Qal`at el `Aqaba,`Aqaba,akaba,ya ke ba,Акаба,עקבה,العقبة,عقبه,アカバ,亞喀巴', 29.5266700, 35.0077800, 'JO', '2009-11-24', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89963, '‘Ajlūn', '''Ajlun', 'Adjlun,Adzhlun,Ajloun,`Ajlun,Аджлун,عجلون,‘Ajlūn', 32.3332600, 35.7527900, 'JO', '2015-03-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89964, 'Adir', 'Adir', 'Ader,Adir', 31.2021700, 35.7615500, 'JO', '2012-01-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89965, 'Al Khālidīyah', 'Al Khalidiyah', 'Abu Ghara,Abu Gharah,Abū Ghāra,Abū Ghārah,Al Khalidiyah,Al Khālidīyah,alkhaldyt,الخالدية', 32.1790000, 36.3032600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89966, 'Ar Rīshah', 'Ar Rishah', 'Ar Rishah,Ar Rīshah,alrysht,الريشة', 30.2243500, 35.2167100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89967, 'Al Muwaqqar', 'Al Muwaqqar', 'Al Muwaqqar,almwqr,الموقر', 31.8166500, 36.1103600, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89968, 'Karak City', 'Karak City', 'Al-Karak,Karak,Kerak,Карак', 31.1636800, 35.7620400, 'JO', '2012-01-14', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89969, 'Al Ḩusaynīyah', 'Al Husayniyah', 'Al Husayniyah,Al Ḩusaynīyah,alhsynyt,الحسينية', 30.5954500, 35.7970100, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89970, 'Ad Dīsah', 'Ad Disah', 'Ad Disah,Ad Dīsah,aldyst,الديسة', 29.6528400, 35.5112300, 'JO', '2015-11-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89971, 'Russeifa', 'Russeifa', 'Rusaifa,Russayfah,ar-Russayfah', 32.0177800, 36.0463900, 'JO', '2011-05-25', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89972, 'Muthallath Şabḩā', 'Muthallath Sabha', 'Muthallath Sabha,Muthallath Şabḩā,mthlth sbha,مثلث صبحا', 32.2601100, 36.4678000, 'JO', '2015-11-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89973, 'Al Khālidīyah', 'Al Khalidiyah', 'Al Khalidiyah,Al Khālidīyah,alkhaldyt,الخالدية', 32.1787100, 36.3031300, 'JO', '2015-09-08', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89974, 'Tala Bay', 'Tala Bay', '', 29.4084200, 34.9791800, 'JO', '2015-09-18', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89975, 'Muthallath Jāmi‘at Āl al Bayt', 'Muthallath Jami`at Al al Bayt', 'Muthallath Jami`at Al al Bayt,Muthallath Jāmi‘at Āl al Bayt,Muthallath al Jami`ah,Muthallath al Jāmi‘ah,مثلث الجامعة,مثلث جامعة آل البيت', 32.3459200, 36.2335200, 'JO', '2015-11-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89976, 'Az̧ Z̧ulayl', 'Az Zulayl', 'Ad Dalil,Ad Dulayl,Az Zalil,Az Zulayl,Az̧ Z̧alīl,Az̧ Z̧ulayl,Aḑ Ḑalīl,Aḑ Ḑulayl,aldlyl,alzlyl,الضليل,الظليل', 32.1208000, 36.2800800, 'JO', '2015-11-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89977, 'Al ‘Abdallī', 'Al `Abdalli', 'Al `Abdalli,Al ‘Abdallī,العبدلي', 31.9650100, 35.9082100, 'JO', '2015-11-10', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89978, 'Dayr al Kahf', 'Dayr al Kahf', 'Dayr al Kahf,Deir el Kahf,Khirbat Dayr al Kahf,Khirbat Deir el Kahf,dyr alkhf,دير الكهف', 32.2753500, 36.8394900, 'JO', '2015-12-07', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(89979, 'Rukban', 'Rukban', '', 33.3140500, 38.7034200, 'JO', '2017-01-28', 114);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90059, 'Tosu', 'Tosu', 'Tosu,Tosu-chhi,Tosu-chhī,doseu si,niao qi,niao qi shi,twsw,twsw  saga,Тосу,توسو,توسو، ساگا,鳥栖,鳥栖市,도스 시', 33.3666700, 130.5166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90060, 'Tonoshō', 'Tonosho', 'Tonosho,Tonoshō,Tonosyo,Tonosyō,tu zhuang,土庄', 34.4804700, 134.1701700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90061, 'Tondabayashichō', 'Tondabayashicho', 'Tondabayashi,Tondabayashicho,Tondabayashichō,fu tian lin,fu tian lin ding,fu tian lin shi,富田林,富田林市,富田林町', 34.5006500, 135.6021100, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90062, 'Tomioka', 'Tomioka', 'Tomioka,Tomioka-chhi,Tomioka-chhī,domioka si,fu gang,fu gang shi,twmywka,Томиока,Томіока,توميوكا,تومی‌اوکا، گونما,富岡,富岡市,도미오카 시', 36.2541100, 138.8981300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90063, 'Tomigusuku', 'Tomigusuku', 'Gusuku,Temigusuku,Timigusuku,Tomigusuki,Tomigusuku,li jian cheng,豊見城', 26.1858300, 127.6819200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90064, 'Tokyo', 'Tokyo', 'Edo,TYO,Tochiu,Tocio,Tokija,Tokijas,Tokio,Tokió,Tokjo,Tokyo,Toquio,Toquio - dong jing,Toquio - 東京,Tòquio,Tókýó,Tóquio,Tōkyō,dokyo,dong jing,dong jing dou,dong-gyeong,tokeiyw,tokkiyo,tokyo,twkyw,twqyw,Τόκιο,Токио,Токё,Токіо,Տոկիո,טוקיו,توكيو,توکیو,طوكيو,ܛܘܟܝܘ,ܜܘܟܝܘ,टोक्यो,டோக்கியோ,โตเกียว,ტოკიო,东京,東京,東京都,도쿄,동경', 35.6895000, 139.6917100, 'JP', '2017-07-19', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90065, 'Tokuyama', 'Tokuyama', 'Kakuyama,Tokuyama', 34.0500000, 131.8166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90066, 'Tokushima', 'Tokushima', 'TKS,Tokushima,Tokushima - de dao shi,Tokushima - 徳島市,Tokushima-shi,Tokushimashi,Tokusima,Tokušima,de dao,de dao shi,dokusima si,tokushima,tokushimashi,Токусима,とくしま,とくしまし,トクシマ,トクシマシ,徳島,徳島市,도쿠시마 시', 34.0666700, 134.5666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90067, 'Tokorozawa', 'Tokorozawa', 'Tokorodzava,Tokorosawa,Tokorozaua,Tokorozava,Tokorozawa,Tokorozawa-chhi,Tokorozawa-chhī,dokolojawa si,suo ze,suo ze shi,thoa koa roa sa wa,twkwrwzawa,twkwrwzawa  saytama,twkwrwzawa  sayytama,Τοκοροζάβα,Токородзава,Токорозава,Токорозауа,توكوروزاوا,توکوروزاوا، سائیتاما,توکوروزاوا، سایتاما,โทะโกะโระซะวะ,所沢,所沢市,所澤市,도코로자와 시', 35.7991600, 139.4690300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90068, 'Tokoname', 'Tokoname', 'Tokoname,Tokoname-chhi,Tokoname-chhī,Tokoname-cho,Tokoname-chō,Tokonameh,chang hua,chang hua shi,dokoname si,gmagwry,thoa koa na mea,twkwnamh,twkwnamh  aychy,Токонаме,Токонамэ,توكونامه,توکونامه، آیچی,توکونامے، ایچی,گماگوری,โทะโกะนะเมะ,常滑,常滑市,도코나메 시', 34.8833300, 136.8500000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90069, 'Toki', 'Toki', 'Toka,Toki,Toki-chhi,Toki-chhī,Tokitsu-cho,Tokitsu-chō,doki si,tu qi,tu qi shi,twky,twky  gyfw,Тока,Токи,Токі,توكي,توکی، گیفو,土岐,土岐市,도키 시', 35.3500000, 137.1833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90070, 'Tōkamachi', 'Tokamachi', 'Toka,Tokamachi,Tokamati,Tōka,Tōkamachi,shi ri ding,shi ri ding shi,Токамати,十日町,十日町市', 37.1333300, 138.7666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90071, 'Togitsu', 'Togitsu', 'Togitsu,Tokitsu', 32.8333300, 129.8500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90072, 'Tochio-honchō', 'Tochio-honcho', 'Tochio,Tochio-honcho,Tochio-honchō,Tochiomachi,li wei ben ding,栃尾本町', 37.4764200, 138.9951300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90073, 'Tochigi', 'Tochigi', 'Lungsod ng Tochigi,Tochigi,Totigi,Totigi-chhi,Totigi-chhī,dochigi si,li mu,li mu shi,twchygy,twtshyghy,Тотиги,Тотіґі,Точиги,توتشيغي,توچیگی,栃木,栃木市,도치기 시', 36.3833300, 139.7333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90074, 'Toba', 'Toba', 'Toba,niao yu,niao yu shi,Тоба,鳥羽,鳥羽市', 34.4833000, 136.8418600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90075, 'Tenri', 'Tenri', 'Tehnri,Tenri,Tenri-chhi,Tenri-chhī,denli si,tian li,tian li shi,tnry  nara,tyrny,Тенри,Тенрі,Тэнри,تنری، نارا,تيرني,天理,天理市,덴리 시', 34.5833300, 135.8333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90076, 'Tennō', 'Tenno', 'Tenno,Tennō,tian wang,天王', 39.9000000, 139.9666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90077, 'Tawaramoto', 'Tawaramoto', 'Taharamoto,Tawaramoto', 34.5542000, 135.7929700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90078, 'Tatsuno', 'Tatsuno', '', 35.9842600, 137.9972100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90079, 'Tatsunochō-tominaga', 'Tatsunocho-tominaga', 'Tatsuno,Tatsunocho-tominaga,Tatsunochō-tominaga,long ye ding fu yong,龍野町富永', 34.8643700, 134.5520000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90080, 'Tateyama', 'Tateyama', 'Hojo,Hōjō,Tatejama,Tateyama,Tateyama-chhi,Tateyama-chhī,Tateyamahojo,Tateyamahozyo,Tateyamahōjō,Tateyamahōzyō,dateyama si,guan shan,guan shan shi,tath yama,tatyama  chyba,tatyyama  chyba,tha tea ya ma,Татеяма,تاته ياما,تاتیاما، چیبا,تاتییاما، چیبا,ทะเตะยะมะ,館山,館山市,다테야마 시', 34.9833300, 139.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90081, 'Tatebayashi', 'Tatebayashi', 'Tatebajashi,Tatebajasi,Tatebayashi,Tatebayasi-chhi,Tatebayasi-chhī,datebayasi si,guan lin,guan lin shi,tatybayashy,Татебаяси,Татебаясі,Татебаяши,تاته‌بایاشی، گونما,تاتيباياشي,館林,館林市,다테바야시 시', 36.2500000, 139.5333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90082, 'Tarumizu', 'Tarumizu', 'Tarumi,chui shui,垂水', 31.4833300, 130.7000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90083, 'Tarui', 'Tarui', 'Tarui,Таруи', 35.3666700, 136.5333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90084, 'Tanushimarumachi-toyoki', 'Tanushimarumachi-toyoki', 'Tanushimaru,Tanushimarumachi-toyoki,tian zhu wan ding li cheng,田主丸町豊城', 33.3500000, 130.6833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90085, 'Tanuma', 'Tanuma', 'Tanuma', 36.3666700, 139.5833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90086, 'Nishi-Tokyo-shi', 'Nishi-Tokyo-shi', 'Hoya,Hoya-shi,Nishitokyo-shi,Tanashi,Tanashi-machi,bao gu shi,tian wu shi,xi dong jing,xi dong jing shi,保谷市,田無市,西東京,西東京市', 35.7252600, 139.5383000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90087, 'Tanashichō', 'Tanashicho', 'Tanashi,Tanashicho,Tanashichō,tanashichou,tian wu ding,たなしちょう,タナシチョウ,田無町', 35.7292200, 139.5381300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90088, 'Tanabe', 'Tanabe', 'Tanabe,tian bian,田辺', 34.8224200, 135.7660400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90089, 'Tanabe', 'Tanabe', 'Tanabe,Tanabe-chhi,Tanabe-chhī,Tanabeh,danabe si,tanaba,tanabh  wakayama,tian bian,tian bian shi,Танабе,Танабэ,تانابا,تانابه، واکایاما,田辺,田辺市,田邊市,다나베 시', 33.7333300, 135.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90090, 'Tamano', 'Tamano', 'Tamano,Tamano-chhi,Tamano-chhī,damano si,tamanw,tamanw  awkayama,yu ye shi,Тамано,تامانو,تامانو، اوکایاما,玉野市,다마노 시', 34.4833300, 133.9500000, 'JP', '2012-01-19', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90091, 'Tamana', 'Tamana', 'Tamana,Tamana-chhi,Tamana-chhī,Tamano,damana si,tamana,tamana  kwmamwtw,yu ming,yu ming shi,Тамана,تامانا,تامانا، کوماموتو,たまな,タマナ,玉名,玉名市,다마나 시', 32.9471600, 130.5744600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90092, 'Tamamura', 'Tamamura', 'Tamamura', 36.3000000, 139.1166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90093, 'Taketoyo', 'Taketoyo', 'Taketoyo,Taketoyocho,Taketoyochō', 34.8500000, 136.9166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90094, 'Takeochō-takeo', 'Takeocho-takeo', 'Takeo,Takeo-chhi,Takeo-chhī,Takeocho-takeo,Takeochō-takeo,dake-o si,takyw  sagha,wu xiong ding wu xiong,wu xiong shi,Такео,تاكيو، ساغا,تاکه‌ئو، ساگا,武雄市,武雄町武雄,다케오 시', 33.1900900, 130.0208400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90095, 'Takehara', 'Takehara', 'Takehara,Takehara-chhi,Takehara-chhī,Takekara,Takekhara,dakehala si,takyhara,zhu yuan,zhu yuan shi,Такехара,Такеҳара,تاكيهارا,تاکه‌هارا، هیروشیما,竹原,竹原市,다케하라 시', 34.3383300, 132.9166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90096, 'Takefu', 'Takefu', 'Takebo,Takebu,Takefu,Takehu,wu sheng shi,武生市', 35.9039300, 136.1668700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90097, 'Takedamachi', 'Takedamachi', 'Takeda,Takedamachi,Taketa,Taketa-machi', 32.9666700, 131.4000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90098, 'Takayama', 'Takayama', 'Takajama,Takayama,Takayama-chhi,Takayama-chhī,dakayama si,fei tuono gao shan,gao shan,gao shan shi,takayama,takayama  gyfw,tha ka ya ma,Такаяма,تاكاياما,تاکایاما، گیفو,ทะกะยะมะ,たかやま,飛騨の高山,高山,高山市,다카야마 시', 36.1333300, 137.2500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90099, 'Takatsuki', 'Takatsuki', 'Takacuki,Takatsuki,Takatuki,gao gui,gao gui shi,高槻,高槻市', 34.8483300, 135.6167800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90100, 'Takasaki', 'Takasaki', 'Takasaki,Takasaki-chhi,Takasaki-chhī,dakasaki si,gao qi,gao qi shi,takasaky,takasaky  gwnma,tha ka saki,Такасаки,Такасакі,تاكاساكي,تاکاساکی، گونما,ทะกะซะกิ,ტაკასაკი,高崎,高崎市,다카사키 시', 36.3333300, 139.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90101, 'Takarazuka', 'Takarazuka', 'Takaradzuka,Takarazuka,Takarazuka-chhi,Takarazuka-chhī,bao zhong,bao zhong shi,dakalajeuka si,takarazwka,takarazwka  hywgw,tha ka ra suk a,Такарадзука,Такаразука,تاكارازوكا,تاکارازوکا، هیوگو,تاکارازوکا، ہیوگو,ทะกะระซุกะ,宝塚,宝塚市,寶塚市,다카라즈카 시', 34.7993600, 135.3569700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90102, 'Takaoka', 'Takaoka', 'Takaoka,Takaoka-chhi,Takaoka-chhī,dakaoka si,gao gang,gao gang shi,takawka,takaywka  twyama,Такаока,تاكاوكا,تاکائوکا، تویاما,高岡,高岡市,다카오카 시', 36.7500000, 137.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90103, 'Takanabe', 'Takanabe', 'Takanabe,Takanabecho,Takanabechō', 32.1333300, 131.5000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90104, 'Takamatsu', 'Takamatsu', 'Gorad Takamacu,TAK,Takamacu,Takamatsu,Takamatsu-shi,Takamatsushi,Takamatu,Takamatu-chhi,Takamatu-chhī,dakamasseu si,gao song,gao song shi,takamastu,takamatsu,takamatsushi,takamatsw,takamatsw  kagawa,tha ka masu,Горад Такамацу,Такаматсу,Такамацу,تاكاماتسو,تاکاماتسو، کاگاوا,टाकामास्तु,ทะกะมะสึ,ტაკამაცუ,たかまつ,たかまつし,タカマツ,タカマツシ,高松,高松市,다카마쓰 시', 34.3333300, 134.0500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90105, 'Takaishi', 'Takaishi', 'Takaishi,Takaishi-kita,Takashi-kita,gao shi,高石', 34.5166700, 135.4333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90106, 'Takahashi', 'Takahashi', 'Takahashi,Takahasi,Takahasi-chhi,Takahasi-chhī,Takahasyi,Takakhashi,Takakhasi,dakahasi si,gao liang,gao liang shi,takahashy,takahashy  awkayama,Такахаси,Такахаші,Такаҳаши,تاكاهاشي,تاکاهاشی، اوکایاما,高梁,高梁市,다카하시 시', 34.7833300, 133.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90107, 'Takahama', 'Takahama', 'Takahama-cho,Takahama-chō,Takakhama,gao bang,gao bang shi,Такахама,高浜,高浜市', 34.9166700, 136.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90108, 'Bungo-Takada-shi', 'Bungo-Takada-shi', 'Bungo-Takada,Bungo-Takata,BungoTakada,Takata,gao tian,li hou gao tian,li hou gao tian shi,豊後高田,豊後高田市,高田', 33.5567000, 131.4450600, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90109, 'Tajimi', 'Tajimi', 'Tadimi,Tadzimi,Tajima,Tajimi,Tajumi,Tazimi,Tazimi-chhi,Tazimi-chhī,dajimi si,duo zhi jian,duo zhi jian shi,tajymy ghyfw,tajymy  gyfw,Тадзими,Тадзімі,Таџими,Таҷими,تاجيمي غيفو,تاجیمی، گیفو,多治見,多治見市,다지미 시', 35.3166700, 137.1333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90110, 'Tahara', 'Tahara', 'Tahara,Tahara-chhi,Tahara-chhī,Takhara,Tawara,dahala si,tahara,tahara  aychy,tian yuan,tian yuan shi,Тахара,Таҳара,تاهارا,تاهارا، آیچی,تاہارا، ایچی,田原,田原市,다하라 시', 34.6666700, 137.2666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90111, 'Tagawa', 'Tagawa', 'Tagava,Tagawa,Tagawa-chhi,Tagawa-chhī,Takawa,dagawa si,tagawa  fwkwywka,taghawa,tian chuan,tian chuan shi,Тагава,Таґава,تاغاوا,تاگاوا، فوکوئوکا,田川,田川市,다가와 시', 33.6333300, 130.8000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90112, 'Tadotsu', 'Tadotsu', 'Tadotsu,Tadotsucho,Tadotsuchō', 34.2750000, 133.7500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90113, 'Suzuka', 'Suzuka', 'Kambe,Sudzuka,Susuka,Suzuka,Suzuka-chhi,Suzuka-chhī,ling lu,ling lu shi,seujeuka si,swzwka,swzwka  myh,Судзука,Сузука,سوزوكا,سوزوکا، میه,鈴鹿,鈴鹿市,스즈카 시', 34.8833300, 136.5833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90114, 'Suzaka', 'Suzaka', 'Susaka,Suzaka,xu ban,xu ban shi,須坂,須坂市', 36.6500000, 138.3166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90115, 'Suwa', 'Suwa', 'Kamisuwa,Suva,Suwa-chhi,Suwa-chhī,seuwa si,swa,swwa  naganw,zou fang,zou fang shi,Сува,Սուվա,سوا,سووا، ناگانو,諏訪,諏訪市,스와 시', 36.0379900, 138.1130800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90116, 'Susaki', 'Susaki', 'Susaki,xu qi,xu qi shi,須崎,須崎市', 33.3947100, 133.2912800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90117, 'Sumoto', 'Sumoto', 'Sumoto,Сумото', 34.3500000, 134.9000000, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90118, 'Sukumo', 'Sukumo', 'Sukumo,su mao,su mao shi,宿毛,宿毛市', 32.9333300, 132.7333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90119, 'Suita', 'Suita', 'Suika,Suita,Suita-chhi,Suita-chhī,Sujta,chui tian,chui tian shi,seu-ita si,suxi ta,swyta  awsaka,swyyta  awsaka,Суита,Суйта,سوئیتا، اوساکا,سويتا، أوساكا,ซุอิตะ,吹田,吹田市,스이타 시', 34.7614300, 135.5156700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90120, 'Suibara', 'Suibara', 'Suibara,shui yuan,水原', 37.8460800, 139.2303900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90121, 'Sugito', 'Sugito', 'Sugito,shan hu,sugito,すぎと,スギト,杉戸', 36.0310700, 139.7263600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90122, 'Sueyoshichō-ninokata', 'Sueyoshicho-ninokata', 'Sueyoshi,Sueyoshicho-ninokata,Sueyoshichō-ninokata,mo ji ding er zhi fang,末吉町二之方', 31.6500000, 131.0166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90123, 'Sōka', 'Soka', 'Sok,Soka,Sōka,cao jia,Сок,草加', 35.8364300, 139.7995700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90124, 'Sōja', 'Soja', 'Soja,Sozya,Sōja,Sōzya,zong she,総社', 34.6753400, 133.7509100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90125, 'Sobue', 'Sobue', '', 35.2500000, 136.7166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90126, 'Shōbu', 'Shobu', 'Sebu,Shobu,Shōbu,chang pu,shoubu,Себу,しょうぶ,ショウブ,菖蒲', 36.0666700, 139.6000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90127, 'Shōbara', 'Shobara', 'S''obara,Shobara,Shōbara,Sjobara,Syobara-chhi,Syôbara-chhī,shwbara,shwbara  hyrwshyma,syobala si,zhuang yuan,zhuang yuan shi,Сьобара,Сёбара,Шобара,شوبارا,شوبارا، هیروشیما,庄原,庄原市,쇼바라 시', 34.8500000, 133.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90128, 'Shizuoka', 'Shizuoka', 'FSZ,Gorad Sidzuoka,Lungsod ng Shizuoka,Shidzuoka,Shizuoka,Shizuoka-shi,Shizuokashi,Siduoka,Sidzuok,Sidzuoka,Sizuoka,Sizuoka-chhi,Sizuoka-chhī,chisu xoa ka,jing gang,jing gang shi,shizuoka,shizuokashi,shyzwka,shyzwywka,sijeuoka si,sijhu''oka,Ŝizuoka,Şizuoka,Šidzuoka,Šizuoka,Горад Сідзуока,Сидзуока,Сідзуока,Шидзуока,Шизуока,שיזואוקה,شيزوكا,شیزوئوکا,شیزوکا,शिझुओका,ชิซุโอะกะ,しずおか,しずおかし,シズオカ,シズオカシ,静岡,静岡市,靜岡市,시즈오카 시', 34.9833300, 138.3833300, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90129, 'Shirone', 'Shirone', 'Shirone,bai gen,白根', 37.7635400, 139.0219900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90130, 'Shiraoka', 'Shiraoka', 'Shiraoka,bai gang,shiraoka,しらおか,シラオカ,白岡', 36.0183900, 139.6603400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90131, 'Shirahamachō-usazakiminami', 'Shirahamacho-usazakiminami', 'Shirahama,Shirahama-ku,Shirahamacho-usazakiminami,Shirahamachō-usazakiminami,Shirakhama,bai bang ding yu zuo qi nan,Ширахама,白浜町宇佐崎南', 34.7833300, 134.7166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90132, 'Shiozawa', 'Shiozawa', 'Shiozawa,yan ze,塩沢', 37.0375700, 138.8486700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90133, 'Shiojiri', 'Shiojiri', 'Shiojiri,Siodziri,Siojiri,Sioziri,Sioziri-chhi,Sioziri-chhī,shywjyry,shywjyry  naganw,siojili si,yan kao,yan kao shi,Сиодзири,Сіодзірі,Шиоҷири,Սիոձիրի,شيوجيري,شیوجیری، ناگانو,塩尻,塩尻市,鹽尻市,시오지리 시', 36.1000000, 137.9666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90134, 'Shinshiro', 'Shinshiro', 'Shinshiro,Sinsiro,Sinsiro-chhi,Sinsiro-chhī,Syinsyiro,shynshyrw  aychy,shynshyrw  aytshy,sinsilo si,xin cheng,xin cheng shi,Синсиро,Сінсіро,Шинширо,شينشيرو، آيتشي,شینشیرو، آیچی,新城,新城市,신시로 시', 34.9000000, 137.5000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90135, 'Shin’ichi', 'Shin''ichi', 'Shin''ichi,Shin’ichi,xin shi,新市', 34.5554300, 133.2729700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90136, 'Shingū', 'Shingu', 'Shingu,Shingū,Sing,Singu,Singū,xin gong,Синг,新宮', 33.7139900, 130.4313000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90137, 'Shimo-tsuma', 'Shimo-tsuma', 'Shimo-tsuma,xia qi,下妻', 36.1833300, 139.9666700, 'JP', '2017-07-25', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90138, 'Shimonoseki', 'Shimonoseki', 'Gorad Simanaseki,Shimonoseki,Simonoseki,Simonoseki-chhi,Simonoseki-chhī,chi moa noa seaki,shymwnwsky,shymwnwsky  yamagwchy,shymwnwsyky  yamagwchy,simonoseki si,xia guan shi,Ŝimonoseki,Şimonoseki,Горад Сіманасекі,Симоносеки,Сімоносекі,Шимоносеки,Սիմոնոսեկի,شيمونوسكي,شیمونوسکی، یاماگوچی,شیمونوسیکی، یاماگوچی,ชิโมะโนะเซะกิ,下关市,下関市,시모노세키 시', 33.9500000, 130.9500000, 'JP', '2012-01-19', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90139, 'Shimodate', 'Shimodate', 'Shimodate,Simodate', 36.3000000, 139.9833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90140, 'Shimoda', 'Shimoda', 'Shimoda,Simoda,Simoda-chhi,Simoda-chhī,Syimoda,shymwda,shymwda  shyzwywka,simoda si,xia tian,xia tian shi,Ŝimoda,Şimoda,Симода,Сімода,Шимода,شيمودا,شیمودا، شیزوئوکا,下田,下田市,시모다 시', 34.6765200, 138.9445600, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90141, 'Minato', 'Minato', 'Minato,Shimminatocho,Shimminatochō,Shinkomachi,Shinkōmachi,cou,湊', 34.2152000, 135.1501000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90142, 'Nishishinminato', 'Nishishinminato', 'Nishishinminato,Shimminato,Shinminato,xi xin cou,西新湊', 36.7795700, 137.0757600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90143, 'Shimada', 'Shimada', 'Shimada,Simada,Simada-chhi,Simada-chhī,Syimada,dao tian,dao tian shi,shymada,shymada  shyzwywka,simada si,Симада,Сімада,Шимада,شيمادا,شیمادا، شیزوئوکا,島田,島田市,시마다 시', 34.8166700, 138.1833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90144, 'Shimabara', 'Shimabara', 'Shimabara,Simabara,Simabara-chhi,Simabara-chhī,dao yuan,dao yuan shi,shymabara  nagazaky,shymbara,simabala si,Симабара,Шимабара,Шімабара,شيمبارا,شیمابارا، ناگازاکی,島原,島原市,시마바라 시', 32.7833300, 130.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90145, 'Shima', 'Shima', 'Shima,zhi mo,zhi mo shi,志摩,志摩市', 34.3333300, 136.8333300, 'JP', '2017-02-28', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90146, 'Shiki', 'Shiki', 'Shiki,Siki,zhi mu,zhi mu shi,Сики,志木,志木市', 35.8333300, 139.5833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90147, 'Shiida', 'Shiida', 'Shiida,Shiita', 33.6534100, 131.0579700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90148, 'Shido', 'Shido', 'Shido,zhi du,志度', 34.3233300, 134.1733300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90149, 'Shibushi', 'Shibushi', 'Shibushi,Sibusi,Sibusi-chhi,Sibusi-chhī,shybwshy,shybwshy  kagwshyma,sibusi si,zhi bu zhi,zhi bu zhi shi,Šibuši,Сибуси,Шибуши,Шібуші,شيبوشي,شیبوشی، کاگوشیما,志布志,志布志市,시부시 시', 31.4760000, 131.1011400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90150, 'Shibukawa', 'Shibukawa', 'Shibukava,Shibukawa,Sibukava,Sibukawa,Sibukawa-chhi,Sibukawa-chhī,se chuan,se chuan shi,shybwkawa,shybwkawa  gwnma,sibukawa si,Šibukawa,Сибукава,Сібукава,Шибукава,شيبوكاوا,شیبوکاوا، گونما,渋川,渋川市,澀川市,시부카와 시', 36.4833300, 139.0000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90151, 'Shibata', 'Shibata', 'Shibata,Sibata,Sibata-chhi,Sibata-chhī,Syibata,shybata,shybata  nygata,sibata,sibata si,xin fa tian,xin fa tian shi,Сибата,Сібата,Шибата,شيباتا,شیباتا، نیگاتا,新発田,新発田市,新發田市,시바타 시', 37.9500000, 139.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90152, 'Settsu', 'Settsu', 'Settsu,Settsu-no-kuni,she jin,摂津,攝津', 34.7781900, 135.5951200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90153, 'Seto', 'Seto', 'Seto,Seto-chhi,Seto-chhī,Setu,lai hu,lai hu shi,seto si,stw  aychy,sytw,sytw  aychy,Сето,Сету,ستو، آیچی,سيتو,سیتو، ایچی,سیٹو,瀨戶市,瀬戸,瀬戸市,세토 시', 35.2333300, 137.1000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90154, 'Setakamachi-takayanagi', 'Setakamachi-takayanagi', 'Sedaka,Setaka,Setakamachi-takayanagi,lai gao ding gao liu,瀬高町高柳', 33.1485800, 130.4654800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90155, 'Satsumasendai', 'Satsumasendai', 'Sacuma-Sendaj,Sacumasendaj,Satsumasendai,Satumasendai-chhi,Satumasendai-chhī,Sendai,Sendaj,Sendajus,chuan nei,chuan nei shi,sa mo chuan nei,sa mo chuan nei shi,sasseumasendai si,satswmasnday  kagwshyma,satswmasynday,Сатсумасендаи,Сацума-Сендай,Сацумасендай,Сацумасендај,Сендай,ساتسوماسندای، کاگوشیما,ساتسوماسينداي,川内,川内市,薩摩川內市,薩摩川内,사쓰마센다이 시', 31.8166700, 130.3000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90156, 'Sekimachi', 'Sekimachi', 'Seki,Sekimachi,guan,関', 35.4833300, 136.9166700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90157, 'Satte', 'Satte', 'Satte,satte,xing shou,さって,サッテ,幸手', 36.0725400, 139.7261500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90158, 'Sasebo', 'Sasebo', 'Gorad Saseba,Sasebo,Sasebo-chhi,Sasebo-chhī,Sasebum,Saseho,sa sea boa,sasebo si,sasybw,sasybw  nagasaky,ssbw,zuo shi bao,zuo shi bao shi,Горад Сасеба,Сасебо,ססבו,ساسه‌بو، ناگازاکی,ساسيبو,ساسیبو، ناگاساکی,ซะเซะโบะ,佐世保,佐世保市,사세보 시', 33.1683400, 129.7250200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90159, 'Sasayama', 'Sasayama', 'Sasajama,Sasayama,Sasayama-chhi,Sasayama-chhī,sasayama,sasayama si,sasayama  hywgw,xiao shan,xiao shan shi,Сасаяма,ساساياما,ساسایاما، هیوگو,篠山,篠山市,사사야마 시', 35.0666700, 135.2166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90160, 'Sasaguri', 'Sasaguri', 'Sasaguri,xiao li,篠栗', 33.6156100, 130.5510500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90161, 'Sano', 'Sano', 'Sana,Sano,Sano-chhi,Sano-chhī,sano si,sanw,sanw  twchygy,zuo ye,zuo ye shi,Сана,Сано,سانو,سانو، توچیگی,佐野,佐野市,사노 시', 36.3166700, 139.5833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90162, 'Sanjō', 'Sanjo', 'Sandscho,Sandyo,Sandz''o,Sandze,Sandzjo,Sandzo,Sanjo,Sanjō,Sanzyo,Sanzyo-chhi,Sanzyô-chhī,Sanzyō,san tiao,san tiao shi,sanjo si,sanjw,sanjw  nygata,Сандзе,Сандзьо,Сандзё,Санџо,Санҷо,سانجو,سانجو، نیگاتا,三条,三条市,三條市,산조 시', 37.6166700, 138.9500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90163, 'Sandachō', 'Sandacho', 'Sanda,Sandacho,Sandachō,san tian ding,Санда,三田町', 34.8844400, 135.2269400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90164, 'Sakurai', 'Sakurai', 'Sakurai,Sakurai-chhi,Sakurai-chhī,Sakuraj,Sakuri,sakulai si,sakwray,sakwray  nara,ying jing,ying jing shi,Сакураи,Сакурай,ساكوراي,ساکورای، نارا,桜井,桜井市,櫻井市,사쿠라이 시', 34.5000000, 135.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90165, 'Saku', 'Saku', 'Saku,Saku-chhi,Saku-chhī,sa ku,saku si,sakw,sakw  naganw,zuo jiu,zuo jiu shi,Саку,Սակու,ساكو,ساکو، ناگانو,ซะกุ,佐久,佐久市,사쿠 시', 36.2166700, 138.4833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90166, 'Sakata', 'Sakata', 'SYO,Sakata,Sakata-chhi,Sakata-chhī,jiu tian,jiu tian shi,sakata,sakata si,sakata  yamagata,Саката,ساكاتا,ساکاتا، یاماگاتا,酒田,酒田市,사카타 시', 38.9166700, 139.8550000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90167, 'Sakaiminato', 'Sakaiminato', 'Sakae,Sakai,Sakaiminatas,Sakaiminato,Sakaiminato-chhi,Sakaiminato-chhī,Sakaj-Minato,jing gang shi,sakaiminato si,sakaymynatw,song jiang,Сакаиминато,Сакай-Мінато,ساكايميناتو,ساکای‌میناتو، توتوری,境港市,松江,사카이미나토 시', 35.5500000, 133.2333300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90168, 'Sakaidechō', 'Sakaidecho', 'Sakaide,Sakaide-cho,Sakaide-chō,Sakaidecho,Sakaidechō,Sakate,ban chu,ban chu ding,坂出,坂出町', 34.3227800, 133.8356000, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90169, 'Sakai-nakajima', 'Sakai-nakajima', 'Sakai,Sakai-nakajima,jing zhong dao,境中島', 36.2666700, 139.2500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90170, 'Sakai', 'Sakai', 'Sakai,Сакаи', 36.1000000, 139.8000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90171, 'Sakai', 'Sakai', 'Sacaia,Sacaium,Sakai,jie,jie shi,sakai si,Сакаи,堺,堺市,사카이 시', 34.5833300, 135.4666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90172, 'Sakado', 'Sakado', 'Sakado,Sakado-chhi,Sakado-chhī,ban hu,ban hu shi,sakado si,sakadw  saytama,sakwdw,Сакадо,ساكودو,ساکادو، سایتاما,坂戶市,坂戸,坂戸市,사카도 시', 35.9569400, 139.3888900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90173, 'Saiki', 'Saiki', 'Saeki,Saiki,Saiki-chhi,Saiki-chhī,saiki si,sayky  awyta,sayky  awyyta,syky  wyta,zuo bo,zuo bo shi,Саики,Саїкі,سايكي، أويتا,سایکی، اوئیتا,سیکی، ویتا,佐伯,佐伯市,사이키 시', 32.9500000, 131.9000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90174, 'Sagara', 'Sagara', 'Sagara,xiang liang,相良', 34.6850300, 138.2046100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90175, 'Saga', 'Saga', 'HSG,Saga,Saga Japonija,Saga-shi,Sagashi,sa nga,saga,saga si,sagashi,sagha,zuo he,zuo he shi,Сага,Сага Япония,ساغا,ساگا,ซะงะ,さが,さがし,サガ,サガシ,佐賀,佐賀市,사가 시', 33.2333300, 130.3000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90176, 'Sabae', 'Sabae', 'Sabae,qing jiang shi,zheng jiang,鯖江,鯖江市', 35.9464700, 136.1849800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90177, 'Ryūō', 'Ryuo', 'Ryuo,Ryūō', 35.6500000, 138.5000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90178, 'Ryōtsu-minato', 'Ryotsu-minato', 'Ryotsu,Ryotsu-minato,Ryotu,Ryozu,Ryōtsu,Ryōtsu-minato,Ryōzu,liang jin cou,両津湊', 38.0781700, 138.4393900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90179, 'Ōzu', 'Ozu', 'Odzu,Otsu,Ozu,da jin,oodzu,Ōzu,Одзу,おおづ,オオヅ,大津', 32.8804000, 130.8716100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90180, 'Oyama', 'Oyama', 'Ojama,Oyama,Oyama-chhi,Oyama-chhī,awyama,awyama  twchygy,oyama si,xiao shan,xiao shan shi,Ояма,Ојама,أوياما,اویاما، توچیگی,小山,小山市,오야마 시', 36.3000000, 139.8000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90181, 'Ōyama', 'Oyama', 'Oyama,da shan,Ōyama,大山', 34.6035900, 138.2171900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90182, 'Owase', 'Owase', 'Otaka,Ovaseh,Owase,Owashi,wei jiu,Овасэ,尾鷲', 34.0666700, 136.2000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90183, 'Ōtsuki', 'Otsuki', 'Ocuki,Otsuki,Otuki-chhi,awtswky,awtswky  yamanashy,da yue shi,dou liu,osseuki si,xo suki,Ócuki,Ôtuki-chhī,Ōtsuki,Отсуки,Оцуки,Оцукі,Օցուկի,أوتسوكي,اوتسوکی، یاماناشی,โอสึกิ,大月市,都留,오쓰키 시', 35.6000000, 138.9333300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90184, 'Ōtsu', 'Otsu', 'Gorad Ocu,Ocu,Otsu,Otsu-shi,Otsushi,Otu,Otu-chhi,atsw  shyga,awtsw,da jin,da jin shi,ootsu,ootsushi,osseu si,xosu,Ócu,Ôtu-chhī,Ōtsu,Ōtsu-shi,Ōtsushi,Ōtu,Горад Оцу,Отсу,Оцу,Оцү,أوتسو,اتسو، شیگا,โอสึ,おおつ,おおつし,オオツ,オオツシ,大津,大津市,오쓰 시', 35.0000000, 135.8666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90185, 'Ōtake', 'Otake', 'Otake,Otakeh,Ōtake,Отакэ', 34.2075400, 132.2206300, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90186, 'Ōta', 'Ota', 'Ota,Ota-chhi,awta,awta  gwnma,ota si,tai tian,tai tian shi,xo ta,Ôta-chhī,Ōta,Ота,أوتا,اوتا، گونما,โอตะ,太田,太田市,오타 시', 36.3000000, 139.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90187, 'Osaka', 'Osaka', 'OSA,Osaacke,Osaca,Osaca - da ban shi,Osaca - 大阪市,Osaka,Osaka-shi,Osako,Oszaka,awsaka,awzaka,da ban,da ban shi,oosakashi,osaka,osaka si,xo sa ka,ywsaka,Ósaka,Ószaka,Ōsaka,Ōsaka-shi,Осака,אוסקה,أوساكا,ئوساكا,اوزاکا,ওসাকা,โอซะกะ,ოსაკა,おおさかし,大阪,大阪市,오사카 시', 34.6937400, 135.5021800, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90188, 'Onomichi', 'Onomichi', 'Onomichi,Onomici,Onomiti,Onomiti-chhi,Onomiti-chhī,Onomiči,awnwmychy  hyrwshyma,awnwmytshy,onomichi si,wei dao,wei dao shi,Ономити,Ономичи,Ономіті,أونومیتشي,اونومیچی، هیروشیما,尾道,尾道市,오노미치 시', 34.4166700, 133.2000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90189, 'Onoda', 'Onoda', '', 34.0013900, 131.1836100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90190, 'Ono', 'Ono', 'Ono,da ye,Оно,大野', 35.9810600, 136.4872700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90191, 'Ono', 'Ono', 'Ono,Ono-chhi,Ono-chhī,Onocho,Onochō,awnw,awnw  hywgw,ono si,xiao ye,xiao ye shi,Оно,أونو,اونو، هیوگو,小野,小野市,오노 시', 34.8500000, 134.9333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90192, 'Ōno-hara', 'Ono-hara', 'Hama,Ono,Ono-hara,da ye yuan,Ōno,Ōno-hara,Оно,大野原', 34.2833300, 132.2666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90193, 'Ōmuta', 'Omuta', 'Omuda,Omuta,Omuta-chhi,awmwta,awmwta  fwkwywka,da mou tian,da mou tian shi,omuta si,Ômuta-chhī,Ōmuda,Ōmuta,Омута,أوموتا,اوموتا، فوکوئوکا,大牟田,大牟田市,오무타 시', 33.0333300, 130.4500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90194, 'Ōmura', 'Omura', 'Omura,Omura-chhi,awmwra,awmwra  nagazaky,da cun,da cun shi,omula si,xo mu ra,Ômura-chhī,Ōmura,Омура,أومورا,اومورا، ناگازاکی,โอมุระ,大村,大村市,오무라 시', 32.9213900, 129.9538900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90195, 'Ōme', 'Ome', 'Ome,Ome-chhi,Omė,Oume,awmh,awmh  twkyw,ome si,qing mei,qing mei shi,xo mea,Ôme-chhī,Ōme,Оме,Օմե,أومه,اومه، توکیو,โอเมะ,青梅,青梅市,오메 시', 35.7838900, 139.2430600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90196, 'Ōmamachō-ōmama', 'Omamacho-omama', 'Omama,Omamacho-omama,da jian 々 ding da jian 々,Ōmama,Ōmamachō-ōmama,大間々町大間々', 36.4318100, 139.2753400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90197, 'Ōmachi', 'Omachi', 'Omachi,Omati,Omati-chhi,awmachy  naganw,awmatshy,da ding shi,da ting,omachi si,Ômati-chhī,Ōmachi,Омати,Оматі,Омачи,Օմատի,أوماتشي,اوماچی، ناگانو,大町,大町市,오마치 시', 36.5000000, 137.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90198, 'Ōkuchi-shinohara', 'Okuchi-shinohara', 'Oguchi,Okuchi,Okuchi-shinohara,Okuti,da kou xiao yuan,ookuchishinohara,Ōguchi,Ōkuchi,Ōkuchi-shinohara,Ōkuti,おおくちしのはら,オオクチシノハラ,大口篠原', 32.0677900, 130.6243900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90199, 'Okegawa', 'Okegawa', 'Okegawa,Okugawamachi,tong chuan,tong chuan shi,桶川,桶川市', 36.0000000, 139.5572200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90200, 'Okazaki', 'Okazaki', 'Aichi,Okadzaki,Okasaki,Okazaki,Okazaki-chhi,Okazaki-chhī,awkazaky,awkazaky  aychy,gang qi,gang qi shi,okajaki si,xoa ka saki,Окадзаки,Окадзакі,Оказаки,أوكازاكي,اوکازاکی، آیچی,اوکازاکی، ایچی,โอะกะซะกิ,岡崎,岡崎市,오카자키 시', 34.9500000, 137.1666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90201, 'Okayama', 'Okayama', 'OKJ,Okajama,Okayama,Okayama-shi,Okayamashi,gang shan,gang shan shi,okayama,okayama si,okayamashi,Окаяма,おかやま,おかやまし,オカヤマ,オカヤマシ,岡山,岡山市,오카야마 시', 34.6500000, 133.9333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90202, 'Okaya', 'Okaya', 'Hirano,gang gu,岡谷', 36.0565900, 138.0451000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90203, 'Ōkawa', 'Okawa', 'Okava,Okawa,da chuan,da chuan shi,Ōkawa,Окава,大川,大川市', 33.2056600, 130.3752700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90204, 'Ojiya', 'Ojiya', 'Ojiya,xiao qian gu,小千谷', 37.3000000, 138.8000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90205, 'Ōita', 'Oita', 'OIT,Oita,Oita-shi,Oitashi,da fen,da fen shi,oita si,ooita,ooitashi,Óita,Ōita,Ōita-shi,Ōitashi,Оита,おおいた,おおいたし,オオイタ,オオイタシ,大分,大分市,오이타 시', 33.2333300, 131.6000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90206, 'Ōiso', 'Oiso', 'Oiso,Oiso-machi,da ji,Ōiso,Ōiso-machi,大磯', 35.3155800, 139.3162500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90207, 'Ōi', 'Oi', 'Oi,da jing,ooi,Ōi,おおい,オオイ,大井', 35.8509100, 139.5199800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90208, 'Ogōri-shimogō', 'Ogori-shimogo', 'Ogori,Ogori-shimogo,Ogōri,Ogōri-shimogō,xiao jun xia xiang,小郡下郷', 34.1000000, 131.4000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90209, 'Ogawa', 'Ogawa', 'Ogava,Ogawa,xiao chuan ding,Огава,小川町', 36.0534200, 139.2661200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90210, 'Ōgaki', 'Ogaki', 'Oaki,Ogaki,Ogaki-chhi,awgaky  gyfw,awghaky,da yuan,da yuan shi,ogaki si,Ôgaki-chhī,Ōgaki,Огаки,Оґакі,أوغاكي,اوگاکی، گیفو,大垣,大垣市,오가키 시', 35.3500000, 136.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90211, 'Odawara', 'Odawara', 'Odauara,Odavara,Odawara,Odawara-chhi,Odawara-chhī,Odaŭara,Ontagouara,awdawara  kanagawa,awdawara  kanaghawa,odawala si,xiao tian yuan,xiao tian yuan shi,xoa da wa ra,Ονταγουάρα,Одавара,أوداوارا، كاناغاوا,اوداوارا، کاناگاوا,โอะดะวะระ,小田原,小田原市,오다와라 시', 35.2555600, 139.1597200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90212, 'Ōdachō-ōda', 'Odacho-oda', 'Oda,Odacho-oda,Ota,da tian ding da tian,da tian shi,Ōda,Ōdachō-ōda,Ōta,Ода,大田市,大田町大田', 35.1902500, 132.5084600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90213, 'Ōbu', 'Obu', 'Obu,Obu-chhi,Ofu,awbw,awbw  aychy,da fu shi,obu si,xo bu,Ôbu-chhī,Ōbu,Ōfu,Обу,أوبو,اؤبو، ایچی,اوبو، آیچی,โอบุ,大府市,오부 시', 35.0000000, 136.9666700, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90214, 'Obita', 'Obita', 'Nagayo,Obita', 32.8166700, 129.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90215, 'Obama', 'Obama', 'Obama,Obama-chhi,Obama-chhī,Ohama,awbama,awbama  fwkwyy,obama si,xiao bang,xiao bang shi,xiao bin shi,xoaba ma,Обама,אובמה,أوباما,اوباما، فوکوئی,โอะบะมะ,小浜,小浜市,小濱市,오바마 시', 35.4957600, 135.7460400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90216, 'Nyūzen', 'Nyuzen', 'Nyuzen,Nyūzen,ru shan,入膳', 36.9374400, 137.5005900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90217, 'Numazu', 'Numazu', 'Numadu,Numadzu,Numasu,Numazu,Numazu-chhi,Numazu-chhī,namazw,nu masu,numajeu si,nwmazw  shyzwka,nwmazw  shyzwywka,zhao jin,zhao jin shi,Нумадзу,Нумазу,Нүмазү,نامازو,نومازو، شیزوئوکا,نومازو، شیزوکا,นุมะซุ,沼津,沼津市,누마즈 시', 35.1000000, 138.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90218, 'Numata', 'Numata', 'Numata,Numata-chhi,Numata-chhī,numata si,nwmata,nwmata  gwnma,zhao tian,zhao tian shi,Нумата,نوماتا,نوماتا، گونما,沼田,沼田市,누마타 시', 36.6333300, 139.0500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90219, 'Nonoichi', 'Nonoichi', 'Nonoichi,ye 々,ye 々 shi shi,Ноноичи,野々,野々市市', 36.5333300, 136.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90220, 'Nōgata', 'Nogata', 'Naogata,Naokata,Nogata,Nōgata,zhi fang,直方', 33.7405100, 130.7226300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90221, 'Noda', 'Noda', 'Noda,Noda-Shi,Noda-chhi,Noda-chhī,noa da,noda si,nwda,nwda  chyba,ye tian,ye tian shi,Нода,نودا,نودا، چیبا,โนะดะ,野田,野田市,노다 시', 35.9489700, 139.8679300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90222, 'Nobeoka', 'Nobeoka', 'Nobeoka,Nobeoka-chhi,Nobeoka-chhī,nobe-oka si,nwbywka,yan gang,yan gang shi,Нобеока,نوبه‌اوکا، میازاکی,نوبيوكا,延岡,延岡市,노베오카 시', 32.5833300, 131.6666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90223, 'Nishiwaki', 'Nishiwaki', 'Nishivaki,Nishiwaki,xi xie,Нишиваки,西脇', 34.9841900, 134.9740700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90224, 'Nishio', 'Nishio', 'Nishio,Nisio,Nisio-chhi,Nisio-chhī,Nisyio,Niŝio,nisio si,nyshw,nyshyw,nyshyw  aychy,xi wei,xi wei shi,Нисио,Нишио,Нісіо,نيشيو,نیشو,نیشیو، آیچی,نیشیو، ایچی,西尾,西尾市,니시오 시', 34.8666700, 137.0500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90225, 'Nishinoomote', 'Nishinoomote', 'IIN,Nishinoomote,Nisinoomote,Nisinoomote-chhi,Nisinoomote-chhī,Nišinoomote,nisinoomote si,nyshynwawmwth  kagwshyma,nyshynwmwty,xi zhi biao,xi zhi biao shi,Нисиноомоте,Нишиноомоте,Нішіноомоте,نيشينوموتي,نیشینواوموته، کاگوشیما,西之表,西之表市,니시노오모테 시', 30.7333300, 131.0000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90226, 'Nishinomiya-hama', 'Nishinomiya-hama', 'Nishinomiya,Nishinomiya-hama,Nisinomija,xi gong,xi gong bang,xi gong shi,Нисиномия,西宮,西宮市,西宮浜', 34.7156200, 135.3319900, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90227, 'Nirasaki', 'Nirasaki', 'Nirasaki,Nirasakimachi,Nirazaki,Nirazakimachi,jiu qi,韮崎', 35.7000000, 138.4500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90228, 'Ninomiya', 'Ninomiya', 'Ninomija,Ninomiya,er gong,Ниномия,二宮', 35.3015000, 139.2558100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90229, 'Nikkō', 'Nikko', 'Nikko,Nikko-chhi,Nikkó,Nikkô-chhī,Nikkō,Niko,nik ko,nisko si,nykw,nykw  twchygy,nyqw,ri guang,ri guang shi,Никко,Нікко,ניקו,نيكو,نیکو، توچیگی,นิกโก,日光,日光市,닛코 시', 36.7500000, 139.6166700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90230, 'Niitsu-honchō', 'Niitsu-honcho', 'Niitsu,Niitsu-honcho,Niitsu-honchō,Niitu,Niizu,xin jin ben ding,xin jin shi,新津市,新津本町', 37.8002400, 139.1224000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90231, 'Niimi', 'Niimi', 'Niimi,xin jian,Ниими,新見', 34.9833300, 133.4666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90232, 'Niihama', 'Niihama', 'Niihama,Niihama-chhi,Niihama-chhī,Niikhama,Nijihama,Nikhama,niihama,niihama si,nyhama,xin ju bang,xin ju bang shi,xin ju bin shi,Ниихама,Нииҳама,Нихама,Ніїхама,نيهاما,نیہاما، اہیمے,نی‌ایهاما، اهیمه,にいはま,新居浜,新居浜市,新居濱市,니이하마 시', 33.9604700, 133.3052200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90233, 'Niigata', 'Niigata', 'KIJ,Niahi-niigata,Nigita,Niigata,nigata si,niigata,niigatashi,xin xi,xin xi shi,Ниигата,にいがた,にいがたし,ニイガタ,ニイガタシ,新潟,新潟市,니가타 시', 37.8863700, 139.0058900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90234, 'Nichinan', 'Nichinan', 'Nichinan,Nitinan,Nitinan-chhi,Nitinan-chhī,nichinan si,nychynan  myazaky,nytshynan,ri nan,ri nan shi,Нитинан,Ничинан,Нічінан,نيتشينان,نیچینان، میازاکی,日南,日南市,니치난 시', 31.6000000, 131.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90235, 'Naze', 'Naze', 'Nase,Naze', 28.3666700, 129.4833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90236, 'Narutochō-mitsuishi', 'Narutocho-mitsuishi', 'Muya,Naruto,Narutocho-mitsuishi,Narutochō-mitsuishi,ming men,ming men ding san~tsu shi,鳴門,鳴門町三ッ石', 34.1993300, 134.6093200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90237, 'Nara-shi', 'Nara-shi', 'Nara,Nara-shi,nai liang,nai liang shi,nala si,nara,narashi,Нара,نارا,ならし,奈良,奈良市,나라 시', 34.6850500, 135.8048500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90238, 'Nanao', 'Nanao', 'Nanao,Nanao-chhi,Nanao-chhī,nanao si,nanaw,nanayw  ayshykawa,qi wei,qi wei shi,Нанао,نانائو، ایشیکاوا,ناناو,七尾,七尾市,나나오 시', 37.0500000, 136.9666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90239, 'Namerikawa', 'Namerikawa', 'Namehrikava,Namerigawa,Namerikaua,Namerikava,Namerikawa,Namerikawa-chhi,Namerikawa-chhī,hua chuan,hua chuan shi,namelikawa si,namyrykawa,Намерикава,Намерикауа,Намерікава,Намэрикава,نامه‌ریکاوا، تویاما,ناميريكاوا,滑川,滑川市,나메리카와 시', 36.7596500, 137.3621500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90240, 'Nakatsugawa', 'Nakatsugawa', 'Nakacugava,Nakatsu,Nakatsugava,Nakatsugawa,Nakatugawa-chhi,Nakatugawa-chhī,na ka sung a wa,nakasseugawa si,nakatswgawa  gyfw,nakatswghawa ghyfw,zhong jin chuan,zhong jin chuan shi,Накатсугава,Накацугава,Накацуґава,ناكاتسوغاوا غيفو,ناکاتسوگاوا، گیفو,นะกะสึงะวะ,中津川,中津川市,나카쓰가와 시', 35.4833300, 137.5000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90241, 'Nakatsu', 'Nakatsu', 'Nakacu,Nakatsu,Nakatu,Nakatu-chhi,Nakatu-chhī,nakasseu si,nakatsw  awyta,nakatsw  awyyta,zhong jin shi,Накатсу,Накацу,ناكاتسو، أويتا,ناکاتسو، اوئیتا,中津市,나카쓰 시', 33.5981100, 131.1883000, 'JP', '2017-07-28', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90242, 'Nakanojōmachi', 'Nakanojomachi', 'Nakanojo,Nakanojomachi,Nakanojō,Nakanojōmachi,zhong zhi tiao ding,中之条町', 36.5871700, 138.8408300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90243, 'Nakano', 'Nakano', 'Nakano,zhong ye,Накано,中野', 36.7500000, 138.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90244, 'Nakamura', 'Nakamura', 'Nakamura,Nakamuramachi,Накамура', 32.9833300, 132.9333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90245, 'Nakama', 'Nakama', 'Nakama,Nakama-chhi,Nakama-chhī,nakama,nakama si,nakamh  fwkwywka,zhong jian,zhong jian shi,Накама,ناكاما,ناکامه، فوکوئوکا,中間,中間市,나카마 시', 33.8168800, 130.7096200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90246, 'Naha', 'Naha', 'Nafa,Naha,Naha-shi,Nahashi,Nakha,Nawa,na ba,na ba shi,naha,naha si,nahashi,nhh,Наха,נהה,なは,なはし,ナハ,ナハシ,那覇,那覇市,那霸市,나하 시', 26.2166700, 127.6833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90247, 'Nagoya', 'Nagoya', 'NGO,Nagoia,Nagoja,Nagojo,Nagoya,Nagoya City,Nagoya-shi,ming gu wu,ming gu wu shi,na ngoa ya,naghwya,nagoya si,nagoyashi,nagwya  aychy,Нагоя,ناغويا,ناگویا، آیچی,นะโงะยะ,なごやし,名古屋,名古屋市,나고야 시', 35.1814700, 136.9064100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90248, 'Nago', 'Nago', 'Naga,Nago,Nago-chhi,Nago-chhī,Nagu,Okaneku,ming hu,ming hu shi,naghw  awkynawa,nago si,nagw  awkynawa,Ôkaneku,Нага,Наго,Наґо,נאגו,ناغو، أوكيناوا,ناگو، اوکیناوا,名護,名護市,나고 시', 26.6150200, 127.9854300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90249, 'Nagata', 'Nagata', 'Nagata,Нагата', 30.3951600, 130.4254800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90250, 'Nagasaki', 'Nagasaki', 'NGS,Nagasacium,Nagasaki,Nagasaki-shi,Nagasakis,Nagasakishi,Nagasako,Nagaszaki,Nangasaque,nagasaki,nagasaki si,nagasakishi,nagazaky,naghasaky,najazaky,zhang qi,zhang qi shi,Нагасаки,נגסאקי,ناجازاكي,ناغاساكي,ناگازاکی,नागासाकी,ნაგასაკი,ながさき,ながさきし,ナガサキ,ナガサキシ,長崎,長崎市,长崎市,나가사키 시', 32.7500000, 129.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90251, 'Nagareyama', 'Nagareyama', 'Nagarejama,Nagareyama,Nagareyama-chhi,Nagareyama-chhī,liu shan,liu shan shi,na ngarea ya ma,nagaleyama si,nagaryama  chyba,nagaryyama  chyba,nagharh yama,Нагареяма,Нагарејама,Наґареяма,ناغاره ياما,ناگاریاما، چیبا,ناگارییاما، چیبا,นะงะเระยะมะ,流山,流山市,나가레야마 시', 35.8563000, 139.9026600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90252, 'Nagaoka', 'Nagaoka', 'Gorad Nagaoka,Nagaoka,Nagaoka-chhi,Nagaoka-chhī,na nga xoa ka,nagaoka si,nagawka  nygata,nagaywka  nygata,naghawka,zhang gang,zhang gang shi,Горад Нагаока,Нагаока,Наґаока,ناغاوكا,ناگائوکا، نیگاتا,ناگاوکا، نیگاتا,นะงะโอะกะ,ნაგაოკა,長岡,長岡市,나가오카 시', 37.4500000, 138.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90253, 'Nagano', 'Nagano', 'Nagano,Nagano-shi,Naganoshi,nagano,naganoshi,zhang ye,zhang ye shi,Нагано,ながの,ながのし,ナガノ,ナガノシ,長野,長野市', 36.6500000, 138.1833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90254, 'Nagahama', 'Nagahama', 'Nagahama,Nagakhama,zhang bang,zhang bang shi,Нагахама,長浜,長浜市', 35.3833300, 136.2666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90255, 'Nabari', 'Nabari', 'Nabari,ming zhang,ming zhang shi,名張,名張市', 34.6166700, 136.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90256, 'Musashino', 'Musashino', 'Musashino,Musasinas,Musasino,Musasino-chhi,Musasino-chhī,Musašinas,mu sa chi noa,musasino si,mwsashynw,mwsashynw  twkyw,wu cang ye shi,wu zang ye,wu zang ye shi,Мусасино,Мусасіно,Мусашино,Մուսասինո,מוסאשינו,موساشينو,موساشینو، توکیو,มุซะชิโนะ,武蔵野,武蔵野市,武藏野市,무사시노 시', 35.7061100, 139.5594400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90257, 'Muroto-misakicho', 'Muroto-misakicho', 'Muroto,Muroto-misakicho,shi hu jia ding,室戸岬町', 33.2866200, 134.1683200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90258, 'Muramatsu', 'Muramatsu', 'Muramatsu,cun song,村松', 37.6925700, 139.1712700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90259, 'Murakami', 'Murakami', 'Murakami,Murakami-chhi,Murakami-chhī,Murakamimachi,cun shang,cun shang shi,mulakami si,mwrakamy,mwrakamy  nygata,Мураками,Муракамі,موراكامي,موراکامی، نیگاتا,村上,村上市,무라카미 시', 38.2333300, 139.4833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90260, 'Mukō', 'Muko', 'Muka,Мука', 34.9654500, 135.7041500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90261, 'Muikamachi', 'Muikamachi', 'Muika,Muikamachi,liu ri ding,六日町', 37.0666700, 138.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90262, 'Morohongō', 'Morohongo', 'Morohongo,Morohongō,Moroyama', 35.9355600, 139.3044400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90263, 'Moriyama', 'Moriyama', 'Morijama,Moriyama,shou shan,Морияма,守山', 35.0666700, 135.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90264, 'Moriguchi', 'Moriguchi', 'Moriguchi,Moriguci,Moriguti,Moriguti-chhi,Moriguti-chhī,Morigutsi,Moriguĉi,QGT,moa ringu ci,moliguchi si,mwryghwtshy  awsaka,mwrygwchy  awsaka,shou kou,shou kou shi,Моригути,Моригучи,Моригучӣ,Моріґучі,موريغوتشي، أوساكا,موریگوچی، اوساکا,โมะริงุจิ,守口,守口市,모리구치 시', 34.7333300, 135.5666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90265, 'Mori', 'Mori', 'More,Mori,Море', 34.8333300, 137.9333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90266, 'Mizunami', 'Mizunami', 'Midzunami,Mizunami,Mizunami-chhi,Mizunami-chhī,Mizunami-cho,Mizunami-chō,mijeunami si,myzwnamy ghyfw,myzwnamy  gyfw,rui lang,rui lang shi,Мидзунами,Мизунами,Мідзунамі,ميزونامي غيفو,میزونامی، گیفو,瑞浪,瑞浪市,미즈나미 시', 35.3666700, 137.2500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90267, 'Miyoshi', 'Miyoshi', 'Mijoshi,Mijosi,Miyoshi,Miyosi,miyosi si,mywshy,mywshy  hyrwshyma,san ci,san ci shi,Миёси,Миёши,Мійосі,میوشي,میوشی، هیروشیما,三次,三次市,미요시 시', 34.8000000, 132.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90268, 'Miyazu', 'Miyazu', 'Mijadzu,Mijazu,Miyazu,Miyazu-chhi,Miyazu-chhī,gong jin,gong jin shi,miyajeu si,myazw,myazw  kywtw,Миядзу,Миязу,Міядзу,ميازو,میازو، کیوتو,宮津,宮津市,미야즈 시', 35.5333300, 135.1833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90269, 'Miyazaki', 'Miyazaki', 'KMI,Mijadzaki,Miyazaki,Miyazaki-shi,Miyazakishi,gong qi,gong qi shi,miyazaki,miyazakishi,Миядзаки,みやざき,みやざきし,ミヤザキ,ミヤザキシ,宮崎,宮崎市', 31.9166700, 131.4166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90270, 'Miyanoura', 'Miyanoura', 'Mijanoura,Miranoura,Miyanoura,Мияноура', 30.4269000, 130.5715100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90271, 'Miyakonojō', 'Miyakonojo', 'Mijakonodzh''o,Mijakonodzjo,Mijakonodzo,Mijakonojo,Miyakonojo,Miyakonojō,Miyakonozyo,Miyakonozyo-chhi,Miyakonozyô-chhī,Miyakonozyō,dou cheng,dou cheng shi,mi ya koa noa co,miyakonojo si,myakwnwjw,myakwnwjw  myazaky,Мияконодзё,Мияконоҷо,Мијаконоџо,Міяконоджьо,مياكونوجو,میاکونوجو، میازاکی,มิยะโกะโนะโจ,都城,都城市,미야코노조 시', 31.7333300, 131.0666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90272, 'Miyajima', 'Miyajima', 'Itsukushima,Mijadzima,Miyashima,Миядзима', 34.2990700, 132.3218600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90273, 'Miyata', 'Miyata', 'Miyada,Miyata,gong tian,宮田', 33.7081100, 130.6529700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90274, 'Mitsuke', 'Mitsuke', 'Mitsuke,jian fu,見附', 37.5333300, 138.9333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90275, 'Mitsukaidō', 'Mitsukaido', 'Mitsukaido,Mitsukaidō,Mizukaido,Mizukaidō', 36.0166700, 139.9833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90276, 'Mitake', 'Mitake', 'Mitake,Mitake-cho,Mitake-chō', 35.4166700, 137.1333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90277, 'Mitaka-shi', 'Mitaka-shi', 'Mitaka,san ying,san ying shi,三鷹,三鷹市', 35.6835100, 139.5596300, 'JP', '2010-02-18', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90278, 'Mishima', 'Mishima', 'Mishima,Misima,Misima-chhi,Misima-chhī,Misyima,Mişima,mi chi ma,misima si,myshyma,myshyma  shyzwywka,san dao,san dao shi,Мисима,Мишима,Місіма,ميشيما,میشیما، شیزوئوکا,มิชิมะ,三島,三島市,미시마 시', 35.1166700, 138.9166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90279, 'Mino', 'Mino', 'Mino-shi,Minoh,Minoh City,ji mian,ji mian shi,箕面,箕面市', 34.8269100, 135.4705700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90280, 'Mino', 'Mino', 'Mina,Mino,Minomachi,mei nong,Мина,美濃', 35.5333300, 136.9166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90281, 'Minamirinkan', 'Minamirinkan', 'Minami Rinkan Yamato,Minami-rinkan,Minamirinkan,nan lin jian,南林間', 35.4952700, 139.4427900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90282, 'Minamata', 'Minamata', 'Minamata,Minamata-chhi,Minamata-chhī,Mizumata,minamata si,mynamata,mynamata  kwmamwtw,shui yu,shui yu shi,Минамата,Мінамата,ميناماتا,میناماتا، کوماموتو,水俁市,水俣,水俣市,미나마타 시', 32.2166700, 130.4000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90283, 'Minakuchichō-matoba', 'Minakuchicho-matoba', 'Minakuchi,Minakuchicho-matoba,Minakuchichō-matoba,shui kou ding de chang,水口町的場', 34.9666700, 136.1666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90284, 'Mikuni', 'Mikuni', '', 36.2170600, 136.1518500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90285, 'Miki', 'Miki', 'Miki,Miki-chhi,Miki-chhī,miki,miki si,myky,myky  hywgw,san mu,san mu shi,Мики,Мікі,ميكي,میکی، هیوگو,มิกิ,三木,三木市,미키 시', 34.8000000, 134.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90286, 'Mihara', 'Mihara', 'Mihama,Mihara,Mihara-chhi,Mihara-chhī,Mikhara,mihala si,myhara,myhara  hyrwshyma,san yuan,san yuan shi,Михара,Миҳара,Міхара,میهارا,میهارا، هیروشیما,三原,三原市,미하라 시', 34.4000000, 133.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90287, 'Mibu', 'Mibu', 'Mibu,mibu jeong,ren sheng ding,Мибу,Мібу,壬生町,미부 정', 36.4166700, 139.8000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90288, 'Menuma', 'Menuma', 'Menuma,qi zhao,妻沼', 36.2224500, 139.3820500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90289, 'Matsutō', 'Matsuto', 'Matsuto,Matsutō,Matto,Mattō', 36.5166700, 136.5666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90290, 'Matsumoto', 'Matsumoto', 'Fukase,Fukashi,MMJ,Macumoto,Matsumoto,Matumoto,Matumoto-chhi,Matumoto-chhī,Shonai,masseumoto si,masu moa toa,matswmwtw,matswmwtw  naganw,song ben,song ben shi,Матсумото,Мацумото,Մացումոտո,ماتسوموتو,ماتسوموتو، ناگانو,มะสึโมะโตะ,松本,松本市,마쓰모토 시', 36.2333300, 137.9666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90291, 'Matsue', 'Matsue', 'Macue,Macueh,Macuje,Macujė,Matsu,Matsue,Matsue-shi,Matsue-su,Matsue-sṳ,Matsueshi,Matue,Matue-chhi,Matue-chhī,masseue si,masu xea,matsue,matsueshi,matswa,matswyh,song jiang,song jiang shi,Матсуе,Мацуе,Мацуэ,ماتسو، شیمانے,ماتسوئه,ماتسوا,มะสึเอะ,まつえ,まつえし,マツエ,マツエシ,松江,松江市,마쓰에 시', 35.4833300, 133.0500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90292, 'Matsudo', 'Matsudo', 'Macudo,Matsudo,Matudo-chhi,Matudo-chhī,masseudo si,masu doa,matswdw,matswdw  chyba,song hu,song hu shi,Матсудо,Мацудо,ماتسودو,ماتسودو، چیبا,มะสึโดะ,松戶市,松戸,松戸市,마쓰도 시', 35.7799500, 139.9014400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90293, 'Matsubase', 'Matsubase', 'Matsubase,matsubase,song yuan,まつばせ,マツバセ,松原', 32.6500000, 130.6666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90294, 'Matsubara', 'Matsubara', 'Matsubara,song yuan,松原', 34.5666700, 135.5500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90295, 'Masuda', 'Masuda', 'IWJ,Masud,Masuda,Masuda-chhi,Masuda-chhī,Maszuda,maseuda si,maswda,maswda  shymanh,yi tian,yi tian shi,Масуд,Масуда,ماسودا,ماسودا، شیمانه,益田,益田市,마스다 시', 34.6666700, 131.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90296, 'Maruoka', 'Maruoka', '', 36.1534000, 136.2702900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90297, 'Kamimaruko', 'Kamimaruko', 'Kamimaruko,Mariko,Maruko,shang wan zi,Маруко,上丸子', 36.3186500, 138.2732900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90298, 'Marugame', 'Marugame', 'Marugame,Marugame-chhi,Marugame-chhī,Marukame,Maruqame,malugame si,marwgamh  kagawa,marwghamh,wan gui,wan gui shi,Маругаме,Маруґаме,ماروغامه,ماروگامه، کاگاوا,丸亀,丸亀市,丸龜市,마루가메 시', 34.2833300, 133.7833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90299, 'Makurazaki', 'Makurazaki', 'Makurasaki,Mazuraki,zhen qi,枕崎', 31.2666700, 130.3166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90300, 'Makinohara', 'Makinohara', 'Makinohara,makinoharashi,mu zhi yuan,まきのはらし,牧之原', 34.7743700, 138.1483100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90301, 'Maki', 'Maki', '', 37.7500000, 138.8833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90302, 'Maizuru', 'Maizuru', 'Maidsuru,Maiduru,Maidzuru,Maizuru,Maizuru-chhi,Maizuru-chhī,Majdzuru,maijeulu si,mayzwrw,mayzwrw  kywtw,misu ru,wu he,wu he shi,Маизуру,Майдзуру,مايزورو,مایزورو، کیوتو,ไมซุรุ,舞鶴,舞鶴市,舞鹤市,마이즈루 시', 35.4500000, 135.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90303, 'Maibara', 'Maibara', 'Maibara,Maibara-chhi,Maibara-chhī,Maihara,Majbara,maibala si,maybara,maybara  shyga,mi yuan,mi yuan shi,miba ra,Маибара,Майбара,مايبارا,مایبارا، شیگا,ไมบะระ,米原,米原市,마이바라 시', 35.3166700, 136.2833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90304, 'Maebashi', 'Maebashi', 'Maebashi,Maebashi-shi,Maebashishi,Maebasi,Maebaši,Maehbasi,ma-ebasi si,maebashi,maebashishi,qian qiao,qian qiao shi,Маэбаси,まえばし,まえばしし,マエバシ,マエバシシ,前橋,前橋市,마에바시 시', 36.4000000, 139.0833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90305, 'Maebaru-chūō', 'Maebaru-chuo', 'Maebaru,Maebaru-chuo,Maebaru-chūō,Maeharu,qian yuan zhong yang,前原中央', 33.5591600, 130.2014800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90306, 'Machida', 'Machida', 'Machida,Macida,Matida,Matida-chhi,Matida-chhī,Mačida,ding tian,ding tian shi,ma chi da,machida si,machyda  twkyw,matshyda,ting tian shi,Матида,Матіда,Мачида,Մատիդա,ماتشيدا,ماچیدا، توکیو,ماچیدا، ٹوکیو,มะชิดะ,町田,町田市,마치다 시', 35.5402800, 139.4508300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90307, 'Kyoto', 'Kyoto', 'Gorad Kijota,Kejuots,Kiaⁿ-to͘-chhī,Kiotas,Kioto,Kiotó,Kjoto,Kjóto,Kyoto,Kyoto-shi,Kyotu,Kyotum,Kyōto,Kyōto-shi,Kėjuots,Lungsod ng Kyoto,Quioto,UKY,gyoto si,jing dou,jing dou shi,kheiyw toa,ki''oto,kiyoto,kiyotto,kyeattea,kyoto,kyoutoshi,kywtw,qywtw,Κιότο,Горад Кіёта,Киото,Кёто,Кіото,Кјото,Կիոտո,קיאטא,קיוטו,كيوتو,کیوتو,کیوٹو,ܩܝܘܛܘ,क्योटो,क्योतो,কিয়োটো,ਕਿਓਤੋ,கியோத்தோ,ക്യോത്തോ,ක්යෝතෝ,เคียวโตะ,ཁེཡོ་ཐྲོ།,ကျိုတိုမြို့,კიოტო,きょうとし,京都,京都市,교토 시', 35.0210700, 135.7538500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90308, 'Kushikino', 'Kushikino', 'Kushigino,Kushikino,Kusiki-no', 31.7166700, 130.2666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90309, 'Kusatsu', 'Kusatsu', 'Kusacu,Kusatsu,Kusatsu-cho,Kusatsu-chō,Kusatu,Susatsu,cao jin,Кусацу,草津', 35.0166700, 135.9666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90310, 'Kurume', 'Kurume', 'Kurume,Kurume-chhi,Kurume-chhī,gulume si,jiu liu mi,jiu liu mi shi,khuru mea,kwrwmh  fwkwywka,kwrwmy,kwrwmy  fwkwka,Куруме,كورومي,کورومه، فوکوئوکا,کورومی، فوکوکا,คุรุเมะ,久留米,久留米市,구루메 시', 33.3166700, 130.5166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90311, 'Kuroda', 'Kuroda', 'Kisogawa,Kuroda,Курода', 35.3500000, 136.7833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90312, 'Kurio', 'Kurio', 'Kurio,Kuryu,Курио', 30.2712300, 130.4236000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90313, 'Kurihashi', 'Kurihashi', 'Kurihashi', 36.1333300, 139.7000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90314, 'Kure', 'Kure', 'Kure,Kure-chhi,Kure-chhī,gule si,khurea,kwrh  hyrwshyma,kwrshy,qwrh,wu,wu shi,Куре,קורה,كورشي,کوره، هیروشیما,کورے، ہیروشیما,คุเระ,吳市,呉,呉市,구레 시', 34.2322200, 132.5665800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90315, 'Kurayoshi', 'Kurayoshi', 'Kurajoshi,Kurajosi,Kurajosis,Kurajošis,Kurayoshi,Kurayosi-chhi,Kurayosi-chhī,Kurayosyi,cang ji,cang ji shi,gulayosi si,kwraywshy,kwraywshy  twtwry,Курайоші,Кураёси,Кураёши,كورايوشي,کورایوشی، توتوری,倉吉,倉吉市,구라요시 시', 35.4333300, 133.8166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90316, 'Kurashiki', 'Kurashiki', 'Kurashiki,Kurasiki,Kurasiki-chhi,Kurasiki-chhī,Kurasyiki,Kuraşiki,cang fu,cang fu shi,gulasiki si,khu ra chiki,kwrashyky  awkayama,Курасики,Курасікі,Курашики,كوراشيكي، أوكاياما,کوراشیکی، اوکایاما,คุระชิกิ,倉敷,倉敷市,구라시키 시', 34.5833300, 133.7666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90317, 'Kumamoto', 'Kumamoto', 'KMJ,Kumamoto,Kumamoto-shi,gumamoto si,kumamotoshi,xiong ben,xiong ben shi,Кумамото,くまもとし,熊本,熊本市,구마모토 시', 32.8058900, 130.6918100, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90318, 'Kumagaya', 'Kumagaya', 'Kumagai,Kumagaja,Kumagaya,Kumagaya-chhi,Kumagaya-chhī,gumagaya si,khu ma nga ya,kwmagaya  saytama,kwmagaya  sayytama,kwmaghaya,xiong gu,xiong gu shi,Кумагая,Кумагаја,Кумаґая,كوماغايا,کوماگایا، سائیتاما,کوماگایا، سایتاما,คุมะงะยะ,熊谷,熊谷市,구마가야 시', 36.1349700, 139.3900400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90319, 'Kukichūō', 'Kukichuo', 'Kuki,Kukichuo,Kukichūō,jiu xi zhong yang,kukichuuou,Куки,くきちゅうおう,クキチュウオウ,久喜中央', 36.0673900, 139.6749800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90320, 'Kudamatsu', 'Kudamatsu', 'Kudamatsu', 34.0000000, 131.8666700, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90321, 'Kozakai-chō', 'Kozakai-cho', 'Kozakai,Kozakai-cho,Kozakai-chō,kozakaichou,xiao ban jing ding,こざかいちょう,小坂井町', 34.8000000, 137.3588900, 'JP', '2017-04-25', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90322, 'Koshima', 'Koshima', 'Kojima,Koshima,Кошима', 30.2346100, 130.5351700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90323, 'Koshigaya', 'Koshigaya', 'Koshigaja,Koshigaya,Kosigaja,Kosigaya-chhi,Kosigaya-chhī,Kosyigaya,gosigaya si,khoa chi nga ya,kwshygaya  saytama,kwshygaya  sayytama,kwshyghaya,yue gu,yue gu shi,Косигая,Косіґая,Кошигая,Кошигаја,كوشيغايا,کوشیگایا، سائیتاما,کوشیگایا، سایتاما,โคะชิงะยะ,越谷,越谷市,고시가야 시', 35.8903500, 139.7891600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90324, 'Koseda', 'Koseda', 'Koseda,Коседа', 30.3879600, 130.6492400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90325, 'Kōnosu', 'Konosu', 'Konosu,Kōnosu,hong chao,kounosu,こうのす,コウノス,鴻巣', 36.0686800, 139.5168400, 'JP', '2017-04-16', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90326, 'Kōnan', 'Konan', 'Konan,jiang nan,Конан,江南', 35.3316500, 136.8704200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90327, 'Komoro', 'Komoro', 'Komoro,Komoro-chhi,Komoro-chhī,gomolo si,kwmwrw,kwmwrw  naganw,xiao zhu,xiao zhu shi,Коморо,Կոմորո,كومورو,کومورو، ناگانو,小諸,小諸市,고모로 시', 36.3166700, 138.4333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90328, 'Komono', 'Komono', 'Komono', 35.0000000, 136.5166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90329, 'Komatsushimachō', 'Komatsushimacho', 'Komatsujima,Komatsushima,Komatsushimacho,Komatsushimachō,Komatusima,xiao song dao,xiao song dao ding,小松島,小松島町', 34.0000000, 134.5833300, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90330, 'Komatsu', 'Komatsu', 'KMQ,Komacu,Komatsu,Komatu-chhi,Komatu-chhī,gomasseu si,kwmatsw,kwmatsw  ayshykawa,xiao song,xiao song shi,Коматсу,Комацу,كوماتسو,کوماتسو، ایشیکاوا,小松,小松市,고마쓰 시', 36.4026300, 136.4508800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90331, 'Komaki', 'Komaki', 'Komaki,Komaki-chhi,Komaki-chhī,gomaki si,khoa maki,kwmaky,kwmaky  aychy,kwmaky  aytshy,xiao mu,xiao mu shi,Комаки,Комакі,كوماكي، آيتشي,کوماکی,کوماکی، آیچی,โคะมะกิ,小牧,小牧市,고마키 시', 35.2833300, 136.9166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90332, 'Kokubunji', 'Kokubunji', 'Kokubundzi,Kokubundzis,Kokubundžis,Kokubungi,Kokubunji,Kokubunzi-chhi,Kokubunzi-chhī,Kokubunĝi,gokubunji si,guo fen si,guo fen si shi,khoa ku bun ci,kwkwbwnjy,kwkwbwnjy  twkyw,Кокубундзи,Кокубундзі,Кокубунџи,Кокубунҷи,Կոկուբունձի,كوكوبونجي,کوکوبونجی، توکیو,โคะกุบุนจิ,国分寺,国分寺市,國分寺市,고쿠분지 시', 35.7022200, 139.4755600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90333, 'Kokubu-matsuki', 'Kokubu-matsuki', 'Kokubo,Kokubu,Kokubu-matsuki,Kokubun,guo fen,guo fen song mu,Кокубу,国分,国分松木', 31.7333300, 130.7666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90334, 'Koga', 'Koga', 'Koga,Koga-chhi,Koga-chhī,goga si,gu he,gu he shi,kwga  aybaraky,kwgha,Кога,Коґа,كوغا,کوگا، ایباراکی,古河,古河市,고가 시', 36.1833300, 139.7166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90335, 'Koga', 'Koga', 'Koga,gu he,Кога,古賀', 33.7333300, 130.4666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90336, 'Kōfu', 'Kofu', 'Kofe,Kofu,Kofu-shi,Kofushi,Kohu,Kohu-chhi,Kófu,Kôhu-chhī,Kōfu,Kōfu-shi,Kōfushi,Kōhu,gohu si,jia fu,jia fu shi,kho fu,koufu,koufushi,kwfw,kwfw  yamanashy,qwpw,Кофе,Кофу,Կոֆու,קופו,كوفو,کوفو، یاماناشی,โคฟุ,こうふ,こうふし,コウフ,コウフシ,甲府,甲府市,고후 시', 35.6666700, 138.5666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90337, 'Kodamachō-kodamaminami', 'Kodamacho-kodamaminami', 'Kodama,Kodamacho-kodamaminami,Kodamachō-kodamaminami,er yu ding er yu nan,Кодама,児玉町児玉南', 36.1849700, 139.1319100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90338, 'Kochi', 'Kochi', 'KCZ,Kochi,Kochi-shi,Kochin,Kochishi,Koti,Kôti,Kōchi-shi,Kōchishi,gao zhi,gao zhi shi,kouchi,kouchishi,Кочин,こうち,こうちし,コウチ,コウチシ,高知,高知市', 33.5500000, 133.5333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90339, 'Kobe', 'Kobe', 'Gorad Kobeh,Kobe,Kobe-chhi,Kobe-shi,Kobė,Kompe,Kóbe,Kôbe-chhī,Kōbe,Kōbe-shi,Lungsod ng Kobe,gobe si,kaube,kho bea,kobe,kope,koubeshi,kwbh,qwbh,shen hu,shen hu shi,Κόμπε,Горад Кобэ,Кобе,Կոբե,קובה,كوبه,کوبه,کوبے,कोबे,কৌবে,கோபே,โคเบะ,კობე,こうべし,神戶,神户市,神戸,神戸市,고베 시', 34.6913000, 135.1830000, 'JP', '2017-07-28', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90340, 'Kobayashi', 'Kobayashi', 'Kobajasi,Kobayashi,Kobayashi-cho,Kobayashi-chō,xiao lin,Кобаяси,小林', 31.9833300, 130.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90341, 'Kiyosu', 'Kiyosu', 'Kiesu,Kijosu,Kiyosu,Kiyosu-chhi,Kiyosu-chhī,giyoseu si,khi yoasu,kywsw,kywsw  aychy,kyywsw  aychy,qing xu,qing xu shi,Киесу,Киёсу,Кійосу,كيوسو,کیوسو، آیچی,کییوسو، ایچی,คิโยะซุ,清須,清須市,기요스 시', 35.2166700, 136.8333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90342, 'Kitsuki', 'Kitsuki', 'Kicuki,Kitsuki,chu zhu,Кицуки,杵築', 33.4199800, 131.6183700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90343, 'Kitakyushu', 'Kitakyushu', 'KKJ,Kita-Kjushju,Kitakiusiu,Kitakiūšiū,Kitakjushju,Kitakjushu,Kitakjusju,Kitakjusu,Kitakjuŝu,Kitakjúsú,Kitakjúšú,Kitakjūshū,Kitakyuesue,Kitakyushu,Kitakyusyu,Kitakyüşü,Kitakyūshū,Pak-kiu-chiu-chhi,Pak-kiú-chiu-chhī,bei jiu zhou,bei jiu zhou shi,gitakyusyu si,khi ta kiw chu,kytakywshw,kytakywshw  fwkwywka,Китакюсю,Китакюшу,Китакюшю,Китакјушу,Кіта-Кюшю,Կիտակյուսյու,كيتاكيوشو,کیتاکیوشو، فوکوئوکا,คิตะกีวชู,北九州,北九州市,기타큐슈 시', 33.8518100, 130.8503400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90344, 'Kitakata', 'Kitakata', 'Kitagata,Kitakata,Kitakata-chhi,Kitakata-chhī,gitakata si,khi ta ka ta,kytakata,kytakata  fwkwshyma,xi duo fang,xi duo fang shi,Китаката,Кітаката,كيتاكاتا,کیتاکاتا، فوکوشیما,คิตะกะตะ,喜多方,喜多方市,기타카타 시', 37.6500000, 139.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90345, 'Kitahama', 'Kitahama', '', 35.1666700, 135.9166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90346, 'Kishiwada', 'Kishiwada', 'Kishiwada,Kisivada,Kisiwada,an he tian,an he tian shi,gisiwada si,Кисивада,岸和田,岸和田市,기시와다 시', 34.4666700, 135.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90347, 'Kisarazu', 'Kisarazu', 'Kisaradu,Kisaradzu,Kisarazu,Kisarazu-chhi,Kisarazu-chhī,Kizarazu,gisalajeu si,khi sa rasu,kisaradzu,ksarazw  chyba,kysarazw,kysarazw  chyba,mu geng jin,mu geng jin shi,Кисарадзу,Кисаразу,Кісарадзу,كيسارازو,کسارازو، چیبا,کیسارازو، چیبا,คิซะระซุ,きさらづ,キサラヅ,木更津,木更津市,기사라즈 시', 35.3832900, 139.9325400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90348, 'Kisai', 'Kisai', 'Kisai', 36.1000000, 139.5833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90349, 'Kiryū', 'Kiryu', 'Kiri,Kiriu,Kirju,Kiryu,Kiryu-chhi,Kiryû-chhī,Kiryū,gilyu si,kyrw,kyryw  gwnma,tong sheng,tong sheng shi,Кири,Кирю,Кирју,Кірю,كيرو,کیریو، گونما,桐生,桐生市,기류 시', 36.4000000, 139.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90350, 'Kikuchi', 'Kikuchi', 'Kikuchi,Kikuti,Kikuti-chhi,Kikuti-chhī,gikuchi si,ju chi,ju chi shi,kykwchy  kwmamwtw,kykwtshy,Кикути,Кикучи,Кікучі,كيكوتشي,کیکوچی، کوماموتو,菊池,菊池市,기쿠치 시', 32.9833300, 130.8166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90351, 'Kazo', 'Kazo', 'Kadzo,Kaso,Kazo,Kazo-chhi,Kazo-chhī,gajo si,jia xu,jia xu shi,kazw,kazw  saytama,Кадзо,Казо,كازو,کازو، سایتاما,加須,加須市,가조 시', 36.1166700, 139.6000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90352, 'Kawasaki', 'Kawasaki', 'Cita de Kawasaki,Cità de Kawasaki,Gorad Kavasaki,Kauasaki,Kavasaki,Kavasakis,Kavaszaki,Kawasaki,Kawasaki City,Kawasaki Si,Kawasaki-chhi,Kawasaki-chhī,Kaŭasaki,chuan qi,chuan qi shi,gawasaki si,kavasaki,kawasaky,kawasaky  kanagawa,kha wa saki,Καβασάκι,Горад Кавасакі,Кавасаки,Кавасакі,Կավասակի,קווסאקי,كاواساكي,کاواساکی، کاناگاوا,कावासाकी,คะวะซะกิ,川崎,川崎市,가와사키 시', 35.5205600, 139.7172200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90353, 'Kawasaki', 'Kawasaki', 'Kawasaki', 33.5999300, 130.8149500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90354, 'Kawanishi', 'Kawanishi', 'Kauanishi,Kavanishi,Kavanisi,Kawanishi,Kawanisi-chhi,Kawanisi-chhī,chuan xi,chuan xi shi,gawanisi si,kawanyshy,kawanyshy  hywgw,Каваниси,Каваниши,Каваніші,Кауаниши,كاوانيشي,کاوانیشی، هیوگو,川西,川西市,가와니시 시', 34.8166700, 135.4166700, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90355, 'Kawaguchi', 'Kawaguchi', 'Kauaguchi,Kavaguchi,Kavagucis,Kavaguti,Kavagučis,Kavaquci,Kavaquçi,Kawaguchi,Kawaguti-chhi,Kawaguti-chhī,Kawagutsi,chuan kou,chuan kou shi,gawaguchi si,kawaghwtshy,kawaguchi,kawagwchy  saytama,kawagwchy  sayytama,kha wangu chi,Кавагути,Кавагучи,Каваґуті,Кауагучи,كاواغوتشي,کاواگوچی، سائیتاما,کاواگوچی، سایتاما,คะวะงุชิ,კავაგუტი,かわぐち,カワグチ,川口,川口市,가와구치 시', 35.8052100, 139.7107200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90356, 'Kawagoe', 'Kawagoe', 'Kavagoe,Kavagoeh,Kawagoe,Kawagoe-chhi,Kawagoe-chhī,chuan yue,chuan yue shi,gawago-e si,kawaghwyh,kawagwyh  saytama,kha wa ngoa xea,Кавагое,Кавагоэ,Каваґое,كاواغويه,کاواگوئه، سایتاما,کاواگوے، سائیتاما,คะวะโงะเอะ,კავაგოე,川越,川越市,가와고에 시', 35.9086100, 139.4852800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90357, 'Katsuyama', 'Katsuyama', 'Kacujama,Katsujama,Katuyama-chhi,Katuyama-chhī,gasseuyama si,katswyama,katswyama  fwkwyy,sheng shan,sheng shan shi,Катсуяма,Кацуяма,كاتسوياما,کاتسویاما، فوکوئی,勝山,勝山市,가쓰야마 시', 36.0617300, 136.5010100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90358, 'Kasukabe', 'Kasukabe', 'Kasukabe,Kasukabe-chhi,Kasukabe-chhī,chun ri bu,chun ri bu shi,gaseukabe si,kasukabe,kaswkabh  saytama,kaswkaby,kha suk a bea,po bi,Касукабе,كاسوكابي,کاسوکابه، سایتاما,کاسوکابے، سائیتاما,คะซุกะเบะ,かすかべ,カスカベ,春日部,春日部市,粕壁,가스카베 시', 35.9830800, 139.7496600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90359, 'Kasugai', 'Kasugai', 'Kasugai,Kasugai-chhi,Kasugai-chhī,Kasugaj,chun ri jing,chun ri jing shi,gaseugai si,kaswgay,kaswgay  aychy,kaswgayy  aychy,kaswghay,khasu ngi,Касугаи,Касугай,Касугај,Касуґай,Касүгаи,كاسوغاي,کاسوگائی، ایچی,کاسوگای,کاسوگای، آیچی,کسوگا‌‍‌ئ,คะซุไง,春日井,春日井市,가스가이 시', 35.2476200, 136.9722900, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90360, 'Kashiwazaki', 'Kashiwazaki', 'Kashivazaki,Kashiwazaki,Kasivadzaki,Kasiwazaki-chhi,Kasiwazaki-chhī,Kasyiwasaki,bai qi,bai qi shi,gasiwajaki si,kashywazaky,kashywazaky  nygata,Касивадзаки,Касівадзакі,Кашивазаки,كاشيوازاكي,کاشیوازاکی، نیگاتا,柏崎,柏崎市,가시와자키 시', 37.3666700, 138.5500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90361, 'Kashiwa', 'Kashiwa', 'Kashiva,Kashiwa,Kasiva,Kasiwa-chhi,Kasiwa-chhī,Kaşiva,bai,bai shi,gasiwa si,kashywa,kashywa  chyba,kha chi wa,Касива,Касіва,Кашива,كاشيوا,کاشیوا، چیبا,คะชิวะ,柏,柏市,가시와 시', 35.8622400, 139.9773200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90362, 'Kashima', 'Kashima', 'Kashima,Kasima,gasima si,kashyma,kashyma  saga,lu dao,lu dao shi,Касима,Кашима,Кашіма,كاشيما,کاشیما، ساگا,鹿島,鹿島市,가시마 시', 33.1061100, 130.0905600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90363, 'Kashihara-shi', 'Kashihara-shi', 'Kashihara,Kashihara-shi,jiang yuan,jiang yuan shi,橿原,橿原市', 34.5089600, 135.7929000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90364, 'Kashihara', 'Kashihara', 'Kashihara,Kashiharacho,Kashiharachō,Kashiwabara,Kashiwara', 34.5833300, 135.6166700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90365, 'Kaseda-shirakame', 'Kaseda-shirakame', 'Kaseda,Kaseda-shirakame,jia shi tian bai gui,加世田白亀', 31.4166700, 130.3166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90366, 'Kasaoka', 'Kasaoka', 'Kasaoka,li gang,笠岡', 34.5059700, 133.5039100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90367, 'Kasamatsuchō', 'Kasamatsucho', 'Kasamatsu,Kasamatsucho,Kasamatsuchō', 35.3666700, 136.7666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90368, 'Kariya', 'Kariya', 'Karija,Kariya,Kariya-chhi,Kariya-chhī,Kariya-cho,Kariya-chō,galiya si,karya  aychy,karyya,karyya  aychy,yi gu,yi gu shi,Кария,Карија,Карія,كارييا,کاریا، آیچی,کاریہ,کارییا، ایچی,刈谷,刈谷市,가리야 시', 34.9833300, 136.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90369, 'Karatsu', 'Karatsu', 'Karacu,Karatsu,Karatu,Karatu Si,Karatu-chhi,Karatu-chhī,galasseu si,karatsw,karatsw  saga,tang jin,tang jin shi,Каратсу,Карацу,كاراتسو,کاراتسو,کاراتسو، ساگا,唐津,唐津市,가라쓰 시', 33.4425000, 129.9697200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90370, 'Kanzakimachi-kanzaki', 'Kanzakimachi-kanzaki', 'Kanzaki,Kanzakimachi-kanzaki,shen qi ding shen qi,神埼町神埼', 33.3089500, 130.3738300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90371, 'Kanuma', 'Kanuma', 'Kamima,Kanuma,Kanuma-chhi,Kanuma-chhī,ganuma si,kanwma,kanwma  twchygy,lu zhao,lu zhao shi,Канума,كانوما,کانوما، توچیگی,鹿沼,鹿沼市,가누마 시', 36.5500000, 139.7333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90372, 'Kanoya', 'Kanoya', 'Kanoja,Kanoya,Kanoya-chhi,Kanoya-chhī,ganoya si,kanwya,kanwya  kagwshyma,lu wu,lu wu shi,Каноя,Каноја,كانويا,کانویا، کاگوشیما,鹿屋,鹿屋市,가노야 시', 31.3833300, 130.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90373, 'Kan’onjichō', 'Kan''onjicho', 'Kan''onjicho,Kannonji,Kannonzi,Kanonji,Kanonji-cho,Kanonji-chō,Kan’onjichō,guan yin si ding,観音寺町', 34.1276000, 133.6459800, 'JP', '2016-11-25', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90374, 'Kannabechō-yahiro', 'Kannabecho-yahiro', 'Kannabe,Kannabecho-yahiro,Kannabechō-yahiro,shen bian ding ba xun,神辺町八尋', 34.5580800, 133.4179600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90375, 'Kanie', 'Kanie', 'Kanie', 35.1333300, 136.8000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90376, 'Kanekomachi', 'Kanekomachi', 'Kaneko,Kanekomachi,jin gu ding,金古町', 36.4109700, 138.9962100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90377, 'Kanda', 'Kanda', 'Kanda,Karita,Канда', 33.7833300, 130.9833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90378, 'Kanazawa', 'Kanazawa', 'Canasava,Kanadzava,Kanazaua,Kanazawa,Kanazawa-shi,Kanazawa-si,Kanazawashi,Kanazaŭa,ganajawa si,jin ze,jin ze shi,kanazawa,kanazawashi,Канадзава,かなざわ,かなざわし,カナザワ,カナザワシ,金沢,金沢市,金澤市,가나자와 시', 36.6000000, 136.6166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90379, 'Kanaya', 'Kanaya', 'Kanaya,jin gu,金谷', 34.8202200, 138.1277500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90380, 'Kamojimachō-jōgejima', 'Kamojimacho-jogejima', 'Kamojima,Kamojimacho-jogejima,Kamojimachō-jōgejima,Kamoshima,ya dao ding shang xia dao,鴨島町上下島', 34.0680300, 134.3503300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90381, 'Kamogatachō-kamogata', 'Kamogatacho-kamogata', 'Kamogata,Kamogatacho-kamogata,Kamogatachō-kamogata,Kamokata,ya fang ding ya fang,鴨方町鴨方', 34.5374500, 133.5896700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90382, 'Kamo', 'Kamo', 'Kamo,jia mao,Камо,加茂', 37.6644200, 139.0350200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90383, 'Kamirenjaku', 'Kamirenjaku', 'Kami-renjaku,Kamirenjaku,Mitaka,Mitaka-machi,Mitaka-mura,kamirenjaku,shang lian que,Митака,かみれんじゃく,カミレンジャク,上連雀', 35.6942300, 139.5549500, 'JP', '2015-11-08', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90384, 'Kaminokawa', 'Kaminokawa', 'Kaminokawa', 36.4333300, 139.9166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90385, 'Kamiichi', 'Kamiichi', 'Kamiichi', 36.7000000, 137.3666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90386, 'Kameyama', 'Kameyama', 'Kameyama,gui shan,亀山', 34.8500000, 136.4500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90387, 'Kameoka', 'Kameoka', 'Kameoka,Kameoka-chhi,Kameoka-chhī,game-oka si,gui gang,gui gang shi,kamywka,kha mea xoa ka,Камеока,كاميوكا,کامه‌اوکا، کیوتو,คะเมะโอะกะ,亀岡,亀岡市,龜岡市,가메오카 시', 35.0000000, 135.5833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90388, 'Kameda-honchō', 'Kameda-honcho', 'Kameda,Kameda-honcho,Kameda-honchō,gui tian ben ding,亀田本町', 37.8721400, 139.1099000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90389, 'Kamakura', 'Kamakura', 'Gorad Kamakura,Kamakura,Kamakura-chhi,Kamakura-chhī,gamakula si,kamakwra,kamakwra  kanagawa,kha ma kura,lian cang,lian cang shi,Горад Камакура,Камакура,كاماكورا,کاماکورا، کاناگاوا,คะมะกุระ,鎌倉,鎌倉市,镰仓市,가마쿠라 시', 35.3088900, 139.5502800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90390, 'Kakogawachō-honmachi', 'Kakogawacho-honmachi', 'Kakogawa,Kakogawacho-honmachi,Kakogawachō-honmachi,gakogawa si,jia gu chuan ding ben ding,jia gu chuan shi,加古川市,加古川町本町,가코가와 시', 34.7694300, 134.8290500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90391, 'Kakegawa', 'Kakegawa', 'Kakegaua,Kakegava,Kakegawa,Kakegawa-chhi,Kakegawa-chhī,Kakegaŭa,Kakehgava,gakegawa si,gua chuan,gua chuan shi,kakyghawa,Какегава,Какеґава,Какэгава,كاكيغاوا,کاکه‌گاوا، شیزوئوکا,掛川,掛川市,가케가와 시', 34.7666700, 138.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90392, 'Kakamigahara', 'Kakamigahara', 'Kagamigahara,Kagamihara,Kakamigahara,Kakamigahara-chhi,Kakamigahara-chhī,Kakamigakhara,gakamigahala si,ge wu yuan,ge wu yuan shi,kakamygahara  gyfw,kakamyghhara,Какамигахара,Какамигаҳара,Какаміґахара,كاكاميغهارا,کاکامیگاهارا، گیفو,کاکامیگاہارا، گیفو,各务原市,各務原,各務原市,가카미가하라 시', 35.4166700, 136.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90393, 'Kashima-shi', 'Kashima-shi', 'Kashima,lu dao,lu dao shi,鹿島,鹿島市,鹿嶋,鹿嶋市', 35.9653600, 140.6447400, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90394, 'Kajiki', 'Kajiki', 'Kajiki-cho,Kajiki-chō', 31.7333300, 130.6666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90395, 'Kaizuka', 'Kaizuka', 'Kaitsuka,Kaizuka,bei zhong,bei zhong shi,貝塚,貝塚市', 34.4500000, 135.3500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90396, 'Kainan', 'Kainan', 'Kainan,Kainan-chhi,Kainan-chhī,Kajnan,gainan si,hai nan,hai nan shi,kaynan,kaynan  wakayama,Каинан,Кайнан,كاينان,کاینان، واکایاما,海南,海南市,가이난 시', 34.1516600, 135.2139800, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90397, 'Kagoshima', 'Kagoshima', 'KOJ,Kagoshima,Kagoshima-shi,Kagoshimashi,Kagosima,Kagošima,gagosima si,kaghwshyma,kagoshima,kagoshimashi,lu er dao,lu er dao shi,lu r dao shi,Кагошима,كاغوشيما,かごしま,かごしまし,カゴシマ,カゴシマシ,鹿儿岛市,鹿児島,鹿児島市,가고시마 시', 31.5666700, 130.5500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90398, 'Kadoma', 'Kadoma', 'Kadoma,Kadoma-chhi,Kadoma-chhī,Kadome,gadoma si,kadwma  awsaka,kha doa ma,men zhen,men zhen shi,Кадома,Кадоме,كادوما، أوساكا,کادوما، اوساکا,คะโดะมะ,門真,門真市,가도마 시', 34.7381000, 135.5744200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90399, 'Izumo', 'Izumo', 'IZO,Idzumo,Isumo,Itsumo,Izumo,Izumo-chhi,Izumo-chhī,ayzwmw,azwmw,chu yun,chu yun shi,ijeumo si,xisu moa,Ідзумо,Идзумо,Изумо,إزومو,ایزومو,อิซุโมะ,出雲,出雲市,이즈모 시', 35.3666700, 132.7666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90400, 'Izumiōtsu', 'Izumiotsu', 'Ebisucho,Ebisuchō,Idzumotsu,Izumiotsu,Izumiōtsu,Otsu,quan da jin,Ōtsu,Идзумотсу,泉大津', 34.5000000, 135.4000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90401, 'Izumi', 'Izumi', 'Izumi,he quan,和泉', 34.4833300, 135.4333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90402, 'Izumi', 'Izumi', 'Izumi,chu shui,Изуми,出水', 32.0833300, 130.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90403, 'Iwatsuki', 'Iwatsuki', 'Iwatsuki,iwatsuki,yan gui,いわつき,イワツキ,岩槻', 35.9647400, 139.6964400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90404, 'Iwata', 'Iwata', 'Ivata,Iwata,Iwata-chhi,Iwata-chhī,awata,aywata  shyzwywka,iwata si,pan tian,pan tian shi,xi wa ta,İvata,Івата,Ивата,إواتا,ایواتا، شیزوئوکا,อิวะตะ,磐田,磐田市,이와타 시', 34.7000000, 137.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90405, 'Iwakura', 'Iwakura', 'Iwakura,yan cang,岩倉', 35.2833300, 136.8666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90406, 'Iwakuni', 'Iwakuni', 'IWK,Ivakuni,Iwakuni,Iwakuni-chhi,Iwakuni-chhī,Ngam-koet-su,Ngàm-koet-sṳ,awakwny,aywakwny  yamagwchy,iwakuni si,yan guo,yan guo shi,Івакуні,Ивакуни,איוואקוני,إواكوني,ایواکونی، یاماگوچی,ივაკუნი,岩国,岩国市,岩國市,이와쿠니 시', 34.1629700, 132.2200000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90407, 'Iwai', 'Iwai', '', 36.0500000, 139.9000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90408, 'Iwade', 'Iwade', 'Iwade,yan chu,岩出', 34.2500000, 135.3166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90409, 'Itsukaichi', 'Itsukaichi', 'Itsukaichi', 35.7252800, 139.2177800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90410, 'Itoman', 'Itoman', 'Ichuman,Itoman,Shionja,Shunja,Sunja,Sunza,itoman,mi man,いとまん,糸満', 26.1264700, 127.6691800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90411, 'Itoigawa', 'Itoigawa', 'Itoigava,Itoigawa,Itoigawa-chhi,Itoigawa-chhī,Itoikawa,atwyghawa,itoigawa si,mi yu chuan,mi yu chuan shi,Ітоїґава,Итоигава,إتويغاوا,ایتویی‌گاوا، نیگاتا,糸魚川,糸魚川市,이토이가와 시', 37.0333300, 137.8500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90412, 'Itō', 'Ito', 'Itas,Ito,Ito-chhi,Itó,Itô-chhī,Itō,atw,aytw  shyzwywka,ito si,xi to,yi dong,yi dong shi,Іто,Ито,إتو,ایتو، شیزوئوکا,อิโต,伊東,伊東市,이토 시', 34.9666700, 139.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90413, 'Itami', 'Itami', 'Itami,Itami-chhi,Itami-chhī,Itan,atamy,aytamy  hywgw,itami si,xi ta mi,yi dan,yi dan shi,İtami,Ітамі,Итами,إتامي,ایتامی، هیوگو,อิตะมิ,伊丹,伊丹市,이타미 시', 34.7842700, 135.4012600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90414, 'Ishiki', 'Ishiki', 'Ishiki,Isshiki', 34.8000000, 137.0166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90415, 'Ishikawa', 'Ishikawa', 'Ishikawa,Ishiza,Isikava,Исикава', 26.4233300, 127.8213900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90416, 'Ishii', 'Ishii', 'Ishii,Isii,shi jing,Исии,石井', 34.0675200, 134.4420800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90417, 'Ishige', 'Ishige', 'Ishige,Moto-ishige', 36.1166700, 139.9666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90418, 'Ishigaki', 'Ishigaki', 'ISG,Ishigachi,Ishigaki,Ishigaki-jima,Isigaki,Isigaki-chhi,Isigaki-chhī,Isigakis,Išigakis,Shika,ashyghaka,ayshygaky  awkynawa,ishigaki,isigaki si,shi yuan,shi yuan shi,İshigaki,Ішіґакі,Исигаки,Ишигаки,إشيغاكا,ایشیگاکی، اوکیناوا,いしがき,石垣,石垣市,이시가키 시', 24.3447800, 124.1571700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90419, 'Isesaki', 'Isesaki', 'Iseaki,Isehsaki,Isesaki,Isesaki-chhi,Isesaki-chhī,Isezaki,asysaky,asysaky  gwnma,isesaki si,xi sea saki,yi shi qi,yi shi qi shi,Ісесакі,Исесаки,Исэсаки,إسيساكي,اسیساکی، گونما,ایسه‌ساکی، گونما,อิเซะซะกิ,伊勢崎,伊勢崎市,이세사키 시', 36.3166700, 139.2000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90420, 'Isehara', 'Isehara', 'Isehara,yi shi yuan,伊勢原', 35.3993200, 139.3101900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90421, 'Ise', 'Ise', 'Ise,Ise-chhi,Ise-chhī,Iseh,Isė,Udiyamada,Uji,Uji-Yamada,Uziyamada,Yamada,aysh,aysh  myh,ise,ise si,yi shi,yi shi shi,Ісе,Исе,Исэ,إيسه,ایسه، میه,ისე,伊勢,伊勢市,이세 시', 34.4833300, 136.7000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90422, 'Isawa', 'Isawa', 'Isawa', 35.6500000, 138.6333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90423, 'Isahaya', 'Isahaya', 'Isahaja,Isahara,Isahaya,Isahaya-chhi,Isahaya-chhī,Isakhaja,aysahaya,aysahaya  nagazaky,dong zao,dong zao shi,isahaya si,jian zao,jian zao shi,Ісахая,Исахая,Исахаја,Исаҳая,إيساهايا,ایساهایا، ناگازاکی,諌早,諌早市,諫早,諫早市,이사하야 시', 32.8411100, 130.0430600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90424, 'Inuyama', 'Inuyama', 'Inujama,Inuyama,Inuyama-chhi,Inuyama-chhī,Inuyama-cho,Inuyama-chō,anwyama  aytshy,aynwyama  aychy,inuyama si,quan shan,quan shan shi,xinu ya ma,Інуяма,Инуяма,إنوياما، آيتشي,انویامہ,اینویاما، آیچی,อินุยะมะ,犬山,犬山市,이누야마 시', 35.3799500, 136.9429500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90425, 'Ino', 'Ino', 'Ino,Inocho,Inochō,Ино', 33.5500000, 133.4333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90426, 'Innoshima', 'Innoshima', '', 34.2833300, 133.1833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90427, 'Inazawa', 'Inazawa', 'Inadzava,Inasawa,Inasawacho,Inasawachō,Inazava,Inazawa,Inazawa-chhi,Inazawa-chhī,Inazawacho,Inazawachō,anazawa,anazawa  aychy,aynazawa  aychy,dao ze,dao ze shi,inajawa si,Інадзава,Инадзава,Иназава,إنازاوا,انازاوا، ایچی,انازاوہ,اینازاوا، آیچی,稲沢,稲沢市,稻澤市,이나자와 시', 35.2500000, 136.7833300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90428, 'Ina', 'Ina', 'Ina,Ina-chhi,Ina-chhī,ana,ayna  naganw,ina si,xin a,yi na,yi na shi,Іна,Ина,Ինա,إنا,اینا، ناگانو,อินะ,伊那,伊那市,이나 시', 35.8275600, 137.9537800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90429, 'Imarichō-kō', 'Imaricho-ko', 'Imari,Imaricho-ko,Imarichō-kō,Imarimachi,yi wan li ding jia,Имари,伊万里町甲', 33.2736200, 129.8787700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90430, 'Imaichi', 'Imaichi', '', 36.7166700, 139.6833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90431, 'Ikoma', 'Ikoma', 'Ikoma,Ikoma-chhi,Ikoma-chhī,Ikuma,akwma,aykwma  nara,ikoma si,sheng ju,sheng ju shi,xi koa ma,Ікома,Икома,إكوما,ایکوما، نارا,อิโกะมะ,生駒,生駒市,이코마 시', 34.6833300, 135.7000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90432, 'Ikeda', 'Ikeda', 'Ikeda,chi tian,chi tian shi,Икеда,池田,池田市', 34.8220800, 135.4298000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90433, 'Ikedachō', 'Ikedacho', 'Ikeda,Ikedacho,Ikedachō,chi tian ding,池田町', 34.0284900, 133.8061600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90434, 'Ijūin', 'Ijuin', 'Ijuin,Ijūin,Izyuin,Izyūin', 31.6166700, 130.4000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90435, 'Iizuka', 'Iizuka', 'Iidzuka,Iisuka,Iizuka,Iizuka-chhi,Iizuka-chhī,Izuka,ayzwka  fwkwywka,fan zhong,fan zhong shi,ijeuka si,lyzwka,Іїдзука,Изука,Иидзука,Иизука,ایزوکا، فوکوئوکا,ليزوكا,飯塚,飯塚市,이즈카 시', 33.6365400, 130.6867800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90436, 'Iiyama', 'Iiyama', 'Iiyama,Iyama,fan shan,飯山', 36.8500000, 138.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90437, 'Iida', 'Iida', 'Ida,Iida,Iida-chhi,Iida-chhī,ayda  naganw,ayyda,fan tian,fan tian shi,ida si,xi da,Іїда,Ида,Иида,Իիդա,إييدا,ایدا، ناگانو,อีดะ,飯田,飯田市,이다 시', 35.5196500, 137.8207400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90438, 'Ichinomiya', 'Ichinomiya', 'Ichinomija,Ichinomiya,Itinomija,Itinomiya,Itinomiya-chhi,Itinomiya-chhī,Owari-ichinomiya,achynwmya  aychy,aychynwmya  aychy,aytshynwmya,ichinomiya si,xi chi noa mi ya,yi gong,yi gong shi,İtinomiya,Ітіномія,Итиномия,Ичиномия,Ичиномија,إيتشينوميا,اچینومیا، ایچی,ایچینومیا، آیچی,อิชิโนะมิยะ,იტინომია,一宮,一宮市,이치노미야 시', 35.3000000, 136.8000000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90439, 'Ibusuki', 'Ibusuki', 'Ibusuki,Ibusuki-chhi,Ibusuki-chhī,aybwswky,aybwswky  kagwshyma,ibuseuki si,zhi su,zhi su shi,Ібусукі,Ибусуки,إيبوسوكي,ایبوسوکی، کاگوشیما,指宿,指宿市,이부스키 시', 31.2333300, 130.6500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90440, 'Ibaraki', 'Ibaraki', 'IBR,Ibaragi,Ibaraki,Ibaraki-chhi,Ibaraki-chhī,abaraky,aybaraky  awsaka,ci cheng shi,ci mu,ci mu shi,ibalaki si,xiba raki,Ібаракі,Ибараки,إباراكي,ایباراکی، اوساکا,อิบะระกิ,იბარაკი,茨城市,茨木,茨木市,이바라키 시', 34.8164100, 135.5682800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90441, 'Ibara', 'Ibara', 'Ibara,Ibara-chhi,Ibara-chhī,Ihara,abara,aybara  awkayama,ibala si,jing yuan,jing yuan shi,Ібара,Ибара,إبارا,ایبارا، اوکایاما,井原,井原市,이바라 시', 34.6000000, 133.4666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90442, 'Hotaka', 'Hotaka', '', 36.3396000, 137.8825400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90443, 'Honjō', 'Honjo', 'Hondyo,Honjo,Honjō,Honzyo-chhi,Honzyô-chhī,Khondz''o,Khondzjo,ben zhuang,ben zhuang shi,honjo si,hwnjw,hwnjw  saytama,Хондзьо,Хондзё,Ҳонҷо,هونجو,هونجو، سایتاما,本庄,本庄市,혼조 시', 36.2378000, 139.1902300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90444, 'Hondomachi-hondo', 'Hondomachi-hondo', 'Hondo,Hondomachi-hondo,Khondo,ben du ding ben du,hondomachihondo,Хондо,ほんどまちほんど,ホンドマチホンド,本渡町本渡', 32.4599300, 130.1671300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90445, 'Hōfu', 'Hofu', 'Bofu,Bohu,Bōfu,Bōhu,Hofu,Hōfu,fang fu,防府', 34.0500000, 131.5666700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90446, 'Hitoyoshi', 'Hitoyoshi', 'Hitoyoshi,Hitoyosi,Hitoyosi-chhi,Hitoyosi-chhī,Khitojoshi,Khitojosi,hitoyosi si,hytwywshy,hytwywshy  kwmamwtw,ren ji,ren ji shi,Хитоёси,Хітойоші,Ҳитоёши,هيتويوشي,هیتویوشی، کوماموتو,人吉,人吉市,히토요시 시', 32.2166700, 130.7500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90447, 'Hita', 'Hita', 'Hida,Hita,Hita-chhi,Hita-chhī,Khita,Khity,hita si,hyta  awyta,hyta  awyyta,ri tian,ri tian shi,Хита,Хиты,Хіта,Ҳита,هيتا، أويتا,هیتا، اوئیتا,日田,日田市,히타 시', 33.3213000, 130.9409800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90448, 'Hisai-motomachi', 'Hisai-motomachi', 'Hisai,Hisai-motomachi,jiu ju yuan ding,久居元町', 34.6666700, 136.4666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90449, 'Hiroshima', 'Hiroshima', 'Chirosima,HIJ,Hiroshima,Hiroshima-shi,Hiroshimashi,Hirosima,Hirosimo,Hiroxima,Hiroxima - guang dao shi,Hiroxima - 広島市,Hiroŝimo,Hiroşima,Hirošima,Hiroșima,Khiroshima,Khirosima,canghwad hi roa chi ma,guang dao,guang dao shi,hi ro chi ma,hilosima si,hiroshima,hiroshimashi,hirosima,hyrwshyma,hyrwsymh,Χιροσίμα,Хиросима,Хирошима,Хіросіма,הירושימה,هيروشيما,هیروشیما,हिरोशिमा,จังหวัดฮิโระชิมะ,ฮิโรชิมา,ჰიროსიმა,ჰიროშიმა,ひろしま,ひろしまし,ヒロシマ,ヒロシマシ,広島,広島市,廣島市,히로시마 시', 34.4000000, 132.4500000, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90450, 'Hiratsuka', 'Hiratsuka', 'Hiracuka,Hiratsuka,Hiratuka,Hiratuka-chhi,Hiratuka-chhī,Khiracuka,hi ra suk a,hilasseuka si,hyratswka,hyratswka  kanagawa,ping zhong,ping zhong shi,Хирацука,Хірацука,Ҳиратсука,هيراتسوكا,هیراتسوکا، کاناگاوا,ہیراتسوکا، کاناگاوا,ฮิระสึกะ,ჰირაცუკა,平塚,平塚市,히라쓰카 시', 35.3278500, 139.3373500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90451, 'Hiratachō', 'Hiratacho', 'Hirata,Hiratacho,Hiratachō,ping tian ding,平田町', 35.4333300, 132.8166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90452, 'Hirara', 'Hirara', 'Hirara,Taira,hirara,ping liang,ひらら,平良', 24.8037900, 125.3022200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90453, 'Hirakata', 'Hirakata', 'Hirakata,hilakata si,hyrakata  awsaka,mei fang,mei fang shi,هيراكاتا، أوساكا,枚方,枚方市,히라카타 시', 34.8135200, 135.6491400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90454, 'Hirado', 'Hirado', 'Hirado,Hirado-chhi,Hirado-chhī,Hirato,Khirado,hi ra doa,hilado si,hyradw,hyradw  nagazaky,ping hu,ping hu shi,Хирадо,Хірадо,Ҳирадо,היראדו,هيرادو,هیرادو، ناگازاکی,ฮิระโดะ,平戶市,平戸,平戸市,히라도 시', 33.3685300, 129.5524700, 'JP', '2013-08-17', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90455, 'Hioki', 'Hioki', 'Hioki-chhi,Hioki-chhī,Khioki,hioki si,hywky,hywky  kagwshyma,ri zhi,ri zhi shi,Хиоки,Хіокі,Ҳиоки,هيوكي,هیوکی، کاگوشیما,日置,日置市,히오키 시', 31.5833300, 130.3500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90456, 'Hino', 'Hino', 'Hinas,Hino,Hino-chhi,Hino-chhī,Khino,hi noa,hino si,hynw,hynw  twkyw,ri ye,ri ye shi,Хино,Хіно,Ҳино,Հինո,هينو,هینو، توکیو,ฮิโนะ,日野,日野市,히노 시', 35.6730600, 139.4002800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90457, 'Hino', 'Hino', 'Hino', 35.0000000, 136.2500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90458, 'Himimachi', 'Himimachi', 'bi mei ding,比美町', 36.8560900, 136.9885000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90459, 'Himeji', 'Himeji', 'Gorad Khimedzi,Hime,Himeci,Himedi,Himegi,Himeji,Himezi,Himezi-chhi,Himezi-chhī,Himeĝi,Khimedzhi,Khimedzi,Khimehdzi,hi mea ci,himeji si,hymgy,hymyjy,ji lu shi,zhen lu,Горад Хімедзі,Химеджи,Химедзи,Химеџи,Химэдзи,Хімедзі,Ҳимеҷи,הימגי,هيميجي,هیمه‌جی، هیوگو,ہیمیجی، ہیوگو,ฮิเมะจิ,姫路,姫路市,姬路市,히메지 시', 34.8166700, 134.7000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90460, 'Hikone', 'Hikone', 'Hikone,Khikoneh,yan gen,yan gen shi,Хиконэ,彦根,彦根市', 35.2500000, 136.2500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90461, 'Hiji', 'Hiji', 'Higi,Hiji,Hinode,Hizi,ri chu,日出', 33.3708100, 131.5302500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90462, 'Higashi-ōsaka', 'Higashi-osaka', 'Higashi-osaka,Higashi-ōsaka,Higashiosaka,Higashiōsaka,Higasiosaka,Higaŝiosaka,Osaca Orientalis,dong da ban,dong da ban shi,higasiosaka si,hyghashywsaka  awsaka,هيغاشيوساكا، أوساكا,東大阪,東大阪市,히가시오사카 시', 34.6666700, 135.5833300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90463, 'Hekinan', 'Hekinan', 'Hekinan,Hekinan-chhi,Hekinan-chhī,Khekinan,bi nan,bi nan shi,hekinan si,hkynan  aychy,hykynan,Хекинан,Хекинан қаласы,Хекінан,Ҳекинан,هيكينان,هکینان، آیچی,ہیکینان,碧南,碧南市,헤키난 시', 34.8833300, 136.9833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90464, 'Heda', 'Heda', 'Heda,Khehda,Toda,hu tian,Хэда,戸田', 34.9627700, 138.7854300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90465, 'Hayama', 'Hayama', 'Hayama,Khajama,hayama,ye shan,Хаяма,はやま,ハヤマ,葉山', 35.2765100, 139.5773300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90466, 'Hatsukaichi', 'Hatsukaichi', 'Hacukaici,Hacukaiĉi,Hatsukaichi,Hatukaiti,Hatukaiti-chhi,Hatukaiti-chhī,Khacukaichi,Khacukaiti,hasseukaichi si,hasu ki chi,hatswkaaychy  hyrwshyma,hatswkayjy,nian ri,nian ri shi shi,Хацукаити,Хацукаичи,Хацукаїті,Ҳатсукаичи,هاتسوکاایچی، هیروشیما,هاتسوکایجي,ฮะสึไกชิ,廿日,廿日市市,하쓰카이치 시', 34.3500000, 132.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90467, 'Hatogaya-honchō', 'Hatogaya-honcho', 'Hatagayacho,Hatagayachō,Hatogaya,Hatogaya-honcho,Hatogaya-honchō,Hatogayamachi,hatogayahonchou,jiu~ke gu ben ding,はとがやほんちょう,ハトガヤホンチョウ,鳩ヶ谷本町', 35.8331400, 139.7425000, 'JP', '2014-02-17', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90468, 'Hashimoto', 'Hashimoto', 'Hashimoto,Hasimoto,Hasimoto-chhi,Hasimoto-chhī,Haŝimoto,Khasimoto,hashymwtw,hashymwtw  wakayama,hasimoto si,qiao ben,qiao ben shi,Хасимото,Хасімото,Ҳашимото,هاشيموتو,هاشیموتو,هاشیموتو، واکایاما,橋本,橋本市,하시모토 시', 34.3166700, 135.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90469, 'Hanyū', 'Hanyu', 'Hanyu,Hanyu-chhi,Hanyû-chhī,Hanyū,Khan''juj,Khanju,hanya,hanyu si,hanyw,hanyw  saytama,yu sheng,yu sheng shi,Ханьюй,Ханю,Ҳаню,هانيا,هانیو,هانیو، سایتاما,羽生,羽生市,하뉴 시', 36.1666700, 139.5333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90470, 'Hannō', 'Hanno', 'Channo,Hanno,Hanno-chhi,Hanno-chhī,Hannō,Khanno,fan neng,fan neng shi,hanno si,hanw,Χάννο,Ханно,Ҳанноу,هانو,هان‌نو,هان‌نو، سایتاما,飯能,飯能市,한노 시', 35.8519400, 139.3180600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90471, 'Handa', 'Handa', 'Handa,Handa-chhi,Handa-chhī,Khanda,Manda,ban tian,ban tian shi,handa,handa si,handa  aychy,Ханда,Ханда қаласы,هاندا,هاندا، آیچی,ہانڈا، ایچی,ہینڈا,半田,半田市,한다 시', 34.8833300, 136.9333300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90472, 'Hamanoichi', 'Hamanoichi', 'Hama-no-iti,Hamanoichi,Hayato', 31.7166700, 130.7333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90473, 'Hamamatsu', 'Hamamatsu', 'Hamamacu,Hamamatsu,Hamamatsu City,Hamamatsu-shi,Hamamatu,Hamamatu-chhi,Hamamatu-chhī,Khamamacu,bang song,bang song shi,bin song shi,ha ma masu,hamamasseu si,hamamatsw,hamamatsw  shyzwywka,Хамамацу,Хамамацү,Ҳамаматсу,هاماماتسو,هاماماتسو، شیزوئوکا,ہاماماتسو,ฮะมะมะสึ,浜松,浜松市,滨松市,하마마쓰 시', 34.7000000, 137.7333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90474, 'Hamakita', 'Hamakita', 'Hamakita', 34.8000000, 137.7833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90475, 'Hamada', 'Hamada', 'Hamada,Hamada-chhi,Hamada-chhī,Khamada,bang tian,bang tian shi,bin tian shi,hamada,hamada si,hamada  shymanh,Хамада,Ҳамада,هامادا,هامادا، شیمانه,浜田,浜田市,濱田市,하마다 시', 34.8833300, 132.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90476, 'Hakui', 'Hakui', 'Hagui,Hakui,yu za,羽咋', 36.8833300, 136.7833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90477, 'Hakone', 'Hakone', 'Hakone,Khakone,ha koanea,hakone jeong,hakwnh,xiang gen,xiang gen ding,Хаконе,هاكونه,ฮะโกะเนะ,ក្រុងហាកុណិ,箱根,箱根町,하코네 정', 35.1894500, 139.0264900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90478, 'Haibara-akanedai', 'Haibara-akanedai', 'Hagihara,Hagiwara,Haibara,Haibara-akanedai,zhen yuanakane tai,榛原あかね台', 34.5333300, 135.9500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90479, 'Hagi', 'Hagi', 'Hagi,Hagi-chhi,Hagi-chhī,Khagi,haghy,hagi si,hagy,hagy  yamagwchy,qiu,qiu shi,Хаги,Хаґі,Ҳаги,Հագի,هاغي,هاگی,هاگی، یاماگوچی,萩,萩市,하기 시', 34.4000000, 131.4166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90480, 'Katsuren-haebaru', 'Katsuren-haebaru', 'Haebaru,Hiebaru,Katsuren-haebaru,sheng lian nan feng yuan,勝連南風原', 26.3329400, 127.8740300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90481, 'Hadano', 'Hadano', 'Hadano,Hadano-chhi,Hadano-chhī,Hatano,Hatano-machi,Khadano,ha da noa,hadano si,hadanw,hadanw  kanagawa,qin ye,qin ye shi,Хадано,Ҳадано,هادانو,هادانو، کاناگاوا,ฮะดะโนะ,秦野,秦野市,하다노 시', 35.3711100, 139.2236100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90482, 'Hachiōji', 'Hachioji', 'Hachioji,Hachiouji,Hachiōji,Haciodzis,Haciogi,Hatiozi,Hatiozi-chhi,Hatiôzi,Hatiôzi-chhī,Haĉioĝi,Hačiodžis,Khachiodzhi,Khachiodzi,Khatiodzi,ba wang zi,ba wang zi shi,ha chi xo ci,hachioji si,hatshywwjy,Хатиодзи,Хатіодзі,Хачиоджи,Хачиоџи,Ҳачиоҷи,هاتشيؤوجي,هاچی‌اوجی، توکیو,ہاچیوجی، ٹوکیو,ฮะชิโอจิ,八王子,八王子市,하치오지 시', 35.6558300, 139.3238900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90483, 'Ōmihachiman', 'Omihachiman', 'Omi-Khachiman,Omihachiman,Omihachiman-shi,Omihatiman-chhi,Omikhatiman,awmyhachyman  shyga,awmyhatshyman,jin jiang ba fan,jin jiang ba fan shi,omihachiman si,Ômihatiman-chhī,Ōmihachiman-shi,Омихатиман,Омі-Хачіман,Оумиҳачиман,أوميهاتشيمان,اومیهاچیمان، شیگا,近江八幡,近江八幡市,오미하치만 시', 35.1286100, 136.0976000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90484, 'Gyōda', 'Gyoda', 'G''oda,Gjoda,Gyoda,Gyoda-chhi,Gyôda-chhī,Gyōda,ghywda,gyoda si,gywda  saytama,xing tian,xing tian shi,Гёда,Ґьода,غيودا,گیودا، سایتاما,行田,行田市,교다 시', 36.1407400, 139.4601100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90485, 'Gushikawa', 'Gushikawa', 'Geshicha,Geshichā,Gushichaa,Gushikawa,Gusikawa,ju zhi chuan,具志川', 26.3593700, 127.8673500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90486, 'Gōtsuchō', 'Gotsucho', 'Gatsu,Gotsu,Gotsucho,Gotu,Gozu,Gōtsu,Gōtsuchō,Gōtu,Gōzu,jiang jin,jiang jin ding,江津,江津町', 35.0085600, 132.2257000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90487, 'Gotenba', 'Gotenba', 'Gotemba,Gotenba,Kyu-gotemba,Kyū-gotemba,yu dian chang,Готемба,御殿場', 35.3185900, 138.9434300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90488, 'Gosen', 'Gosen', 'Gosen,wu quan,Госен,五泉', 37.7333300, 139.1666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90489, 'Gose', 'Gose', 'Gose,Gose-chhi,Gose-chhī,Gosecho,Gosho,Gosé,Goze,Gōsechō,ghwsy,gose si,gwsh  nara,yu suo,yu suo shi,Госе,Ґосе,غوسي,گوسه، نارا,御所,御所市,고세 시', 34.4500000, 135.7333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90490, 'Gojō', 'Gojo', 'Godyo,Godz''o,Godzjo,Gogo,Goio,Goiō,Gojo,Gojō,Gozyo-chhi,Gozyô-chhī,Goĝo,ghwjw,gojo si,gwjw  nara,koa co,wu tiao,wu tiao shi,Годзё,Гоҷо,Ґодзьо,غوجو,گوجو، نارا,โกะโจ,五條,五條市,고조 시', 34.3500000, 135.7000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90491, 'Gōdo', 'Godo', 'Goda,Godo,Godo-cho,Gōdo,Gōdō-chō,Года', 35.4166700, 136.6000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90492, 'Gobō', 'Gobo', 'Gobo,Gobo-chhi,Gobô-chhī,Gobō,Hidaka,ghwbw,gobo si,gwbw  wakayama,yu fang shi,Гобо,Ґобо,غوبو,گوبو، واکایاما,御坊市,고보 시', 33.8833300, 135.1500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90493, 'Ginowan', 'Ginowan', 'Chinon,Chinōn,Ginowan,Jinon,Jinōn,ginowan,ginowan si,yi ye wan,yi ye wan shi,ぎのわん,宜野湾,宜野湾市,宜野灣市,기노완 시', 26.2626500, 127.7614700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90494, 'Gifu-shi', 'Gifu-shi', 'Gifu,Gifu City,Gifu-shi,Gihu,gifushi,gihu si,qi fu,qi fu shi,Гифу,ぎふし,岐阜,岐阜市,기후 시', 35.4229100, 136.7603900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90495, 'Gamagōri', 'Gamagori', 'Gamagori,Gamagori-chhi,Gamagôri-chhī,Gamagōri,gamagoli si,gamagwry,gamagwry  aychy,ghamaghwry,pu jun,pu jun shi,Гамагори,Ґамаґорі,غاماغوري,گاماگوری,گاماگوری، آیچی,蒲郡,蒲郡市,가마고리 시', 34.8333300, 137.2333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90496, 'Futtsu', 'Futtsu', 'Fuccu,Futtso,Futtsu,Huttu-chhi,Huttu-chhī,fu jin,fu jin shi,fut su,futtsu,fwtsw  chyba,fwtsw  tshyba,hus-sseu si,Футтсу,Фуццу,فوتسو، تشيبا,فوتسو، چیبا,ฟุตสึ,ふっつ,フッツ,富津,富津市,훗쓰 시', 35.3108000, 139.8187700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90497, 'Honchō', 'Honcho', 'Funabashi,Funabasi,Funabaŝi,Funabaşi,Furabeshi,Honcho,Honchō,Hunabasi,Hunabasi-chhi,Hunabasi-chhī,ben ding,chuan qiao,chuan qiao shi,fu naba chi,fwnabashy,fwnabashy  chyba,hunabasi si,Фунабаси,Фунабасі,Фунабаши,فوناباشي,فوناباشی، چیبا,ฟุนะบะชิ,本町,船橋,船橋市,후나바시 시', 35.7012900, 139.9864800, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90498, 'Fukuyama', 'Fukuyama', 'Fukujama,Fukuyama,Hukuyama,Hukuyama-chhi,Hukuyama-chhī,fu ku ya ma,fu shan,fu shan shi,fwkwyama,fwkwyama  hyrwshyma,hukuyama si,Фукуяма,Фукујама,فوکویاما,فوکویاما، هیروشیما,فوکویاما، ہیروشیما,ฟุกุยะมะ,福山,福山市,후쿠야마 시', 34.4833300, 133.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90499, 'Fukuroi', 'Fukuroi', 'Fukuroi,Fukuroj,Hukuroi-chhi,Hukuroi-chhī,Pukuroi,dai jing,dai jing shi,fu ku roaxi,fwkwrwyy  shyzwywka,fwkwry,hukuloi si,phukro''i,Фукурои,Фукурой,فوكوري,فوکورویی، شیزوئوکا,फुक्रोई,ฟุกุโระอิ,袋井,袋井市,후쿠로이 시', 34.7500000, 137.9166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90500, 'Fukura', 'Fukura', 'Fukura,Hukura,fu liang,福良', 34.2576500, 134.7153500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90501, 'Fukuoka', 'Fukuoka', 'FUK,Fucuoca,Fukuoka,Fukuoka-shi,Fukuokashi,Hukuoka,fu gang,fu gang shi,fukuoka,fukuokashi,fwkwka,hukuoka si,Фукуока,فوكوكا,ふくおか,ふくおかし,フクオカ,フクオカシ,福岡,福岡市,후쿠오카 시', 33.6000000, 130.4166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90502, 'Fukumitsu', 'Fukumitsu', 'Fukumitsu,Fukumitsumachi,fu guang,福光', 36.5575100, 136.8694500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90503, 'Nishifukuma', 'Nishifukuma', 'Fukuma,Nishifukuma,xi fu jian,西福間', 33.7662700, 130.4746100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90504, 'Fukui-shi', 'Fukui-shi', 'FKJ,Fukuj,fu jing,fu jing shi,fukuishi,Фукуй,ふくいし,福井,福井市', 36.0644300, 136.2225700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90505, 'Fukuechō', 'Fukuecho', 'FUJ,Fukae,Fukaye,Fukue,Fukuecho,Fukuechō,Fukuego,Hukae,Hukue,fu jiang ding,福江町', 32.6973200, 128.8456100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90506, 'Fukuchiyama', 'Fukuchiyama', 'Fukuchijama,Fukuchiyama,Fukucijama,Fukutijama,Fukučijama,Hukutiyama,fu ku chi ya ma,fu zhi shan,fu zhi shan shi,fwkwtshyama,hukuchiyama si,Фукутияма,Фукучияма,Фукучіяма,פוקושיאמה,فوكوتشياما,فوکوچی‌یاما، کیوتو,ฟุกุชิยะมะ,福知山,福知山市,후쿠치야마 시', 35.3000000, 135.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90507, 'Fukiage-fujimi', 'Fukiage-fujimi', 'Fukiage,Fukiage-fujimi,chui shang fu shi jian,吹上富士見', 36.1000000, 139.4500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90508, 'Fukayachō', 'Fukayacho', 'Fukaya,Fukayacho,Fukayachō,shen gu ding,深谷町', 36.2000000, 139.2833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90509, 'Fujisawa', 'Fujisawa', 'Fudzhisava,Fudzisava,Fudžisava,Fujisava,Fujisawa,Gorad Fudzisava,Huzisawa-chhi,Huzisawa-chhī,Pudyisawa,fu ci sa wa,fwjysawa,fwjysawa  kanagawa,hujisawa si,teng ze,teng ze shi,Горад Фудзісава,Фуджисава,Фудзисава,Фудзісава,Фуџисава,Фуҷисава,فوجيساوا,فوجیساوا، کاناگاوا,ฟุจิซะวะ,藤沢,藤沢市,藤澤市,후지사와 시', 35.3492600, 139.4766600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90510, 'Fujioka', 'Fujioka', 'Fudzioka,Fujioka,Фудзиока', 36.2500000, 139.6500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90511, 'Fujioka', 'Fujioka', 'Fudzioka,Fujioka,Huzioka-chhi,Huzioka-chhī,fwjywka,hujioka si,teng gang,teng gang shi,Фудзиока,Фудзіока,Фуҷиока,فوجيوكا,فوجی‌اوکا، گونما,藤岡,藤岡市,후지오카 시', 36.2462400, 139.0720400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90512, 'Fujinomiya', 'Fujinomiya', 'Fudzinomija,Fudžinomija,Fujimiya,Fujinomija,Fujinomiya,Huzinomiya-chhi,Huzinomiya-chhī,Omiya,Pudyinomiya,fu ci noa mi ya,fu shi gong,fu shi gong shi,fwjynwmya,hujinomiya si,Ōmiya,Фудзиномия,Фудзіномія,Фуџиномија,Фуҷиномия,فوجينوميا,فوجی‌نومیا، شیزوئوکا,ฟุจิโนะมิยะ,富士宮,富士宮市,후지노미야 시', 35.2166700, 138.6166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90513, 'Fujieda', 'Fujieda', 'Fudziehda,Fujieda,teng zhi,teng zhi shi,Фудзиэда,藤枝,藤枝市', 34.8666700, 138.2666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90514, 'Fuji', 'Fuji', 'Foutzi,Fudzhi,Fudzi,Fudzis,Fudži,Fudžis,Fuji,Huzi-chhi,Huzi-chhī,fu ci,fu shi,fu shi shi,fwjy,fwjy  shyzwywka,fywjy  shyzwka,huji si,phuji,Φούτζι,Фуджи,Фудзи,Фудзі,Фуџи,Фуҷи,Фүжи,فوجي,فوجی، شیزوئوکا,فیوجی، شیزوکا,ফুজি,ฟุจิ,富士,富士市,후지 시', 35.1666700, 138.6833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90515, 'Fuchūchō', 'Fuchucho', 'Fuchu,Fuchucho,Fuchū,Fuchūchō,fu zhong,fu zhong ding,Фучу,府中,府中町', 34.5735000, 133.2351300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90516, 'Enzan', 'Enzan', 'Enzan', 35.7000000, 138.7333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90517, 'Daitōchō', 'Daitocho', 'Daito,Daitocho,Daitō,Daitōchō,da dong,da dong ding,大東,大東町', 34.7137800, 135.6203300, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90518, 'Chōfugaoka', 'Chofugaoka', 'Chofu,Chofugaoka,Chōfu,Chōfugaoka,diao bu~ke qiu,調布ヶ丘', 35.6592400, 139.5483700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90519, 'Chiryū', 'Chiryu', 'Chirju,Chiryu,Chiryu-cho,Chiryū,Chiryū-chō,Csirju,Csirjú,Tirju,Tiryu-chhi,Tiryū-chhī,Tsiryu,chyrw  aychy,chyryw  aychy,jilyu si,tshyryw,zhi li,zhi li shi,Тирю,Тірю,Чирю,تشيريو,چیرو، آیچی,چیریو، ایچی,知立,知立市,지류 시', 35.0000000, 137.0333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90520, 'Chino', 'Chino', 'Chino,Cino,Tino,Tino-chhi,Tino-chhī,chi noa,chynw  naganw,jino si,mao ye,mao ye shi,tshynw,Ĉino,Тино,Тіно,Чино,Տինո,تشينو,چینو، ناگانو,ชิโนะ,茅野,茅野市,지노 시', 35.9944000, 138.1542800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90521, 'Chikushino-shi', 'Chikushino-shi', 'chikushino,zhu zi ye,zhu zi ye shi,筑紫野,筑紫野市', 33.4963100, 130.5156000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90522, 'Chigasaki', 'Chigasaki', 'Chigaraki,Chigasaki,Cigasakis,Tigasaki,Tigasaki-chhi,Tigasaki-chhī,chi nga saki,chygasaky  kanagawa,jigasaki si,mao qi shi,maoke qi,mao~ke qi,mao~ke qi shi,tshyghasaky,Čigasakis,Тигасаки,Тіґасакі,Чигасаки,تشيغاساكي,چیگاساکی، کاناگاوا,ชิงะซะกิ,茅ケ崎,茅ヶ崎,茅ヶ崎市,茅崎市,지가사키 시', 35.3363800, 139.4043400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90523, 'Chichibu', 'Chichibu', 'Chichibu,Cicibu,Titibu,Titibu-chhi,Titibu-chhī,Titubunomiya,Tsitsibu,chi chi bu,chychybw  saytama,jichibu si,tshytshybw,zhi fu,zhi fu shi,Čičibu,Титибу,Тітібу,Чичибу,تشيتشيبو,چیچیبو، سایتاما,ชิชิบุ,秩父,秩父市,지치부 시', 35.9902800, 139.0763900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90524, 'Chatan', 'Chatan', 'Chatan,Tyatan,bei gu,北谷', 26.3094800, 127.7702400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90525, 'Beppu', 'Beppu', 'BPU,Behppu,Beppu,Beppu-chhi,Beppu-chhī,Bepu,bespu si,bie fu,bie fu shi,bpw  awyyta,bybw,Беппу,Бепу,Бэппу,بيبو,بپو، اوئیتا,ბეპუ,別府,別府市,벳푸 시', 33.2794500, 131.4975100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90526, 'Ayabe', 'Ayabe', 'Ajabe,Ajabė,Ayabe,Ayabe-chhi,Ayabe-chhī,ayabe si,ayabh,ayabh  kywtw,ling bu,ling bu shi,Аябе,איאבה,آيابه,آیابه، کیوتو,綾部,綾部市,아야베 시', 35.3000000, 135.2500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90527, 'Awara', 'Awara', 'Avara,Awara-chhi,Awara-chhī,awala si,awara,awara shi,awara  fwkwyy,lu yuan shi,Авара,آوارا، فوکوئی,أوارا,あわら,あわら市,蘆原市,아와라 시', 36.2230900, 136.1923600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90528, 'Atami', 'Atami', 'Atami,Atami-chhi,Atami-chhī,Atamis,atami si,atamy,atamy  shyzwywka,re hai,re hai shi,xa ta mi,Атами,Атамі,آتامی، شیزوئوکا,أتامي,อะตะมิ,熱海,熱海市,아타미 시', 35.0883400, 139.0532500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90529, 'Ashiya', 'Ashiya', 'Ashija,Ashiya,Asija,Asiya,Asiya-chhi,Asiya-chhī,Aŝija,Aşiya,ashya,ashya  hywgw,asiya si,lu wu,lu wu shi,Асия,Ашия,Ашія,آشيا,آشیا، هیوگو,芦屋,芦屋市,蘆屋市,아시야 시', 34.7280700, 135.3026400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90530, 'Ashikaga', 'Ashikaga', 'Ashikaga,Ashikaga - zu li shi,Ashikaga - 足利市,Asikaga,Asikaga-chhi,Asikaga-chhī,Ašikaga,ashykaga  twchygy,ashykagha,asikaga si,zu li,zu li shi,Асикага,Асікаґа,Ашикага,آشیکاگا، توچیگی,أشيكاغا,足利,足利市,아시카가 시', 36.3333300, 139.4500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90531, 'Arai', 'Arai', 'Arai,xin jing,新井', 37.0005900, 138.2259000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90532, 'Annaka', 'Annaka', 'Annaka,Annaka-chhi,Annaka-chhī,an zhong,an zhong shi,anaka,annaka si,annaka  gwnma,Аннака,آنناکا، گونما,أناكا,安中,安中市,안나카 시', 36.3301100, 138.8958500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90533, 'Anjō', 'Anjo', 'Andyo,Andz''o,Andzijas,Andzjo,Andzo,Andzso,Andzsó,Andžijas,Anjo,Anjō,Anziyan,Anzyo-chhi,Anzyô-chhī,an cheng,an cheng shi,anjo si,anjw,anjw  aychy,aynjw,xan co,Андзьо,Андзё,Анџо,Анҷо,آنجو، آیچی,آنجو، ایچی,أنجو,اینجو,อันโจ,安城,安城市,안조 시', 34.9582800, 137.0805400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90534, 'Anan', 'Anan', 'Anan,Anan-chhi,Anan-chhī,a nan,a nan shi,anan,anan si,anan  twkwshyma,Анан,آنان، توکوشیما,أنان,阿南,阿南市,아난 시', 33.9166700, 134.6500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90535, 'Amagi', 'Amagi', 'Amagi,Amaki,gan mu,甘木', 33.4180400, 130.6541300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90536, 'Amagasaki', 'Amagasaki', 'Amagasaki,ni qi,ni qi shi,尼崎,尼崎市', 34.7166700, 135.4166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90537, 'Akune', 'Akune', 'a jiu gen,阿久根', 32.0166700, 130.2000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90538, 'Kariya', 'Kariya', 'Akaho,Ako,Akō,Kariya,jia wu,Ако,仮屋', 34.7513600, 134.3873400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90539, 'Aki', 'Aki', 'Aki,Aki-chhi,Aki-chhī,Akii,aki si,aky,aky  kwchy,an yi shi,an yun,an yun shi,Аки,Акі,آکی، کوچی,أكي,安芸,安芸市,安藝市,아키 시', 33.5000000, 133.9000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90540, 'Aioi', 'Aioi', 'Aioi,Aioi-shi,O,aioishi,xiang sheng,xiang sheng shi,Ō,あいおいし,相生,相生市', 34.8036100, 134.4680600, 'JP', '2014-07-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90541, 'Ageoshimo', 'Ageoshimo', 'Ageo,Ageomura,Ageoshimo,ageoshimo,shang wei,shang wei shi,shang wei xia,あげおしも,アゲオシモ,上尾,上尾下,上尾市', 35.9714500, 139.6138200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90542, 'Okinawa', 'Okinawa', 'Lungsod ng Okinawa,OKA,Okinava,Okinawa,Okinawa-chhi,Okinawa-chhī,awkynawa,chong sheng shi,chong ying,chong ying shi,mdynt awkynawa,okinawa si,xoa kin a wa,Окинава,Окінава,اوکیناوا,مدينة أوكيناوا,ඔකිනාවා,โอะกินะวะ,沖縄,沖縄市,沖繩市,오키나와 시', 26.3358300, 127.8013900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90543, 'Kushima', 'Kushima', 'Kushima,Kusima,Kusima-chhi,Kusima-chhī,chuan jian,chuan jian shi,gusima si,kwshyma,kwshyma  myazaky,Кусима,Кушима,Кушіма,كوشيما,کوشیما، میازاکی,串間,串間市,구시마 시', 31.4862100, 131.2421000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90544, 'Hikari', 'Hikari', 'Hikari,Hikari-chhi,Hikari-chhī,Khikari,guang,guang shi,hikali si,hykary,hykary  yamagwchy,Хикари,Хікарі,Ҳикари,هيكاري,هیکاری، یاماگوچی,光,光市,히카리 시', 33.9550000, 131.9500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90545, 'Nagato', 'Nagato', 'Chhong-mun-su,Chhòng-mùn-sṳ,Nagato,Nagato-chhi,Nagato-chhī,nagato si,nagatw  yamagwchy,naghwtw,zhang men,zhang men shi,Нагато,Наґато,ناغوتو,ناگاتو، یاماگوچی,長門,長門市,나가토 시', 34.3833300, 131.2000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90546, 'Hasuda', 'Hasuda', 'Hasuda,hasuda,lian tian,lian tian shi,はすだ,ハスダ,蓮田,蓮田市', 35.9711300, 139.6491000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90547, 'Kamifukuoka', 'Kamifukuoka', 'Kamifukuoka,kamifukuoka,shang fu gang,かみふくおか,カミフクオカ,上福岡', 35.8726600, 139.5136900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90548, 'Sayama', 'Sayama', 'Irumagawa,Sajama,Sayama,Sayama-chhi,Sayama-chhī,sayama,sayama si,sayama  saytama,xia shan,xia shan shi,Саяма,Сајама,ساياما,سایاما، سایتاما,狭山,狭山市,狹山市,사야마 시', 35.8529500, 139.4121200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90549, 'Fussa', 'Fussa', 'Fusa,Fussa,Hussa-chhi,Hussa-chhī,fu sheng,fu sheng shi,fus sa,fwsa,fwsa  twkyw,hus-sa si,Фусса,Ֆուսա,فوسا,فوسا، توکیو,ฟุสซะ,福生,福生市,훗사 시', 35.7366700, 139.3236100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90550, 'Asaka', 'Asaka', 'Asaka,Asaka-chhi,Asaka-chhī,asaka si,asaka  saytama,asaky,chao xia,chao xia shi,xa sa ka,Асака,آساکا، سایتاما,أساكي,อะซะกะ,朝霞,朝霞市,아사카 시', 35.8047200, 139.6019400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90551, 'Wako', 'Wako', 'Vako,Wako,he guang,Вако,和光', 35.7894400, 139.6233300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90552, 'Shimotoda', 'Shimotoda', 'Shimotoda,Toda,shimotoda,xia hu tian,Тода,しもとだ,シモトダ,下戸田', 35.8150000, 139.6853000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90553, 'Kimitsu', 'Kimitsu', 'Kimicu,Kimitsu,Kimitu-chhi,Kimitu-chhī,gimisseu si,jun jin,jun jin shi,khi misu,kimitsu,kymytsw,kymytsw  chyba,Кимитсу,Кимицу,Кіміцу,كيميتسو,کیمیتسو، چیبا,คิมิสึ,きみつ,キミツ,君津,君津市,기미쓰 시', 35.3504300, 139.8702900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90554, 'Miura', 'Miura', 'Miura,Miura-chhi,Miura-chhī,mi xura,miula si,mywra,mywra  kanagawa,san pu,san pu shi,Миура,Міура,ميورا,میورا، کاناگاوا,มิอุระ,三浦,三浦市,미우라 시', 35.1400000, 139.6191700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90555, 'Wakayama', 'Wakayama', 'Vakajama,Wakayama,Wakayama-shi,Wakayamashi,he ge shan,he ge shan shi,wakayama,wakayamashi,Вакаяма,わかやま,わかやまし,ワカヤマ,ワカヤマシ,和歌山,和歌山市', 34.2333300, 135.1666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90556, 'Iyo', 'Iyo', 'Ie,Ijo,Iyo,Iyo-chhi,Iyo-chhī,ayw,ayw  ahymh,iyo si,yi yu,yi yu shi,Ійо,Ие,Иё,إيو,ایو، اهیمه,ایو، اہیمے,伊予,伊予市,이요 시', 33.7513900, 132.7013900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90557, 'Uwajima', 'Uwajima', 'Uvadzhima,Uvadzima,Uwadyima,Uwazima,Uwazima-chhi,Uwazima-chhī,awajyma  ahymh,uwajima si,yu he dao,yu he dao shi,ywajyma,Уваджіма,Увадзима,Уваҷима,اواجیما، اهیمه,اواجیما، اہیمے,يواجيما,宇和島,宇和島市,우와지마 시', 33.2237500, 132.5600100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90558, 'Saijō', 'Saijo', 'Saidyo,Saidzo,Saijo,Saijō,Saizyo,Saizyo-chhi,Saizyô,Saizyô-chhī,Sajdzh''o,Sajdzjo,saijo si,sajyw,sayjw  ahymh,xi tiao,xi tiao shi,Саиџо,Саиҷо,Сайджьо,Сайдзё,ساجيو,سایجو، اهیمه,سےجو، اہمے,西条,西条市,西條市,사이조 시', 33.9166700, 133.1833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90559, 'Ōzu', 'Ozu', 'Odzu,Oozu-chhi,Oozu-chhī,Osu,Ozu,awzw,awzw  ahymh,da zhou,da zhou shi,ojeu si,Ōsu,Ōzu,Одзу,Озу,اؤزو، اہیمے,اوزو,اوزو، اهیمه,大洲,大洲市,오즈 시', 33.5000000, 132.5500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90560, 'Matsuyama', 'Matsuyama', 'MYJ,Macujama,Matsujama,Matsuyama,Matsuyama-shi,Matuyama,Matuyama-chhi,Matuyama-chhī,masseuyama si,masu ya ma,matsuyamashi,matswyama,matswyama  ahymh,song shan,song shan shi,Матсуяма,Мацуяма,Мацујама,מצויאמה,ماتسوياما,ماتسویاما، اهیمه,ماتسویاما، اہیمے,มะสึยะมะ,まつやまし,松山,松山市,마쓰야마 시', 33.8391600, 132.7657400, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90561, 'Masaki-chō', 'Masaki-cho', 'Masaki,song qian ding,松前町', 33.7875700, 132.7112400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90562, 'Kawanoechō', 'Kawanoecho', 'Kawanoe,Kawanoecho,Kawanoechō,chuan zhi jiang ding,川之江町', 34.0165400, 133.5784400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90563, 'Imabari-shi', 'Imabari-shi', 'Imabari,Imabari-shi,Imabaru-shi,jin zhi,今治', 34.0700100, 133.0002300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90564, 'Hōjō', 'Hojo', 'Khodze,Ходзе', 33.9766100, 132.7776700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90565, 'Yuzawa', 'Yuzawa', 'Judzava,Juzava,Yuzawa,Yuzawa-chhi,Yuzawa-chhī,tang ze,tang ze shi,yujawa si,ywzawa akyta,ywzawa  akta,ywzawa  akyta,Юдзава,Юдзава қаласы,Юзава,يوزاوا آكيتا,یوزاوا، آکیتا,یوزاوا، اکتا,湯沢,湯沢市,湯澤市,유자와 시', 39.1666700, 140.5000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90566, 'Yotsukaidō', 'Yotsukaido', 'Yotsukaido,Yotsukaidō,si jie dao,si jie dao shi,四街道,四街道市', 35.6500000, 140.1666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90567, 'Yonezawa', 'Yonezawa', 'Jonedzava,Jonehdzava,Jonezava,Yonesawa,Yonezawa,Yonezawa-chhi,Yonezawa-chhī,ionedzava,mi ze,mi ze shi,yoanea sa wa,yonejawa si,ywnyzawa,ywnyzawa  yamagata,Ёнезава,Ёнэдзава,Йонедзава,Йонезава,يونيزاوا,یونه‌زاوا، یاماگاتا,یونیزاوا، یاماگاتا,โยะเนะซะวะ,იონეძავა,米沢,米沢市,米澤市,요네자와 시', 37.9100000, 140.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90568, 'Yokotemachi', 'Yokotemachi', 'Jokote,Yokote,Yokotemachi,heng shou,heng shou ding,横手,横手町', 39.3169100, 140.5503400, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90569, 'Yōkaichiba', 'Yokaichiba', 'Yokaichiba,Yōkaichiba', 35.7000000, 140.5500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90570, 'Yanagawamachi-saiwaichō', 'Yanagawamachi-saiwaicho', 'Janagava,Yanagawa,Yanagawamachi-saiwaicho,Yanagawamachi-saiwaichō,Yanakawa,liang chuan ding xing ding,Янагава,梁川町幸町', 37.8500000, 140.6000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90571, 'Yamoto', 'Yamoto', 'Yamoto,shi ben,yamoto,やもと,ヤモト,矢本', 38.4273800, 141.2148700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90572, 'Yamagata', 'Yamagata', 'GAJ,Jamagata,Yamagata,Yamagata-shi,Yamagatashi,shan xing,shan xing shi,yamagata,yamagatashi,Ямагата,やまがた,やまがたし,ヤマガタ,ヤマガタシ,山形,山形市', 38.2333300, 140.3666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90573, 'Yamada', 'Yamada', 'Jamada,Yamada,Yamatamachi,Ямада', 39.4666700, 141.9500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90574, 'Yachimata', 'Yachimata', 'Jachimata,Jatimata,Yachimata,Yatimata-chhi,Yatimata-chhī,ba jie,ba jie shi,ya chi ma ta,yachimata si,yachymata  chyba,yatshymata,ychmata  chba,Ятимата,Ятімата,Ячимата,ياتشيماتا,یاچیماتا، چیبا,یچماتا، چبا,ยะชิมะตะ,八街,八街市,야치마타 시', 35.6500000, 140.3166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90575, 'Watari', 'Watari', 'Vatari,Watari,Ватари', 38.0350000, 140.8511100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90576, 'Wakuya', 'Wakuya', 'Wakuya,yong gu,涌谷', 38.5446500, 141.1346100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90577, 'Ushiku', 'Ushiku', 'Ushiku,Usiku,Usiku-chhi,Usiku-chhī,awshykw,awshykw  aybaraky,niu jiu,niu jiu shi,usiku si,Усику,Усіку,Ушику,أوشيكو,اوشیکو، ایباراکی,牛久,牛久市,우시쿠 시', 35.9666700, 140.1333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90578, 'Tsukuba', 'Tsukuba', 'Tsukuba,XEI,tsukuba,tsukuba shi,つくば,つくば市', 36.2000000, 140.1000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90579, 'Toride', 'Toride', 'Toride,Toride-chhi,Toride-chhī,Torite,dolide si,qu shou,qu shou shi,thoa ridea,twrydh,twrydh  aybaraky,Ториде,Торіде,توريده,توریده، ایباراکی,โทะริเดะ,取手,取手市,도리데 시', 35.9000000, 140.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90580, 'Tōno', 'Tono', 'Nambu,Tona,Tonas,Tono,Tono-chhi,Tôno-chhī,Tōno,dono si,twnw,twnw  aywath,yuan ye,yuan ye shi,Тона,Тоно,تونو,تونو، ایواته,遠野,遠野市,도노 시', 39.3166700, 141.5333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90581, 'Tomobe', 'Tomobe', '', 36.3500000, 140.3000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90582, 'Tomiya', 'Tomiya', 'Tomiya', 38.3930600, 140.8861100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90583, 'Tōgane', 'Togane', 'Togane,Togane-chhi,Toganemachi,Tôgane-chhī,Tōgane,Tōganemachi,dogane si,dong jin,dong jin shi,tho nganea,twganh  chyba,twghanh,Тогане,Тоґане,تؤگانے، چیبا,توغانه,توگانه، چیبا,โทงะเนะ,東金,東金市,도가네 시', 35.5500000, 140.3666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90584, 'Tendō', 'Tendo', 'Tendo,Tendō,tian tong,Тендо,天童', 38.3536100, 140.3697200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90585, 'Takahata', 'Takahata', 'Takahata,Takakhata,gao tian,Такахата,高畠', 38.0025000, 140.1911100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90586, 'Takahagi', 'Takahagi', 'Takahagi,Takahagi-chhi,Takahagi-chhī,Takakhagi,dakahagi si,gao qiu,gao qiu shi,takahaghy,takahagy  aybaraky,Такахаги,Такахаґі,Такаҳаги,تاكاهاغي,تاکاهاگی، ایباراکی,高萩,高萩市,다카하기 시', 36.7166700, 140.7166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90587, 'Tagajō-shi', 'Tagajo-shi', 'Tagajo,Tagajo-machi,Tagajo-mura,Tagajo-shi,Tagajō,Tagajō-machi,Tagajō-mura,Tagajō-shi,duo he cheng,多賀城', 38.3000000, 141.0000000, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90588, 'Sukagawa', 'Sukagawa', 'Sukagawa,xu he chuan,xu he chuan shi,須賀川,須賀川市', 37.2833300, 140.3833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90589, 'Shizukuishi', 'Shizukuishi', 'Shizukuishi,na shi,雫石', 39.6941400, 140.9844200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90590, 'Shisui', 'Shisui', 'Shisui,Shisuimachi,Shusui', 35.7166700, 140.2666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90591, 'Shiroishi', 'Shiroishi', 'Shiroishi,Siroisi,bai shi,白石', 38.0033300, 140.6183300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90592, 'Shiroi', 'Shiroi', 'Shiroi,Siroi,Siroi-chhi,Siroi-chhī,Siroj,bai jing,bai jing shi,chi roaxi,shyrwy,shyrwy  chyba,shyrwyy  chyba,siloi si,Сирои,Сірой,Широи,شيروي,شیروئی، چیبا,شیروی، چیبا,ชิโระอิ,白井,白井市,시로이 시', 35.8000000, 140.0666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90593, 'Shiogama', 'Shiogama', 'Schiogama,Shiogama,Siogama,yan zao,Сиогама,塩竃,塩竈', 38.3166700, 141.0333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90594, 'Shinjō', 'Shinjo', 'Shinjo,Shinjō,Sindscho,Sindze,Sinzyo,xin zhuang,Синдзе,新庄', 38.7586100, 140.3008300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90595, 'Sendai', 'Sendai', 'SDJ,Sendai,Sendai-shi,Sendaishi,Sendaj,sendai,sendaishi,xian tai,xian tai shi,Сендай,せんだい,せんだいし,センダイ,センダイシ,仙台,仙台市', 38.2666700, 140.8666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90596, 'Sawara', 'Sawara', 'Sawara', 35.8833300, 140.5000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90597, 'Sakura', 'Sakura', 'Sakura,Sakura-chhi,Sakura-chhī,sa kura,sakula si,sakwra,sakwra  chyba,zuo cang,zuo cang shi,Сакура,ساكورا,ساکورا، چیبا,ซะกุระ,佐倉,佐倉市,사쿠라 시', 35.7166700, 140.2333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90598, 'Sagae', 'Sagae', 'Sagae,Sagae-chhi,Sagae-chhī,Sagaeh,han he jiang,han he jiang shi,saga-e si,sagayh  yamagata,saghay,Сагае,Сагаэ,Саґае,ساغاي,ساگائه، یاماگاتا,سگے، یاماگاتا,寒河江,寒河江市,사가에 시', 38.3725000, 140.2725000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90599, 'Ryūgasaki', 'Ryugasaki', 'Rjugasaki,Ryugasaki,Ryugasaki-chhi,Ryûgasaki-chhī,Ryūgasaki,long qi shi,longke qi,longke qi shi,lyugasaki si,rywgasaky  aybaraky,rywghasaky,Рюгасаки,Рюґасакі,ريوغاساكي,ریوگاساکی، ایباراکی,龍ケ崎,龍ケ崎市,龍崎市,류가사키 시', 35.9000000, 140.1833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90600, 'Rifu', 'Rifu', 'Rifu,Rifuhongo,Rifuhongō,Ritu,li fu,利府', 38.3309200, 140.9769100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90601, 'Ōtsuchi', 'Otsuchi', 'Otsuchi,Ozuchi,Ozuti,Ōtsuchi', 39.3666700, 141.9000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90602, 'Ōtawara', 'Otawara', 'Otahara,Otavara,Otawara,Otawara-chhi,awtawara,awtawara  twchygy,da tian yuan,da tian yuan shi,otawala si,Ôtawara-chhī,Ōtawara,Отавара,أوتاوارا,اوتاوارا، توچیگی,大田原,大田原市,오타와라 시', 36.8666700, 140.0333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90603, 'Onagawa Chō', 'Onagawa Cho', 'Onagawa,Onagawa Cho,Onagawa Chō,Onakawa,Onogawa,nu chuan ding,onagawachou,おながわちょう,オナガワチョウ,女川町', 38.4449100, 141.4326900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90604, 'Ōmiya', 'Omiya', 'Omiya,Ōmiya', 36.5500000, 140.4166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90605, 'Omigawa', 'Omigawa', 'Omigawa,Omikawa', 35.8500000, 140.6166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90606, 'Ōmagari', 'Omagari', 'Omagari,da qu,Ōmagari,大曲', 39.4500000, 140.4833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90607, 'Okunoya', 'Okunoya', '', 36.2833300, 140.4166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90608, 'Ōkawara', 'Okawara', 'Ogawara,Okawara,Ōkawara', 38.0500000, 140.7336100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90609, 'Ōhara', 'Ohara', 'Ohara,da yuan,oohara,Ōhara,おおはら,オオハラ,大原', 35.2476100, 140.3928900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90610, 'Ōfunato', 'Ofunato', 'Ofunatas,Ofunato,Ohunato-chhi,afwnatw,awfwnatw  aywath,da chuan du,da chuan du shi,ohunato si,Ôhunato-chhī,Ōfunato,Офунато,أفوناتو,اوفوناتو، ایواته,大船渡,大船渡市,오후나토 시', 39.0716700, 141.7166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90611, 'Obanazawa', 'Obanazawa', 'Obanadzava,Obanasawa,Obanazava,Obanazawa,Obanazawa-chhi,Obanazawa-chhī,awbanazawa,awbanazawa  yamagata,obanajawa si,wei hua ze,wei hua ze shi,Обанадзава,Обаназава,أوبانازاوا,اوبانازاوا، یاماگاتا,尾花沢,尾花沢市,尾花澤市,오바나자와 시', 38.6033300, 140.4019400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90612, 'Ōarai', 'Oarai', 'Oarai,da xi ding,Ōarai,大洗町', 36.3140900, 140.5838900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90613, 'Ōami', 'Oami', '', 35.5166700, 140.3166700, 'JP', '2016-06-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90614, 'Nihommatsu', 'Nihommatsu', 'Nihommatsu,Nihonmatsu,er ben song,二本松', 37.5833300, 140.4333300, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90615, 'Natori-shi', 'Natori-shi', 'Natori,Natori-shi,ming qu,名取', 38.1666700, 140.8833300, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90616, 'Narutō', 'Naruto', 'Naruto,Narutō', 35.6000000, 140.4166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90617, 'Narita', 'Narita', 'Narita,Narita-chhi,Narita-chhī,cheng tian,cheng tian shi,na ri ta,nalita si,naryta,naryta  chyba,Нарита,Наріта,ناريتا,ناریتا، چیبا,นะริตะ,成田,成田市,나리타 시', 35.7833300, 140.3166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90618, 'Namie', 'Namie', 'Namie', 37.4833300, 141.0000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90619, 'Naka', 'Naka', 'Naka,Nakamuracho,Nakamurachō', 36.0500000, 140.1666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90620, 'Nagai', 'Nagai', 'Nagai,Nagai-chhi,Nagai-chhī,Nagaj,nagai si,nagay  yamagata,naghay,zhang jing,zhang jing shi,Нагаи,Наґай,ناغاي,ناگای، یاماگاتا,長井,長井市,나가이 시', 38.1036100, 140.0350000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90621, 'Motomiya', 'Motomiya', 'Motomija,Motomiya,Motomiya  Fukushima,Motomiya-chhi,Motomiya-chhī,ben gong,ben gong shi,motomiya si,mwtwmaya,mwtwmya  fwkwshyma,Мотомия,Мотомія,موتومايا,موتومیا، فوکوشیما,本宮,本宮市,모토미야 시', 37.5139100, 140.4006300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90622, 'Motegi', 'Motegi', 'Motegi', 36.5166700, 140.1833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90623, 'Moriya', 'Moriya', 'Morija,Moriya,Moriya-chhi,Moriya-chhī,moliya si,mwrya,mwrya  aybaraky,shou gu,shou gu shi,Мория,Морія,موريا,موریا، ایباراکی,守谷,守谷市,모리야 시', 35.9333300, 140.0000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90624, 'Morioka', 'Morioka', 'Morioka,Morioka-chhi,Morioka-chhī,Morioka-shi,Moriokashi,moa ri xoa ka,molioka si,morioka,moriokashi,mwrywka,mwrywka  aywath,sheng gang,sheng gang shi,Мориока,Моріока,מוריאוקה,موريوكا,موریوکا، ایواته,موریوکا، ایواتے,โมะริโอะกะ,もりおか,もりおかし,モリオカ,モリオカシ,盛岡,盛岡市,모리오카 시', 39.7000000, 141.1500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90625, 'Mooka', 'Mooka', 'Moka,Moka-chhi,Moka-chhī,Mooka,Mōka,moka si,mwka,mwka  twchygy,zhen gang,zhen gang shi,Мока,Моока,موكا,موکا، توچیگی,真岡,真岡市,모카 시', 36.4333300, 140.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90626, 'Mobara', 'Mobara', 'Mobara,Mobara-chhi,Mobara-chhī,Mobaramachi,Mohara,mao yuan,mao yuan shi,moaba ra,mobala si,mobara,mwbara  chyba,mwbara  tshyba,Мобара,موبارا، تشيبا,موبارا، چیبا,โมะบะระ,もばら,モバラ,茂原,茂原市,모바라 시', 35.4258300, 140.2960800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90627, 'Mizusawa', 'Mizusawa', 'Midzusava,Mizusawa,Mizuzawa,Мидзусава', 39.1333300, 141.1333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90628, 'Miyako', 'Miyako', 'Mijakas,Mijako,Miyako,Miyako-chhi,Miyako-chhī,gong gu,gong gu shi,maykw,miyako si,myakw  aywath,Мияко,Міяко,مايكو,میاکو، ایواته,宮古,宮古市,미야코 시', 39.6469100, 141.9405700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90629, 'Mito', 'Mito', 'Mito,Mito-shi,Mitoshi,mito,mitoshi,shui hu,shui hu shi,みと,みとし,ミト,ミトシ,水戸,水戸市', 36.3500000, 140.4500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90630, 'Miharu', 'Miharu', 'Miharu', 37.4333300, 140.4833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90631, 'Matsushima', 'Matsushima', 'Macusima,Matsushima,Matsusima,matsushima,song dao,Мацусима,まつしま,マツシマ,松島', 38.3735700, 141.0610500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90632, 'Mashiko', 'Mashiko', 'Mashiko,yi zi,益子', 36.4666700, 140.1000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90633, 'Marumori', 'Marumori', 'Marumori,wan sen,丸森', 37.9166700, 140.7666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90634, 'Makabe', 'Makabe', 'Makabe', 36.2666700, 140.1000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90635, 'Kuroiso', 'Kuroiso', '', 36.9666700, 140.0500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90636, 'Kōriyama', 'Koriyama', 'Ginqsan Si,Korijama,Koriyama,Koriyama-chhi,Kôriyama-chhī,Kōriyama,goliyama si,jun shan,jun shan shi,kho ri ya ma,kwryama,kwryama  fwkwshyma,kwryyama  fwkwshyma,Корияма,Коријама,Коріяма,كورياما,کوریاما، فوکوشیما,کورییاما، فوکوشیما,کوری‌یاما، فوکوشیما,โคริยะมะ,郡山,郡山市,고리야마 시', 37.4000000, 140.3833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90637, 'Kogota', 'Kogota', 'Kogota', 38.5500000, 141.0500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90638, 'Kitakami', 'Kitakami', 'Kitakami,Kitakami-chhi,Kitakami-chhī,Kitakamis,bei shang,bei shang shi,gitakami si,kytakamy,kytakamy  aywath,Китаками,Кітакамі,كيتاكامي,کیتاکامی، ایواته,北上,北上市,기타카미 시', 39.2833300, 141.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90639, 'Kitaibaraki', 'Kitaibaraki', 'Kita-Ibaraki,Kitaibaragi,Kitaibaraki,Kitaibaraki-chhi,Kitaibaraki-chhī,bei ci cheng,bei ci cheng shi,gitaibalaki si,kyta aybaraky,kytaaybaraky  aybaraky,Китаибараки,Кіта-Ібаракі,كيتا إيباراكي,کیتاایباراکی، ایباراکی,北茨城,北茨城市,기타이바라키 시', 36.7867100, 140.7490100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90640, 'Kesennuma', 'Kesennuma', 'Kesen-Numa,Kesennuma,Kesennuma-chhi,Kesennuma-chhī,Kesenuma,Kissennuma,gesennuma si,khea sen nu ma,kysyn-nwma  myaghy,qi xian zhao,Кесен-Нума,Кесеннума,Кесенума,كيسين-نوما، مياغي,کسن‌نوما، میاگی,เคะเซนนุมะ,気仙沼,氣仙沼,게센누마 시', 38.9011200, 141.5774600, 'JP', '2017-07-28', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90641, 'Kamogawa', 'Kamogawa', 'Kamogawa,ya chuan,Камогаwа,鴨川', 35.0969000, 140.1003000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90642, 'Katsuura', 'Katsuura', 'Kacuura,Katsura,Katsuura,Katuura-chhi,Katuura-chhī,gasseuula si,katsuura,katswra  tshyba,katwswra  chyba,khasu xura,sheng pu,sheng pu shi,Катсура,Кацуура,كاتسورا، تشيبا,کاتوسورا، چیبا,คะสึอุระ,かつうら,カツウラ,勝浦,勝浦市,가쓰우라 시', 35.1462100, 140.3150700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90643, 'Katsuta', 'Katsuta', '', 36.3833300, 140.5333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90644, 'Katori-shi', 'Katori-shi', 'Katori,Sawara,Sawara-shi,xiang qu,xiang qu shi,zuo yuan shi,佐原市,香取,香取市', 35.8976700, 140.4994300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90645, 'Kasama', 'Kasama', 'Kasama,Kasama-chhi,Kasama-chhī,gasama si,kasama,kasama  aybaraky,li jian,li jian shi,Касама,كاساما,کاساما، ایباراکی,笠間,笠間市,가사마 시', 36.3833300, 140.2666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90646, 'Karasuyama', 'Karasuyama', '', 36.6500000, 140.1500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90647, 'Kaminoyama', 'Kaminoyama', 'Kaminojama,Kaminoyama,Kaminoyama-chhi,Kaminoyama-chhī,gaminoyama si,kamynwyama,kamynwyama  yamagata,shang shan,shang shan shi,Каминояма,Камінояма,كامينوياما,کامینویاما، یاماگاتا,上山,上山市,가미노야마 시', 38.1538900, 140.2736100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90648, 'Kamaishi', 'Kamaishi', 'Kamaischi,Kamaishi,Kamaisi,Kamaisi-chhi,Kamaisi-chhī,Kamaisis,Kamaisyi,Kamaiši,Kamaišis,fu shi,fu shi shi,gamaisi si,kamaayshy  aywath,kamayshy,Камаиси,Камаиши,Камаїсі,كامايشي,کاماایشی، ایواته,釜石,釜石市,가마이시 시', 39.2769400, 141.8680100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90649, 'Kakunodatemachi', 'Kakunodatemachi', 'Kakudate,Kakunodate,Kakunodatemachi,jiao guan ding,Какунодате,角館町', 39.5892600, 140.5672400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90650, 'Kakuda', 'Kakuda', 'Kakuda,Kakuda-chhi,Kakuda-chhī,Kakudskij,gakuda si,jiao tian,jiao tian shi,kakwda,kakwda  myagy,kha ku da,Какуда,Какудский,كاكودا,کاکودا، میاگی,คะกุดะ,角田,角田市,가쿠다 시', 37.9745100, 140.7720200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90651, 'Iwase', 'Iwase', 'Ivaseh,Iwase,Ивасэ', 36.3500000, 140.1000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90652, 'Iwanuma', 'Iwanuma', 'Iwanuma,yan zhao,岩沼', 38.1047200, 140.8594400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90653, 'Iwaki', 'Iwaki', 'Banjsingz Si,Iuaki,Ivaki,Iwaki,Iwaki-chhi,Iwaki-chhī,Iŭaki,aywaky  fwkwshyma,iwaki,iwaki shi,iwaki si,lwaky,pan cheng,pan cheng shi,xi waki,Івакі,Иваки,ایواکی، فوکوشیما,لواكي,อิวะกิ,いわき,いわき市,磐城,磐城市,이와키 시', 37.0500000, 140.8833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90654, 'Itako', 'Itako', 'Idako,Itako,Itako-chhi,Itako-chhī,atakw,aytakw  aybaraky,chao lai,chao lai shi,itako si,Ітако,Итако,إتاكو,ایتاکو، ایباراکی,潮來市,潮来,潮来市,이타코 시', 35.9333300, 140.5500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90655, 'Ishioka', 'Ishioka', 'Ishioka,Isioka,Isioka-chhi,Isioka-chhī,ayshywka,isioka si,shi gang,shi gang shi,Ісіока,Исиока,Ишиока,إيشيوكا,ایشی‌اوکا، ایباراکی,石岡,石岡市,이시오카 시', 36.1833300, 140.2666700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90656, 'Ishinomaki', 'Ishinomaki', 'Ishinomachi,Ishinomaki,Isinomaki,Isinomaki-chhi,Isinomaki-chhī,Isyinomaki,Iŝinomaki,ayshynwmaky,ayshynwmaky  myagy,isinomaki si,shi juan,shi juan shi,xi chi noa maki,Ісіномакі,Исиномаки,Ишиномаки,إيشينوماكي,ایشینوماکی، میاگی,อิชิโนะมะกิ,石卷市,石巻,石巻市,이시노마키 시', 38.4166700, 141.3000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90657, 'Ishikawa', 'Ishikawa', 'Ishikawa,Isikava,Исикава', 37.1500000, 140.4500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90658, 'Inawashiro', 'Inawashiro', 'Inawashiro', 37.5666700, 140.1166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90659, 'Ichinoseki', 'Ichinoseki', 'Ichinoseki,Icinosekis,Itinoseki,Itinoseki-chhi,Itinoseki-chhī,Itschinoseki,Ičinosekis,atshynwsyky,aychynwsky  aywath,ichinoseki si,yi guan,yi guan shi,Ітіносекі,Итиносеки,Ичиносеки,إتشينوسيكي,ایچینوسکی، ایواته,一关市,一関,一関市,이치노세키 시', 38.9166700, 141.1333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90660, 'Ichihara', 'Ichihara', 'Ichihara,Ichikhara,Icihara,Itihara-chhi,Itihara-chhī,Itikhara,Iĉihara,aychyhara  chyba,aytshyhara,ichihala si,shi yuan shi,xi chi ha ra,yuan,Ітіхара,Итихара,Ичихара,Ичиҳара,إيتشيهارا,اچیہارا، چیبا,ایچیهارا، چیبا,อิชิฮะระ,იტიჰარა,原,市原市,이치하라 시', 35.5166700, 140.0833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90661, 'Hokota', 'Hokota', 'Hokota,Hokota-chhi,Hokota-chhī,Khokota,hokota si,hwkwta,hwkwta  aybaraky,mou tian,mou tian shi,Хокота,هوكوتا,هوکوتا، ایباراکی,鉾田,鉾田市,호코타 시', 36.1500000, 140.5166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90662, 'Hobaramachi', 'Hobaramachi', 'Hobara,Hobaramachi,bao yuan ding,保原町', 37.8166700, 140.5500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90663, 'Hitachi', 'Hitachi', 'Hidachi,Hitachi,Hitati-chhi,Hitati-chhī,Khitachi,Khitati,hi ta chi,hitachi si,hytachy  aybaraky,hytatshy,ri li,ri li shi,Хитати,Хитачи,Хітаті,Ҳитачи,هيتاتشي,هیتاچی، ایباراکی,ฮิตะชิ,ჰიტატი,日立,日立市,히타치 시', 36.6000000, 140.6500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90664, 'Higashine', 'Higashine', 'Higashine,Higasine-chhi,Higasine-chhī,Khigasine,dong gen,dong gen shi,hi nga chinea,higasine si,hygashynh  yamagata,hyghashyna,Хигасине,Хіґасіне,Ҳигашине,هيغاشينا,هیگاشینه، یاماگاتا,ฮิงะชิเนะ,東根,東根市,히가시네 시', 38.4388900, 140.4005600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90665, 'Hasaki', 'Hasaki', 'Hasaki,Hazaki,Namisaki', 35.7333300, 140.8333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90666, 'Hanamaki', 'Hanamaki', 'HNA,Hanamaki,Hanamaki-chhi,Hanamaki-chhī,Hanamakis,Khanamaki,ha na maki,hanamaki si,hanamaky,hanamaky  aywath,hua juan,hua juan shi,Ханамаки,Ханамакі,Ҳанамаки,هاناماكي,هاناماکی,هاناماکی، ایواته,ฮะนะมะกิ,花卷市,花巻,花巻市,하나마키 시', 39.3833300, 141.1166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90667, 'Furukawa', 'Furukawa', 'Furukawa,Hurukawa', 38.5716700, 140.9555600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90668, 'Funehikimachi-funehiki', 'Funehikimachi-funehiki', 'Funahiki,Funehiki,Funehikimachi-funehiki,chuan yin ding chuan yin,船引町船引', 37.4472200, 140.5771000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90669, 'Funaishikawa', 'Funaishikawa', 'Funaishikawa,Tokai-mura,Tōkai-mura', 36.4666700, 140.5666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90670, 'Fukushima', 'Fukushima', 'FKS,Fukushima,Fukushima-shi,Fukushimashi,Fukusima,Furukawa,Hukusima,fu dao,fu dao shi,fukushima,fukushimashi,Фукусима,ふくしま,ふくしまし,フクシマ,フクシマシ,福島,福島市', 37.7500000, 140.4666700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90671, 'Fujishiro', 'Fujishiro', '', 35.9166700, 140.1166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90672, 'Edosaki', 'Edosaki', 'Edosaki', 35.9500000, 140.3166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90673, 'Date', 'Date', 'Date,Nagaoka,yi da,伊達', 37.8166700, 140.5000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90674, 'Daigo', 'Daigo', 'Daigo,Даиго', 36.7666700, 140.3500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90675, 'Choshi', 'Choshi', 'Choshi,Chosi,Tyosi,Tyôsi,josi si,yao zi,yao zi shi,銚子,銚子市,조시 시', 35.7333300, 140.8333300, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90676, 'Chiba', 'Chiba', 'Chiba,Chiba-shi,Chibashi,Ciba,QCB,Tiba,chiba,chibashi,jiba si,qian ye,qian ye shi,tshyba,Ĉiba,Čiba,Чиба,تشيبا,ちば,ちばし,チバ,チバシ,千葉,千葉市,지바 시', 35.6000000, 140.1166700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90677, 'Asahi', 'Asahi', 'Asahi,Asahi-chhi,Asahi-chhī,Asakhi,asahi si,asahy,asahy  chyba,xa sa hi,xu,xu shi,Асахи,Асахі,Асаҳи,آساهي,آساهی، چیبا,آساہی، چیبا,อะซะฮิ,旭,旭市,아사히 시', 35.7166700, 140.6500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90678, 'Ami', 'Ami', 'Ami,Ами', 36.0333300, 140.2000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90679, 'Akita', 'Akita', 'AXT,Akita,Akita-shi,akita,akita si,akyta,qiu tian,qiu tian shi,Акита,آکیتا,أكيتا,अकिता,秋田,秋田市,아키타 시', 39.7166700, 140.1166700, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90680, 'Abiko', 'Abiko', 'Abiko,wo sun zi,wo sun zi shi,Абико,我孫子,我孫子市', 35.8666700, 140.0166700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90681, 'Akita', 'Akita', 'Akita,akita,akitashi,qiu tian,qiu tian shi,あきた,あきたし,アキタ,アキタシ,秋田,秋田市', 39.7166700, 140.1000000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90682, 'Otrada', 'Otrada', 'Chikappunai,Otrada,Otradnoye,Tikappunai,Tikappunay,Отрада', 44.0683200, 145.8645400, 'JP', '2013-08-04', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90683, 'Bihoro', 'Bihoro', 'Biboro,Biholo,Bihoro,Biporo', 43.8227800, 144.1044400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90684, 'Yūbari', 'Yubari', 'Jubari,Yubari,Yubari-chhi,Yuebari,Yûbari-chhī,Yübari,Yūbari,xi zhang,xi zhang shi,yuba ri,yubali si,ywbary,ywbary  hwkaydw,Юбари,Юбарі,يوباري,یوباری، هوکایدو,یوبری، ہوکیدو,ยูบะริ,夕張,夕張市,유바리 시', 43.0377800, 141.9577800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90685, 'Wakkanai', 'Wakkanai', 'Gorad Vakanaj,Inai,Vakkanai,Vakkanaj,WKJ,Wakkanai,Wakkanai-chhi,Wakkanai-chhī,wakanay,wakanay  hwkaydw,wakka ni,waskanai si,zhi nei,zhi nei shi,Вакканаи,Вакканай,Горад Ваканай,واكاناي,واکانای، هوکایدو,วักกะไน,稚內市,稚内,稚内市,왓카나이 시', 45.4094400, 141.6738900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90686, 'Utashinai', 'Utashinai', 'Utashinai,Utasinai,Utasinai-chhi,Utasinai-chhī,Utasinaj,Utaşinai,awtashynay  hwkaydw,ge zhi nei,ge zhi nei shi,utasinai si,ywtashyna,Утасинай,Утасінай,Уташинаи,اوتاشینای، هوکایدو,يوتاشينا,歌志內市,歌志内,歌志内市,우타시나이 시', 43.5166700, 142.0500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90687, 'Tomakomai', 'Tomakomai', 'QTM,Tomakomai,Tomakomai-chhi,Tomakomai-chhī,Tomakomaj,domakomai si,shan xiao mu,shan xiao mu shi,thoa ma koami,twmakwmay,twmakwmay  hwkaydw,Томакомаи,Томакомай,Томакомај,توماكوماي,توماکومای، هوکایدو,โทะมะโกะไม,苫小牧,苫小牧市,도마코마이 시', 42.6369400, 141.6033300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90688, 'Tōbetsu', 'Tobetsu', 'Tobetsu,Tōbetsu', 43.2169400, 141.5169400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90689, 'Mutsu', 'Mutsu', 'Mucu,Mutsu,Mutu-chhi,Mutu-chhī,Tanabe,Tanabu,lu ao shi,musseu si,musu,mutsu,mutsu shi,mwtsw,mwtsw  awmwry,mwtsw  aywmwry,Мутсу,Муцу,Муцу қаласы,موتسو,موتسو، آئوموری,موتسو، اوموری,มุสึ,მუცუ,むつ,むつ市,陸奧市,무쓰 시', 41.2894400, 141.2169400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90690, 'Takikawa', 'Takikawa', 'Takigawa,Takikawa,long chuan,滝川', 43.5527800, 141.9063900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90691, 'Takanosu', 'Takanosu', 'Takanosu,ying chao,鷹巣', 40.2226800, 140.3661100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90692, 'Sunagawa', 'Sunagawa', 'Sunagava,Sunagawa,Sunagawa-chhi,Sunagawa-chhī,Sunakawa,Sunaqava,Sunigawa,seunagawa si,sha chuan,sha chuan shi,swnagawa  hwkaydw,swnaghawa,Сунагава,Сунаґава,سوناغاوا,سوناگاوا، هوکایدو,砂川,砂川市,스나가와 시', 43.4863900, 141.9055600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90693, 'Shizunai-furukawachō', 'Shizunai-furukawacho', 'Shimo geho,Shimo-kebo,Shimo-kebō,Shimo-keho,Shimo-kehō,Shizunai,Shizunai-furukawacho,Shizunai-furukawachō,jing nei gu chuan ding,静内古川町', 42.3338900, 142.3669400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90694, 'Shiraoi', 'Shiraoi', 'Shiraoi', 42.5500000, 141.3500000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90695, 'Shimo-furano', 'Shimo-furano', 'Shimo-furano,Shimo-furanoshigai', 43.3500000, 142.3833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90696, 'Shibetsu', 'Shibetsu', 'Sibetsu,Sibetu,Sipetu,biao jin,標津', 43.6589900, 145.1319700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90697, 'Sapporo', 'Sapporo', 'Gorad Sapara,SPK,Saporas,Saporo,Sapporo,Sapporo-chhi,Sapporo-chhī,Sapporo-shi,Sapporoshi,Sapporum,Szapporo,capporo,sabwrw,sap poa roa,sapporo,sapporoshi,sapwrw,saspolo si,sypwrw,zha huang,zha huang shi,Σαππόρο,Горад Сапара,Сапоро,Саппоро,Սապորո,סאפורו,سابورو,ساپورو,سیپورو,सप्पोरो,சப்போரோ,ซัปโปะโระ,საპორო,さっぽろ,さっぽろし,サッポロ,サッポロシ,札幌,札幌市,삿포로 시', 43.0666700, 141.3500000, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90698, 'Rumoi', 'Rumoi', 'Rumoe,Rumoi,Rumoi-chhi,Rumoi-chhī,Rumoj,liu meng,liu meng shi,lumoi si,rwmwy,rwmwy  hwkaydw,Румои,Румой,روموي,روموی، هوکایدو,留萌,留萌市,루모이 시', 43.9344400, 141.6427800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90699, 'Otofuke', 'Otofuke', 'Otopuke', 42.9916700, 143.2002800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90700, 'Otaru', 'Otaru', 'Otaru,Otaru-chhi,Otaru-chhī,QOT,awtarw,awtarw  hwkaydw,otalu si,xiao zun,xiao zun shi,xoa ta ru,Отару,Отарү,أوتارو,اوتارو، هوکایدو,โอะตะรุ,小樽,小樽市,오타루 시', 43.1894400, 141.0022200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90701, 'Ōdate', 'Odate', 'ONJ,Odate,Odate-chhi,Otate,awdath,awdath  akyta,da guan,da guan shi,odate si,oodate,xo da tea,Ódate,Ôdate-chhī,Ōdate,Ōtate,Одате,Одатэ қаласы,أوداته,اوداته، آکیتا,اوداتے، اکیتا,โอดะเตะ,おおだて,オオダテ,大館,大館市,오다테 시', 40.2717800, 140.5575600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90702, 'Obihiro', 'Obihiro', 'OBO,Obibiro,Obihiro,Obihiro-chhi,Obihiro-chhī,Obikhiro,awbyhyrw,awbyhyrw  hwkaydw,dai guang,dai guang shi,obihilo si,xoa bi hi roa,Обихиро,Обиҳиро,Обіхіро,أوبيهيرو,اوبیهیرو، هوکایدو,โอะบิฮิโระ,帯広,帯広市,帶廣市,오비히로 시', 42.9172200, 143.2044400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90703, 'Noshiro', 'Noshiro', 'Noshiro,Noshiro-shi,Noshiromachi,Noshirominato,Nosiro,ONJ,neng dai,neng dai ding,neng dai shi,nosilo si,nwshyrw,nwshyrw  akyta,Носиро,نوشيرو,نوشیرو، آکیتا,能代,能代市,能代町,노시로 시', 40.2083800, 140.0274000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90704, 'Noboribetsu', 'Noboribetsu', 'Noboribecu,Noboribetsu,Noboribetsucho,Noboribetu-chhi,Noboribetu-chhī,deng bie,deng bie shi,noa boa ri bea su,nobolibesseu si,nwbwrybtsw  hwkaydw,nwbwrybytsw,Ноборибетсу,Ноборибецу,Ноборібецу,نوبوريبيتسو,نوبوریبتسو، هوکایدو,โนะโบะริเบะสึ,登別,登別市,노보리베쓰 시', 42.4521500, 141.1791400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90705, 'Nemuro', 'Nemuro', 'Nehmuro,Nemuras,Nemuro,Nemuro-chhi,Nemuro-chhī,gen shi,gen shi shi,nea mu roa,nemulo si,nmwrw  hwkaydw,nymwrw,Немуро,Нэмуро,نمورو، هوکایدو,نيمورو,เนะมุโระ,根室,根室市,네무로 시', 43.3236100, 145.5750000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90706, 'Nayoro', 'Nayoro', 'Naero,Najoro,Nayoro,Nayoro-chhi,Nayoro-chhī,Nayoru,ming ji,ming ji shi,na yoa roa,nayolo si,naywrw,naywrw  hwkaydw,Наеро,Найоро,Наёро,نايورو,نایورو، هوکایدو,นะโยะโระ,名寄,名寄市,나요로 시', 44.3505600, 142.4577800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90707, 'Nanae', 'Nanae', 'Nanae', 41.8833300, 140.6833300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90708, 'Namioka', 'Namioka', 'Namioka,lang gang,namioka,Намиока,なみおか,ナミオカ,浪岡', 40.7106900, 140.5904800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90709, 'Mobetsu', 'Mobetsu', 'Mobetsu,Naka-mobetsu,mobetsu,wen bie,zao bie,もべつ,モベツ,紋別,藻別', 44.2709600, 143.3602500, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90710, 'Muroran', 'Muroran', 'Muroran,Muroran-chhi,Muroran-chhī,QRN,mu roa rang,mulolan si,mwrwan,mwrwran  hwkaydw,shi lan,shi lan shi,Муроран,موروان,موروران، هوکایدو,มุโระรัง,室蘭,室蘭市,무로란 시', 42.3172200, 140.9880600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90711, 'Mombetsu', 'Mombetsu', 'MBE,Mobetsu,Mombecu,Mombetsu,Monbetsu,Monbetu,wen bie,Момбецу,紋別', 44.3525000, 143.3525000, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90712, 'Misawa', 'Misawa', 'MSJ,Misaua,Misava,Misawa,Misawa-chhi,Misawa-chhī,Misaŭa,Omisawa,misava,misawa,misawa si,mysawa,mysawa  awmwry,mysawa  aywmwry,san ze,san ze shi,Ōmisawa,Мисава,Мисава қаласы,Місава,ميساوا,میساوا، آئوموری,میساوا، اوموری,მისავა,みさわ,ミサワ,三沢,三沢市,三澤市,미사와 시', 40.6868200, 141.3896900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90713, 'Yoichi', 'Yoichi', 'Minatomachi,Yoichi,Yoichicho,Yoichichō,Yoiti', 43.2038900, 140.7702800, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90714, 'Mikasa', 'Mikasa', 'Mikasa,Mikasa-cho,Mikasa-chō,Mikasa-shi,Mikasayama-mura,san li,san li shi,三笠,三笠市', 43.2558100, 141.8881800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90715, 'Makubetsu', 'Makubetsu', '', 45.3713900, 141.8211100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90716, 'Kushiro', 'Kushiro', 'KUH,Kushira,Kushiro,Kushiro  Hokkaido,Kushiro  Hokkaidō,Kushiro-shi,Kusiras,Kusiro,Kusiro-chhi,Kusiro-chhī,Kusyiro,Kuŝiro,Kuşiro,Kuširas,Kuširo,chuan lu,chuan lu shi,gusilo si,khu chi roa,kwshyrw,kwshyrw  hwkaydw,qwsyrw,Кусиро,Кусіро,Куширо,קושירו,كوشيرو,کوشیرو، هوکایدو,คุชิโระ,釧路,釧路市,구시로 시', 42.9750000, 144.3747200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90717, 'Kuroishi', 'Kuroishi', 'Kuroishi,Kuroisi,Kuroisi-chhi,Kuroisi-chhī,Kuroisyi,Kuroiŝi,guloisi si,hei shi,hei shi shi,khu roaxi chi,kuroishi,kwrwayshy  aywmwry,kwrwyshy,kwrwyshy  awmwry,Куроиси,Куроиси қаласы,Куроиши,Куроїсі,كورويشي,کوروایشی، آئوموری,کورویشی، اوموری,คุโระอิชิ,კუროისი,くろいし,クロイシ,黑石市,黒石,黒石市,구로이시 시', 40.6458100, 140.5835400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90718, 'Kuji', 'Kuji', 'Kudschi,Kuji,Kuzi,jiu ci,久慈', 40.1877800, 141.7688900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90719, 'Shimokizukuri', 'Shimokizukuri', 'Kizukuri,Shimokizukuri,shimokidzukuri,xia mu zao,しもきづくり,シモキヅクリ,下木造', 40.8160900, 140.3753900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90720, 'Kitami', 'Kitami', 'Kitami,Kitami-chhi,Kitami-chhī,Kitamis,Kity,Nokkeushi,Nokkeusi,Notsukeushi,Nupukeushi-mura,bei jian,bei jian shi,gitami si,khi ta mi,kytamy,kytamy  hwkaydw,Китами,Киты,Кітамі,كيتامي,کیتامی، هوکایدو,คิตะมิ,北見,北見市,기타미 시', 43.8030600, 143.8908300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90721, 'Kamikawa', 'Kamikawa', 'Kamikawa', 43.8400000, 142.7711100, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90722, 'Kamiiso', 'Kamiiso', '', 41.8201300, 140.6448200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90723, 'Iwanai', 'Iwanai', 'Iwanai', 42.9744400, 140.5088900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90724, 'Iwamizawa', 'Iwamizawa', 'Iuamizaua,Iuamizava,Ivamidzava,Ivamizava,Iwamisawa,Iwamizawa,Iwamizawa-chhi,Iwamizawa-chhī,Iŭamizaŭa,Twamizawa,aywamyzawa,aywamyzawa  hwkaydw,iwamijawa si,iwamizawa,yan jian ze,yan jian ze shi,İvamizava,Івамідзава,Ивамидзава,Иуамизава,إيواميزاوا,ایوامیزاوا، هوکایدو,いわみざわ,イワミザワ,岩見沢,岩見沢市,岩見澤市,이와미자와 시,ｲﾜﾐｻﾞﾜ', 43.2002800, 141.7597200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90725, 'Ishikari', 'Ishikari', 'Ishikari,Isikari,Isikari-chhi,Isikari-chhī,ashykary,ayshykary  hwkaydw,isikali si,shi shou,shi shou shi,İşikari,Ісікарі,Исикари,Ишикари,إشيكاري,ایشیکاری، هوکایدو,石狩,石狩市,이시카리 시', 43.2397200, 141.3538900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90726, 'Ichinohe', 'Ichinohe', 'Ehinohe,Ichinobe,Ichinohe,Itinohe,Itschinohe,ichinohe,yi hu,いちのへ,イチノヘ,一戸', 40.2196500, 141.2898600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90727, 'Kitahiroshima', 'Kitahiroshima', 'Hiroshima,Khirosima,Kitahiroshima,Kitahirosima,Kitahirosima-chhi,Kitahirosima-chhī,Kitahiroşima,Kitakhirosima,Nakaosawa,bei guang dao,bei guang dao shi,gitahilosima si,khi ta hi roa chi ma,kytahyrwshyma,kytahyrwshyma  hwkaydw,Китахиросима,Китаҳирошима,Кітахіросіма,Хиросима,كيتاهيروشيما,کیتاهیروشیما، هوکایدو,คิตะฮิโระชิมะ,北広島,北広島市,北廣島市,기타히로시마 시', 42.9758300, 141.5672200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90728, 'Hirosaki', 'Hirosaki', 'Hirosaki,Hirosaki-chhi,Hirosaki-chhī,Hiroszaki,Khirosaki,hi roa saki,hilosaki si,hong qian,hong qian shi,hyrwsaky,hyrwzaky  aywmwry,Хиросаки,Хиросаки қаласы,Хіросакі,Ҳиросаки,هيروساكي,هیروزاکی، آئوموری,ہیروساکی، اوموری,ฮิโระซะกิ,ჰიროსაკი,弘前,弘前市,히로사키 시', 40.5930600, 140.4725000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90729, 'Hanawa', 'Hanawa', 'Hanawa,Kadzuno,Kazuno,Kazuno-chhi,Kazuno-chhī,gajeuno si,hua lun,kazwnw,kazwnw  akyta,lu jiao shi,Кадзуно,Кадзуно қаласы,Казуно,كازونو,كازونو، أكيتا,کازونو، آکیتا,花輪,鹿角市,가즈노 시', 40.1836100, 140.7872200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90730, 'Hakodate', 'Hakodate', 'HKD,Hakodate,Hakodate-chhi,Hakodate-chhī,Hakodatė,Hokodate,Khakodate,Khakodateh,ha koa da tea,hakodate si,hakwdath,hakwdath  hwkaydw,han guan,han guan shi,Хакодате,Хакодатэ,Ҳакодате,הקודאטה,هاكوداته,هاکوداته,هاکوداته، هوکایدو,ہاکوداتے، ہوکائیدو,ฮะโกะดะเตะ,ჰაკოდატე,函館,函館市,하코다테 시', 41.7758300, 140.7366700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90731, 'Hachinohe', 'Hachinohe', 'Hachinohe,ba hu,八戸', 40.5000000, 141.5000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90732, 'Furano', 'Furano', 'Furano,Furano-cho,Furano-chō,Furano-machi,Hurano,Hurano-chhi,Hurano-chhī,Shima-furano,fu liang ye,fu liang ye shi,fu ra noa,fwranw,fwranw  hwkaydw,hulano si,Фурано,فورانو,فورانو، هوکایدو,ฟุระโนะ,富良野,富良野市,후라노 시', 43.3500000, 142.3833300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90733, 'Fukagawa', 'Fukagawa', 'Fukagaua,Fukagava,Fukagawa,Fukaqava,Hukagawa,Hukagawa-chhi,Hukagawa-chhī,fwkagawa  hwkaydw,fwkaghawa,hukagawa si,shen chuan,shen chuan shi,Фукагава,Фукагауа,Фукаґава,فوكاغاوا,فوکاگاوا، هوکایدو,深川,深川市,후카가와 시', 43.7080600, 142.0391700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90734, 'Ebetsu', 'Ebetsu', 'Ebecu,Ebetsu,Ebetu-chhi,Ebetu-chhī,Ehbecu,abtsw  hwkaydw,abytsw,ebesseu si,jiang bie,jiang bie shi,Ебетсу,Ебецу,Эбецу,إبيتسو,ابتسو، هوکایدو,江別,江別市,에베쓰 시', 43.1080600, 141.5505600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90735, 'Date', 'Date', 'Date,Nishi-mombetsu,yi da,yi da shi,伊達,伊達市', 42.4680600, 140.8680600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90736, 'Chitose', 'Chitose', 'Chitose,Citose,Titose,Titose-chhi,Titose-chhī,chi toa sea,chytwsh  hwkaydw,jitose si,qian sui,qian sui shi,tshytwzy,Çitose,Титосе,Тітосе,Читосе,تشيتوزي,چیتوسه، هوکایدو,ชิโตะเซะ,千歲市,千歳,千歳市,지토세 시', 42.8194400, 141.6522200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90737, 'Bibai', 'Bibai', 'Bibai,Bibai-chhi,Bibai-chhī,Bibaj,Numakai,bibai si,bybay,bybay  hwkaydw,mei bei,mei bei shi,Бибаи,Бибай,Бібай,بيباي,بیبای، هوکایدو,美唄,美唄市,비바이 시', 43.3247200, 141.8586100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90738, 'Ashibetsu', 'Ashibetsu', 'Ashibetsu,Asibecu,Asibetsu,Asibetu-chhi,Asibetu-chhī,Aşibetsu,Shimo-ashibetsu,ashybytsw,asibesseu si,lu bie,lu bie shi,Асибецу,Асібецу,Ашибетсу,آشی‌بتسو، هوکایدو,أشيبيتسو,芦別,芦別市,蘆別市,아시베쓰 시', 43.5097200, 142.1855600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90739, 'Asahikawa', 'Asahikawa', 'AKJ,Asahikava,Asahikawa,Asahikawa-chhi,Asahikawa-chhī,Asakhikava,Gorad Asakhikava,asahikawa si,asahykawa,asahykawa  hwkaydw,xa sa hi kawa,xu chuan,xu chuan shi,Асахикава,Асахікава,Асаҳикауа,Горад Асахікава,אסהיקאווה,آساهیکاوا، هوکایدو,أساهيكاوا,اساہیکاوا، ہوکائیدو,อะซะฮิกะวะ,旭川,旭川市,아사히카와 시', 43.7706300, 142.3648900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90740, 'Aomorishi', 'Aomorishi', 'AOJ,Aomori,Aomori-shi,Aomorishi,aomoli si,aomori,aomorishi,awmwry,qing sen,qing sen shi,Аомори,آوموري,あおもり,あおもりし,アオモリ,アオモリシ,青森,青森市,아오모리 시', 40.8166700, 140.7333300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91206, 'Phnom Penh', 'Phnom Penh', 'Gorad Pnampen'',Krong Chaktomuk,Nam Van,Nam-Vang,Nom Pen,PNH,Phnom Pen,Phnom Penh,Phnom Pénh,Phnom-Penh,Phnompen,Phnompenh,Phnum Penh,Phnum Peny,Phnum Pénh,Phnum Pény,Phnôm Pênh,Phon Phen,Pnom Pehn'',Pnom Pen,Pnom Pen''ch,Pnom Pene,Pnom Penh,Pnom-Peno,Pnompen,Pnompen'',Pnompena,Pnompenis,Pnompeņa,Ville de Phnom Penh,bnwm bnh,fnwm pn,fnwm pېn,jin bian,namapenha,panoma pena,peunompen,phnm pen,phnmpey,pnwm pn,punom pen,punonpen,Πνομ Πενχ,Горад Пнампень,Пном Пен,Пном Пэнь,Пномпень,Պնոմպեն,פנום פן,بنوم بنه,فنوم پن,فنوم پېن,پنوم پن,پنوم‌پن,پنۆم پێن,नामपेन्ह,पनॉम पेन,প্‌নম পেন,புனோம் பென்,พนมเปญ,พนมเปณ,ཕོམ་ཕེན།,ဖနွမ်းပင်မြို့,პნომპენი,ፕኖም ፔን,ភនកពងតរាច,ភនពេញ,ភ្នំកំពង់ត្រាច,ភ្នំពេញ,プノンペン,金边,프놈펜', 11.5624500, 104.9160100, 'KH', '2016-01-25', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91207, 'Veun Sai', 'Veun Sai', 'Moulapoumok,Veun Sai,Virachei,Virachey,Virocheay,Virochey,Virôchey,Virôcheăy,Voeune Sai', 13.9759800, 106.8114400, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91208, 'Ta Khmau', 'Ta Khmau', 'Ta Khmau,Takhman,Takhmau,Takkhmau,Такхмау,កណតាល,កណ្តាល', 11.4833300, 104.9500000, 'KH', '2015-07-13', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91209, 'Takeo', 'Takeo', 'Prasat,Pràsàt,Takeo,Takev,Takéo,Takêv', 10.9908100, 104.7849800, 'KH', '2013-08-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91210, 'Svay Rieng', 'Svay Rieng', 'Phumi Svay Rieng,Phumĭ Svay Riĕng,SVR,Soai Rieng,Soei Rieng,Svai Rieng,Svay Rieng,Svay Riĕng', 11.0878500, 105.7993500, 'KH', '2014-05-29', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91211, 'Svay Chek', 'Svay Chek', 'Khum Svay Chek,Svay Chek,Svay Chék,Sway-Chek', 13.8053900, 102.9618400, 'KH', '2017-01-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91212, 'Suŏng', 'Suong', 'Phumi Suong,Phumĭ Suŏng,Suong,Suŏng', 11.9117800, 105.6582100, 'KH', '2016-05-01', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91213, 'Stung Treng', 'Stung Treng', 'Stoeng Treng,Stung Teeng,Stung Treng,Stung-treng,Stœ̆ng Trêng,TNX', 13.5258600, 105.9683000, 'KH', '2017-02-11', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91214, 'Srae Ambel', 'Srae Ambel', 'Phum Sre Ambel,Phumi Sre Ambel,Phumĭ Srê Âmbel,Srae Ambel,Sre Ambel,Sre Umbell,Sreumbel,Srê Âmbĕl', 11.1221200, 103.7538300, 'KH', '2017-02-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91215, 'Sisŏphŏn', 'Sisophon', 'Serei Saophoan,Sesopone,Sisobhon,Sisophon,Sisŏphŏn', 13.5858800, 102.9736900, 'KH', '2012-10-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91216, 'Siem Reap', 'Siem Reap', 'Ciudad de Siem Riep,Khett Siem Reab,REP,Siem Reab,Siem Reap,Siem-Reap,Siemrap,Siemreab,Siemreabas,Siemreap,Siemrãp,Sijem Reap,Siĕm Réab,Siĕmréab,Sziemreap,Xiem Riep,Xiêm Riệp,ciyem rip,seiy mrath,shemuriappu,siemleapeu,sima ripa,syam ryb,sym ryp,syym ryp,syym ryyp,xian li sheng,xian li shi,Сием-Реап,Сиемреап,Сијем Реап,Сіемреап,سيام ريب,سیئم ریئپ,سیئم ریپ,سیم ریپ,सीम रीप,சியெம் ரீப்,เสียมราฐ,ក្រុងសៀមរាប,シェムリアップ,暹粒市,暹粒省,시엠레아프', 13.3617900, 103.8605600, 'KH', '2014-05-29', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91217, 'Siem Pang', 'Siem Pang', 'Siem Pang,Siem Prang,Siempang,Siĕmpang', 14.1172800, 106.3883800, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91218, 'Sênmônoŭrôm', 'Senmonourom', 'Krong Saen Monourom,Mondul Kiri,Saen Monourom,Sen Monorom,Sen Monorum,Sen Moronom,Senmanorum,Senmonorom,Senmonourom,Sênmônoŭrôm', 12.4558300, 107.1881100, 'KH', '2015-06-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91219, 'Prey Veng', 'Prey Veng', 'Prei Veng,Prey Veng,Prey Vêng', 11.4868200, 105.3253300, 'KH', '2013-08-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91220, 'S’ang', 'S''ang', 'Prek Taugh,Prek Toch,Prêk Toch,S''ang,S’ang,ព្រែកតូច', 11.3606700, 105.0077600, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91221, 'Koah Thum', 'Koah Thum', 'Koah Thum,Phum Prek Thmey,Phumi Prek Thmei,Phumĭ Prêk Thmei,Prek T''mei,Prek Thmei,Prek Thmey,Prek T’mei,Prey Thmey,Prêk Thmei,ព្រែកថ្ម', 11.1242100, 105.0572200, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91222, 'Pursat', 'Pursat', 'Porsat,Pousat,Pouthisat,Poŭsăt,Poŭthĭsăt,Pursat', 12.5387800, 103.9192000, 'KH', '2011-01-17', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91223, 'Phumĭ Véal Srê', 'Phumi Veal Sre', '', 10.9808100, 104.7782800, 'KH', '2011-04-19', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91224, 'Bak Khlang', 'Bak Khlang', 'Bak Khlang,Ban Snam Khwai,Packlang,Phum Thnal Krabei,Phum Thnál Krâbei,Phumi Thnal Krabei,Phumĭ Thnál Krâbei,Snam Krapeu,Snom Crabeu,Snom Craboeu,Snom Khuai,Snon Khuai', 11.5690300, 102.9554200, 'KH', '2017-01-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91225, 'Thma Puok', 'Thma Puok', 'Hmar Pouok,Phum Thma Pok,Phum Thmâ Pôk,Phumi Thma Pok,Phumĭ Thmâ Pôk,Thma Puok,Thmar Pouok,Thmar Puok,ភូមិ ថ្មពក', 13.9398700, 103.0530700, 'KH', '2017-01-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91226, 'Ta Loas', 'Ta Loas', 'Phum Taluh,Phum Talŭh,Phumi Talon,Phumi Talun,Phumĭ Talón,Phumĭ Talŭn,Ta Loas,Taluo,ភូមិ តាលន់', 12.8079000, 103.4602300, 'KH', '2016-11-22', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91227, 'Sâmraông', 'Samraong', 'Phumi Samraong,Phumi Samrong,Phumi Samroung,Phumi Sâmroŭng,Phumĭ Sâmraông,Phumĭ Sâmrông,Samraong,Samrong,Somrong,Sâmraông', 14.1817500, 103.5176100, 'KH', '2013-08-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91228, 'Sala Krau', 'Sala Krau', 'Phum Sala Krau,Phum Sala Krau (1),Phumi Sala Krau (1),Phumĭ Sala Krau (1),Sala Krau,Sala Krav,ភូមិ សាលាក្រៅ', 12.9561200, 102.6089100, 'KH', '2016-11-22', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91229, 'Preaek Prasab', 'Preaek Prasab', 'Phumi Prek Prasab,Phumi Prek Prasap,Phumĭ Prêk Prâsáb,Phumĭ Prêk Prâsâp,Preaek Prasab,ភូមិ ព្រែកប្រសប់', 12.3536700, 106.0356200, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91230, 'Koas Krala', 'Koas Krala', 'Kas Kralo,Koas Krala,Koas Kralar,Kokolor,Koăs Krâlâ,Phum Kas Kralo,Phum Koas Krala,Phum Kôâs Krâlâ,Phumi Koas Krala,Phumĭ Koăs Krâlâ,ភូមិ គាស់ក្រឡ', 12.7558800, 103.2551400, 'KH', '2016-11-22', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91231, 'Kampong Seila', 'Kampong Seila', 'Kampong Seila,Kompong Sala,Kompong Seila,Kompong Sela,Kompong Siela,Phumi Kampong Sala,Phumĭ Kâmpóng Sala', 11.0916700, 103.9007800, 'KH', '2017-02-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91232, 'Chhuk', 'Chhuk', 'Chhouk,Chhuk,Phumi Chhuk,Phumĭ Chhuk', 10.8364400, 104.4552800, 'KH', '2017-02-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91233, 'Chhloung', 'Chhloung', 'Chhlong,Chhloung,Chlong,Phum Chhlong,Phumi Chhlong,Phumĭ Chhlong,ភូមិ ឆ្លូង', 12.2561000, 105.9700400, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91234, 'Bavel', 'Bavel', 'Bavel,Boh Wel,Phum Bavel,Phumi Bavil,Phumĭ Bâvĭl', 13.2512800, 102.8779500, 'KH', '2017-01-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91235, 'Banan', 'Banan', 'Banan,Phum Banon,Phumi Banan,Phumĭ Banăn', 12.9396400, 103.1423900, 'KH', '2017-01-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91236, 'Tbêng Méanchey', 'Tbeng Meanchey', 'Kampong Preng,Kimpong Pranak,Kompong Pranak,Kompong Prena,Kompong Preng,OMY,Phnom Tbeng Meanchey,Phnom Thbeng Meanchey,Phnom Thbeng Neanchey,Phnum Tbeng Meanchey,Phnum Tbêng Méanchey,Phom Thbeng Meanchey,Phumi Thbeng Meanchey,Phumĭ Thbeng Meanchey,Tbaeng Mean Chey,Tbeng Meanchey,Tbêng Méanchey,Thbeng Meanchey', 13.8073100, 104.9804600, 'KH', '2017-02-11', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91237, 'Paoy Paet', 'Paoy Paet', 'Paoy Paet,Paoy Pet,Paôy Pêt,Phum Paoy Pet,Phum Paôy Pêt,Phumi Paoy Pet,Phumĭ Paôy Pêt,Poipet,Pojpet,Пойпет,ប៉ោយប៉ែត', 13.6580500, 102.5636500, 'KH', '2016-11-22', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91238, 'Pailin', 'Pailin', 'Ciudad de Pailin,Ciudad de Pailín,Krong Pailin,Pailin,Pailĭn,pairin,ក្រុងប៉ៃលិន,パイリン', 12.8489500, 102.6092800, 'KH', '2013-04-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91239, 'Moung Ruessei', 'Moung Ruessei', 'Maung,Maung Russei,Moung,Moung Roessei,Moung Ruessei,Moung Russei,Moung Russey,Moŭng Rœssei,Moŭng Rŭssei,Muong Roessei,Russey,មោងឬស្សី', 12.7745200, 103.4492600, 'KH', '2016-11-22', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91240, 'Lumphat', 'Lumphat', 'Lomphat,Lumphat,Lumphăt,លំផាត់', 13.4914600, 106.9802200, 'KH', '2017-05-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91241, 'Kuleaen', 'Kuleaen', 'Koulen,Kuleaen,Kulen,Kulén,Phumi Kulen,Phumĭ Kulén,គូលេន', 13.8214700, 104.6982400, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91242, 'Krong Kep', 'Krong Kep', 'Kaeb,Kep,Krong Keb,Krong Kep,Krŏng Kêb,Krŏng Kêp,របភាពករង,រូបភាពក្រុង', 10.4829100, 104.3167200, 'KH', '2015-07-13', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91243, 'Koh Kong', 'Koh Kong', 'KKZ,Kaoh Kong,Kaôh Kŏng,Khemarak Phoumin,Khemarak Phoumin Ville,Khemareah Phumint,Koh Kong,Koville,Krong Kao Kong,Krong Kaoh Kong,Krong Khemarak Phoumin,Krong Khemoreah Phumint,Krong Koh Kong,Krŏng Kaôh Kŏng,Krŏng Khémôreăh Phumĭnt,កោះកង,កោះកុង', 11.6153100, 102.9838000, 'KH', '2017-02-11', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91244, 'Kratié', 'Kratie', 'KTI,Kracheh,Krati,Kratie,Krâchéh,ករចេះ,ក្រចេះ', 12.4881100, 106.0187900, 'KH', '2017-02-11', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91245, 'Batheay', 'Batheay', 'Bat''eay,Batheay,Bat’eay,Khum Batheay,Khŭm Bathéay,Phumi Batheay,Phumĭ Batheay', 11.9893500, 104.9420800, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91246, 'Kampot', 'Kampot', 'Compong Bai,Compong Baï,Kampat,Kampot,Kampot Lalawigan,Kampotas,Kamput,Kompong Bai,Krong Kampot,Krŏng Kâmpôt,Kâmpôt,gong bu,kampoteu,kampwt,kanpotto,Кампот,کامپوت,کمپوٹ شہر,កពត,កំពត,ក្រុងកំពត,カンポット,贡布,캄포트', 10.6104100, 104.1814500, 'KH', '2015-07-13', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91247, 'Kampong Trach', 'Kampong Trach', 'Kampong Trach,Kampong Trak,Kompong Trach,Kâmpóng Trach,Phumi Kampong Trach,Phumi Kompong Trach,Phumĭ Kompong Trach,Phumĭ Kâmpông Trach', 10.5584700, 104.4675300, 'KH', '2017-02-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91248, 'Kampong Trabaek', 'Kampong Trabaek', 'Kampong Trabaek,Kampong Trabek,Kompong Trabek,Kâmpóng Trâbêk,Phumi Kampong Trabek,Phumĭ Kâmpông Trâbêk', 11.1437900, 105.4827500, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91249, 'Kampong Thom', 'Kampong Thom', 'Kampong Thom,Kampong Thum,Kampong Thun,Kompong Thom,Kâmpóng Thom,Kâmpóng Thum', 12.7111200, 104.8887300, 'KH', '2013-04-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91250, 'Kampong Speu', 'Kampong Speu', 'Kampong Speu,Kampong Spoe,Kompon Spu,Kompong Speu,Kâmpóng Spœ,Kŏmpon Spu', 11.4533200, 104.5208500, 'KH', '2013-04-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91251, 'Sihanoukville', 'Sihanoukville', 'Ciudad de Sihanoukville,KOS,Kampong Saom,Kampong Semville,Kampong Som,Kampong Somville,Kom Pong Song,Kompong Som,Kompong Somville,Krong Preah Seihanu,Krong Preah Sihanouk,Krŏng Preăh Seihanŭ,Krŏng Preăh Sihanouk,Kâmpóng Saôm,Port de Sihanoukville,Preah Seihanouk,Sianukvil'',Sihanouk,Sihanoukville,Sikanonville,shianukubiru,sih nu will,xi ha nu ke shi,Сиануквиль,สีหนุวิลล์,ក្រុងព្រះសីហនុ,シアヌークビル,西哈努克市', 10.6093200, 103.5295800, 'KH', '2017-05-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91252, 'Kampong Chhnang', 'Kampong Chhnang', 'KZC,Kampong Chhnang,Kampong Chnang,Kampongchnang,Kompon Chnang,Kompong Chhang,Kompong Chhnang,Kâmpóng Chhnăng,Phumi Kampong Chhnang,Phumĭ Kâmpông Chhnăng,Кампонгчнанг,ករងកពងឆនាង,ក្រុងកំពង់ឆ្នាំង', 12.2500000, 104.6666700, 'KH', '2017-02-11', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91253, 'Kampong Cham', 'Kampong Cham', 'Compon-lina,Kampong Cham,Kampongtjam,Kompon Cam,Kompong Cham,Kâmpóng Cham,Кампонгтям,ករងកពងចាម,ក្រុងកំពង់ចាម', 11.9933900, 105.4635000, 'KH', '2015-07-13', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90741, 'Akabira', 'Akabira', 'Akabira,Akabira-chhi,Akabira-chhī,Kami-akabira,akabila si,akabyra,akabyra  hwkaydw,chi ping,chi ping shi,xa kabi ra,Акабира,Акабіра,آکابیرا، هوکایدو,أكابيرا,อะกะบิระ,赤平,赤平市,아카비라 시', 43.5513900, 142.0530600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90742, 'Abashiri', 'Abashiri', 'Abashiri,Abasiri,Abasiri-chhi,Abasiri-chhī,Abasiris,Abaŝiri,Abaşiri,Abaširis,Aburatsu,abashyry,abashyry  hwkaydw,abasili si,abasiri,wang zou,wang zou shi,xaba chi ri,Абасири,Абасірі,آباشیری، هوکایدو,أباشيري,อะบะชิริ,აბასირი,網走,網走市,아바시리 시', 44.0212700, 144.2697100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90743, 'Goshogawara', 'Goshogawara', 'Gos''ogavara,Goshogavara,Goshogawara,Gosjogavara,Gosogauara,Gosyogawara,Gosyogawara-chhi,Gosyogawara-chhī,Goŝogaŭara,ghwshwghawara,gosiogavara,gosyogawala si,gwshwgawara  awmwry,gwshwgawara  aywmwry,koachoa nga wa ra,wu suo chuan yuan,wu suo chuan yuan shi,Госегавара қаласы,Госёгавара,Гошогавара,Ґосьоґавара,غوشوغاوارا,گوشوگاوارا، آئوموری,گوشوگاوارا، اوموری,โกะโชะงะวะระ,გოსიოგავარა,五所川原,五所川原市,고쇼가와라 시', 40.8044400, 140.4413900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90744, 'Aso', 'Aso', 'Aso,a su,a su shi,Асо,阿蘇,阿蘇市', 32.9372600, 131.0800800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90745, 'Kōya', 'Koya', 'Koja,Koya,Kója,gao ye ding,goya jeong,Коя,高野町,고야 정', 34.2129400, 135.6224400, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90746, 'Kihoku-chō', 'Kihoku-cho', 'Kihoku,gui bei ting,鬼北町', 33.2559200, 132.6834300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90747, 'Nanto-shi', 'Nanto-shi', 'Nanto,nan li,nan li shi,南砺,南砺市', 36.5692200, 136.9116200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90748, 'Kawage', 'Kawage', '', 34.8044700, 136.5464500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90749, 'Asahi', 'Asahi', '', 35.9725900, 136.1245500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90750, 'Neyagawa', 'Neyagawa', 'Neyagawa-shi,qin wu chuan,qin wu chuan shi,寝屋川,寝屋川市', 34.7661500, 135.6275900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90751, 'owariasahi', 'owariasahi', 'wei zhang xu,尾張旭', 35.2080000, 137.0300000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90752, 'Hitachi-Naka', 'Hitachi-Naka', 'hitachinaka,hitachinaka shi,hitachinaka-shi,ひたちなか,ひたちなか市', 36.3965900, 140.5347900, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90753, 'Chikusei', 'Chikusei', 'Chikusei,Chikusej,Tikusei-chhi,Tikusei-chhī,Tikusej,chykwsy  aybaraky,jikusei si,tshykwsh,zhu xi,zhu xi shi,Тикусей,Тікусей,Чикусеи,Чикусеј,تشيكوسه,چیکوسی، ایباراکی,筑西,筑西市,지쿠세이 시', 36.3160000, 139.9823800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90754, 'Kasumigaura', 'Kasumigaura', 'Kasumigaura,Kasumigaura-chhi,Kasumigaura-chhī,gaseumigaula si,kasumigaura,kasumigaura shi,kaswmygaywra  aybaraky,kaswmyghawra,xia pu shi,Касумигаура,Касуміґаура,كاسوميغاورا,کاسومیگائورا، ایباراکی,かすみがうら,かすみがうら市,霞浦市,가스미가우라 시', 36.1532600, 140.2463500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90755, 'Tsuchiura', 'Tsuchiura', 'Tsuchiura,tu pu,土浦', 36.0904700, 140.2104700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90756, 'Tsukubamirai', 'Tsukubamirai', 'Cukuba-Miraj,Cukubamiraj,Tsukubamirai,Tukubamirai-chhi,Tukubamirai-chhī,sseukubamilai si,tsukubamirai,tsukubamirai shi,tswkwba-myray,tswkwbamyray  aybaraky,zhu bo wei lai shi,Цукуба-Мірай,Цукубамирай,تسوكوبا-ميراي,تسوکوبامیرای، ایباراکی,つくばみらい,つくばみらい市,筑波未來市,쓰쿠바미라이 시', 35.9841100, 140.0092900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90757, 'Omitama', 'Omitama', 'Omitama,xiao mei yu,xiao mei yu shi,小美玉,小美玉市', 36.2544900, 140.3796200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90758, 'Hitachiomiya', 'Hitachiomiya', 'Hitachiomiya,chang lu da gong,常陸大宮', 36.5644700, 140.4026900, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90759, 'Kamisu', 'Kamisu', 'Kamisu,Kamisu-chhi,Kamisu-chhī,gamiseu si,kamysw,kamysw  aybaraky,shen qi,shen qi shi,Камису,Камісу,كاميسو,کامیسو، ایباراکی,神栖,神栖市,가미스 시', 35.8968500, 140.6666600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90760, 'Namegata', 'Namegata', 'Namegata,Namekata,xing fang,xing fang shi,行方,行方市', 36.0070500, 140.4962300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90761, 'Sakuragawa', 'Sakuragawa', 'Sakuragava,Sakuragawa,Sakuragawa-chhi,Sakuragawa-chhī,sakulagawa si,sakwragawa  aybaraky,sakwraghawa,ying chuan,ying chuan shi,Сакурагава,Сакураґава,ساكوراغاوا,ساکوراگاوا، ایباراکی,桜川,桜川市,櫻川市,사쿠라가와 시', 36.2505200, 140.1156500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90762, 'Bandō', 'Bando', 'Bando,Bandō,ban dong,坂東', 36.0699700, 139.8670500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90763, 'Hitachi-ota', 'Hitachi-ota', 'Hitachi-ota,chang lu tai tian,常陸太田', 36.5513000, 140.5282100, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90764, 'Inashiki', 'Inashiki', 'Inashiki,Inasiki,Inasiki-chhi,Inasiki-chhī,anashyky,aynashyky  aybaraky,dao fu,dao fu shi,inasiki si,sakuragawa,sakuragawa-mura,Інасікі,Инасики,Инашики,إناشيكي,ایناشیکی، ایباراکی,稲敷,稲敷市,稻敷市,이나시키 시', 35.9563300, 140.3235600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90765, 'Azumino', 'Azumino', 'Azumino,an tan ye,安曇野', 36.2881500, 137.8870500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90766, 'Chikuma', 'Chikuma', 'Chikuma,Tikuma,Tikuma-chhi,Tikuma-chhī,chi ku ma,chykwma  naganw,jikuma si,qian qu,qian qu shi,tshykwma,Тикума,Тікума,Чикума,Տիկումա,تشيكوما,چیکوما، ناگانو,ชิกุมะ,千曲,千曲市,지쿠마 시', 36.5271500, 138.0894300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90767, 'Murayama', 'Murayama', 'Murayama,cun shan,村山', 38.4697200, 140.4144100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90768, 'Minamiashigara', 'Minamiashigara', 'Minami-Ashigara,Minami-Asigara,Minamiashigara,Minamiasigara,Minamiasigara-chhi,Minamiasigara-chhī,mi na mixa chi nga ra,minamiasigala si,mynamy ashyghara,nan zu bing,nan zu bing shi,Минамиасигара,Минамиашигара,Мінамі-Асіґара,مينامي أشيغارا,مینامی‌آشیگارا، کاناگاوا,มินะมิอะชิงะระ,南足柄,南足柄市,미나미아시가라 시', 35.3194700, 139.1096000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90769, 'Rittō', 'Ritto', 'Ritto,Rittō,li dong,栗東', 35.0274500, 135.9997100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90770, 'Takashima', 'Takashima', 'Takashima,Takasima,Takasima-chhi,Takasima-chhī,Takaŝima,dakasima si,gao dao,gao dao shi,takashyma,takashyma  shyga,Такасима,Такасіма,Такашима,تاكاشيما,تاکاشیما، شیگا,高島,高島市,다카시마 시', 35.4134700, 136.0161200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90771, 'Kōka', 'Koka', 'Koka,Koka-chhi,Kôka-chhī,Kōka,goka si,jia he,jia he shi,kwka,kwka  shyga,Кока,كوكا,کوکا، شیگا,甲賀,甲賀市,고카 시', 34.9802000, 136.1575200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90772, 'Katsuragi', 'Katsuragi', 'Kacuragi,Katsuragi,Katuragi-chhi,Katuragi-chhī,gasseulagi si,ge cheng,ge cheng shi,katswraghy,katswragy  nara,Катсураги,Кацураги,Кацураґі,كاتسوراغي,کاتسوراگی، نارا,葛城,葛城市,가쓰라기 시', 34.4856200, 135.6969800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90773, 'Kashiba', 'Kashiba', 'Kashiba,Kasiba,Kasiba-chhi,Kasiba-chhī,Kasyiba,Kaŝiba,gasiba si,kashyba,kashyba  nara,kha chiba,xiang zhi,xiang zhi shi,Касиба,Касіба,Кашиба,كاشيبا,کاشیبا، نارا,คะชิบะ,香芝,香芝市,가시바 시', 34.5347200, 135.7092500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90774, 'Nanto', 'Nanto', 'Nanto,Nanto-chhi,Nanto-chhī,nan li,nan li shi,nanto si,nantw,nantw  twyama,Нанто,نانتو,نانتو، تویاما,南砺,南砺市,난토 시', 36.5127400, 136.8935200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90775, 'Oyabe', 'Oyabe', 'Oyabe,xiao shi bu,小矢部', 36.6666700, 136.8500000, 'JP', '2012-08-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90776, 'Imizu', 'Imizu', 'Imizu,Imizucho,Imizuchō,imizuchou,she shui,she shui ding,いみずちょう,射水,射水町', 36.7683500, 137.1257200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90777, 'Kurobe-shi', 'Kurobe-shi', 'Kurobe,Kurobeshin,hei bu,hei bu xin,黒部,黒部新', 36.9012300, 137.4495500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90778, 'Tama', 'Tama', 'Tama,Tama-chhi,Tama-chhī,dama si,duo mo,duo mo shi,tama,tama  twkyw,tha ma,Тама,Տամա,تاما,تاما، توکیو,ทะมะ,多摩,多摩市,다마 시', 35.6436000, 139.4684400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90779, 'Musashimurayama', 'Musashimurayama', 'Musashimurajama,Musashimurayama,Musasi-Murajama,Musasimurajama,Musasimurayama,Musasimurayama-chhi,Musasimurayama-chhī,Musašimurajama,dong da he,mu sa chi mu raya ma,musasimulayama si,mwsashymwrayama,wu cang cun shan shi,wu zang cun shan,wu zang cun shan shi,Мусасимураяма,Мусасі-Мураяма,Мусашимураяма,Մուսասիմուրայամա,موساشيموراياما,موساشی‌مورایاما، توکیو,มุซะชิมุระยะมะ,東大和,武蔵村山,武蔵村山市,武藏村山市,무사시무라야마 시', 35.7424200, 139.4263500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90780, 'Akishima', 'Akishima', 'Akishima,Akisima,Akisima-chhi,Akisima-chhī,Akiŝima,Akišima,akisima si,akyshyma,akyshyma  twkyw,xaki chi ma,zhao dao,zhao dao shi,Акисима,Акишима,Акісіма,Ակիսիմա,آکیشیما، توکیو,أكيشيما,อะกิชิมะ,昭島,昭島市,아키시마 시', 35.7208500, 139.3799900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90781, 'Higashiyamato', 'Higashiyamato', 'Higashi-yamato,Higashiyamato,Higasijamatas,Higasiyamato-chhi,Higasiyamato-chhī,Higasyiyamato,Higašijamatas,Hikasiyamato,Khigasi-Jamato,Khigasijamato,dong cun shan,dong da he,dong da he shi,hi nga chi ya ma toa,higasiyamato si,hyghashy yamatw,Хигасиямато,Хіґасі-Ямато,Ҳигашиямато,Հիկասիյամատո,هيغاشي ياماتو,هیگاشی‌یاماتو، توکیو,ฮิงะชิยะมะโตะ,東大和,東大和市,東村山,히가시야마토 시', 35.7629800, 139.4457500, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90782, 'Misato', 'Misato', 'Misato,Misato  Saitama,Misato-chhi,Misato-chhī,misato si,mysatw,mysatw  saytama,san xiang,san xiang shi,Мисато,Місато,ميساتو,میساتو، سایتاما,三郷,三郷市,三鄉市,미사토 시', 35.8437300, 139.8834700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90783, 'Niiza', 'Niiza', 'Niidza,Niisa,Niiza,Niiza-chhi,Niiza-chhī,Niza,niiza,nija si,nyza,xin zuo,xin zuo shi,Низа,Ниидза,Нииза,Ніїдза,نيزا,نی‌ایزا، سایتاما,にいざ,ニイザ,新座,新座市,니자 시', 35.8208800, 139.5579100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90784, 'Tonami', 'Tonami', 'Tonami,li bo,砺波', 36.6204700, 136.9432100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90785, 'Kahoku', 'Kahoku', 'Kahoku,Kahoku-chhi,Kahoku-chhī,Kakhoku,gahoku si,he bei shi,kahoku,kahoku shi,kahwkw,kahwkw  ayshykawa,Кахоку,Каҳоку,كاهوكو,کاهوکو، ایشیکاوا,かほく,かほく市,河北市,가호쿠 시', 36.7575800, 136.7116200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90786, 'Kaga', 'Kaga', 'Kaga,jia he,加賀', 36.3000000, 136.3333300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90787, 'Suzu', 'Suzu', 'Sudzu,Susu,Suzu,Suzu-chhi,Suzu-chhī,seujeu si,swzw,swzw  ashykawa,swzw  ayshykawa,zhu zhou,zhu zhou shi,Судзу,Сузу,سوزو,سوزو، اشیکاوا,سوزو، ایشیکاوا,珠洲,珠洲市,스즈 시', 37.4166700, 137.2500000, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90788, 'Matsuura', 'Matsuura', 'Macuura,Matsuura,Matuura-chhi,Matuura-chhī,masseuula si,matswra,matswywra  nagazaky,song pu,song pu shi,Матсуура,Мацуура,ماتسوئورا، ناگازاکی,ماتسورا,松浦,松浦市,마쓰우라 시', 33.3405800, 129.6950400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90789, 'Ōnojō', 'Onojo', 'Onodyo,Onodzh''o,Onodzjo,Onodzo,Onojo,Onojyo,Onozyo-chhi,awnjw,awnwjw  fwkwywka,da ye cheng,da ye cheng shi,onojo si,Ónodžó,Ônozyô-chhī,Оноджьо,Онодзё,Оноҷо,Օնոձյո,أونجو,اونوجو، فوکوئوکا,大野城,大野城市,오노조 시', 33.5356700, 130.4786100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90790, 'Kasuga', 'Kasuga', 'Kasuga,Kasuga-chhi,Kasuga-chhī,chun ri,chun ri shi,gaseuga si,kaswga  fwkwywka,kaswgha,Касуга,Касуґа,كاسوغا,کاسوگا، فوکوئوکا,春日,春日市,가스가 시', 33.5259400, 130.4611000, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90791, 'Aizu-Wakamatsu', 'Aizu-Wakamatsu', 'Aizu-Wakamatsu,hui jin ruo song,hui jin ruo song ,会津若松,会津若松　', 37.4914200, 139.9454600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90792, 'Minami-Sōma', 'Minami-Soma', 'Minami-Soma,Minami-Sōma,nan xiang ma,南相馬', 37.6290800, 140.9786800, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90793, 'Urasoe', 'Urasoe', 'Urasoe,pu tian,浦添', 26.2590200, 127.7301200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90794, 'Uruma', 'Uruma', 'Uruma,Uruma-chhi,Uruma-chhī,awrwma  awkynawa,uluma si,uruma,uruma shi,xuru ma,yu liu ma shi,ywrwma  awkynawa,Урума,اوروما، اوکیناوا,يوروما، أوكيناوا,อุรุมะ,うるま,うるま市,宇流麻市,우루마 시', 26.3760900, 127.8590800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90795, 'Jōsō', 'Joso', 'Joso,Jōsō,chang zong,chang zong shi,常総,常総市', 36.0355300, 139.9614300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90796, 'Midori', 'Midori', 'Midori,Midori-chhi,Midori-chhī,lu shi,mi doa ri,midoli si,midori,midori shi,mydwry,mydwry  gwnma,Мидори,Мідорі,ميدوري,میدوری، گونما,มิโดะริ,みどり,みどり市,綠市,미도리 시', 36.4449200, 139.2844800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90797, 'Miyakojima', 'Miyakojima', 'Mijakodzhima,Mijakodzima,Miyakozima-chhi,Miyakozima-chhī,gong gu dao,gong gu dao shi,mi ya koa ci ma,miyakojima si,myakwjyma  awkynawa,Миякодзима,Міякоджіма,מיאקוגימה,مياكوجيما، أوكيناوا,میاکوجیما، اوکیناوا,มิยะโกะจิมะ,宮古島,宮古島市,미야코지마 시', 24.7901600, 125.3110900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90798, 'Hidaka', 'Hidaka', 'Hidaka,Hidaka-chhi,Hidaka-chhī,Khidaka,hidaka si,hydaka,hydakh  saytama,ri gao,ri gao shi,Хидака,Хідака,Ҳидака,هيداكا,هیداکه، سایتاما,日高,日高市,히다카 시', 35.9166400, 139.3623300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90799, 'Higashi-Matsuyama', 'Higashi-Matsuyama', 'Higashi-Matsuyama,dong song shan,東松山', 36.0333300, 139.4166700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90800, 'Iruma', 'Iruma', 'Iruma,Iruma-chhi,Iruma-chhī,arwma,ayrwma  saytama,iluma si,ru jian,ru jian shi,Ірума,Ирума,إروما,ایروما، سایتاما,入間,入間市,이루마 시', 35.8180000, 139.3680000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90801, 'Kitamoto', 'Kitamoto', 'Kitamoto,bei ben,kitamoto,きたもと,キタモト,北本', 36.0332200, 139.5377500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90802, 'Tsurugashima', 'Tsurugashima', 'Tsurugashima,he~ke dao,鶴ヶ島', 35.9599600, 139.4028300, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90803, 'Sōsa', 'Sosa', 'Sosa,Sosa-chhi,Sôsa-chhī,Sōsa,so sa,sosa si,swsa,swsa  chyba,za cuo,za cuo shi,Соса,سؤسا، چیبا,سوسا,سوسا، چیبا,โซซะ,匝瑳,匝瑳市,소사 시', 35.7154100, 140.5530900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90804, 'Sanmu', 'Sanmu', 'Sammu,Sanmu,Sanmu-chhi,Sanmu-chhī,san mu,sanmu si,sanmw,sanmw  chyba,shan wu,shan wu shi,Самму,سانمو,سانمو، چیبا,سان‌مو، چیبا,ซันมุ,山武,山武市,산무 시', 35.6275600, 140.4176200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90805, 'Sōma', 'Soma', 'Soma,Sōma,xiang ma,相馬', 37.7928300, 140.9294100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90806, 'Tamura', 'Tamura', 'Tamura,Tamura-chhi,Tamura-chhī,damula si,tamwra,tamwra  fwkwshyma,tian cun,tian cun shi,Тамура,تامورا,تامورا، فوکوشیما,田村,田村市,다무라 시', 37.4305500, 140.6033500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90807, 'Kinokawa', 'Kinokawa', 'Kinokava,Kinokawa,Kinokawa-chhi,Kinokawa-chhī,ginokawa si,ji zhi chuan shi,jino chuan,jino chuan shi,kynwkawa,kynwkawa  wakayama,Кинокава,Кинокава қаласы,Кінокава,كينوكاوا,کینوکاوا، واکایاما,紀の川,紀の川市,紀之川市,기노카와 시', 34.2697300, 135.4104500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90808, 'Kumano', 'Kumano', 'Kumano,xiong ye,xiong ye shi,熊野,熊野市', 33.9038900, 136.1221400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90809, 'Inabe', 'Inabe', 'Inabe,inabe,inabe shi,いなべ,いなべ市', 35.1134400, 136.5720500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90810, 'Shimotsuke', 'Shimotsuke', 'Shimotsuke,Simocuke,Simotuke-chhi,Simotuke-chhī,shymwtswka,shymwtswkh  twchygy,simosseuke si,xia ye,xia ye shi,Симоцуке,Сімоцуке,شيموتسوكا,شیموتسوکه، توچیگی,下野,下野市,시모쓰케 시', 36.4132300, 139.8662200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90811, 'Nasukarasuyama', 'Nasukarasuyama', 'Nasu-Karasujama,Nasukarasujama,Nasukarasuyama,Nasukarasuyama-chhi,Nasukarasuyama-chhī,na xu wu shan,na xu wu shan shi,naseukalaseuyama si,naswkaraswyama,naswkaraswyama  twchygy,Насу-Карасуяма,Насукарасуяма,ناسوكاراسوياما,ناسوکاراسویاما، توچیگی,那須烏山,那須烏山市,나스카라스야마 시', 36.6523300, 140.1608400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90812, 'Tōmi', 'Tomi', 'Tomi,Tōmi,dong yu,東御', 36.3558200, 138.3609300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90813, 'Komagane', 'Komagane', 'Komagane,Komagane-chhi,Komagane-chhī,Komagene,gomagane si,ju gen shi,ju~ke gen,ju~ke gen shi,kwmaganh  naganw,kwmaghanh,Комагане,Комаґане,Կոմագենե,كوماغانه,کوماگانه، ناگانو,駒ヶ根,駒ヶ根市,駒根市,고마가네 시', 35.7165700, 137.9374500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90814, 'Inzai', 'Inzai', 'Indzaj,Inzai,Inzai-chhi,Inzai-chhī,anzay,anzayy  chyba,aynzay  chyba,injai si,xin si,yin xi,yin xi shi,Індзай,Индзай,Инзаи,إنزاي,انزائی، چیبا,اینزای، چیبا,อินไซ,印西,印西市,인자이 시', 35.8347900, 140.1636100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90815, 'Isumi', 'Isumi', 'Isumi,Isumi-chhi,Isumi-chhī,aswmy,aswmy  chyba,ayswmy  chyba,iseumi si,isumi,isumi shi,xisu mi,yi yu shi,Ісумі,Исуми,Իսումի,إسومي,اسومی، چیبا,ایسومی، چیبا,อิซุมิ,いすみ,いすみ市,夷隅市,이스미 시', 35.2300500, 140.4049200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90816, 'Yachiyo', 'Yachiyo', 'Jachijo,Jatijo,Yachiyo,Yatiyo-chhi,Yatiyo-chhī,ba qian dai,ba qian dai shi,ya chi yoa,yachiyo si,yashyw  chyba,yatshyw,ychyw  chba,Јачијо,Ятиё,Ятійо,Ячиё,ياتشيو,یاشیو، چیبا,یچیو، چبا,ยะชิโยะ,八千代,八千代市,야치요 시', 35.7353100, 140.1244500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90817, 'Tomisato', 'Tomisato', 'Tomisato,Tomisato-chhi,Tomisato-chhī,domisato si,fu li,fu li shi,thoa mi sa toa,twmysatw,twmysatw  chyba,Томисато,Томісато,توميساتو,تومیساتو، چیبا,โทะมิซะโตะ,富里,富里市,도미사토 시', 35.7448300, 140.4038600, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90818, 'Ōshū', 'Oshu', 'Oshu,Osiu,Osju,Osu,Osyu-chhi,Ošiū,ao zhou,ao zhou shi,awshw,awshw  aywath,osyu si,Óšú,Ôsyû-chhī,Ōshū,Осю,Ошу,أوشو,اوشو، ایواته,奥州,奥州市,奧州,奧州市,오슈 시', 39.1392700, 141.1685000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90819, 'Hachimantai', 'Hachimantai', 'Hachimantai,Hacimantai,Hacimantajus,Hatimantai-chhi,Hatimantai-chhī,Hačimantai,Hačimantajus,Khatimantaj,ba fan ping,ba fan ping shi,hachimantai si,hachymantay  aywath,hatshymantay,Хатимантай,Хатімантай,هاتشيمانتاي,هاچیمانتای، ایواته,ہاچیمانٹائی،اواٹے,八幡平,八幡平市,하치만타이 시', 39.8997900, 141.1298900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90820, 'Ninohe', 'Ninohe', 'er hu,二戸', 40.2908100, 141.3133400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90821, 'Ōsaki', 'Osaki', 'Osaki,Osaki-chhi,awsaky,awsaky  myagy,da qi,da qi shi,osaki si,Ôsaki-chhī,Ōsaki,Осаки,Осакі,أوساكي,اوساکی، میاگی,大崎,大崎市,오사키 시', 38.5886600, 140.9730000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90822, 'Higashimatsushima', 'Higashimatsushima', 'Higashimatsushima,dong song dao,higashimatsushima,ひがしまつしま,ヒガシマツシマ,東松島', 38.4088600, 141.1790100, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90823, 'Kurihara', 'Kurihara', 'Kurihara,li yuan,栗原', 38.7500000, 141.0000000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90824, 'Izunokuni', 'Izunokuni', 'Izunokuni,yi douno guo,伊豆の国', 35.0390700, 138.9514300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90825, 'Izu', 'Izu', 'Idzu,Isu,Izu,Izu-chhi,Izu-chhī,ayzw  shyzwywka,azw,ijeu si,yi dou,yi dou shi,Ідзу,Идзу,Изу,إزو,ایزو، شیزوئوکا,伊豆,伊豆市,이즈 시', 34.9715900, 138.9464300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90826, 'Kikugawa', 'Kikugawa', 'Kikugawa,ju chuan,菊川', 34.7029100, 138.1197800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90827, 'Kosai', 'Kosai', 'Kosai,hu xi,湖西', 34.7005300, 137.5225300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90828, 'Susono', 'Susono', 'Susono,Susono-chhi,Susono-chhī,ju ye,ju ye shi,seusono si,susonoshi,swswnw,swswnw  shyzwywka,Сусоно,سوسونو,سوسونو، شیزوئوکا,すそのし,裾野,裾野市,스소노 시', 35.1738800, 138.9069100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90829, 'Omaezaki', 'Omaezaki', 'Omaedzaki,Omaehdzaki,Omaesaki,Omaezaki,Omaezaki-chhi,Omaezaki-chhī,awmazaky,oma-ejaki si,xoa ma xea saki,yu qian qi,yu qian qi shi,Омаедзакі,Омаезаки,Омаэдзаки,أومازاكي,اومائه‌زاکی، شیزوئوکا,โอะมะเอะซะกิ,御前崎,御前崎市,오마에자키 시', 34.5988200, 138.2193400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90830, 'Nikaho', 'Nikaho', 'Nikaho,Nikaho-chhi,Nikaho-chhī,Nikakho,nikaho,nikaho shi,nikaho si,nykahw,nykahw  akyta,ren he bao shi,Никахо,Никахо қаласы,Нікахо,نيكاهو,نیکاهو، آکیتا,نیکاہو، اکیتا,にかほ,にかほ市,仁賀保市,니카호 시', 39.2707700, 139.9394900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90831, 'Daisen', 'Daisen', 'Daisen,Daisen-chhi,Daisen-chhī,Dajsen,Dajsen Japonija,da xian,da xian shi,daisen si,daysn  akyta,daysyn,daysyn  akyta,Даисен,Дайсен,Дайсен Япония,Дайсен қаласы,دائسین، اکیتا,دايسين,دایسن، آکیتا,大仙,大仙市,다이센 시', 39.4411600, 140.4896100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90832, 'Oga', 'Oga', 'Oga,Oga-chhi,Oga-chhī,awga  akyta,awgha,nan lu,nan lu shi,oga si,Ога,Ога қаласы,Оґа,أوغا,اوگا، آکیتا,اوگا، اکیتا,男鹿,男鹿市,오가 시', 39.8710000, 139.8492600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90833, 'Yurihonjō', 'Yurihonjo', 'Juri-Khondz''o,Jurihondzso,Jurihondzsó,Jurikhondzjo,Yurihondyo,Yurihonjo,Yurihonjō,Yurihonzyo-chhi,Yurihonzyô-chhī,you li ben zhuang,you li ben zhuang shi,yulihonjo si,ywryhwnjw,ywryhwnjw  akyta,Юрихондзё,Юрихондхзе қаласы,Юриҳонҷо,Юрі-Хондзьо,يوريهونجو,یوریهونجو، آکیتا,یوریھونجو، اکتا,由利本荘,由利本荘市,由利本莊市,유리혼조 시', 39.3895000, 140.0581300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90834, 'Katagami', 'Katagami', 'Katagami,xi shang,潟上', 39.8786900, 139.9976700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90835, 'Kita-Akita', 'Kita-Akita', 'Kita-Akita,bei qiu tian,北秋田', 40.1995600, 140.3938800, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90836, 'Tsugaru', 'Tsugaru', 'Cugaru,Tsugaru,Tugaru-chhi,Tugaru-chhī,jin qing shi,sseugalu si,sung a ru,swgarw  awmwry,tsugaru,tsugaru shi,tswgarw  aywmwry,tswgharw,Тсугару,Цугару,Цугару қаласы,Цуґару,تسوغارو,تسوگارو، آئوموری,سوگارو، اوموری,สึงะรุ,ცუგარუ,つがる,つがる市,津輕市,쓰가루 시', 40.8035700, 140.4029900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90837, 'Hirakawa', 'Hirakawa', 'Hirakaua,Hirakawa,Hirakawa-chhi,Hirakawa-chhī,Hirakaŭa,Khirakava,hi raka wa,hilakawa si,hyrakawa,hyrakawa  aywmwry,ping chuan,ping chuan shi,Хиракава,Хиракава қаласы,Хіракава,هيراكاوا,هیراکاوا، آئوموری,ہیراکاوا، اوموری,ฮิระกะวะ,ჰირაკავა,平川,平川市,히라카와 시', 40.5872800, 140.5710700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90838, 'Towada', 'Towada', 'Touada,Tovada,Towada,Towada-chhi,Towada-chhī,Toŭada,dowada si,shi he tian,shi he tian shi,thoa wa da,twada  aywmwry,twwada,twwada  awmwry,Товада,Товада қаласы,توادا، آئوموری,تووادا,تووادا، اوموری,โทะวะดะ,ტოვადა,十和田,十和田市,도와다 시', 40.6204900, 141.2106700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90839, 'Kitanagoya', 'Kitanagoya', 'Kitanagoya,bei ming gu wu,北名古屋', 35.2296800, 136.8934800, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90840, 'Nisshin', 'Nisshin', 'Nisshin,Nissin,Nissin-chhi,Nissin-chhī,Nissyin,ming gu wu,nis-sin si,nyshyn,nysshyn  aychy,ri jin,ri jin shi,Ниссин,Нисшин,Ніссін,نيشين,نیسشین، آیچی,نیسشین، ایچی,名古屋,日进市,日進,日進市,닛신 시', 35.1658300, 136.9639800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90841, 'Toyoake', 'Toyoake', 'Toyoake,li ming,li ming shi,豊明,豊明市', 35.0380000, 136.9993100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90842, 'Chita', 'Chita', 'Chita,Cita,Tita,Tita-chhi,Tita-chhī,chitashi,chyta  aychy,jita si,tshyta,zhi duo,zhi duo shi,Ĉita,Тита,Тіта,Чита,تشيتا,چیتا، آیچی,چیتا، ایچی,ちたし,知多,知多市,지타 시', 35.0026700, 136.8642000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90843, 'Aisai', 'Aisai', 'Aisai,Aisai-chhi,Aisai-chhī,Aisajus,Aiszai,Ajsaj,ai xi,ai xi shi,aisai,aisai si,aisaishi,aysay,aysay  aychy,aysayy  aychy,xi si,Аисаи,Айсай,آيساي,آیسای، آیچی,ایسائی، ایچی,ไอไซ,აისაი,あいさいし,愛西,愛西市,아이사이 시', 35.1634900, 136.7322200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90844, 'Hashima', 'Hashima', 'Hashima,Hasima,Hasima-chhi,Hasima-chhī,Haŝima,Haşima,Hašima,Khasima,hashyma,hashyma  gyfw,hasima si,yu dao,yu dao shi,Хасима,Хасіма,Ҳашима,هاشيما,هاشیما,هاشیما، گیفو,羽島,羽島市,하시마 시', 35.3290000, 136.6805100, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90845, 'Kaizu', 'Kaizu', 'Kaizu,hai jin,海津', 35.2016900, 136.6350500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90846, 'Kani', 'Kani', 'Kani,Kani-chhi,Kani-chhī,gani si,kany ghyfw,kany  gyfw,ke er,ke er shi,ke r shi,Кани,Кані,كاني غيفو,کانی، گیفو,可児,可児市,可兒市,가니 시', 35.4043500, 137.0559500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90847, 'Minokamo', 'Minokamo', 'Mino-Kamo,Minokamo,Minokamo-chhi,Minokamo-chhī,mei nong jia mao,mei nong jia mao shi,minokamo si,mynwkamw ghyfw,mynwkamw  gyfw,Минокамо,Міно-Камо,مينوكامو غيفو,مینوکامو، گیفو,美濃加茂,美濃加茂市,미노카모 시', 35.4819900, 137.0216600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90848, 'Motosu', 'Motosu', 'Motosu,Motosu-chhi,Motosu-chhī,ben chao,ben chao shi,motoseu si,mwtsw,mwtwsw  gyfw,qi fu,Мотосу,موتسو,موتوسو، گیفو,岐阜,本巢市,本巣,本巣市,모토스 시', 35.4732000, 136.6883100, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90849, 'Gujō', 'Gujo', 'Gudyo,Gudz''o,Gudzjo,Gudzyo,Gujo,Gujō,Guzyo-chhi,Guzyô-chhī,ghwjw ghyfw,gujo si,gwjw  gyfw,jun shang,jun shang shi,Гудзё,Гуҷо,Ґудзьо,غوجو غيفو,گوجو، گیفو,郡上,郡上市,구조 시', 35.7369100, 136.9585200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90850, 'Ena', 'Ena', 'Ehna,Ena,Ena-chhi,Ena-chhī,ana  gyfw,ayna,ena si,hui na,hui na shi,xea na,Ена,Эна,إينا,انا، گیفو,เอะนะ,恵那,恵那市,惠那市,에나 시', 35.4472200, 137.3833200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90851, 'Nanjō', 'Nanjo', 'Nanjo,Nanjō,nan cheng,南城', 26.1444700, 127.7669700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90852, 'Agano', 'Agano', 'Agano,a he ye,阿賀野', 37.7739200, 139.2219200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90853, 'Jōetsu', 'Joetsu', 'Dz''oecu,Dzjoehcu,Dzoecu,Joecu,Joetsu,Joetsu-shi,Zyoetu-chhi,Zyôetu-chhī,co xeasu,jo-esseu si,jwytsw,jwytsw  nygata,jwyytsw  nygata,shang yue,shang yue shi,Џоецу,Дзьоецу,Дзёэцу,Йоецу,Ҷоетсу,جوئتسو، نیگاتا,جوئیتسو، نیگاتا,جويتسو,โจเอะสึ,上越,上越市,조에쓰 시', 37.1482800, 138.2364200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90854, 'Minamiuonuma', 'Minamiuonuma', 'Minamiuonuma,nan yu zhao,南魚沼', 37.0825900, 138.8741300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90855, 'Myoko', 'Myoko', 'Myoko,Myōkō,miao gao,妙高', 37.0149700, 138.2732400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90856, 'Sado', 'Sado', 'Japonija,Sado,zuo du,Япония,佐渡', 38.0249600, 138.3593100, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90857, 'Tainai', 'Tainai', 'Tainai,tai nei,胎内', 38.0664600, 139.3743600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90858, 'Uonuma', 'Uonuma', 'Juonuma,Uonuma,Uonuma-chhi,Uonuma-chhī,awywnwma  nygata,uonuma si,yu zhao,yu zhao shi,ywnwma,Уонума,Юонума,اوئونوما، نیگاتا,يونوما,魚沼,魚沼市,우오누마 시', 37.2448800, 138.9623400, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90859, 'Fujiidera', 'Fujiidera', 'Fujiidera,teng jing si,藤井寺', 34.5676000, 135.5974000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90860, 'Habikino', 'Habikino', 'Habikino,Habikino-chhi,Habikino-chhī,Khabikino,ha bi ki noa,habikino,habikino si,habykynw,yu ye ye,yu ye ye shi,Хабикино,Хабікіно,Ҳабикино,هابيكينو,هابی‌کینو، اوساکا,ฮะบิกิโนะ,はびきの,羽曳野,羽曳野市,하비키노 시', 34.5527600, 135.5909700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90861, 'Hannan', 'Hannan', 'Hannan,ban nan,阪南', 34.3333300, 135.2500000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90862, 'Kawachi-Nagano', 'Kawachi-Nagano', 'Kawachi-Nagano,he nei zhang ye,河内長野', 34.4410800, 135.5828300, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90863, 'Sennan', 'Sennan', 'Sennan,quan nan,泉南', 34.3483500, 135.2684200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90864, 'Shijōnawate', 'Shijonawate', 'Shijonawate,Shijōnawate,si tiao zhui,四条畷,四條畷', 34.7333300, 135.6833300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90865, 'Hokuto', 'Hokuto', 'Hokuto,Khokuto,bei dou,bei dou shi,hokuto si,hwkwtw,hwkwtw  hwkaydw,Хокуто,هوكوتو,هوکوتو، هوکایدو,北斗,北斗市,호쿠토 시', 41.8162600, 140.6347200, 'JP', '2017-06-12', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90866, 'Saitama', 'Saitama', 'Saitama,saitama,Саитама,さいたま', 35.9080700, 139.6565700, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90867, 'Niseko Town', 'Niseko Town', 'Nisekoa,Nisekoan,Nisekoā', 42.7787100, 140.6690300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90868, 'Higashimurayama-shi', 'Higashimurayama-shi', 'Higashi-Murayama,Higashi-Murayama-shi,Higashimurayama,dong cun shan,dong cun shan shi,東村山,東村山市', 35.7545900, 139.4685200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90869, 'Fujikawaguchiko', 'Fujikawaguchiko', 'Fudzi-Kavagutiko,Fudzikavaguchiko,Fudzikavagutiko,Fudzsikavagucsiko,Fujikavagutiko,fu ci ka wangu chi koa,fu shi he kou hu ding,hujikawaguchiko jeong,Фудзикавагутико,Фудзі-Каваґутіко,Фуџикавагучико,Ֆուձիկավագուտիկո,ฟุจิกะวะงุชิโกะ,富士河口湖町,후지카와구치코 정', 35.4893300, 138.6883200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90870, 'Yawatahama', 'Yawatahama', 'ba fan bang,八幡浜', 33.4573700, 132.4328000, 'JP', '2017-07-30', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90871, 'Kirishima', 'Kirishima', 'wu dao,霧島', 31.7408700, 130.7628800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90872, 'amami', 'amami', 'yan mei,奄美', 28.3769000, 129.4937900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90873, 'Rishiri Town', 'Rishiri Town', 'Rishiri,Ришири', 45.1592800, 141.1962900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90874, 'Arashiyama', 'Arashiyama', 'Arashijama,lan shan,Арашияма,嵐山', 35.0148100, 135.6775500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90875, 'Oda', 'Oda', 'da tian,da tian shi,大田,大田市', 35.2010300, 132.4996700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90876, 'Dazaifu', 'Dazaifu', 'Dadzajfu,Dasaipu,Dazaifu-chhi,Dazaifu-chhī,Dazaifu-shiyakusho,dajaihu si,dazaifushiyakusho,dazayfw,dazayfw  fwkwywka,tai zai fu,tai zai fu shi,Дадзайфу,دازايفو,دازایفو، فوکوئوکا,だざいふしやくしょ,太宰府,太宰府市,다자이후 시', 33.5127800, 130.5238900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90877, 'Amakusa', 'Amakusa', 'AXJ,Amakusa,amakusashiyakusho,tian cao,tian cao shi yi suo,あまくさしやくしょ,天草,天草市役所', 32.4586100, 130.1930600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90878, 'Kamigyō-ku', 'Kamigyo-ku', '', 35.0295400, 135.7566600, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90879, 'Buzen', 'Buzen', 'li qian,豊前', 33.6115300, 131.1300200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90880, 'Yoshitomi', 'Yoshitomi', '', 33.6024700, 131.1759900, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90881, 'Ikata-chō', 'Ikata-cho', 'Ikata-cho,Ikata-chō,ikatachou,yi fang ding,いかたちょう,伊方町', 33.4883300, 132.3541700, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90882, 'Inuotose', 'Inuotose', 'Inuotose,inuotose,quan luo lai,いぬおとせ,イヌオトセ,犬落瀬', 40.6017600, 141.3266200, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90883, 'Furudate', 'Furudate', 'Furudate,furudate,gu guan,ふるだて,フルダテ,古舘', 40.5293400, 141.3055300, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90884, 'Hakuba', 'Hakuba', 'Khakuba,bai ma cun,hakuba chon,Хакуба,白馬村,하쿠바 촌', 36.6981800, 137.8618500, 'JP', '2017-04-09', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90885, 'Nagaoka', 'Nagaoka', 'Nagaoka,zhang gang,zhang gang jing,長岡,長岡京', 34.9309700, 135.6920300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90886, 'Kofu', 'Kofu', 'jia fu,甲府', 35.6976300, 138.5881900, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90887, 'Tsushima', 'Tsushima', 'Cusima,TSJ,Tsushima,dui ma,dui ma shi,sseusima si,tswshyma,Цусима,تسوشيما,تسوشیما,対馬,対馬市,對馬市,쓰시마 시', 34.2063400, 129.2907600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90888, 'Kuroishi', 'Kuroishi', 'hei shi,黒石', 40.6154500, 140.7036200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90889, 'Ichikawa-minami', 'Ichikawa-minami', 'Ichikawa-minami,chuan,shi chuan nan,川,市川南', 35.7263400, 139.9039200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90890, 'Eniwa', 'Eniwa', 'hui ting,恵庭', 42.8935700, 141.5760000, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90891, 'Arao', 'Arao', 'Arao,arao,huang wei,あらお,アラオ,荒尾', 32.9788800, 130.4457200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90892, 'Ukiha', 'Ukiha', 'ukiha,うきは', 33.3563400, 130.7496600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90893, 'Iga', 'Iga', 'yi he,yi he shi,伊賀,伊賀市', 34.7579700, 136.1346800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90894, 'Kihoku', 'Kihoku', 'ji bei ding,紀北町', 34.2105200, 136.3347500, 'JP', '2017-04-05', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90895, 'Kuwana', 'Kuwana', 'sang ming,sang ming shi,桑名,桑名市', 35.0519200, 136.6695800, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90896, 'Matsusaka', 'Matsusaka', 'song ban,song ban shi,松坂市,松阪', 34.5789500, 136.5370600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90897, 'Minamiise', 'Minamiise', 'nan yi shi ding,南伊勢町', 34.3496700, 136.6994500, 'JP', '2017-04-05', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90898, 'Yonedacho Sendo', 'Yonedacho Sendo', '', 34.7756000, 134.8255100, 'JP', '2017-04-14', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90899, 'Hokuto', 'Hokuto', 'bei du,bei du shi,北杜,北杜市', 35.8345800, 138.3960600, 'JP', '2017-07-21', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90900, 'Fujimino', 'Fujimino', 'fujimi ye,ふじみ野', 35.8648500, 139.5103200, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90901, 'Himi', 'Himi', 'bing jian,bing jian shi,氷見,氷見市', 36.8466600, 136.9835500, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90902, 'Takizawa', 'Takizawa', 'long ze,滝沢', 39.8028000, 141.1346600, 'JP', '2017-07-22', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90903, 'Tōon', 'Toon', 'dong wen,東温', 33.7942700, 132.8901100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90904, 'Yasu', 'Yasu', 'ye zhou,野洲', 35.1005300, 136.0177800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90905, 'Yame', 'Yame', 'ba nu,八女', 33.2279200, 130.6487300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90906, 'Yamatokōriyama', 'Yamatokoriyama', 'da he jun shan,大和郡山', 34.6065800, 135.7703300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90907, 'Yamato', 'Yamato', 'da he,大和', 35.4727600, 139.4510100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90908, 'Yamanashi', 'Yamanashi', 'shan li,山梨', 35.6715200, 138.6982700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90909, 'Urayasu', 'Urayasu', 'pu an,浦安', 35.6418800, 139.9040200, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90910, 'Tosashimizu', 'Tosashimizu', 'tu zuo qing shui,土佐清水', 32.7839600, 132.9632400, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90911, 'Toda', 'Toda', 'hu tian,戸田', 35.8144700, 139.6601800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90912, 'Taku', 'Taku', '', 33.2770900, 130.1092800, 'JP', '2017-07-25', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90913, 'Taketa', 'Taketa', 'zhu tian,竹田', 32.9593500, 131.3673000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90914, 'Takeo', 'Takeo', 'wu xiong,武雄', 33.1918700, 130.0128100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90915, 'Takasago', 'Takasago', 'gao sha,高砂', 34.7629800, 134.7922900, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90916, 'Tachikawa', 'Tachikawa', 'li chuan,立川', 35.7091000, 139.4189100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90917, 'Shimonoseki', 'Shimonoseki', 'xia guan,下関', 34.1673600, 131.0001200, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90918, 'Saito', 'Saito', 'xi dou,西都', 32.0819900, 131.3995700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90919, 'Sagamihara', 'Sagamihara', '', 35.5489900, 139.2606400, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90920, 'Ogōri', 'Ogori', 'xiao jun,小郡', 33.3873800, 130.5486500, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90921, 'Ogi', 'Ogi', 'xiao cheng,小城', 33.2802800, 130.1950300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90922, 'Nishinomiya', 'Nishinomiya', 'shen hu,神戸', 34.8095800, 135.2368900, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90923, 'Nagakute', 'Nagakute', '', 35.1732500, 137.0566700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90924, 'Munakata', 'Munakata', 'zong xiang,宗像', 33.7957000, 130.5589500, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90925, 'Mitoyo', 'Mitoyo', 'san li,三豊', 34.2105200, 133.6746000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90926, 'Mimasaka', 'Mimasaka', 'mei zuo,美作', 35.0413800, 134.2244300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90927, 'Kunitachi', 'Kunitachi', '', 35.6833000, 139.4384800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90928, 'Miyake', 'Miyake', '', 34.0899100, 139.5195000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90929, 'Hachijō', 'Hachijo', '', 33.1027600, 139.7788000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90930, 'Ōshima', 'Oshima', '', 34.7482400, 139.3624300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90931, 'Ogasawara', 'Ogasawara', '', 27.0968800, 142.2037700, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90932, 'Kizugawa', 'Kizugawa', 'mu jin chuan,木津川', 34.7366800, 135.8399400, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90933, 'Kawanishi', 'Kawanishi', 'chuan xi,川西', 34.8811400, 135.3986000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90934, 'Katano', 'Katano', 'jiao ye,交野', 34.7932900, 135.6859600, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90935, 'Hyūga', 'Hyuga', 'ri xiang,日向', 32.4227200, 131.6409300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90936, 'Sakai', 'Sakai', 'ban jing,坂井', 36.1473000, 136.1940800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90937, 'Higashihiroshima', 'Higashihiroshima', 'dong guang dao,東広島', 34.4086100, 132.7368200, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90938, 'Higashikurume', 'Higashikurume', '', 35.7520200, 139.5116900, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90939, 'Hamura', 'Hamura', 'yu cun,羽村', 35.7623200, 139.3195200, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90940, 'Funabashi', 'Funabashi', 'chuan qiao,船橋', 35.7204500, 140.0114800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90941, 'Fuji-yoshida', 'Fuji-yoshida', 'fu shi ji tian,富士吉田', 35.4848600, 138.8112300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90942, 'Fuchū', 'Fuchu', 'fu zhong,府中', 35.6745200, 139.4821600, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90943, 'Fujimi', 'Fujimi', 'fu shi jian,富士見', 35.8481500, 139.5552100, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90944, 'Chikugo', 'Chikugo', '', 33.2053700, 130.4918300, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90945, 'Sanuki', 'Sanuki', 'sanuki,さぬき', 34.2668600, 134.2295800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90946, 'Ayase', 'Ayase', 'ling lai,綾瀬', 35.4351500, 139.4256000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90947, 'Arida', 'Arida', 'you tian,有田', 34.0808900, 135.1190500, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90948, 'Aira', 'Aira', 'e liang,姶良', 31.7742900, 130.5920800, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90949, 'Ama', 'Ama', 'ama,あま', 35.1830700, 136.7997000, 'JP', '2017-07-26', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90950, 'Fukaya', 'Fukaya', 'shen gu,深谷', 36.1771000, 139.2602900, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90951, 'Kodaira', 'Kodaira', 'xiao ping,小平', 35.7260300, 139.4850800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90952, 'Nishitōkyō', 'Nishitokyo', 'xi dong jing,西東京', 35.7335500, 139.5476100, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90953, 'Nanyō', 'Nanyo', 'nan yang,南陽', 38.0432200, 140.1127600, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90954, 'Kakogawa', 'Kakogawa', 'jia gu chuan,加古川', 34.7506400, 134.8695400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90955, 'Kan’onji', 'Kan''onji', 'guan yin si,観音寺', 34.0697200, 133.6490200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90956, 'Katō', 'Kato', 'jia dong,加東', 34.9242200, 135.0260900, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90957, 'Mine', 'Mine', 'mei mi,美祢', 34.1868100, 131.2162400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90958, 'Hida', 'Hida', 'fei tuo,飛騨', 36.2448300, 137.1732300, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90959, 'Kiyose', 'Kiyose', 'qing lai,清瀬', 35.7795200, 139.5301400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90960, 'Jōyō', 'Joyo', 'cheng yang,城陽', 34.8439600, 135.8056100, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90961, 'Yatomi', 'Yatomi', 'mi fu,弥富', 35.1053000, 136.7337800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90962, 'Tome', 'Tome', 'deng mi,登米', 38.7088200, 141.1557800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90963, 'Kamagaya', 'Kamagaya', 'lianke gu,鎌ケ谷', 35.7697100, 140.0023800, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90964, 'Ebino', 'Ebino', 'ebino,えびの', 32.0476600, 130.8444200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90965, 'Isa', 'Isa', 'yi zuo,伊佐', 32.0671600, 130.6118200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90966, 'Ako', 'Ako', 'chi sui,赤穂', 34.7596700, 134.3703500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90967, 'Bizen', 'Bizen', 'bei qian,備前', 34.7867400, 134.2354200, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90968, 'Higashiōmi', 'Higashiomi', 'dong jin jiang,東近江', 35.1039000, 136.2627400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90969, 'Nakatsu', 'Nakatsu', 'zhong jin,中津', 33.4623800, 131.1417400, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90970, 'Usa', 'Usa', 'yu zuo,宇佐', 33.4394600, 131.3367500, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90971, 'Etajima', 'Etajima', 'jiang tian dao,江田島', 34.2386300, 132.4796700, 'JP', '2017-07-27', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90972, 'Shimanto', 'Shimanto', 'si wan shi,四万十', 33.0783100, 132.8523400, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90973, 'Tatsuno', 'Tatsuno', 'tatsuno,たつの', 34.8318400, 134.5433800, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90974, 'Iki', 'Iki', 'yi qi,壱岐', 33.7828600, 129.7209000, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90975, 'Tosa', 'Tosa', 'gao zhi,高知', 33.5047600, 133.4447500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90976, 'Tsuru', 'Tsuru', '', 35.5473100, 138.9095900, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90977, 'Nankoku', 'Nankoku', '', 33.5682900, 133.5834500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90978, 'Aki-takata', 'Aki-takata', 'an yun gao tian,安芸高田', 34.6741600, 132.6818800, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90979, 'Seiyo', 'Seiyo', 'xi yu,西予', 33.3881700, 132.6317600, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90980, 'Awa', 'Awa', 'a bo,阿波', 34.0920500, 134.2845200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90981, 'Yatsushiro', 'Yatsushiro', 'ba dai,八代', 32.5572300, 130.6528500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90982, 'Kai', 'Kai', 'jia fei,甲斐', 35.6846300, 138.5097900, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90983, 'Sakura', 'Sakura', '', 36.7207200, 139.9877900, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90984, 'Awaji', 'Awaji', 'dan lu,淡路', 34.4776900, 134.9306500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90985, 'Warabi', 'Warabi', 'jue,蕨', 35.8218800, 139.6854500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90986, 'Miyoshi', 'Miyoshi', 'miyoshi,みよし', 35.0897100, 137.0899800, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90987, 'Itoshima', 'Itoshima', 'mi dao,糸島', 33.5422500, 130.1842100, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90988, 'Yufu', 'Yufu', 'you bu,由布', 33.1956000, 131.3782900, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90989, 'Akiruno', 'Akiruno', 'akiru ye,あきる野', 35.7285400, 139.2318000, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90990, 'Shikokuchūō', 'Shikokuchuo', '', 33.9754000, 133.5489500, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90991, 'Ureshino', 'Ureshino', 'xi ye,嬉野', 33.1352500, 130.0571800, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90992, 'Narashino', 'Narashino', 'xi zhi ye,習志野', 35.6818400, 140.0415200, 'JP', '2017-07-29', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90993, 'Minamibōsō', 'Minamiboso', 'nan fang zong,南房総', 35.0312600, 139.9265100, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90994, 'Ōamishirasato', 'Oamishirasato', 'da wang bai li,大網白里', 35.5118300, 140.3525700, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90995, 'Sodegaura', 'Sodegaura', 'xiuke pu,袖ケ浦', 35.4136800, 140.0213500, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90996, 'Echizen', 'Echizen', 'yue qian,越前', 35.8857100, 136.1707300, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90997, 'Kama', 'Kama', 'jia ma,嘉麻', 33.5348800, 130.7422800, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90998, 'Miyama', 'Miyama', 'miyama,みやま', 33.1210200, 130.5000700, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(90999, 'Miyawaka', 'Miyawaka', 'gong ruo,宮若', 33.7170600, 130.6411700, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91000, 'Shirakawa', 'Shirakawa', 'bai he,白河', 37.1195400, 140.2621100, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91001, 'Mizuho', 'Mizuho', 'rui sui,瑞穂', 35.3943000, 136.6689800, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91002, 'Motosu', 'Motosu', 'ben chao,本巣', 35.6553400, 136.6101800, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91003, 'Yamagata', 'Yamagata', 'shan xian,山県', 35.5830600, 136.7585000, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91004, 'Shibetsu', 'Shibetsu', 'shi bie,士別', 44.1713700, 142.3951700, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91005, 'Asago', 'Asago', 'chao lai,朝来', 35.2590800, 134.8139200, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91006, 'Kasai', 'Kasai', 'jia xi,加西', 34.9263300, 134.8453300, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91007, 'Minamiawaji', 'Minamiawaji', 'nanawaji,南あわじ', 34.2739600, 134.7751200, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91008, 'Sanda', 'Sanda', 'san tian,三田', 34.9471600, 135.2138900, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91009, 'Shisō', 'Shiso', 'rou su,宍粟', 34.9810700, 134.5639800, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91010, 'Tanba', 'Tanba', 'dan bo,丹波', 35.1603400, 135.0391400, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91011, 'Nomi', 'Nomi', 'neng mei,能美', 36.4290200, 136.5456400, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91012, 'Tōkai', 'Tokai', 'dong hai,東海', 35.0226900, 136.9088700, 'JP', '2017-07-31', 112);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91013, 'Yala', 'Yala', 'Yala,Yala Station', 0.0990600, 34.5375700, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91014, 'Wundanyi', 'Wundanyi', 'Wundanyi', -3.4019300, 38.3640200, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91015, 'Wote', 'Wote', 'Wote', -1.7807900, 37.6288200, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91016, 'Witu', 'Witu', 'Witu', -2.3889200, 40.4382700, 'KE', '2017-05-07', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91017, 'Webuye', 'Webuye', 'Broderick Falls,Webuye', 0.6075100, 34.7696600, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91018, 'Wajir', 'Wajir', 'El Sadi,Uadzhir,Vadzhir,Vadziras,Vadžiras,WJR,Wajeer,Wajir,vajiri,wa ji er,wajiru,wajyr,wajyr  knya,Ваджир,Уаджир,واجیر,واجیر، کنیا,ვაჯირი,ワジール,瓦吉爾', 1.7471000, 40.0573200, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91019, 'Voi', 'Voi', 'Voi,boi,voi,wwy,Вои,ووی,ვოი,ボイ', -3.3960500, 38.5560900, 'KE', '2013-10-30', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91020, 'Thika', 'Thika', 'Dhika,Thika,Tik,Тик', -1.0332600, 37.0693300, 'KE', '2013-08-17', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91021, 'Taveta', 'Taveta', 'Taveta', -3.3987900, 37.6833600, 'KE', '2012-05-29', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91022, 'Takaungu', 'Takaungu', 'Takaungu', -3.6836700, 39.8566100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91023, 'Sotik', 'Sotik', 'Chamagel,Chemagal,Chemagel,Sotik', -0.6833300, 35.1187100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91024, 'Shimoni', 'Shimoni', 'Shimoni', -4.6475600, 39.3817500, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91025, 'Sawa Sawa', 'Sawa Sawa', 'Sawa Sawa,Sawasawa', -4.4716600, 39.4846300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91026, 'Sagana', 'Sagana', 'Sagana', -0.6666700, 37.2000000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91027, 'Rumuruti', 'Rumuruti', '', 0.2669900, 36.5388600, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91028, 'Rongai', 'Rongai', 'Rongai', -0.1733300, 35.8638200, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91029, 'Pumwani', 'Pumwani', 'Pumuani,Pumwani', -1.2833300, 36.8500000, 'KE', '2013-05-05', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91030, 'Oyugis', 'Oyugis', 'Oyugis', -0.5089800, 34.7358300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91031, 'Othaya', 'Othaya', 'Othaya', -0.5651500, 36.9609100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91032, 'Ogembo', 'Ogembo', 'Ogembo', -0.7983900, 34.7253100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91033, 'Nyeri', 'Nyeri', 'N''eri,NYE,Njeri,Njeris,Nyeri,Nyiri,ni ye li,nieli,nieri,nyry  knya,nyyry,Њери,Ньери,نیئری,نیری، کنیا,ნიერი,ニエリ,尼耶利,니에리', -0.4201300, 36.9475900, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91034, 'Nyahururu', 'Nyahururu', 'Nyahururu,Nyahururu Falls,Thompsons Falls,Thomsons Falls,Thorason''s Falls,Thorason’s Falls', 0.0421000, 36.3673400, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91035, 'Ngong', 'Ngong', 'Ngong', -1.3617500, 36.6566000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91036, 'Naro Moru', 'Naro Moru', 'Naro Moru', -0.1675600, 37.0212900, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91037, 'Narok', 'Narok', 'Narok', -1.0782900, 35.8601200, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91038, 'Nanyuki', 'Nanyuki', 'NYK,Nanjuki,Nanyuki,na niu ji,nanywky,nanywky  knya,Нанюки,نانیوکی,نانیوکی، کنیا,ნანიუკი,納紐基', 0.0166700, 37.0728300, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91039, 'Nandi Hills', 'Nandi Hills', '', 0.1066000, 35.1837800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91040, 'Nambale', 'Nambale', 'Nambale,Nambare', 0.4459400, 34.2519400, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91041, 'Namanga', 'Namanga', 'Namanga', -2.5432700, 36.7905300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91042, 'Nakuru', 'Nakuru', 'Gorad Nakuru,NUU,Nakuru,na ku lu,nakulu,nakuru,nakwrw,nakwrw  knya,Горад Накуру,Накуру,ناکورو,ناکورو، کنیا,ნაკურუ,ナクル,纳库鲁,나쿠루', -0.2833300, 36.0666700, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91043, 'Naivasha', 'Naivasha', 'Naivasa,Naivasha,Naivaša,Najvasha,nai wa sha,naivasha,naywasha  knya,Найваша,نایواشا، کنیا,ნაივაშა,奈瓦沙', -0.7166700, 36.4359100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91044, 'Nairobi', 'Nairobi', 'Gorad Najrobi,NBO,Nairoba,Nairobi,Nairobia,Nairobis,Nairobo,Nairoby,Nairobî,Nairompi,Nairòbi,Nairóbi,Najrobi,Najrobo,Nayrobi,Nayroobi,Naíróbí,Naýrobi,na''irobi,nai luo bi,nailobi,nairobi,nairopi,nayreabi,nayrwby,nei luo bi,nirobi,nyrwby,nyyrwby,Ναϊρόμπι,Горад Найробі,Найроби,Найробі,Најроби,Նայրոբի,נייראבי,ניירובי,نايروبى,نایروبی,نایرۆبی,نيروبي,نیروبی,नैरोबी,নাইরোবি,ਨੈਰੋਬੀ,நைரோபி,ನೈರೋಬಿ,നയ്റോബി,ไนโรบี,ནའི་རོ་བི།,နိုင်ရိုဘီမြို့,ნაირობი,ናይሮቢ,ナイロビ,内罗毕,奈洛比,나이로비', -1.2833300, 36.8166700, 'KE', '2014-10-29', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91045, 'Mwingi', 'Mwingi', '', -0.9343500, 38.0600500, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91046, 'Murang’a', 'Murang''a', 'Fort Hall,Murang''a,Murang’a', -0.7166700, 37.1500000, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91047, 'Mumias', 'Mumias', 'Mumias', 0.3351100, 34.4864000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91048, 'Muhoroni', 'Muhoroni', 'Muhoroni', -0.1540600, 35.1987800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91049, 'Mtito Andei', 'Mtito Andei', 'Mtito Andei,Mutitu Andei', -2.6900900, 38.1663100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91050, 'Moyale', 'Moyale', 'Fort Harrington,Moyale,OYL,Port Harrington', 3.5216000, 39.0547200, 'KE', '2014-02-01', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91051, 'Mombasa', 'Mombasa', 'Gorad Mambasa,MBA,Mombaaso,Mombaca,Mombasa,Mombassa,Mombaça,Mombása,Mompasa,Mvita,meng ba sa,mmbasa,momabaka,mombasa,monbasa,mwmbasa,mwmbsh,Μομπάσα,Горад Мамбаса,Момбаса,מומבסה,ممباسا,مومباسا,मोम्बासा,মোমবাকা,მომბასა,モンバサ,蒙巴萨,몸바사', -4.0546600, 39.6635900, 'KE', '2014-10-29', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91052, 'Molo', 'Molo', 'Molo,Моло', -0.2479000, 35.7374300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91053, 'Migori', 'Migori', 'Migori', -1.0634300, 34.4731300, 'KE', '2016-12-10', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91054, 'Meru', 'Meru', 'Meru,Mery,Меры', 0.0462600, 37.6558700, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91055, 'Mbale', 'Mbale', 'Maragoli', -3.4000000, 38.3833300, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91056, 'Maua', 'Maua', 'Maua', 0.2320600, 37.9405200, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91057, 'Marsabit', 'Marsabit', 'Marsabit,RBT', 2.3283900, 37.9898600, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91058, 'Mariakani', 'Mariakani', 'Mariakani', -3.8633200, 39.4736200, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91059, 'Maralal', 'Maralal', 'Maralal', 1.0967900, 36.6979900, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91060, 'Maragua', 'Maragua', 'Maragua', -0.7833300, 37.1333300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91061, 'Mandera', 'Mandera', 'Madera,Mandera,Mandere,NDE,Мандере', 3.9372600, 41.8568800, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91062, 'Malindi', 'Malindi', 'MYD,Malindi,Malindis,Melinde,ma lin di,malindi,mallindi,malyndy,malyndy  knya,marindi,Малинди,Малінді,ماليندي,مالیندی,مالیندی، کنیا,მალინდი,マリンディ,馬林迪,말린디', -3.2179900, 40.1169200, 'KE', '2013-08-17', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91063, 'Malikisi', 'Malikisi', 'Malakisi,Malikisi', 0.6769400, 34.4216700, 'KE', '2010-08-09', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91064, 'Malaba', 'Malaba', 'Malaba', 0.6345700, 34.2756000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91065, 'Makueni', 'Makueni', 'Makueni,Makueni Boma', -1.8040900, 37.6203400, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91066, 'Magadi', 'Magadi', 'Magadi', -1.9012200, 36.2870000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91067, 'Machakos', 'Machakos', 'Machakos,Machakosskij,Makhakos,Masaku,ma cha ke si,machakoseu,machakosu,machakws,machakws  knya,Махакос,Мачакос,Мачакосский,ماچاکوس,ماچاکوس، کنیا,მაჩაკოსი,マチャコス,马查科斯,마차코스', -1.5166700, 37.2666700, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91068, 'Kipkelion', 'Kipkelion', 'Kipkelion,Lumbwa,Lumowa', -0.1967500, 35.4684700, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91069, 'Lugulu', 'Lugulu', 'Busia,Lugulu', 0.3936100, 34.3052800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91070, 'Luanda', 'Luanda', 'Luanda,Lwanda', 0.2966800, 34.0645900, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91071, 'Londiani', 'Londiani', 'Londiani', -0.1649600, 35.5908700, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91072, 'Lodwar', 'Lodwar', 'LOK,Lodvar,Lodvaras,Lodwar,lodvari,luo de wa er,lwdwar,Лодвар,لودوار,ლოდვარი,洛德瓦爾', 3.1191100, 35.5972700, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91073, 'Litein', 'Litein', 'Litein', -0.5822600, 35.1902900, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91074, 'Limuru', 'Limuru', 'Limuru', -1.1000000, 36.6500000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91075, 'Lamu', 'Lamu', 'Amu,Antiga Cidade de Lamu,Gorad Lamu,LAU,Lama,Lamu,la mu,lamu,lamw,ramu,Горад Ламу,Лама,Ламу,לאמו,لامو,ლამუ,ラム,拉穆,라무', -2.2716900, 40.9020100, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91076, 'Kwale', 'Kwale', 'Kwale,kua lei,夸勒', -4.1737500, 39.4520600, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91077, 'Konza', 'Konza', 'Konza', -1.7426000, 37.1294100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91078, 'Kitui', 'Kitui', 'Kitui', -1.3669600, 38.0105500, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91079, 'Kitale', 'Kitale', 'KTL,Kitale,Kitalė,ji ta lai,kitare,kytalh  knya,Китале,کیتاله، کنیا,کیتالے,კიტალე,キタレ,基塔萊', 1.0157200, 35.0062200, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91080, 'Kisumu', 'Kisumu', 'Gorad Kisumu,KIS,Kisumo,Kisumu,Lady Whitehouse,Port Florence,Winam,ji su mu,kisumu,kyswmw  knya,kyzymw,Горад Кісуму,Кисуму,Кісуму,كيزيمو,کیسومو، کنیا,კისუმუ,キスム,基蘇木,키수무', -0.1022100, 34.7617100, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91081, 'Kisii', 'Kisii', 'Kisii,Kisii town,ji xi,kysy  knya,kysyy  kynya,کیسی، کنیا,کیسیی، کینیا,კისიი,基西', -0.6817400, 34.7666600, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91082, 'Kipini', 'Kipini', '', -2.5256500, 40.5262000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91083, 'Kinango', 'Kinango', '', -4.1372300, 39.3152800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91084, 'Kihancha', 'Kihancha', 'Kihancha,Kinancha', -1.1837600, 34.6261600, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91085, 'Kilifi', 'Kilifi', 'Kilifi,ji li fei,kylyfy,kylyfy  knya,Килифи,کیلیفی,کیلیفی، کنیا,კილიფი,基利菲', -3.6304500, 39.8499200, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91086, 'Kikuyu', 'Kikuyu', 'Gikuyu,Kikuyu', -1.2457600, 36.6632800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91087, 'Kijabe', 'Kijabe', 'Kijabe', -0.9330400, 36.5758100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91088, 'Kiambu', 'Kiambu', 'Kiambu,Kiambuu,Киамбу', -1.1666700, 36.8333300, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91089, 'Keruguya', 'Keruguya', 'Kerugoya,Keruguya', -0.4988700, 37.2803100, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91090, 'Keroka', 'Keroka', 'Keroka', -0.7758400, 34.9453100, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91091, 'Kericho', 'Kericho', '', -0.3677400, 35.2831400, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91092, 'Karuri', 'Karuri', '', -0.7000000, 37.1833300, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91093, 'Kapsowar', 'Kapsowar', 'Kapsowar,Marakwet', 0.9811900, 35.5614500, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91094, 'Kapsabet', 'Kapsabet', 'Kapsabet,Nandi', 0.2038700, 35.1050000, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91095, 'Kapenguria', 'Kapenguria', 'Kap-Nguria,Kapenguria', 1.2333300, 35.1166700, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91096, 'Kangundo', 'Kangundo', 'Kangundo,Kangundu', -1.2979200, 37.3470500, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91097, 'Kangema', 'Kangema', 'Kangema', -0.6833300, 36.9666700, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91098, 'Kakamega', 'Kakamega', 'GGM,Kakamega,Kakamege,ka ka mei jia,kakamga  knya,Какамега,Какамеге,کاکامگا، کنیا,კაკამეგა,卡卡梅加', 0.2842200, 34.7522900, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91099, 'Kajiado', 'Kajiado', 'Kajiado,Ol Kejuado', -1.8523800, 36.7768300, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91100, 'Kabarnet', 'Kabarnet', 'Kabarnet', 0.4919400, 35.7430300, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91101, 'Isiolo', 'Isiolo', 'Isiolo,Исиоло', 0.3546200, 37.5821800, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91102, 'Homa Bay', 'Homa Bay', 'Homa,Homa Bay', -0.5273100, 34.4571400, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91103, 'Hola', 'Hola', 'Galole,HOA,Hola', -1.4825600, 40.0334100, 'KE', '2015-11-26', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91104, 'Gazi', 'Gazi', 'Gasi,Gaze,Gazi', -4.4240200, 39.5058800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91105, 'Garissa', 'Garissa', 'GAS,Gaarisa,Garisa,Garissa,galisa,garisa,garissa,garysa,garysa  knya,gharysa,jia li sa,Гариса,Гарисса,Гарісса,גאריסה,غاريسا,گاریسا,گاریسا، کنیا,გარისა,ガリッサ,加里萨,가리사', -0.4527500, 39.6460100, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91106, 'Embu', 'Embu', 'Ehmba,Ehmbu,Embu,Kirimari,ambw  knya,embu,en bu,Ембу,Эмба,Эмбу,امبو، کنیا,عمبو، کینیا,ემბუ,恩布', -0.5311200, 37.4506100, 'KE', '2013-05-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91107, 'Eldoret', 'Eldoret', 'EDL,Ehldoret,Eldoret,Eldoretas,Olderet,Olteret,ai er duo lei te,aldwrt,aldwrt  knya,eldoleteu,erudoretto,xel do ret,Елдорет,Элдорет,الدورت,الدورت، کنیا,เอลโดเรต,ელდორეტი,エルドレット,埃爾多雷特,엘도레트', 0.5203600, 35.2699300, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91108, 'Eldama Ravine', 'Eldama Ravine', 'Eldama,Eldama Ravine,Shimoni', 0.0515800, 35.7307800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91109, 'Chuka', 'Chuka', 'Chuka', -0.3331600, 37.6458700, 'KE', '2013-11-12', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91110, 'Chepareria', 'Chepareria', 'Cheberia,Chepareria', 1.3077400, 35.2039000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91111, 'Butere', 'Butere', 'Butere', 0.2063600, 34.4934800, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91112, 'Busia', 'Busia', 'Busia', 0.4600500, 34.1116900, 'KE', '2013-08-04', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91113, 'Port Bunyala', 'Port Bunyala', 'Bunyala,Port Bunyala,Port Victoria', 0.0938800, 33.9755900, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91114, 'Bungoma', 'Bungoma', 'Bungoma,Бунгома', 0.5635000, 34.5605500, 'KE', '2013-06-27', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91115, 'Bondo', 'Bondo', 'Bondo', 0.2386100, 34.2694400, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91116, 'Bomet', 'Bomet', 'Bomet,Sotik,Sotik Post', -0.7812900, 35.3415600, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91117, 'Baringo', 'Baringo', '', 0.4666700, 35.9666700, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91118, 'Athi River', 'Athi River', 'Athi River', -1.4563000, 36.9782600, 'KE', '2013-11-04', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91119, 'Ahero', 'Ahero', 'Ahero', -0.1746200, 34.9163000, 'KE', '2013-09-06', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91120, 'Siaya', 'Siaya', 'Siaya', 0.0611600, 34.2882300, 'KE', '2013-06-28', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91121, 'Ol Kalou', 'Ol Kalou', '', -0.2708800, 36.3791700, 'KE', '2013-08-04', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91122, 'Nyamira', 'Nyamira', '', -0.6480000, 34.9670000, 'KE', '2013-07-03', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91123, 'Bungoma', 'Bungoma', '', 0.5833300, 34.5833300, 'KE', '2013-10-31', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91124, 'Kathwana', 'Kathwana', '', -0.1281700, 37.9357900, 'KE', '2015-11-26', 116);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91125, 'Tayan', 'Tayan', 'Taen,Tajan,Tayan,Таян', 39.9026000, 71.1082600, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91126, 'Suluktu', 'Suluktu', 'Seluka,Selukta,Suljukta,Sulyukta,Sүlүktү,Сулюкта,Сүлүктү', 39.9365200, 69.5677900, 'KG', '2015-05-23', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91127, 'Korgon', 'Korgon', 'Korgon,Lyaylyak,Коргон', 39.8889900, 69.9355900, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91128, 'Aydarken', 'Aydarken', 'Aidarken,Ajdarken,Aydarken,Khaidarkan,Khajdarkan,Khaydarkan,Khaydarken,Xaydarkon,Айдаркен,Хайдаркан', 39.9431900, 71.3418400, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91129, 'Katran', 'Katran', 'Katran,Катран', 39.8443400, 70.0147400, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91130, 'Isfana', 'Isfana', 'Isfana,Isfina,asfnh,yi si fa na,yysfana,İsfana,Ісфана,Исфана,ئیسفانا,اسفنه,伊斯法納', 39.8389500, 69.5276000, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91131, 'Andarak', 'Andarak', 'Andarak,Андарак', 39.7684900, 69.4639800, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91132, 'Balykchy', 'Balykchy', 'Balagch,Balikci,Baliksi,Balikĉi,Baloktso,Balykchi,Balykchy,Balykchy shaary,Balykci,Balykcy,Balykczy,Balyktchy,Balyktschy,Balyktsjy,Balykči,Balykčy,Balõktšõ,Balıkçı,Bałykczy,Issyk-Kul'',Issyk-Kul’,Rybach''e,Rybach''ye,Rybach’e,Rybach’ye,Ysyk-Kol,Ysyk-Köl,ba lei ke qi,balqchy,balyqchy  qrqyzstan,baruikuchi,Балагч,Балыкчи,Балыкчы шаары,Рыбачье,بالقچی,بالیقچی، قرقیزستان,バルイクチ,巴雷克奇', 42.4601700, 76.1870900, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91133, 'Uch-Korgon', 'Uch-Korgon', 'Molotovabad,Uch-Korgon,Uch-Kurgan,Uch-Qo`rg`on,Uch-Qo‘rg‘on,Uchkorgon,Уч-Коргон,Үch-Korgon,Үч-Коргон', 40.2288100, 72.0592400, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91134, 'Tyup', 'Tyup', 'Preobrazhenskoye,Tjup,Tup,Tyup,Tüp,Тюп', 42.7276000, 78.3647600, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91135, 'Tokmok', 'Tokmok', 'To''qmoq,Tokmak,Tokmakas,Tokmok,Toʻqmoq,tkhmaq,tokamoka,tokeumakeu,tokmaki,tokumaku,tuo ke ma ke,twkmwk,Токмак,Токмок,تخماق,توكموك,تۆقمۆق,तोकमोक,თოქმაქი,トクマク,托克马克,토크마크', 42.8419400, 75.3014900, 'KG', '2015-05-26', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91136, 'Ak-Suu', 'Ak-Suu', 'Ak-Suu,Teplokljuchenka,Teploklyuchenka,Teploklyuchinka,Ак-Суу,Теплоключенка', 42.4994800, 78.5270200, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91137, 'Tash-Kumyr', 'Tash-Kumyr', 'Naryn,Tash-Komur,Tash-Kumyr,Tash-Kömür,Tashkumor,Tashkumör,Таш-Кумыр', 41.3461200, 72.2170700, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91138, 'Talas', 'Talas', 'Dmitriyevka,Dmitriyevskoye,Talas,Talass,Талас', 42.5227700, 72.2427400, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91139, 'Suzak', 'Suzak', 'Suzak,Сузак', 40.8982000, 72.9048100, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91140, 'Chuy', 'Chuy', 'Chuj,Chuy,Chüy,Pokrovka,Staraya Pokrovka,Staropokrovka,Чуй', 42.8197300, 75.2823300, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91141, 'Sosnovka', 'Sosnovka', 'Sosnovka,Сосновка', 42.6370700, 73.8960800, 'KG', '2015-05-28', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91142, 'Sokuluk', 'Sokuluk', 'Kaganovich,Novo-Troitskoye,Sokuluk,Сокулук', 42.8540100, 74.3025700, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91143, 'Pokrovka', 'Pokrovka', 'Pokrovka,Pokrovskoye,Покровка', 42.7362000, 71.6098200, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91144, 'Kyzyl-Suu', 'Kyzyl-Suu', 'Kyzyl-Suu,Leninskoye,Nov Pokrovka,Novo-Pokrovskoye,Pokrovka,Кызыл-Суу,Покровка', 42.3421100, 78.0064400, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91145, 'Uzgen', 'Uzgen', 'O''zgan,OEsgoen,OEzcent,Owzgen,Ozgon,Oʻzgan,Uzgen,Uzgenas,Uzkend,awzgn,awzknd,wu zi gen,Ösgön,Özgön,Özkənd,Özçent,Узген,Өзген,Өзгөн,Өзгөн шаары,Ուզգեն,ئۆزگوێن,اؤزگن,اوزکند,烏茲根', 40.7699400, 73.3006800, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91146, 'Osh', 'Osh', 'Gorad Osh,O''sh,OSS,Och,Oix,Os,Osa,Osas,Osch,Osh,Osj,Osz,Ox,Oŝ,Oş,Oš,Oša,Ošas,Oʻsh,ao shen,awsh,osa,oshi,osi,xxch,Горад Ош,Ош,אוש,أوش,اوش,ओश,ออช,ოში,オシ,奧什,오시', 40.5282800, 72.7985000, 'KG', '2015-06-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91147, 'Orozbekovo', 'Orozbekovo', 'O`rozbekovo,Okhna,Orozbekov,Orozbekovo,O‘rozbekovo,Urazbekovo,Орозбеков,Орозбеково', 40.0568900, 71.6694500, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91148, 'Naryn', 'Naryn', 'Naron,Naryn,Нарын', 41.4286600, 75.9911100, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91149, 'Bakai-Ata', 'Bakai-Ata', 'Bakaj-Ata,Leninpol'',Бакай-Ата,Ленинполь', 42.4929800, 71.9236000, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91150, 'Massy', 'Massy', 'Lenin-Dzhol,Leninjol,Massy,Ленин-Джол,Массы', 41.0601000, 72.6328500, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91151, 'Lebedinovka', 'Lebedinovka', 'Lebedinka,Lebedinovka,Лебединовка', 42.8845400, 74.6781900, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91152, 'Kyzyl-Kyya', 'Kyzyl-Kyya', 'Kizol-Kiva,Kizyl-Kiya,Kizöl-Kiva,Kyzyl-Kija,Kyzyl-Kiya,Kyzyl-Kyja,Kyzyl-Kyya,Kzyl-Kiya,Qizilqiya,Кызыл-Кия,Кызыл-Кыя', 40.2568400, 72.1279300, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91153, 'Kochkor', 'Kochkor', 'Kochkor,Kochkorka,Кочкор', 42.2155200, 75.7565900, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91154, 'Kyzyl-Adyr', 'Kyzyl-Adyr', 'Aleksandrovka,Aleksandrovskiy,Aleksandrovskoye,Kirov,Kirovskoe,Kirovskoye,Kyzyl-Adyr,Кировское,Кызыл-Адыр', 42.6198100, 71.5891000, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91155, 'Khalmion', 'Khalmion', 'Halmion,Kalmion,Khalmion,Xalmion,Халмион', 40.2121800, 71.6327400, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91156, 'Kazarman', 'Kazarman', 'Kazarman,Казарман', 41.4045200, 74.0282800, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91157, 'Kerben', 'Kerben', 'Karavan,Kerben,Караван,Кербен', 41.4939900, 71.7582600, 'KG', '2015-08-17', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91158, 'Karavan', 'Karavan', 'Karavan,Kerben,Караван', 40.2951300, 72.1862700, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91159, 'Kara Suu', 'Kara Suu', 'Kara Suu,Kara-Su,Kara-Suu,Qora-Suu,Кара Суу,Кара-Суу', 40.7046000, 72.8666600, 'KG', '2016-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91160, 'Karakol', 'Karakol', 'Gorad Karakol,Karakol,Karakola,Karakolas,Karakoł,Karakul,Karàkol,Khargol,Prjeval''sk,Prjeval’sk,Przheval''sk,Przheval’sk,Qoraqo''l,Qoraqoʻl,ka la ke er,kalakol,karakola,karakoru,kha ra khxl,qrakwl  qrqyzstan,Горад Каракол,Каракол,Пржевальск,Харгол,Қарақол,קארקול,قاراقۆل,قراکول، قرقیزستان,काराकोल,คาราคอล,カラコル,卡拉科尔,카라콜', 42.4906800, 78.3936200, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91161, 'Kara-Dzhygach', 'Kara-Dzhygach', 'Kara-Djygach,Kara-Dzhegach,Kara-Dzhygach,Kara-Zhygach,Karadzhigach,Qora-Jig`ach,Qora-Jig‘ach,Кара-Джыгач,Кара-Жыгач', 40.1220900, 72.0927100, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91162, 'Kara-Balta', 'Kara-Balta', 'Imeni Mikoyana,Kara-Balta,Kara-Balty,Karabalto,Karabaltö,Кара-Балта', 42.8142300, 73.8481300, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91163, 'Kanysh-Kyya', 'Kanysh-Kyya', 'Kanysh-Kiya,Kanysh-Kyja,Kanysh-Kyya,Каныш-Кыя', 41.7653600, 71.0918100, 'KG', '2012-08-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91164, 'Kant', 'Kant', 'Kant,Кант', 42.8910600, 74.8507700, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91165, 'Kaindy', 'Kaindy', 'Kainda,Kaindy,Kayyngdy,Molotovsk,Molotovskiy,Каинды', 42.8246900, 73.6758500, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91166, 'Kadzhi-Say', 'Kadzhi-Say', 'Kadzhi-Saj,Kadzhi-Say,Kaji-Say,Каджи-Сай', 42.1410700, 77.1784800, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91167, 'Jalal-Abad', 'Jalal-Abad', 'Celal-Abad,Djalalabad,Dschalalabat,Dzalal Abad,Dzalal Abadas,Dzalal-Abad,Dzalalabad,Dzalalabada,Dzalalabat,Dzhalal Abad,Dzhalal-Abad,Dzjalal-Abad,Dzsalalabad,Dżalalabad,Džalal Abad,Džalal Abadas,Džalal-Abad,Džalalabada,Džalalabat,Gorad Dzhalal-Abad,Jalal-Abad,Jalalabat,Jalolobod,Zalal-Abad,Zalalabad,Zalalabat,Zhalal-Abad,Zhalal-Abad shaary,Zhalalabat,gu la la ba de,jalalabada,jallal-abateu,jararabado,jlal-abad,Ĵalalabat,Žalal-Abad,Žalalabad,Žalalabat,Горад Джалал-Абад,Джалал Абад,Джалал-Абад,Жалал-Абад,Жалал-Абад шаары,Жалалабат,جلال-آباد,جلال‌آباد، قرقیزستان,جەلالابات، قرغیزستان,जलालाबाद,ジャララバード,賈拉拉巴德,잘랄아바트', 40.9333300, 73.0000000, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91168, 'Ivanovka', 'Ivanovka', 'Ivanovka,Ivanovna,Ивановка', 42.8877800, 75.0850000, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91169, 'Ivanovo-Alekseyevka', 'Ivanovo-Alekseyevka', 'Ivano-Alekseevka,Ivanovo-Alekseevka,Ivanovo-Alekseyevka,Kek-Oy,Këk-Oy,Иваново-Алексеевка', 42.5468900, 72.2092100, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91170, 'Iradan', 'Iradan', 'Iradan,Radinan,Ирадан', 40.2666700, 72.1000000, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91171, 'Gul’cha', 'Gul''cha', 'Guelchoe,Gul''cha,Gultscha,Gul’cha,Gülchö,Gүlchө,Гульча,Гүлчө', 40.3138000, 73.4441800, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91172, 'Nookat', 'Nookat', 'Eski-Nookat,Iski-Naukat', 40.2659700, 72.6183400, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91173, 'Cholpon-Ata', 'Cholpon-Ata', 'Chalpan-Ata,Cholpon-Ata,Stanovishche Chalpan-Ata,Чолпон-Ата', 42.6494400, 77.0822500, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91174, 'Chayek', 'Chayek', 'Chaek,Chayek,Kul''chigash,Kul’chigash,Чаек', 41.9276800, 74.5169900, 'KG', '2015-05-26', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91175, 'Kemin', 'Kemin', 'Bostrorechenskoye,Bystrorechenskoye,Bystrovka,Kemin,Быстровка,Кемин', 42.7861100, 75.6916700, 'KG', '2017-07-20', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91176, 'Bokombayevskoye', 'Bokombayevskoye', 'Boekoenbaev,Bokombaevskoe,Bokombayevskoye,Bokonbayevo,Bokonbayevskoye,Bökönbaev,Bөkөnbaj,Kol''tsovka,Kol’tsovka,Kunchigosh,Kunchigysh,Kunchigösh,Бокомбаевское,Бөкөнбай', 42.1176900, 76.9933200, 'KG', '2015-05-26', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91177, 'Bishkek', 'Bishkek', 'Bichkek,Biscecum,Bischkek,Bishkek,Bishkek osh,Bisjkek,Biskek,Biskeka,Biskekas,Biskeko,Biskekʻ,Bisqeq,Bisqueque,Biszkek,Bixkek,Biŝkeko,Bişkek,Bişqeq,Biškek,Biškeka,Biškekas,Bișkek,Bîşkek,FRU,Frunze,Gorad Bishkek,Mpiskek,Pishkek,Pishpek,bi shen kai ke,bichkhek,bisakeka,bishukeku,biskek,biskeka,biskekk,bisyukekeu,bshkyk,byshkk,byshkyk,bysqq,picukkek,Μπισκέκ,Бишкек,Бишкек ош,Бішкек,Горад Бішкек,Բիշկեք,בישקעק,בישקק,بشکیک,بيشكك,بيشكيك,بيشکک,بیشکک,بیشکێک,बिश्केक,বিশকেক,ਬਿਸ਼ਕੇਕ,பிசுக்கெக்,ಬಿಷ್ಕೆಕ್,ബിഷ്കെക്ക്,บิชเคก,པི་སི་ཁེག,ბიშკეკი,ቢሽኬክ,ビシュケク,比什凯克,비슈케크', 42.8700000, 74.5900000, 'KG', '2015-05-27', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91178, 'Belovodskoye', 'Belovodskoye', 'Belovodskoe,Belovodskoye,Stalinskoye,Беловодское', 42.8294400, 74.1083000, 'KG', '2015-06-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91179, 'Bazar-Korgon', 'Bazar-Korgon', 'Bazar,Bazar-Korgon,Bozor-Qo`rg`on,Bozor-Qo‘rg‘on,Базар-Коргон', 41.0376000, 72.7458600, 'KG', '2016-05-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91180, 'Batken', 'Batken', 'Batken,Batkena,Batkenas,Batkén,Botken,ba te ken,badknd,basken,batakena,batoken,Баткен,باتکێن,بادکند,बातकेन,バトケン,巴特肯,밧켄', 40.0625900, 70.8193900, 'KG', '2012-08-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91181, 'Baetovo', 'Baetovo', 'Baetov,Baetovo,Bayetovo,Djurbel''dzhin,Durbel''jin,Durbel’jin,Dyurbel''dzhin,Dyurbel''jin,Dyurbel’dzhin,Dyurbel’jin,Баетов,Баетово,Дюрбельджин', 41.2666800, 74.9569800, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91182, 'At-Bashi', 'At-Bashi', 'At-Bashi,At-Bashy,Ат-Баши,Ат-Башы', 41.1695100, 75.8009900, 'KG', '2015-05-25', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91183, 'Aravan', 'Aravan', 'Aravan,Араван', 40.5160800, 72.4996000, 'KG', '2015-05-24', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91184, 'Alga', 'Alga', 'Alga,Olg`a,Olg‘a,Алга', 40.2363000, 71.4989900, 'KG', '2015-11-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91185, 'Ala-Buka', 'Ala-Buka', 'Ala-Buka,Ola-Bo`ka,Ola-Bo`qa,Ola-Bo‘ka,Ola-Bo‘qa,Ала-Бука', 41.4105000, 71.4862800, 'KG', '2016-10-07', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91186, 'Beshkent', 'Beshkent', 'Beshkent,Togal,Бешкент', 40.0308300, 69.8186100, 'KG', '2015-07-03', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91187, 'Toktogul', 'Toktogul', 'Toktogul,Токтогул', 41.8744200, 72.9419200, 'KG', '2015-05-26', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91188, 'Pulgon', 'Pulgon', 'Pulgon,Пулгон', 40.1472400, 71.7296200, 'KG', '2015-05-31', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91189, 'Talas', 'Talas', '', 42.3547300, 72.6567800, 'KG', '2011-02-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91190, 'Üch-Terek', 'Uch-Terek', 'Sargata,UEch-Terek,Uch-Tereg,Üch-Terek,Саргата,Уч-Терег', 41.7622200, 73.2003300, 'KG', '2015-05-26', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91191, 'Kara-Dëbë', 'Kara-Debe', 'Kara-Debe,Kara-Djobjo,Kara-Dobo,Kara-Dëbë,Kara-Döbö,Qora-Dyobyo,Кара-Дёбё', 40.2442800, 72.0447500, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91192, 'Kara-Kulja', 'Kara-Kulja', 'Kara-Kul''dzha,Kara-Kulja,Kara-Kul’dzha,Кара-Кульджа', 40.6322300, 73.5924900, 'KG', '2015-06-08', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91193, 'Chek', 'Chek', 'Chek,Чек', 40.1093400, 70.8463600, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91194, 'Kara-Bak', 'Kara-Bak', 'Kara-Bak,Qora-Bak,Кара-Бак', 40.1616900, 70.8195900, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91195, 'Samarkandyk', 'Samarkandyk', 'Samarkandyk,Самаркандык', 39.9981000, 70.5458900, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91196, 'Kyrgyz-Kyshtak', 'Kyrgyz-Kyshtak', 'Kirgiz-Kyshtak,Kyrgyz-Kyshtak,Qirg`iz-Qishtak,Qirg‘iz-Qishtak,Киргиз-Кыштак,Кыргыз-Кыштак', 40.3105500, 71.3496600, 'KG', '2015-11-09', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91197, 'Kyzyl-Bulak', 'Kyzyl-Bulak', 'Kyzyl-Bulak,Qizil-Buloq,Кызыл-Булак', 40.0517000, 71.7372600, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91198, 'Boz-Adyr', 'Boz-Adyr', 'Bo`z-Adir,Boz-Adyr,Bo‘z-Adir,Боз-Адыр', 39.9986000, 71.0733800, 'KG', '2015-11-09', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91199, 'Markaz', 'Markaz', 'Markaz,Марказ', 40.2401900, 71.8998300, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91200, 'Kulundu', 'Kulundu', 'Kulundu,Кулунду', 40.1063500, 69.6412700, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91201, 'Ak-Suu', 'Ak-Suu', 'Ak-Suu,Zambarych,Ак-Суу', 39.8987700, 69.3716000, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91202, 'Toguz-Bulak', 'Toguz-Bulak', 'Toguz-Bulak,Тогуз-Булак', 39.8433100, 69.7135500, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91203, 'Ak-Tatyr', 'Ak-Tatyr', 'Ak-Tatyr,Ак-Татыр', 39.9599000, 70.4845100, 'KG', '2015-07-04', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91204, 'Ormosh', 'Ormosh', 'O`rmosh,Ormosh,O‘rmosh,Ормош', 39.9459100, 71.2608600, 'KG', '2015-11-09', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91205, 'Ak-Say', 'Ak-Say', 'Ak-Sai,Ak-Saj,Ak-Say,Ак-Сай', 39.8743800, 70.5221100, 'KG', '2015-07-05', 121);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91254, 'Sesan', 'Sesan', 'Ban Komphun,Kamphun,Kâmphŭn,Sesan,កំភុន', 13.5532900, 106.0922400, 'KH', '2017-04-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91255, 'Ban Lŭng', 'Ban Lung', 'Ban Lung,Ban Lŭng,Banlung,Bong Long,Boung Long,Bung Lung,Bông Lông,Bŭng Lŭng,Krong Ban Lung,Phumi Bung Lung,Phumĭ Bŭng Lŭng,Soung Long', 13.7393900, 106.9872700, 'KH', '2013-08-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91256, 'Odongk', 'Odongk', 'Bat Deng,Bat Doeng,Bat Dong,Batt Doeng,Batt Dœ̆ng,Băt Dœ̆ng,Odongk,Phumi Batt Doeng,Phumĭ Batt Dœ̆ng', 11.6826700, 104.6994500, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91257, 'Battambang', 'Battambang', 'BBM,Bat Dambang,Batambang,Batambangas,Batdamban,Batdambang,Batdâmbâng,Battamban,Battambang,Battampan''nk,Băt Dâmbâng,Bătdâmbâng,Ciudad de Battambang,Khett Batdambang,Phratabong,batambang,batanban,byatamabam,ma de wang,pattampan,phra tabxng,Μπατταμπάνγκ,Батамбанг,Батдамбан,Баттамбанг,باتم‌بنگ,باٹامبانگ,ব্যাটামবং,பட்டாம்பாங்,พระตะบอง,ករងបាតដបង,ក្រុងបាត់ដំបង,バタンバン,马德望,바탐방', 13.1027100, 103.1982200, 'KH', '2016-12-27', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91258, 'Baray', 'Baray', 'Barai,Baray,Barayn,Bareayon,Baréayôn,Phumi Baray,Phumĭ Baray', 12.3942900, 105.0751800, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91259, 'Bar Kaev', 'Bar Kaev', 'Andaung Pech,Andaung Pich,Ba Kev,Bakeo,Bar Kaev,Bo Kheo,Bokeo,Bâ Kêv,Phum Ba Key,Phumi Ba Kev,Phumĭ Bâ Kêv', 13.6862000, 107.2141700, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91260, 'Pal Hal', 'Pal Hal', 'Bahal,Banhai,Barhal,Pal Hal,Palhal,Phum Pahal,Phumi Bahal,Phumĭ Bahal', 13.7922600, 104.9785900, 'KH', '2017-03-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91261, 'Anlong Veaeng', 'Anlong Veaeng', 'Anlong Veaeng,Anlong Veng,Anlung Veng,Anlung Vêng,Srok Anlongweng,Ânlóng Vêng,Ânlūng Vêng', 14.2322300, 104.0810700, 'KH', '2017-02-04', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91262, 'Sampov Lun', 'Sampov Lun', 'Sampou Lun,Sampov Lun,Sâmpŏu Lun', 13.4319000, 102.3757400, 'KH', '2017-01-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91263, 'Smach Mean Chey', 'Smach Mean Chey', '', 11.5466500, 103.0356900, 'KH', '2014-04-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91264, 'Phnum Proek', 'Phnum Proek', 'Phnum Proek', 13.2235000, 102.3954600, 'KH', '2017-01-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91265, 'Kamrieng', 'Kamrieng', 'Kamrieng', 13.0880600, 102.4907400, 'KH', '2017-01-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91266, 'Samlout', 'Samlout', '', 12.6169800, 102.8586200, 'KH', '2016-11-24', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91267, 'Ou Chrov', 'Ou Chrov', 'Ou Chrov', 13.6388500, 102.5835600, 'KH', '2016-11-24', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91268, 'Veal Veaeng', 'Veal Veaeng', 'Veal Veaeng', 12.3049100, 103.1023000, 'KH', '2016-11-24', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91269, 'Aek Phnum', 'Aek Phnum', 'Aek Phnum', 13.1599300, 103.2313400, 'KH', '2016-12-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91270, 'Bat Dambang', 'Bat Dambang', 'Bat Dambang', 13.2629800, 103.0903700, 'KH', '2016-12-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91271, 'Phnum Srok', 'Phnum Srok', '', 13.7440300, 103.3389200, 'KH', '2016-12-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91272, 'Kralanh', 'Kralanh', 'Kralanh,Sala Srok Kralanh,Sala Srŏk Krâlanh', 13.6053500, 103.4190300, 'KH', '2016-12-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91273, 'Mongkol Borei', 'Mongkol Borei', 'Mongkol Borei', 13.5405700, 103.0269300, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91274, 'Preah Netr Preah', 'Preah Netr Preah', 'Preah Netr Preah', 13.6237100, 103.1821200, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91275, 'Mondul Seima', 'Mondul Seima', 'Mondul Seima', 11.6241100, 102.9501500, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91276, 'Smach Meanchey', 'Smach Meanchey', 'Smach Meanchey', 11.6041200, 102.9880100, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91277, 'Botum Sakor', 'Botum Sakor', 'Botum Sakor', 11.1872000, 103.4711700, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91278, 'Sangkae', 'Sangkae', 'Sangkae', 13.0794300, 103.2445400, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91279, 'Mittakpheap', 'Mittakpheap', 'Mittakpheap', 10.6226800, 103.5247300, 'KH', '2017-01-07', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91280, 'Thma Bang', 'Thma Bang', 'Thma Bang', 11.6292500, 103.5295800, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91281, 'Phnum Kravanh', 'Phnum Kravanh', 'Phnum Kravanh', 12.3512100, 103.7694000, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91282, 'Srei Snam', 'Srei Snam', 'Srei Snam', 13.8342000, 103.5131500, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91283, 'Chum Kiri', 'Chum Kiri', 'Chum Kiri', 10.9252200, 104.4218500, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91284, 'Kampot', 'Kampot', 'Kampot', 10.6042100, 104.2561100, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91285, 'Damnak Chang’aeur', 'Damnak Chang''aeur', 'Damnak Chang''aeur,Damnak Chang’aeur', 10.5302100, 104.3688100, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91286, 'Phnum Sruoch', 'Phnum Sruoch', 'Phnum Sruoch', 11.3850000, 104.3716500, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91287, 'Thpong', 'Thpong', 'Thpong', 11.7537500, 104.4274300, 'KH', '2017-02-05', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91288, 'Soutr Nikom', 'Soutr Nikom', 'Soutr Nikom', 13.2387900, 104.1378400, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91289, 'Trapeang Prasat', 'Trapeang Prasat', 'Trapeang Prasat', 14.1868900, 104.3553300, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91290, 'Kiri Vongs', 'Kiri Vongs', 'Kiri Vongs', 10.6378100, 104.8731900, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91291, 'Banteay Meas', 'Banteay Meas', 'Banteay Meas', 10.6678100, 104.5602600, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91292, 'Kandal Stueng', 'Kandal Stueng', 'Kandal Stueng', 11.4135000, 104.8264800, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91293, 'Ta Khmau', 'Ta Khmau', 'Ta Khmau', 11.4464100, 104.9455600, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91294, 'Tram Kak', 'Tram Kak', 'Tram Kak', 11.0117300, 104.6763100, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91295, 'Basedth', 'Basedth', 'Basedth', 11.1491800, 104.5364100, 'KH', '2017-02-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91296, 'Mukh Kampul', 'Mukh Kampul', 'Mukh Kampul', 11.7357700, 104.9771300, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91297, 'Ponhea Lueu', 'Ponhea Lueu', 'Ponhea Lueu', 11.6557700, 104.8668400, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91298, 'Ruessei Kaev', 'Ruessei Kaev', 'Ruessei Kaev', 11.6243900, 104.9094100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91299, 'Dangkao', 'Dangkao', 'Dangkao', 11.5617300, 104.8555300, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91300, 'Mean Chey', 'Mean Chey', 'Mean Chey', 11.5326400, 104.9366200, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91301, 'Kampong Leaeng', 'Kampong Leaeng', 'Kampong Leaeng', 12.2744600, 104.7273700, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91302, 'Stueng Saen', 'Stueng Saen', 'Stueng Saen', 12.7112100, 104.8910800, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91303, 'Stoung', 'Stoung', 'Stoung', 12.9404000, 104.5707200, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91304, 'Bourei Cholsar', 'Bourei Cholsar', 'Bourei Cholsar', 10.8343100, 105.0185100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91305, 'Preah Sdach', 'Preah Sdach', 'Preah Sdach', 11.0951100, 105.3844700, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91306, 'Kang Meas', 'Kang Meas', 'Kang Meas', 11.9462700, 105.2749100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91307, 'Kaoh Soutin', 'Kaoh Soutin', 'Kaoh Soutin', 11.8854800, 105.4278200, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91308, 'Sithor Kandal', 'Sithor Kandal', 'Sithor Kandal', 11.7726400, 105.3827400, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91309, 'Prey Veaeng', 'Prey Veaeng', 'Prey Veaeng', 11.5710100, 105.4205800, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91310, 'Chamkar Leu', 'Chamkar Leu', 'Chamkar Leu', 12.3085100, 105.2818600, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91311, 'Cheung Prey', 'Cheung Prey', 'Cheung Prey', 12.0568500, 105.0747500, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91312, 'Prey Chhor', 'Prey Chhor', 'Prey Chhor', 12.0580400, 105.2572300, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91313, 'Sandan', 'Sandan', 'Sandan', 13.1045900, 105.2540700, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91314, 'Rumduol', 'Rumduol', 'Rumduol', 11.1588800, 105.8226100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91315, 'Svay Teab', 'Svay Teab', 'Svay Teab', 11.0545600, 105.8853100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91316, 'Me Sang', 'Me Sang', 'Me Sang', 11.3276100, 105.5460500, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91317, 'Stueng Trang', 'Stueng Trang', 'Sala Srok Stoeng Trang,Sala Srŏk Stœ̆ng Trâng,Stueng Trang', 12.2557800, 105.5352200, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91318, 'Chantrea', 'Chantrea', 'Chantrea', 10.9843100, 106.1248600, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91319, 'Kaev Seima', 'Kaev Seima', 'Kaev Seima', 12.1873900, 106.8806100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91320, 'Ou Chum', 'Ou Chum', 'Ou Chum', 13.7978000, 106.9937800, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91321, 'Andoung Meas', 'Andoung Meas', 'Andoung Meas', 13.8672400, 107.2968200, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91322, 'Ou Ya Dav', 'Ou Ya Dav', 'Ou Ya Dav', 13.6706100, 107.3470100, 'KH', '2017-03-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91323, 'Sangkom Thmei', 'Sangkom Thmei', 'Sangkom Thmei', 13.5814700, 104.9131500, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91324, 'Peam Ro', 'Peam Ro', 'Peam Ro', 11.3085200, 105.2836600, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91325, 'Kampong Leav', 'Kampong Leav', 'Kampong Leav', 11.4930800, 105.3431800, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91326, 'Leuk Daek', 'Leuk Daek', 'Leuk Daek,Sala Srok Leuk Dek,Sala Srŏk Leuk Dêk,សាលាស្រុកលើកដែក', 11.1751000, 105.2292000, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91327, 'Peam Chor', 'Peam Chor', 'Peam Chor,Sala Srok Peam Chor,Sala Srŏk Péam Chôr,សាលាស្រុកពាមជរ', 11.0987700, 105.2211400, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91328, 'Koun Mom', 'Koun Mom', 'Koun Mom', 13.5776700, 106.7728900, 'KH', '2017-04-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91329, 'Pechreada', 'Pechreada', 'Pechreada', 12.5525400, 107.4239300, 'KH', '2017-05-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91330, 'Prey Nob', 'Prey Nob', 'Prey Nob', 10.7093900, 103.8209100, 'KH', '2017-05-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91331, 'Bakan', 'Bakan', 'Bakan', 12.6020900, 103.7857900, 'KH', '2017-05-09', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91332, 'Angkor Thum', 'Angkor Thum', 'Angkor Thum', 13.4833900, 103.8741300, 'KH', '2017-06-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91333, 'Bakong', 'Bakong', 'Bakong', 13.3474100, 103.9875600, 'KH', '2017-06-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91334, 'Varin', 'Varin', 'Varin', 13.7932200, 103.7608500, 'KH', '2017-06-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91335, 'Angkor Chum', 'Angkor Chum', 'Angkor Chum', 13.6838500, 103.6479000, 'KH', '2017-06-08', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91336, 'Aoral', 'Aoral', 'Aoral', 11.6877800, 104.1295900, 'KH', '2017-07-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91337, 'Baribour', 'Baribour', 'Baribour', 12.4375800, 104.4628600, 'KH', '2017-07-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91338, 'Chi Kraeng', 'Chi Kraeng', 'Chi Kraeng', 13.1223400, 104.3462700, 'KH', '2017-07-06', 39);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91735, 'West Bay', 'West Bay', 'West Bay,West End', 19.3666700, -81.4166700, 'KY', '2015-07-12', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91736, 'North Side', 'North Side', 'North Side,North Side Village', 19.3500000, -81.2000000, 'KY', '2015-07-12', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91737, 'George Town', 'George Town', 'Corctaun,Dzhordzh Taun,Dzhordzhtaun,Dzordz Taun,Dzordztaun,Dzordztaunas,Džordžtaunas,GCM,George Town,George Town pa Caymanoyane,George Town på Caymanøyane,Georgetown,Georgurbo,Gorad Dzhordzhtaun,Tzortz Taoun,cxrc thawn,gwrg tʼwn,jarj tavun,jojitaun,jorjata''una,jwrj tawn,qiao zhi dui,qiao zhi dun,Τζωρτζ Τάουν,Џорџ Таун,Џорџтаун,Горад Джорджтаўн,Джордж Таун,Джорджтаун,גורג טאון,جارج ٹاؤن، جزائر کیمین,جرج‌تاون، جزایر کیمن,جورج تاون,जॉर्जटाउन,ஜார்ஜ் டவுன்,จอร์จทาวน์,ჯორჯტაუნი,ジョージタウン,喬治敦,조지타운', 19.2866000, -81.3743600, 'KY', '2015-07-13', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91738, 'East End', 'East End', 'East End,Old Isaacs', 19.3000000, -81.1166700, 'KY', '2015-07-12', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91739, 'Bodden Town', 'Bodden Town', 'Bodden,Bodden Town', 19.2764700, -81.2542000, 'KY', '2015-07-12', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91740, 'Little Cayman', 'Little Cayman', '', 19.6611400, -80.1098400, 'KY', '2015-07-12', 42);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91357, 'Ouanani', 'Ouanani', 'Oanani,Ouanani,Wanani', -12.3375000, 43.7975000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91358, 'Vouani', 'Vouani', 'Voani,Voany,Vouani', -12.2441700, 44.3744400, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91359, 'Vanambouani', 'Vanambouani', 'Vanamboini,Vanambouani', -11.6113900, 43.2530600, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91360, 'Singani', 'Singani', 'Singani', -11.8455600, 43.3091700, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91361, 'Sima', 'Sima', 'Sima', -12.1955600, 44.2766700, 'KM', '2012-05-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91362, 'Salimani', 'Salimani', 'Salimani,Selimani', -11.8080600, 43.2591700, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91363, 'Patsi', 'Patsi', 'Patsi,Patsy,Wilson', -12.1555600, 44.4372200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91364, 'Ouzini', 'Ouzini', 'Ousini,Ouzini', -12.2672200, 44.4797200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91365, 'Oussivo', 'Oussivo', 'Ousivo,Oussivo', -11.5850000, 43.2672200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91366, 'Ourovéni', 'Ouroveni', 'Ouroveni,Ourovéni', -11.9097200, 43.4886100, 'KM', '2013-04-03', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91367, 'Ouani', 'Ouani', 'AJN,Oani,Ouani,Ouany', -12.1355400, 44.4249300, 'KM', '2013-10-26', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91368, 'Ongoni', 'Ongoni', 'Ongoni', -12.1702800, 44.5069400, 'KM', '2013-04-03', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91369, 'Ntsoudjini', 'Ntsoudjini', 'Mitsoudjini,Mitsudje,Mitsuje,Ntsoudjini,Tsudjim,Tsudjin,Tsudjini,Tsujuni', -11.6597200, 43.2613900, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91370, 'Ntsaouéni', 'Ntsaoueni', 'Mitsaoueni,Mtsaoueni,Ntsaoueni,Ntsaouéni,Tsaueni', -11.4658300, 43.2627800, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91371, 'Nioumachoua', 'Nioumachoua', 'Niomachoi,Nioumachoi,Nioumachoua,Nioumgchoi,Numa Choa', -12.3613900, 43.7152800, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91372, 'Kyo', 'Kyo', 'Kyo,Niambahamoro', -12.3322200, 44.5191700, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91373, 'Moutsamoudou', 'Moutsamoudou', 'Matsamudu,Moutsamoudou,Mutsamudu', -12.1667200, 44.3994400, 'KM', '2013-05-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91374, 'Mtsamdou', 'Mtsamdou', 'Mtsamdou', -11.6069400, 43.3805600, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91375, 'Mrémani', 'Mremani', 'Mremani,Mrenani,Mrémani', -12.3083300, 44.4986100, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91376, 'Mramani', 'Mramani', 'M''Ramoni,M''ramoni,Mramani,M’Ramoni,M’ramoni', -12.3463900, 44.5286100, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91377, 'Moya', 'Moya', 'Moya', -12.3066700, 44.4377800, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91378, 'Moroni', 'Moroni', 'Gorad Maroni,Moroni,Moronio,Moronis,Morony,Moròni,Muruni,Móróní,YVA,mo luo ni,mo ro ni,moloni,moroni,muruni,mwrwny,Μορονί,Горад Мароні,Морони,Мороні,Մորոնի,מורוני,موروني,مورونی,مۆرۆنی,मोरोनी,ਮੋਰੋਨੀ,மூறூனீ,โมโรนี,མོ་རོ་ནི།,მორონი,ሞሮኒ,モロニ,莫洛尼,莫羅尼,모로니', -11.7021600, 43.2550600, 'KM', '2010-05-28', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91379, 'Mohoro', 'Mohoro', 'Mohoro', -11.8258300, 43.4461100, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91380, 'Mjimandra', 'Mjimandra', 'M''Jimanda,Mjimandra,Moujimada,M’Jimanda', -12.1916700, 44.3702800, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91381, 'Mjamaoué', 'Mjamaoue', 'Jamaue,Jamaué,Mjamaoue,Mjamaoué', -12.1936100, 44.3100000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91382, 'Mitsamiouli', 'Mitsamiouli', 'Mitsamihouh,Mitsamiouli,Mitsumiuli,Mtamuhuli', -11.3847200, 43.2844400, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91383, 'Mbéni', 'Mbeni', 'Mbeni,Mbéni', -11.5013900, 43.3775000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91384, 'Maraharé', 'Marahare', 'Marahabe,Marahabé,Marahare,Maraharé', -12.2308300, 44.3133300, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91385, 'Koni-Djodjo', 'Koni-Djodjo', 'Koni,Koni-Djodjo', -12.2297200, 44.4816700, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91386, 'Koni-Ngani', 'Koni-Ngani', 'Kone N''Goni,Kone N’Goni,Koni-Ngani', -12.2158300, 44.4800000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91387, 'Koki', 'Koki', '', -12.1713900, 44.4416700, 'KM', '2006-01-17', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91388, 'Kangani', 'Kangani', '', -12.3116700, 44.4747200, 'KM', '2006-01-17', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91389, 'Ivouani', 'Ivouani', 'Inani,Iuani,Ivoini,Ivouani', -11.3915700, 43.3945400, 'KM', '2014-03-26', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91390, 'Itsandra', 'Itsandra', 'Itsandha,Itsandra', -11.6711100, 43.2547200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91391, 'Héroumbili', 'Heroumbili', 'Heroumbili,Héroumbili,Iroumbili,Irumbilli', -11.5438900, 43.3797200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91392, 'Hoani', 'Hoani', 'Hoani', -12.2508300, 43.6747200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91393, 'Foumbouni', 'Foumbouni', 'Fomboni,Foumbouni,Mbagini,Mbajini', -11.8616700, 43.4841700, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91394, 'Fomboni', 'Fomboni', 'Fomboni,Fumboni', -12.2875900, 43.7434400, 'KM', '2016-07-27', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91395, 'Dziani', 'Dziani', 'Dziani', -12.1833300, 44.4833300, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91396, 'Domoni', 'Domoni', 'Deumoni,Domoni', -12.2569400, 44.5319400, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91397, 'Djoyézi', 'Djoyezi', 'Djoiezi,Djoyezi,Djoyézi,Mudjiauesi,Mujiauesi', -12.3058700, 43.7742500, 'KM', '2016-07-27', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91398, 'Dembéni', 'Dembeni', 'Debeni,Dembeni,Dembéni,Djembeni', -11.8736100, 43.3977800, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91399, 'Chironkamba', 'Chironkamba', 'Chironkamba', -12.1911100, 44.3525000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91400, 'Chindini', 'Chindini', 'Chendini,Chindini,Shendini', -11.9208300, 43.4811100, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91401, 'Chezani', 'Chezani', 'Cezani,Chezani', -11.4314000, 43.3962500, 'KM', '2014-03-26', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91402, 'Chandra', 'Chandra', 'Chanda,Chandra', -12.1950000, 44.4647200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91403, 'Bouni', 'Bouni', 'Bouni', -11.4869400, 43.3883300, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91404, 'Boungouéni', 'Boungoueni', 'Boungoueni,Boungouéni', -12.2055600, 44.2994400, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91405, 'Bimbini', 'Bimbini', 'Bimbini', -12.1883300, 44.2355600, 'KM', '2013-03-28', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91406, 'Assimpao', 'Assimpao', 'Assimpao', -12.2330600, 44.3197200, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91407, 'Antsahé', 'Antsahe', 'Antsahe,Antsahé', -12.3563900, 44.5225000, 'KM', '2012-01-18', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91408, 'Mtakoudja', 'Mtakoudja', 'Mtakoudja', -12.2611100, 43.7036100, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91409, 'Ziroudani', 'Ziroudani', 'Ziroudani', -12.3325000, 43.7775000, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91410, 'Kavani', 'Kavani', '', -12.1919400, 44.2694400, 'KM', '2006-01-17', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91411, 'Bandajou', 'Bandajou', 'Bandajou', -12.1916700, 44.2869400, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91412, 'Chitrouni', 'Chitrouni', 'Chitrouni', -12.1858300, 44.3355600, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91413, 'Hajoho', 'Hajoho', 'Hajoho', -12.1175000, 44.4883300, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91414, 'Barakani', 'Barakani', 'Barakani', -12.1386100, 44.4302600, 'KM', '2013-10-12', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91415, 'Harembo', 'Harembo', 'Harembo', -12.1436100, 44.4983300, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91416, 'Mirontsi', 'Mirontsi', 'Mirontsi', -12.1566700, 44.4080600, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91417, 'Pajé', 'Paje', '', -12.1697200, 44.3880600, 'KM', '2006-01-17', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91418, 'Limbi', 'Limbi', 'Limbi', -12.2394400, 44.5052800, 'KM', '2013-04-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91419, 'Lingoni', 'Lingoni', 'Lingoni', -12.2558300, 44.4183300, 'KM', '2013-04-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91420, 'Magnassini-Nindri', 'Magnassini-Nindri', 'Magnassini-Nindri', -12.2780600, 44.4158300, 'KM', '2013-04-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91421, 'Adda-Douéni', 'Adda-Doueni', 'Adda-Doueni,Adda-Douéni', -12.2925000, 44.4972200, 'KM', '2013-05-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91422, 'Daji', 'Daji', 'Daji', -12.3258300, 44.4886100, 'KM', '2014-04-06', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91423, 'Ouhozi', 'Ouhozi', 'Ouhozi', -11.4050000, 43.2822200, 'KM', '2013-04-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91424, 'Mandza', 'Mandza', 'Mandza', -11.4180600, 43.2952800, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91425, 'Douniani', 'Douniani', 'Douniani', -11.4211100, 43.2888900, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91426, 'Koua', 'Koua', '', -11.4208300, 43.2763900, 'KM', '2006-01-17', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91427, 'Hantsindzi', 'Hantsindzi', 'Hantsindzi', -11.4317800, 43.4110200, 'KM', '2014-03-26', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91428, 'Itsandzéni', 'Itsandzeni', 'Itsandzeni,Itsandzéni', -11.4727800, 43.3844400, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91429, 'Bambadjani', 'Bambadjani', 'Bambadjani', -11.4786100, 43.3772200, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91430, 'Mnoungou', 'Mnoungou', '', -11.5177800, 43.3738900, 'KM', '2006-01-27', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91431, 'Vanadjou', 'Vanadjou', 'Vanadjou', -11.6075000, 43.2761100, 'KM', '2013-04-05', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91432, 'Bahani', 'Bahani', 'Bahani', -11.6397200, 43.2841700, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91433, 'Ouella', 'Ouella', '', -11.6536100, 43.2805600, 'KM', '2006-01-27', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91434, 'Tsidjé', 'Tsidje', 'Tsidje,Tsidjé', -11.6980600, 43.2619400, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91435, 'Mvouni', 'Mvouni', 'Mvouni', -11.7161100, 43.2647200, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91436, 'Mavingouni', 'Mavingouni', 'Mavingouni', -11.7163900, 43.2525000, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91437, 'Séléa', 'Selea', 'Selea,Séléa', -11.7844400, 43.2608300, 'KM', '2014-04-06', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91438, 'Madjeouéni', 'Madjeoueni', 'Madjeoueni,Madjeouéni', -11.8216700, 43.2780600, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91439, 'Nioumamilima', 'Nioumamilima', 'Nioumamilima', -11.8511100, 43.4372200, 'KM', '2012-01-19', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91440, 'Mkiriwadjumoi', 'Mkiriwadjumoi', '', -12.3108600, 44.4370200, 'KM', '2011-09-27', 50);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91741, 'Zhumysker', 'Zhumysker', '', 49.3333300, 49.4000000, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91742, 'Zhetibay', 'Zhetibay', 'Zhetibay,Zhetybaj,Zhetybay,Жетыбай', 43.5941700, 52.0788900, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91743, 'Zhanaozen', 'Zhanaozen', 'Novyj Uzen'',Novyy Uzen’,Schangaoesen,Schangaösen,Zhanaozen,Zhangaoezen,Zhangaozen,Zhangaözen,Zhaңaөzen,Жанаозен,Жаңаөзен,Новый Узень', 43.3411600, 52.8619200, 'KZ', '2016-12-02', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91744, 'Temir', 'Temir', 'Temir,Темир', 49.1413200, 57.1285500, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91745, 'Taūshyq', 'Taushyq', 'Tauchik,Taushik,Taushyq,Taūshyq,Таучик', 44.3467800, 51.3493200, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91746, 'Shubarshi', 'Shubarshi', 'Shubarshi,Shubarshī,Шубарши', 48.5802200, 57.1828900, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91747, 'Shubarkuduk', 'Shubarkuduk', 'Chubar Kuduk,Shuba Kuduk,Shubarkuduk,Shubarqudyq,Шубаркудук', 49.1439100, 56.4819600, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91748, 'Shetpe', 'Shetpe', 'Shetpe,Шетпе', 44.1666700, 52.1166700, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91749, 'Shalqar', 'Shalqar', 'Chelkar,Shalkar,Shalqar,Шалкар', 47.8333300, 59.6000000, 'KZ', '2014-11-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91750, 'Shalkar', 'Shalkar', 'Chalkhar,Shalkar,Шалкар', 48.0333300, 48.9000000, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91751, 'Sayötesh', 'Sayotesh', 'Saj-Utes,Say-Utes,Say-Utës,Sayoetesh,Sayotesh,Sayötesh,Сай-Утес', 44.3278100, 53.5324600, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91752, 'Saykhin', 'Saykhin', 'Sajkhin,Saykhin,Сайхин', 48.8561100, 46.8336100, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91753, 'Peremetnoe', 'Peremetnoe', 'Peremetnaya,Peremetnoe,Peremetnoye,Peremëtnoye,Переметное', 51.1992500, 50.8554400, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91754, 'Oral', 'Oral', 'Gorad Ural''sk,O''ral,Oral,Orala,Oralas,Oural,Oʻral,URA,Ural''s''k,Ural''sk,Uralsk,Ural’sk,awral,awral  kazakhstan,awral  qazqstan,awral  qzaqstan,olal,oraru,wu la er,Οράλ,Горад Уральск,Орал,Уралск,Уральск,Уральськ,Җаек,אוראל,أورال,أورال، كازاخستان,ئۆرال، کازاخستان,اورال,اورال، قازقستان,اورال، قزاقستان,オラル,烏拉爾,오랄', 51.2333300, 51.3666700, 'KZ', '2017-03-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91755, 'Kandyagash', 'Kandyagash', 'Kandagach,Kandagash,Kandyagash,Oktyabr'',Oktyabr''sk,Oktyabr’,Oktyabr’sk,Кандыагаш', 49.4691200, 57.4191400, 'KZ', '2014-11-14', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91756, 'Munayshy', 'Munayshy', 'Munajshi,Munayshi,Munayshy,Мунайши', 43.4911100, 52.1086100, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91757, 'Miyaly', 'Miyaly', 'Mijaly,Miyala,Miyaly,Mīyaly,Миялы', 48.8850400, 53.7919400, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91758, 'Martuk', 'Martuk', 'Martok,Martu,Martuk,Martök,Mortyq,Мартук', 50.7474600, 56.5061100, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91759, 'Maqat', 'Maqat', 'Makat,Makat Severnyy,Maqat,Макат', 47.6500000, 53.3166700, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91760, 'Maloye Ganyushkino', 'Maloye Ganyushkino', '', 46.6000000, 49.2666700, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91761, 'Makhambet', 'Makhambet', 'Makhambet,Yamanka,Yamankhalinka,Yamankhalinski,Yamankhalinskiy,Махамбет', 47.6666700, 51.5833300, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91762, 'Qulsary', 'Qulsary', 'Kol''sary,Kul''sari,Kul''sary,Кульсары', 46.9530700, 54.0197800, 'KZ', '2010-03-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91763, 'Krūgloozernoe', 'Krugloozernoe', 'Krugloozerni,Krugloozernoe,Krugloozernoye,Krugloozernyy,Krugloozërnyy,Krūgloozernoe,Круглоозерное', 51.0785400, 51.2899200, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91764, 'Khromtau', 'Khromtau', 'Khrom-Tai,Khromtau,Khromtaū,Хромтау', 50.2511700, 58.4400300, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91765, 'Kaztalovka', 'Kaztalovka', 'Kaztalovka,Talovka,Казталовка', 49.7661200, 48.6890300, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91766, 'Qaraton', 'Qaraton', 'Karatan,Karaton,Qaraton,Каратон', 46.4352800, 53.4863900, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91767, 'Karagandy', 'Karagandy', 'KGF,Karaganda,Karagandi,Karagandy,Qaragandi,Qaraghandy,Qarağandı,Караганда', 49.8333300, 73.1658000, 'KZ', '2017-03-16', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91768, 'Kamenka', 'Kamenka', 'Kamenka,Kamennyy,Каменка', 51.1107300, 50.2945400, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91769, 'Īnderbor', 'Inderbor', 'Inder,Inderbor,Inderborskij,Inderborskiy,Inderborstroy,Indero,Inderskoye,Īnderbor,Индерборский', 48.5500000, 51.7833300, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91770, 'Fort-Shevchenko', 'Fort-Shevchenko', 'Fort Aleksandrovsk,Fort Aleksandrovskiy,Fort Uritskogo,Fort-Schewtschenko,Fort-Shevchenko,Форт-Шевченко', 44.5065400, 50.2638800, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91771, 'Fedorovka', 'Fedorovka', 'Fedorovka,Федоровка', 51.2210200, 51.9572300, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91772, 'Yeraliyev', 'Yeraliyev', 'Eraliev,Erälīev,Kuryk,Quryq,Yeraliyev,Yeraliyevo,Yeraly,Ералиев,Құрық', 43.1803200, 51.6811600, 'KZ', '2015-11-08', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91773, 'Embi', 'Embi', 'Amba,Ehmba,Emba,Embi,Эмба', 48.8298100, 58.1504200, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91774, 'Zhänibek', 'Zhanibek', 'Djanibek,Djanybek,Djiembet,Dzhanibek,Dzhanybek,Janybek,Zhaenibek,Zhanibek,Zhänibek,Джаныбек', 49.4220700, 46.8470500, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91775, 'Dzhangala', 'Dzhangala', 'Dzhangala,Kisik-Kamishen,Kisyk-Kamysh,Kisyk-Kamyshskiy,Kisykkamys,Kysykkamys,Kyysykkamys,Джангала', 49.2166700, 50.3333300, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91776, 'Dzhambeyty', 'Dzhambeyty', 'Dzhambeita,Dzhambejty,Dzhambeyta,Dzhambeytinskaya Stavka,Dzhambeyty,Zhympity,Zhympīty,Джамбейты', 50.2567600, 52.5989500, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91777, 'Dossor', 'Dossor', 'Bos-Sor,Dossor,Доссор', 47.5272200, 52.9811100, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91778, 'Chingirlau', 'Chingirlau', 'Chingirlau,Shyngghyrlau,Shyngghyrlaū,Чингирлау', 51.0987800, 54.0842600, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91779, 'Chapaev', 'Chapaev', 'Chapaev,Chapayev,Chapayevo,Lbishchensk,Lbishchenski,Lbishchenskoye,Чапаев', 50.2000000, 51.1666700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91780, 'Burlin', 'Burlin', 'Boerili,Borili,Burli,Burlin,Burlinskiy,Börili,Бурлин', 51.4272400, 52.7139200, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91781, 'Beyneu', 'Beyneu', 'Beyneu,Beyneu 1,Beyneū', 45.3166700, 55.2000000, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91782, 'Bayganin', 'Bayganin', 'Bajganin,Bayganin,Bayghanin,Bayghanīn,Karaulkel''dy,Karaulkel’dy,Байганин', 48.6897500, 55.8751200, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91783, 'Bayshonas', 'Bayshonas', 'Bajchunas,Baychunas,Bayshonas,Байчунас', 47.2413900, 52.9411100, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91784, 'Baūtīno', 'Bautino', 'Bautino,Bautino Seleniye,Baūtīno,Nikolayevskoye,Seleniye Bautino,Staro-Nikolayevskaya,Баутино', 44.5447900, 50.2462900, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91785, 'Batamshinskiy', 'Batamshinskiy', 'Badamsha,Batamshinskij,Batamshinskiy,Батамшинский', 50.5602200, 58.2771500, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91786, 'Balyqshy', 'Balyqshy', 'Balykshi,Balyqshy,Belykshi,Балыкши', 47.0666700, 51.8666700, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91787, 'Atyrau', 'Atyrau', 'Aterau,Atirau,Atirav,Atiraw,Atorau,Aturau,Atyraou,Atyrau,Atyraw,Atyraū,Atîrau,Atõrau,Atırau,Atırav,Atıraw,Chapayev,GUW,Gorad Atyrau,Gur''yev,Gurev,Guriev,Gur’yev,a te lao,atilau,atirau,aturau,atyraw,atyrayw  qzaqstan,yatraw,Атирау,Атърау,Атырау,Горад Атырау,אטיראו,آتیراؤ,آتیرائو، قزاقستان,أتيراو,ئاتراو,اتیراؤ,ਅਤੁਰੌ,ატირაუ,アティラウ,阿特勞,아티라우', 47.1166700, 51.8833300, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91788, 'Aqtöbe', 'Aqtobe', 'AKX,Aktioube,Aktioubé,Aktiube,Aktiubinsk,Aktobe,Aktoebe,Aktubinsk,Aktyubinsk,Aktöbe,Aqtoebe,Aqtöbe,Ukhtiubinskii,agtoebe,Актобе,Ақтөбе,악퇴베', 50.2796900, 57.2071800, 'KZ', '2017-03-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91789, 'Aktau', 'Aktau', 'Akhtau,Aktaou,Aktau,Aktauskiy,Aktav,Aqtau,Aqtaw,Aqtaū,SCO,Shevchenko,a ke tao,agtau,aktau,aktaw,akutau,aqata''u,aqtaw,aq‌taw,yaqtaw,Актау,Ақтау,آقتاؤ,آق‌تاو,أكتاو,ئاقتاو,اقتاؤ,अक़तऊ,აქთაუ,アクタウ,阿克套,악타우', 43.6500000, 51.1666700, 'KZ', '2016-02-13', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91790, 'Aqsay', 'Aqsay', 'Aksaj,Aksay,Aqsay,Kazakhstan,Аксай', 51.1681000, 52.9978200, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91791, 'Akkol’', 'Akkol''', 'Akkol'',Akkol’,Акколь', 48.7717700, 53.1858000, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91792, 'Ömirzaq', 'Omirzaq', 'OEmirzaq,Omirzaq,Umirzak,Ömirzaq,Умирзак', 43.5978600, 51.2417100, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91793, 'Zyryanovsk', 'Zyryanovsk', 'Ziryanovsk,Zyranovsk,Zyranovskoye,Zyrjanovsk,Zyryan,Zyryanovsk,Zyryanovskoye,Зыряновск', 49.7265400, 84.2731800, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91794, 'Zhosaly', 'Zhosaly', 'Dzhusaly,Jusaly,Karmakchi,Zhosaly,Zhusaly,Джусалы', 45.4877800, 64.0780600, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91795, 'Zholymbet', 'Zholymbet', 'Dzhalambet,Dzholonbet,Dzhoronbet,Zholymbet', 51.7421100, 71.7124500, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91796, 'Zhezqazghan', 'Zhezqazghan', 'Bol''shoy Dzhezkazgan,Bol’shoy Dzhezkazgan,DZN,Dzhezkazgan,Jez-Kazgan,Jezgazgan,Schesqasghan,Zhezkazgan,Zhezkˌazgan,Zhezqazghan,Джезказган,Жезказган,Жезқазған', 47.7833300, 67.7666700, 'KZ', '2017-03-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91797, 'Zhezkent', 'Zhezkent', 'Zhezkent,Жезкент', 50.9311200, 81.3615000, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91798, 'Dzhetygara', 'Dzhetygara', 'Dzhetygara,Dzhetygora,Dzhetygorinskiy Sovkhoz,Jetygara,Zhetiqara,Zhitikara,Zhitikˌara,Zhitiqara,Джетыгара,Жітіқара', 52.1901900, 61.1989400, 'KZ', '2017-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91799, 'Zhelezinka', 'Zhelezinka', 'Zhelezinka,Zhelezinskaya,Zheleznenka,Zhelezīnka,Железинка', 53.5388000, 75.3132600, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91800, 'Zharyk', 'Zharyk', 'Saken Seifullin,Saken Seyfullin,Säken Seyfūllīn,Zharyk,Zharyq,Жарык,Сәкен Сейфуллин', 48.8569200, 72.8359800, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91801, 'Zhangatas', 'Zhangatas', 'Dzhanatas,Dzhanytas,Zhanatas,Zhangatas,Жанатас,Жаңатас', 43.5622200, 69.7342800, 'KZ', '2015-08-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91802, 'Ayteke Bi', 'Ayteke Bi', 'Ayteke Bi,Novokazalinsk,Zhangaqazaly,Äyteke Bī', 45.8460700, 62.1526400, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91803, 'Taraz', 'Taraz', 'Auliye-Ata,DMB,Dzhambul,Gorad Taraz,Jambul,Talas,Taras,Taraz,Taraza,Tarazas,Zhambyl,ta la ci,talajeu,taraz,tarazu,traz,Ταράζ,Горад Тараз,Тараз,Թարազ,טאראז,تاراز,تراز,طراز,ტარაზი,タラズ,塔拉兹,타라즈', 42.9000000, 71.3666700, 'KZ', '2017-03-16', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91804, 'Zhalghyztobe', 'Zhalghyztobe', 'Zhalghyztobe,Zhangiztobe,Zhangyz Tyube,Жангизтобе', 49.2109400, 81.2159600, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91805, 'Zhaqsy', 'Zhaqsy', 'Dzhaksy,Zhaksy,Zhaqsy', 51.9105800, 67.3166500, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91806, 'Zaysan', 'Zaysan', 'SZI,Zaisan,Zaysan', 47.4665700, 84.8714400, 'KZ', '2013-06-02', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91807, 'Yrghyz', 'Yrghyz', 'Irgiz,Yrghyz,Иргиз', 48.6166700, 61.2666700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91808, 'Yavlenka', 'Yavlenka', 'Javlenka,Yavlenka,Явленка', 54.3452500, 68.4574000, 'KZ', '2015-11-08', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91809, 'Yanykurgan', 'Yanykurgan', 'Janykurgan,Yani-Kurgan,Yany-Kurian,Yanykurgan,Zhanakorgan,Zhangaqorghan,Жаңақорған,Яныкурган', 43.9065200, 67.2463700, 'KZ', '2015-11-08', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91810, 'Volodarskoye', 'Volodarskoye', 'Saumalkol,Saumalkol'',Saumalkol’,Saūmalköl,Volodarskiy,Volodarskoe,Volodarskoye,Volodarskīy,Володарское,Саумалкөл', 53.2927000, 68.1050000, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91811, 'Verkhniye Kayrakty', 'Verkhniye Kayrakty', 'Kaskakashka,Verkhniye Kayrakty', 48.6833300, 73.2833300, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91812, 'Vannovka', 'Vannovka', 'Turar Ryskulov,Turar Rysqulov,Vannovka,Vannovskoye,Ванновка,Тұрар Рысқұлов', 42.5334000, 70.3496000, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91813, 'Ūst’-Talovka', 'Ust''-Talovka', 'Ust''-Talovka,Ūst''-Talovka,Ūst’-Talovka,Усть-Таловка', 50.5492700, 81.8499700, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91814, 'Ush-Tyube', 'Ush-Tyube', 'Ush-Tyube,Ushtobe,Üshtöbe,Уштобе', 45.2520100, 77.9800700, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91815, 'Urzhar', 'Urzhar', 'UZR,Urdjar,Urdzhar,Urdzharsk,Urdzharskaya,Urdzharskoye,Urjar,Uryzhar,Urzhar,Ürzhar', 47.0930200, 81.6293900, 'KZ', '2013-09-22', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91816, 'Turkestan', 'Turkestan', 'Turkestan,Turkistan,Türkistan,Туркестан,Түркістан', 43.2973300, 68.2517500, 'KZ', '2015-08-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91339, 'Teaoraereke Village', 'Teaoraereke Village', 'Teaoraereka,Teaoraereke,Teaoraereke Mission', 1.3330900, 173.0116200, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91340, 'Rawannawi Village', 'Rawannawi Village', '', 2.0537900, 173.2635400, 'KI', '2010-11-01', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91341, 'Buota Village', 'Buota Village', '', 1.3907800, 173.1308200, 'KI', '2010-11-05', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91342, 'Betio Village', 'Betio Village', '', 1.3579700, 172.9210500, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91343, 'Banraeaba Village', 'Banraeaba Village', 'Banraeaba,Banreaba', 1.3454000, 173.0346400, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91344, 'Tarawa', 'Tarawa', 'Juzhnaja Tarava,South Tarawa,Sued-Tarawa,Süd-Tarawa,TRW,Tarawa,Tarawa Sud,Tarawa do Sul,Tarawa-Sud,Zuid-Tarawa,namtalawa,sauseutalawa,talawa,Южная Тарава,דרום טאראווה,남타라와,사우스타라와,타라와', 1.3278000, 172.9769600, 'KI', '2017-06-22', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91345, 'Napari Village', 'Napari Village', 'Nabari,Napari', 3.9080600, -159.3883200, 'KI', '2012-06-18', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91346, 'London Village', 'London Village', 'London', 1.9848700, -157.4750200, 'KI', '2010-10-22', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91347, 'Tabwakea Village', 'Tabwakea Village', '', 2.0164300, -157.4877300, 'KI', '2010-10-22', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91348, 'Banana Village', 'Banana Village', '', 1.9832900, -157.3652600, 'KI', '2010-10-22', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91349, 'Makin Village', 'Makin Village', '', 3.3644000, 172.9835200, 'KI', '2010-11-02', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91350, 'Bairiki Village', 'Bairiki Village', '', 1.3292400, 172.9752200, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91351, 'Ambo Village', 'Ambo Village', '', 1.3531700, 173.0425900, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91352, 'Bonriki Village', 'Bonriki Village', '', 1.3808100, 173.1388700, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91353, 'Temaiku Village', 'Temaiku Village', '', 1.3629200, 173.1622600, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91354, 'Nawerewere Village', 'Nawerewere Village', 'Causeway', 1.3636200, 173.1393500, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91355, 'Bikenibeu Village', 'Bikenibeu Village', '', 1.3673000, 173.1241500, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91356, 'Eita Village', 'Eita Village', '', 1.3615400, 173.0811300, 'KI', '2010-11-09', 117);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91455, 'Yonggang-ŭp', 'Yonggang-up', 'Chinji-ri,Shinchi-ri,Shinchido,Shinchidō,Yonggang,Yonggang-up,Yonggang-ŭp', 38.8561100, 125.4244400, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91456, 'Yŏngbyŏn', 'Yongbyon', 'Neihen,Nyongbyon,Nyŏngbyŏn,Yongbyon,Yongbyon-up,Yŏngbyŏn,Yŏngbyŏn-ŭp', 39.8133300, 125.8041700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91457, 'Yŏnan-ŭp', 'Yonan-up', 'Enan,Yonan,Yonan-up,Yŏnan,Yŏnan-ŭp', 37.9088900, 126.1611100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91458, 'Yŏmju-ŭp', 'Yomju-up', 'Chonggo-dong,Chŏnggŏ-dong,Teisha,Teisha-do,Teisha-dō,Yomju,Yomju-up,Yŏmju,Yŏmju-ŭp,yeomju,염주', 39.8933300, 124.5980600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91459, 'Wŏnsan', 'Wonsan', 'Gensan,Genzan,Genzan Hu,Onsan,Vonsan,Vonsanas,WOS,Wensen,Wonsan,Wŏnsan,Yuenchan,Yuensan,wonsan,wonsansi,yuan shan shi,Вонсан,元山市,원산,원산시', 39.1527800, 127.4436100, 'KP', '2014-04-20', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91460, 'T’ongch’ŏn-ŭp', 'T''ongch''on-up', 'Kojo,Kojŏ,Kotei,T''ongch''on,T''ongch''on-up,T’ongch’ŏn,T’ongch’ŏn-ŭp', 38.9538900, 127.8916700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91461, 'Sŭngho 1-tong', 'Sungho 1-tong', 'Shoko-ri,Shōko-ri,Sungho,Sungho 1-tong,Sungho-dong,Sungno-ri,Sŭngho,Sŭngho 1-tong,Sŭngho-dong,Sŭngno-ri,seungho1dong,승호1동', 38.9913900, 125.9777800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91462, 'Sunan', 'Sunan', 'Junan,Sunan,Sunan-dong,Sunan-ni,Sunan-up,Sunan-ŭp,Сунан', 39.1983300, 125.6900000, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91463, 'Songnim', 'Songnim', 'Kenjiho,Kenjiko,Kenniho,Kenziho,Kyomip''o,Kyŏmip’o,Shorin,Shōrin,Songnim', 38.7541700, 125.6450000, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91464, 'Sil-li', 'Sil-li', 'Sil-li,Sin-ni', 39.4947200, 125.4736100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91465, 'Sinmak', 'Sinmak', 'Shimbaku,Shimmaku,Shinbaku,Sinmak,sinmag,신막', 38.4166700, 126.2333300, 'KP', '2016-12-03', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91466, 'Sinanju', 'Sinanju', 'Shin-anshu,Shin-anshū,Sin-ansyu,Sin-ansyū,Sinanju,Sinanju-nodongjagu,Sinanju-rodongjagu,Wonhung-ni,Wŏnhŭng-ni,sin-anju,신안주', 39.5980600, 125.6097200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91467, 'Sariwŏn', 'Sariwon', 'Hozan,Sa-ri-uen,Sarivone,Sariwon,Sariwŏn,Shariin,Syariin,Sā-ri-uen,Саривоне', 38.5072200, 125.7558300, 'KP', '2013-07-06', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91468, 'Sangsŏng-ni', 'Sangsong-ni', 'Ku Yangdok,Ku Yangdŏk,Sangsong-ni,Sangsŏng-ni,Tongyang,Tongyang-ni,Toyo,Tōyō,Yangdok,Yangdŏk,Yotoku,Yōtoku', 39.1694400, 126.8855600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91469, 'Samho-rodongjagu', 'Samho-rodongjagu', 'Samho,Samho-dong,Samho-nodongjagu,Samho-rodongjagu,Sanko,samholodongjagu,삼호로동자구', 39.9475000, 127.8711100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91470, 'Pyongyang', 'Pyongyang', 'Binh Nhuong,Bình Nhưỡng,FNJ,Gorad Pkhen''jan,Heijo,Heijo-fu,Heijō,Heijō-fu,Heizyo,Heizyo Hu,Heizyō,Heizyō Hu,Hpyeng-yang,P''yongyang,P''yongyang-si,P''yŏngyang,P''yŏngyang-si,P-hjong-jang,P-hjöng-jang,Pchenjanas,Pchjongjang,Phenian,Phenjan,Phenjana,Phyeng-yang,Phyong-yang,Pienyang,Pingyang,Pion''gian''nk,Pion''nkgian''nk,Piongiang,Pionguiangue,Pionyang,Pjoengjang,Pjongian,Pjongjang,Pjongjango,Pjöngjang,Pkhen''jan,Pkhenjan,Pxenyan,Pyeongyang,Pyoengyang,Pyongyang,Pyongyang-si,Pyöngyang,bywnghyangh,peiyngyang,pi''ongayanga,ping rang,ping rang shi,piyam iyam,piyonyan,pkheniani,pyamgayanga,pyang yang,pyeong-yang,pyeong-yangjighalsi,pyeong-yangsi,pyon''gyang,pyongayanga,pywng yang,pywngyang,Πιονγιάνγκ,Πιονγκγιάνγκ,Горад Пхеньян,Пхеньян,Пхенян,Пјонгјанг,Փխենյան,פיאנגיאנג,פיונגיאנג,بيونغيانغ,پيونګيانګ,پيونگ يانگ,پيوڭياڭ,پیانگ یانگ,پیونگ‌یانگ,پیۆنگیانگ,प्याँगयांग,प्योंगयांग,পিয়ং ইয়াং,ਪਿਓਂਗਯਾਂਗ,பியொங்யாங்,ಪ್ಯೊನ್ಗ್ಯಾಂಗ್,เปียงยาง,ཕོང་ཡང་།,ფხენიანი,ፕዮንግያንግ,平壌,平壤,平壤市,평양,평양시,평양직할시', 39.0338500, 125.7543200, 'KP', '2016-04-09', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91471, 'P’yŏngsŏng', 'P''yongsong', 'P''yongsong,P’yŏngsŏng,Sain-ni,Sainjang,Sanchon,Shajimjo,Shajimjō,Shajinjo,Shajinjō,Shaninjo,Shaninjō', 39.2463900, 125.8719400, 'KP', '2013-08-04', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91472, 'Pyŏksŏng-ŭp', 'Pyoksong-up', 'Ch''wiya,Chuya,Ch’wiya,Pyoksong,Pyoksong-up,Pyŏksŏng,Pyŏksŏng-ŭp,Suiya-ri', 38.0475000, 125.5566700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91473, 'Panghyŏn-dong', 'Panghyon-dong', 'Namsi,Nanshi,Panghyon,Panghyon-dong,Panghyon-nodongjagu,Panghyŏn,Panghyŏn-dong,Panghyŏn-nodongjagu', 39.8872200, 125.2413900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91474, 'Ongjin', 'Ongjin', 'Bazan,Onchzhin,Ongjin,Ongjin-up,Ongjin-ŭp,Oshin,Osin,Yoshin,Yōshin,ongjin,Ōshin,Ōsin,Ончжин,옹진', 37.9347200, 125.3619400, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91475, 'Namp’o', 'Namp''o', 'Channampo,Chinnamp''o,Chinnamp’o,Chinnanpo,Namp''o,Nampkho,Namp’o,Tinnanpo,Treaty Port,Tschin-nam-p-ho,nampo,Нампхо,남포', 38.7375000, 125.4077800, 'KP', '2010-08-03', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91476, 'Kwaksan', 'Kwaksan', 'Kakusan,Kakuzan,Kwaksan,Kwaksan-up,Kwaksan-ŭp,gwagsan,곽산', 39.6875000, 125.0827800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91477, 'Kusŏng', 'Kusong', 'Kijo,Kijō,Kuisong,Kuisŏng,Kusong,Kusong-up,Kusŏng,Kusŏng-ŭp,Kwisog,Kwisŏg', 39.9811100, 125.2447200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91478, 'Kujang-ŭp', 'Kujang-up', 'Kuchung,Kujang,Kujang-dong,Kujang-up,Kujang-ŭp,Kyujo-do,Kyujō-dō', 39.8672200, 126.0302800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91479, 'Kowŏn-ŭp', 'Kowon-up', 'Kogen,Kovon-do,Kowon,Kowon-up,Kowŏn,Kowŏn-ŭp,Kōgen,gowon,Ковон-до,고원', 39.4380600, 127.2430600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91480, 'Kosan', 'Kosan', 'Kosan,Kosan-up,Kosan-ŭp,Shinko-san,Shinkozan,Shinkō-san,Shinkōzan,Sin''gosan,Sin’gosan,gosan,고산', 38.8558300, 127.4180600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91481, 'Koksan', 'Koksan', 'Kokan,Kokchang,Koksan,Koksan-up,Koksan-ŭp,Kokusan,Kokuso,Kokusō,Kokuzan,gogsan,곡산', 38.7819400, 126.6663900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91482, 'Kangdong-ŭp', 'Kangdong-up', 'Kandong,Kangdong,Kangdong-up,Kangdong-ŭp,Koto,Kōtō', 39.1425000, 126.0961100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91483, 'Kaesŏng', 'Kaesong', 'Kaesong,Kaesŏng,Kai-seng,Kaijo,Kaijō,Kaisong,Kaizyo,Kaizyō,Kehson,Kesongas,Shoto,Shōto,Songdo,gaeseongsi,gaeseongteuggeubsi,kai cheng shi,kai cheng te ji shi,Кэсон,开城特级市,開城市,개성시,개성특급시', 37.9708300, 126.5544400, 'KP', '2012-07-04', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91484, 'Hwangju-ŭp', 'Hwangju-up', 'Hwangju,Hwangju-up,Hwangju-ŭp,Koshu,Koshyu,Kosyu,Kōshū,Kōsyū,hwangjueub,황주읍', 38.6702800, 125.7761100, 'KP', '2017-01-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91485, 'Hŭngnam', 'Hungnam', 'Hungbong-ni,Hungdogi-dong,Hungdogil-tong,Hungdok-2-dong,Hungdok-tong,Hungdoki-dong,Hungdong-ni,Hungnam,Hungnam-dong,Hungnam-ni,Hungyam,Hŭngbong-ni,Hŭngdong-ni,Hŭngdŏgi-dong,Hŭngdŏgil-tong,Hŭngdŏk-2-dong,Hŭngdŏk-tong,Hŭngdŏki-dong,Hŭngnam,Hŭngnam-dong,Hŭngnam-ni,Konan,Kōnan,heunglam,흥람', 39.8316700, 127.6186100, 'KP', '2017-01-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91486, 'Hŭkkyo-ri', 'Hukkyo-ri', 'Hukkyo-ri,Hŭkkyo-ri,Kokkyo-ri,Kokkyō-ri,Kokukyori,heuggyoli,흑교리', 38.7986100, 125.7919400, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91487, 'Hoeyang', 'Hoeyang', 'Chunyang,Hoeyang,Hoeyang-up,Hoeyang-ŭp,Junyo,Waiyo,Waiyō,hoeyang,회양', 38.7102800, 127.5983300, 'KP', '2012-02-28', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91488, 'Hamhŭng', 'Hamhung', 'Hamheung,Hamhung,Hamhungas,Hamhungo,Hamhŭng,Hienhing,Kanko,Kankō,hamheung,hamheungsi,xian xing shi,咸興市,함흥,함흥시', 39.9183300, 127.5363900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91489, 'Haeju', 'Haeju', 'Haeju,Hai-dschu,Hai-ju,Hai-tjyou,Haijuube,Haitcheou,Kaishu,Kaishū,Khehdzhu,haeju,Хэджу,해주', 38.0405600, 125.7147200, 'KP', '2017-02-04', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91490, 'Chunghwa', 'Chunghwa', 'Chunghwa,Chunghwa-up,Chunghwa-ŭp,Chuwa,Chūwa,junghwa,중화', 38.8638900, 125.8000000, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91491, 'Chŏngju', 'Chongju', 'Chongju,Chongju-up,Chŏngju,Chŏngju-ŭp,Teishu,Teishū,Teisyu,Teisyū,jeongju,정주', 39.6933300, 125.2102800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91492, 'Changyŏn', 'Changyon', 'Changyon,Changyon-up,Changyŏn,Changyŏn-ŭp,Choen,Chōen,Tschang-jon,Tschang-jön,jang-yeon,장연', 38.2508300, 125.0961100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91493, 'Chaeryŏng-ŭp', 'Chaeryong-up', 'Chaenyong,Chaenyŏng,Chaeryong,Chaeryong-up,Chaeryŏng,Chaeryŏng-ŭp,Cheyong,Sainei,Sainei-men,Sainei-yu,Sainei-yū,jaelyeong-eub,재령읍', 38.3991700, 125.6155600, 'KP', '2013-05-09', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91494, 'Ayang-ni', 'Ayang-ni', 'Ayang-ni,Gayo-ri,Gayō-ri,ayangli,아양리', 38.2430600, 125.7800000, 'KP', '2017-02-04', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91495, 'Anju', 'Anju', 'Aanshu,An-dschu,Anju,Anju-up,Anju-ŭp,Anshu,Anshū,Ansyu,Ansyu Yu,Ansyū,Ansyū Yū,anju,안주', 39.6177800, 125.6647200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91496, 'Anbyŏn-ŭp', 'Anbyon-up', 'Ampen,Anbyon,Anbyon-up,Anbyŏn,Anbyŏn-ŭp,Anhen,Anpen', 39.0425000, 127.5238900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91497, 'Anak', 'Anak', 'Aenak,Anag-up,Anag-ŭp,Anak,Anak-up,Anak-ŭp,Angaku,Nangaku,an-ag,안악', 38.5108300, 125.4941700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91498, 'Sinsang-ni', 'Sinsang-ni', 'Sinsang-ni,sinsangli,신상리', 39.6502800, 127.4058300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91499, 'Yuktae-dong', 'Yuktae-dong', 'Rokudaito-ri,Rokudaitō-ri,Yuktae-dong,Yuktae-nodongjagu,Yuktaedong-ni,Yuktaetong-ni', 40.0247200, 128.1597200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91500, 'Ungsang-nodongjagu', 'Ungsang-nodongjagu', 'Ungsang-dong,Ungsang-ni,Ungsang-nodongjagu,ungsanglodongjagu,웅상로동자구', 42.3577800, 130.4622200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91501, 'Ŭiju', 'Uiju', 'Eui-chu,Gishu,Gishū,Gisyu,Gisyū,Ui-tsiu,Uiju,Uiju-up,Wi-dschu,Wi-ju,uiju,Ŭiju,Ŭiju-ŭp,의주', 40.1994400, 124.5316700, 'KP', '2016-06-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91502, 'Ŭijin-dong', 'Uijin-dong', 'Uijil-li,Uijin-dong,Uijin-ni,uijindong,uijinli,Ŭijil-li,Ŭijin-dong,Ŭijin-ni,의진동,의진리', 40.9751800, 126.4958400, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91503, 'Sŭngam-nodongjagu', 'Sungam-nodongjagu', 'Kjong-song,Kjöng-söng,Kyeng-seng,Kyojo,Kyongsong,Kyongusogu,Kyozyo,Kyōjō,Kyōzyō,Kyŏngsŏng,Sungam-ni,Sungam-nodongjagu,Sŭngam-ni,Sŭngam-nodongjagu,seung-amlodongjagu,승암로동자구', 41.6697200, 129.6688900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91504, 'Sŏnbong', 'Sonbong', 'Ongei,Seonbong,Sonbon,Sonbong,Sonbong-up,Sŏnbong,Sŏnbong-ŭp,Unggi,Unggi-up,Unggi-yu,Yuki,Yūki,seonbong,Сонбон,선봉', 42.3416100, 130.3944500, 'KP', '2017-07-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91505, 'Sinŭiju', 'Sinuiju', 'New Eui-chu,Shingishu,Shingishū,Sin-eui-chu,Sin-gi-shu,Sineidzu,Sineidžu,Sinidzsu,Sinuiju,Sinyichju,Sinŭiju,Wi-dschu,Wi-ju,sin-uiju,sin-uijusi,xin yi zhou,xin yi zhou shi,新义州,新義州市,신의주,신의주시', 40.1005600, 124.3980600, 'KP', '2016-06-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91506, 'Sakchu-ŭp', 'Sakchu-up', 'Sakchu,Sakchu-up,Sakchu-ŭp,Sakushu,Sakushū', 40.3894400, 125.0466700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91507, 'Puryŏng', 'Puryong', 'Funei,Kuum-nodongjagu,Kuup-nodongjagu,Kuŭm-nodongjagu,Kuŭp-nodongjagu,Pu-rjong,Punyong,Punyŏng,Purong-dong,Puryong,Puryong-ni,Puryong-up,Puryŏng,Puryŏng-ŭp,Puyong,bulyeong,부령', 42.0605600, 129.7116700, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91508, 'Pukchil-lodongjagu', 'Pukchil-lodongjagu', 'Hokuchin,Puckchin,Pukch''ang,Pukchil-lodongjagu,Pukchin,Pukchin-nodongjagu,Pukch’ang,Pukutin,bugjinlodongjagu,북진로동자구', 40.2019400, 125.7483300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91509, 'Yŏnggwang-ŭp', 'Yonggwang-up', 'Goro-ri,Gorō-ri,Oro,Oro-ri,Oro-up,Oro-ŭp,Yonggwang-up,Yongwang,Yŏnggwang-ŭp,Yŏngwang', 40.0183300, 127.4547200, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91510, 'Onsŏng', 'Onsong', 'Kosong,Kosong-ni,Kosŏng,Kosŏng-ni,Onjo,Onjō,Onsong,Onsong-up,Onsŏng,Onsŏng-ŭp,onseong,온성', 42.9572200, 129.9933300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91511, 'Nanam', 'Nanam', 'Naman,Nanam,Ranam,lanam,Нанам,라남', 41.7136100, 129.6844400, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91512, 'Namyang-dong', 'Namyang-dong', '', 42.9500000, 129.8666700, 'KP', '2006-01-17', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91513, 'Rajin', 'Rajin', 'Najin,Najin-up,Najin-ŭp,Radzin,Rajin,Rashin,Rasin,lajin,Радзин,라진', 42.2488900, 130.3002800, 'KP', '2017-01-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91514, 'Musan-ŭp', 'Musan-up', 'Mosan,Mozan,Musan,Musan-up,Musan-ŭp,musan-eub,무산읍', 42.2260900, 129.2077600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91515, 'Kyŏngwŏn', 'Kyongwon', 'Keigen,Kyongwon,Kyungwan,Kyungwon,Kyŏngwŏn,gyeong-won,경원', 42.8136100, 130.1527800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91516, 'Kyŏngsŏng', 'Kyongsong', 'Churuonjan,Chuul,Chuuronjang,Chuŭl,Chuŭronjang,Kyongsong,Kyongsong-up,Kyŏngsŏng,Kyŏngsŏng-ŭp,Shuotsu,Shuotsuonjo,Shuotsuonjō,gyeongseong,경성', 41.5877800, 129.6061100, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91517, 'Kimch’aek-si', 'Kimch''aek-si', 'Kimch''aek,Kimch''aek-si,Kimch’aek,Kimch’aek-si,Siong-tschin,Siöng-tschin,Song-chin,Songjin,Sŏngjin,gimchaeg,gimchaegsi,김책,김책시', 40.6688900, 129.1897200, 'KP', '2012-09-07', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91518, 'Kilju', 'Kilju', 'Kichishu,Kichishū,Kil''dzhu,Kil-dschu,Kilchu,Kilchu-up,Kilchu-ŭp,Kilju,Kisshu,Kisshū,gilju,Кильджу,길주', 40.9641700, 129.3277800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91519, 'Kapsan-ŭp', 'Kapsan-up', 'Kapsan,Kapsan-up,Kapsan-ŭp,Kapsane-do,Kosan,Kozan,Kōsan,Kōzan,gabsan-eub,Капсане-до,갑산읍', 41.0902800, 128.2933300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91520, 'Kanggye', 'Kanggye', 'Kakai,Kang-ge,Kange,Kanggye,Kanggye-si,Kokai,Kōkai,gang-gye,gang-gyesi,jiang jie,jiang jie shi,Канге,江界,江界市,강계,강계시', 40.9694600, 126.5852300, 'KP', '2017-01-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91521, 'Iwŏn-ŭp', 'Iwon-up', 'Gunsen,Iwon,Iwon-up,Iwŏn,Iwŏn-ŭp,Kunsen,Kunson,Kunsŏn,liwon,리원', 40.3230600, 128.6552800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91522, 'Hyesan-dong', 'Hyesan-dong', 'Hyesan-dong,hyesandong,혜산동', 41.3975600, 128.1787300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91523, 'Hyesan', 'Hyesan', 'Hesanjin,Hyesan,Hyesan-si,Hyesanjin,Keisanchin,Keizan,Keizanchin,Keizantin,hui shan shi,hyesan,hyesansi,恵山市,惠山市,혜산,혜산시', 41.4016700, 128.1777800, 'KP', '2017-01-05', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91524, 'Hŭngju-dong', 'Hungju-dong', 'Hungju-dong,Hungju-ri,Hŭngju-dong,Hŭngju-ri,heungjudong,흥주동', 40.9962900, 126.5475600, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91525, 'Hongwŏn', 'Hongwon', 'Hongwon,Hongwon-up,Hongwŏn,Hongwŏn-ŭp,Kogen,Kogon,Kōgen,hong-won,홍원', 40.0252800, 127.9558300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91526, 'Hoeryŏng', 'Hoeryong', 'Hoenyong,Hoenyŏng,Hoeryong,Hoeryong-up,Hoeryŏng,Hoeryŏng-ŭp,Kaeryong,Kaeryŏng,Kainei,Kainei-yu,Kainei-yŭ,Kwainei,hoelyeong,회령', 42.4427800, 129.7508300, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91527, 'Hoemul-li', 'Hoemul-li', 'Hoemul-li,Hoemun-dong,Hoemun-ni,Kaibon,Kaibun-do,Kaibun-dŏ,hoemunli,회문리', 41.4338900, 129.6700000, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91528, 'Hau-ri', 'Hau-ri', 'Hau-ri,Haun-ni,Meisen,Menchkan,Menchkhon,Myonchon,Myongch''on,Myŏngch’ŏn,hauli,하우리', 41.2005600, 129.4702800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91529, 'Chongjin', 'Chongjin', 'Cchongdzin,Ch''ongjin,Cheongjin,Chkhonchzhine,Chkhondzhin,Chkhundzhin,Chongjin,Chonjin,Chonzhin'',Chŏngjin,Ch’ŏngjin,Condzinas,Congjin,Cshongdzsin,RGO,Seishin,Seisin,Tschiun-tschan,Tschiün-tschan,ch xng cin,cheongjinsi,chwngjn,congjina,qing jin shi,Ĉongĵin,Čchongdžin,Čondžinas,Чонжинь,Чхонджин,Чхонджін,Чхончжине,Чхънджин,چونگجن,चोंग्जिन,ช็องจิน,清津市,청진시', 41.7955600, 129.7758300, 'KP', '2013-05-22', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91530, 'Chasŏng', 'Chasong', 'Chasong,Chasong-up,Chasŏng,Chasŏng-ŭp,Jijo,Jijō,Tscha-song,Tscha-söng,Zizyo,Zizyō', 41.4608300, 126.6413900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91531, 'Aoji-ri', 'Aoji-ri', 'Agochi,Agochi-do,Agochi-dŏ,Agoji-do,Agoji-dŏ,Aodi-ri,Aoji,Aoji-dong,Aoji-ri,aojili,Аоди-ри,아오지리', 42.5205600, 130.3952800, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91532, 'Sŭngjibaegam', 'Sungjibaegam', 'Sungjibaegam,Sungjipaegam,Sŭngjibaegam', 41.2427800, 128.7988900, 'KP', '2012-01-19', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91533, 'Komusan 1-tong', 'Komusan 1-tong', '', 42.1091700, 129.7000000, 'KP', '2006-01-17', 118);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91534, 'Heunghae', 'Heunghae', 'Funhai,Heung-hai,Heunghae,Hunghae,Hŭnghae,Kokai,Kōkai,Uich''ang,heunghae,Ŭich’ang,흥해', 36.1094500, 129.3451700, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91535, 'Yeonil', 'Yeonil', 'Eijitsu,Enjitsu,Yeonil,Yonil,Yŏnil,yeon-il,연일', 35.9952600, 129.3516200, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91536, 'Neietsu', 'Neietsu', 'Neietsu,Yongwol,Yŏngwŏl,yeong-wol,영월', 37.1844700, 128.4682100, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91537, 'Eisen', 'Eisen', 'Eisen,Eishu,Eishū,Yongju,Yŏngju', 36.8216700, 128.6308300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91538, 'Reiko', 'Reiko', 'Reiko,Yonggwang,Yŏnggwang', 35.2750000, 126.5094400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91539, 'Yŏng-dong', 'Yong-dong', 'Eido,Eidō,Yeongdong,Yong-dong,Yŏng-dong,yeongdong,영동', 36.1750000, 127.7763900, 'KR', '2013-03-02', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91540, 'Yeongdeok', 'Yeongdeok', 'Bontoku,Eitoku,Tongdok,Tŏngdŏk,Yeongdeok,Yondoku,Yongdok,Yŏngdŏk,yeongdeog,영덕', 36.4136600, 129.3700000, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91541, 'Eisen', 'Eisen', 'Eisen,Yongch''on,Yŏngch’ŏn', 35.9675000, 128.9308300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91542, 'Yeoncheon', 'Yeoncheon', 'Rensen,Yeoncheon,Yonch''on,Yŏnch’ŏn,yeoncheon,연천', 38.1011300, 127.0772700, 'KR', '2014-12-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91543, 'Yeoju', 'Yeoju', 'Reishu,Reishū,Rishu,Rishū,Yeoju,Yoju,Yŏju,yeoju,여주', 37.2958300, 127.6338900, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91544, 'Yesan', 'Yesan', 'Esan,Jesan,Reisan,Reizan,Yesan,Yosan,Yŏsan,yesan,Есан,예산', 36.6775600, 126.8427200, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91545, 'Yecheon', 'Yecheon', 'Hosen,Reisen,Yech''on,Yecheon,Yech’ŏn,yecheon,예천', 36.6574000, 128.4551400, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91546, 'Yangsan', 'Yangsan', 'Jangsan,Jansan,Ryosan,Ryozan,Ryōsan,Ryōzan,Yangsan,liang shan shi,yangsan,yangsansi,Янсан,سانگ‌سان,یانگسان,梁山市,양산,양산시', 35.3419900, 129.0335800, 'KR', '2016-03-10', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91547, 'Yangp''yŏng', 'Yangp''yong', 'Tohei,Yangp''yongumnae,Yangp''yŏngŭmnae,Yangpyeong,Yanp''yong,Yanp''yŏng,yangpyeong,yangpyeong-gun,양평,양평군', 37.4897200, 127.4905600, 'KR', '2010-08-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91548, 'Yangju', 'Yangju', 'Jandzhu,Yangju-gun,yang zhou shi,yangju,yangjusi,yangjw,Янджу,یانگجو,楊州市,양주,양주시', 37.8331100, 127.0616900, 'KR', '2010-07-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91549, 'Yanggu', 'Yanggu', 'Yanggu,yang-gu,yang-gugun,양구,양구군', 38.1058300, 127.9894400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91550, 'Wŏnju', 'Wonju', 'Genshu,Genshū,Vondzhu,WJU,Wonju,Wŏnju,Вонджу', 37.3513900, 127.9452800, 'KR', '2017-01-24', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91551, 'Wanju', 'Wanju', 'wanju,wanju-gun,wanjugun,완주,완주군', 35.8450900, 127.1475200, 'KR', '2010-07-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91552, 'Waegwan', 'Waegwan', 'Chilgok,Oegwan,Waegwan,Waegwan-dong,Waegwan-ni,Waikan,Wakan,chungju,waegwan,왜관', 35.9925100, 128.3978500, 'KR', '2015-12-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91553, 'Ulsan', 'Ulsan', 'USN,Ul''san,Ulsan,Ulsan-si,Urusan,ulsan,ulsangwang-yeogsi,ulsansi,wei shan,wei shan guang yu shi,Ульсан,蔚山,蔚山広域市,울산,울산광역시,울산시', 35.5372200, 129.3166700, 'KR', '2014-01-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91554, 'Uijeongbu-si', 'Uijeongbu-si', 'Uijeongbu,Uijeongbu-si,uijeongbu,uijeongbusi,의정부,의정부시', 37.7415000, 127.0474000, 'KR', '2014-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91555, 'Dongnae', 'Dongnae', 'Dongnae,Tokunei,Tongnae,Torai,Tōrai,donglae,동래', 35.2015900, 129.0847700, 'KR', '2016-04-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91556, 'Tangjin', 'Tangjin', 'Tangjin,Toshin,Tosin,Tōshin,Tōsin,dangjin,당진', 36.8944400, 126.6297200, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91557, 'Damyang', 'Damyang', 'Damyang,Tamyang,Tanyang,Tanyo,Tanyō,dam-yang,담양', 35.3188900, 126.9838900, 'KR', '2016-06-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91558, 'Taesal-li', 'Taesal-li', 'Taesal-li,Taesan,Taesan-ni,Taisan-ri,daesanli,대산리', 36.9714000, 126.4542000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91559, 'Daejeon', 'Daejeon', 'Daejeon,Daejeon-si,Daejon,Daiden,QTW,Taejon,Taejŏn,Taiden,Tehdzhon,Tetyan,Thai-tyen,Thāi-tyen,Tētyan,da tian guang yu shi,daejeon,daejeongwang-yeogsi,daejeonsi,Тэджон,大田广域市,大田広域市,대전,대전광역시,대전시', 36.3213900, 127.4197200, 'KR', '2014-01-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91560, 'Daegu', 'Daegu', 'Daegu,Daegu Kong-hek-chhi,Daegu Kóng-he̍k-chhī,Daegu-si,Daikyu,Daikyū,GJai Khau,Ntenkou,TAE,Taegu,Taikando,Taikandō,Taiku,Taikyu,Taikyū,Tegu,Teguo,Tehgu,Tägu,da qiu guang yu shi,daegu,daegugwang-yeogsi,daegusi,daigu,dayjw,degu,dyghw,tgw,Đại Khâu,Ντέγκου,Тегу,Тэгу,Тэгү,טגו,دائجو,ديغو,ڈیگو,दैगू,ദേഗു,แทกู,大邱广域市,大邱広域市,大邱廣域市,대구,대구광역시,대구시', 35.8702800, 128.5911100, 'KR', '2016-02-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91561, 'Taisen-ri', 'Taisen-ri', 'Daisen,Hannae-ri,Poryong,Poryŏng,Taech''on,Taech''on-ni,Taech’ŏn,Taech’ŏn-ni,Taisen,Taisen-ri,bolyeong,보령', 36.3493100, 126.5977200, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91562, 'T’aebaek', 'T''aebaek', 'T''aebaek,Tkhehbehk,T’aebaek,taebaeg,Тхэбэк,태백', 37.1759000, 128.9889000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91563, 'Suwon', 'Suwon', 'SWU,Sououon,Suvon,Suwon,Suwon-si,shui yuan shi,suvona,suwon,suwonsi,suwxn,swwn,Σούουον,Сувон,سوون,सुवोन,ซูว็อน,水原市,수원,수원시', 37.2911100, 127.0088900, 'KR', '2017-04-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91564, 'Suncheon', 'Suncheon', 'Junten,SYS,Sunch''on,Suncheon,Sunchun,Sunch’ŏn,suncheon,순천', 34.9480800, 127.4894700, 'KR', '2013-02-26', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91565, 'Seoul', 'Seoul', 'Gorad Seul,Hanyang,SEL,Seoel,Seol,Seoul,Seoul-si,Seuel,Seul,Seula,Seulas,Seulo,Seulum,Seúl,Seül,Siul,Soeul,Sol,Soul,Sye-ul,Syou-ouen,Szoeul,Szöul,Séoul,Sêûl,Söul,Sŏul,Wang-ching,Wo-jo,Wō-jō,ciyol,han-yang,saul,seoul,seoulsi,seoulteugbyeolsi,seuli,shou er,shou er te bie shi,si''ula,siyola,sol,sola,souru,souru te bie shi,sywl,Σεούλ,Горад Сеул,Сеул,Соул,Сөүл,Սեուլ,סאול,סיאול,סעאל,سئول,سيول,سیول,سێئول,سېئول,सियोल,सोल,সিউল,சியோல்,ಸೌಲ್,സോൾ,โซล,སེ་ཨུལ།,ဆိုးလ်မြို့,სეული,ሶል,សេអ៊ូល,ソウル,ソウル特別市,首尔,首尔特别市,서울,서울시,서울특별시,한양', 37.5660000, 126.9784000, 'KR', '2015-06-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91566, 'Seosan', 'Seosan', 'HMY,Seosan,Seosan City,Sosan,Suisan,Sŏsan,rui shan shi,seosan,seosansi,Сосан,瑞山市,서산,서산시', 36.7816700, 126.4522200, 'KR', '2016-06-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91567, 'Jenzan', 'Jenzan', 'Jenzan,Seonsan,Sonsan,Sŏnsan,seonsan,선산', 36.2408300, 128.2975000, 'KR', '2013-03-02', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91568, 'Seonghwan', 'Seonghwan', 'Seikan-ri,Seonghwan,Songhwan,Songhwan-ni,Songwon,Sŏnghwan,Sŏnghwan-ni,seonghwan,성환', 36.9155600, 127.1313900, 'KR', '2015-02-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91569, 'Sokcho', 'Sokcho', 'Sogcho,Sokch''o,Sokch''o-ri,Sokchkho,Sokcho,Sokch’o,Sokch’o-ri,sogcho,Сокчхо,속초', 38.2070100, 128.5918100, 'KR', '2014-11-05', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91570, 'Seogeom-ri', 'Seogeom-ri', 'Seogeom-ri,Seogeomni,Sogom-ni,Sŏgŏm-ni,seogeomli,서검리', 37.7187100, 126.2330400, 'KR', '2013-07-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91571, 'Sintansin', 'Sintansin', 'Shinnanri,Shintanshin,Shintanzhin,Sint''anjin,Sintansin,Sint’anjin,sintanjin,Шинтанжин,신탄진', 36.4536100, 127.4311100, 'KR', '2013-01-13', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91572, 'Sangju', 'Sangju', 'Ch''angju,Ch’angju,Sandzhu,Sang-dschu,Sangju,Shoshu,Shōshū,Syosyu,Syōsyū,sangju,Санджу,상주', 36.4152800, 128.1605600, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91573, 'Santyoku', 'Santyoku', 'Samch''ok,Samcheok,Samchkhok,Samch’ŏk,Samuchoku,Sanchoku,Sansho,Santyoku,samcheog,Самчхок,삼척', 37.4405600, 129.1708300, 'KR', '2015-06-16', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91574, 'Fuyo', 'Fuyo', 'Fuyo,Pujo,Puyo,Puyŏ,buyeo,Пуйо,부여', 36.2819400, 126.9125000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91575, 'Busan', 'Busan', 'Bousan,Busan,Busan-si,Busán,Fousan,Fusan,Fuzan,PUS,Phu San,Phủ San,Pusan,Pusana,Pusano,Tsau-liang-hai,busan,busangwang-yeogsi,busansi,fu shan,fu shan guang yu shi,fu shan shi,pu san,Μπούσαν,Пусан,ปูซาน,釜山,釜山市,釜山广域市,釜山広域市,부산,부산광역시,부산시', 35.1027800, 129.0402800, 'KR', '2016-04-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91576, 'Bucheon-si', 'Bucheon-si', 'Bucheon,Bucheon-si,bucheon,bucheonsi,부천,부천시', 37.4988900, 126.7830600, 'KR', '2014-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91577, 'Puan', 'Puan', 'Fuan,Puan', 35.7280600, 126.7319400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91578, 'Beolgyo', 'Beolgyo', 'Bakkyo-ri,Bakkyō-ri,Beolgyo,Polgyo,Pŏlgyo,beolgyo,벌교', 34.8449500, 127.3429300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91579, 'Pohang', 'Pohang', 'Geijitsu,Hoko,Hoko-do,Hokō-dō,KPO,P''ohang,P''ohang-dong,Pohang,P’ohang,P’ohang-dong,pohang,포항', 36.0291700, 129.3648100, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91580, 'Beobwon', 'Beobwon', 'Beobwon,Pobwon,Pobwon-dong,Pobwon-ni,Pŏbwŏn,Pŏbwŏn-dong,Pŏbwŏn-ni,beob-won,법원', 37.8490200, 126.8753300, 'KR', '2015-02-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91581, 'Osan', 'Osan', 'OSN,Osan,Osan-ni,Usan'',Usan-ri,Vu-san-su,Vû-sân-sṳ,awsan,osan,osansi,wu shan shi,xo san,Осан,Усань,اوسان,โอซัน,烏山市,오산,오산시', 37.1522200, 127.0705600, 'KR', '2017-04-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91582, 'Asan', 'Asan', 'Asan,Asan'',Aszan,Nga-san-su,Ngà-sân-sṳ,Onyang,Onyo,Onyō,acan,asan,asansi,xa san,ya shan shi,Асан,Асань,آسان,அசன்,อาซัน,牙山市,아산,아산시', 36.7836100, 127.0041700, 'KR', '2014-04-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91583, 'Okcheon', 'Okcheon', 'Kumgu-ri,Okcheon,ogcheon,ogcheongun,옥천,옥천군', 36.3012000, 127.5680000, 'KR', '2013-03-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91584, 'Kosong', 'Kosong', 'Kosong,goseong,goseong-gun,고성,고성군', 38.3788100, 128.4676000, 'KR', '2010-07-28', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91585, 'Nonsan', 'Nonsan', 'Lun-san-su,Lun-sân-sṳ,Nonsan,Nun''san'',Ronsan,Ronzan,lun shan shi,nnsan,nonsansi,nwnsan,Нонсан,Нуньсань,ننسان,نونسان,論山市,논산시', 36.2038900, 127.0847200, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91586, 'Nangen', 'Nangen', 'Mangen,Namvon,Namweon,Namwon,Namwun,Namwŏn,Namwŭn,Nangen,Намвон', 35.4100000, 127.3858300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91587, 'Naju', 'Naju', 'Nadzhu,Nadzu,Nadžu,Naju,Rashu,Rashū,luo zhou shi,naju,najusi,najw,Наджу,Нажү,ناجو,羅州市,나주,나주시', 35.0292000, 126.7175000, 'KR', '2016-06-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91588, 'Munsan', 'Munsan', 'Munsan,Munsan-ni,Мунсан', 37.8594400, 126.7850000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91589, 'Mungyeong', 'Mungyeong', 'Bunke-gun,Bunkei-gun,Bunkē-gun,Mun''gyong,Mun''gyong-gun,Mun''gyōng-gun,Mun''gyŏng,Mungjon,Mungjong,Mungyeong gun,Munkyong-Mining Region,mungyeong,mungyeongsi,mwngywang,wen qing shi,Мунгён,مونگیوانگ,聞慶市,문경,문경시', 36.5945800, 128.1994600, 'KR', '2010-07-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91590, 'Mungyeong', 'Mungyeong', 'Bunkei,Mun''gyong,Mungyeong,Mun’gyŏng,mungyeong,문경', 36.7352800, 128.1083300, 'KR', '2015-08-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91591, 'Muan', 'Muan', 'MWX,Muan,Muan-gun,Muap', 34.9901400, 126.4789900, 'KR', '2013-08-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91592, 'Moppo', 'Moppo', 'Mogpkho,Mogpo,Mok-pho,Mokp''o,Mokp’o,Mokuho,Moppo,Могпхо', 34.7936100, 126.3886100, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91593, 'Miryang', 'Miryang', 'Milyang,Mirjan,Mirjang,Miryang,Mitsuyo,Mitsuyō,mi yang shi,mil-yangsi,mryang,myryang,Мирян,مریانگ,میریانگ,密陽市,밀양시', 35.4933300, 128.7488900, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91594, 'Masan', 'Masan', 'Masan,Masan-ni,masan,마산', 35.1272500, 126.8314900, 'KR', '2017-04-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91595, 'Gyeongsan-si', 'Gyeongsan-si', 'Gyeongsan,Gyeongsan-si,gyeongsan,gyeongsansi,경산,경산시', 35.8233300, 128.7377800, 'KR', '2014-03-30', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91596, 'Kyonju', 'Kyonju', 'Gyeongju,Keishu,Keishū,Keisyu,Keisyū,Kjondzhu,Kjong-dschu,Kjöng-dschu,Kyeng-chu,Kyeng-ju,Kyong-choo,Kyongju,Kyonju,Kyŏngju,gyeongjusi,qing zhou,qing zhou shi,Кёнджу,慶州,慶州市,경주시', 35.8427800, 129.2116700, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91597, 'Kwangyang', 'Kwangyang', 'Gwang-yang,Koyo,Kuwagyan,Kwangyang,Kōyō', 34.9752800, 127.5891700, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91598, 'Gwangju', 'Gwangju', 'Gwangju,Kong-chu-su,Kvandzhu,Kwangdzu,Kwangdžu,Kwangju,Kóng-chû-sṳ,guang zhou,guang zhou shi,gwang jw  gyywngy,gwangju,gwangjusi,gwangjw  gywnggy,kh wang cu,Кванджу,گوانگ جو، گیئونگی,گوانگجو، گیونگگی,ควังจู,კვანჯუ,広州市,廣州,廣州市,광주,광주시', 37.4100000, 127.2572200, 'KR', '2015-07-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91599, 'Gwangju', 'Gwangju', 'Gorad Kvandzhu,Gouanjou,Gwangju,Gwangju Kong-hek-chhi,Gwangju Kóng-he̍k-chhī,Gwangju-si,KWJ,Koshu,Kosyu,Kuandzhu,Kuangju,Kuangjuo,Kvandzhu,Kvandzu,Kvandžu,Kvangdzsu,Kvangdzu,Kvanju,Kvanzhe,Kvaңdzhu,Kwang-choo,Kwang-dschu,Kwangdzu,Kwangdžu,Kwangju,Kōshū,Kōsyū,Kŭangĵuo,Quansua,ghwanghjw,guang zhou,guang zhou guang yu shi,guang zhou shi,gvangaju,gwang jw,gwangju,gwangjugwang-yeogsi,gwangjusi,gwangjw,kh wang cu,Горад Кванджу,Квангџу,Кванджу,Кванже,Кваңджу,Куанджу,Куанжү,קוואנגגו,غوانغجو,گوانگ جو,گوانگجو,ग्वांगजू,ควังจู,光州,光州市,光州广域市,光州広域市,光州廣域市,광주,광주광역시,광주시', 35.1547200, 126.9155600, 'KR', '2014-04-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91600, 'Guryongpo', 'Guryongpo', 'Guryongpo,Kuryongp''o,Kuryongp’o,Kuryuho-ri,Kuyongp''o,Kuyongp’o,Kyuryuho-ri,Kyūryūho-ri,Kūryūho-ri,gulyongpo,구룡포', 35.9899400, 129.5537700, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91601, 'Kurye', 'Kurye', 'Kurye,Kyurei,Kyūrei,gulye,gulyegun,구례,구례군', 35.2094400, 127.4644400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91602, 'Guri-si', 'Guri-si', 'Guri,Guri-si,guli,gulisi,구리,구리시', 37.5986000, 127.1394000, 'KR', '2014-01-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91603, 'Kunwi', 'Kunwi', 'Guni,Kunwi,gun-wi,gun-wigun,군위,군위군', 36.2347200, 128.5727800, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91604, 'Gunsan', 'Gunsan', 'Gunsan,Gunzan,KUV,Kunsan,Kunzan,gunsansi,qun shan shi,Кунсан,群山市,군산시', 35.9786100, 126.7113900, 'KR', '2016-12-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91605, 'Kinzan', 'Kinzan', 'Kinsan,Kinzan,Kumsan,Kumzan,Kŭmsan,Kŭmzan,geumsan,금산', 36.1030600, 127.4888900, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91606, 'Gumi', 'Gumi', 'Gumi,Kibi,Kumi,Kwimi,QKM,gui wei shi,gumi,gumisi,Куми,亀尾市,龟尾市,구미,구미시', 36.1136000, 128.3360000, 'KR', '2013-05-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91607, 'Goyang-si', 'Goyang-si', 'Goyang,Goyang-si,QYK,goyang,goyangsi,고양,고양시', 37.6563900, 126.8350000, 'KR', '2014-01-30', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91608, 'Goseong', 'Goseong', 'Goseong,Kojo,Kojō,Koson,Kosong,Kosŏng,Kozyo,Kozyō,goseong,Косон,고성', 34.9763100, 128.3236100, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91609, 'Gongju', 'Gongju', 'Gongju,Kochu,Kondzhu,Kong Tjou,Kong-dschu,Kongju,Koshu,Kosyu,Kōshū,Kōsyū,gong zhou,gong zhou shi,gongju,gongjusi,Конджу,公州,公州市,공주,공주시', 36.4555600, 127.1247200, 'KR', '2014-04-23', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91610, 'Kyosai', 'Kyosai', 'Koje,Kyosai,Kŏje', 34.8502800, 128.5886100, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91611, 'Koesan', 'Koesan', 'Goesan,Kaesong,Kaisan,Kaizan,Koesan,Kwaesan,Kwaizan,goesan,goesangun,괴산,괴산군', 36.8108300, 127.7947200, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91612, 'Koch''ang', 'Koch''ang', 'Kosho,Kōshō,gochang,gochang-gun,고창,고창군', 35.4333300, 126.7000000, 'KR', '2010-08-14', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91613, 'Kimje', 'Kimje', 'Kimje,Kintei,Kum,Kumje,Kŭmje', 35.8016700, 126.8888900, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91614, 'Kimhae', 'Kimhae', 'Gimhae,Kimhae,Kinkai,Kumhae,Kŭmhae', 35.2341700, 128.8811100, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91615, 'Gimcheon', 'Gimcheon', 'Gimcheon,Kimcchon,Kimch''on-si,Kimch''ŏn-si,Kimchkhon,Kimčchon,Kumch''on-si,Kŭmch''ŏn-si,gim cheonsi,gimcheon,gimcheonsi,gmchywn,gymchywn,jin quan shi,Кимчхон,گمچیون,گیمچئون,金泉市,김 천시,김천,김천시', 36.1217600, 128.1198100, 'KR', '2010-07-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91616, 'Gijang', 'Gijang', 'Gijang,Kichang,Kicho,Kichō,Kijang,gijang,기장', 35.2441700, 129.2138900, 'KR', '2015-05-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91617, 'Gapyeong', 'Gapyeong', 'District de Gapyeong,Gapyeong County,Gapyeong-gun,Kahei-gun,Kap''yong-gun,Kap''yŏng-gun,Kapkhjon,gapyeong,gapyeong-gun,jia ping jun,Капхён,加平郡,가평,가평군', 37.8310100, 127.5105900, 'KR', '2016-01-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91618, 'Kang-neung', 'Kang-neung', 'Gangneung,Gangreung,KAG,Kaguun,Kang-neung,Kangnung,Kangnŭng,Kannyn,Koryo,Kōryō,gangleungsi,jiang ling shi,Каннын,江陵市,강릉시', 37.7555600, 128.8961100, 'KR', '2017-02-02', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91619, 'Ganghwa-gun', 'Ganghwa-gun', 'Ganghwa-gun,ganghwagun,강화군', 37.7472200, 126.4855600, 'KR', '2014-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91620, 'Gampo', 'Gampo', 'Gampo,Kamp''o,Kamp''o-ri,Kamp’o,Kamp’o-ri,Kanho-ri,Kanpori,gampo,감포', 35.8053800, 129.5011000, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91621, 'Iksan', 'Iksan', 'Iksan,Iri,Riri,aksan,ayksan,igsansi,iksani,yi shan shi,Іксан,Иксан,اکسان,ایکسان,იქსანი,益山市,익산시', 35.9438900, 126.9544400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91622, 'Incheon', 'Incheon', 'Gorad Inchkhon,ICN,Incchon,Inch''on,Inch''ŏn,Incheon,Incheon-si,Inchkhon,Inchkhun,Inchon,Inchona,Incon,Inconas,Incshon,Intson,Inĉon,Inčchon,Inčhona,Inčonas,JCN,Nhan Xuyen,Nhân Xuyên,anchn,antshwn,aynchywn,incevona,incheon,incheongwang-yeogsi,incheonsi,inkiyon,ren chuan guang yu shi,xin chxn,İncheon,Ίντσον,Інчхон,Горад Інчхон,Инчон,Инчхон,Инчхън,אינצ''ון,إنتشون,انچن,اینچئون,इंचेवॉन,இங்கியோன்,อินช็อน,仁川广域市,仁川広域市,仁川廣域市,인천,인천광역시,인천시', 37.4564600, 126.7051500, 'KR', '2016-02-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91623, 'Imsil', 'Imsil', 'Imsil,Ninjitsu,imsil,imsilgun,임실,임실군', 35.6130600, 127.2794400, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91624, 'Icheon-si', 'Icheon-si', 'Icheon,Icheon-si,icheon,icheonsi,이천,이천시', 37.2791700, 127.4425000, 'KR', '2014-03-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91625, 'Hyeonpung', 'Hyeonpung', 'Gempu,Gempū,Genfu,Genfū,Genpu,Geupuu,Hyeonpung,Hyongp''ung,Hyonp''ung,Hyŏngp’ung,Hyŏnp’ung,Pudong,hyeonpung,현풍', 35.6955700, 128.4460800, 'KR', '2016-02-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91626, 'Hwasun', 'Hwasun', 'Hwansun,Hwason,Hwasun,Khvasun,Wajun,hwasun,Хвасун,화순', 35.0612500, 126.9874600, 'KR', '2016-07-05', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91627, 'Hwaseong-si', 'Hwaseong-si', 'Hwaseong,Hwaseong-si,hwaseong,hwaseongsi,화성,화성시', 37.2068200, 126.8169000, 'KR', '2014-01-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91628, 'Hwacheon', 'Hwacheon', 'Huachon,Hwach''on,Hwach''ŏn,Hwacheon,Hwach’ŏn,Kasen,hwacheon,hwacheongun,화천,화천군', 38.1070500, 127.7063200, 'KR', '2016-10-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91629, 'Hongsung', 'Hongsung', 'CaminodeFloresta,Hongseong,Hongsong,Hongsŏng,Kojo,Kōjō,hongseong,홍성', 36.6009000, 126.6650000, 'KR', '2016-06-15', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91630, 'Hongch’ŏn', 'Hongch''on', 'Hongch''on,Hongch’ŏn,Kosen,Kōsen,hongcheon,hongcheongun,홍천,홍천군', 37.6918000, 127.8857000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91631, 'Hayang', 'Hayang', 'Hayang,Kayo,Kayō', 35.9133300, 128.8200000, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91632, 'Hancheolli', 'Hancheolli', 'Hanch''ol-li,Hanch''on,Hanch''on-ni,Hancheolli,Hanch’on,Hanch’ŏl-li,Hanch’ŏn-ni,hancheon,hancheonli,한천,한천리', 34.9741100, 127.0002800, 'KR', '2016-07-05', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91633, 'Haenam', 'Haenam', 'Haenam,Kainan,haenam,해남', 34.5711100, 126.5988900, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91634, 'Chuncheon', 'Chuncheon', 'Cchuncchon,Ch''unch''on,Ch''unch''ŏn,Chhun-chhen,Chhun-chhon-su,Chhûn-chhôn-sṳ,Chkhunchkhon,Chuncheon,Chүn''chon'',Ch’unch’ŏn,Cunceon,Cuncon,Cunconas,QUN,Shunsen,Shusen,Syunsen,Tsch-hun-tsch-hon,Tsch-hun-tsch-hŏn,chanchywn,chun chuan,chun chuan shi,chuncheon,chuncheonsi,chwnchywn,tshntshwn,Çunçeon,Ĉunĉon,Čchunčchon,Čunčonas,Чхунчхон,Чүньчонь,تشنتشون,چانچئون,چونچیون,春川,春川市,춘천,춘천시', 37.8747200, 127.7341700, 'KR', '2015-03-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91635, 'Cheorwon', 'Cheorwon', 'Ch''orwon,Cheolwan,Cheorwon,Ch’ŏrwŏn,Tetsugen,Tetugen,Tsch-hol-won,Tsch-hŏl-wŏn,cheol-won,철원', 38.2091700, 127.2175000, 'KR', '2014-12-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91636, 'Jeonju', 'Jeonju', 'CHN,Chenju,Chondzhu,Chongju,Chonju,Chunju,Chŏngju,Chŏnju,Condzu,Dzondzu,Džondžu,Jenchu,Jeonju,Tjyen-tjyou,Tschon-dschu,Tschön-dschu,Tsiuentcheou,Tyondyu,Tyondyū,jeonju,jeonjusi,jonju,jwnjw,jywnjw,quan zhou,quan zhou shi,Čondžu,Чонджу,Чоньжү,جئونجو,جونجو,जॉन्जू,全州,全州市,전주,전주시', 35.8219400, 127.1488900, 'KR', '2014-05-29', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91637, 'Cheongsong gun', 'Cheongsong gun', 'Ch''ongsong-gun,Ch''ŏngsong-gun,Cheongsong gun,Seisho,Seisho-gun,Seishō,Seishō-gun,cheongsong,cheongsong-eub,cheongsong-gun,청송,청송군,청송읍', 36.4335100, 129.0570000, 'KR', '2010-07-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91638, 'Cheongpyeong', 'Cheongpyeong', 'Ch''ongp''yong,Ch''ongp''yongch''on,Cheongpyeong,Ch’ŏngp’yŏng,Ch’ŏngp’yŏngch’ŏn,Karohyon,Karohyŏn,Karugae,Karuge,Kuch''ongp''yongnae,Kuch’ŏngp’yŏngnae,Seiheisen,cheongpyeong,청평', 37.7355000, 127.4174000, 'KR', '2014-04-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91639, 'Jeongok', 'Jeongok', 'Chon''gok,Chon''gong-ni,Chŏn’gok,Chŏn’gong-ni,Jeongok,jeongog,전곡', 38.0259600, 127.0702100, 'KR', '2014-12-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91640, 'Cheongju-si', 'Cheongju-si', 'CJJ,Cheongju,Cheongju-si,cheongju,cheongjusi,청주,청주시', 36.6372200, 127.4897200, 'KR', '2014-08-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91641, 'Cheonan', 'Cheonan', 'Cchonan,Ch''onan,Ch''ŏnan,Cheonan,Chkhonan,Chonan'',Ch’ŏnan,Tenan,Thien-on-su,Thiên-ôn-sṳ,Thyen-an,Thyen-ān,cheon-an,cheon-ansi,chywnan,tian an shi,tshwnan,Čchonan,Чонань,Чхонан,تشونان,چئونان,چیونان,天安市,천안,천안시', 36.8065000, 127.1522000, 'KR', '2015-06-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91642, 'Chinju', 'Chinju', 'Chindzhu,Chinju,HIN,Jinju,Shinshu,Shinshū,Sinsyu,Sinsyū,Tschin-dschu,jin zhou,jin zhou shi,jinjusi,Чинджу,晋州,晋州市,진주시', 35.1927800, 128.0847200, 'KR', '2015-06-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91643, 'Chinch''ŏn', 'Chinch''on', 'Chinchon,Chinsen,Jincheon,jincheon,jincheongun,진천,진천군', 36.8566700, 127.4433300, 'KR', '2010-08-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91644, 'Jinan-gun', 'Jinan-gun', 'Jinan-gun,jin-angun,진안군', 35.7916700, 127.4252800, 'KR', '2014-01-06', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91645, 'Jeju City', 'Jeju City', 'CJU,Chedzhu,Cheju,Chu-sung,Chyei Chyu,Czedzu,Czedżu,Jeju,Jeju City,Kota Jeju,Saishu,Saishū,Saisyu,Saisyu Yu,Saisyū,Saisyū Yū,Tsche-dschu,Tse-tsiu,Tsitcheou,Tzetzou,chjw,jeju,jejusi,ji zhou,ji zhou shi,jyjw,Τζέτζου,Чеджу,جيجو,چجو,済州市,濟州,濟州市,제주,제주시', 33.5097200, 126.5219400, 'KR', '2016-02-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91646, 'Changwon', 'Changwon', 'Cangvonas,Cchangwon,Ch''angwon,Ch''angwŏn,Changuon,Changwon,Chanvon,Chkhanvon,Ch’angwŏn,Cshangvon,Sangwon,Shogen,Shōgen,chang yuan,chang yuan shi,chang-wonsi,changwn,changwwn,tshanghwwn,zngwwn,Čangvonas,Čchangwon,Чанвон,Чангуон,Чханвон,צנגוון,تشانغوون,چانگون,چانگوون,چانگ‌وون,昌原,昌原市,창원시', 35.2280600, 128.6811100, 'KR', '2012-02-28', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91647, 'Changsu', 'Changsu', 'Changsu,Changsu-ri,Chosui-ri,Chōsui-ri,jangsu,jangsugun,장수,장수군', 35.6484200, 127.5152300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91648, 'Jangseong', 'Jangseong', 'Changsong,Changsŏng,Chojo,Chongsong,Chōjō,Chŏngsong,Jangseong,jangseong,장성', 35.2977800, 126.7844400, 'KR', '2016-06-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91649, 'Changpyeong', 'Changpyeong', 'Ch''angp''yong,Ch''angp''yong-ni,Changpyeong,Ch’angp’yŏng,Ch’angp’yŏng-ni,Shohei,Shōhei,changpyeong,창평', 35.2390400, 127.0179200, 'KR', '2016-06-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91650, 'Jangan', 'Jangan', 'Changal-li,Changan,Jangan,jang-an,장안', 35.3129600, 129.2424400, 'KR', '2016-03-10', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91651, 'Anyang-si', 'Anyang-si', 'Anyang,Anyang-si,an-yang,an-yangsi,안양,안양시', 37.3925000, 126.9269400, 'KR', '2014-01-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91652, 'Anseong', 'Anseong', 'Anjo,Anjŏ,Anseong,Anson,Ansong,Ansŏng,an cheng shi,anseong,anseongsi,Ансон,安城市,안성,안성시', 37.0108300, 127.2702800, 'KR', '2015-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91653, 'Ansan-si', 'Ansan-si', 'Ansan,Ansan-si,an shan,an shan shi,ansan,ansansi,安山,安山市,안산,안산시', 37.3236100, 126.8219400, 'KR', '2015-06-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91654, 'Andong', 'Andong', 'An''dun,Andang,Andon,Andong,Andongas,Anto,Antō,an dong shi,andong,andongsi,andoni,andwng,xan dng,Андон,Аньдун,آندونگ,انڈونگ,อันดง,ანდონი,安东市,安東市,안동,안동시', 36.5663600, 128.7227500, 'KR', '2016-10-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91655, 'Gaigeturi', 'Gaigeturi', 'Aewol,Aewol-li,Aewŏl,Aewŏl-li,Gaigetsu,Gaigetsu-ri,Gaigeturi', 33.4644400, 126.3183300, 'KR', '2012-01-18', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91656, 'Sinhyeon', 'Sinhyeon', 'Sinhyeon,Sinhyon,Sinhyŏn', 34.8825000, 128.6266700, 'KR', '2012-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91657, 'Yeosu', 'Yeosu', 'Josu,RSU,Yoch''on,Yosu,Yŏch’ŏn,Yŏsu,iosu,li shui shi,yeosusi,ywsw,yywsw,Ёсү,Йосу,یئوسو,یوسو,იოსუ,麗水市,여수시', 34.7627800, 127.6652800, 'KR', '2013-05-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91658, 'Yŏnmu', 'Yonmu', '', 36.1294400, 127.1000000, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91659, 'Tonghae', 'Tonghae', '', 37.5438900, 129.1069400, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91660, 'Cheongha', 'Cheongha', 'Ch''ongha,Cheongha,Ch’ŏngha,cheongha,청하', 36.1979700, 129.3391100, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91661, 'Ocheon', 'Ocheon', 'Och''on,Ocheon,Och’ŏn,ocheon,오천', 35.9704600, 129.4122200, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91662, 'Ilgwang', 'Ilgwang', 'Ilgwang,ilgwang,일광', 35.2640000, 129.2334900, 'KR', '2016-03-10', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91663, 'Pubal', 'Pubal', '', 37.2916700, 127.5077800, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91664, 'Seongnam-si', 'Seongnam-si', 'Seongnam,Seongnam-si,seongnam,seongnamsi,성남,성남시', 37.4386100, 127.1377800, 'KR', '2014-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91665, 'Hanam', 'Hanam', 'Hanam,hanam,하남', 37.5400000, 127.2055600, 'KR', '2012-01-19', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91666, 'Hwado', 'Hwado', '', 37.6525000, 127.3075000, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91667, 'Namyangju', 'Namyangju', 'Nam-yong-chu-su,Namjandzhu,Namujandzhu,Namujanzhү khot,Namyangju,Namyangju-si,Nàm-yòng-chû-sṳ,nam-yangju,nam-yangjusi,namyangjw,nan yang zhou shi,Намъянджу,Намъянжү хот,Намянджу,نامیانگجو,南楊州市,남양주,남양주시', 37.6366700, 127.2141700, 'KR', '2014-04-23', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91668, 'Ungsang', 'Ungsang', '', 35.4061100, 129.1686100, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91669, 'Wabu', 'Wabu', 'Wabu,wabu,와부', 37.5897200, 127.2202800, 'KR', '2015-07-03', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91670, 'Naesŏ', 'Naeso', '', 35.2497200, 128.5200000, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91671, 'Hwawŏn', 'Hwawon', '', 35.8016700, 128.5008300, 'KR', '2006-01-17', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91672, 'Kwangmyŏng', 'Kwangmyong', 'Kwangmyong,Kwangmyŏng', 37.4772200, 126.8663900, 'KR', '2012-01-20', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91673, 'Paju', 'Paju', 'P''aju,Paju,P’aju,paju,파주', 37.8327800, 126.8169400, 'KR', '2013-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91674, 'Sinan', 'Sinan', 'sin-an,sin-angun,신안,신안군', 34.8262000, 126.1086300, 'KR', '2010-08-02', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91675, 'Seogwipo', 'Seogwipo', 'JSP,Seogwipo,Sogvipkho,Согвипхо', 33.2533300, 126.5618100, 'KR', '2015-06-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91676, 'Singwang', 'Singwang', 'Sin''gwang,Singwang,Sin’gwang,singwang,신광', 36.1291100, 129.2636000, 'KR', '2016-09-09', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91677, 'Songgangdong', 'Songgangdong', 'Songgangdong,Sungan,song-gangdong,Сунган,송강동', 36.4340600, 127.3755900, 'KR', '2015-05-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91678, 'Daehap', 'Daehap', 'Daehap,Taehap,daehab,대합', 35.6136500, 128.4716500, 'KR', '2016-02-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91679, 'Changnyeong', 'Changnyeong', 'Ch''angnyong,Ch’angnyŏng,changnyeong,changnyeong-eub,changnyeong-gun,창녕,창녕군,창녕읍', 35.5414500, 128.4950600, 'KR', '2010-07-26', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91680, 'Songhae', 'Songhae', 'Songhae,songhae,송해', 37.7636000, 126.4657700, 'KR', '2013-07-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91681, 'Hajeom', 'Hajeom', 'Hajeom,hajeom,하점', 37.7741900, 126.4122600, 'KR', '2013-07-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91682, 'Yangsa', 'Yangsa', 'Yangsa,yangsa,양사', 37.7987200, 126.4080000, 'KR', '2013-07-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91683, 'Samsan', 'Samsan', 'Samsan,samsan,삼산', 37.7030600, 126.3213600, 'KR', '2013-07-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91684, 'Seonwon', 'Seonwon', 'Seonwon,seon-won,선원', 37.7122300, 126.4843900, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91685, 'Wolgot', 'Wolgot', 'Wolgot,wolgoj,월곶', 37.7164600, 126.5542900, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91686, 'Haseong', 'Haseong', 'Haseong,haseong,하성', 37.7195300, 126.6310700, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91687, 'Tongjin', 'Tongjin', 'Tongjin,tongsin,통신', 37.6919100, 126.5985500, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91688, 'Gyodong', 'Gyodong', 'Gyodong,gyodong,교동', 37.7827200, 126.2811700, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91689, 'Gwangtan', 'Gwangtan', 'Gwangtan,gwangtan,광탄', 37.7805500, 126.8500400, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91690, 'Jangheung', 'Jangheung', 'Jangheung,jangheung,장흥', 37.7172700, 126.9412200, 'KR', '2013-09-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91691, 'Tanhyeon', 'Tanhyeon', 'Tanhyeon,tanhyeon,탄현', 37.8024000, 126.7159800, 'KR', '2013-10-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91692, 'Gwangjeok', 'Gwangjeok', 'Gwangjeok,gwangjeog,광적', 37.8256600, 126.9834900, 'KR', '2014-02-16', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91693, 'Su-dong', 'Su-dong', 'Su-dong,sudong,수동', 37.7035300, 127.3258000, 'KR', '2014-03-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91694, 'Sindong', 'Sindong', 'Sindong,sindong,신동', 37.8173500, 127.7165600, 'KR', '2014-03-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91695, 'Dongnae', 'Dongnae', 'Dongnae,dongnae,동내', 37.8474700, 127.7616400, 'KR', '2014-03-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91696, 'Seoseok', 'Seoseok', 'Seoseok,seoseog,서석', 37.7119000, 128.1871300, 'KR', '2014-03-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91697, 'Jinjeop', 'Jinjeop', 'Jinjeop,jinjeob,진접', 37.7272200, 127.1899200, 'KR', '2014-03-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91698, 'Onam', 'Onam', 'Onam,onam,오남', 37.6983400, 127.2057900, 'KR', '2014-03-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91699, 'Haean', 'Haean', 'Haean,haean,해안', 38.2863400, 128.1377400, 'KR', '2014-11-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91700, 'Toseong', 'Toseong', 'Toseong,toseong,토성', 38.2567900, 128.5596800, 'KR', '2014-11-07', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91701, 'Sinseo', 'Sinseo', 'Sinseo,sinseo,신서', 38.1856100, 127.1081900, 'KR', '2014-12-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91702, 'Gwanin', 'Gwanin', 'Gwanin,gwan-in,관인', 38.1592100, 127.2493500, 'KR', '2014-12-04', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91703, 'Bangsan', 'Bangsan', 'Bangsan,bangsan,방산', 38.2088000, 127.9502800, 'KR', '2015-01-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91704, 'Dongmyeon', 'Dongmyeon', 'Dongmyeon,dongmyeon,동면', 38.2013500, 128.0432700, 'KR', '2015-01-08', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91705, 'Yeonsan', 'Yeonsan', 'Yeonsan,yeonsan,연산', 36.2137600, 127.2000400, 'KR', '2015-11-10', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91706, 'Oepo', 'Oepo', 'Oepo,oepo,외포', 34.9403600, 128.7166500, 'KR', '2016-04-12', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91707, 'Sejong', 'Sejong', 'Sedzong,Sedżong,Sejong,Sejong Special Self-Governing City,Yeongi,se(ː).dʑon,se(ː).dʑoŋ,sejong,shi zong,世宗,세종', 36.5924500, 127.2922300, 'KR', '2017-04-11', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91708, 'Bupyeong', 'Bupyeong', '', 37.5053300, 126.7220200, 'KR', '2017-05-25', 119);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91709, 'Janūb as Surrah', 'Janub as Surrah', 'Janub as Surrah,Janūb as Surrah,South Surra,janub aalsurat,جَنُوب اَلسُّرَّة', 29.2691700, 47.9780600, 'KW', '2015-01-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91710, 'Ḩawallī', 'Hawalli', 'Hawali-nogra,Hawalli,Hawaly,hawaliy,hwly,حولي,حَوَلِّي,Ḩawallī', 29.3327800, 48.0286100, 'KW', '2013-08-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91711, 'Bayān', 'Bayan', 'Bajan,Bayan,Bayān,bayan,byan,Баян,بيان,بَيَان', 29.3032000, 48.0488100, 'KW', '2016-09-13', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91712, 'Az Zawr', 'Az Zawr', 'Az Zaur,Az Zawr,Az Zor,Failakka Village,Zor,aalzawr,اَلزَّوْر', 29.4425000, 48.2747200, 'KW', '2012-01-18', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91713, 'As Sālimīyah', 'As Salimiyah', 'Ad Dumna,Ad Dumnah,As Salimiyah,As Sālimīyah,As-Salimiyah,As-Sālimiyah,Dimnah,Salimiyah,Salmiya,Salmiyah,Salmiyyeh,aalsaalimiat,alsalmyt,السالمية,اَلسَّالِمِيَّة', 29.3338900, 48.0761100, 'KW', '2016-06-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91714, 'Ash Shāmīyah', 'Ash Shamiyah', 'Al Shamiya,Ash Shamiyah,Ash Shāmīyah,Shamiya,Shamiyah,Shamiyeh,Shamiyyeh,Shamīyah,aalshaamiat,اَلشَّامِيَّة', 29.3472200, 47.9616700, 'KW', '2013-03-02', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91715, 'Ar Rumaythīyah', 'Ar Rumaythiyah', 'Ar Rumaythiyah,Ar Rumaythīyah,Rumaithiya,aalrumaythiat,alrmythyt,الرميثية,اَلرُّمَيْثِيَّة', 29.3116700, 48.0741700, 'KW', '2013-07-19', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91716, 'Ar Riqqah', 'Ar Riqqah', 'Al-Riqqah,Ar Riqqah,Reqqa,aalriqat,alrqt,الرقة,اَلرِّقَّة', 29.1458300, 48.0947200, 'KW', '2012-01-18', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91717, 'Al Wafrah', 'Al Wafrah', 'Al Wafrah,aalwafrat,اَلْوَفْرَة', 28.6391700, 47.9305600, 'KW', '2013-05-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91718, 'Al Manqaf', 'Al Manqaf', 'Al Manjaf,Al Manqaf,Al-Mangaf,Manqaf,aalmanqaf,almnqf,المنقف,اَلْمَنْقَف', 29.0961100, 48.1327800, 'KW', '2012-01-18', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91719, 'Al Mahbūlah', 'Al Mahbulah', 'Al Mahbulah,Al Mahbūlah,Al-Mahabulah,Al-Mahabūlah,Mahboola,aalmahbulat,almhbwlt,المهبولة,اَلْمَهْبُولَة', 29.1450000, 48.1302800, 'KW', '2012-12-06', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91720, 'Kuwait City', 'Kuwait City', 'Al Kuwait,Al Kuwayt,Al-Kuwait,Ciudad de Kuwait,Ehl''-Kuvejt,KWI,Koeweit,Kota Kuwait,Koveyit,Koweit,Koweït,Kuvaeyt,Kuvajt,Kuvajto,Kuvajturbo,Kuveitas,Kuväyt,Kuwait,Kuwait City,Kuwait Stad,Kuwait by,Kuwait-Stadt,Kuwait-Urbo,Kuwayt,Kuweit,Kuwejt,Madinat al Kuwayt,Madinat al-Kuwait,Madīnat al Kuwayt,Pole tou Koubeit,aalkuayt,ke wei te shi,khuwet si ti,kuu~eto shi,kuweiteu,kuweiteusiti,kwwyt syty,mdynt alkwyt,Πόλη του Κουβέιτ,Эль-Кувейт,כווית סיטי,اَلْكُوَيْت,مدينة الكويت,คูเวตซิตี,クウェート市,科威特市,쿠웨이트,쿠웨이트시티', 29.3697200, 47.9783300, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91721, 'Al Jahrā’', 'Al Jahra''', 'Al Jahara,Al Jahra,Al Jahra'',Al Jahrah,Al Jahrā’,Al-Jaharah,Iahara,Jahra Village,Jahrah,اَلْجَهْرَاء', 29.3375000, 47.6580600, 'KW', '2013-05-05', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91722, 'Al Funayţīs', 'Al Funaytis', 'Al Fanaitis,Al Funaitis,Al Funaytis,Al Funayţīs,Al-Finaitees,Fanaitis,Fneitees,Fraitsass,Funaitis,Funaitís,Funaytis,Funayţīs,aalfunaytis,alfnytys,الفنيطيس,اَلْفُنَيْطِيس', 29.2252800, 48.1016700, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91723, 'Al Faḩāḩīl', 'Al Fahahil', 'Al Fahahil,Al Faḩāḩīl,Al Fuhaihil,Al Fuhayhil,Al Fuħaiħil,Al Fuḩayḩīl,Al Ifhaihil,Al-Fahaheel,Al-Fahahil,Fahaheel,Fahahil,Fahaihil,Fahaihīl,Fahayhil,Fahāhīl,Faḩayḩīl,Fuhayhil,Fuḩayḩīl,aalfuhayhil,alfhahyl,الفحاحيل,اَلْفُحَيْحِيل', 29.0825000, 48.1302800, 'KW', '2012-10-19', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91724, 'Al Finţās', 'Al Fintas', 'Al Fantas,Al Fintas,Al Fintass,Al Fintās,Al Finţās,Fantas,Fantass,Fanţās,Finatus,Fintas,Fintass,Finţās,Funtas,Funtás,aalfintas,alfntas,الفنطاس,اَلْفِنْطَاس', 29.1738900, 48.1211100, 'KW', '2016-06-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91725, 'Al Farwānīyah', 'Al Farwaniyah', 'Al Farwania,Al Farwaniyah,Al Farwānīyah,Al-Farawaniyah,Al-Farwaniyyah,Farwaniah,Farwaniyyeh,aalfarwaniat,اَلْفَرْوَانِيَّة', 29.2775000, 47.9586100, 'KW', '2013-05-05', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91726, 'Al Aḩmadī', 'Al Ahmadi', 'Ahmad,Ahmadi,Ahmedi,Al Ahmadi,Al Aħmadi,Al Aḩmadī,aalaahmadi,alahmdy,الاحمدي,اَلأَحْمَدِي', 29.0769400, 48.0838900, 'KW', '2014-01-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91727, 'Ad Dasmah', 'Ad Dasmah', 'Ad Dasma'',Ad Dasmah,Ad Dasmā’,Dasma,Dasmah,aaldasmat,اَلدَّسْمَة', 29.3650000, 48.0013900, 'KW', '2015-01-04', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91728, 'Salwá', 'Salwa', 'Sal''va,Salwa,Salwá,salway,slwy,Сальва,سلوى,سَلْوَى', 29.2958300, 48.0786100, 'KW', '2012-10-19', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91729, 'Ar Rābiyah', 'Ar Rabiyah', 'Ar Rabiyah,Ar Rābiyah,aalraabiat,اَلرَّابِيَة', 29.2950000, 47.9330600, 'KW', '2012-10-19', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91730, 'Şabāḩ as Sālim', 'Sabah as Salim', 'Sabah as Salim,Sabah as Salim as Sabbah,sabah aalsaalim,Şabāḩ as Salim aş Sabbāḩ,Şabāḩ as Sālim,صَبَاح اَلسَّالِم', 29.2572200, 48.0572200, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91731, 'Mubārak al Kabīr', 'Mubarak al Kabir', 'Mubarak Al-Kabeer', 29.1897900, 48.0871600, 'KW', '2013-07-03', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91732, 'Al-Masayel', 'Al-Masayel', '', 29.2393000, 48.0886200, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91733, 'Abu Fatira', 'Abu Fatira', '', 29.1974600, 48.1027800, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91734, 'Abu Al Hasaniya', 'Abu Al Hasaniya', '', 29.1907600, 48.1135500, 'KW', '2017-06-22', 120);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91441, 'Trinity', 'Trinity', '', 17.3003700, -62.7758400, 'KN', '2017-07-05', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91442, 'Sandy Point Town', 'Sandy Point Town', 'Sandy Point,Sandy Point Town,Sandy Point Village', 17.3590800, -62.8485800, 'KN', '2014-04-15', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91443, 'Saint Paul’s', 'Saint Paul''s', 'Saint Paul''s,Saint Paul''s Village,Saint Paul’s,Saint Paul’s Village', 17.4060500, -62.8356200, 'KN', '2017-07-04', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91444, 'Nicola Town', 'Nicola Town', 'Nichola Town', 17.3795600, -62.7531800, 'KN', '2017-07-02', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91445, 'Newcastle', 'Newcastle', 'Newcastle,Newcastle Village', 17.2000000, -62.5833300, 'KN', '2014-08-18', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91446, 'Monkey Hill', 'Monkey Hill', 'Monkey Hill,Monkey Hill Village', 17.3232700, -62.7291400, 'KN', '2017-07-03', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91447, 'Middle Island', 'Middle Island', 'Middle Island,Middle Island Village', 17.3259000, -62.8105500, 'KN', '2016-11-02', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91448, 'Market Shop', 'Market Shop', 'Market Shop', 17.1321800, -62.5726700, 'KN', '2017-07-02', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91449, 'Fig Tree', 'Fig Tree', 'Fig Tree,Fig Tree Village,Figtree', 17.1262300, -62.6026500, 'KN', '2017-07-01', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91450, 'Dieppe Bay Town', 'Dieppe Bay Town', 'Dieppe Bay', 17.4147300, -62.8139000, 'KN', '2014-04-15', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91451, 'Cotton Ground', 'Cotton Ground', 'Cotton Ground,Cotton Ground Village', 17.1666700, -62.6166700, 'KN', '2012-01-14', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91452, 'Charlestown', 'Charlestown', 'Charlestown,NEV', 17.1333300, -62.6166700, 'KN', '2016-05-15', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91453, 'Cayon', 'Cayon', 'Cayon,Cayon Village,Cayton', 17.3500000, -62.7333300, 'KN', '2012-01-14', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91454, 'Basseterre', 'Basseterre', 'Basse Terre Town,Basseterre,Baste,Baster,Bastera,Basteras,Bastero,Bastè,Gorad Bastehr,Mpaster,SKB,ba si te er,basetera,baseteru,baseuteleu,bastyr,basytyr,pacettere,Μπαστέρ,Бастер,Горад Бастэр,באסטר,باستير,باسه‌تر,باسیتیر,बासेतेर,பாசெட்டெரே,บาสแตร์,པ་སི་ཐེར།,ბასტერი,ባስቴር,バセテール,巴斯特尔,바스테르', 17.2948400, -62.7261000, 'KN', '2010-12-07', 187);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91817, 'Turgen', 'Turgen', 'Turgen,Turgen'',Turgen’,Türgen,Турген,Түрген', 43.4005600, 77.5933300, 'KZ', '2015-06-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91818, 'Timiryazevo', 'Timiryazevo', 'Celinnyj,Timirjazevo,Timiryazevo,Tselinnoy,Tselinnyy,Tīmīryazevo,Тимирязево,Целинный', 53.7494700, 66.4885200, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91819, 'Troyebratskiy', 'Troyebratskiy', 'Troebratskij,Troebratskiy,Troebratskīy,Troyebratnoye,Troyebratskiy,Троебратский', 54.4430600, 66.0798200, 'KZ', '2015-11-08', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91820, 'Torghay', 'Torghay', 'Torgay,Torghay,Turgai,Turgaj,Turgay,Тургай', 49.6338900, 63.4980600, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91821, 'Tokarevka', 'Tokarevka', 'Tokarevka,Tokaryevko,Токаревка', 50.1157300, 73.1603400, 'KZ', '2017-02-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91822, 'Tobol', 'Tobol', 'Tobol,Tobyl,Тобол,Тобыл', 52.6936600, 62.5914000, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91823, 'Terenozek', 'Terenozek', 'Teren''-Uzyak,Terengozek,Terengözek,Terenozek,Terenuzek,Teren’-Uzyak', 45.0505300, 64.9839500, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91824, 'Temirtau', 'Temirtau', 'Samarand,Samarka,Samarkand,Samarkandskoye,Temirtaou,Temirtau,Temirtaw,Temirtaū,Temyrtau,temileutau,tie mi er tao,tmyrtaw,Темиртау,Теміртау,تميرتاو,تمیرتاؤ,تمیرتاو,تێمیرتاو,鐵米爾套,테미르타우', 50.0549400, 72.9646400, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91825, 'Temirlanovka', 'Temirlanovka', 'Tamerlanovka,Temirlan,Temirlanovka,Темирлановка,Темірлан', 42.5999800, 69.2583600, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91826, 'Tekeli', 'Tekeli', 'Tekeli,Tekely,Текели', 44.8332200, 78.8308900, 'KZ', '2013-07-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91827, 'Tasböget', 'Tasboget', 'Tasboget,Tasbuget,Tasböget', 44.7738400, 65.5522700, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91828, 'Taranovskoye', 'Taranovskoye', 'Bolchaia Viktorovka,Bolshaya Viktorovka,Taranovskoe,Taranovskoye,Viktorovka,Викторовка,Тарановское', 52.8355400, 62.5207800, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91829, 'Talshik', 'Talshik', 'Tal''chik,Tal''shchik,Talshik,Talshyq,Tal’chik,Tal’shchik,Талшик,Талшық', 53.6373600, 71.8740400, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91830, 'Talghar', 'Talghar', 'Talgar,Talghar', 43.3034800, 77.2408500, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91831, 'Taldykorgan', 'Taldykorgan', 'Gavrilovka,Gavrilovskoye,Gorad Taldykargan,TDK,Taldi Kurgan,Taldikorgan,Taldiqo''rg''an,Taldiqorgan,Taldiqoʻrgʻan,Taldokorgan,Taldukorgan,Taldy-Korgon,Taldy-Kurgan,Taldykorgan,Taldykorganas,Taldykourgan,Taldyqorghan,Taldîkorgan,Taldõkorgan,Taldıqorğan,Talto-Kurgan,Taltö-Kurgan,Tałdykorgan,ta er di ku er gan,taldikoleugan,taldykwrghan,taldyqwrghan,taldyqwrghan  qzaqstan,tarudikorugan,tldykwrghan,Горад Талдыкарган,Талдикорган,Талдъкорган,Талды-Коргон,Талдыкорган,Талдықорған,Տալդի Կուրգան,تالدقۆرغان,تالديكورغان,تالدیقورغان,تالدیقورغان، قزاقستان,تلدیکورغان,თალდიყორღანი,タルディコルガン,塔爾迪庫爾干,탈디코르간', 45.0155600, 78.3738900, 'KZ', '2017-01-22', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91832, 'Taldyqorghan', 'Taldyqorghan', 'Taldy - Kurgan,Taldy-Kurgan,Taldy-Kurgan Stantsiya,Taldykurgan,Taldyqorghan,Талды - Курган', 45.0000000, 77.9166700, 'KZ', '2013-10-25', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91833, 'Suykbulak', 'Suykbulak', 'Suykbulak,Suyqbulaq,Sūyqbulaq,Суыкбулак,Суықбұлақ', 49.7083700, 81.0485400, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91834, 'Stepnyak', 'Stepnyak', 'Spepnjak,Spepnyak,Stepniak,Stepnjak,Stepnyak,Спепняк,Степняк', 52.8348900, 70.7886100, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91835, 'Smirnovo', 'Smirnovo', 'Smiirnovo,Smirnovo,Smirnovskiy,Smīirnovo,Smīrnovo,Смирново', 54.5148000, 69.4273200, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91836, 'Slavyanka', 'Slavyanka', 'Mirzakent,Myrzakent,Slavjanka,Slavyanka,Slavyanski,Slavyanskiy,Slavyanskoye,Мырзакент,Славянка', 40.6633800, 68.5451000, 'KZ', '2016-09-08', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91837, 'Shymkent', 'Shymkent', 'CIT,Chimkent,Chymkent,Cimkent,Gorad Shymkent,Schymkent,Shimkent,Shymkent,Shımkent,Simkent,Simkenta,Simkento,Sjimkent,Sjymkent,Somkent,Symkent,Symkentas,Szymkent,Tsjimkent,Ximkent,Xymkent,chymknd,qi mu ken te,shimkenti,shimukento,shmkynt,shymknt,simakenta,swimkenteu,symqnt,Çimkent,Çimkənd,Ŝimkento,Şımkent,Šimkent,Šimkenta,Šymkent,Šymkentas,Šõmkent,Șîmkent,Σιμκέντ,Горад Шымкент,Чимкент,Чымкент,Шимкент,Шымкент,שימקנט,شمکینت,شمکێنت,شيمكنت,شیمکنت,چیمکند,शिमकेंत,შიმქენთი,シムケント,奇姆肯特,쉼켄트', 42.3000000, 69.6000000, 'KZ', '2017-03-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91838, 'Chu', 'Chu', 'Chu,Shu,Shū,Чу,Шу', 43.6033400, 73.7591900, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91839, 'Shortandy', 'Shortandy', 'Shartandy,Shortandy', 51.6994600, 70.9945700, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91840, 'Shemonaīkha', 'Shemonaikha', 'Shemonaikha,Shemonaīkha,Шемонаиха', 50.6281100, 81.9121300, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91841, 'Shchuchinsk', 'Shchuchinsk', 'Shchuch''ye,Shchuchinsk,Shchuch’ye,Shchūchīnsk,Shhuchinsk,Щучинск', 52.9359200, 70.1889500, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91842, 'Shar', 'Shar', 'Charsk,Charskiy,Shar,Чарск,Шар', 49.5872000, 81.0488300, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91843, 'Shantobe', 'Shantobe', 'Shangtobe,Shangtöbe,Shantobe,Shantyube,Шантобе,Шаңтөбе', 52.4537600, 68.1747500, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91844, 'Shakhan', 'Shakhan', 'Shakan,Shakanskiye Vyselki,Shakhan,Shaqan,Шахан,Шақан', 49.8195800, 72.6540700, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91845, 'Sergeyevka', 'Sergeyevka', 'Sergeevka,Sergeyevka,Сергеевка', 53.8813900, 67.4088200, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91846, 'Semey', 'Semey', 'Alash-kala,PLX,Semei,Semej,Semeja,Semejus,Semey,Semeï,Semipalatinsk,Semipalatynsk,sai mi yi,semei,smy,smyy,symay,symy,Σεμέι,Семей,Семеј,Семипалатинск,סמיי,سمی,سيماي,سیمی,سێمێی,セメイ,塞米伊,세메이', 50.4267500, 80.2666900, 'KZ', '2017-04-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91847, 'Sayaq', 'Sayaq', 'Sayak,Sayaq', 47.0000000, 77.2666700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91848, 'Sastobe', 'Sastobe', 'Sas-Tyube,Sastobe,Sastyvbe,Sastöbe,Састобе,Састөбе', 42.5533000, 69.9983500, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91849, 'Saryshaghan', 'Saryshaghan', 'Saryshagan,Saryshaghan', 46.1191700, 73.6191700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91850, 'Saryozek', 'Saryozek', 'Saro-Ozak,Sary-Uzek,Sary-Uzekskiy,Saryozek,Saryözek,Сарыозек,Сарыөзек', 44.3617800, 77.9727900, 'KZ', '2016-02-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91851, 'Sarykamys', 'Sarykamys', 'Bidaik,Sarykamys,Sarykamysh', 47.7833300, 78.7166700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91852, 'Saryaghash', 'Saryaghash', 'Saryagach,Saryagash,Saryaghash,Ssary-Agatsch,Сарыагач,Сарыагаш,Сарыағаш', 41.4604200, 69.1679100, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91853, 'Sarkand', 'Sarkand', 'Sarkand,Sarkanskaya,Sarqan,Sarqant,Сарканд', 45.4112600, 79.9154500, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91854, 'Soran', 'Soran', 'Saran'',Saran’,Soran,Sorang,Сарань,Соран', 49.7908000, 72.8374400, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91855, 'Sekseūil', 'Sekseuil', 'Saksaul''skij,Saksaul''skiy,Saksaul''skoye,Saksaulskaya,Saksauly,Saksaul’skiy,Saksaul’skoye,Sekseuil,Sekseūil,Саксаульский', 47.0900000, 61.1519400, 'KZ', '2014-11-21', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91856, 'Rudnyy', 'Rudnyy', 'Rudnyj,Rudnyy,Rūdnyy,Рудный', 52.9729000, 63.1167700, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91857, 'Kyzylorda', 'Kyzylorda', 'Ak-Mechet,Ak-Mechet'',Fort Perovskij,Fort Perovsky,Gorad Kyzylarda,KZO,Khizilorda,Khizilordà,Kizilorda,Kizilornta,Kozolorda,Kuzulorda,Kyzylorda,Kyzyłorda,Kzyl-Orda,Kîzîlorda,Kõzõlorda,Kızılorda,Kˌyzylorda,Perovsk,Qizilo''rda,Qizilorda,Qiziloʻrda,Qysylorda,Qyzylorda,Qızılorda,ke zi lei ao er da,khuy si lxx r da,kijilloleuda,kijilorada,kuzuroruda,kyzylwrda,qyzylwrda,qzl awrda,Κιζιλορντά,Ак-Мечеть,Горад Кызыларда,Кзыл-Орда,Кизилорда,Къзълорда,Кызылорда,Перовск,Форт Перовский,Қызылорда,Կզըլ-Օրդա,قزل اوردا,قیزیلوردا,قیزیل‌اوردا,كيزيلوردا,ਕਿਜਿਲੋਰਡਾ,คืยซิลออร์ดา,ყიზილორდა,クズロルダ,克孜勒奧爾達,키질로르다', 44.8527800, 65.5091700, 'KZ', '2014-08-20', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91858, 'Qusmuryn', 'Qusmuryn', 'Kushmurun,Qusmuryn,Кушмурун', 52.4510700, 64.6197700, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91859, 'Kostanay', 'Kostanay', 'KSN,Kostanai,Kostanaj,Kostanajus,Kostanay,Kostanaï,Kostanái,Kustanai,Kustanaisk,Kustanaj,Kustanay,Nikolayevsk,Qo''stanay,Qostanai,Qostanaj,Qostanay,Qoʻstanay,koseutanai,kosutanai,ku s ta ni,ku si ta nai,kwstnay,qwstanay,qwstanay  qzaqstan,qwstanayy,Κοστανάι,Костанай,Кустанай,Кустанај,Қостанай,قوستانائی,قوستانای,قوستانای، قزاقستان,قۆستانای,كوستناي,กุสตาไน,კოსტანაი,コスタナイ,庫斯塔奈,코스타나이', 53.2143500, 63.6246300, 'KZ', '2016-10-23', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91860, 'Qashar', 'Qashar', 'Kachar,Qashar,Качар,Қашар', 53.3679900, 62.8683900, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91861, 'Qarqaraly', 'Qarqaraly', 'Karkaralinsk,Qarqaraly,Каркаралинск,Қарқаралы', 49.4128700, 75.4728600, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91862, 'Qarazhal', 'Qarazhal', 'Kara-Dzhal,Karazhal,Qarazhal,Каражал,Қаражал', 48.0062700, 70.7960700, 'KZ', '2017-02-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91863, 'Qaraūyl', 'Qarauyl', 'Abay,Karaaul,Karaul,Qarauyl,Qaraūyl,Караул', 48.9450900, 79.2550200, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91864, 'Karatau', 'Karatau', 'Chulak-Tau,Karatau,Qaratau,Qarataū,Каратау,Қаратау', 43.1786900, 70.4676800, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91865, 'Kapshagay', 'Kapshagay', 'Ili,Iliisk,Ilijek,Iliysk,Iliyskoye,Kapchagai,Kapchagaj,Kapchagay,Kapshagaj,Kˌapshagaj,Капчагай,Капшагай,Қапшағай', 43.8668100, 77.0630400, 'KZ', '2013-11-11', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91866, 'Tūghyl', 'Tughyl', 'Priozernyy,Priozërnyy,Tarbagatay,Tughyl,Tugyl,Tūghyl', 47.7252100, 84.2062900, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91867, 'Petropavl', 'Petropavl', 'Kizilyar,Kızılyar,PPK,Petropavel,Petropavl,Petropavla,Petropavlas,Petropavlovs''k,Petropavlovsk,Petropawl,Petropawlowsk,Petropawł,Pietropawlowsk,Pietropawłowsk,bi de luo ba fu er,btrwbafl,peteulopabeul,petoropaburu,ptrwpawl  qzaqstan,pytrwpawl,Πετροπάβλ,Петропавел,Петропавл,Петропавловск,Петропавловськ,بتروبافل,پتروپاول، قزاقستان,پیتروپاول,پێترۆپاڤل,ペトロパブル,彼得罗巴甫尔,페트로파블', 54.8666700, 69.1500000, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91868, 'Pervorosiyskiy', 'Pervorosiyskiy', 'Pervorosiyskiy,Pervorossijskoe,Pervorossiyskoye,Zubovka,Zubovskiy,Первороссийское', 49.7165000, 83.8492000, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91869, 'Pervomayka', 'Pervomayka', 'Imeni Pervaya Maya,Kolkhoz Imeni Pervaya Maya,Pervomajka,Pervomajskij,Pervomajskoe,Pervomayka,Pervomayskiy,Pervomayskīy,Первомайка,Первомайский,Первомайское', 43.3736100, 76.9400000, 'KZ', '2017-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91870, 'Pavlodar', 'Pavlodar', 'Gorad Pauladar,Kereku,Kerekū,PWQ,Pavlodar,Pavlodara,Pavlodaras,Pavlontar,Pawlodar,Pawłodar,ba fu luo da er,baflwdar,pabeullodaleu,paf lod ar,pavalodara,pavurodaru,pawlwdar,pawlwdar  qzaqstan,pawlwdr,pblwdr,Παβλοντάρ,Горад Паўладар,Павлодар,פבלודר,بافلودار,پاؤلودار,پاولودار، قزاقستان,پاولودر,پاڤلۆدار,ਪਾਵਲੋਦਰ,ปัฟโลดาร์,პავლოდარი,パヴロダル,巴甫洛達爾,파블로다르', 52.2833300, 76.9666700, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91871, 'Zharkent', 'Zharkent', 'Djarkent,Dzharkent,Jarkent,Panfilov,Panfīlov,Scharkent,Zharkent,Жаркент,Панфилов', 44.1666000, 80.0065500, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91872, 'Oytal', 'Oytal', 'Ojtal,Oytal,Ойтал', 42.9057300, 73.2697200, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91873, 'Ust-Kamenogorsk', 'Ust-Kamenogorsk', 'OEskemen,Oskemen,UKK,Ust''-Kamenogorsk,Ust-Kamenogorsk,Ust-Kamienogorsk,oeseukemen,Öskemen,Усть-Каменогорск,Өskemen,Өскемен,ウスチ・カメノゴルスク,외스케멘', 49.9714300, 82.6058600, 'KZ', '2014-04-16', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91874, 'Osakarovka', 'Osakarovka', 'Osakarovka,Oskarovka,Осакаровка', 50.5621900, 72.5708900, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91875, 'Ordzhonikidze', 'Ordzhonikidze', 'Denisovka,Denisovski,Denīsovka,Ordzhonikidze,Ordzhonīkīdze,Денисовка,Орджоникидзе', 52.4477200, 61.7494200, 'KZ', '2017-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91876, 'Ognevka', 'Ognevka', 'Ognevka,Огневка', 49.6835100, 83.0167400, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91877, 'Zhabagly', 'Zhabagly', 'Novonikolayevka,Zhabagly,Жабаглы', 42.4378100, 70.4784100, 'KZ', '2012-05-02', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91878, 'Novodolinskiy', 'Novodolinskiy', 'Novodolinskij,Novodolinskiy,Novodolīnskīy,Новодолинский', 49.7065000, 72.7080700, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91879, 'Zhanga Buqtyrma', 'Zhanga Buqtyrma', 'Novaja Bukhtarma,Novaya Bukhtarma,Zhanga Buqtyrma,Новая Бухтарма', 49.6295000, 83.5247500, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91880, 'Narynkol', 'Narynkol', 'Naron Kol,Narynkol,Narynqol,Narön Kol,Нарынкол,Нарынқол', 42.7263600, 80.1749500, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91881, 'Mynaral', 'Mynaral', 'Mok-Aral Fishery,Mynaral,Mök-Aral Fishery,Rybalka Myk-Aral,Rybnyy Promysel Myk-Aral', 45.4161100, 73.6844400, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91882, 'Moyynty', 'Moyynty', 'Mointy,Moyynty', 47.2211100, 73.3669400, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91883, 'Kurchatov', 'Kurchatov', 'Konechnaya,Kurchatov,Kurchatov-21,Kūrchatov,Maldar,Moldar,Moldary,Semipalatinsk-21,Курчатов', 50.7561700, 78.5418800, 'KZ', '2017-02-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91884, 'Mikhaylovka', 'Mikhaylovka', 'Mikhajlovka,Mikhaylovka,Sarykamar,Sarykemer,Михайловка,Сарыкемер', 43.0000000, 71.5000000, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91885, 'Merke', 'Merke', 'Merke,Мерке', 42.8697600, 73.1846300, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91886, 'Mayqayyng', 'Mayqayyng', 'Majkajn,Maykain,Maykainskiy,Maykayn,Mayqayyng,Майкайн,Майқайың', 51.4598100, 75.8023200, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91887, 'Matay', 'Matay', 'Matay,Motay', 45.8950000, 78.7180600, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91888, 'Makinsk', 'Makinsk', 'Makinsk,Makīnsk,Макинск', 52.6329000, 70.4191100, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91889, 'Lugovoye', 'Lugovoye', 'Kulan,Lugovaya,Lugovoe,Lugovoy,Lugovoye,Lūgovoy,Qulan,Луговое,Құлан', 42.9101000, 72.7206600, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91890, 'Lugovoy', 'Lugovoy', 'Lugovka,Lugovoe,Lugovoj,Lugovoy,Lugovoye,Lugowaja,Lūgovoe,Lūgovoy,Луговой', 42.9419700, 72.7609800, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91891, 'Lisakovsk', 'Lisakovsk', 'Lisakovka,Lisakovsk,Līsakovsk,Лисаковка', 52.5470700, 62.4998700, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91892, 'Lepsy', 'Lepsy', 'Lepsi,Lepsy', 46.2350000, 78.9455600, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91893, 'Leninskoye', 'Leninskoye', 'Kazyghurt,Kazygurt,Kazykurt,Lenin,Leninskoe,Leninskoye,Lenīn,Qazyqurt,Ленинское,Қазықұрт', 41.7564000, 69.3839000, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91894, 'Leninskiy', 'Leninskiy', 'Aul Sed''moy,Aul Sed’moy,Bayer,Leninskij,Leninskiy,Lenīnskīy,Sed''moy Aul,Sed’moy Aul,Ленинский', 52.2534600, 76.7821100, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91895, 'Baikonur', 'Baikonur', 'BXY,Baikonur,Bajkonur,Bajkˌoңyr,Baykonur,Bayqonir,Bayqoñır,Leninsk,Leninskiy,Tyuratam,Zarya,Байконур,Байқоңыр,Ленинск', 45.6166700, 63.3166700, 'KZ', '2016-10-01', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91896, 'Ridder', 'Ridder', 'Leninogor,Leninogorsk,Lenīnogor,Lenīnogorsk,Ridder,Ridderskiy,Rideras,Rïdder,li de,rydr,rydr  qazqstan,rydr  qzaqstan,Лениногорск,Риддер,Ріддер,ريدر,ریدر، قازقستان,ریدر، قزاقستان,ڕیددێر,里德', 50.3441300, 83.5128700, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91897, 'Lenger', 'Lenger', 'Kopi-Lenger,Lenger,Lenger-Ugol'',Lenger-Ugol’,Lengeras,Lengerskaya,Lengerskij,Lengerskiy,Lengir,lnjr,Ленгер,Ленгір,لنجر', 42.1815200, 69.8858200, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91898, 'Kzyltu', 'Kzyltu', 'KZYLTU,Kishkenekol,Kishkenekol'',Kishkenekol’,Kishkeneköl,Kyzl Tau,Kzyltu,Kzyltuu,Qyzyltu,Qyzyltū,КЗЫЛТУ,Кзылту,Кішкенекөл', 53.6358900, 72.3407900, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91899, 'Kyzylzhar', 'Kyzylzhar', 'Kyzylzhar,Kyzylzhay,Кызылжар', 49.9819700, 72.6076100, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91900, 'Kushoky', 'Kushoky', 'Kushoky,Qushoqy,Qūshoqy,Кушокы,Қушоқы', 50.2309100, 73.4014600, 'KZ', '2017-02-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91901, 'Kurchum', 'Kurchum', 'Kumashenkino,Kumashkino,Kurchum,Kurshim,Kürshim,Курчум', 48.5660300, 83.6614600, 'KZ', '2012-04-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91902, 'Egindiköl', 'Egindikol', 'Egindikol,Egindiköl,Krasnoznamenka,Krasnoznamenskiy,Krasnoznamenskoe,Krasnoznamenskoye,Krasoznamenskoye,Shunkyrkol'',Shunkyrkol’', 51.0541200, 69.4792800, 'KZ', '2013-04-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91903, 'Krasnogorskiy', 'Krasnogorskiy', 'Krasnogorskij,Krasnogorskiy,Krasnogorskīy,Красногорский', 52.2456000, 66.5208100, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91904, 'Taiynsha', 'Taiynsha', 'Krasnoarmejsk,Krasnoarmeysk,Taincha,Taiynsha,Tayncha,Красноармейск', 53.8479600, 69.7677300, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91905, 'Kokshetau', 'Kokshetau', 'KOV,Keksetau,Kekšetau,Ko''kshetau,Kochetayev,Koekschetau,Koeksetaw,Koekshetau,Koeksjetau,Kokcetau,Kokchetaou,Kokchetar,Kokchetau,Kokchetav,Kokczetaw,Koksetau,Kokshetau,Koksjetau,Kokxetau,Kokčetau,Kokšetau,Kokșetau,Koshetau,Koʻkshetau,Kökschetau,Kökshetaū,Köksjetau,Kökşetaw,Köshetaū,ke ke she tao,kogsyetau,kokshetau,kokushetau,kwkshh‌taw,kwkshytaw,kwkshytw,Кокчетав,Кокшетау,Көкчө-Тоо,Көкшетау,Կոկչետավ,كوكشيتو,کوکشه‌تاو,کوکشیتاؤ,کوێکشێتاو,ქოქშეთაუ,コクシェタウ,科克舍套,콕셰타우', 53.2833300, 69.4000000, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91906, 'Komsomolets', 'Komsomolets', 'Komsomolec,Komsomolets,Kˌarabalykˌ,Qarabalyq,Комсомолец,Қарабалық', 53.7501900, 62.0584000, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91907, 'Kokterek', 'Kokterek', 'Imeni Michurina,Kokterek,Коктерек', 42.4944200, 70.2547800, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91908, 'Koktal', 'Koktal', '', 49.6500000, 73.5166700, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91909, 'Kokpekty', 'Kokpekty', '', 48.7500000, 82.4000000, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91910, 'Kīevka', 'Kievka', 'Kievka,Kiewskaja,Kiyevka,Kiyevskoye,Kīevka', 50.2621200, 71.5483900, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91911, 'Balpyk Bī', 'Balpyk Bi', 'Balpyk Bi,Balpyk Bī,Kirovskiy,Kīrovskīy', 44.9022500, 78.2315700, 'KZ', '2013-07-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91912, 'Asyqata', 'Asyqata', 'Asykata,Asyqata,Kirov,Kirovskij,Kirovskiy,Kirovskoye,Kīrovskīy,Асықата,Кировский', 40.8946000, 68.3643000, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91913, 'Khantaū', 'Khantau', '', 44.2274400, 73.7955500, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91914, 'Kentau', 'Kentau', 'Kentaou,Kentau,Kentaw,Kentaū,ken tao,kentau,kntaw,Кентау,كنتاو,کنتاؤ,کن‌تاو,کێنتاو,ქენთაუ,肯套', 43.5167200, 68.5046300, 'KZ', '2016-02-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91915, 'Kegen', 'Kegen', 'Kegen,Кеген', 43.0214300, 79.2205500, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91916, 'Qazaly', 'Qazaly', 'Kasalinsk,Kazalinsk,Qazaly', 45.7627800, 62.1075000, 'KZ', '2014-11-24', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91917, 'Karasu', 'Karasu', 'Karaman,Karasu,Karasul'',Karasul’,Qarasu,Qarasū,Караман,Карасу,Қарасу', 52.6599500, 65.4842100, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91918, 'Karabas', 'Karabas', '', 46.5333300, 76.2000000, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91919, 'Kantagi', 'Kantagi', 'Kantagi,Khantaghy,Khantagy,Kontagi,Tastak,Кантаги,Хантағы', 43.5278600, 68.5828700, 'KZ', '2016-02-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91920, 'Kalkaman', 'Kalkaman', 'Kalkamak,Kalkaman,Kol''-Koman,Kol’-Koman,Qalqaman,Калкаман,Қалқаман', 51.9534900, 76.0272300, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91921, 'Qashyr', 'Qashyr', 'Kachirski,Kachirskiy,Kachiry,Kachīry,Kashir,Qashyr,Качиры,Қашыр', 53.0664900, 76.1048900, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91922, 'Esik', 'Esik', 'Esik,Issok,Issyk,Issök,Yesik,Есик,Иссык', 43.3552000, 77.4524500, 'KZ', '2010-10-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91923, 'Irtyshsk', 'Irtyshsk', 'Ertis,Irtysch,Irtysh,Irtyshsk,Irtyshskoye,Ертіс,Иртышск', 53.3336500, 75.4577500, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91924, 'Atakent', 'Atakent', 'Atakent,Il''ich,Ilyich,Il’ich,Īl’īch,Атакент,Ильич', 40.8478200, 68.5064300, 'KZ', '2015-12-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91925, 'Granitogorsk', 'Granitogorsk', 'Granitogorsk,Granītogorsk,Гранитогорск', 42.7440000, 73.4684800, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91926, 'Glubokoye', 'Glubokoye', 'Glubokoe,Glubokoye,Glūbokoe,Глубокое', 50.1388700, 82.3111400, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91927, 'Georgiyevka', 'Georgiyevka', 'Georgievka,Georgiyevka,Georgīevka,Qorday,Георгиевка,Қордай', 43.0388200, 74.7128700, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91928, 'Georgīevka', 'Georgievka', 'Georgievka,Georgievskaya,Georgiyevka,Georgīevka,Георгиевка', 49.3267100, 81.5737300, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91929, 'Moyynkum', 'Moyynkum', 'Furmanovka,Fūrmanovka,Moyynkum,Moyynqum', 44.2846100, 72.9392000, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91930, 'Fyodorovka', 'Fyodorovka', 'Fedorovka,Fedorovskiy,Fjodorovka,Fyodorovka,Fëdorovka,Фёдоровка', 53.6380900, 62.6965300, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91931, 'Esil', 'Esil', 'Esil,Yesil'',Yesil’', 51.9549500, 66.4084100, 'KZ', '2013-12-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91932, 'Aksu', 'Aksu', 'Aksu,Aqsu,Aqsū,Ermak,Yermak,Аксу,Ақсу,Ермак', 52.0402300, 76.9274800, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91933, 'Yermentau', 'Yermentau', 'Erejmentau,Ereymentau,Ereymentaū,Ermentau,Ermentaū,Yereymentau,Yermentau,Ерейментау,Ерментау', 51.6236400, 73.1026500, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91934, 'Otegen Batyra', 'Otegen Batyra', 'Ehnergeticheskij,Energeticheskiy,Energetīcheskīy,Otegen Batyra,Отеген Батыра,Энергетический', 43.4194900, 77.0202000, 'KZ', '2015-06-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91935, 'Ekibastuz', 'Ekibastuz', 'EKB,Ehkibastuz,Ekibastouz,Ekibastus,Ekibastuz,Ekibastuza,Ekibastuzas,Ekibastuzugol'',Ekibastuzugol’,Ekibastūz,Energograd,Gorad Ehkibastuz,Jekibastuz,Jekybastuz,ai ji ba si tu zi,akybastwz,akybastwz  qzaqstan,ekibaseutujeu,ekibasutosu,xe khi bas tus,Горад Экібастуз,Екибастуз,Екібастуз,Екібастұз,Экибастуз,ئێکیباستوز,اکیباستوز,اکیباستوز، قزاقستان,เอคีบาสตุซ,エキバストス,埃基巴斯圖茲,에키바스투즈', 51.7237100, 75.3228700, 'KZ', '2017-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91936, 'Zhambyl', 'Zhambyl', 'Dzhambul,Zhambyl,Джамбул', 47.2069400, 71.3969400, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91937, 'Dzhalagash', 'Dzhalagash', 'Dzhalagash,Zhalagash,Zhalaghash', 45.0833300, 64.6666700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91938, 'Dostyq', 'Dostyq', 'Dostyk,Dostyq,Druzhba,Дружба', 45.2550000, 82.4878300, 'KZ', '2012-02-28', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91939, 'Dolinka', 'Dolinka', 'Dolinka,Dolinqa,Dolinskoye,Dolīnka,Dolīnqa,Долинка', 49.6768500, 72.6782200, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91940, 'Derzhavīnsk', 'Derzhavinsk', 'Derzhavinsk,Derzhavinskiy,Derzhavīnsk', 51.0992200, 66.3155700, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91941, 'Chulakkurgan', 'Chulakkurgan', 'Chalak-Kurgan,Chulakkurgan,Sholakkorgan,Sholaqqkorghan,Sholaqqorghan,Tschulak-Kurgan,Чулаккурган,Шолаққорған', 43.7645300, 69.1785600, 'KZ', '2015-08-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91942, 'Shīeli', 'Shieli', 'Chiili,Shieli,Shīeli,Шиели', 44.1688200, 66.7388700, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91943, 'Chayan', 'Chayan', 'Chajan,Chayan,Shajan,Shayan,Чаян,Шаян', 43.0339900, 69.3804800, 'KZ', '2015-09-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91944, 'Chardara', 'Chardara', 'Chardara,Shardara,Syrdar''inskiy,Syrdar’inskiy,Чардара,Шардара', 41.2583200, 67.9699100, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91945, 'Burunday', 'Burunday', 'Baranday,Boraldaj,Boralday,Burundaj,Burunday,Боралдай,Бурундай', 43.3556700, 76.8547700, 'KZ', '2017-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91946, 'Bulayevo', 'Bulayevo', 'Bulaevo,Bulayevo,Būlaevo,Булаево', 54.9059600, 70.4415500, 'KZ', '2015-10-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91947, 'Borovskoy', 'Borovskoy', 'Borovo,Borovoye,Borovskoj,Borovskoy,Borovskoye,Боровской', 53.7927000, 64.1826800, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91948, 'Būrabay', 'Burabay', 'Borovoe,Borovoye,Burabaj,Burabay,Būrabay,Kurort Borovoye,Боровое,Бурабай', 53.0838200, 70.3137900, 'KZ', '2010-07-13', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91949, 'Borodulikha', 'Borodulikha', 'Borodulikha,Borodūlīkha,Бородулиха', 50.7184100, 80.9295000, 'KZ', '2017-02-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91950, 'Priisk Boko', 'Priisk Boko', 'Boke,Boko,Böke,Priisk Boko', 49.0602800, 81.6452800, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91951, 'Bishkul', 'Bishkul', 'Beskol,Besköl,Bishkul,Bishkul'',Бишкуль', 54.7776300, 69.0995100, 'KZ', '2014-04-16', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91952, 'Bestobe', 'Bestobe', 'Bestobe,Bestoebe,Bestyube,Bestöbe,Бестобе,Бестөбе', 52.4979500, 73.0959200, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91953, 'Belyye Vody', 'Belyye Vody', 'Aksu,Aqsu,Aqsū,Belye Vody,Belyye Vody,Аксу,Ақсу,Белые Воды', 42.4219300, 69.8270900, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91954, 'Belousovka', 'Belousovka', 'Belousovka,Belousovskoye,Beloūsovka,Belusovka,Belūsovka,Rud Bylousovskiy,Белоусовка', 50.1328700, 82.5248100, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91955, 'Belogor’ye', 'Belogor''ye', 'Belogor''e,Belogor''ye,Belogor’ye,Byelogor''ye,Byelogor’ye,Koktobe,Köktöbe,Белогорье,Көктөбе', 51.5298300, 77.4714600, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91956, 'Belogorskīy', 'Belogorskiy', 'Belogor,Belogorsk,Belogorskij,Belogorskiy,Belogorskīy,Белогорский', 49.4769800, 83.1480300, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91957, 'Bayzhansay', 'Bayzhansay', 'Baidzhansai,Bajzhansaj,Baydzhansay,Bayzhansay,Байжансай', 43.1670800, 69.9145900, 'KZ', '2015-09-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91958, 'Bayanaul', 'Bayanaul', 'Bajanaul,Bajanauyl,Bayan-Aul''skoye,Bayan-Aulskaya,Bayan-Aul’skoye,Bayanaul,Bayanauyl,Bayanaūyl,Баянаул,Баянауыл', 50.7930400, 75.7012300, 'KZ', '2016-06-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91959, 'Qogham', 'Qogham', 'Baladyr,Bayaldyr,Kogam,Qogham,Когам,Қоғам', 42.8277400, 68.2807400, 'KZ', '2015-08-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91960, 'Balqash', 'Balqash', 'BXH,Balkhash,Balqash,Pribalkhash,Pribalkhashstroy,Балхаш', 46.8480600, 74.9950000, 'KZ', '2017-03-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91961, 'Balkashino', 'Balkashino', 'Balkashino,Balkashinskoye,Balkashīno,Балкашино', 52.5177900, 68.7516000, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91962, 'Bakanas', 'Bakanas', 'Bakanas,Bakˌanas,Baqanas,Бақанас', 44.8083800, 76.2721400, 'KZ', '2015-11-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91963, 'Ayagoz', 'Ayagoz', 'Ayagoz,Ayaguz,Ayagöz,Ayakoz,Ayaköz,Sergiopol'',Sergiopol’', 47.9644700, 80.4343700, 'KZ', '2013-07-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91964, 'Auezov', 'Auezov', 'AEuezov,Auehzov,Auezov,Bakyrchik,Bakyrshik,Äūezov,Ауэзов,Әуезов', 49.7100300, 81.5801800, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91965, 'Atbasar', 'Atbasar', 'ATX,Atbasa,Atbasar,Atbasaras,Atbassar,Otbosar,a te ba sa er,atbasar,Атбасар,Աթբասար,آتباسار,阿特巴薩爾', 51.8065200, 68.3599600, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91966, 'Atasū', 'Atasu', 'Atasu,Atasuskiy,Atasū', 48.6865900, 71.6446900, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91967, 'Asūbulaq', 'Asubulaq', 'Asubulak,Asubulaq,Asūbulaq,Асубулак', 49.5568800, 83.0635500, 'KZ', '2014-06-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91968, 'Astrakhan', 'Astrakhan', 'Astrakhan,Astrakhanka,Astrakhanskiy,Astrakhanskoye', 51.5309200, 69.7968400, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91969, 'Ashchysay', 'Ashchysay', 'Achi-Sai,Achisaj,Achisay,Achisayskiy,Ashchysay,Ashhisaj,Ashhysaj,Atschissa,Ачисай,Ащисай,Ащысай', 43.5537000, 68.8979200, 'KZ', '2016-02-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91970, 'Arys', 'Arys', 'Aris,Aris'',Arys,Arys'',Arysas,Arys’,Arıs,Oris,a lei xi,arusu,arys,Арись,Арыс,Арысь,أريس,アルス,阿雷西', 42.4301500, 68.8087000, 'KZ', '2016-04-10', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91971, 'Arkalyk', 'Arkalyk', 'AYK,Arkalik,Arkalyk,Arkalykas,Arkałyk,Arkˌalykˌ,Arqalyk,Arqalyq,Orqaliq,a er ka lei ke,aleukallikeu,arkalyk,arqalyq,arqalyq  qzaqstan,arukaruiku,yarqalq,Аркалык,Арқалық,آرقالیق,آرقالیق، قزاقستان,أركاليك,ئارقالق,არკალიკი,アルカルイク,阿尔卡雷克,아르칼리크', 50.2491500, 66.9202700, 'KZ', '2012-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91972, 'Aral', 'Aral', 'Aral,Aral Sea,Aral''s''k,Aral''sk,Aral''skoye More,Aralas,Aralsk,Aral’sk,Aral’skoye More,a la er,alal,araru,Арал,Аралск,Аральск,Аральськ,Араљск,アラル,阿拉尔,아랄', 46.8000000, 61.6666700, 'KZ', '2014-12-03', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91973, 'Aqtoghay', 'Aqtoghay', 'Aktogay,Aqtoghay', 46.9500000, 79.6666700, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91974, 'Aktau', 'Aktau', 'Aktau,Aqtau,Aqtaū,Актау,Ақтау', 50.2346600, 73.0666200, 'KZ', '2017-02-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91975, 'Aksu', 'Aksu', 'Aksu,Aqsu,Aqsū,Karasuk,Stalinskiy,Аксу,Ақсу', 52.4442200, 71.9576100, 'KZ', '2016-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91976, 'Aqshataū', 'Aqshatau', 'Akchatan,Akchatau,Akchataul,Akshatau,Aqshatau,Aqshataū,Акшатау', 47.9891700, 74.0575000, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91977, 'Astana', 'Astana', 'Akmola,Akmolinsk,Aqmola,Astana,Astano,Astanà,Astaná,Asztana,Aστάνα,Ostona,Qaraotkel,Qaraötkel,TSE,Tselinograd,a si ta na,aseutana,astana,astanh,asutana,Астана,Остона,Աստանա,אסטנה,آستانه,أسطانا,আস্তানা,ასტანა,አስታና,アスタナ,阿斯塔纳,아스타나', 51.1801000, 71.4459800, 'KZ', '2011-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91978, 'Aqadyr', 'Aqadyr', 'Agadyr'',Agadyr’,Aqadyr,Агадырь,Ақадыр', 48.2601400, 72.8585100, 'KZ', '2017-04-06', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91979, 'Almaty', 'Almaty', 'ALA,Alma Ata,Alma-Ata,Almaato,Almata,Almati,Almato,Almaty,Almatî,Almatõ,Almatý,Almatı,Almatʻa,Ałmaty,Gorad Alma-Ata,Vernyy,a la mu tu,alamati,almaaty,almati,almaty,arumatoi,xal mati,Αλμάτι,Алма-Ата,Алмаато,Алмати,Алматы,Горад Алма-Ата,Ալմաթա,אלמאטיע,אלמטי,آلماآتی,آلماتی,ألماتي,ئالمۇتا,الماتی,अलमाती,अल्माटी,อัลมาตี,ཨཱལ་མ་ཊི།,ალმათი,アルマトイ,阿拉木圖,알마티', 43.2566700, 76.9286100, 'KZ', '2016-06-01', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91980, 'Aqköl', 'Aqkoel', 'Ak-Kul'',Ak-Kul’,Akkol'',Akkol’,Alekseev,Alekseevka,Alekseyevka,Alekseyevskoye,Aqkol,Aqköl,Акколь,Алексеевка', 51.9937400, 70.9470400, 'KZ', '2017-07-13', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91981, 'Prigorodnoye', 'Prigorodnoye', 'Akzhal,Akzhol,Aqzhol,Imeni Martbeka,Pervoye Maya,Prigorodnoe,Prigorodnoye,Prigorodnyy,Акжол,Ақжол,Пригородное', 49.6924400, 75.5843800, 'KZ', '2017-01-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91982, 'Aktogay', 'Aktogay', '', 48.1666700, 75.3000000, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91983, 'Aktau', 'Aktau', 'Aktau,Актау', 48.0333300, 72.8333300, 'KZ', '2013-05-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91984, 'Aktas', 'Aktas', 'Aktas,Aqtas,Актас,Ақтас', 49.7795200, 72.9612800, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91985, 'Aksu-Ayuly', 'Aksu-Ayuly', 'Aksu-Ajuly,Aksu-Ayuly,Aqsu-Ayuly,Aqsū-Ayuly,Аксу-Аюлы,Ақсу-Аюлы', 48.7678800, 73.6727200, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91986, 'Aksuat', 'Aksuat', '', 48.7166700, 83.7000000, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91987, 'Akkol’', 'Akkol''', 'Akkol'',Akkol’,Alexeyevka,Aqkol,Aqköl,Акколь,Ақкөл', 53.2961700, 69.5999700, 'KZ', '2016-01-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91988, 'Aqbaqay', 'Aqbaqay', 'Akbakay,Aqbaqay', 45.0000000, 72.7833300, 'KZ', '2012-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91989, 'Abay', 'Abay', 'Abaj,Abay,Churbay-Nura,Churubay-Nura,Абай', 49.6357500, 72.8616400, 'KZ', '2017-03-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91990, 'Shalqīya', 'Shalqiya', 'Shalkiya,Shalqiya,Shalqīya', 44.0094700, 67.4106200, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91991, 'Birlestik', 'Birlestik', 'Birlestik,Бирлестик,Бірлестік', 53.5841400, 68.3538200, 'KZ', '2015-10-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91992, 'Maleyevsk', 'Maleyevsk', 'Maleevsk,Maleyevsk,Малеевск', 49.8144100, 84.2910200, 'KZ', '2017-01-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91993, 'Belköl', 'Belkol', 'Belkol,Belkul'',Belkul’,Belköl', 44.8116200, 65.5879600, 'KZ', '2012-07-04', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91994, 'Novoishimskiy', 'Novoishimskiy', 'Novoishimskij,Novoishimskiy,Novoīshīmskīy,Новоишимский', 53.1980600, 66.7694400, 'KZ', '2014-06-26', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91995, 'Shashūbay', 'Shashubay', 'Ozernoye,Ozërnoye,Rybtrest,Shashubay,Shashūbay', 46.8169400, 75.0402800, 'KZ', '2013-06-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91996, 'Shyghanaq', 'Shyghanaq', 'Chiganak,Shyganak,Shyghanaq', 44.8305600, 70.0019400, 'KZ', '2012-01-19', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91997, 'Shubarköl', 'Shubarkol', '', 48.8822200, 68.8072200, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91998, 'Stepnogorsk', 'Stepnogorsk', 'Stepnogor,Stepnogors''k,Stepnogorsk,Stepnogorskas,Stiepnogorsk,astpnwgwrsk,astpnwgwrsk  qzaqstan,si jie pu nuo ge er si ke,stybnwghwrsk,Степногорск,Степногорськ,استپنوگورسک,استپنوگورسک، قزاقستان,ستيبنوغورسك,ستێپنۆگۆرسک,斯捷普諾戈爾斯克', 52.3506200, 71.8816100, 'KZ', '2016-05-09', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(91999, 'Zavodskoy', 'Zavodskoy', 'Zavodskoj,Zavodskoy,Заводской', 52.4703100, 72.0151400, 'KZ', '2015-10-05', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92000, 'Ülken', 'Ulken', '', 45.2119400, 73.9786100, 'KZ', '2006-01-17', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92001, 'Altayskiy', 'Altayskiy', 'Altaj,Altajskij,Altay,Altayskiy,Алтай,Алтайский', 50.2459300, 82.3625200, 'KZ', '2017-04-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92002, 'Priozersk', 'Priozersk', 'Priozersk,Приозерск', 46.0310600, 73.7024700, 'KZ', '2010-10-07', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92003, 'Tyuratam', 'Tyuratam', 'Toretam,Tyuratam,Торетам', 45.6500500, 63.3116300, 'KZ', '2016-10-01', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92004, 'Kyzyl-Orda', 'Kyzyl-Orda', 'Kyzylorda,Кызылорда', 44.8479000, 65.4998900, 'KZ', '2014-11-27', 115);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92005, 'Vientiane', 'Vientiane', 'Bientian,Fanhyiengh,Gorad Venc''jan,Nakhon Viangchan,V''ent''jan,VTE,Vent''jan,Ventjan,Ventyan,Vianchan,Viang chan,Viangchan,Vien Can,Vien Chang,Vienciana,Vieng Chan,Vieng-Caen,Vieng-Chan,Vieng-Cæn,Viengchan,Viengtjan,Vientane,Vientian,Vientianas,Vientiane,Vientijan,Vientián,Vientjan,Vientyan,Vijentijan,Viêng Chăn,Vjencana,Vjentiano,Vjentjan,Vjenčana,Vyantyan,Vyantyàn,Vyentyan,Wei-t''ien,Wei-t’ien,Wiang Chan,Wiangcan,Wien Tsjan,Wientian,Wiën Tsjan,Wyentyan,Wyéntyan,bhiyenatiyena,bientian,fyyntyan,vhi''antiyana,vi''anga cana,viyancan,viyen tiyen,vu~ienchan,vu~ienchan shi,wan xiang,weiyngcanthn,wyntyan,yong zhen,Βιεντιάν,Вентян,Виентијан,Виентян,Вијентијан,Вьентьян,Вєнтьян,Горад Венцьян,Վիենտյան,ויינטיאן,فيينتيان,وینتیان,ڤیێنتیان,व्हिआंतियान,ভিয়েনতিয়েন,ਵਿਆਂਗ ਚਾਨ,வியஞ்சான்,ವಿಯೆನ್ ಟಿಯೇನ್,വിയന്റിയൻ,เวียงจันทน์,ວຽງຈນ,ວຽງຈັນ,ཝིན་ཆིའང་,ဗီယင်ကျန်းမြို့,ვიენტიანი,ቭየንትዬን,ヴィエンチャン,ヴィエンチャン市,万象,永珍,비엔티안', 17.9666700, 102.6000000, 'LA', '2012-01-17', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92006, 'Xam Nua', 'Xam Nua', 'Muang Sam,NEU,Sammeua,Samnua,Xam Nua', 20.4159100, 104.0483800, 'LA', '2017-03-23', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92007, 'Savannakhét', 'Savannakhet', 'Khwaeng Savannakhet,Khwaeng_Savannakhet,Muang Savannaket,Savannaket,Savannakhet,Savannakhét,Savannakkhet,Suvannakhet,Suwanakhet,Svannakhet,Svannakhét,ZVK,sawan''naketo xian,Саваннакхет,แขวงสะหวันนะเขต,サワンナケート県', 16.5650500, 104.7527300, 'LA', '2017-02-06', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92008, 'Salavan', 'Salavan', 'Muang Saravane,Salavan,Saravan,Saravane,Sarawan,VNA', 15.7165200, 106.4174400, 'LA', '2017-03-23', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92009, 'Phôngsali', 'Phongsali', 'Fong Sali,Muong Hou,Phong Saly,Phongsali,Phôngsali', 21.6837200, 102.1053600, 'LA', '2012-11-08', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92010, 'Pakse', 'Pakse', 'PKZ,Pakse,Paksé,Paksė,Pakxe,Pakxé,ba se,baksy,pagse,pak se,paksh,pakuse jun,Паксе,باكسي,پاکسه,پاکسے,ปากเซ,ປາກເຊ,ເມືອງປາກເຊ,პაქსე,パークセー郡,巴色,팍세', 15.1202200, 105.7989800, 'LA', '2016-02-27', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92011, 'Pakkading', 'Pakkading', 'Ban Nam Ca Dinh,Ban Namkading,Ban Pak Nam Krading,Ban Pakkading,Ban Paknamkading,Pak Ca Dinh,Pakkading', 18.3245900, 103.9937800, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92012, 'Ban Xiang-Ngeun', 'Ban Xiang-Ngeun', 'Ban Xiang-Ngeun,Ban Xiang-Nguen,Muang Xiang-Ngeun,Pacvet,Pak Vet,Xiang Ngeun,Xieng Ngeun,Xom Ngeun', 19.7585900, 102.1823200, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92013, 'Muang Xay', 'Muang Xay', 'Mouang Sai,Muang Xai,Muang Xay,Muangsaj,Muong Sai,ODY,Oudomsay,Udomxai,Муангсай', 20.6922900, 101.9836800, 'LA', '2012-12-15', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92014, 'Sainyabuli', 'Sainyabuli', 'Ban Samaboury,Khwaeng Sainyabuli,Muang Xaignabouri,Muong Samaboury,Muong Sayaboury,Sainyabuli,Sajnjabuli,Saniabouri,Sayaboury,Xaignabouli,Xayaboury,Xayaburi,Xayabury,ZBY,Сайнябули', 19.2575600, 101.7103200, 'LA', '2014-04-19', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92015, 'Vangviang', 'Vangviang', 'Muang Vangviang,Vang V''eng,Vang Vieng,Vangviang,Viangviang,Ванг Вьенг', 18.9235000, 102.4478400, 'LA', '2012-10-06', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92016, 'Ban Thatèng', 'Ban Thateng', 'Ban Tateng,Ban Thateng,Ban Thatèng,Muang Thateng,Muang Thatèng,Thateng,Thatèng,Tkhateng,Тхатенг', 15.4331700, 106.3827200, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92017, 'Muang Sing', 'Muang Sing', 'Ban Muangsing,Muang Sing,Muong Sen,Muong Seng,Muong Sing,Muong-ting,Sing', 21.1920600, 101.1478900, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92018, 'Muang Sanakham', 'Muang Sanakham', 'Ban Sala Kham,Ban Sanakham,Muang Sanakham,Muong Sankham,Sanakham', 17.9100600, 101.6734800, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92019, 'Phônthong', 'Phonthong', 'Muang Phonthong,Muang Phônthong,Phon Thong,Phon Thuong,Phonthong,Phoune Thong,Phônthong', 15.1011600, 105.6541600, 'LA', '2013-01-10', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92020, 'Muang Phônsavan', 'Muang Phonsavan', 'Muang Phonsavan,Muang Phônsavan,Phone Savan,Phong Savan,Phonsavan,Phônsavan,ໂພນສະຫວນ,ໂພນສະຫວັນ', 19.4500000, 103.2166700, 'LA', '2013-08-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92021, 'Muang Phôn-Hông', 'Muang Phon-Hong', 'Ban Phon Hong,Ban Phong Hong,Muang Phon-Hong,Muang Phone,Muang Phone Hong,Muang Phôn-Hông,Phone Hong,Phong Hong,Phonhong', 18.4956500, 102.4142100, 'LA', '2012-10-06', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92022, 'Muang Phin', 'Muang Phin', 'Muang Phin,Muang Phine,Muong Phin,Muong Phine,Muong Pin,Phine', 16.5339900, 106.0240100, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92023, 'Pakxong', 'Pakxong', 'Muang Pakxong,Pak Song,Paksong,Pakxong,Паксонг', 15.1815400, 106.2303800, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92024, 'Muang Pakxan', 'Muang Pakxan', 'Muang Pakxan,Paksan,Paksane,Pakxan', 18.3826100, 103.6585700, 'LA', '2012-10-06', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92025, 'Muang Mok', 'Muang Mok', 'Muang Moc,Muang Mok,Muong Moc', 18.9099700, 104.0062600, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92026, 'Muang Long', 'Muang Long', 'Ban Muanglong,Muang Long,Muong Long', 20.9650400, 100.8207400, 'LA', '2016-09-08', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92027, 'Ban Pakla', 'Ban Pakla', 'Ban Pakla,Moung La,Muang La,Muang Lang,Pak-La', 20.8694000, 102.1115300, 'LA', '2016-09-08', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92028, 'Khoa', 'Khoa', 'Khoa,Muang Khoa,Muang Khoua,Muang Khua,Muong Khoua', 21.0783300, 102.5060800, 'LA', '2016-09-08', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92029, 'Không', 'Khong', 'Khon,Khong,Không,Muang Khong,Muang Không,Muong Khong', 14.1179200, 105.8486900, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92030, 'Thakhèk', 'Thakhek', 'Khammouane,Muang Khammouan,Muang Thakek,Tha Khaek,Thakhek,Thakhet,Thakhok,Thakhèk', 17.4102700, 104.8306800, 'LA', '2017-06-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92031, 'Muang Kènthao', 'Muang Kenthao', 'Ban Ken Thao,Kene Thad,Kene Thao,Muang Kenthao,Muang Kènthao,Muong Ken Thao', 17.7328900, 101.3981500, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92032, 'Muang Kasi', 'Muang Kasi', 'Kasi,Muang Kasi,Muong Kassy', 19.2292600, 102.2531900, 'LA', '2012-11-08', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92033, 'Muang Hinboun', 'Muang Hinboun', 'Ban Hinboun,Muang Hinboun,Pak Hin Boun', 17.5910000, 104.6038800, 'LA', '2012-01-17', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92034, 'Luang Prabang', 'Luang Prabang', 'LPQ,Louang Prabang,Louangphabang,Louangphrabang,Luan Praban,Luang Phrabang,Luang Prabang,Luang-Prabang,Luangpkhabang,Luangprabang,Luangprabangas,Luangprabango,Luanpabana,Luanpraban,hlwng phra bang,lang bo la bang,lu''anga parabanga,lu''anga prabanga,luangpeulabang,luvan praban,lwang prabang,lwangh brabangh,ruanpaban jun,Луанг Прабанг,Луанг-Прабанг,Луангпхабанг,Луанпрабан,לואנג פרבאנג,لوآنگ پرابانگ,لوانغ برابانغ,لوانگ پرابانگ,लुआंग प्रबांग,ਲੁਆਂਗ ਪਰਾਬਾਂਗ,ലുവാങ് പ്രബാങ്,หลวงพระบาง,ຫລວງພະບາງ,ເມືອງຫຼວງພະບາງ,ლუანგპრაბანგი,ルアンパバーン郡,琅勃拉邦,루앙프라방', 19.8860100, 102.1350300, 'LA', '2015-09-05', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92035, 'Luang Namtha', 'Luang Namtha', 'Khong Luong Nam Tha,LXG,Louang Namtha,Loung Nam Tha,Luang Namtha,Luong Nam Tha,Muang Luong Nam Tha,Muong Long Nam Tha,Muong Luong,Muong Luong Nam Ta,Muong Luong Nam Tha,Nam Tha,hlwng na tha,lang nan ta,luangnamtʼha,lwang namta,ruan''namuta jun,لوانگ نامتا,หลวงน้ำทา,ມ. ນາແລ  ຫລວງນາທາ,ມ. ນາແລ  ຫລວງນໍ້າທາ,ლუანგნამტჰა,ルアンナムター郡,琅南塔', 20.9486000, 101.4018800, 'LA', '2016-12-17', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92036, 'Muang Khamkeut', 'Muang Khamkeut', 'Ban Phonmuang,Ban Phônmuang,Kam Kert,Kam Keut,Kham Kheut,Kham-Ko''t,Kham-Ko’t,Khamkeut,Muang Khamkeut', 18.2257200, 104.7311900, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92037, 'Ban Dônghén', 'Ban Donghen', 'Ban Dong Hen,Ban Donghen,Ban Dônghén,Donghen,Dônghén', 16.7029700, 105.2821100, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92038, 'Champasak', 'Champasak', 'Basak,Bassac,Bassak,Champasak,Champassac,Champassak,Чампасак', 14.8920400, 105.8778700, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92039, 'Borikhan', 'Borikhan', 'Berikhane,Bolikanh,Bolikhan,Borikane,Borikham,Borikhan,Borikhane,Muang Borikan,Muang Borikane,Muong Borikan,Muong Borikane', 18.5628600, 103.7267100, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92040, 'Lamam', 'Lamam', 'Ban Phon,Ban Phone,Ban Phôn,Lamam,Lamarm,Phone', 15.4170500, 106.6946100, 'LA', '2013-01-10', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92041, 'Ban Nahin', 'Ban Nahin', 'Ban Na Inh,Ban Nahin', 18.2425300, 104.2128100, 'LA', '2016-08-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92042, 'Ban Houayxay', 'Ban Houayxay', 'Ban Houayxai,Ban Houayxay,Ban Houei Sai,Ban Huei Sai,Ban Hueu Sai,Ban Hwei Sai,Fort Carnot,Houayxay,Houei Sai,Hovei Sai,Huoei Sai,Khuajsaj,Van Houei Sai,Хуайсай', 20.2765200, 100.4130200, 'LA', '2016-06-28', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92043, 'Ban Hatgnao', 'Ban Hatgnao', 'Ban Hat Nhao,Ban Hatgnao,Hat Nao,Hat Nhao', 14.6803000, 106.5821200, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92044, 'Ban Fangdèng', 'Ban Fangdeng', 'Ban Fangdeng,Ban Fangdèng,Muang Xaisettha,Muang Xaiséttha,Phen Deng', 14.8132000, 106.9343400, 'LA', '2016-07-04', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92045, 'Attapu', 'Attapu', 'AOU,Atpu,Attapeu,Attapu,Attopeu,Muang Mai,Muang Samakhixai,Muong Attopeu,attapu xian,アッタプー県', 14.8107100, 106.8318400, 'LA', '2017-03-22', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92046, 'Ban Houakhoua', 'Ban Houakhoua', 'Ban  Khojjaksjau,Ban Houakhoua,Ban Houayxay,Бан  Хойяксяу', 20.2467000, 100.4540100, 'LA', '2013-08-13', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92047, 'Ban Namnga', 'Ban Namnga', 'Ban Namnga,Muang Mai', 21.1719300, 102.7256200, 'LA', '2016-09-09', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92048, 'Viangxai', 'Viangxai', 'Viangxai,Vieng Xai,ViengSai,ViengXay', 20.4067700, 104.2237900, 'LA', '2016-09-09', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92049, 'Muang Nalè', 'Muang Nale', 'Muang Nale,Muang Nalè', 20.5321200, 101.4467800, 'LA', '2016-09-09', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92050, 'Dak Cheung', 'Dak Cheung', '', 15.4666700, 107.2666700, 'LA', '2011-01-28', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92051, 'Sanaxy', 'Sanaxy', '', 15.0220700, 107.2601600, 'LA', '2011-01-31', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92052, 'Huameung', 'Huameung', '', 20.1489500, 103.8589500, 'LA', '2011-01-31', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92053, 'Viengxay', 'Viengxay', '', 20.3422200, 104.3446400, 'LA', '2013-03-02', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92054, 'Xamtay', 'Xamtay', '', 19.9451500, 104.5172200, 'LA', '2011-01-31', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92055, 'Viengthong', 'Viengthong', '', 20.3279200, 103.4085600, 'LA', '2011-01-31', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92056, 'Xaysetha', 'Xaysetha', 'Saysetha', 14.8144400, 106.9344400, 'LA', '2017-06-03', 122);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92057, 'Zghartā', 'Zgharta', 'Ezgharta,Zagharta,Zaghartā,Zgharta,Zghartā,zghrta,زغرتا', 34.3973900, 35.8949300, 'LB', '2013-10-07', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92058, 'Zahlé', 'Zahle', 'Gorad Zakhle,QZQ,Sahla,Zachle,Zahla,Zahlah,Zahle,Zahleh,Zahlé,Zahlė,Zakhla,Zakhle,Zaḩlah,jaheulle,zare,zha he lei,zhlh,zhlh  lbnan,zhlt,Ζάχλε,Горад Захле,Захла,Захле,Զահլե,זאכלא,זחלה,زحلة,زحله,زحله، لبنان,زحلہ,ザーレ,扎赫勒,자흘레', 33.8467500, 35.9020300, 'LB', '2013-04-21', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92059, 'Tripoli', 'Tripoli', 'Gorad Trypali,KYE,Tarabulus,Trablous,Trablussam,Trablusşam,Tripol,Tripole,Tripoli,Tripoli i Libanon,Tripolis,Tripolo,Tripuli,Trypolis,Trâblous,Trìpuli,Trípol,Trípoli,de li bo li,teulipolli,toripori,trabls,trabls alsham,tripoli,trippeali,trypwly,Ţarābulus,Τρίπολη,Горад Трыпалі,Триполи,Триполі,Տրիպոլի,טריפאלי,טריפולי,ترابلس,طرابلس,طرابلس الشام,त्रिपोली,ട്രിപ്പൊളി,ตริโปลี,ტრიპოლი,トリポリ,的黎波里,트리폴리', 34.4366700, 35.8497200, 'LB', '2012-02-02', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92060, 'Tyre', 'Tyre', 'Es Sur,Sor,Sour,Soûr,Sur,Surru,Tir,Tiro,Tyr,Tyras,Tyre,Tyros,Tyrus,Týros,alswr,swr,tai er,tirusu,zr,zwr,Şūr,Τύρος,Тир,Тір,Тѵръ,צור,צר,الصور,صور,Ṣur,Ṣurru,Ṣōr,ティルス,泰爾', 33.2733300, 35.1938900, 'LB', '2012-02-02', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92061, 'Sîr ed Danniyé', 'Sir ed Danniye', 'Sir ad Dinniyah,Sir ed Danniye,Sîr ed Danniyé,Sīr aḑ Ḑinnīyah,syr aldnyt,سير الضنية', 34.3852800, 36.0311100, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92062, 'Sidon', 'Sidon', 'Cidono,Gorad Sajda,QSQ,Saida,Sajda,Sayda,Saïda,Sido,Sidon,Sidona,Sidonas,Sidone,Sidoni,Sidun,Sidó,Sidón,Sidѡnu,Sydon,Sydón,Szidon,Szidón,Sídon,sai da,saida,si dxn,sidon,sidoni,syda,zydwn,Şaydā,Σιδώνα,Горад Сайда,Сайда,Сидон,Сідон,Сїдѡнъ,Սայդա,צידון,صيدا,صیدا,ไซดอน,სიდონი,サイダ,赛达,시돈', 33.5599300, 35.3756400, 'LB', '2013-04-04', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92063, 'Ra’s Bayrūt', 'Ra''s Bayrut', '', 33.9000000, 35.4833300, 'LB', '2006-01-17', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92064, 'Marjayoûn', 'Marjayoun', 'Djedeideh,El Judeide,Marjaayoun,Marjayoun,Marjayoûn,Marji`yun,Marji‘yūn,مرجعيون', 33.3602800, 35.5911100, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92065, 'Jounieh', 'Jounieh', 'Djounie,Jounie,Joünié,Juniyah,Jūniyah,jwnyh,جونيه', 33.9808300, 35.6177800, 'LB', '2017-03-29', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92066, 'Joubb Jannîne', 'Joubb Jannine', 'Djeb Djennin,Joub Jannine,Joubb Jannine,Joubb Jannîne,Jubb Jannin,Jubb Jannīn,jb jnyn,جب جنين', 33.6269400, 35.7841700, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92067, 'Jbaïl', 'Jbail', 'Bibl (Bibl),Biblo,Biblos,Biblos (Biblos),Biblus,Bueblosz,Byblos,Büblosz,Bīblūs,Djebail,Djébail,Gebal,Gibelet,Giblet,Gubayl,Gubla,Jbail,Jbayl,Jbaïl,Jbeil,Jebail,Jebaïl,Jubayl,Kypt (Keben),Kypt (Kepen),biburosu,byblws,gbl  (gbl),jbyl,vyvlos (byblos),Ǧubayl,βύβλος (byblos),Библ (Bibl),Библос (Biblos),גבל  (gbl),بيبلوس,جبيل,ビブロス', 34.1211100, 35.6480600, 'LB', '2014-03-08', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92068, 'Jezzîne', 'Jezzine', 'Djezzin,Djezzine,Jazzin,Jazzīn,Jezzine,Jezzîne,jzyn,جزين', 33.5416700, 35.5844400, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92069, 'Hâsbaïya', 'Hasbaiya', 'Hasbaiya,Hasbayya,Hasbeiya,Hasbeya,Hasibayya,Hâsbaïya,Hāsbeya,hasbya,حاصبيا,Ḩāşbayyā,Ḩāşibayyā', 33.3977800, 35.6850000, 'LB', '2013-04-04', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92070, 'Halba', 'Halba', 'Aakar,Akkar,Halba,Halbe,`Akkar,hlba,حلبا,عكار,Ḩalbā,‘Akkār', 34.5427800, 36.0797200, 'LB', '2012-02-02', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92071, 'Habboûch', 'Habbouch', 'Habbouch,Habboush,Habboûch,Habbush,Khabbushe,hbwsh,Хаббуше,حبوش,Ḩabbūsh', 33.4072900, 35.4816900, 'LB', '2013-08-06', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92072, 'Bcharré', 'Bcharre', 'Basharri,Basharrī,Bcharre,Bcharreh,Bcharri,Bcharré,Bcharrī,Becharri,Besherri,Bishari,Bisharri,Bsharri,Bsharrī,Bsherri,bshry,Бишари,بشري', 34.2508300, 36.0105600, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92073, 'Bent Jbaïl', 'Bent Jbail', 'Bennt Jbail,Bent Jbail,Bent Jbaïl,Bent Jbeil,Bint Jubayl,Bint Umm Jubail,bnt jbyl,بنت جبيل', 33.1194400, 35.4333300, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92074, 'Bhamdoûn el Mhatta', 'Bhamdoun el Mhatta', 'Bhamdoun,Bhamdoûn,Bhamdun al Mahattah,Bḩamdūn al Maḩaţţah', 33.8086100, 35.6597200, 'LB', '2009-10-20', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92075, 'Bhamdoun', 'Bhamdoun', 'Bhamdourn,Bhamdun,Bihamdun,Biḩamdūn,Bḩamdūn', 33.7950000, 35.6511100, 'LB', '2009-10-20', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92076, 'Beït ed Dîne', 'Beit ed Dine', 'Bayt ad Din,Bayt ad Dīn,Beit ed Din,Beit ed Dine,Beit ed Dīn,Beit ed-Deen,Beteddin,Beït ed Dîne,byt aldyn,بيت الدين', 33.6941700, 35.5808300, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92077, 'Beirut', 'Beirut', 'BEY,Baeyrut,Bairut,Bayrut,Bayrūt,Beiriut,Beiroet,Beirot,Beirots,Beirout,Beiroūt,Beirut,Beiruta,Beirutas,Beirute,Beirút,Beirût,Beirūta,Bejrut,Bejrut oshs'',Bejruti,Bejruto,Bejrút,Berut,Berytos,Berytus,Bewout,Beyrouth,Beyrut,Bey­rutʻ,Birut,Bäyrut,Béiriút,Bêrût,Gorad Bejrut,bairut,bairuta,bayrut,bei lu te,beiluteu,beiruti,beiruto,berut,beruta,beyaruta,beyruta,bey‌rutt,biruta,byrwt,byyrwt,peyrut,Βηρυτός,Бейрут,Бейрут ошсь,Бејрут,Бәйрут,Горад Бейрут,Բեյ­րութ,ביירוט,ביירות,بيروت,بَيْرُوت,بیروت,بېيرۇت,بەیرووت,ܒܝܪܘܬ,बेयरूत,बेय्रुत,बैरूत,বৈরুত,ਬੇਰੂਤ,ବିରୁଟ,பெய்ரூத்,ಬೈರುತ್,ബെയ്‌റൂത്ത്,เบรุต,པ་ར་ཐ།,པེ་རུ་ཐེ།,ဘေရွတ်မြို့,ბეირუთი,ቤይሩት,ベイルート,貝魯特,贝鲁特,베이루트', 33.8889400, 35.4944200, 'LB', '2010-08-11', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92078, 'Baalbek', 'Baalbek', 'Ba`albak,Ba`labak,Ba`labakk,Baal''bek,Baalbeck,Baalbek,Baalbekas,Baalmpek,Baglabek,Ba‘albak,Ba‘labak,Ba‘labakk,Bəəlbək,Gorad Baal''bek,Heliopolis,Héliopolis,ba lei bei ke,baalbekeu,baalbeki,balabeka,barubekku,bʻlbk,Μπάαλμπεκ,Баалбек,Баальбек,Бағлабек,Горад Баальбек,Բաալբեկ,בעלבכ,بعلبك,بعلبک,बालबेक,ബാൽബെക്ക്,ბაალბექი,バールベック,巴勒贝克,바알베크', 34.0058300, 36.2180600, 'LB', '2014-03-09', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92079, 'Baabda', 'Baabda', 'B`abda,Baabda,Babda,B‘abdā,ba bo da,babeuda,Баабда,Բաաբդա,באאבדע,בעבדא,بعبدا,بعبدا، لبنان,巴卜達,바브다', 33.8338900, 35.5441700, 'LB', '2013-08-09', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92080, 'Ain Ebel', 'Ain Ebel', 'Ain Ibel,Ain Ibl,Aïn Ibel,`Ain Ibil,`Ayn Ibil', 33.1102300, 35.4025100, 'LB', '2008-10-02', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92081, 'En Nâqoûra', 'En Naqoura', 'An Naqurah,An Nāqūrah,En Nakura,En Naqoura,En Naqura,En Nâqoûra,En Nāqūra,En-Naqourah,Enn Naqoura,Enn Nâqoura,Naqoura', 33.1180600, 35.1397200, 'LB', '2014-09-05', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92082, 'Nabatîyé et Tahta', 'Nabatiye et Tahta', 'An Nabatiyah at Tahta,An Nabaţīyah at Taḩtā,NABATIEH TAHTA', 33.3788900, 35.4838900, 'LB', '2011-06-27', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92083, 'Aanjar', 'Aanjar', 'Aanjar,Andzhar,Hansh Mousa,Haouch Moussa,Hawsh Musa,`Anjar,Анджар,Ḩawsh Musá,‘Anjar', 33.7277800, 35.9311100, 'LB', '2017-03-16', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92084, 'Amioûn', 'Amioun', 'Amioun,Amioûn,Amiun,Amyun,Amyūn,amywn,أميون', 34.3000000, 35.8088900, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92085, 'Jdaidet el Matn', 'Jdaidet el Matn', 'Djedeide,El Debiyeh,El Judeide,Jdaide,Jdaidet el Matn,Jdaidé,Jedeide,Judaydah al Matn,jdydt almtn,جديدة المتن', 33.8905600, 35.5663900, 'LB', '2012-02-02', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92086, 'El Hermel', 'El Hermel', 'Al Harmal,Al Hirmil,El Hermel,Hermel,Hermil,Hirmil,Hurmal,alhrml,الهرمل', 34.3941700, 36.3847200, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92087, 'Batroûn', 'Batroun', 'Al Batrun,Al Batrūn,Batroun,Batroûn,Batrun,Batrūn,Botrys,albtrwn,البترون', 34.2552800, 35.6580600, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92088, 'Aaley', 'Aaley', 'Aaley,Aley,Alia,Aliye,Alley,`Alayh,`Aleih,عاليه,‘Ālayh,‘Āleih', 33.8052800, 35.6000000, 'LB', '2012-01-18', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92089, 'Râchaïya el Ouadi', 'Rachaiya el Ouadi', 'Rachaiya el Ouadi,Rashayya,Râchaïya el Ouadi,Rāshayyā,rashya,راشيا', 33.5008900, 35.8437000, 'LB', '2012-12-06', 124);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92206, 'Teyateyaneng', 'Teyateyaneng', 'Teyateyaneng', -29.1471900, 27.7489500, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92207, 'Quthing', 'Quthing', 'Cguting,Moyeni,Quthing,UTG,Цгутинг', -30.4000100, 27.7002700, 'LS', '2010-06-25', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92208, 'Qacha’s Nek', 'Qacha''s Nek', 'Qacha''s Neck,Qacha''s Nek,Qacha''s Nek Residency,Qachas Nek Camp,Qachasnek Camp,Qacha’s Neck,Qacha’s Nek,Qacha’s Nek Residency', -30.1153700, 28.6893600, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92209, 'Nako', 'Nako', 'Makhalaneng,Nako,Naku', -29.6166700, 27.7666700, 'LS', '2013-08-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92210, 'Mokhotlong', 'Mokhotlong', 'MKH,Mokhotlong,Мохотлонг', -29.2893900, 29.0675100, 'LS', '2010-05-24', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92211, 'Mohale’s Hoek', 'Mohale''s Hoek', 'Mohale''s Hoek,Mohale’s Hoek', -30.1513700, 27.4769100, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92212, 'Maseru', 'Maseru', 'Gorad Maseru,MSU,Maserou,Maseru,Maseruo,Maserú,Mazerou,ma sai lu,ma se ru,ma xie lu,maceru,maselu,maseru,masrw,masyrw,msrw,Μαζέρου,Μασερού,Горад Масеру,Масеру,Մասերու,מאסערו,מסרו,ماسرو,ماسيرو,ماسیرو,ماسێرو,मासेरू,ਮਸੇਰੂ,மசேரு,มาเซรู,མ་སི་རུ།,მასერუ,መሴሩ,マセル,馬些盧,马塞卢,마세루', -29.3166700, 27.4833300, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92213, 'Maputsoe', 'Maputsoe', 'Maputsoe', -28.8866000, 27.8991500, 'LS', '2012-04-05', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92214, 'Mafeteng', 'Mafeteng', 'MFC,Mafeteng', -29.8229900, 27.2374400, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92215, 'Leribe', 'Leribe', 'Hlotse,LRB,Leribe,Лерибе', -28.8718500, 28.0450100, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92216, 'Butha-Buthe', 'Butha-Buthe', 'Buta-Buteh,Butha-Buthe,Бута-Бутэ', -28.7665900, 28.2493700, 'LS', '2012-01-18', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92217, 'Thaba-Tseka', 'Thaba-Tseka', 'THB,Taba-Ceka,Thaba-Tseka,Таба-Цека', -29.5220400, 28.6084000, 'LS', '2012-01-20', 125);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92187, 'Zwedru', 'Zwedru', 'Tchien,Zvedru,Zwadhru,Zwedru,Зведру', 6.0684600, -8.1355900, 'LR', '2015-01-07', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92188, 'New Yekepa', 'New Yekepa', 'Lamco,Lamco Community,New Yekepa,Yekepa', 7.5794400, -8.5377800, 'LR', '2012-01-17', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92189, 'Voinjama', 'Voinjama', 'VOI,Voinjama,Voinyamai,Vonjama', 8.4219400, -9.7477800, 'LR', '2012-01-17', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92190, 'Tubmanburg', 'Tubmanburg', 'Bomi Hills,Tubmanburg,Vai Tieda,Vaitown', 6.8706400, -10.8211000, 'LR', '2014-11-05', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92191, 'Fish Town', 'Fish Town', 'Datoda,Fish Town,Fish Town City,Tendekehn', 5.1973900, -7.8757900, 'LR', '2015-05-06', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92192, 'Sanniquellie', 'Sanniquellie', 'Sanaquelli,Sangbui,Saniquellie,Sanniguellie,Sanniquellie,Sanniquellie City,Sanokole,Sanokwele,Sanokwelle,Sanoquelli,Sanquilly,Senbui', 7.3621500, -8.7132600, 'LR', '2015-05-06', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92193, 'Robertsport', 'Robertsport', 'Port Robert,Robert Port,Roberts Port,Robertson,Robertsport,Robertstown', 6.7532900, -11.3671000, 'LR', '2014-11-05', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92194, 'Cestos City', 'Cestos City', 'Cesstos City,Cestos City,Niboinkui,RVC,River Cess,River Cess Settlement,Rivercess', 5.4568300, -9.5816700, 'LR', '2014-12-03', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92195, 'Monrovia', 'Monrovia', 'Gorad Manrovija,MLW,Monrobia,Monrofia,Monrovi,Monrovia,Monrovii,Monrovija,Monrovio,Monroviya,Monrowia,Monròvia,Monróvia,Monróvía,manarobhiya,manroweiy,manrwwya,meng luo wei ya,monarovi''a,monlobia,monrobia,monrovhiya,monrovia,monroviya,mwnrwbyh,mwnrwfya,mwnrwwya,Μονρόβια,Горад Манровія,Монрови,Монровия,Монровија,Монровія,Մոնրովիա,מאנראוויע,מונרוביה,مانروویا,مونروفيا,مونروویا,مۆنرۆڤیا,मोन्रोव्हिया,মনরোভিয়া,ਮੋਨਰੋਵੀਆ,மொன்றோவியா,มันโรเวีย,མོང་རོ་ཝི་ཡ།,მონროვია,ሞንሮቪያ,モンロビア,蒙罗维亚,蒙羅維亞,몬로비아', 6.3005400, -10.7969000, 'LR', '2010-05-30', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92196, 'Kakata', 'Kakata', 'Kakata,Kakata City', 6.5310400, -10.3536800, 'LR', '2015-05-06', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92197, 'Harper', 'Harper', 'CPA,Cape Palmas,Harper,Harper City', 4.3782000, -7.7108100, 'LR', '2015-07-03', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92198, 'Greenville', 'Greenville', 'Greenville,Greenville City,SNI,Sino,Sinoe,Sinu,Sinu Village', 5.0113300, -9.0388000, 'LR', '2015-05-06', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92199, 'Gbarnga', 'Gbarnga', 'Gbanga,Gbanka,Gbarnga,Gbarnga City,Gbarnge,Gbarnka,Гбарнге', 6.9954300, -9.4712200, 'LR', '2015-05-06', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92200, 'Ganta', 'Ganta', '', 7.3022200, -8.5308300, 'LR', '2006-01-17', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92201, 'Buchanan', 'Buchanan', 'B''jukenen,Biukenenas,Bjukenen,Buchanan,Byukenen,Fish Town,Grand Bassa,Lower Buchanan,UCN,bu kan nan,bukyanan,byukaeneon,bywkynn  laybyrya,bywqnn,Бьюкенен,Бюкенен,Բուչանան,ביוקנן,بیوکینن، لائبیریا,ブキャナン,布坎南,뷰캐넌', 5.8810900, -10.0447200, 'LR', '2014-11-05', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92202, 'Bopolu', 'Bopolu', 'Bopolu,Bopora,Boporo', 7.0666700, -10.4875000, 'LR', '2012-01-17', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92203, 'Bensonville', 'Bensonville', 'Bensonville,Bensonville City,Bentol,Bentol City,Бенсонвилле', 6.4471600, -10.6128300, 'LR', '2015-07-03', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92204, 'Barclayville', 'Barclayville', 'Barclayville,Barlayville', 4.6744300, -8.2330600, 'LR', '2014-12-03', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92205, 'Buutuo', 'Buutuo', '', 6.8275000, -8.3428000, 'LR', '2012-04-18', 126);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92102, 'Vaduz', 'Vaduz', 'Bantouz,QVU,Vaduc,Vaducas,Vaduz,Vaduzo,fado~utsu,paducheu,vadutsi,wa dou zi,Βαντούζ,Вадуц,פאדוץ,ვადუცი,ፋዱጽ,ファドゥーツ,瓦都茲,파두츠', 47.1415100, 9.5215400, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92103, 'Triesenberg', 'Triesenberg', 'Triesenberg,torizenberuku,トリーゼンベルク', 47.1181500, 9.5419700, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92104, 'Triesen', 'Triesen', 'Triesen,Trizen,torizen,Тризен,トリーゼン', 47.1075200, 9.5281500, 'LI', '2013-10-13', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92105, 'Schellenberg', 'Schellenberg', 'Schellenberg,sherenberuku,シェレンベルク', 47.2312300, 9.5467800, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92106, 'Schaan', 'Schaan', 'Schaan,Schan,Shaan,shan,Шаан,شان,シャーン', 47.1649800, 9.5086700, 'LI', '2013-10-13', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92107, 'Ruggell', 'Ruggell', 'Rugell,Ruggell,Ruggell'',ruggeru,Руггелль,ルッゲル', 47.2379900, 9.5254000, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92108, 'Planken', 'Planken', 'Blanken,Planken,puranken,Планкен,プランケン', 47.1851600, 9.5443700, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92109, 'Mauren', 'Mauren', 'Mauern,Mauren,mauren,マウレン', 47.2180500, 9.5442000, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92110, 'Gamprin', 'Gamprin', 'Gambrin,Gamprin,Gamprin-Bendern,ganpurin,Гамприн,ガンプリン', 47.2203800, 9.5093500, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92111, 'Eschen', 'Eschen', 'Eschen,esshen,エッシェン', 47.2107100, 9.5222300, 'LI', '2013-04-02', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92112, 'Balzers', 'Balzers', 'Balzers,baruzasu,バルザース', 47.0666500, 9.5025100, 'LI', '2015-08-07', 128);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92218, 'Žiežmariai', 'Ziezmariai', 'Zeizmariai,Zhezhmarjaj,Zhezhmaryay,Zhiyezhmaryai,Zhizhmory,Ziezmariai,Ziezmariu,Zizmariai,Zyzmory,Żyżmory,Žeižmariai,Žiežmariai,Žiežmarių,Žižmariai,Жежмаряй', 54.8072500, 24.4407300, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92219, 'Žemaičių Naumiestis', 'Zemaiciu Naumiestis', 'Naumiescio,Naumiestis Taurag,Naumiesčio,Nowe Miasto,Zemaiciu Naumiestis,Zhemajchju-Naumestis,Zhemaychyu-Naumestis,Zhemaychyu-Naumiyestis,Žemaičių Naumiestis,Жемайчю-Науместис', 55.3594100, 21.7036400, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92220, 'Zarasai', 'Zarasai', 'Ezerenai,Ežerėnai,Jeziorossy,Jeziorosy,Novo Aleksandrovsko,Novo Alexandrovsk,Novoaleksandrovsk,Zarasai,Zarasaj,Zarasay,Zarasu,Zarasų,Zargrad,Зарасай', 55.7322500, 26.2511500, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92221, 'Žagarė', 'Zagare', 'Gorad Zhagareh,Zagare,Zagares,Zagory,Zankare,Zhagare,jaghary,zha jia lei,zhagare,zhagarh,Żagory,Žagare,Žagarė,Žagarės,Ζαγκάρε,Горад Жагарэ,Жагаре,זאגר,جاغاري,ژاگاره,ژاگرے,ჟაგარე,扎加雷', 56.3614900, 23.2509400, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92222, 'Visaginas', 'Visaginas', 'Snechkus,Snieckus,Sniečkus,Visagina,Visaginas,Wisaginia,visaginas,Висагинас', 55.5967800, 26.4398400, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92223, 'Virbalis', 'Virbalis', 'Virbalis,Wierzbolowo,Wierzbowo,Wierzbołowo,Wirballen,Вирбалис', 54.6285800, 22.8227200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92224, 'Vilnius', 'Vilnius', 'Bilna,Bilnious,Gorad Vil''njus,IVilnyusi,VNO,Vil''njus,Vil''no,Vil''nyus,Viln'',Vilna,Vilnia,Vilnias,Vilniaus miestas,Vilnious,Vilnis,Vilnius,Vilnjus,Vilnjûs,Vilno,Vilnues,Vilnus,Vilnyus,Vilníus,Vilnüs,Viļņa,Vílnius,Wilna,Wilniyus,Wilno,Wilnus,Wilñus,bhilani''usa,bilnyuseu,fylnyws,vhilniyasa,vilniusi,vilniyas,vu~irinyusu,vylnyws,wei er niu si,wi lni xus,wlnys,wylnh,wylnyws,Βίλνα,Βίλνιους,Βιλνιους,Вилниус,Вилнус,Вилнюс,Вилн҄ь,Вильнюс,Вилњус,Виљнус,Вільнюс,Горад Вільнюс,Վիլնյուս,ווילנע,וילנה,فيلنيوس,ولنیس,ویلنیوس,ڤیلنیوس,व्हिल्नियस,ভিলনিউস,வில்னியஸ்,วิลนีอุส,ལྦེ་ནི་སུ་ནི།,ვილნიუსი,ቪልኒውስ,ᕕᓪᓂᐅᔅ/vilnius,ヴィリニュス,维尔纽斯,빌뉴스', 54.6891600, 25.2798000, 'LT', '2014-10-05', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92225, 'Vilkija', 'Vilkija', 'Vil''kiya,Vilki,Vilkija,Vilkijos,Vil’kiya,Wilki', 55.0460900, 23.5855200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92226, 'Vilkaviskis', 'Vilkaviskis', 'Bilkabiskis,Vil''kavishkis,Vilkavishkis,Vilkaviski,Vilkaviskio,Vilkaviskis,Vilkaviškio,Vilkaviškis,Vilkavišķi,Wilkowyszki,Wiłkowyszki,Wylkowyszki,Wyłkowyszki,Βιλκαβίσκις,Вилкавишкис,Вилькавишкис', 54.6516700, 23.0322200, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92227, 'Vievis', 'Vievis', 'Anastasevskaya,Jewie,V''yevis,Vevis,Vievio,Vievis,Viyevis,V’yevis,Yev''ye,Yev’ye,Вевис', 54.7666700, 24.8000000, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92228, 'Viekšniai', 'Vieksniai', 'V''yekshnyay,Vekshnya,Vekshnyay,Vieksniai,Vieksniu,Viekšniai,Viekšnių,Viyekshnyay,V’yekshnyay,Wieksznie', 56.2359800, 22.5166700, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92229, 'Venta', 'Venta', 'Venta', 56.1916200, 22.6952800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92230, 'Veisiejai', 'Veisiejai', 'Veisejai,Veiseju,Veisiejai,Veisėjai,Veisėjų,Vejsejaj,Veyseyay,Veyseye,Veysyay,Viesee,Wiejsieje,Вейсеяй', 54.1011000, 23.6961400, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92231, 'Varniai', 'Varniai', 'Gorad Varnej,Medininkai,Varne,Varni,Varniai,Varniu,Varnių,Varnjaj,Varnyay,Varnē,Varņi,Wornie,farnyay,wa er ni ai,warnyay,Βαρνιάι,Варняй,Горад Варней,فارنياي,وارنیای,瓦爾尼艾', 55.7443500, 22.3725100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92232, 'Varėna', 'Varena', 'Gorad Varehna,Orany,Varena,Varena kommune,Variena,Varēna,Varėna,Varėna kommune,varena,vu~arena,wa lei na,warna  ltwny,wwryyna,Варена,Горад Варэна,וריאנה,وارنا، لتونی,وورئینا,ვარენა,ヴァレナ,瓦雷纳', 54.2154600, 24.5753800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92233, 'Vabalninkas', 'Vabalninkas', 'Vabal''ninkas,Vabalninkai,Vabalninkas,Vabalninko,Vobol''niki,Vobol’niki,Wobolniki,Zabalninkas,Вабальнинкас', 55.9815100, 24.7482800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92234, 'Utena', 'Utena', 'Gorad Ucjana,Otena,Outena,Owtena,Uciana,Uciany,Uten,Utena,Utena ili,Utenos,Utyana,Uzjany,awtna,awtyna,utena,wu tian na,Ουτενά,Горад Уцяна,Утена,Ուտենա,אוטנה,أوتينا,اوتنا,اوتینا,უტენა,ウテナ,乌田纳,우테나', 55.4976400, 25.5991800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92235, 'Ukmerge', 'Ukmerge', 'Gorad Ukmjarge,Okmergie,Oukmernke,Ukmerge,Ukmerge kommune,Ukmerges,Ukmergė,Ukmergė kommune,Ukmergės,Ukmerģe,Ukmjarge,Vilkmerge,Vilkmergė,Vilkomir,Wilkomierz,Wilkomir,Wiłkomierz,ukeumeleuge,ukumeruge,wu ke mei er gai,Ουκμεργκέ,Горад Укмярге,Укмерге,Укмярге,אוקמרגה,ווילקאמיר,უკმერგე,ウクメルゲ,烏克梅爾蓋,우크메르게', 55.2500000, 24.7500000, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92236, 'Tytuvėnėliai', 'Tytuveneliai', 'Titavenay,Tituvenaj,Tsitovyany,Tytuveneliai,Tytuvėnėliai,Титувенай', 55.6234500, 23.1716200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92237, 'Trakai', 'Trakai', 'Novyye Troki,Trakai,Trakai kommune,Trakaj,Trakay,Troki,Troki Nove,Troki Nowe,Τρακάι,Тракай,Трокі', 54.6378300, 24.9343300, 'LT', '2015-06-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92238, 'Telsiai', 'Telsiai', 'Gorad Cjal''shehj,Tel''she,Tel''shjaj,Telsai,Telsche,Telschen,Telse,Telshay,Telshi,Telshjaj,Telshyay,Telsi,Telsiai,Telsiao,Telsiu,Telsze,Telŝiao,Telšai,Telši,Telšiai,Telšių,Telšē,te er xi ai,telsyai,terushei,tlz,tylshyayy,Τελσιάι,Горад Цяльшэй,Телшяй,Телшјај,Тельше,Тельшяй,טלז,تیلشیائی,ტელშიაი,テルシェイ,特爾希艾,텔샤이', 55.9813900, 22.2472200, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92239, 'Taurage', 'Taurage', 'Gorad Taurage,Taouranke,Taurage,Taurages,Tauragie,Tauragė,Tauragės,Tauraģe,Taurogen,Tauroggen,Taurogi,tao la ge,taulage,taurage,Ταουραγκέ,Горад Таўраге,Таураге,טאורגה,تاؤراگے,ტაურაგე,タウラゲ,陶拉格,타우라게', 55.2522200, 22.2897200, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92240, 'Šventoji', 'Sventoji', 'Schibbe,Shventoji,Shventoy,Shventoyi,Svent,Sventa,Sventoje,Sventoji,Šventoje,Šventoji,Швентойи', 56.0261000, 21.0841100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92090, 'Vieux Fort', 'Vieux Fort', 'Vieux Fort', 13.7166700, -60.9500000, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92091, 'Soufrière', 'Soufriere', '', 13.8561600, -61.0566000, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92092, 'Praslin', 'Praslin', 'Praslin', 13.8754500, -60.8971700, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92093, 'Micoud', 'Micoud', '', 13.8166700, -60.9000000, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92094, 'Laborie', 'Laborie', 'Laborie', 13.7500000, -60.9833300, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92095, 'Gros Islet', 'Gros Islet', 'Gros Ilet,Gros Islet,Gros Islet Village,Nisida Nkros,Νησίδα Γκρος,גרו איסלט', 14.0666700, -60.9500000, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92096, 'Dennery', 'Dennery', '', 13.8995800, -60.8878600, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92097, 'Choiseul', 'Choiseul', 'Choiseuil,Choiseul', 13.7727300, -61.0493100, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92098, 'Castries', 'Castries', 'Castries,Gorad Kastry,Kastri,Kastrijs,Kastris,Kastrizo,Kastrys,Port Castries,ka si te li,kaeseuteuliseu,kasatarisa,kastris,kastrys,kasutorizu,kestrijha,qstryz,Κάστρις,Горад Кастры,Кастри,Кастрийс,Кастрис,Кастрі,קסטריז,كاستريس,کاستریس,कॅस्ट्रीझ,ਕਾਸਤਰੀਸ,காஸ்ட்ரீஸ்,แคสตรีส์,ཁ་སི་ཐྲིས།,კასტრი,ካስትሪስ,カストリーズ,卡斯特里,캐스트리스', 13.9957000, -61.0061400, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92099, 'Canaries', 'Canaries', 'Canaries,Two Friends', 13.9022400, -61.0645900, 'LC', '2013-08-18', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92100, 'Bisée', 'Bisee', '', 14.0242900, -60.9744500, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92101, 'Anse La Raye', 'Anse La Raye', 'Anse La Raye,La Raye', 13.9461900, -61.0387900, 'LC', '2016-11-27', 188);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92113, 'Welisara', 'Welisara', '', 7.0281000, 79.9014000, 'LK', '2006-01-27', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92114, 'Weligama', 'Weligama', 'Weligama', 5.9750100, 80.4296800, 'LK', '2012-11-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92115, 'Wattegama', 'Wattegama', '', 6.7989000, 81.4808000, 'LK', '2006-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92116, 'Wattala', 'Wattala', 'Wattala', 6.9779000, 79.8898000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92117, 'Vavuniya', 'Vavuniya', 'Vavunija,Vavuniya,Vavuniya Town,babuniya,vavuniya,wawwnya,wawwnyya,Вавуния,واوونیا,واوونییا,வவுனியா,වවුනියාව,バブニヤ', 8.7514000, 80.4971000, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92118, 'Valvedditturai', 'Valvedditturai', 'Valvedditturai,Valvettithurai,Valvettiturai', 9.8166700, 80.1666700, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92119, 'Unawatuna', 'Unawatuna', 'Unavatuna,Unawatuna,Унаватуна', 6.0212000, 80.2503000, 'LK', '2013-12-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92120, 'Trincomalee', 'Trincomalee', 'Gorad Trynkamali,TRR,Trikomali,Trikunamalaja,Trincomalee,Trincomali,Trinkomale,Trinkomali,Trinkomalis,Trinquemalay,teulingkomalli,ting ke ma li,tirukkeanamala,tirukkonamalai,torinkomari,trinkomali,trynkwmaly,Горад Трынкамалі,Трикомали,Тринкомале,Тринкомали,Трінкомалі,ترينكومالي,ترینکومالی,त्रिंकोमली,திருக்கோணமலை,തിരുക്കോണമല,ත්‍රිකුණාමලය,ტრინკომალი,トリンコマリー,亭可馬里,亭可马里,트링코말리', 8.5711000, 81.2335000, 'LK', '2012-01-16', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92121, 'Tangalla', 'Tangalla', 'Tangalla,Tangalle,Тангалла', 6.0233800, 80.7973800, 'LK', '2017-07-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92122, 'Talpe', 'Talpe', '', 5.9999000, 80.2787000, 'LK', '2013-12-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92123, 'Talawakele', 'Talawakele', 'Talawakele,Talawakele Town', 6.9371000, 80.6581000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92124, 'Sigiriya', 'Sigiriya', 'GIU,Sigirija,Sigiriya,xi ji li ye,Сигирия,සගරය,සීගිරිය,锡吉里耶', 7.9494600, 80.7503700, 'LK', '2013-11-02', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92125, 'Ratnapura', 'Ratnapura', 'Ratnapur,Ratnapura,Ratnapury,irattinapuri,la te na pu lei,lateunapula,ratn pu ra,ratnabwra,ratnapura,rato~unapura,Ратнапура,Ратнапуры,راتنابورا,رتناپورہ,இரத்தினபுரி,രത്നപുര,රත්නපුර,รัตนปุระ,რატნაპურა,ラトゥナプラ,拉特納普勒,라트나푸라', 6.6827800, 80.3991700, 'LK', '2013-06-28', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92126, 'Puttalam', 'Puttalam', 'Putalao,Putalão,Puttalam,pu ta lei mu qu,puttalam,puttaramu,پوٹالام,புத்தளம்,පුත්තලම,プッタラム,普塔勒姆區', 8.0362000, 79.8283000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92127, 'Polonnaruwa', 'Polonnaruwa', 'Cidade Antiga de Polonnaruva,Gorad Palanaruva,Polonaruva,Polonnaruva,Polonnaruwa,Polonnâruvâ,bo long na lu wo,pealannaruva,polannaruvai,polonanaruva,poron''naruwa,Горад Паланарува,Полоннарува,पोलोननरुवा,பொலன்னறுவை,പൊളന്നറുവ,පොළොනනරව,පොළොන්නරුව,პოლონარუვა,ポロンナルワ,波隆納魯沃', 7.9396500, 81.0027400, 'LK', '2012-11-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92128, 'Point Pedro', 'Point Pedro', 'Point Pedro,Pojnt-Pedro,paruttitturai,Пойнт-Педро,پوائنٹ پیڈرو,பருத்தித்துறை,පේදුරු තුඩුව', 9.8166700, 80.2333300, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92129, 'Pita Kotte', 'Pita Kotte', '', 6.8905000, 79.9015000, 'LK', '2006-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92130, 'Peliyagoda', 'Peliyagoda', 'Peliyagoda', 6.9685000, 79.8836000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92131, 'Panadura', 'Panadura', 'Panadura,Panadure,Pandura', 6.7132000, 79.9026000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92132, 'Nuwara Eliya', 'Nuwara Eliya', 'NUA,Nuvara-Ehlija,Nuvara-Elija,Nuwara Elija,Nuwara Eliya,Nuwari Eliya,nu wo lei ai li ye,nuvareliya,nuwala elliya,nwara alya,nwwara alyya,Нувара-Елія,Нувара-Элия,نوارا إليا,نووارا الییا,நுவரெலியா,නුවරඑළිය,ヌワラ・エリヤ,努沃勒埃利耶,누와라 엘리야', 6.9707800, 80.7828600, 'LK', '2013-09-21', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92133, 'Negombo', 'Negombo', 'Negombas,Negombo,nei gong bo,nigonbo,nirkolumpu,nygwmbw,Негомбо,نیگومبو,நீர்கொழும்பு,මීගමුව,ニゴンボ,內貢博', 7.2083000, 79.8358000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92134, 'Mulleriyawa', 'Mulleriyawa', '', 6.9330000, 79.9297000, 'LK', '2006-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92135, 'Dehiwala-Mount Lavinia', 'Dehiwala-Mount Lavinia', 'Dehivala-Maunt Lavinija,Dehiwala-Mount Lavinia,Dekhivala-Maunt-Lavinija,Mount Lavania,Mount Lavina,Mount Lavinia,Mount Laviniya,dai xi wa lei-mang te la wei ni,tekivalai-kalkicai,Дехивала-Маунт-Лавиния,Дехівала-Маунт-Лавінія,دیہیوالا-ماؤنٹ لاوینیا,தெகிவளை-கல்கிசை,දෙහිවල-ගල්කිස්ස,მაუნტ-ლავინია,デヒワラ・マウントラビニア,代希瓦勒-芒特拉维尼', 6.8401900, 79.8711600, 'LK', '2015-12-13', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92136, 'Moratuwa', 'Moratuwa', 'Moratuva,Moratuwa,mo la tu wa,morato~uwa,morattuvai,mwratwwa,Моратува,موراتووا,மொறட்டுவை,මොරටුව,モラトゥワ,莫拉圖瓦', 6.7730000, 79.8816000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92137, 'Monaragala', 'Monaragala', 'Monaragala,Monaragalla,Moneragala', 6.8714000, 81.3487000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92138, 'Minuwangoda', 'Minuwangoda', 'Minuwangoda', 7.1663000, 79.9533000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92139, 'Mihintale', 'Mihintale', 'Mihintale', 8.3593000, 80.5103000, 'LK', '2016-10-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92140, 'Matara', 'Matara', 'Matara,ma ta la,matara,mattarai,Матара,மாத்தறை,මාතර,მატარა,マータラ,馬塔拉', 5.9485100, 80.5352800, 'LK', '2010-06-15', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92141, 'Maharagama', 'Maharagama', 'Maharagama', 6.8480000, 79.9265000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92142, 'Kurunegala', 'Kurunegala', 'Kornegalle,Kurunegal,Kurunegala,Kurunegald,krnygala,kulunegalla,kurunakal,kurunegara,kwrwnyghala,Курунегала,كورونيغالا,کرنیگالا,குருணாகல்,කරණෑගල නගරය,කුරුණෑගල නගරය,クルネーガラ,쿠루네갈라', 7.4863000, 80.3623000, 'LK', '2012-01-14', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92143, 'Kuliyapitiya', 'Kuliyapitiya', 'Kuliyapitiya', 7.4688000, 80.0401000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92144, 'Sri Jayewardenepura Kotte', 'Sri Jayewardenepura Kotte', 'DWO,Kolompo,Kotte,New Capital Territory,Shri-Dzhajavardenepura-Kotte,Sri Dzajavardenepura,Sri Jayavardhanapura,Sri Jayawardenapura,Sri Jayawardenepura,Sri Jayawardenepura Kotte,Sri Jayewardanapura Kotte,Sri Jayewardanepura,Sri Jayewardanepura Kotte,Sri Jayewardenepura Kotte,kotte,seulijayawaleudanapula,surijayawarudanapurakotte,Šri Džajavardenepura,Κολόμπο,Шри-Джаяварденепура-Котте,கோட்டே,スリジャヤワルダナプラコッテ,스리자야와르다나푸라', 6.8829700, 79.9070800, 'LK', '2015-04-24', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92145, 'Kotikawatta', 'Kotikawatta', 'Kotikawatta', 6.9269000, 79.9095000, 'LK', '2013-04-03', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92146, 'Kolonnawa', 'Kolonnawa', 'Kolonnawa', 6.9329000, 79.8848000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92147, 'Koggala', 'Koggala', 'KCT,Koggala,Коггала', 5.9886000, 80.3286000, 'LK', '2017-07-01', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92148, 'Kilinochchi', 'Kilinochchi', 'Kilinochchi,Killinochchi,ji li nuo qi,kilineacci,kilinocci,kirinotchi,Килиноччи,கிளிநொச்சி,കിളിനൊച്ചി,キリノッチ,基利诺奇', 9.3961000, 80.3982000, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92149, 'Kelaniya', 'Kelaniya', 'Kelanai,Kelaniya', 6.9553000, 79.9220000, 'LK', '2013-04-13', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92150, 'Katunayaka', 'Katunayaka', 'Katunayaka,Katunayaka North,Katunayake', 7.1699200, 79.8883700, 'LK', '2014-08-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92151, 'Kataragama', 'Kataragama', 'Kataragama,Катарагама', 6.4134000, 81.3346000, 'LK', '2017-06-22', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92152, 'Kandy', 'Kandy', 'Gorad Kandy,KDW,Kandi,Kandis,Kandy,Mahanurora,Mahanuvara,Mahanuwara,kaendi,kaindi,kandy,kang ti,kanti,kendi,kndy,kyandi,Горад Канды,Канди,Канді,Կանդի,קאנדי,كاندي,کندی,کینڈی,कॅन्डी,कैंडी,क्यान्डी,ক্যান্ডি,கண்டி,കണ്ടി,මහනවර,මහනුවර,กัณฏิ,კანდი,キャンディ,康提,캔디', 7.2955000, 80.6356000, 'LK', '2012-01-14', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92153, 'Kandana', 'Kandana', 'Kandana', 7.0480000, 79.8937000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92154, 'Kalutara', 'Kalutara', 'KTY,Kalutara,Kalutara South,Калутара', 6.5831000, 79.9593000, 'LK', '2014-02-02', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92155, 'Kalmunai', 'Kalmunai', 'Kalmunai', 7.4090200, 81.8347200, 'LK', '2014-05-03', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92156, 'Kadugannawa', 'Kadugannawa', 'Kadugannawa,Kadugawnawa', 7.2547000, 80.5242000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92157, 'Jaffna', 'Jaffna', 'Dzafn,Dzafna,Dzhafna,Dżafna,Džafn,Džafna,Gorad Dzhafna,JAF,Jaffna,Jaffna Town,gu fu na,jafna,jafuna,japeuna,japhana,japhna,japna,yalppanam,Горад Джафна,Джафна,جافنا,जाफना,ਜਾਫਨਾ,யாழ்ப்பாணம்,జాఫ్నా,ജാഫ്ന,යාපනය,ჯაფნა,ジャフナ,賈夫納,자프나', 9.6684500, 80.0074200, 'LK', '2013-06-28', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92158, 'Ja Ela', 'Ja Ela', '', 7.0744000, 79.8919000, 'LK', '2006-01-27', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92159, 'Horana South', 'Horana South', 'Horana,Horana South', 6.7159000, 80.0626000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92160, 'Homagama', 'Homagama', '', 6.8440000, 80.0024000, 'LK', '2006-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92161, 'Hikkaduwa', 'Hikkaduwa', 'Hikkaduwa,Khikkaduva,Хиккадува', 6.1407000, 80.1012000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92162, 'Hendala', 'Hendala', '', 6.9909000, 79.8830000, 'LK', '2006-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92163, 'Hatton', 'Hatton', 'Hatton,NUF', 6.8916000, 80.5955000, 'LK', '2012-01-19', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92164, 'Haputale', 'Haputale', 'Haputale,Haputale Town', 6.7656600, 80.9510400, 'LK', '2015-04-11', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92165, 'Hanwella Ihala', 'Hanwella Ihala', '', 6.9012000, 80.0852000, 'LK', '2006-01-27', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92166, 'Gampola', 'Gampola', 'Gampola,Gampola Town', 7.1643000, 80.5696000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92167, 'Gampaha', 'Gampaha', 'Gampaha,Qampaha,ganpaha,jia mu po ha,kampaka,گامپاہا,கம்பகா,ගම්පහ,გამპაჰა,ガンパハ,加姆珀哈', 7.0897000, 79.9925000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92168, 'Galle', 'Galle', 'Gale,Galla,Galle,Galė,Gorad Gale,Gálla,gal,gala,gale,gali,galla,galy,ghaly,goru,jia lei,kali,kxll,Гале,Галле,Горад Гале,Ґалле,גאלה,غالي,گال,گالی,गाल,गाली,गाल्ल,গালে,காலி,ഗാലെ,ගාල්ල,กอลล์,გალე,ゴール,加勒,갈', 6.0367000, 80.2170000, 'LK', '2012-01-14', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92169, 'Galkissa', 'Galkissa', '', 6.8293000, 79.8630000, 'LK', '2006-01-27', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92170, 'Eravur Town', 'Eravur Town', 'Ehravure,Eraur,Eravur,Eravur Town,Эравуре', 7.7782000, 81.6038000, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92171, 'Ella Town', 'Ella Town', 'Ehlla,Ella,Ella Town,Элла', 6.8756000, 81.0463000, 'LK', '2017-02-15', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92172, 'Dambulla', 'Dambulla', 'DBU,Dambul,Dambula,Dambulla,Gorad Dambula,dambulla,dan bu lei,danburra,tampullai,Горад Дамбула,Дамбулла,தம்புள்ளை,ദംബുള്ള,දඹුල්ල,ダンブッラ,丹布勒', 7.8600000, 80.6516700, 'LK', '2015-04-11', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92173, 'Colombo', 'Colombo', 'CMB,Colombo,Columbo,Columbum,Gorad Kalomba,Kolombas,Kolombo,Kolompo,Kolonbo,ge lin bao,kalambo,kalombo,ke lun po,kealambea,kholambo,klmbw,kolabo,kolambo,kollombo,kolumpu,kolunbu,koronbo,kwlmbw,kwlwmbw,qwlwmbw,Κολόμπο,Горад Каломба,Коломбо,Կոլոմբո,קולומבו,كولمبو,كولومبو,کلمبو,کولمبو,ކޮޅުނބު,कोलंबो,कोलम्बो,কলম্বো,ਕੋਲੰਬੋ,કોલંબો,କଲୋମ୍ବୋ,கொழும்பு,కొలంబో,ಕೊಲಂಬೊ,കൊളംബോ,කොළඹ,ෙකාළඹ,โคลัมโบ,ཁོ་ལུམ་པོ།,ကိုလံဘိုမြို့,კოლომბო,ኮሎምቦ,コロンボ,可倫坡,哥林堡,콜롬보', 6.9319400, 79.8477800, 'LK', '2007-02-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92174, 'Chilaw', 'Chilaw', 'Chilan,Chilaw,Chilaw Town', 7.5758300, 79.7952800, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92175, 'Beruwala', 'Beruwala', 'Beruwala', 6.4788000, 79.9828000, 'LK', '2012-02-01', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92176, 'Bentota', 'Bentota', 'BJT,Bentota,Бентота', 6.4259800, 79.9957500, 'LK', '2013-04-13', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92177, 'Batticaloa', 'Batticaloa', 'BTC,Batikaloa,Batticaloa,Batticoloa,Battikaloa,Gorad Batykaloa,Madakalapuva,Madakalapuwa,Madakalapuwra,Maddakkalabbu,ba ti ka luo a,battikalova,battikaroa,batykalwa,mattakkalappu,Баттикалоа,Баттікалоа,Горад Батыкалоа,باتيكالوا,باٹیکالوا,बट्टिकलोवा,மட்டக்களப்பு,මඩකලපව නගරය,මඩකලපුව නගරය,ბატიკალოა,バッティカロア,巴提卡洛阿', 7.7102000, 81.6924000, 'LK', '2012-04-05', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92178, 'Battaramulla South', 'Battaramulla South', 'Battaramulla,Battaramulla South', 6.8964000, 79.9181000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92179, 'Badulla', 'Badulla', 'Badull,Badulla,Badully,ba du lei,bado~urra,badula,badulla,badwla,patulai,Бадулла,Бадуллы,بادولا,பதுளை,බදුල්ල,ბადულა,バドゥッラ,巴杜勒,바둘라', 6.9895000, 81.0557000, 'LK', '2013-06-28', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92180, 'Anuradhapura', 'Anuradhapura', 'ACJ,Aneuradhapura,Anuradhapur,Anuradhapura,Anuradhapura Town,Anuradhapuraja,Anuradkhapura,Anurádhapuraja,Anurâdhapura,Anurādhapura,Gorad Anuradkhapura,a nu la de pu lei,a nu la de pu lei wang guo,anuladapula,anuradapura,anuradhapura,anuradhapuram,anuradkhapura,anuratapuram,anwradabwra,xnu rath pu ra,Анурадхапура,Горад Анурадхапура,אנוראדאפורה,أنورادابورا,انورادھاپورہ,अनुराधापुर,अनुराधापुरा,அனுராதபுரம்,അനുരാധപുരം,අනුරාධපුර පෞරාණික නගරය,อนุราธปุระ,ანურადჰაპურა,アヌラーダプラ,阿努拉德普勒,阿努拉德普勒王國,아누라다푸라', 8.3122300, 80.4130600, 'LK', '2013-04-03', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92181, 'Ampara', 'Ampara', 'ADP,Ampara,Amparai,Ampari', 7.2975400, 81.6820200, 'LK', '2012-11-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92182, 'Ambalangoda', 'Ambalangoda', 'Ambalangoda,Ambalangoddi', 6.2355000, 80.0538000, 'LK', '2012-01-17', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92183, 'Horawala Junction', 'Horawala Junction', '', 6.4808800, 80.1270800, 'LK', '2011-06-14', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92184, 'Shanjeev Home', 'Shanjeev Home', '', 7.3821600, 81.8419800, 'LK', '2013-11-08', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92185, 'Padaviya Divisional Secretariat', 'Padaviya Divisional Secretariat', '', 8.8450000, 80.7625000, 'LK', '2014-02-24', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92186, 'Mount Lavinia', 'Mount Lavinia', 'Mount Lavinia', 6.8394700, 79.8645100, 'LK', '2015-12-13', 210);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92477, 'Valmiera', 'Valmiera', 'Gorad Valmiera,Valmeena,Valmeera,Valmeira,Valmera,Valmiera,Valmieras,Valmijera,Valmėira,Vol''mar,Wolmar,balmiela,falmyra,valamira,valmiera,vu~arumiera,wa er mi ye la,walmyra,wlmyrh,Валмиера,Валмијера,Валмієра,Горад Валміера,ולמירה,فالميرا,والمیرا,ਵਾਲਮੀਰਾ,ვალმიერა,ヴァルミエラ,瓦爾米耶拉,발미에라', 57.5410800, 25.4275100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92478, 'Zilupe', 'Zilupe', 'Sinuoja,Sīnuoja,Zilope,Zilopė,Zilupe,Zilupes,Ziluppe,Zilupė,ji lu pei,zylwb,zylwp,Зилупе,Зілупе,زيلوب,زیلوپ,濟盧佩', 56.3861600, 28.1216500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92479, 'Zelmeņi', 'Zelmeni', 'Bites,Sovkhoz Brivays-Tsel''sh,Sovkhoz Brivays-Tsel’sh,Zelmeni,Zelmeņi', 56.4516700, 23.3519400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92480, 'Viļaka', 'Vilaka', 'Vilaka,Viljaka,Vilyaka,Viļaka,Виляка', 57.1845800, 27.6722000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92481, 'Viļāni', 'Vilani', 'Veleny,Vilani,Vilany,Vileni,Viljani,Viljany,Vilyane,Vilyani,Vilyany,Vilēni,Viļāni,Weleny,Виляны', 56.5525300, 26.9244900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92482, 'Viesīte', 'Viesite', 'Eckengrafen,Vesite,Viesite,Viesīte,Viyesite,Виесите', 56.3475100, 25.5551400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92483, 'Vecumnieki', 'Vecumnieki', 'Vecmuiza,Vecmuiža,Vecumnieki,Vetsmuizha,Vetsumneki,Vetsumniyeki,Вецумниеки', 56.6063900, 24.5222200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92484, 'Ventspils', 'Ventspils', 'VNT,Ventspilis,Ventspils,Vindau,Vindava,Wentspils,Windau,Вентспилс', 57.3898800, 21.5728800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92485, 'Vecvārkava', 'Vecvarkava', 'Upmala,Varkava,Varkava II,Vecvarkava,Vecvārkava,Vārkava,Варкава', 56.1983800, 26.5081100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92486, 'Vecpiebalga', 'Vecpiebalga', 'Myza Vetspiebalgas,Vecpiebalga,Vecpiebalgas Muiza,Vecpiebalgas Muiža,Vetspiyebalga', 57.0609000, 25.8162400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92487, 'Varakļāni', 'Varaklani', 'Varaklani,Varakljany,Varaklyany,Varakļāni,Varklyane,Warkland,Warklany,Варакляны', 56.6082600, 26.7537700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92488, 'Vangaži', 'Vangazi', 'Vangazhi,Vangazi,Vangaži,Вангажи', 57.0936100, 24.5486100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92489, 'Valka', 'Valka', 'Gorad Valka,Valga,Valk,Valka,Valkas,Walk,balka,falka,valaka,vu~aruka,wa er ka,walka,Βάλκα,Валка,Горад Валка,فالكا,والکا,ਵਾਲਕਾ,ヴァルカ,瓦爾卡,발카', 57.7752000, 26.0101300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92490, 'Valdemārpils', 'Valdemarpils', '', 57.3706800, 22.5918800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92491, 'Vaiņode', 'Vainode', 'Vain''ody,Vainode,Vainodes,Vain’ody,Vaiņode,Vaiņodes,Vaynede,Vaynëde', 56.4333300, 21.8666700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92492, 'Ulbroka', 'Ulbroka', 'Sarkanmuiza,Sarkanmuiža,Ulbroka,Ulbroke', 56.9363000, 24.3038700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92493, 'Tukums', 'Tukums', 'Tukkum,Tukum,Tukumas,Tukumes,Tukums,Tukumės,to~ukumusu,tu ku mu si,tukumseu,twkwms,twkwmws,Тукумс,توكوموس,توکومس,トゥクムス,圖庫姆斯,투쿰스', 56.9669400, 23.1552800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92494, 'Tīreļi', 'Tireli', 'Kalnciema Muiza,Kalnciema Muiža,Kalnciems,Kalnciems Muiza,Kalnciems Muiža,Kalntsiems,Kalntsiyems,Myza Kalntsiema,Tireli,Tīreļi', 56.8399100, 23.5890200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92495, 'Tērvete', 'Tervete', 'Kalna Muizas Centrs,Kalna Muižas Centrs,Kalnamuiza,Kalnamuiža,Kalnamuyzha,Tervete,Tervetes,Tērvete,Тервете', 56.4798900, 23.3889500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92496, 'Talsi', 'Talsi', 'Talsai,Talse,Talsen,Talsi,Talsy,Talsē,Telsy,ta er xi,talsi,talsy,Талси,Талсі,تالسي,تالسی,塔尔西,탈시', 57.2456200, 22.5813700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92497, 'Strenči', 'Strenci', 'Stackeln,Stakkeln,Strenchi,Strenci,Strencis,Strenči,Стренчи', 57.6257400, 25.6853500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92498, 'Stende', 'Stende', 'Stende,Stendesciems,Стенде', 57.1449700, 22.5348200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92499, 'Stalbe', 'Stalbe', 'Myza Stalbe,Stalbe,Stalbes Muiza,Stalbes Muiža,Сталбе', 57.3706500, 25.0310600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92500, 'Staicele', 'Staicele', 'Staicele,Stajcele,Staytsele,Стайцеле', 57.8363900, 24.7500000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92501, 'Smiltene', 'Smiltene', 'Smilten,Smiltene', 57.4244400, 25.9016400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92502, 'Smārde', 'Smarde', 'Myza Smarde,Smarde,Smardes Muiza,Smārde,Smārdes Muiža,Vecsmardes Pusmuizas Centrs,Vecsmārdes Pusmuižas Centrs,Смарде', 56.9542000, 23.3373600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92503, 'Skrunda', 'Skrunda', 'Skrunda', 56.6833300, 22.0166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92504, 'Skrīveri', 'Skriveri', 'Skriveri,Skrīveri,Скривери', 56.6450000, 25.1205800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92505, 'Sigulda', 'Sigulda', 'Segewold,Segolda,Sigulda,Sėgolda,sigulda,su~iguruda,sygwldh,xi gu er da,Сигулда,Сігулда,סיגולדה,სიგულდა,スィグルダ,錫古爾達,시굴다', 57.1519400, 24.8647200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92506, 'Seda', 'Seda', 'Salanietis,Salanyetys,Seda,Sedaskudra,Sedaskūdra,Tomeni,Tomēni,Седа', 57.6500000, 25.7500000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92507, 'Saulkrasti', 'Saulkrasti', 'Neibade,Neybade,Saulkrastai,Saulkraste,Saulkrasti,Saulkrasty,Saulkrastē,sawlkrasty,shao er ke la si di,Саулкрасти,Саулкрасты,ساولكراستي,ساولکراستی,紹爾克拉斯蒂', 57.2622400, 24.4147100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92508, 'Saldus', 'Saldus', 'Frauenburg,Saldos,Saldus,sa er du si,saladusa,salduseu,saldws,Салдус,سالدوس,ਸਾਲਦੁਸ,薩爾杜斯,살두스', 56.6636300, 22.4880700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92509, 'Salaspils', 'Salaspils', 'Kirchholm,Kirkholm,Salaspeles,Salaspilis,Salaspils,Salaspėlės,sa la si pi er si,sallaseupilseu,Саласпилс,Саласпілс,薩拉斯皮爾斯,살라스필스', 56.8601400, 24.3654400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92510, 'Salacgrīva', 'Salacgriva', 'Salacgriva,Salacgryva,Salacgrīva,Salatsgriva,Salatsi,Salismunde,Salismünde,sa la ci ge li wa,salakghryfa,salakgrywa,Салацгрива,Салацгріва,سالاكغريفا,سالاکگریوا,薩拉茨格里瓦', 57.7536100, 24.3580600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92511, 'Sala', 'Sala', '', 56.5067500, 25.7642300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92512, 'Sabile', 'Sabile', 'Sabile,Zabeln,Сабиле', 57.0457700, 22.5726100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92513, 'Rūjiena', 'Rujiena', 'Aujiena,Ruhja,Ruiena,Ruiyena,Rujen,Rujene,Rujiena,Rujienas,Rujina,Ruyen,Ruyena,Ruyyena,Rūjiena,Rūjienas,Руиена', 57.8975200, 25.3315500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92514, 'Rugāji', 'Rugaji', 'Rugai,Rugaji,Rugaju,Rugayi,Rugāji,Rugāju,Ругаи', 57.0000000, 27.1333300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92515, 'Rucava', 'Rucava', 'Paurupe,Rucava,Rucavas,Rutsava,Ruzau', 56.1631400, 21.1615600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92516, 'Garkalne', 'Garkalne', 'Garkalne,Ropazhi,Ropazi,Ropaži', 57.0448600, 24.4195100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92517, 'Ropaži', 'Ropazi', 'Myza Ropazhi,Myza Ropazhu,Ropazhi,Ropazi,Ropaži,Ропажи', 56.9738900, 24.6336100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92518, 'Roja', 'Roja', 'Roja,Roya,Роя', 57.5014600, 22.8088100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92519, 'Riga', 'Riga', 'Gorad Ryga,RIX,Reiga,Riga,Rigae,Rige,Rigg-a,Rigo,Riia,Riigaa,Riika,Rija,Riqa,Ryga,Ríga,Ríge,Rīga,li jia,liga,ri ka,riga,rika,ryga,rygh,rygha,ryja,Ρίγα,Горад Рыга,Ригæ,Рига,Ріґа,Ռիգա,ריגה,ריגע,رىگا,ريجا,ريغا,ریگا,रिगा,रीगा,রিগা,ரீகா,รีกา,རི་ག,რიგა,ሪጋ,リガ,里加,리가', 56.9460000, 24.1058900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92520, 'Riebiņi', 'Riebini', 'Riebini,Riebiņi', 56.3428000, 26.7999500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92521, 'Rēzekne', 'Rezekne', 'Gorad Rehzehkneh,Rezekne,Rezeknė,Rezhitsa,Rezne,Riezekne,Riezeknė,Rositten,Ryezhitsa,Rzezyca,Rzeżyca,Rēzekne,Rēzne,Rėzeknė,lei ze ke nei,lejekeune,rezekune,ryzkny,rzqnh,Ρέζεκνε,Горад Рэзэкнэ,Резекне,Ռեզեկնե,רזקנה,ريزكني,რეზეკნე,レーゼクネ,雷澤克內,레제크네', 56.5102800, 27.3400000, 'LV', '2017-05-07', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92522, 'Rauna', 'Rauna', 'Rauna,Ronneburg,Рауна', 57.3317300, 25.6094700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92523, 'Ragana', 'Ragana', 'Ragana,Raganas,Рагана', 57.1807400, 24.7073100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92524, 'Priekuļi', 'Priekuli', 'Myza Priekulu,Myza Priyekuli,Priekuli,Priekulu Muiza,Priekuļi,Priekuļu Muiža,Priyekuli,Приекули', 57.3150000, 25.3614700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92525, 'Priekule', 'Priekule', 'Preekuln,Prekule,Prekuln,Priekule,Priyekule,Priyekuli,Приекуле', 56.4467900, 21.5896800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92526, 'Preiļi', 'Preili', 'Gorad Prehjli,Preila,Preili,Preiliai,Preilā,Preiļi,Prejli,Preli,Preyli,Prieli,bryly,peuleilli,pryly,pu lei li,Горад Прэйлі,Прейли,Прейлі,Прејли,بريلي,پریلی,普雷利,프레일리', 56.2944400, 26.7245900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92527, 'Pļaviņas', 'Plavinas', 'Plavinas,Plavinyas,Pljavinjas,Plyavinas,Plyavinyas,Pļaviņas,Плявиняс', 56.6178000, 25.7255200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92528, 'Piņķi', 'Pinki', 'Myza Pintu,Pin''ki,Pin''ti,Pinki,Pin’ti,Piņķi,Saliena,Saliyena,Пиньки', 56.9418900, 23.9136500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92529, 'Piltene', 'Piltene', 'Gorad Piltehneh,Peltene,Pilten,Piltene,Piltenė,Piltyn,Piltyń,Pėltėnė,byltynh,pi er tai nei,pyltnh,Горад Пілтэнэ,Пилтене,Пілтене,بيلتينه,پیلتنه,皮尔泰内', 57.2242600, 21.6743900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92530, 'Pilsrundāle', 'Pilsrundale', 'Pilsrundale,Pilsrundāle', 56.4166700, 24.0000000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92531, 'Pāvilosta', 'Pavilosta', 'Akagals,Paulshafen,Pavilosta,Porvilostu,Pāvilosta,Ākagals', 56.8879100, 21.1859300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92532, 'Ozolnieki', 'Ozolnieki', 'Ozolnieki,Ozolniyeki', 56.6863900, 23.7877800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92533, 'Olaine', 'Olaine', 'Olaine,Olayne', 56.7852800, 23.9380600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92534, 'Ogre', 'Ogre', 'Ogre,Uogre,Uogrė,Огре', 56.8162000, 24.6140100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92535, 'Nīca', 'Nica', 'Nica,Nicas Muiza,Nitsa,Nīca,Nīcas Muiža', 56.3460100, 21.0640100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92536, 'Nereta', 'Nereta', 'Myza Nereta,Nereta,Neretas,Нерета', 56.2027900, 25.3075200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92537, 'Naukšēni', 'Naukseni', 'Myza Nauksheny,Naukseni,Nauksenu Muiza,Nauksheni,Nauksheny,Naukšēni,Naukšēnu Muiža,Nauskuela,Nausküla,Наукшени', 57.8834900, 25.4560900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92538, 'Murmuiža', 'Murmuiza', 'Murmuiza,Murmuiža,Murmujzha,Мурмуйжа', 57.4833300, 25.4833300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92539, 'Mērsrags', 'Mersrags', 'Margraf,Markgrafen,Mererags,Mersrag,Mersragciems,Mersragiems,Mersrags,Mersya,Mērsrags', 57.3353500, 23.1245500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92540, 'Mazsalaca', 'Mazsalaca', 'Mazsalaca,Mazsalace,Mazsalatsa,Mazsalatse,Salisburg', 57.8632900, 25.0547500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92541, 'Matīši', 'Matisi', 'Matishi,Matisi,Matīši,Матиши', 57.6989200, 25.1588600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92542, 'Mālpils', 'Malpils', 'Malpils,Malpils Muiza,Malpils Muiža,Myza Malpil,Myza Malpils,Mālpils', 57.0111100, 24.9630600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92543, 'Madona', 'Madona', 'Madona,Maduona,ma duo na,madona,madwna  ltwny,Мадона,مادونا، لتونی,馬多納,마도나', 56.8532900, 26.2169800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92544, 'Ludza', 'Ludza', 'Gorad Ludza,Loutza,Lucyn,Ludsen,Ludza,Ludze,Lyutsin,lu zha,luja,lwdza,lwdzh,Λούτζα,Горад Лудза,Лудза,לודזה,لودزا,盧扎,루자', 56.5395800, 27.7189100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92545, 'Lubāna', 'Lubana', 'Lubana,Lubāna,Лубана', 56.9000000, 26.7166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92546, 'Loja', 'Loja', 'Loja,Loya', 57.1544400, 24.6444400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92547, 'Līvāni', 'Livani', 'Leivuons,Livane,Livani,Livany,Lyvanai,Līvanē,Līvāni,li wa ni,lyfany,lywany,Ливани,Ливаны,Лівани,ليفاني,لیوانی,利瓦尼', 56.3543100, 26.1757900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92548, 'Limbaži', 'Limbazi', 'Lemsal,Lemzal,Limbaze,Limbazhi,Limbazi,Limbaziai,Limbaži,Limbažiai,Limbažē,limbaji,lin ba ri,lymbajy,lymbazhy,Лимбажи,Лімбажі,ليمباجي,لیمباژی,林巴日,림바지', 57.5128700, 24.7194100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92549, 'Līgatne', 'Ligatne', 'Ligat,Ligatne,Līgatne,Patmale,Лигатне', 57.2342900, 25.0405900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92550, 'Liepāja', 'Liepaja', 'Gorad Liepaja,LPX,Leepaja,Lepaya,Libau,Libava,Liepagia,Liepaiya,Liepaja,Liepaya,Liepoja,Liepāja,Lietaja,Lietaya,Lijepaja,Lipawa,Liyepaya,li ye pa ya,lipaya,liyepaya,lyypʼyh,riepaya,Λιεπάγια,Λιεπαγια,Горад Ліепая,Лиепая,Лијепаја,Лієпая,לייפאיה,लीपाया,ლიეპაია,リエパーヤ,利耶帕亚,리예파야', 56.5166700, 21.0166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92551, 'Lielvārde', 'Lielvarde', 'Lielvarde,Lielvardė,Lielvārde,Liyelvarde,li ye er wa er dai,lielbaleude,lyfardy,lylwardh,ryeruvu~ade,Лиелварде,Лієлварде,ليفاردي,لیلوارده,リェルヴァーデ,利耶爾瓦爾代,리엘바르데', 56.7206600, 24.8074300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92552, 'Lieģi', 'Liegi', 'Liege,Lieges Muiza,Lieges Muiža,Liegi,Lieģi,Myza Liyege', 56.5817300, 21.3339900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92553, 'Kuldīga', 'Kuldiga', 'Goldingen,Gorad Kuldyga,Kuldiga,Kuldigas,Kuldyga,Kuldīga,Kuldīgas,ku er di jia,kuladiga,kuldiga,kurudiga,kwldyga,kwldygha,Горад Кулдыга,Кулдига,Кулдіга,كولديغا,کولدیگا,ਕੁਲਡਿਗਾ,კულდიგა,クルディーガ,库尔迪加,쿨디가', 56.9739900, 21.9572100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92554, 'Krustpils', 'Krustpils', 'Kreutzburg,Krustpilis,Krustpils,Krystapils,Krystapiļs,Kryzborg,Kryżborg,Крустпилс,Крустпілс', 56.5106800, 25.8611700, 'LV', '2015-11-03', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92555, 'Krāslava', 'Kraslava', 'Gorad Kraslava,Kraaslava,Kraslava,Kraslaw,Krasław,Kreslavka,Kreslawka,Kruoslova,Krāslava,karasalava,ke la si la wa,keulaseullaba,kraslafa,kraslawa,Горад Краслава,Краслава,كراسلافا,کراسلاوا,ਕਰਾਸਲਾਵਾ,克拉斯拉瓦,크라슬라바', 55.8951400, 27.1679900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92556, 'Koknese', 'Koknese', 'Koaknese,Kokenhusen,Kokenhuza,Koknese,Kokneses Muiza,Kokneses Muiža,Kukenojs,Кокнесе,Кукенойс', 56.6500000, 25.4333300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92557, 'Kocēni', 'Koceni', 'Koceni,Koceny,Kociena,Kocēni,Kokmuiza,Kokmuiža,Kokmuyzha,Myza Kok,Коцены', 57.5205700, 25.3382100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92558, 'Ķekava', 'Kekava', 'Kekava,Liel Kekava,Liel Ķekava,Tekava,Ķekava,Кекава', 56.8266200, 24.2300000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92559, 'Ķegums', 'Kegums', 'Gorad Kegums,Keggum,Keggums,Kegumas,Kegums,Kiegumos,kai gu mu si,kghwms,kgwms,Ķegums,Горад Кегумс,Кегумс,كغومس,کگومس,凱古姆斯', 56.7451000, 24.7243900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92560, 'Kārsava', 'Karsava', 'Karsava,Korsovka,Korsowka,Kārsava,Карсава', 56.7840500, 27.6882900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92561, 'Karosta', 'Karosta', 'Kara Osta,Karaosta,Karosta,Karya Osta,Port Aleksandra III,Кароста,Порт Александра III', 56.5500000, 21.0166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92562, 'Kandava', 'Kandava', 'Kandau,Kandava,Кандава', 57.0408700, 22.7746600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92563, 'Jūrmala', 'Jurmala', 'Jurmala,Jūrmala,Riga Beach,Riga-Strand,Rigas Iurmala,Rigas Jormalas Pilseta,Rigas Jurmala,Rigas Yurmala,Rigastrand,Rizhskoye Vzmor''ye,Rīgas Jormalas Pilsēta,Rīgas Jūrmala,Yuomala,Yurmala,Юрмала', 56.9680000, 23.7703800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92564, 'Jumprava', 'Jumprava', 'Jumprava,Yumprava', 56.6761300, 24.9721000, 'LV', '2010-10-27', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92565, 'Jelgava', 'Jelgava', 'Elgava,Iyelgava,Jelgava,Jelgawa,Mitau,Mitava,Mitawa,Yelgava,Елгава,Елґава', 56.6500000, 23.7127800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92566, 'Jēkabpils', 'Jekabpils', 'Ekabpils,Jakobstadt,Jakubmists,Jekabpeles,Jekabpilis,Jekabpils,Jiekabpelis,Jiekabpėlis,Jākubmīsts,Jēkabpils,Jėkabpilis,Jėkabpėlės,i~ekabupirusu,jikabapilasa,jykabbyls,ye ka bu pi er si,yekabpilseu,ykabpyls,yqbpyls,Єкабпілс,Јекабпилс,Екабпилс,Екабпілс,Йекабпилс,יקבפילס,جيكاببيلس,یکابپیلس,ਜੀਕਾਬਪਿਲਸ,იეკაბპილსი,イェーカブピルス,葉卡布皮爾斯,예캅필스', 56.4990300, 25.8573500, 'LV', '2015-10-25', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92567, 'Jaunpils', 'Jaunpils', 'Jaunpils,Jaunpils Muiza,Jaunpils Muiža,Yaunpils,Яунпилс', 56.7325000, 23.0136100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92568, 'Jaunpiebalga', 'Jaunpiebalga', 'Jaun Piebalga Muizas Centrs,Jaun Piebalga Muižas Centrs,Jaunpiebalga,Jaunpiebalgas Muiza,Jaunpiebalgas Muiža,Myza Yaunpiebalga,Yaunpiebalga,Yaunpiyebalga', 57.1833300, 26.0500000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92569, 'Jaunjelgava', 'Jaunjelgava', 'Friedrichstadt,Gorad Jaunelgava,Jaunelgava,Jaunjelgava,Yaun-Yelgava,Yaunelgava,jawnylghafa,xin ye er jia wa,yawnylgawa,yawnyylgawa,Горад Яўнелгава,Яунелгава,Яунєлгава,جاونيلغافا,یاونیئلگاوا,یاونیلگاوا,新葉爾加瓦', 56.6131900, 25.0831600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92570, 'Jaunciems', 'Jaunciems', 'Jaunciems,Yauntsiyems,Яунциемс', 57.0391000, 24.1741300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92571, 'Jaunaglona', 'Jaunaglona', 'Jaunaglona,Яунаглона', 56.1606600, 27.0071400, 'LV', '2013-08-07', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92572, 'Inčukalns', 'Incukalns', 'Inchukaln,Inchukalns,Incukalns,Inčukalns,Инчукалнс', 57.0980600, 24.6863900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92573, 'Ilūkste', 'Ilukste', 'Aluksta,Alūksta,Ilukste,Ilukszta,Ilūkste,Iłukszta,aylwkst,yi lu ke si tai,Īlūkstė,Ілуксте,Илуксте,إيلوكست,الوکستے,ایلوکست,伊盧克斯泰', 55.9775400, 26.2965500, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92574, 'Ikšķile', 'Ikskile', 'Ikshkile,Ikshtile,Ikskile,Ikškilė,Ikšķile,Ykskylae,Ykskylä,Икшкиле', 56.8333300, 24.5000000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92575, 'Iecava', 'Iecava', 'Eckau,Iecava,Iyetsava,Иецава', 56.5986100, 24.2022200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92576, 'Gulbene', 'Gulbene', 'Alt-Schwaneburg,Golbene,Golbėnė,Gorad Gulbehneh,Gulbene,Gulbenė,ghwlbyn,gu er bei nei,gulbene,gwlbn,Горад Гулбэнэ,Гулбене,غولبين,گولبن,گولبینے,გულბენე,古爾貝內,굴베네', 57.1776700, 26.7529100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92577, 'Grobiņa', 'Grobina', 'Gerobin,Grobin,Grobina,Grobinya,Grobiņa', 56.5352100, 21.1678200, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92578, 'Cibla', 'Cibla', 'Cibla,Eversmuiza,Eversmuiža,Tsibla,Цибла', 56.5498000, 27.8837000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92579, 'Ērgļi', 'Ergli', 'Ehrgli,Ergli,Ergli Bijusas Muizas Centrs,Erglu Muiza,Myza Ergli,Ērgļi,Ērgļi Bijušās Muižas Centrs,Ērgļu Muiža,Эргли', 56.8975200, 25.6366800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92580, 'Engure', 'Engure', 'Anger,Engurciems,Engure', 57.1606100, 23.2252700, 'LV', '2010-12-04', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92581, 'Dundaga', 'Dundaga', 'Dundaga,Dundagas', 57.5049800, 22.3504100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92582, 'Drabeši', 'Drabesi', 'Drabeshi,Drabesi,Drabesu Muiza,Drabeši,Drabešu Muiža,Myza Drabeshi,Myza Drabeshu', 57.2431600, 25.2774800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92583, 'Dobele', 'Dobele', 'Dobele,Doblen,Doubele,Doubelė,Duobele,Duobelė,dobelle,duo bei lai,dwbl,dwbl  ltwny,dwblh,Добеле,דובלה,دوبل,دوبل، لتونی,دوبیلے,多貝萊,도벨레', 56.6250000, 23.2786100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92584, 'Daugavpils', 'Daugavpils', 'Borisoglebsk,DGP,Daugavpils,Daugawpils,Daugpelis,Daugpilis,Daugpils,Daugpiļs,Daugpėlis,Duenaburg,Duneburgum,Dvinsk,Dwinsk,Dyneburg,Dzwinow,Dünaburg,Dźwinów,Gorad Daugaupils,Nevgin,Ntaounkavpils,Vaeinaenlinna,Vaeinalinn,Väinalinn,Väinänlinna,daugafupirusu,daugapeupilseu,daugaupilsa,dawghafbyls,dwgapyls,tao ge fu pi er si,Ντάουγκαβπιλς,Νταουγκάβπιλς,Борисоглебск,Горад Даўгаўпілс,Даугавпилс,Даугавпілс,Дауґавпілс,Невгин,דאוגבפילס,דענענבורג,داوغافبيلس,دوگاپیلس,दौगौपिल्स,დაუგავპილსი,ダウガフピルス,陶格夫匹尔斯,다우가프필스,', 55.8833300, 26.5333300, 'LV', '2016-07-23', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92585, 'Daugavgrīva', 'Daugavgriva', 'Daugavgriva,Daugavgrīva,Dinamjunde,Duenamuende,Dynemunt,Dünamünde,Ust''-Dvinsk,Даугавгрива,Динамюнде,Усть-Двинск', 57.0431500, 24.0361300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92586, 'Dagda', 'Dagda', 'Dagda,Дагда', 56.0951200, 27.5372300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92587, 'Cesvaine', 'Cesvaine', 'Cesvaine,Cesvaines Muiza,Cesvaines Muiža,Cesvajne,Tsesvayne,Цесвайне', 56.9666700, 26.3166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92588, 'Cēsis', 'Cesis', 'Cesis,Cesys,Ciesis,Cēsis,Cėsys,Kies,Kieś,Tsesis,Venden,Wenden,cai xi si,chesiseu,chyss,ssys,tsu~eshisu,zsys,Цесис,Цесіс,צסיס,سسيس,سسیس,چیسس,ツェーシス,采西斯,체시스', 57.3118800, 25.2745600, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92589, 'Carnikava', 'Carnikava', 'Carnikava,Carnikavas Muiza,Carnikavas Muiža,Tsarnikava,Царникава', 57.1293500, 24.2842300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92590, 'Brocēni', 'Broceni', 'Broceni,Brocenu Muiza,Brocēni,Brocēnu Muiža,Brotseny,Myza Brotseny', 56.7000000, 22.5333300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92591, 'Bolderaja', 'Bolderaja', 'Bol''deraa,Bolderaa,Bolderaj,Bolderaja,Bolderāja,Болдерай,Болдерая,Больдераа', 57.0313200, 24.0557100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92592, 'Berģi', 'Bergi', 'Bergi,Berģi,Juglasciems', 56.9863900, 24.2991700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92593, 'Bauska', 'Bauska', 'Baouska,Bauska,Bauske,Bauskė,Bosko,Gorad Bauska,bao si ka,basaka,bausaka,bauseuka,bawska,Μπάουσκα,Бауска,Горад Баўска,באוסקה,باساكا,باوسکا,ਬੌਸਕਾ,ბაუსკა,包斯卡,바우스카', 56.4079400, 24.1944300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92594, 'Balvi', 'Balvi', 'Balvai,Balve,Balvi,Balvy,Balvē,Bolowsk,Bolvi,Gorad Balvi,ba er wei,balbi,balfy,balwy,balwy  ltwny,blby,Μπάλβι,Балви,Балві,Горад Балві,בלבי,بالفي,بالوی,بالوی، لتونی,巴爾維,발비', 57.1313000, 27.2658300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92595, 'Baltinava', 'Baltinava', 'Baltinava,Baltinova,Балтинава', 56.9439400, 27.6440100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92596, 'Baldone', 'Baldone', 'Baldone', 56.7427800, 24.3944400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92597, 'Auce', 'Auce', 'Auce,Aucė,Autse,Autz', 56.4598100, 22.9016900, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92598, 'Ape', 'Ape', 'Ape,Ope,Апе', 57.5392800, 26.6929100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92599, 'Alūksne', 'Aluksne', 'Alksne,Alouksne,Aluksne,Alūksne,Alūksnė,Gorad Aluksneh,Marienburg,a lu ke si nei,allugseune,alukasana,aluksne,alwksnh,alwksny,Άλουκσνε,Алуксне,Горад Алукснэ,אלוקסנה,آلوكسني,آلوکسنه,آلوکسنے,ਅਲੁਕਸਨ,ალუქსნე,阿盧克斯內,알룩스네', 57.4216200, 27.0466200, 'LV', '2017-01-04', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92600, 'Alsunga', 'Alsunga', 'Alshvanga,Alsung,Alsunga,Alsvanga,Alšvanga,Алсунга', 56.9819400, 21.5593800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92601, 'Aloja', 'Aloja', 'Aloja,Alojas Muiza,Alojas Muiža,Aloya,Aluoja,Aluoje,Aluojė,Gorad Aloja,Myza Aloya,a luo ya,aloia,alwya,alwya  ltwny,Алоя,Горад Алоя,آلويا,آلویا، لتونی,آلویا، لٹویا,ალოია,阿洛亞', 57.7669400, 24.8825000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92602, 'Aknīste', 'Akniste', 'Akniste,Aknīste,Акнисте', 56.1615200, 25.7478300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92603, 'Aizpute', 'Aizpute', 'Aispute,Aizpute,Aizputė,Ayzpute,Gazenpot,Hazenpot', 56.7166700, 21.6000000, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92604, 'Aizkraukle', 'Aizkraukle', 'Aizkraukle,Aizkraukles Muiza,Aizkraukles Muiža,Aizkrauklė,Ajzkraukle,Ayzkraukle,Gorad Ajzkraukleh,ai zi ke lao ke lei,aiseukeulaukeulle,ayzakrawkl,ayzkrawkl,ejakaraukala,Айзкраукле,Ајзкраукле,Горад Айзкраўклэ,אייזקראוקלה,آئزکراوکلے,آيزاكراوكل,آیزکراوکل,ਏਜਕਰੌਕਲ,აიზკრაუკლე,愛茲克勞克雷,아이스크라우클레', 56.6047700, 25.2553400, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92605, 'Ainaži', 'Ainazi', 'Ainaze,Ainazi,Ainaziai,Ainaži,Ainažiai,Ainažē,Ajnazhi,Amazi,Aynazhi,Gainash,Gorad Ajnazhy,Hainasch,Heinaste,ai na ri,ainaji,ainazhi,aynajy,aynazhy,Айнажи,Айнажі,Горад Айнажы,آيناجي,آیناژی,აინაჟი,アイナジ,艾納日,아이나지', 57.8636100, 24.3577800, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92606, 'Aglona', 'Aglona', 'Aglona,Aglonas Muiza,Aglonas Muiža,Agluna,Myza Agluna,Аглона', 56.1333300, 27.0166700, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92607, 'Ādaži', 'Adazi', 'Adazhi,Adazi,Ādaži', 57.0704500, 24.3371300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92608, 'Baloži', 'Balozi', 'Balozhi,Balozi,Baloži,Баложи', 56.8761100, 24.1186100, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92609, 'Mārupe', 'Marupe', '', 56.9054400, 24.0511300, 'LV', '2016-12-02', 123);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92610, 'Bardīyah', 'Bardiyah', 'Al Bardiyah,Al Bardīyah,Bardia,Bardiyah,Bardīyah,Bordi Sleman,Bórdi Slemán,Petras Maior,brdyt,بردية', 31.7561500, 25.0865300, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92611, 'Tobruk', 'Tobruk', 'Antipyrgos,Antipyrgus,Gorad Tabruk,TOB,Thubruq,Tobroek,Tobrouk,Tobruch,Tobruck,Tobruk,Tobrúk,Tomprouk,Tubruk,Tubrukas,Tubruq,Tóbruch,tbrq,tobruka,toburuku,tu bo lu ge,tubeulukeu,tupruk,twbrwq,Ţubruq,Τομπρούκ,Горад Табрук,Тобрук,טוברוק,طبرق,टोब्रुक,துப்ருக்,ტობრუკი,トブルク,图卜鲁格,투브루크', 32.0836100, 23.9763900, 'LY', '2012-09-05', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92612, 'Sulūq', 'Suluq', 'Qaryat Salug,Qaryat Saluq,Qaryat Salūg,Qaryat Salūq,Soluch,Solugh,Solùgh,Suluq,Sulūq,slwq,سلوق', 31.6681800, 20.2520500, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92613, 'Gialo', 'Gialo', 'Gialo,Jalu,Jālū', 29.0333300, 21.5500000, 'LY', '2012-01-16', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92614, 'Darnah', 'Darnah', 'DNF,Daernae,Darnah,Darnis,Derna,Därnä,Dérna,drnh,drnt,דרנה,درنة', 32.7670400, 22.6366900, 'LY', '2017-02-10', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92615, 'Benghazi', 'Benghazi', 'BEN,Baengasi,Banghazi,Banghāzī,Bengasi,Bengaze,Bengazi,Bengazis,Bengazy,Benghasi,Benghazi,Benghází,Bengázi,Bengāzī,Benqazi,Berenice,Bingazi,Binghazi,Binghāzī,Bängasi,Bèngasi,Gorad Bengazi,Hesperides,Vilojati Bengazi,ban jia xi,banagazi,ben ka si,benagajhi,beng-gaji,bengaji,benghazi,bnghazy,pankaci,Βεγγάζη,Бенгази,Бенгазі,Вилояти Бенғази,Горад Бенгазі,Բենղազի,בנגאזי,بنغازى,بنغازي,بنغازی,बेनगाझी,ਬਨਗ਼ਾਜ਼ੀ,பங்காசி,เบนกาซี,ბენღაზი,ベンガジ,班加西,벵가지', 32.1148600, 20.0685900, 'LY', '2014-01-01', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92616, 'Az Zuwaytīnah', 'Az Zuwaytinah', 'Az Zuwaytinah,Az Zuwaytīnah,Ez Zuetina,Ez Zuetína,Marsa Uasili,Qaryat az Zuwaytinah,Qaryat az Zuwaytīnah,Zueitina,Zuetina,Zweytinah,alzwytynt,الزويتينة', 30.9522000, 20.1202200, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92617, 'Awjilah', 'Awjilah', 'Augila,Awjilah,Wajilah,awjlt,أوجلة', 29.1080600, 21.2869400, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92618, 'At Tāj', 'At Taj', 'At Taj,At Tāj,Et Tag', 24.2048700, 23.2857000, 'LY', '2012-10-19', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92619, 'Tūkrah', 'Tukrah', 'Al `Aquriyah,Al ‘Āqūrīyah,Taukra,Teuchira,Tocra,Tokrah,Tukrah,Tūkrah,twkrt,توكرة', 32.5341400, 20.5791100, 'LY', '2012-12-05', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92620, 'Al Qubbah', 'Al Qubbah', 'Al Gubbah,Al Qubbah,Berta,El-Gubba,El-Gúbba,Giovanni Berta,Gubba,alqbt,القبة', 32.7616300, 22.2423700, 'LY', '2014-01-20', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92621, 'Al Marj', 'Al Marj', 'Al Marj,Al''-Mardzh,El Merj,Maerciaen,Märciän,almrj,Аль-Мардж,المرج,شعبية المرج', 32.4879800, 20.8317400, 'LY', '2012-01-16', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92622, 'Al Jawf', 'Al Jawf', 'AKF,Al Gawf,Al Jawf,Al Ğawf,Al-Jof,Ehl''-Dzhauf,El Giof,aljaupeu,aljwf,jaufu,jiao fu,Эль-Джауф,الجوف,ジャウフ,焦夫,알자우프', 24.1989000, 23.2909300, 'LY', '2014-01-01', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92623, 'Al Jaghbūb', 'Al Jaghbub', 'Al Jaghbub,Al Jaghbūb,El-Giagbub,El-Giagbúb,Giarabub,Jaghbub,Jaghbūb', 29.7426200, 24.5167600, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92624, 'Al Bayḑā’', 'Al Bayda''', 'Al Bayda'',Al Bayḑā’,Al-Baida,Az Zawiyah al Bayda'',Az Zāwiyah al Bayḑā’,Baida,Balagrae,Balis,Bayda,Beda,Beida,El Beida,LAQ,White Monastery,Zauia el Beda,Zawiat al-Baida,Zawiyat al Bayda'',Zawiyat el-Beda'',Zāwiyat al Bayḑā’,Zāwiyat el-Bēḑā’,البيضاء', 32.7627200, 21.7550600, 'LY', '2017-02-09', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92625, 'Al Abyār', 'Al Abyar', 'Alabia,El Abiar,Madirat al Abyar,Madīrat al Abyār,alabyar‎,الأبيار‎', 32.1900000, 20.5965300, 'LY', '2013-10-29', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92626, 'Ajdabiya', 'Ajdabiya', 'AEcdabiya,Adjadabia,Adschdabiya,Adzdabija,Adzedabija,Adzhdabija,Adzsdabija,Adzsdábija,Adżdabija,Adždabija,Adžedábíja,Agdabija,Agedabia,Ajdabiya,Ajdabiyah,Ajdābiyah,Ajdābiyā,Aĝdabija,Corniclanum,Ecdebiye,Gorad Adzhdabija,Laecdabiaen,Läcdabiän,QGG,ai ji da bi ye,ajdabia,ajdabya,ajidabiya,ajudabiya,Äcdabiya,Адждабия,Адждабія,Аџдабија,Горад Адждабія,אגדאביא,أجدابيا,اجدابیا,شعبية إجدابيا,აჯდაბია,アジュダービヤー,艾季达比耶,아지다비야', 30.7554500, 20.2262500, 'LY', '2013-05-11', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92627, 'Zuwārah', 'Zuwarah', 'WAX,Zuara,Zuava,Zuwarah,Zuwārah,Zuára,Zuáva,zuart,Зуара,زُوارة', 32.9312000, 12.0819900, 'LY', '2016-12-27', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92628, 'Zliten', 'Zliten', 'Isliten,Islīten,Izliten,Izlīten,QZL,Subgoli,Zalitan,Ziliten,Zlitan,Zliten,Zlitenas,Zlitán,Zlītan,ci li tan,jeulliten,zlytn,zuriten,Злитен,Злітен,زليتن,زلیتن,ზლიტენი,ズリテン,兹利坦,즐리텐', 32.4673900, 14.5687400, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92629, 'Zalţan', 'Zaltan', 'Zaltan,Zalţan,Zelten,zltn,زلطن', 32.9470100, 11.8664700, 'LY', '2013-10-30', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92630, 'Yafran', 'Yafran', 'Gasr Iefren,Iefren,Jafran,Jefren,Yaefraeniaen,Yafran,Yafrin,Yäfräniän,Яфран,شعبية يفرن', 32.0632900, 12.5285900, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92631, 'Waddān', 'Waddan', 'Uaddan,Waddan,Waddān,wdan,ودان', 29.1614000, 16.1390400, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92632, 'Tarhuna', 'Tarhuna', 'El-Buerat,El-Buerát,El-Ubberat,El-Ubberát,Gasr Tarhuna,Qasr Tarhunah,Qaşr Tarhūnah,Tarhuna,Tarhunah,Tarhūnah,Tarkhuny,Тархуны', 32.4350100, 13.6332000, 'LY', '2011-09-26', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92633, 'Tripoli', 'Tripoli', 'Aea,Ea,Gorad Trypali,Oea,TIP,Tarables,Tarabulus,Tarabulus al Gharb,Tarabulus el Gharb,Taràbles,Trables,Trablus,Trablûs,Triboli,Tripili,Tripilí,Tripol,Tripole,Tripoli,Tripolis,Tripolo,Tripoly,Tripołi,Tripul,Tripuli,Trypolis,Trìpoli,Trìpuli,Trípol,Trípoli,Trípólí,de li bo li,tarabalasa,tarabulasa,tarabulus,teulipolli,tirippoli,toripori,trabls,trabls  lybya,tripoli,trippeali,trypwly,Ţarābulus,Ţarābulus al Gharb,Τρίπολη,Горад Трыпалі,Триполи,Триполі,Տրիպոլի,טריפאלי,טריפולי,ترابلس,ترىپولى,تەرابلوس,طرابلس,طرابلس، لیبیا,طَرَابُلُس,ताराबूलस,त्रिपोली,ত্রিপোলি,ਤਰਾਬਲਸ,திரிப்பொலி,ട്രിപ്പോളി,ตริโปลี,ཐི་རི་ཕོ་ལི,ტრიპოლი,ትሪፖሊ,Ṭrables,トリポリ,的黎波里,트리폴리', 32.8751900, 13.1874600, 'LY', '2011-11-27', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92634, 'Tagiura', 'Tagiura', 'Tagiura,Tajura'',Tajurah,Tājūrāh,Tājūrā’', 32.8816700, 13.3505600, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92635, 'Sirte', 'Sirte', 'Gasr Zaafran,Gasr Zaafrán,Gorad Sirt,Macomades-Euphranta,Qasr Sirt,Qasr Za`faran,Qaşr Sirt,Qaşr Za‘farān,SRX,Sert,Sirt,Sirta,Sirte,Sirto,Surt,Surtaen,Surtas,Surtiaen,Surtiän,Surtän,Syrta,Syrte,Syrti,Szurt,Vilojati Surt,sileute,sirta,srt,su er te,su te,surti,suruto,syrt,Σύρτη,Вилояти Сурт,Горад Сірт,Сирт,Сурт,סירת,سرت,شعبية سرت,सिर्त,სურთი,スルト,苏尔特,蘇爾特,蘇特,시르테', 31.2089200, 16.5886600, 'LY', '2014-05-29', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92636, 'Şurmān', 'Surman', 'Sorman,Sormán,Surman,Şurmān', 32.7566800, 12.5715900, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92637, 'Şabrātah', 'Sabratah', 'Madinat Sabratah,Madīnat Şabrātah,Sabra,Sabrah,Sabratah,Sabratha,Sábra,sbratt,Şabrah,Şabrātah,صبراتة', 32.7933500, 12.4884500, 'LY', '2012-12-05', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92638, 'Sabhā', 'Sabha', 'El-Gedid,El-Gedíd,Fort Leclerc,SEB,Sabha,Sabhah,Sabhā,Saebha,Saebhiaen,Sebha,Sebhah,Säbha,Säbhiän,sabha,sai bo ha,sbha,sbht,سبها,سبهة,سَبها,شعبية سبها,塞卜哈', 27.0376600, 14.4283200, 'LY', '2017-01-08', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92639, 'Nālūt', 'Nalut', 'Lalut,Lalút,Nalut,Nālūt,nalwt,نالوت', 31.8684800, 10.9812000, 'LY', '2012-01-16', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92640, 'Murzuq', 'Murzuq', 'Marzuq,Marzūq,Mourzouk,Mursuk,Murzuch,Murzuk,Murzuq,QMQ,mrzq,Мурзук,مرزق', 25.9155200, 13.9183900, 'LY', '2014-04-26', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92641, 'Mizdah', 'Mizdah', 'Misdah,Mizda,Mizdah,mzdt,مزدة', 31.4451400, 12.9801300, 'LY', '2013-10-29', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92642, 'Mişrātah', 'Misratah', 'Al Misratah,MRA,Madinat Misratah,Madīnat Mişrātah,Misrata,Misratah,Misurata,Mişrātah,msrath,msratt,myswrth,Мисурата,מיסורטה,مصراتة,مصراته', 32.3753500, 15.0925400, 'LY', '2013-04-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92643, 'Masallātah', 'Masallatah', '', 32.6166700, 14.0000000, 'LY', '2013-11-08', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92644, 'Al Burayqah', 'Al Burayqah', 'Al Burayqah,El-Brega,LMQ,Marsa Brega,Marsa Bregha,Marsa al Burayqah,Marsa el Brega,Marsá al Burayqah,Port Brega,Qasr al Buraygah,Qasr al Burayqah,Qaşr al Burayqah,albryqt,mrsy albryqt,qsr albryqt,البريقة,قصر البريقة,مرسى البريقة', 30.4062400, 19.5738600, 'LY', '2017-02-10', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92645, 'Marādah', 'Maradah', 'Marada,Maradah,Marādah,mradt,مرادة', 29.2333300, 19.2166700, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92646, 'Giado', 'Giado', 'Giado,Jadu,Jādū', 31.9581500, 12.0203300, 'LY', '2012-01-16', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92647, 'Hūn', 'Hun', 'HUQ,Hon,Hun,Hūn,Madinat Hun,Madīnat Hūn,hwn,هون', 29.1268400, 15.9477200, 'LY', '2017-02-10', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92648, 'Zawiya', 'Zawiya', 'Al Harah,Al Ḩārah,El-Hara,El-Hára,Haraf Az Zawiyah,Haraf Az Zāwīyah,Harat az Zawiyah,Zawiya,Ḩārat az Zāwiyah', 32.7522200, 12.7277800, 'LY', '2011-09-26', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92649, 'Ghat', 'Ghat', 'GHT,Gat,Ghat,Ghāt,Rhat,ghat,Гат,غات', 24.9633400, 10.1800300, 'LY', '2015-09-26', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92650, 'Gharyan', 'Gharyan', 'Garian,Gasr Garian,Gasr Gariàn,Gharyan,Gharyān,QGH,ghryan,غريان', 32.1722200, 13.0202800, 'LY', '2013-05-11', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92651, 'Ghadāmis', 'Ghadamis', 'Gadames,Gadamis,Gadamés,Ghadames,Ghadamis,Ghadāmis,Ghudamis,Ghudāmis,LTD,Rhadames,ghdams,Гадамес,غدامس', 30.1336600, 9.5007200, 'LY', '2017-02-09', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92652, 'Brak', 'Brak', 'BCQ,Birak,Birāk,Brach,Brak,bi la ke,bilakeu,brak,براك,比拉克,비라크', 27.5495600, 14.2713900, 'LY', '2014-01-01', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92653, 'Bani Walid', 'Bani Walid', 'Baeni Vaelid,Bani Ualid,Bani Valid,Bani Validas,Bani Valíd,Bani Walid,Baní Walíd,Banī Walīd,Beni Ulid,Beni Valid,Beni-Valid,Beniulid,Bäni Välid,Gasr Beni Ulid,Gasr Béni Ulíd,Gorad Beni-Valid,QBL,Qasr Bani Walid,Qaşr Banī Walīd,bai ni wo li de,bani-validi,baniwallideu,baniwarido,bny wlyd,bny‌wlyd,qsr bny wlyd,Бани Валид,Бани Уалид,Бени-Валид,Бені-Валід,Горад Бені-Валід,بني وليد,بنی ولید,بنی‌ولید,قصر بني وليد,ბანი-ვალიდი,バニワリード,拜尼沃利德,바니왈리드', 31.7455400, 13.9835400, 'LY', '2016-02-28', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92654, 'Zintan', 'Zintan', 'As-Sintan,Az Zintan,Az Zintān,Ehz-Zintan,Ez-Zintan,Ez-Zintán,ZIS,Zentan,Zintan,alzntan  lyby,alzntan‎,Эз-Зинтан,الزنتان، لیبی,الزنتان‎', 31.9315500, 12.2529100, 'LY', '2016-04-15', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92655, 'Az Zāwīyah', 'Az Zawiyah', 'Az Zawiyah,Az Zawiyah al Gherbiyah,Az Zāwiyah al Gherbīyah,Az Zāwīyah,Ez Zauia,Zauia,Zavia,Zawia,alzawyt,الزاوية', 32.7571000, 12.7276400, 'LY', '2013-08-09', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92656, 'Awbārī', 'Awbari', 'Awbari,Awbārī,QUB,Ubari,awbary,أوباري', 26.5920600, 12.7804900, 'LY', '2017-02-10', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92657, 'Al Qaţrūn', 'Al Qatrun', 'Al Gatrun,Al Katrun,Al Qatrun,Al Qaţrūn,El Gatrun,alqtrwn,القطرون', 24.9513900, 14.6486100, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92658, 'Al Khums', 'Al Khums', 'Al Hums,Al Khums,Al Ĥums,Al-Chums,Al-Khums,El Choms,Gorad Al''-Khums,Homs,Humsas,Khoms,Khums,Kums,Labdah,Lebda,alkhms,alkhms  lyby,alkhums,el-khumsi,fumusu,hu mu si,humseu,khms  lybya,Горад Аль-Хумс,Хомс,Хумс,אל-חומס,الخمس,الخمس، لیبی,الخُمس,خمس، لیبیا,ელ-ხუმსი,フムス,胡姆斯,훔스', 32.6486100, 14.2619100, 'LY', '2012-01-16', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92659, 'Al Jadīd', 'Al Jadid', 'Al Jadid,Al Jadīd,Al''-Dzhadid,El-Gedid,El-Gedíd,Аль-Джадид', 27.0500000, 14.4000000, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92660, 'Al ‘Azīzīyah', 'Al ''Aziziyah', 'Al `Aziziyah,Al ‘Azīzīyah,Azizia,El Azizia,العَزيزية', 32.5319400, 13.0175000, 'LY', '2011-03-19', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92661, 'Idrī', 'Idri', 'Adiri,Adri,Adrī,Adīrī,Ederi,Edri,Idri,Idrī,adry,أدري,إدري', 27.5000000, 13.2666700, 'LY', '2012-12-05', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92662, 'Qasr Abu Hadi', 'Qasr Abu Hadi', 'Qasr Abu Hadi,Qaşr Abū Hādī,qsr abw hady,قصر ابو هادي', 31.0592600, 16.6590500, 'LY', '2013-08-13', 127);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92241, 'Švenčionys', 'Svencionys', 'Shvenchenis,Shvenchionis,Shvenchënis,Svencionys,Sventsyany,Swieciany,Swięciany,Švenčionys,Швенченис', 55.1350000, 26.1590000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92242, 'Švenčionėliai', 'Svencioneliai', 'Nove S''ventsyany,Nove S’ventsyany,Novo-Sventsyany,Novyye S''ventsyany,Novyye Svenchany,Novyye S’ventsyany,Nowe Swieciany,Nowe Święciany,Nowo-Swieciany,Nowo-Swięciany,Shvencheneljaj,Shvenchenelyay,Shvenchënelyay,Svencioneliai,Švenčionėliai,Швенченеляй', 55.1616300, 26.0017700, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92243, 'Skuodas', 'Skuodas', 'Schoden,Skoda,Skouontas,Skudoas,Skuodas,Skuodo,Szkudy,Σκουόντας,Скуодас', 56.2705700, 21.5320800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92244, 'Būgai', 'Bugai', 'Bugai,Būgai,Skaudvile,Skaudvilė,Скаудвиле', 55.4138700, 22.6089400, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92245, 'Skaidiškės', 'Skaidiskes', 'Skaidiskes,Skaidiškės', 54.6139800, 25.3957300, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92246, 'Širvintos', 'Sirvintos', 'Shirvintay,Shirvintos,Sirvintai,Sirvintar,Sirvintos,Sirvintu,Szyrwinty,Širvintai,Širvintar,Širvintos,Širvintų,Ширвинтос', 55.0440000, 24.9544600, 'LT', '2016-11-27', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92247, 'Simnas', 'Simnas', 'Poselok Simno,Posëlok Simno,Simnas,Simno,Симнас', 54.3820000, 23.6460000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92248, 'Silute', 'Silute', 'Heidekrug,Heydekrug,Heydekrug-Matzicken,Shilute,Silute,Szylokarczma,Szyłokarczma,sillute,Šilute,Šilutė,Шилуте,실루테', 55.3488900, 21.4830600, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92249, 'Šilalė', 'Silale', 'Shilale,Silale,Silales,Szyiele,Szylele,Šilalė,Šilalės,Шилале', 55.4898000, 22.1869200, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92250, 'Šiauliai', 'Siauliai', 'Comune urbano di Siauliai,Comune urbano di Šiauliai,Gorad Shauljaj,SQQ,Sauli,Schaulen,Shaulyay,Shavli,Shawllay,Shjaulaj,Shjauljaj,Shyaulyay,Siaouliai,Siaule,Siauliai,Siauliu,Sjaulaj,Sokniai,Syaulyay,Szawle,cheale,shaurei,shiauliai,shyawlyay,shyawlyayy,syaullyai,xi ao li ai,Ŝjaulaj,Şyaulyay,Šauļi,Šiauliai,Šiaulių,Šiaulē,Σιαουλιάι,Горад Шаўляй,Шяуляй,Шјауљај,שאולאי,شياولياي,شیاؤلیائی,เชาเล,შიაულიაი,シャウレイ,希奥利艾,샤울랴이', 55.9333300, 23.3166700, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92251, 'Senieji Trakai', 'Senieji Trakai', 'Seneyi Trakay,Senieji Trakai,Stare Troki,Staryj Trakaj,Staryye Troki,Troki Stare,dzveli tʼrakʼai,Старый Тракай,ძველი ტრაკაი', 54.6090000, 24.9800000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92252, 'Šeduva', 'Seduva', 'Schadow,Sedava,Seduva,Seduvos,Sheduva,Szadow,Szadów,Šedava,Šeduva,Šeduvos,Шедува', 55.7493000, 23.7561000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92253, 'Seda', 'Seda', 'Seda,Sedos,Siady,Седа', 56.1685400, 22.0907100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92254, 'Sargėnai', 'Sargenai', 'Sargenai,Sargėnai', 54.9493300, 23.8831600, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92255, 'Šalčininkai', 'Salcininkai', 'Bol''shiye Solechniki,Bol’shiye Solechniki,Salcininkai,Shal''chininkaj,Shal''chininkay,Shal’chininkay,Soleczniki Wielkie,Vel''ke Solechniki,Velikiye Solechniki,Velke Solecniki,Velke Solečniki,Vel’ke Solechniki,Šalčininkai,Шальчининкай', 54.3086400, 25.3867700, 'LT', '2016-11-27', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92256, 'Salantai', 'Salantai', 'Salantai,Salantay,Salantu,Salanty,Salantų,Skilandziai,Skilándžiai', 56.0565000, 21.5689000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92257, 'Šakiai', 'Sakiai', 'Sakiai,Sakiu,Schaki,Shaki,Shakjaj,Shakyay,Szaki,Šakiai,Šakių,Шакяй', 54.9533900, 23.0477900, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92258, 'Rusnė', 'Rusne', 'Rus,Rusne,Rusnė,Russ,Ruß,Русне', 55.2982000, 21.3712000, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92259, 'Rūdiškės', 'Rudiskes', 'Rudishkes,Rudiskes,Rudzishki,Rudziszki,Rūdiškės,Рудишкес', 54.5160900, 24.8308400, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92260, 'Rokiškis', 'Rokiskis', 'Myasto Rokishkis,Rakischki,Rakishki,Rakiskis,Rakiszki,Rakiškis,Rokishkis,Rokiski,Rokiskio,Rokiskis,Rokiškio,Rokiškis,Rokišķi,Рокишкис', 55.9586700, 25.5946600, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92261, 'Rietavas', 'Rietavas', 'Retavas,Retowo,Rietavas,Rietavo,Ретавас', 55.7270800, 21.9234300, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92262, 'Raseiniai', 'Raseiniai', 'Raseinen,Raseini,Raseiniai,Raseiniu,Raseinių,Raseiņi,Raseynyay,Reseiniai,Rosienie,Rossienie,Rossieny,Rossingen,Rossiyeny', 55.3797300, 23.1238600, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92263, 'Ramygala', 'Ramygala', 'Ramigala,Ramygala,Ramygalos,Remigola,Remigoła,Remygala,Рамигала', 55.5140000, 24.3000000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92264, 'Ramučiai', 'Ramuciai', 'Ramuciai,Ramučiai', 54.9483000, 24.0305000, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92265, 'Radviliskis', 'Radviliskis', 'Radvilai,Radvilishkis,Radviliski,Radviliskio,Radviliskis,Radviliskis-Nemunelio,Radvilisks,Radviliškio,Radviliškis,Radvilišks,Radvilišķi,Radziwiliszki,Rantbiliskis,Ραντβιλίσκις,Радвилишкис', 55.8166700, 23.5333300, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92266, 'Prienai', 'Prienai', 'Prenaj,Prenay,Preny,Prienai,Prieni,Prienu,Prienų,Priyenay,Пренай', 54.6360000, 23.9458500, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92267, 'Priekulė', 'Priekule', 'Gorad Pryekule,Prekule,Priekule,Priekulė,Prikole,Priyekule,Proekuls,Prokuls,Prökuls,Prīkolė,brykwlh,prykwlh,pu lie ku lai,Горад Прыекуле,Прекуле,بريكوله,پریکوله,普列庫萊', 55.5542700, 21.3190300, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92268, 'Plunge', 'Plunge', 'Plunge,Plunges,Plungiany,Plungė,Plungės,Płungiany,Плунге', 55.9113900, 21.8441700, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92269, 'Plateliai', 'Plateliai', 'Plateliai,Plateliu,Platelių,Plateljaj,Platelyai,Platelyay,Plotele,Плателяй', 56.0465700, 21.8161500, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92270, 'Pasvalys', 'Pasvalys', 'Pasvalio,Pasvalis,Pasvalys,Posvol,Poswol,Пасвалис', 56.0594400, 24.4036100, 'LT', '2014-06-27', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92271, 'Panevėžys', 'Panevezys', 'PNV,Paneveza,Panevezhi,Panevezhis,Panevezio,Panevezis,Panevezys,Panevežis,Panevjazhys,Panevēža,Panevėžio,Panevėžys,Panevėžīs,Panjavezhis,Ponewesch,Ponewiesch,Poniewesch,Poniewiesh,Poniewiez,Poniewież,pa nei wei ri si,pa neiy weci s,panebejiseu,panevu~ejisu,pwnybz,pynywyzhys,Πανεβέζυς,Паневежис,Паневяжыс,Панявежис,פוניבז,پینیویژیس,ปาเนียเวจีส,პანევეჟისი,パネヴェジース,帕內韋日斯,파네베지스', 55.7333300, 24.3500000, 'LT', '2015-11-11', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92272, 'Palanga', 'Palanga', 'Gorad Palanga,PLQ,Palanga,Palanga bykommune,Palangos,Palonga,Polaga,Polanga,Polangen,Połąga,pa lan jia,palanga,pallang-ga,paranga,Горад Паланга,Паланга,פלאנגה,პალანგა,パランガ,帕兰加,팔랑가', 55.9175000, 21.0686100, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92273, 'Pakruojis', 'Pakruojis', 'Gorad Pakruojis,Pakroja,Pakroujis,Pakrouogis,Pakruois,Pakruojis,Pakruojo,Pakruojus,Pakruoyus,Pokroje,bakrwjys,pa ke lu ao yi si,pakrwwyys,pakrwyys,Πακρουόγις,Горад Пакруойіс,Пакруойис,Пакруоїс,باكروجيس,پاکرووئیس,پاکروییس,帕克魯奧伊斯', 55.9788900, 23.8550800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92274, 'Pagėgiai', 'Pagegiai', 'Gorad Pagegej,Pagegi,Pagegiai,Pagegjaj,Pagegyay,Pagiege,Pagiegē,Pagojaus,Pagėgiai,Paģēģi,Pogegen,Pojegi,baghyghyay,pa gai ji ai,paggyay,pagygyyy,Горад Пагегей,Пагегяй,باغيغياي,پاگگیای,پاگیگیئی,帕蓋吉艾', 55.1379300, 21.9137800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92275, 'Pabradė', 'Pabrade', 'Maloye Podbrodze,Pabrade,Pabradė,Пабраде', 54.9810000, 25.7610000, 'LT', '2016-09-22', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92276, 'Fabijoniškės', 'Fabijoniskes', 'Fabijoniskes,Fabijoniškės', 54.7333300, 25.2416700, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92277, 'Obeliai', 'Obeliai', 'Obeliai,Obeliu,Obelių,Obelyay', 55.9689500, 25.1564800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92278, 'Nida', 'Nida', 'Neda,Neringa,Nida,Nidden,Nėda,ni da,nida,Нида,Ніда,نیدا، لتھووینیا,ニダ,尼達', 55.3086000, 20.9965100, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92279, 'Neringa', 'Neringa', 'Neringa,Preyla,Неринга', 55.3719400, 21.0647200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92280, 'Nemenčinė', 'Nemencine', 'Gorad Njamjanchyne,Nemencene,Nemenchin,Nemenchine,Nemenchyn,Nemencine,Nemenčine,Nemenčinė,Nemenčėnė,Niemenczyn,nei men qi nei,nemenchine,nmnchynh,nymynsynh,Горад Нямянчыне,Неменчине,نمنچینه,نيمينسينه,ნემენჩინე,ネメンチネ,內門奇內', 54.8477600, 25.4699200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92281, 'Naujoji Akmene', 'Naujoji Akmene', 'Karpenai,Karpėnai,Naougiogi Akmene,Naujogi-Akmene,Naujogi-Akmenė,Naujoji Akmene,Naujoji Akmenė,Nauyeyi-Akmyane,Nauyëyi-Akmyane,Nowe Okmiany,Ναουγιόγι Ακμένε', 56.3166700, 22.9000000, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92282, 'Molėtai', 'Moletai', 'Gorad Maletaj,Malaty,Maletai,Maletay,Maletu,Malyaty,Malėtai,Malėtų,Moletai,Moletaj,Moletay,Moleti,Molēti,Molėtai,Muolieta,Muolietā,mo lei tai,moletai,moretai,mwltay,mwlytyy,Μολετάι,Горад Малетай,Молетай,مولتای,مولیتئی,मोलेतै,モレタイ,莫雷泰', 55.2246900, 25.4168800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92283, 'Mazeikiai', 'Mazeikiai', 'Mazeiki,Mazeikiai,Mazeikiu,Mazhejkjaj,Mazheykyay,Mažeikiai,Mažeikių,Mažeiķi,Mozejki,Możejki,Muravjovo,Murawlewo,Μαζεϊκιάι,Мажейкяй', 56.3166700, 22.3333300, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92284, 'Marijampolė', 'Marijampole', 'Gorad Maryjampale,Kapsukas,Marejampuole,Mariampol,Mariampol'',Mariampole,Mariampoles,Mariampolė,Mariampolės,Mariampol’,Marigiampole,Marijampole,Marijampolė,Mariyampol'',Mariyampole,Mariyampol’,Marjampol,Marėjampuolė,Pasesupiai,Pašešupiai,Starapole,Starapolė,ma li yang po lie,maliyampolle,mariyanpore,maryambwlh,Μαριγιαμπολέ,Горад Марыямпале,Мариямполе,Маријамполе,Маріямполе,מריאמפול,ماريامبوله,ماریجمپولے,მარიამპოლე,マリヤーンポレ,馬里揚泊列,마리얌폴레', 54.5599100, 23.3541200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92285, 'Linkuva', 'Linkuva', 'Linkuva,Linkuvos,Линкува', 56.0859600, 23.9706100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92286, 'Lentvaris', 'Lentvaris', 'Gorad Ljantvarys,Landvaruv,Landwarow,Landwarów,Lentvaravas,Lentvare,Lentvaris,Liudvtvaras,Liutavariskes,Liutavariškės,Lyandvarovo,Lyandvaruv,Lėntvaris,lntwarys,lun te wa li si,Λέντβαρις,Горад Лянтварыс,Лентварис,لنتواریس,ლენტვარისი,倫特瓦里斯', 54.6436400, 25.0516200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92287, 'Lazdijai', 'Lazdijai', 'Lazdijai,Lazdijaj,Lazdiji,Lazdiyay,Lazdyyay,Lazntigiai,Loz''dzeye,Lozdzieje,Loz’dzeye,Lożdzieje,Łoździeje,Λαζντιγιάι,Лаздияй', 54.2332600, 23.5146600, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92288, 'Kybartai', 'Kybartai', 'Kibartaj,Kibartay,Kibarty,Kybartai,Kybartu,Kybartų,Кибартай', 54.6385800, 22.7631600, 'LT', '2016-12-07', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92289, 'Kuršėnai', 'Kursenai', 'Gorad Kurshehnaj,Korsiena,Koršienā,Koursenai,Kursenai,Kurseni,Kurshchenay,Kurshenaj,Kurshenay,Kurszany,Kurzenu,Kuršēni,Kuršėnai,Kuržėnų,ku er she nai,kurushenai,kwrshnay,qwrsn,Κουρσέναι,Κουρσέναϊ,Горад Куршэнай,Куршенай,Куршенај,קורשן,کورشنای,კურშენაი,クルシェナイ,庫爾舍奈', 56.0031800, 22.9366200, 'LT', '2016-03-15', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92290, 'Kupiskis', 'Kupiskis', 'Koupiskis,Kupishki,Kupishkis,Kupiskio,Kupiskis,Kupiszki,Kupiškio,Kupiškis,Myasto Kupishkis,Κουπίσκις,Купишкис', 55.8333300, 24.9666700, 'LT', '2014-09-24', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92291, 'Kulautuva', 'Kulautuva', 'Dachi Kolotovo,Dachios Kolotovo,Kulautuva', 54.9421200, 23.6421800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92292, 'Kudirkos Naumiestis', 'Kudirkos Naumiestis', 'Kudirkos Naumiestis,Kudirkos-Naumestis,Naum''yestis,Naumestis,Naumiescio,Naumiestis,Naumiestis Sakiu,Naumiestis Šakiu,Naumiesčio,Naumiyestis,Naum’yestis,Wladislawow,Wladyslawow,Władysławow,Кудиркос-Науместис', 54.7735300, 22.8613800, 'LT', '2017-05-07', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92293, 'Kretinga', 'Kretinga', 'Kratinga,Kretin''nka,Kretinga,Kretingos,Kretynga,Krottingen,Myasto Kretinga,keuleting-ga,Κρετίνγκα,Кретинга,크레팅가', 55.8888000, 21.2444800, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92294, 'Klaipėda', 'Klaipeda', 'KLJ,Klaipada,Klaipeda,Klaipenta,Klaipéda,Klaipēda,Klaipėda,Klajpeda,Klaypeda,Kłajpeda,Lungsod ng Klaipeda,Lungsod ng Klaipėda,Memel,Memela,ke lai pei da,keullaipeda,khil pheda,klaipedas,kuraipeda,qlypdh,qlyypdh,Κλαϊπέντα,Клаипеда,Клайпеда,Клајпеда,קלייפדה,קליפדה,ไคลเพดา,クライペダ,克莱佩达,클라이페다', 55.7088800, 21.1431200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92295, 'Kelmė', 'Kelme', 'Kel''me,Kelme,Kelmes,Kelmė,Kelmės,Kielmy,kelme,Кельме,켈메', 55.6300900, 22.9349000, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92296, 'Kėdainiai', 'Kedainiai', 'Gorad Kedajnjaj,Kedaini,Kedainiai,Kedainiu,Kedainių,Kedajnaj,Kedajnjaj,Kedayny,Kedaynyai,Kedaynyay,Kehdain''aj,Keidany,Kentainiai,Keydany,Kidaynay,Kidayñay,Kiedaine,Kiedainē,Kiejdany,Kėdainiai,kai dai ni ai,kedaimai,kedainai,kedainei,kedajnjaj,Ķēdaiņi,Κενταϊνιάι,Горад Кедайняй,Кедайняй,Кедајњај,Кэдаиньай,Кєиданꙑ,קדאייני,केदैंऐ,केदैञै,კედაინიაი,ケダイネイ,凱代尼艾,케다이네이', 55.2878200, 23.9727500, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92297, 'Kazlų Rūda', 'Kazlu Ruda', 'Gorad Kazlu Ruda,Kazlai,Kazlu Ruda,Kazlu Rudos,Kazlu Rūda,Kazlu-Ruda,Kazlū Rūda,Kazlų Rūda,Kazlų Rūdos,Kozlova-Ruda,Kozlowa Ruda,Kozłowa Ruda,ka zi lu lu da,kazlw rwda,Горад Казлу Руда,Казлу-Руда,کازلو رودا,კაზლუ-რუდა,カズルー・ルーダ,卡茲盧魯達', 54.7490000, 23.4900000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92298, 'Kaunas', 'Kaunas', 'Caunas,Couna,Gorad Kaunas,KUN,Kaounas,Kauen,Kauna,Kaunas,Kauno,Kauns,Kauņa,Kawnas,Kaŭno,Kovno,Kowno,Palemonas,kao na si,kaunaseu,kaunasu,kawnas,khea nas,konasa,qwbnh,Κάουνας,Горад Каўнас,Каунас,קאוונע,קובנה,كاوناس,کاؤناس,کاوناس,कॉनास,เคานัส,კაუნასი,ᑯᓇᔅ/kunas,カウナス,考那斯,카우나스', 54.9027200, 23.9096100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92299, 'Karmėlava', 'Karmelava', 'Karmelava,Karmelavo,Karmelavos,Karmelova,Karmėlava,Karmėlavos,Kormialow,Kormiałów,Kormjalov,Kormyalov,Кармелова,Кормялов', 54.9705500, 24.0618200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92300, 'Kalvarija', 'Kalvarija', 'Kalbarigia,Kalvarija,Kalvarijos,Kalvariya,Kalwaria,Kalwarja,Καλβαρίγια,Калвария', 54.4170000, 23.2230000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92301, 'Kaišiadorys', 'Kaisiadorys', 'Kaisedorys,Kaisiadorio,Kaisiadorys,Kaišedorys,Kaišiadorio,Kaišiadorys,Kajshjadoris,Kashedary,Kasheydarys,Kayshadoris,Kayshadorys,Kayshyadoris,Koshedary,Koszedary,Кайшядорис', 54.8652800, 24.4681500, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92302, 'Jurbarkas', 'Jurbarkas', 'Georgenburg,Jurbarka,Jurbarkas,Jurbarko,Jurbork,Yurbarkas,Yurburg,ywrbwrg,Юрбаркас,יורבורג', 55.0755600, 22.7641600, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92303, 'Juodupė', 'Juodupe', 'Juodupe,Juodupė,Yuodupe,Юодупе', 56.0870000, 25.6070000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92304, 'Joniškis', 'Joniskis', 'Gioniskis,Ionishkis,Janiszki,Jonischki,Jonishkis,Joniski,Joniskio,Joniskis,Joniškio,Joniškis,Jonišķi,Yanishki,Yonishkis,Γιονίσκις,Йонишкис', 56.2393900, 23.6154100, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92305, 'Jonava', 'Jonava', 'Gorad Ionava,Ionava,Janow,Janów,Jonava,Jonavos Miestelis,Juonava,Yonava,Yonawa,ionava,yonaba,yonavu~a,yue na wa,Јонава,Горад Іонава,Ионава,Йонава,იონავა,ヨナヴァ,約納瓦,요나바', 55.0833300, 24.2833300, 'LT', '2014-06-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92306, 'Jieznas', 'Jieznas', 'Eznas,Iyeznas,Jeznas,Jezno,Jieznas,Yeznas,Езнас', 54.5993700, 24.1759300, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92307, 'Ignalina', 'Ignalina', 'Ignalina,Ignaline,Ignalino,Ignalinė,Inknalina,Ιγκναλίνα,Игналина', 55.3406300, 26.1604900, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92308, 'Grigiškės', 'Grigiskes', 'Grigishkes,Grigiskes,Grigiškės,Grigor''yevo,Grigor’yevo,Григишкес', 54.6833300, 25.0833300, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92309, 'Gelgaudiškis', 'Gelgaudiskis', 'Gelgaudishkis,Gelgaudiskio,Gelgaudiskis,Gelgaudiškio,Gelgaudiškis,Gelgudyshki,Gielgudyszki,Гелгаудишкис', 55.0768800, 22.9769900, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92310, 'Garliava', 'Garliava', 'Garliava,Garliavos,Garljava,Garlyava,Godlewo,Godlezo,Gorleva,Гарлява', 54.8213900, 23.8713000, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92311, 'Gargždai', 'Gargzdai', 'Gardzdai,Gardždai,Gargzdai,Gargzdi,Gargzdu,Gargzhdaj,Gargzhday,Gargždai,Gargždi,Gargždų,Garsden,Garzdai,Garždai,Gorzdy,Gorżdy,Гаргждай', 55.7095100, 21.3944100, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92312, 'Ežerėlis', 'Ezerelis', 'Ehzherelis,Ezerelis,Ezherelis,Ežerėlis,Эжерелис', 54.8831500, 23.6039600, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92313, 'Elektrėnai', 'Elektrenai', 'Ehlektrenaj,Elektrenai,Elektrenaj,Elektrenay,Elektreni,Elektreny,Elektriena,Elektrienā,Elektrēni,Elektrėnai,Gorad Ehlektrehnaj,ai lai ke te lun ai,ellegteulenai,erekutorenai,Горад Электрэнай,Електренай,Електренај,Электренай,エレクトレナイ,埃莱克特伦艾,엘렉트레나이', 54.7854400, 24.6630200, 'LT', '2014-07-25', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92314, 'Eišiškės', 'Eisiskes', 'Aisiskes,Aišiškės,Ehjshishkes,Eiseskes,Eisiskes,Eiszyski,Eišiškės,Eišišķes,Eišėškės,Ejshishkes,Ejszyszki,Eyshishkes,Eyshishki,Gorad Ehjshyshkes,Malyy Eyshishki,Yeyshyshki,ai xi shen kai si,ayshyshks,Горад Эйшышкес,Ейшишкес,Эйшишкес,איישישוק,إيشيشكس,ایشیشکس,埃希什凱斯', 54.1741400, 24.9991700, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92315, 'Dūkštas', 'Dukstas', 'Dukshtas,Dukshty,Dukstas,Dukszty,Dūkštas,Дукштас', 55.5220000, 26.3210000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92316, 'Druskininkai', 'Druskininkai', 'Droskininka,Droskininkā,Drushkininkaj,Druskeniki,Druskieniki,Druskiniki,Druskininkai,Druskininkaj,Druskininkay,Druskininki,Druskininkаy,Druśkieniki,Gorad Druskininkaj,Ntrouskinin''kai,de lu si ji ning kai,dorusukininkai,drwskykynkayy,drwskynynkay,Ντρούσκινινκαϊ,Горад Друскінінкай,Друскининкай,Друскінінкай,Друшкининкај,דרוסקינינקאי,دروسکینینکای,دروسکیکینکائی,ドルスキニンカイ,德魯斯基寧凱', 54.0157300, 23.9870300, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92317, 'Daugai', 'Daugai', 'Daugai,Daugaj,Daugay,Dauge,Daugi,Daugu,Daugų,Даугай', 54.3666700, 24.3333300, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92318, 'Birzai', 'Birzai', 'Birsche,Birsen,Birza,Birzai,Birze,Birzhaj,Birzhay,Birzhi,Birzi,Birzu,Birże,Biržai,Birži,Biržā,Biržų,Gorad Birzhaj,Mpirzai,Myasto Birzhay,bi er zha yi,birujai,birzhai,byrzs,Μπιρζάι,Биржай,Биржај,Біржай,Горад Біржай,בירזש,ბირჟაი,ビルジャイ,比爾扎伊', 56.2000000, 24.7500000, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92319, 'Birštonas', 'Birstonas', 'Birshtonas,Birstonas,Birstonas-Kurortas,Birstono,Birsztany,Birštonas,Birštonas-Kurortas,Birštono,Mpirstonas,Μπιρστόνας,Бирштонас', 54.6080000, 24.0340000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92320, 'Baltoji Vokė', 'Baltoji Voke', 'Baltoji Voke,Baltoji Vokė,Belaya Vaka,Waka Biala,Waka Biała,Балтойи Воке', 54.6000200, 25.1931800, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92321, 'Aukstadvaris', 'Aukstadvaris', 'Auksdvaris,Aukshtadvaris,Aukstadvario,Aukstadvaris,Aukstdvaris,Aukstdvarys,Aukšdvaris,Aukštadvaris,Aukštdvaris,Aukštdvarys,Visoki Dvor,Wysaki Dwor,Wysoki Dwor,Wysoki Dwór,Аукштадварис', 54.5794600, 24.5268300, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92322, 'Ariogala', 'Ariogala', 'Aregala,Ariogala,Ariogalos,Arëgala,Eiragola,Ejragola,Ejragoła,Арегала', 55.2620000, 23.4770000, 'LT', '2016-09-29', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92323, 'Anyksciai', 'Anyksciai', 'Aniksci,Anikshchay,Anikshchyay,Anikshhjaj,Anyksciai,Anyksciu,Anykshchay,Anykstsiai,Anykščiai,Anykščių,Anīkšči,Onikschty,Onikshty,Onikszty,Onukszty,Ανυκστσιάι,Аникщяй', 55.5255700, 25.1026400, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92324, 'Alytus', 'Alytus', 'Alita,Alitos,Alitous,Alitus,Alytaus,Alytus,Alīta,Alītos,Gorad Alitus,Olita,a li tu si,allituseu,alwts,alytas,alyts,alytws,arito~usu,Αλίτους,Алитус,Алітус,Горад Алітус,Ալիտուս,אליטא,أليتس,الوتس,الیتاس,الیتوس,ალიტუსი,アリートゥス,阿利图斯,알리투스', 54.3963500, 24.0414200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92325, 'Aleksotas', 'Aleksotas', 'Aleksota,Aleksotas,Aleksoto', 54.8803700, 23.9084200, 'LT', '2016-11-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92326, 'Akmenė', 'Akmene', 'Akmene,Akmenes,Akmenė,Akmenės,Akmyane,Okmiany', 56.2500000, 22.7500000, 'LT', '2016-11-28', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92327, 'Dainava (Kaunas)', 'Dainava (Kaunas)', '', 54.9152500, 23.9683100, 'LT', '2014-09-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92328, 'Šilainiai', 'Silainiai', '', 54.9291100, 23.8859900, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92329, 'Eiguliai', 'Eiguliai', '', 54.9313300, 23.9324300, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92330, 'Akademija (Kaunas)', 'Akademija (Kaunas)', '', 54.8964000, 23.8241100, 'LT', '2014-09-26', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92331, 'Mastaiciai', 'Mastaiciai', 'Mastaiciai,Mastaičiai', 54.8199800, 23.8446200, 'LT', '2014-09-23', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92332, 'Pašilaičiai', 'Pasilaiciai', '', 54.7342900, 25.2191200, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92333, 'Pilaitė', 'Pilaite', '', 54.6998100, 25.1839300, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92334, 'Justiniškės', 'Justiniskes', '', 54.7166400, 25.2174000, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92335, 'Šeškinė', 'Seskine', '', 54.7097200, 25.2505300, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92336, 'Lazdynai', 'Lazdynai', '', 54.6681500, 25.2068400, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92337, 'Vilkpėdė', 'Vilkpede', '', 54.6696900, 25.2477000, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92338, 'Naujamiestis', 'Naujamiestis', '', 54.6795100, 25.2685500, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92339, 'Rasos', 'Rasos', '', 54.6787700, 25.3117300, 'LT', '2015-02-12', 129);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92340, 'Wormeldange', 'Wormeldange', 'Wormeldange', 49.6111400, 6.4054600, 'LU', '2017-06-15', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92341, 'Winseler', 'Winseler', 'Gemeng Wanseler,Vinseler,Vinzeler,Wanseler,Winseler,wynzlr,Винзелер,Вінселер,وینزلر', 49.9677800, 5.8902800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92342, 'Wincrange', 'Wincrange', 'Wenerange,Wincrange,Wintger', 50.0533300, 5.9191700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92343, 'Wilwerwiltz', 'Wilwerwiltz', 'Wilwerwiltz,Wilwerwilz', 49.9888900, 5.9991700, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92344, 'Wiltz', 'Wiltz', 'Vil''c,Vilc,Vilcas,Wiltz,Wilz,Wolz,wyltz,Вилц,Вильц,Вільц,ویلتز', 49.9688900, 5.9319400, 'LU', '2017-06-15', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92345, 'Weiswampach', 'Weiswampach', 'Weiswampach', 50.1372200, 6.0750000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92346, 'Weiler-la-Tour', 'Weiler-la-Tour', 'Weiler-la-Tour', 49.5408300, 6.2008300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92347, 'Wasserbillig', 'Wasserbillig', 'Wasserbillig', 49.7153400, 6.4986100, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92348, 'Warken', 'Warken', 'Warken', 49.8544400, 6.0950000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92349, 'Walferdange', 'Walferdange', 'Walfer,Walferdange,Walferdingen', 49.6583300, 6.1372200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92350, 'Waldbredimus', 'Waldbredimus', 'Waldbredimus', 49.5550000, 6.2875000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92351, 'Waldbillig', 'Waldbillig', 'Waldbillig', 49.7888900, 6.2866700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92352, 'Wahl', 'Wahl', 'Wahl,Wal', 49.8366700, 5.9063900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92353, 'Vichten', 'Vichten', 'Vichten,Viichten', 49.8030600, 6.0000000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92354, 'Vianden', 'Vianden', 'Veianen,Vianden,Vijandehn,Vijanden,wei an deng,wyandn,Вианден,Вијанден,Віанден,Віяндэн,ویاندن,維安登', 49.9350000, 6.2088900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92355, 'Useldange', 'Useldange', 'Useldange,Useldeng', 49.7697200, 5.9822200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92356, 'Tuntange', 'Tuntange', 'Tenten,Tuntange,Tuntingen,Tënten', 49.7177800, 6.0102800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92357, 'Troisvierges', 'Troisvierges', 'Elwen,Gemeng Elwen,Gemeng Ëlwen,Troavjerzh,Troisvierges,Truav''erzh,Truaverzh,Ulflingen,torowavu~ieruju,trwawyrzh,Ëlwen,Троавјерж,Труавьерж,Труавєрж,ترواویرژ,トロワヴィエルジュ', 50.1211100, 6.0002800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92358, 'Tétange', 'Tetange', 'Tetange,Tétange', 49.4758300, 6.0422200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92359, 'Tandel', 'Tandel', 'Tandel', 49.8975000, 6.1833300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92360, 'Strassen', 'Strassen', 'Strassen', 49.6205600, 6.0733300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92361, 'Steinsel', 'Steinsel', 'Steinsel', 49.6769400, 6.1238900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92362, 'Steinfort', 'Steinfort', 'Steinfort,Stengefort', 49.6613900, 5.9191700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92363, 'Stadtbredimus', 'Stadtbredimus', 'Stadtbredimus', 49.5627800, 6.3644400, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92364, 'Soleuvre', 'Soleuvre', 'Soleuvre,Zolver,Zolwer', 49.5255600, 5.9405600, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92365, 'Septfontaines', 'Septfontaines', 'Septfontaines,Siebenborn,Simmern', 49.7011100, 5.9672200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92366, 'Schuttrange', 'Schuttrange', 'Schuttrange', 49.6205600, 6.2686100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92367, 'Schrassig', 'Schrassig', 'Schrassig', 49.6058300, 6.2588900, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92368, 'Schouweiler', 'Schouweiler', 'Schouweiler', 49.5825000, 5.9563900, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92369, 'Schifflange', 'Schifflange', 'Scheffleng,Schifflange,Schëffleng', 49.5063900, 6.0127800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92370, 'Schieren', 'Schieren', 'Schieren', 49.8305600, 6.0986100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92371, 'Schengen', 'Schengen', 'Convenio de Schengen,Gemeng Schengen,Schengen,Sengen,Sengenas,Shengen,shen gen,shengen,shengeni,shngn lwkzambwrg,shynjn,sngn,syeng-gen,Şengen,Šengenas,Шенген,שנגן,شنگن لوکزامبورگ,شينجن,ෂෙන්ගන්,შენგენი,シェンゲン,申根,神根,솅겐', 49.4700000, 6.3620000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92372, 'Sanem', 'Sanem', 'Sanem,Sassenheim,Suessem', 49.5480600, 5.9288900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92373, 'Sandweiler', 'Sandweiler', 'Gemeng Sandweiler,Sandvajler,Sandvejler,Sandweiler,sndwaylr,Сандвайлер,Сандвейлер,سندوایلر', 49.6133300, 6.2188900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92374, 'Saeul', 'Saeul', 'Saeul,Sell,Sëll', 49.7272200, 5.9863900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92375, 'Rumelange', 'Rumelange', 'Rumelange,Rumelingen', 49.4608300, 6.0330600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92376, 'Rosport', 'Rosport', 'Rosport', 49.7977800, 6.5041700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92377, 'Rollingen', 'Rollingen', 'Rollingen', 49.7416700, 6.1144400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92378, 'Roeser', 'Roeser', 'Gemeng Reiser,Gemeng Réiser,Reiser,Rezer,Roeser,Réiser,rwzr,Резер,روزر', 49.5422200, 6.1500000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92379, 'Rodange', 'Rodange', 'Rodange', 49.5463900, 5.8408300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92380, 'Remich', 'Remich', 'Rehmikh,Reimech,Rejmekh,Remich,Remichas,Remikh,Réimech,lei mi xi,rmysh,Ремих,Реміх,Рејмех,Рэміх,رمیش,雷米希', 49.5450000, 6.3669400, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92381, 'Reisdorf', 'Reisdorf', 'Reisdorf,Reisduerf', 49.8686100, 6.2677800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92382, 'Redange-sur-Attert', 'Redange-sur-Attert', 'Redange,Redange-sur-Attert,Redingen,Reiden,Réiden', 49.7655600, 5.8908300, 'LU', '2017-06-15', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92383, 'Reckange-sur-Mess', 'Reckange-sur-Mess', 'Reckange,Reckange-sur-Mess,Reckange-sur-Messe,Reckeng op der Mess,Reckingen', 49.5625000, 6.0088900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92384, 'Rambrouch', 'Rambrouch', 'Gemeng Rammerech,Rambrouch,Rambruch,Rambrukh,Rambrush,Rammerech,rambrwk,Рамбрух,Рамбруш,رامبروک', 49.8308300, 5.8450000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92385, 'Putscheid', 'Putscheid', 'Petscht,Putscheid,Pëtscht', 49.9608300, 6.1430600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92386, 'Pontpierre', 'Pontpierre', 'Pontpierre,Steinbrucken', 49.5363900, 6.0294400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92387, 'Pétange', 'Petange', 'Gemeng Peiteng,Gemeng Péiteng,Peiteng,Petange,Petanzas,Petanzh,Petanžas,Petingen,Péiteng,Pétange,ptanzh,Петанж,پتانژ', 49.5583300, 5.8805600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92388, 'Olm', 'Olm', 'Olm', 49.6572200, 6.0002800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92389, 'Obercorn', 'Obercorn', 'Oberkorn', 49.5136100, 5.8961100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92390, 'Nommern', 'Nommern', 'Nommern', 49.7869400, 6.1747200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92391, 'Niedercorn', 'Niedercorn', 'Niederkorn', 49.5361100, 5.8930600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92392, 'Niederanven', 'Niederanven', 'Gemeng Nidderaanwen,Nidderanven,Nidehranven,Nideranven,Niederanven,nydranwn,Нидеранвен,Нідеранвен,Нідэранвен,نیدرآنون', 49.6475000, 6.2600000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92393, 'Müllendorf', 'Muellendorf', 'Muellendorf,Mullendorf,Müllendorf', 49.6802800, 6.1300000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92394, 'Moutfort', 'Moutfort', 'Moutfort', 49.5852800, 6.2555600, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92395, 'Mondorf-les-Bains', 'Mondorf-les-Bains', 'Bad Mondorf,Bains,Gemeng Munneref,Mondorf le Benas,Mondorf-le-Ben,Mondorf-les-Bains,Munneref,mondorp-le-beni,mwndwrf,Мондорф-ле-Бен,موندورف,მონდორფ-ლე-ბენი', 49.5050000, 6.2811100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92396, 'Mondercange', 'Mondercange', 'Mondercange,Monnerich', 49.5330600, 5.9883300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92397, 'Mompach', 'Mompach', 'Mompach', 49.7461100, 6.4650000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92398, 'Mertzig', 'Mertzig', 'Mertzig,Merzig', 49.8338900, 6.0075000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92399, 'Mertert', 'Mertert', 'Mertert', 49.6961100, 6.4813900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92400, 'Mersch', 'Mersch', 'Gemeng Miersch,Mersas,Mersch,Mersh,Meršas,Miersch,Morsche,mei er shi,mrsh,Мерш,مرش,梅尔施', 49.7488900, 6.1061100, 'LU', '2017-06-15', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92401, 'Medernach', 'Medernach', 'Medernach', 49.8095500, 6.2152100, 'LU', '2017-02-01', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92402, 'Manternach', 'Manternach', 'Manternach', 49.7027800, 6.4263900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92403, 'Mamer', 'Mamer', 'Gemeng Mamer,Mamer,Mameris,ma mo,mamr,Мамер,مامر,马默', 49.6275000, 6.0233300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92404, 'Luxembourg', 'Luxembourg', 'Bandar Luxembourg,Ciudad de Luxemburgo,Ciutat de Luxemburg,Dinas Lwcsembwrg,Gorad Ljuksemburg,LUX,Letzebuerg,Letzeburg,Liksanbou,Liuksemburgas,Ljuksemburg,Louxemvourgo,Lucemburk,Lucilinburhuc,Lucsamburg,Lucsemburg,Lueksemburg,Lueksemburq,Luessemburgh,Luksambuur,Luksemboarch,Luksembourg,Luksemburg,Luksemburga,Luksemburgo,Luksemburgu,Luksembùrg,Luksimbur,Lungsod ng Luksemburgo,Lusenburgo,Lussemborgh,Lussemburgo,Lussemburgu,Lussimbork veye,Luxemboerg,Luxemborg,Luxemborj,Luxembourg,Luxembourg by,Luxemburg,Luxemburgo,Luxemburgum,Luxembuurich,Luxembôrg,Luxembörg,Luxenburgo,Lëtzebuerg,Lúksemboarch,Lúxemborg,Lüksemburg,Lüksemburq,Lüssemburgh,Rakapuo,Rakapuō,Stad Letzebuerg,Stad Lëtzebuerg,Stadt Luxemburg,Ville de Luxembourg,lak sem beirk,lakcampark,lakjhembarga,lksmbrg,lu sen bao cheng,lu sen bao shi,lugsembuleukeu,luksemaburga,luksemburgi,lwksmbwrgh,lwkzambwrg,lwqsmbwrg,rukusenburuku,Λουξεμβούργο,Горад Люксембург,Луксембург,Люксембург,Лүксембург,Լյուքսեմբուրգ,לוקסמבורג,لوكسمبورغ,لوکزامبورگ,لوکسەمبورگ,ليۇكسېمبۇرگ شەھىرى,لکسمبرگ,लक्झेंबर्ग,লুক্সেমবুর্গ,லக்சம்பர்க்,ลักเซมเบิร์ก,ལུ་སེམ་བའུརག,ლუქსემბურგი,ሉክሰምበርግ,ルクセンブルク,盧森堡城,盧森堡市,룩셈부르크', 49.6116700, 6.1300000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92405, 'Lorentzweiler', 'Lorentzweiler', 'Lorentzweiler,Lorenzweiler', 49.6947200, 6.1425000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92406, 'Lintgen', 'Lintgen', 'Lintgen', 49.7158300, 6.1336100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92407, 'Leudelange', 'Leudelange', 'Leudelange', 49.5683300, 6.0652800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92408, 'Lenningen', 'Lenningen', 'Lenningen', 49.5986100, 6.3680600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92409, 'Larochette', 'Larochette', 'Fels,Larochette', 49.7769400, 6.2211100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92410, 'Lamadelaine', 'Lamadelaine', 'Lamadelaine,Lamadeleine,Rollingen', 49.5463900, 5.8563900, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92411, 'Kopstal', 'Kopstal', 'Kopstal', 49.6644400, 6.0730600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92412, 'Koerich', 'Koerich', 'Gemeng Kaeerch,Gemeng Käerch,Kaeerch,Kerikh,Kjorikh,Kjorykh,Koerich,Korich,Käerch,Körich,kwyrysh,Керіх,Кёрих,Кёрых,کوئریش', 49.6700000, 5.9500000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92413, 'Kirchberg', 'Kirchberg', 'Kirchberg,Luxembourg-Kirchberg', 49.6238900, 6.1494400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92414, 'Kehlen', 'Kehlen', 'Kehlen', 49.6683300, 6.0358300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92415, 'Kayl', 'Kayl', 'Gemeng Keel,Kajl'',Kayl,Keel,Kejl,Kelis,kyl  lwkzambwrg,Кайль,Кейл,کیل، لوکزامبورگ', 49.4891700, 6.0397200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92416, 'Junglinster', 'Junglinster', 'Junglinster', 49.7072200, 6.2530600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92417, 'Itzig', 'Itzig', 'Itzig', 49.5841700, 6.1736100, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92418, 'Hosingen', 'Hosingen', 'Hosingen', 50.0177800, 6.0933300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92419, 'Hobscheid', 'Hobscheid', 'Habscht,Hobscheid', 49.6886100, 5.9147200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92420, 'Hesperange', 'Hesperange', 'Hesperange', 49.5680600, 6.1513900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92421, 'Helmsange', 'Helmsange', 'Helmsange', 49.6527800, 6.1413900, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92422, 'Heisdorf', 'Heisdorf', 'Heisdorf,Heisdorf-sur-Alzette', 49.6686100, 6.1422200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92423, 'Heffingen', 'Heffingen', 'Heffingen', 49.7625000, 6.2413900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92424, 'Hautcharage', 'Hautcharage', 'Hautcharage,Oberkerschen', 49.5775000, 5.9108300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92425, 'Grosbous', 'Grosbous', 'Grosbous', 49.8277800, 5.9672200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92426, 'Grevenmacher', 'Grevenmacher', 'Grehvenmakher,Greivemaacher,Greiwemaacher,Grevenmacher,Grevenmacheris,Grevenmakher,Gréivemaacher,Gréiwemaacher,Grėvenmacheris,ge lei wen ma he,geulebenmaheo,grbnmkr,grwnmakhr,gurevu~enmaha,Гревенмахер,Грэвенмахер,גרבנמכר,گرونماخر,グレーヴェンマハ,格雷文马赫,그레벤마허', 49.6747200, 6.4419400, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92427, 'Gonderange', 'Gonderange', 'Gonderange', 49.6888900, 6.2483300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92428, 'Gœsdorf', 'Gœsdorf', 'Goesdorf,Gosdorf,Gosdorf bei Wilz,Gösdorf,Gösdorf bei Wilz,Gœsdorf', 49.9216700, 5.9683300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92429, 'Garnich', 'Garnich', 'Garnech,Garnich', 49.6166700, 5.9525000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92430, 'Frisange', 'Frisange', 'Freiseng,Frisange,Fréiseng', 49.5150000, 6.1916700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92431, 'Flaxweiler', 'Flaxweiler', 'Flaxweiler,Fluessweller', 49.6616700, 6.3436100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92432, 'Fischbach', 'Fischbach', 'Fischbach', 49.7397200, 6.1872200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92433, 'Niederfeulen', 'Niederfeulen', 'Feulen,Neiderfeulen,Niederfeulen', 49.8555600, 6.0472200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92434, 'Fentange', 'Fentange', 'Fentange', 49.5627800, 6.1538900, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92435, 'Ettelbruck', 'Ettelbruck', 'Ehtehl''bruk,Ehttel''brjuk,Etelbrek,Etelbriukas,Ettel''brjuk,Ettelbreck,Ettelbruck,Ettelbrueck,Ettelbréck,Ettelbrück,Ettlebruk,Gemeng Ettelbreck,Gemeng Ettelbréck,atl brwk,aytlbrwk,Етелбрек,Еттельбрюк,Эттельбрюк,Этэльбрук,إيتلبروك,اتل بروک,ایٹل برک', 49.8475000, 6.1041700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92436, 'Esch-sur-Sûre', 'Esch-sur-Sure', 'Ehsh-sjur-Sjur,Escch-sur-Sure,Esch,Esch-Sauer,Esch-sur-Sure,Esch-sur-Sûre,Esh-sjur-Sur,Gemeng Esch-Sauer,ash-swr-swr,Еш-сюр-Сур,Эш-сюр-Сюр,اش-سور-سور', 49.9113900, 5.9363900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92437, 'Esch-sur-Alzette', 'Esch-sur-Alzette', 'Ehsh-sjur-Al''zet,Ehsh-sjur-Al''zett,Ehsh-sjur-Alzette,Es-syr-Alzet,Esas prie Alzeto,Esch,Esch an der Alzette,Esch-Uelzecht,Esch-an-der-Alzette,Esch-an-der-Alzig,Esch-sur-Alzette,Esh sir Alzet,Esh-sjur-Al''zett,Ešas prie Alzeto,a er ze te he pan ai shi,ash-swr-alzt,eshu=shuru=aruzetto,esyuswileualjeteu,Ες-συρ-Αλζέτ,Еш сир Алзет,Еш-сюр-Альзетт,Эш-сюр-Алзетте,Эш-сюр-Альзет,Эш-сюр-Альзетт,اش-سور-الزت,エシュ＝シュル＝アルゼット,阿尔泽特河畔埃施,에슈쉬르알제트', 49.4958300, 5.9805600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92438, 'Erpeldange', 'Erpeldange', 'Erpeldange,Erpeldange-sur-Sure,Erpeldange-sur-Sûre', 49.8647200, 6.1147200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92439, 'Ell', 'Ell', 'Ell', 49.7638900, 5.8572200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92440, 'Eischen', 'Eischen', 'Eischen', 49.6855600, 5.8786100, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92441, 'Echternach', 'Echternach', 'Echternach,Echternachas,Echternak,Ehkhtehrnakh,Ehkhternakh,Ekhternakh,Iechternach,akhtrnakh,ashtrnakh,ehitanaha,ehiteonaheu,Ехтернах,Эхтернах,Эхтэрнах,اخترناخ,اشترناخ,ეხტერნახი,エヒタナハ,에히터나흐', 49.8055600, 6.4222200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92442, 'Dudelange', 'Dudelange', 'Diddeleng,Didelanzh,Diudelanzas,Diudelanžas,Djudelanzh,Dudelange,Dudelingen,Duedelingen,Dzjudzelanzh,Düdelingen,Gemeng Diddeleng,dwdlanzh,Дзюдзеланж,Диделанж,Дюделанж,دودلانژ', 49.4805600, 6.0875000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92443, 'Dippach', 'Dippach', 'Dippach', 49.5883300, 5.9833300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92444, 'Differdange', 'Differdange', 'Deifferdeng,Diferdanzas,Diferdanžas,Differdange,Differdanzh,Differdingen,Dziferdanzh,Déifferdeng,Gemeng Deifferdeng,Gemeng Déifferdeng,di fu dang ri,dyfrdanzh,Дзіферданж,Дифферданж,Діфферданж,دیفردانژ,迪弗當日', 49.5241700, 5.8913900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92445, 'Diekirch', 'Diekirch', 'Diekirch,Dikirkh,Dikrech,District de Diekirch,Dykirchas,Dzikirkh,di ji xi,dykyrsh,dyqyrk,Дзікірх,Дикирх,Дікірх,דיקירך,ديكيرش,دیکیرش,迪基希', 49.8677800, 6.1558300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92446, 'Dalheim', 'Dalheim', 'Dalheim', 49.5408300, 6.2597200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92447, 'Crauthem', 'Crauthem', 'Crauthem,Krauthem', 49.5355600, 6.1469400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92448, 'Contern', 'Contern', 'Contern', 49.5819400, 6.2266700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92449, 'Consdorf', 'Consdorf', 'Consdorf', 49.7730600, 6.3383300, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92450, 'Colmar', 'Colmar', '', 49.8102800, 6.0972200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92451, 'Clervaux', 'Clervaux', 'Clerf,Clervaux,Cliarref,Cliärref,Gemeng Klierf,Kamuna Klervo,Klerf,Klervo,Klierf,klrww,Камуна Клерво,Клерво,کلروو', 50.0547200, 6.0313900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92452, 'Clemency', 'Clemency', 'Clemency,Kuentzig,Kuntzig,Küntzig', 49.5966700, 5.8758300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92453, 'Capellen', 'Capellen', 'Capellen,Kapellen', 49.6450000, 5.9908300, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92454, 'Bridel', 'Bridel', 'Bridel', 49.6583300, 6.0822200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92455, 'Bous', 'Bous', 'Bous', 49.5538900, 6.3291700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92456, 'Bourscheid', 'Bourscheid', 'Bourscheid,Burscheid', 49.9100000, 6.0672200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92457, 'Boulaide', 'Boulaide', 'Bauschleiden,Boulaide', 49.8877800, 5.8163900, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92458, 'Boevange-sur-Attert', 'Boevange-sur-Attert', 'Boevange,Boevange-sur-Attert,Boewingen,Bovange,Bowen an der Attert', 49.7752800, 6.0155600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92459, 'Biwer', 'Biwer', 'Biwer', 49.7027800, 6.3747200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92460, 'Bissen', 'Bissen', 'Bissen', 49.7875000, 6.0694400, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92461, 'Betzdorf', 'Betzdorf', 'Betzdorf', 49.6833300, 6.3500000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92462, 'Bettendorf', 'Bettendorf', 'Bettendorf,Bettenduerf', 49.8766700, 6.2180600, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92463, 'Bettembourg', 'Bettembourg', 'Beetebuerg,Betehmbur,Betemburas,Betembūras,Bettambur,Bettembourg,Bettemburg,Gemeng Beetebuerg,btmbwrg,Беттамбур,Беттембург,Бетэмбур,Բետտամբուր,بتمبورگ', 49.5186100, 6.1027800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92464, 'Bettborn', 'Bettborn', 'Bettborn', 49.7952800, 5.9411100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92465, 'Bertrange', 'Bertrange', 'Bertrange', 49.6111100, 6.0500000, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92466, 'Bergem', 'Bergem', 'Bergem', 49.5250000, 6.0422200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92467, 'Béreldange', 'Bereldange', 'Bereldange,Béreldange', 49.6569400, 6.1275000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92468, 'Berdorf', 'Berdorf', 'Berdorf', 49.8136100, 6.3502800, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92469, 'Belvaux', 'Belvaux', 'Beles,Belvaux', 49.5127800, 5.9294400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92470, 'Beckerich', 'Beckerich', 'Beckerich', 49.7305600, 5.8872200, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92471, 'Bech', 'Bech', 'Bech,Bekh,Gemeng Bech,bk,bykh,Бех,بک,بیخ', 49.7461100, 6.3636100, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92472, 'Beaufort', 'Beaufort', 'Beaufort,Beefort,Befort', 49.8358300, 6.2916700, 'LU', '2017-01-14', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92473, 'Bavigne', 'Bavigne', 'Bavigne,Boeven,Boewen', 49.9219400, 5.8494400, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92474, 'Bascharage', 'Bascharage', 'Bascharage,Niederkerschen', 49.5672700, 5.9073000, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92475, 'Aspelt', 'Aspelt', 'Aspelt', 49.5227800, 6.2247200, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92476, 'Alzingen', 'Alzingen', 'Altzingen,Alzingen', 49.5650000, 6.1636100, 'LU', '2017-01-28', 130);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92663, 'Smara', 'Smara', 'Asmara,Es-Semara,Es-Smara,Esmara,SMW,Semara,Smar,Smara,alsmart,seumala,si ma la,smarh,sumara,Смара,Смара қаласы,סמארה,السمارة,سماره,スマラ,斯马拉,스마라', 26.7384100, -11.6719400, 'MA', '2017-07-08', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92664, 'Zoumi', 'Zoumi', 'Zoumi,Zumi', 34.8032100, -5.3445800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92665, 'Zinat', 'Zinat', 'Ercouiene,Ercoulene,Jinat,Sinat,Zinat', 35.4300000, -5.4000000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92666, 'Saddina', 'Saddina', 'Saddina,Zatdina', 35.6141000, -5.4519100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92667, 'Zouiat ech Cheïkh', 'Zouiat ech Cheikh', 'Zaouia ech Cheikh,Zaouia ech Cheïkh,Zavijja ash Shejkh,Zouiat ech Cheikh,Zouiat ech Cheïkh,Завийя аш Шейх', 32.6456200, -5.9178300, 'MA', '2013-10-16', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92668, 'Zaïo', 'Zaio', 'Toumiat Zaio,Toumiat Zaïo,Tumiat,Tumiat Zaio,Zaio,Zaïo', 34.9428200, -2.7329000, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92669, 'Zagora', 'Zagora', 'OZG,Zagora,Загора', 30.3324100, -5.8384000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92670, 'Youssoufia', 'Youssoufia', 'Louis Gentil,Youssoufia', 32.2463400, -8.5294100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92671, 'Touama', 'Touama', 'El Touama,Oulad Touama,Touama', 31.5350100, -7.4929100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92672, 'Tmourghout', 'Tmourghout', 'Tamoughout,Tamourhout,Tamrghoute,Tmourghout,Tmourhout', 33.9065000, -4.0269600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92673, 'Tiztoutine', 'Tiztoutine', 'Tistoutine,Tistutin,Tiztoutine', 34.9715900, -3.1527300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92674, 'Tiznit', 'Tiznit', 'Tiznit,Tiznitas,ti zi ni te,tznyt,Тизнит,تزنيت,تزنیت,提茲尼特', 29.6974200, -9.7316200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92675, 'Tizguine', 'Tizguine', '', 31.2283600, -8.3161100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92676, 'Tit Mellil', 'Tit Mellil', '', 33.5580800, -7.4864700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92677, 'Tissa', 'Tissa', 'El Arbaa de Tissa,L''Arba de Tissa,L’Arba de Tissa,Tissa,Village de Tissa', 34.2879100, -4.6637200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92678, 'Tirhanimîne', 'Tirhanimine', '', 35.2361900, -3.9545300, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92679, 'Tiout', 'Tiout', 'Agadir Tiout,Tiout,Tioute', 30.3887000, -8.6957200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92680, 'Tiouli', 'Tiouli', '', 34.3667900, -1.8370500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92681, 'Tinghir', 'Tinghir', 'Tineghir,Tinerhir,Tinghir,Tinrhir', 31.5147200, -5.5327800, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92682, 'Timoulilt', 'Timoulilt', 'Souk-Tnine de Timoulilt,Timouillit,Timoulilt', 32.2036800, -6.4666000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92683, 'Timezgana', 'Timezgana', 'Et Tnine de Timesgana,Timezgana', 34.5800000, -4.7300000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92684, 'Timezgadiouine', 'Timezgadiouine', 'Timesgadioume,Timezgadiouine', 30.8836600, -9.0454800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92685, 'Tilmi', 'Tilmi', '', 31.8179400, -5.7681200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92686, 'Tifni', 'Tifni', '', 31.6277700, -6.9409300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92687, 'Tiflet', 'Tiflet', '', 33.8946900, -6.3064900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92688, 'Tétouan', 'Tetouan', 'Gorad Tehtuan,TTU,Tetouan,Tetouán,Tetuan,Tetuanas,Tetuano,Tetuao,Tetuán,Tetuão,Tétouan,de tu an,teto''una,teto~uan,tetuan,ttwan,Τετουάν,Горад Тэтуан,Тетуан,Тетуан қаласы,תטואן,تطوان,तेतोउन,თეტუანი,テトゥアン,得土安,테투안', 35.5784500, -5.3683700, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92689, 'Temara', 'Temara', 'Kasba Temara,Temara', 33.9286600, -6.9065600, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92690, 'Telouet', 'Telouet', 'Dar Kaid el Glaoui,Telouet,Telouete,Telouète,Teluet', 31.2892500, -7.2378900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93171, 'Zrnovci', 'Zrnovci', 'Zrnovce,Zrnovci,Зрновци', 41.8541700, 22.4444400, 'MK', '2014-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93172, 'Zletovo', 'Zletovo', 'Zletovo,Злетово', 41.9886100, 22.2361100, 'MK', '2014-07-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93173, 'Žitoše', 'Zitose', 'Zhitoshe,Zitose,Zitoste,Žitoše,Žitošte,Житоше', 41.4199100, 21.2907800, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93174, 'Желино', 'Zhelino', 'Zelino,Zeljino,Zheline,Zhelino,Zhelinë,Željino,Желино', 41.9802800, 21.0641700, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93175, 'Зелениково', 'Zelenikovo', 'Zelenikove,Zelenikovo,Zelenikovë,Зелениково', 41.8866700, 21.5869400, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93176, 'Zajas', 'Zajas', 'Zajac,Zajas,Zajasz,Zajazi,zaiasi,zajas,Заяс,Зајас,زاجاس,ზაიასი', 41.6072200, 20.9383300, 'MK', '2014-11-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93177, 'Vrutok', 'Vrutok', 'Vrutog,Vrutok,Вруток', 41.7686100, 20.8391700, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93178, 'Вратница', 'Vratnica', 'Vratnica,Vratnice,Vratnicë,Вратница', 42.1433300, 21.1169400, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93179, 'Vrapčište', 'Vrapciste', 'Vrapchishte,Vrapcicshte,Vrapcista,Vrapciste,Vrapçicshtë,Vrapčišta,Vrapčište,Врапчиште', 41.8343900, 20.8856300, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93180, 'Vraneštica', 'Vranestica', 'Vraneshtica,Vranesnica,Vranestica,Vranešnica,Vraneštica,Вранештица', 41.4449600, 21.0268300, 'MK', '2015-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93181, 'Vladimirovo', 'Vladimirovo', 'Vladimirovo,Владимирово', 41.7100000, 22.7927800, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93182, 'Vinica', 'Vinica', 'Vinica,Виница', 41.8827800, 22.5091700, 'MK', '2014-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93183, 'Vevčani', 'Vevcani', 'Vehcane,Vehcani,Vehčane,Vehčani,Vevcane,Vevcani,Vevchani,Vevčane,Vevčani,Вевчани', 41.2405600, 20.5933300, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93184, 'Veljusa', 'Veljusa', 'Veljusa,Velusa,Вељуса', 41.4761100, 22.5675000, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93185, 'Velesta', 'Velesta', 'Veleshta,Velesta,Veleste,Velešte,Велешта', 41.2408300, 20.6438900, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93186, 'Vataša', 'Vatasa', 'Vatasa,Vatasha,Vataša,Ваташа', 41.4169400, 22.0188900, 'MK', '2014-04-30', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93187, 'Василево', 'Vasilevo', 'Vasilevo,Vasiljevo,Василево', 41.4761100, 22.6416700, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93188, 'Markov Grad', 'Markov Grad', 'Markov Grad,Varos,Varosh,Varoš,Варош,Марков Град', 41.3572200, 21.5325000, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93189, 'Valandovo', 'Valandovo', 'Valandova,Valandovas,Valandovo,Vallandova,Walandowo,Wałandowo,ballandobo,falandwfw,valandovo,wa lan duo wo,Валандово,فالاندوفو,ვალანდოვო,瓦蘭多沃,발란도보', 41.3174400, 22.5600200, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93190, 'Ваксинце', 'Vaksince', 'Vaksinc,Vaksince,Ваксинце', 42.2061100, 21.6630600, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93191, 'Usje', 'Usje', 'Usija,Usije,Usje,Усје', 41.9587100, 21.4583500, 'MK', '2017-02-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93192, 'Tuin', 'Tuin', 'Tuin,Tujin,Tujna,Туин', 41.6194400, 21.0452800, 'MK', '2014-11-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93193, 'Topolčani', 'Topolcani', 'Topolcane,Topolcani,Topolchani,Topolčani,Тополчани', 41.2277200, 21.4311300, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93194, 'Veles', 'Veles', 'Koprulu,Köprülü,Titov Veles,Veles,Velesa,Velesas,Velesi,Velessa,Velesu,Vélès,Weles,Wełes,belleseu,fylys,velesi,vu~eresu,wei lai si,wls,Βελεσά,Велес,Вєлєсъ,Վելես,ולס,فيليس,ولس,ველესი,ヴェレス,韋萊斯,벨레스', 41.7155600, 21.7755600, 'MK', '2014-04-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93195, 'Tetovo', 'Tetovo', 'Gorad Cetava,Kalkandelen,Qalqan Delen,Tetobo,Tetova,Tetovas,Tetovo,Tetowo,tai tuo wo,tetobo,tetovu~o,ttwbw,ttwfw,tytwfw,Τέτοβο,Горад Цетава,Тетово,Хътѣтово,Տետովո,טטובו,تتوفو,تيتوفو,ტეტოვო,テトヴォ,泰托沃,테토보', 42.0097300, 20.9715500, 'MK', '2015-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93196, 'Теарце', 'Tearce', 'Tearce,Теарце', 42.0744400, 21.0525000, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93197, 'Sveti Nikole', 'Sveti Nikole', 'Kilisseli,Sveti Nikola,Sveti Nikole', 41.8695600, 21.9527400, 'MK', '2011-08-15', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93198, 'Sušica', 'Susica', 'Sushica,Susica,Sušica,Сушица', 41.4398200, 22.8367600, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93199, 'Студеничани', 'Studenichani', 'Studenicane,Studenichani,Studeničane,Студеничани', 41.9158300, 21.5305600, 'MK', '2007-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93200, 'Strumica', 'Strumica', 'Stromitza,Stromnitsa,Stromnitza,Stroumitsa,Strumica,Strumitsa,Strumitza,Ustrumcha,Струмица', 41.4375000, 22.6433300, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93201, 'Struga', 'Struga', 'Gorad Struga,QXP,Strouga,Struga,Ustrugha,astrwga,seuteuluga,si te lu jia,strwgh,strwgha,sutoruga,Горад Струга,Строуга,Струга,Ստրուգա,סטרוגה,استروگا,ستروغا,სტრუგა,ストルガ,斯特鲁加,스트루가', 41.1779900, 20.6778400, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93202, 'Strelci', 'Strelci', 'Strelci,Стрелци', 41.5404600, 21.0056300, 'MK', '2014-11-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93203, 'Stojakovo', 'Stojakovo', 'Stojakovo,Стојаково', 41.1555600, 22.5775000, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93204, 'Shtip', 'Shtip', 'Ishtib,Istip,Shhip,Shtip,Stip,Stiplia,İştip,Štip,Штип,Щип', 41.7458300, 22.1958300, 'MK', '2011-08-15', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93205, 'Старо Нагоричане', 'Staro Nagorichane', 'Nagorican i Vjeter,Nagoriçan i Vjetër,Staro Nagoricane,Staro Nagoricino,Staro Nagoričane,Staro Nagoričino', 42.1980600, 21.8286100, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93206, 'Star Dojran', 'Star Dojran', 'Doerane,Dojran,Doēranē,Star Dojran,Stari Dojran,Стар Дојран', 41.1864700, 22.7203000, 'MK', '2012-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93207, 'Dolno Srpci', 'Dolno Srpci', 'Dolno Srpci,Srpci,Долно Српци', 41.1748000, 21.3646400, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93208, 'Sredno Konjare', 'Sredno Konjare', 'Sredno Konare,Sredno Konjare,Sredno Konjari,Средно Коњаре', 41.9574300, 21.7149400, 'MK', '2013-09-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93209, 'Srbinovo', 'Srbinovo', 'Srbinovo,Србиново', 41.7058600, 20.9585900, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93210, 'Srbica', 'Srbica', 'Srbica,Србица', 41.5867200, 21.0302700, 'MK', '2014-11-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93211, 'Sopotnica', 'Sopotnica', 'Sopotnica,Сопотница', 41.2959400, 21.1535700, 'MK', '2014-01-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93212, 'Сопиште', 'Sopishte', 'Sopishte,Sopiste,Sopište', 41.9547200, 21.4275000, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93213, 'Слупчане', 'Slupchane', 'Sllupcanje,Sllupçanje,Slupchane,Слупчане', 42.1733300, 21.6277800, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93214, 'Slepče', 'Slepce', 'Slepce,Slepche,Slepče,Слепче', 41.2333300, 21.1750000, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93215, 'Slatino', 'Slatino', 'Slatina,Slatine,Slatino,Slatinë,Слатино', 42.0678400, 21.0390200, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93216, 'Skopje', 'Skopje', 'Escopia,Escópia,Gorad Skop''e,SKP,Scopia,Scupi,Shkup,Shkupi,Skop''e,Skope,Skopeia,Skopia,Skopie,Skopiye,Skopje,Skopjo,Skopjė,Skople,Skoplie,Skoplje,Skopye,Szkopje,UEskuep,Uskub,Usküb,askwpyh,s ko peiy,sakopi''e,seukope,si ke pu li,skopje,skopye,skwbyh,sqwpyh,sukopie,Üsküp,Σκόπια,Горад Скоп''е,Скоп''є,Скопе,Скопие,Скопье,Скопје,Скопље,Съкопиѥ,Սկոպյե,סקאפיע,סקופיה,اسکوپیه,اسکوپیہ,سكوبيه,سكوپليې,سکوپ جے,स्कोप्ये,ਸਕੋਪੀਏ,ஸ்கோப்ஜே,สโกเปีย,སི་ཀོཔ་ཇི།,სკოპიე,ስኮፕዬ,スコピエ,斯科普里,스코페', 41.9964600, 21.4314100, 'MK', '2016-05-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93217, 'Šipkovica', 'Sipkovica', 'Mezefovica,Shipkovica,Shipkovice,Shipkovicë,Siikovica,Sipkovica,Šipkovica,Шипковица', 42.0350000, 20.9155600, 'MK', '2014-09-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93218, 'Selce', 'Selce', 'Selce,Селце', 42.0348200, 20.9403500, 'MK', '2014-09-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93219, 'Sekirnik', 'Sekirnik', 'Sekirnik,Секирник', 41.4399900, 22.7953600, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93220, 'Sedlarevo', 'Sedlarevo', 'Salarevo,Sedlarevo,Седларево', 41.8830600, 21.1275000, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93221, 'Сарај', 'Saraj', 'Saraj,Сарай,Сарај', 42.0000000, 21.3277800, 'MK', '2010-01-29', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93222, 'Samokov', 'Samokov', 'Samakov,Samokov,Самоков', 41.6833100, 21.1462500, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93223, 'Rusinovo', 'Rusinovo', 'Rusinovo,Русиново', 41.6872800, 22.8084900, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93224, 'Ростуша', 'Rostusha', 'Radostusha,Rostoucha,Rostusa,Rostusha,Rostusja,Rostuşa,Rostuša,Ростуша,როსტუშა', 41.6100000, 20.6000000, 'MK', '2010-08-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93225, 'Rosoman', 'Rosoman', 'Rasoman,Rosoman,Rosomani,rosomani,Росоман,როსომანი', 41.5167100, 21.9458500, 'MK', '2014-04-30', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93226, 'Романовце', 'Romanovce', 'Rahmanli,Ramanovce,Romanovac,Romanovc,Romanovce,Romanovci,Романовце', 42.0947200, 21.6930600, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93227, 'Ресен', 'Resen', 'Resan,Resen,Resna,Ресен', 41.0888900, 21.0122200, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93228, 'Ранковце', 'Rankovce', 'Rankovci,Ранковци', 42.1696400, 22.1161700, 'MK', '2011-08-15', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93229, 'Радовиш', 'Radovish', 'Radovis,Radovish,Radoviste,Radovište,Rodovis,Rodoviš,Радовиш', 41.6383300, 22.4647200, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93230, 'Радолишта', 'Radolishta', 'Radolishta,Radolista,Radoliste,Radolište,Радолишта', 41.1641700, 20.6233300, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93231, 'Радишани', 'Radishani', 'Radishani,Радишани', 42.0611100, 21.4477800, 'MK', '2006-10-18', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93232, 'Pršovce', 'Prsovce', 'Prosovce,Prošovce,Prsevce,Prshovce,Prsovce,Prševce,Pršovce,Пршовце', 42.0833600, 21.0599400, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93233, 'Probishtip', 'Probishtip', 'Probishtip,Probistip,Пробиштип', 42.0030600, 22.1786100, 'MK', '2011-08-15', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93234, 'Prilep', 'Prilep', 'Perlepe,Perlepes,Perlepé,Pirlepe,Prilep,Prilepa,Prilepas,pirlepe,Прилеп', 41.3451400, 21.5550400, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93235, 'Podareš', 'Podares', 'Podares,Podaresh,Podareš,Подареш', 41.6138900, 22.5422200, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93236, 'Пласница', 'Plasnica', 'Plasnica,Пласница', 41.4672200, 21.1230600, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93237, 'Pirok', 'Pirok', 'Pirok', 41.9108300, 20.9105600, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93238, 'Pirava', 'Pirava', 'Pirava,Пирава', 41.3204200, 22.5304700, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93239, 'Петровец', 'Petrovec', 'Ibraimovo,Petrovac,Petrovec', 41.9388900, 21.6150000, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93240, 'Pehčevo', 'Pehcevo', 'Pehcevo,Pehčevo,Pekhchevo,Пехчево', 41.7622600, 22.8892100, 'MK', '2015-08-07', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93241, 'Otlja', 'Otlja', 'Ode,Odë,Otla,Otlja,Отља', 42.1431500, 21.5867500, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93242, 'Orizari', 'Orizari', 'Orizare,Orizari,Оризари', 41.9226200, 22.4462800, 'MK', '2014-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93243, 'Орашац', 'Orashac', 'Orasec,Orashac,Orašec,Орашац', 42.0625000, 21.7997200, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93244, 'Oraovica', 'Oraovica', 'Orahovica,Oraovica,Ораовица', 41.6258300, 22.5133300, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93245, 'Oktisi', 'Oktisi', 'Oktisi,Октиси', 41.2325000, 20.6072200, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93246, 'Ohrid', 'Ohrid', 'Akhris,Gorad Okhryd,OHD,Ochrid,Ochrida,Ochridas,Ochryda,Ocrida,Ohri,Ohrid,Ohrida,Okhri,Okhrid,Okhridu,Oxrid,ao he li de,awhryd,awkhryd,ofurido,oheulideu,ohridi,xo kh rid,Οχρίδα,Горад Охрыд,Охрид,Охрїдъ,Օխրիդ,אוחריד,آکریڈا,أوخريد,اوهرید,โอครีด,ოჰრიდი,オフリド,奥赫里德,오흐리드', 41.1172200, 20.8019400, 'MK', '2012-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93247, 'Ognjaci', 'Ognjaci', 'Ognanci,Ognjaci,Ognjance,Огњанци', 41.9216700, 21.5830600, 'MK', '2008-03-27', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93248, 'Obršani', 'Obrsani', 'Obrsani,Obrshani,Obršani,Обршани', 41.2816800, 21.3615000, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93249, 'Облешево', 'Obleshevo', 'Oblesevo,Obleshevo,Облешево', 41.8833300, 22.3338900, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93250, 'Ново Село', 'Novo Selo', 'Jenikej,Jenikoj,Jeniköj,Novo Selo,Yenikoey,Yenikoj,Yeniköy,Ново Село', 41.4138900, 22.8811100, 'MK', '2014-08-27', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93251, 'Novaci', 'Novaci', 'Komuna e Novacit,Municipio de Novaci,Novaci,Novaci Municipality,Novatsi,Opcina Novaci,Opshtina Novaci,Opstina Novaci,Općina Novaci,Opština Novaci,Vilojati Novatsi,nobachi si,novatsis temi,nuo wa qi qu,Вилояти Новатси,Новаци,Новаці,Општина Новаци,نواتسی بلدیہ,ნოვაცის თემი,诺瓦齐区,노바치 시', 41.0419700, 21.4586600, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93252, 'Нераште', 'Nerashte', 'Nerashte,Нераште', 42.1066700, 21.1088900, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93253, 'Неготино', 'Negotino', 'Negotin,Negotino,Negotino-Poloshko,Negotino-Polosko,Negotino-Pološko,Неготино,Неготино-Полошко', 41.8786100, 20.8838900, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93254, 'Negotino', 'Negotino', 'Negotin,Negotin Vardarski,Negotina,Negotinas,Negotino,negotino,nei ge di nuo,ngwtynw,Неготино,نگوتینو,ნეგოტინო,內戈蒂諾,네고티노', 41.4845600, 22.0905600, 'MK', '2014-04-30', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93255, 'Murtino', 'Murtino', 'Murtino,Муртино', 41.4153700, 22.7258900, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93256, 'Demir Hisar', 'Demir Hisar', 'Demir Chisaras,Demir Hisar,Demir Hisari,Demir Khisar,Demir-Khisar,Murgasevo,Murgashevo,Murgasjevo,Murgaševo,de mi er xi sa er,demileuhisaleu,demir-hisari,dymyr hysar,Демир Хисар,Демир-Хисар,Мургашево,ديمير هيسار,დემირ-ჰისარი,德米爾希薩爾,데미르히사르', 41.2209700, 21.2030200, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93257, 'Morani', 'Morani', 'Morane,Morani,Морани', 41.9097800, 21.5499700, 'MK', '2013-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93258, 'Могила', 'Mogila', 'Mogila,Могила', 41.1083300, 21.3786100, 'MK', '2010-08-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93259, 'Мислешево', 'Misleshevo', 'Mislesevo,Misleshevo,Мислешево', 41.1850000, 20.7086100, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93024, 'Toamasina', 'Toamasina', 'TMM,Tamatave,Toamasina,Tuamasina,toamasina,to~uamashina,tu a ma xi na,twamasyna,Τοαμασίνα,Тоамасина,Туамасина,Туамасіна,טומאסינה,تواماسینا,ტუამასინა,トゥアマシナ,图阿马西纳,토아마시나', -18.1492000, 49.4023400, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93025, 'Vondrozo', 'Vondrozo', '', -22.8166700, 47.2833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93026, 'Vohipaho', 'Vohipaho', 'Vohipaha,Vohipaho', -23.5500000, 47.5000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93027, 'Vohimanitra', 'Vohimanitra', '', -21.7000000, 47.7000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93028, 'Vohibinany', 'Vohibinany', 'Ampasimanolotra,Brickaville', -17.3500000, 49.0333300, 'MG', '2013-08-13', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93029, 'Vavatenina', 'Vavatenina', '', -17.4666700, 49.2000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93030, 'Vangaindrano', 'Vangaindrano', 'VND,Vangaindrano', -23.3500000, 47.6000000, 'MG', '2013-06-10', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93031, 'Tsiroanomandidy', 'Tsiroanomandidy', 'WTS', -18.7696900, 46.0465300, 'MG', '2014-09-07', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93032, 'Tsiombe', 'Tsiombe', 'Tsihombe,Tsiombe', -25.3000000, 45.4833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93033, 'Tsaratanana', 'Tsaratanana', 'TTS', -16.7970600, 47.6516500, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93034, 'Tranovaho', 'Tranovaho', 'Tranovaho,Tranovako,Tranovoa', -25.3000000, 44.9666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93035, 'Toliara', 'Toliara', 'TLE,Toliara,Toliary,Tulear,Tuliara,Tullear,Tuléar,to li xa ra,tolliala,to~uriara,tu li ya la,Τολιάρα,Тулиара,Туліара,טוליארה,โตลีอารา,ტულიარა,トゥリアラ,圖利亞拉,톨리아라', -23.3500000, 43.6666700, 'MG', '2016-03-03', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93036, 'Fort Dauphin', 'Fort Dauphin', 'Faradofay,Taolanaro,Tolagnaro,Tôlagnaro', -25.0324900, 46.9832900, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93037, 'Soavinandriana', 'Soavinandriana', 'Seavinandriana,Soavinandriana', -19.1666700, 46.7333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93038, 'Soanindrariny', 'Soanindrariny', '', -19.9000000, 47.2333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93039, 'Soanierana Ivongo', 'Soanierana Ivongo', 'Saanierana,Soahierana,Soanierana,Soanierana Ivongo', -16.9166700, 49.5833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93040, 'Sitampiky', 'Sitampiky', 'Sitampiki,Sitampiky', -16.6666700, 46.1000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93041, 'Savana', 'Savana', '', -22.3833300, 47.9000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93042, 'Sambava', 'Sambava', 'SVB,Sahambava,Sahambavany,Sambaha,Sambava,Sampava,campava,sambaba,sanbavu~a,sang ba wa,Σαμπάβα,Самбава,சம்பவா,サンバヴァ,桑巴瓦,삼바바', -14.2666700, 50.1666700, 'MG', '2012-07-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93043, 'Sambaina', 'Sambaina', '', -18.9000000, 47.7833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93044, 'Sakaraha', 'Sakaraha', 'Sakaraha,Sakaray', -22.9000000, 44.5333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93045, 'Sahavato', 'Sahavato', '', -20.6000000, 48.3333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93046, 'Sahatavy', 'Sahatavy', '', -17.4500000, 49.0000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93047, 'Sadjoavato', 'Sadjoavato', 'Sadjoavato,Sadjovato', -12.6166700, 49.3500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93048, 'Sadabe', 'Sadabe', '', -18.6333300, 47.7000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93049, 'Ranohira', 'Ranohira', '', -22.4833300, 45.4000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93050, 'Nosy Varika', 'Nosy Varika', '', -20.5833300, 48.5333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93051, 'Nandihizana', 'Nandihizana', 'Carion,Nandihizana', -18.9000000, 47.7166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93052, 'Morondava', 'Morondava', 'MOQ,Morondava,Murundava,molondaba,morondaba,mu long da wa,Мурундава,モロンダバ,穆龙达瓦,모론다바', -20.2886900, 44.3178200, 'MG', '2013-06-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93053, 'Moramanga', 'Moramanga', 'OHB', -18.9494800, 48.2300700, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93054, 'Miarinarivo', 'Miarinarivo', 'Miarinarivo', -18.9587300, 46.9055300, 'MG', '2013-05-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93055, 'Miandrivazo', 'Miandrivazo', 'Miandrivazo,ZVA', -19.5290500, 45.4555900, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93056, 'Miandrarivo', 'Miandrarivo', '', -19.4333300, 46.7500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93057, 'Miadanandriana', 'Miadanandriana', '', -19.0333300, 47.7833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93058, 'Merikanjaka', 'Merikanjaka', '', -19.1333300, 47.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93059, 'Marovoay', 'Marovoay', 'Marovoay', -16.1106400, 46.6438300, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93060, 'Marolambo', 'Marolambo', '', -20.0500000, 48.1166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93061, 'Maroantsetra', 'Maroantsetra', 'Maroantsetra,Maruancentre,WMN,Маруанцентре', -15.4352700, 49.7379400, 'MG', '2016-12-28', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93062, 'Mantasoa', 'Mantasoa', '', -19.0166700, 47.8333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93063, 'Manjakandriana', 'Manjakandriana', '', -18.9166700, 47.8000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93064, 'Manja', 'Manja', 'Fort Manza,MJA', -21.4333300, 44.3333300, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93065, 'Manato', 'Manato', '', -22.4000000, 47.4833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93066, 'Mananjary', 'Mananjary', 'MNJ', -21.2303400, 48.3417300, 'MG', '2017-03-07', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93067, 'Mananara', 'Mananara', 'Mananara,Mananara Avaratra,WMR', -16.1686400, 49.7662200, 'MG', '2013-06-10', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93068, 'Manakara', 'Manakara', 'Manakara,Manankara,WVK,ma na ka la,manakala,manakara,Манакара,Մանակարա,マナカラ,馬納卡拉,마나카라', -22.1486200, 48.0105500, 'MG', '2013-05-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93069, 'Maintirano', 'Maintirano', 'MXT', -18.0635400, 44.0295100, 'MG', '2013-08-04', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93070, 'Mahavelona', 'Mahavelona', 'Foulpointe,Fulpuant,Фулпуант', -17.6847500, 49.5086900, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93071, 'Mahanoro', 'Mahanoro', 'VVB', -19.9000000, 48.8000000, 'MG', '2016-12-30', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93072, 'Mahalina', 'Mahalina', '', -12.5333300, 48.8166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93073, 'Mahajanga', 'Mahajanga', 'Gorad Makhadzanga,MJN,Machatzan''nka,Mahadzanga,Mahajanga,Majunga,Makhadzanga,Makhadzhanga,ma ha zan jia,mahajang-ga,mahajanga,majnka,Μαχατζάνγκα,Горад Махадзанга,Махаджанга,Махадзанга,מאהאזאנגה,ماجنكا,マハジャンガ,马哈赞加,마하장가', -15.7166700, 46.3166700, 'MG', '2011-03-11', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93074, 'Mahabe', 'Mahabe', 'Mahabe,Mahabo', -17.0833300, 45.3333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93075, 'Maevatanana', 'Maevatanana', 'Maevatanana,Maevetanana,Mavatanana,Mevatanana', -16.9500000, 46.8333300, 'MG', '2013-08-04', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93076, 'Kopoky', 'Kopoky', '', -25.2000000, 45.2000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93077, 'Ikongo', 'Ikongo', 'Fort Carhot,Fort-Carnot,Ikongo', -21.8833300, 47.4333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93078, 'Ikalamavony', 'Ikalamavony', 'Ikalamavony', -21.1500000, 46.5833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93079, 'Ihosy', 'Ihosy', 'IHO,Ihosy', -22.4029300, 46.1257600, 'MG', '2013-05-05', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93080, 'Ifatsy', 'Ifatsy', 'Efasy,Efatsy,Ifatsy,Lfatsy', -22.4000000, 47.7500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93081, 'Ifanadiana', 'Ifanadiana', '', -21.3000000, 47.6333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93082, 'Fianarantsoa', 'Fianarantsoa', 'Fianarancua,Fianarantsoa,WFI,fei ya na lan chu a,fianarantsu~oa,fyanarantswa,pianalanchoa,pianarantsua,Φιαναραντσόα,Фианаранцуа,Фіанаранцуа,פיאנארנצוה,فیانارانتسوا,ფიანარანცუა,フィアナランツォア,菲亞納蘭楚阿,피아나란초아', -21.4526700, 47.0856900, 'MG', '2012-06-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93083, 'Fenoarivo Be', 'Fenoarivo Be', 'Fenoarivo,Fenoarivo Afovoany,Fenoarivo Be', -18.4333300, 46.5666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93084, 'Fenoarivo Atsinanana', 'Fenoarivo Atsinanana', 'Fenerive,Fenerive-Atsinanana,Fenerive-Est,Fenoarivo Atsinanana,Fénérive-Atsinanana,Fénérive-Est', -17.3809500, 49.4082600, 'MG', '2013-05-05', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93085, 'Faratsiho', 'Faratsiho', '', -19.4000000, 46.9500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93086, 'Farafangana', 'Farafangana', 'RVA', -22.8222300, 47.8261500, 'MG', '2012-06-23', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93087, 'Fandriana', 'Fandriana', 'Fandriana,Ifandriana', -20.2333300, 47.3833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93088, 'Fandrandava', 'Fandrandava', 'Alakamisy Fandrandava,Alakamisy-Fandandrave,Fandrandava', -21.5166700, 47.2500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93089, 'Betioky', 'Betioky', 'BKU,Betioky', -23.7206500, 44.3806900, 'MG', '2014-03-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93090, 'Beteza', 'Beteza', '', -24.4500000, 45.1166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93091, 'Betafo', 'Betafo', '', -19.8333300, 46.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93092, 'Beroroha', 'Beroroha', 'Beroroha,Beroroho,Beroroka,WBO', -21.6666700, 45.1666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93093, 'Bemaitso', 'Bemaitso', '', -17.0666700, 48.5000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93094, 'Belo sur Tsiribihina', 'Belo sur Tsiribihina', 'BMD,Belo,Belo - Tsiribihina,Belo Tsiribihina,Belo sur Tsiribihina,Belon''i Tsiribihina', -19.6978700, 44.5458700, 'MG', '2013-06-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93095, 'Beloha', 'Beloha', '', -25.1666700, 45.0500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93096, 'Behompy', 'Behompy', '', -23.2500000, 43.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93097, 'Bealanana', 'Bealanana', 'Bealanana,WBE', -14.5432900, 48.7498100, 'MG', '2013-06-10', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93098, 'Arivonimamo', 'Arivonimamo', 'Arivonimamo,Arivonimamy', -19.0166700, 47.1833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93099, 'Antsohimbondrona', 'Antsohimbondrona', 'Antsohimbondrona,Port Saint-Louis', -13.0833300, 48.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93100, 'Antsohihy', 'Antsohihy', 'Antsohihi,Antsohihy,WAI', -14.8795900, 47.9875100, 'MG', '2013-06-10', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93101, 'Antsiranana', 'Antsiranana', 'Anceranana,Antseranana,Antsirana,Antsiranana,Antsirane,Antsiran̈ana,DIE,Diego Soarez,Diego-Suarez,Diégo-Suarez,Анцеранана', -12.3173200, 49.2918800, 'MG', '2016-11-21', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93102, 'Antsirabe Afovoany', 'Antsirabe Afovoany', 'Ansirabe,Antsirabe,Antsirabe Afovoany', -15.9500000, 48.9666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93103, 'Antsirabe', 'Antsirabe', 'ATJ,Ancirabe,Ancirabė,Antisrabe,Antsirabe,Sirabe,an qi la bei,anchilabe,antsu~irabe,antsyraby,Анцирабе,אנטסיראבה,أنتسيرابي,アンツィラベ,安齐拉贝,안치라베', -19.8658600, 47.0333300, 'MG', '2013-08-04', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93104, 'Antanimena', 'Antanimena', '', -23.5500000, 44.1000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93105, 'Antanifotsy', 'Antanifotsy', '', -19.6500000, 47.3166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93106, 'Antananarivo', 'Antananarivo', 'Antananarifo,Antananarivo,Antananarivu,Antananariwo,Antananaryvas,Antananarywa,Antananarívó,Gorad Antananaryvu,TNR,Tana,Tananaribe,Tananarive,an ta na na li fu,anrananarivea,antananalibo,antananaribo,antananarivho,antananarivo,antananaryfw,antananaryww,antʼananarivu,atananarivo,ta na na li fu,xan ta nana ri wo,Ανταναναρίβο,Ταναναρίβη,Антананариво,Антананариву,Антананаріву,Горад Антананарыву,Тананариве,Անտանանարիվու,אנטאנאנאריווא,אנטננריבו,آنتاناناریوو,أنتاناناريفو,ئانتاناناریڤۆ,انٹاناناریوو,اینٹانانیریو,अंतानानारिव्हो,अन्टाननरीवो,ਅੰਤਾਨਾਨਾਰੀਵੋ,அண்டனானரீவோ,ആന്റനനറീവൊ,อันตานานาริโว,ཨེན་ཊ་ན་ན་རི་བོ།,ანტანანარივუ,አንታናናሪቮ,アンタナナリボ,塔那那利佛,安塔那那利佛,안타나나리보', -18.9136800, 47.5361300, 'MG', '2014-03-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93107, 'Antalaha', 'Antalaha', 'ANM,Antalaha,Antalakhi,Анталахи', -14.9003300, 50.2787600, 'MG', '2013-06-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93108, 'Antakotako', 'Antakotako', '', -15.3166700, 49.8000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93109, 'Ankazondandy', 'Ankazondandy', '', -18.7000000, 47.7833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93110, 'Ankazobe', 'Ankazobe', '', -18.3166700, 47.1166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93111, 'Ankazoabo', 'Ankazoabo', 'Ankazoabe,Ankazoabo,Ankazoabo Sud,WAK', -22.2833300, 44.5166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93112, 'Anjozorobe', 'Anjozorobe', '', -18.4000000, 47.8666700, 'MG', '2017-02-14', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93113, 'Anjepy', 'Anjepy', '', -18.8500000, 47.7166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93114, 'Andramasina', 'Andramasina', '', -19.1878500, 47.5901600, 'MG', '2012-07-31', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93115, 'Hell-Ville', 'Hell-Ville', 'Andoany,Hell-Ville,Helville', -13.3971800, 48.2666300, 'MG', '2017-01-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93116, 'Andilamena', 'Andilamena', '', -17.0100900, 48.5731300, 'MG', '2012-07-30', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93117, 'Andovoranto', 'Andovoranto', 'Andevorante,Andevoranto,Andovoranto', -18.9544300, 49.1094000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93118, 'Andapa', 'Andapa', 'ZWA', -14.6500000, 49.6500000, 'MG', '2017-03-03', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93119, 'Anandravy', 'Anandravy', 'Anadray,Anandravy', -22.9000000, 47.3666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93120, 'Anakao', 'Anakao', '', -23.6666700, 43.6500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93121, 'Ampasimanolotra', 'Ampasimanolotra', 'Ampasimanolotra,Brickaville,Vohibinany', -18.8166700, 49.0666700, 'MG', '2013-10-30', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93122, 'Amparafaravola', 'Amparafaravola', 'Amparafarovola,Amparofaravola', -17.5876000, 48.2239100, 'MG', '2012-11-05', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93123, 'Ampanihy', 'Ampanihy', 'AMP,Ampanihy', -24.6937000, 44.7458100, 'MG', '2013-06-09', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93124, 'Ampahana', 'Ampahana', 'Ampaha,Ampahana', -14.7500000, 50.2166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93125, 'Ambovombe', 'Ambovombe', '', -25.1783800, 46.0872200, 'MG', '2013-05-05', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93126, 'Ambositra', 'Ambositra', 'Ambositra', -20.5303400, 47.2434400, 'MG', '2013-05-05', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93127, 'Ambohitseheno', 'Ambohitseheno', '', -18.7833300, 47.8000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93128, 'Ambohitrolomahitsy', 'Ambohitrolomahitsy', '', -18.7000000, 47.6833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93129, 'Ambohitrandriamanitra', 'Ambohitrandriamanitra', 'Ambohiandriamanitra,Ambohitrandriamanitra', -19.0833300, 47.7833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93130, 'Ambodivoara', 'Ambodivoara', '', -14.3333300, 49.9833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93131, 'Ambodifotatra', 'Ambodifotatra', 'Ambodifotatra,Ambodifototra', -16.9833300, 49.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93132, 'Amboasary', 'Amboasary', 'Amboasary,Amboasary Sud', -25.0333300, 46.3833300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93133, 'Amboasary', 'Amboasary', 'Amboasary', -24.3333300, 45.9500000, 'MG', '2012-07-30', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93134, 'Amboanjo', 'Amboanjo', '', -22.0000000, 47.8500000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93135, 'Ambilobe', 'Ambilobe', 'AMB', -13.2000000, 49.0500000, 'MG', '2017-03-03', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93136, 'Ambatondrazaka', 'Ambatondrazaka', 'Ambatondrazaka,Ambatonoradrazaka,Ambatundrazaka,WAM,ambatwndrazak,an ba tong de la zha ka,Амбатундразака,امباتوندرازاک,安巴通德拉扎卡', -17.8333300, 48.4166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93137, 'Ambatolaona', 'Ambatolaona', '', -18.9333300, 47.9000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93138, 'Ambatolampy', 'Ambatolampy', '', -19.3833300, 47.4166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93139, 'Ambatofinandrahana', 'Ambatofinandrahana', 'Ambatofinandrahana', -20.5528400, 46.8036500, 'MG', '2012-06-23', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93140, 'Ambato Boeny', 'Ambato Boeny', 'Ambato,Ambato Boeni,Ambato Boeny,Ambatoboeny', -16.4666700, 46.7166700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93141, 'Ambarakaraka', 'Ambarakaraka', '', -13.5000000, 48.8666700, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93142, 'Ambanja', 'Ambanja', 'Ambanja,IVA', -13.6690000, 48.4530000, 'MG', '2017-03-04', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93143, 'Ambalavao', 'Ambalavao', 'Ambalava,Ambalavao', -21.8333300, 46.9333300, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93144, 'Ambalasoa', 'Ambalasoa', '', -23.1166700, 46.0000000, 'MG', '2013-06-06', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93145, 'Alarobia', 'Alarobia', 'Alarobi', -18.9666700, 47.7333300, 'MG', '2015-07-22', 133);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93146, 'Likiep', 'Likiep', '', 9.8251100, 169.3106500, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93147, 'Jabor', 'Jabor', 'Jabooru,Jaboru,Jabwor,Jebwad', 5.9209800, 169.6433500, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93148, 'Ailuk', 'Ailuk', 'Enellik Island', 10.2197200, 169.9796700, 'MH', '2013-04-03', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93149, 'Majuro', 'Majuro', 'MAJ,Madzhuro,Majur,Majuro,Mazouro,Μαζούρο,Маджуро', 7.0897100, 171.3802700, 'MH', '2016-11-22', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93150, 'Taroa', 'Taroa', '', 8.7057600, 171.2275000, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93151, 'Ebaye', 'Ebaye', 'Epja,Epjā,Ibae', 8.7747900, 167.7391900, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93152, 'Enewetak', 'Enewetak', '', 11.3473500, 162.3373300, 'MH', '2010-08-05', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93153, 'Ebon', 'Ebon', 'EBO,Epoon', 4.5819900, 168.6963600, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93154, 'Aur', 'Aur', '', 8.1499000, 171.1686900, 'MH', '2013-04-03', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93155, 'Arno', 'Arno', '', 7.0669100, 171.5541300, 'MH', '2013-08-04', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93156, 'Airuk', 'Airuk', 'Airok,Airuk', 7.2771700, 168.8203000, 'MH', '2013-03-10', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93157, 'Mili', 'Mili', '', 6.0815000, 171.7350200, 'MH', '2013-04-03', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93158, 'Lae', 'Lae', 'Lae', 8.9221700, 166.2634400, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93159, 'Utrik', 'Utrik', 'Utirik,Utrik,Utrok,Utrōk', 11.2277800, 169.8473900, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93160, 'Ujae', 'Ujae', 'Ujae,Wujae,Wūjae', 8.9321800, 165.7641600, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93161, 'Rongelap', 'Rongelap', 'Ronlap,Ron̄ļap', 11.1635100, 166.8940800, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93162, 'Loen', 'Loen', '', 7.7600700, 168.2307200, 'MH', '2010-08-06', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93163, 'Namdrik', 'Namdrik', 'Namdik,Namorik,Nam̧dik', 5.5994400, 168.1028200, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93164, 'Mejit', 'Mejit', 'Majeej,Majej,Mājeej,Mājej', 10.2753100, 170.8646100, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93165, 'Lib', 'Lib', '', 8.3122100, 167.3766200, 'MH', '2013-04-03', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93166, 'Kili', 'Kili', '', 5.6438700, 169.1210900, 'MH', '2013-04-03', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93167, 'Jabat', 'Jabat', 'Jabot,Jabwot,Jebat', 7.7500300, 168.9751300, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93168, 'Wotje', 'Wotje', '', 9.4542900, 170.2367400, 'MH', '2013-03-07', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93169, 'Wotho', 'Wotho', 'Wotto,Wōtto', 10.1657500, 166.0102200, 'MH', '2013-08-09', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93170, 'RMI Capitol', 'RMI Capitol', '', 7.0893100, 171.3805000, 'MH', '2011-07-11', 139);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92913, 'Tiraspolul Nou', 'Tiraspolul Nou', 'Novotiraspol''skij,Novotiraspol''skiy,Novotiraspol’skiy,Slobodka,Tiraspolul Nou,Zakrepostnaya Slobodka,Новотираспольский', 46.8287400, 29.5217400, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92914, 'Edineţ', 'Edinet', 'Edincy,Edinec,Edinet,Edineţ,Edineț,Edinita,Edinita-Targ,Ediniti,Ediniţa,Ediniţa-Târg,Edintsy,Yedintsy-Tyrg,edinecheu,Единец,Единцы,에디네츠', 48.1721500, 27.3033700, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92915, 'Iargara', 'Iargara', 'Iagara,Iargara,Jargara,Poselok Yargora,Posëlok Yargora,Yargara,Yargora,Яргара', 46.4252000, 28.4267600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92916, 'Vulcăneşti', 'Vulcanesti', 'Valkaneshty,Volkaneshty,Volkenesht'',Volkenesht’,Volkoneshty,Vulcanesti,Vulcăneşti,Vulkaneshty,Vulkeneshti,Вулканешты', 45.6849200, 28.4061300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92917, 'Vişniovca', 'Visniovca', 'Vishnevka,Vishnëvka,Visinesti,Visniovca,Vişineşti,Vişniovca,Вишневка', 46.3326000, 28.4479700, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92918, 'Varniţa', 'Varnita', 'Varnica,Varnitsa,Варница', 46.8660600, 29.4663600, 'MD', '2010-07-21', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92919, 'Vadul lui Vodă', 'Vadul lui Voda', 'Vadu-luy-Vode,Vadul lui Voda,Vadul lui Vodă,Vadul-Luj-Vodeh,Vadul-Luy-Vode,Vaduluy-Vody,Vady-Lui Voda,Vady-Luy-Voda,Вадул-Луй-Водэ', 47.0900900, 29.0757000, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92920, 'Ustia', 'Ustia', 'Ust''e,Ust''ye,Ustia,Ustya,Ust’ye,Устье', 47.2552400, 29.1240600, 'MD', '2016-12-25', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92921, 'Ungheni', 'Ungheni', 'Ukgeni Tyrg,Ungen,Ungen'',Ungen'' Tyrg,Ungeni,Ungenis,Ungeny,Ungen’ Tyrg,Ungheni,Ungheni Targ,ungeni,wen ge nei,Унген,Унгени,Унгены,Унгень,אונגני,溫格內,운게니', 47.2107900, 27.8004700, 'MD', '2015-12-07', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92922, 'Tvardița', 'Tvardita', 'Tvardica,Tvardita,Tvarditsa,Tvardiţa,Tvardița,Твардица', 46.1482600, 28.9649100, 'MD', '2016-11-29', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92923, 'Tiraspol', 'Tiraspol', 'Gorad Ciraspal'',Tiraspol,Tiraspol'',Tiraspole,Tiraspoli,Tiraspolis,Tiraspolo,Tiraspol’,Tiráspol,Tyraspol,di la si bo er,ti ras pxl,tilaseupol,tirasupori,tyrasbwl,tyraspwl,tyrspwl,Горад Ціраспаль,Тираспол,Тирасполь,Тираспољ,טירספול,تيراسبول,تیراسپول,ตีรัสปอล,ტირასპოლი,ティラスポリ,蒂拉斯波尔,티라스폴', 46.8427400, 29.6290900, 'MD', '2017-06-06', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92924, 'Teleneşti', 'Telenesti', 'Telenesht''-Tyrg,Teleneshty,Telenesht’-Tyrg,Telenesti,Telenesti Targ,Teleneşti,Teleneşti Târg,Tseleneshti-Tyrg,Теленешты', 47.5011000, 28.3653600, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92925, 'Taraclia', 'Taraclia', 'Taraclia,Taraklija,Tarakliya,Тараклия', 45.9027300, 28.6681600, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92926, 'Sîngera', 'Singera', 'Sangera,Singera,Synzhera,Sângera,Sîngera,Сынжера', 46.9155700, 28.9667300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92927, 'Ştefan Vodă', 'Stefan Voda', 'Shtefan-Vode,Shtefan-Vodeh,Stefan Voda,Suvorovo,Ştefan Vodă,Суворово,Штефан-Водэ', 46.5128700, 29.6619300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92928, 'Strășeni', 'Straseni', 'Straseni,Strasheny,Străşeni,Strășeni,Страшены', 47.1421600, 28.6077400, 'MD', '2016-11-29', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92929, 'Stăuceni', 'Stauceni', 'Stauceni,Stavcheny,Stăuceni,Ставчены', 47.0964300, 28.8679100, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92930, 'Bilicenii Vechi', 'Bilicenii Vechi', 'Belichany,Biliceni,Bilicenii Vechi,Bilichen'',Bilicheni,Bilichen’,Bliceni,Gilicheny,Starye Bilicheny,Staryye Bilicheny,Старые Биличены', 47.6558000, 28.0473400, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92931, 'Soroca', 'Soroca', 'Soroca,Soroka,Soroki,Сорока,Сороки', 48.1565900, 28.2848900, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92932, 'Şoldăneşti', 'Soldanesti', 'Chernenko,Sholdanesht'',Sholdaneshti,Sholdaneshty,Sholdanesht’,Sholdenesht'',Sholdenesht’,Soldanesti,Şoldăneşti,Шолданешты', 47.8160800, 28.7971800, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92933, 'Slobozia', 'Slobozia', 'Gorad Slabadzeja,Moldavanskaya-Slobodzaya,Slabodzeja,Slabodzėja,Slobodzeja,Slobodzeya,Slobodzeya Moldavanskaya,Slobozia,si luo bo qi ya,Горад Слабадзея,Слободзея,斯洛博齊亞', 46.7292700, 29.7044600, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92934, 'Saharna', 'Saharna', 'Saharna,Sakharna,Sukharna,Сахарна', 47.6910700, 28.9745800, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92935, 'Rîşcani', 'Riscani', 'Rascani,Rascani Targ,Rashkan'' Tyrg,Rashkani-Tyrg,Rashkan’ Tyrg,Riscani,Ryshkanovka,Ryshkany,Râşcani,Râşcani Târg,Rîşcani,Рышканы', 47.9479200, 27.5637600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92936, 'Rîbniţa', 'Ribnita', 'Rabnita,Ribnica,Ribnicja,Ribnita,Ribņica,Rybnica,Rybnitsa,Rybniza,Râbniţa,Râbnița,Rîbniţa,Rîbnița,rybnyzh,Рибниця,Рыбница,ריבניצה', 47.7681700, 29.0100000, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92937, 'Rezina', 'Rezina', 'Rezina,Rezina Targ,Rezina Târg,Rezina-Tirg,Rezina-Tîrg,Резина', 47.7492800, 28.9658300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92938, 'Pervomaisc', 'Pervomaisc', 'Pervomaisc,Pervomajsk,Pervomaysk,Pervomayskoye,Первомайск', 46.7325300, 29.9617000, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92939, 'Orhei', 'Orhei', 'Orgeev,Orgeyev,Orgiejow,Orgiejów,Orgiiv,Orhei,Orheiu,Orhejus,Orhėjus,Orkhej,Orkhey,ao er hai yi,oleuhei,orhei,Оргеев,Оргіїв,Орхей,Орхеј,אורחיי,اورہیئی,ორჰეი,奧爾海伊,오르헤이', 47.3849400, 28.8244600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92940, 'Ocniţa', 'Ocnita', 'Ocnita,Ocniţa,Oknica,Oknitsa,Окница', 48.3827400, 27.4380500, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92941, 'Anenii Noi', 'Anenii Noi', 'Aneni Nouy,Anenii Noi,Anenii Noui,Novo-Aneny,Novye Aneny,Novyye Aneny,Новые Анены', 46.8783900, 29.2348300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92942, 'Nisporeni', 'Nisporeni', 'Nisiporeni,Nisporeni,Nisporeny,Nisporyany,Ниспорены', 47.0815900, 28.1713800, 'MD', '2017-05-07', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92943, 'Mîndreşti', 'Mindresti', 'Mandresti,Mindresti,Myndresht'',Myndreshti,Myndreshty,Myndresht’,Mândreşti,Mîndreşti,Мындрешты', 47.5052500, 28.2768700, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92944, 'Maiac', 'Maiac', 'Maiac,Majak,Mayak,Маяк', 47.2372700, 29.3849800, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92945, 'Mărculeşti', 'Marculesti', 'Marculesti,Markulesht''-Kolon,Markuleshti-Kolon,Markuleshty,Markuleshty-Kolon,Markulesht’-Kolon,Mărculeşti,Маркулешты', 47.8689700, 28.2410900, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92946, 'Leova', 'Leova', 'Leova,Leovo,Levo,Леово', 46.4823000, 28.2530100, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92947, 'Sîngerei', 'Singerei', 'Lazovsk,Sangerei,Senzherey,Singerei,Syndzherey,Synzhereja,Synzhereya,Synzheria,Sângerei,Sîngerei,Лазовск,Сынжерея', 47.6363200, 28.1429600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92948, 'Cricova', 'Cricova', 'Cricova,Krikova,Krikovo,Криково', 47.1383500, 28.8615600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92949, 'Crasnoe', 'Crasnoe', 'Crasna,Crasnoe,Krasnoe,Krasnoye,Красное', 46.6484400, 29.8040300, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92950, 'Hînceşti', 'Hincesti', 'Ganchesty,Gynchesht'',Gynchesht’,Hancesti,Hincesti,Hânceşti,Hînceşti,Khencheshti,Khynchesht'',Khyncheshty,Khynchesht’,Kotovsk,Kotovskoye,Котовск,Хынчешты', 46.8304700, 28.5906400, 'MD', '2015-11-26', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92951, 'Cocieri', 'Cocieri', 'Cocieri,Kochiery,Kochiyery,Kucheyer,Kuchiyer,Kuchiyery,Кочиеры', 47.3017000, 29.1175500, 'MD', '2015-04-11', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92952, 'Chiţcani', 'Chitcani', 'Kickany,Kitskan'',Kitskani,Kitskany,Кицканы', 46.7829600, 29.6168200, 'MD', '2010-07-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92953, 'Căuşeni', 'Causeni', 'Causani-Novi,Causanii-Noui,Causeni,Căuşani-Novi,Căuşanii-Noui,Căuşeni,Căușeni,Kaushani,Kaushani-Noui,Kaushany,Keusenis,Keušenis,Noui Causanii,Noui Căuşanii,Novo Kaushani,Novyye Kaushany,Novyye Keushani,kawshyny,ke wu xie ni,keousyeni,Каушани,Каушаны,کاؤشینی,克烏謝尼,커우셰니', 46.6367400, 29.4111400, 'MD', '2015-05-06', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92954, 'Ialoveni', 'Ialoveni', 'Ialoveni,Jaloveny,Kutuzov,Ploreny,Ploveny,Yaloven'',Yaloveny,Yaloven’,Yalovyany,Кутузов,Яловены', 46.9434600, 28.7823300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92955, 'Grigoriopol', 'Grigoriopol', 'Gorad Grygaryjopal'',Grigoriopol,Grigoriopol'',Grigoriopolis,Grigoriopol’,Grigoriupol,ge li ge li ao bo er,geuligoliopol,Горад Грыгарыёпаль,Григориополь,Григоріополь,Գրիգորիուպոլ,格里戈里奧波爾,그리고리오폴', 47.1541300, 29.3000800, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92956, 'Glodeni', 'Glodeni', 'Gloden'',Glodeni,Gloden’,Glodjany,Glodyany,Malyye Glodyany,Глодяны', 47.7751300, 27.5189100, 'MD', '2015-11-26', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92957, 'Ghindești', 'Ghindesti', 'Ghindesti,Ghindeşti,Ghindești,Gindeshty,Gyndesht'',Gyndesht’,Leninskij,Leninskiy,Гиндешты,Ленинский', 47.8548200, 28.3767900, 'MD', '2017-04-21', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92958, 'Floreşti', 'Floresti', 'Floresht'',Floreshti,Floreshty,Floresht’,Floresti,Floreşti,Флорешты', 47.8913700, 28.2931200, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92959, 'Fălești', 'Falesti', 'Faleshti,Faleshty,Falesti,Fălești,Фалешти,Фалешты', 47.5766700, 27.7126400, 'MD', '2016-08-22', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92960, 'Giurgiuleşti', 'Giurgiulesti', 'Dzhurdzhulesht'',Dzhurdzhuleshti,Dzhurdzhuleshty,Dzhurdzhulesht’,Dzhurzhuleshty,Giurgiulesti,Giurgiuleşti,Zhurzhuleshty,Джурджулешты', 45.4816700, 28.1972200, 'MD', '2012-01-17', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92961, 'Dubăsari', 'Dubasari', 'Dubasari,Dubehsar'',Dubosari,Dubossary,Dubăsari,dubeosali,Дубоссары,Дубэсарь,두버사리', 47.2656200, 29.1666700, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92962, 'Drochia', 'Drochia', 'Drochia,Drokija,Drokiya,Drokiya Sat,Дрокия', 48.0355500, 27.8129300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92963, 'Donduşeni', 'Donduseni', 'Dondusani,Donduseni,Dondushen'',Dondushen’,Donduşeni,Donduşăni,Dondyushany', 48.2426800, 27.6101000, 'MD', '2011-04-13', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92964, 'Dnestrovsc', 'Dnestrovsc', 'Dnestrovsc,Dnestrovsk,Dnestrovskas,Dnistrovs''k,Gorad Dnjastrousk,de nie si te luo fu si ke,Горад Днястроўск,Днестровск,Дністровськ,德涅斯特羅夫斯克', 46.6164000, 29.9192600, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92965, 'Dancu', 'Dancu', 'Dan''ka,Dancu,Danku,Dan’ka,Данку', 46.7581800, 28.2071600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92966, 'Criuleni', 'Criuleni', 'Criuleni,Kriulen'',Kriuleni,Kriulen’,Kriuljany,Kriulyany,Krivleny,Kryulyany,Криуляны', 47.2130700, 29.1592600, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92967, 'Comrat', 'Comrat', 'Comrat,Gorad Kamrat,Komrad,Komrat,Komratas,ke mu la ci,khxm rat,komlateu,kwmrat,Κομράτ,Горад Камрат,Комрат,کومرات,คอมรัต,კომრატი,科姆拉茨,콤라트', 46.2945600, 28.6565000, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92968, 'Cimişlia', 'Cimislia', 'Chimishlija,Chimishliya,Cimislia,Cimişlia,Чимишлия', 46.5268500, 28.7644100, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92969, 'Chisinau', 'Chisinau', 'Chisinau,Chişinău,Chișinău,KIV,Kischinew,Kiscinev,Kishinef,Kishinehu,Kishinev,Kishiniv,Kishinjov,Kishinëv,Kisinaou,Kisinev,Kisineva,Kisinevo,Kisiniovas,Kisinjev,Kisinov,Kisinyov,Kisyneu,Kiszyniow,Kiszyniów,Kiŝinevo,Kişinev,Kišiniovas,Kišinjev,Kišiněv,Kišiņeva,Kišiňov,cisina''u,cisinau,ji xi ne wu,kishinau,kisineou,kyshynaw,Κισινάου,Κισιναου,Кишинев,Кишинэу,Кишинёв,Кишињев,Кішынёў,Կիշինյով,קישינאו,كيشيناو,चिशिनाउ,चिशिनौ,კიშინიოვი,ኪሺንው,キシナウ,基希讷乌,키시너우', 47.0055600, 28.8575000, 'MD', '2016-08-22', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92970, 'Ceadîr-Lunga', 'Ceadir-Lunga', 'Ceadar-Lunga,Ceadir-Lunga,Ceadâr-Lunga,Ceadîr-Lunga,Chadyr-Lunga,Чадыр-Лунга', 46.0616900, 28.8307800, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92971, 'Cantemir', 'Cantemir', 'Cantemir,Kantemir,Кантемир', 46.2774300, 28.2027000, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92972, 'Camenca', 'Camenca', 'Camenca,Gorad Kamenka,Kamenka,Kamenka-Moldavskaya,Kamionka,Kamjanka,ka men ka,kamenka,kamynka,Горад Каменка,Каменка,Камянка,کامینکا,卡門卡,카멘카', 48.0323300, 28.6989900, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92973, 'Călăraşi', 'Calarasi', 'Calarasi,Calarasi-Targ,Călărasi-Targ,Călăraşi,Kalarash,Kelerashi-Tyrg,Калараш', 47.2556000, 28.3098700, 'MD', '2017-05-07', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92974, 'Cahul', 'Cahul', 'Cahul,Gorad Kakhul,Kagul,Kaguł,Kahul,Kahulis,Kakhul,ka hu er,kahul,qʼhwl,Горад Кахул,Кагул,Кахул,קאחול,کاہول,კაჰული,卡胡爾,카훌', 45.9042500, 28.1992900, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92975, 'Bucovăţ', 'Bucovat', 'Bucovat,Bucovăţ,Bykovec,Bykovets,Быковец', 47.1906400, 28.4580200, 'MD', '2017-01-04', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92976, 'Bugeac', 'Bugeac', 'Budzhak,Bugeac,Komrat,Комрат', 46.3655400, 28.6625000, 'MD', '2017-05-07', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92977, 'Briceni', 'Briceni', 'Briceni,Briceni-Targ,Briceni-Târg,Brichany,Brichen'' Sat,Bricheni Sat,Brichen’ Sat,Бричаны', 48.3628900, 27.0778700, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92978, 'Briceni', 'Briceni', 'Briceni,Brichany,Brichen'',Brichen’,Бричаны', 48.3562800, 27.7029300, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92979, 'Bender', 'Bender', 'Bendary,Bender,Bendera,Benderai,Benderi,Bendery,Bəndər,Gorad Bendehr,Tighina,Tigina,bendeleu,benderi,benderu,bin jie li,byndr,byndr  maldwwa,tygynh,Бендер,Бендери,Бендеры,Горад Бендэр,Тигина,טיגינה,بيندر,بیندر، مالدووا,ბენდერი,ベンデル,賓傑里,벤데르', 46.8315600, 29.4776900, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92980, 'Basarabeasca', 'Basarabeasca', 'Basarabeasca,Basarabiaska,Besarabka,Bessarabka,Bessarabskaya,Bessarabskiy,Romaneshti,Romanesti,Romanovka,Romanovo,Romynesht'',Romynesht’,Româneşti,ba sa la bei ya si ka,basalabeaseuka,basarabyaska,bysarabka,Бесарабка,Бессарабка,باسارابياسكا,بیسارابکا,ბასარაბეასკა,巴薩拉貝亞斯卡,바사라베아스카', 46.3317000, 28.9636500, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92981, 'Bălţi', 'Balti', 'BZY,Balti,Baltsy,Behlc'',Bel''cy,Bel''tsy,Belcai,Belci,Beltsi,Bel’tsy,Bielce,Byelcy,Bălţi,Bălți,Municipalite de Balti,Municipalité de Bălţi,blzy,Белци,Бельцы,Бэлць,בלצי', 47.7631400, 27.9293200, 'MD', '2017-01-20', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92982, 'Otaci', 'Otaci', 'Ataki,Otach-Tyrg,Otaci,Атаки', 48.4328500, 27.7991200, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92983, 'Vatra', 'Vatra', 'Gara Ghidighici,Gidigich,Vatra,Ватра,Гидигич', 47.0746000, 28.7368500, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92984, 'Ciorescu', 'Ciorescu', 'Ciorescu,Krikova-Noue,Krikova-Noueh,Крикова-Ноуэ', 47.1300000, 28.8893700, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92985, 'Biruinţa', 'Biruinta', 'Biruinca,Biruinta,Biruintsa,Biruinţa,Бируинца', 47.8135300, 28.0700400, 'MD', '2015-04-08', 146);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92907, 'Monte-Carlo', 'Monte-Carlo', 'Monte Carlo,Monte Karlo,Monte Karló,Monte-Karlo,Montecarlo,XMM,Монте-Карло', 43.7397600, 7.4273200, 'MC', '2013-03-22', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92908, 'Monaco', 'Monaco', 'MCM,Monaco,Monaco-Ville,Monako,Mònaco,Mónaco,Mónakó,Μονακό,Монако', 43.7333300, 7.4166700, 'MC', '2014-01-26', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92909, 'La Condamine', 'La Condamine', 'Condamine,La Condamine,La-Kondamin,Ла-Кондамин', 43.7343900, 7.4202400, 'MC', '2013-03-22', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92910, 'Fontvieille', 'Fontvieille', 'Fontvieille,Fontvielha,Fontvill'',Fonv''ej,Fonvjejus,Fonvjėjus,Fonvyey,Fòntvielha,fang te wei ye,pongbieyu,Фонвьей,Фонтвілль,Ֆոնվյեյ,芳特维耶,퐁비에유', 43.7268700, 7.4176600, 'MC', '2013-08-18', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92911, 'Saint-Roman', 'Saint-Roman', '', 43.7489000, 7.4342300, 'MC', '2013-02-07', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92912, 'Moneghetti', 'Moneghetti', 'Les Moneghetti,Monegetti,Moneghetti,Monegue,Монегетти', 43.7367900, 7.4164700, 'MC', '2014-07-30', 147);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92986, 'Rožaje', 'Rozaje', 'Roza,Rozagie,Rozaj,Rozaje,Rozhae,Rozhaja,Rozhaje,Rozhajë,Roža,Rožaj,Rožajė,lojaye,luo zha yi,rojai~e,rozhaie,rwzhayh,Ρόζαγιε,Рожае,Рожає,Рожаје,روژایه,روژایے,როჟაიე,ロジャイェ,羅扎伊,로자예', 42.8329900, 20.1665200, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92987, 'Žabljak', 'Zabljak', 'Aleksandrov Grad,Zabliakas,Zhabjaku,Zhablak,Zhabljak,jabeullakeu,jaburyaku,zha bu li ya ke,zhablyak,Žabliakas,Жабляк,Жабљак,ژابلیاک,ジャブリャク,扎布利亞克,자블라크', 43.1542300, 19.1232500, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92988, 'Ulcinj', 'Ulcinj', 'Dulcigno,Oultsin,UElguen,Ul''cin'',Ulcin,Ulcin'',Ulcinis,Ulcinium,Ulcinj,Ulqini,awlkwn,awltsyny,ulchin,ultsini,urutsu~ini,wu er qi ni,Ülgün,Ούλτσιν,Улцин,Улцинь,Улцињ,Ульцинь,אולצין,اولتسینی,اولکون,ულცინი,ウルツィニ,烏爾齊尼,울친', 41.9293600, 19.2243600, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92989, 'Tuzi', 'Tuzi', 'Tuzai,Tuzi,to~uji,tuji,twzy,Тузи,Тузі,توزی,トゥジ,투지', 42.3655600, 19.3313900, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92990, 'Tivat', 'Tivat', 'TIV,Teodo,Tivat,Тиват,Тіват', 42.4363900, 18.6961100, 'ME', '2014-08-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92991, 'Sutomore', 'Sutomore', 'Spic,Spič,Sutomor,Sutomore,Сутоморе', 42.1427800, 19.0466700, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92992, 'Stari Bar', 'Stari Bar', 'Stari Bar', 42.0970000, 19.1360000, 'ME', '2016-09-29', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92993, 'Spuž', 'Spuz', 'Spuz,Spuž', 42.5150000, 19.1950000, 'ME', '2016-09-29', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92994, 'Šavnik', 'Savnik', 'Savnik,Shavnik,Šavnik,Шавник,Шавнік', 42.9563900, 19.0966700, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92995, 'Risan', 'Risan', 'Risan,Risanas,Risani,Risano,li sang,rysan,Рисан,Рісан,ریسان,里桑', 42.5150000, 18.6955600, 'ME', '2013-01-25', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92996, 'Prčanj', 'Prcanj', 'Perzagno,Prcanj,Prčanj', 42.4575000, 18.7422200, 'ME', '2015-06-24', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92997, 'Podgorica', 'Podgorica', 'Birziminium,Gorad Padgoryca,Podgairitse,Podgairítse,Podgorica,Podgoricae,Podgoricja,Podgorico,Podgorika,Podgoritsa,Podgoritza,Podgorytsa,Podgòrica,Podqoritsa,Podugorica,Pontnkoritsa,TGD,Titograd,bo de ge li cha,bwdghwrytsa,padagoritasa,phx dk xrit sa,podagorika,podeugolicha,podogoritsu~a,potkorikka,pwdgwrytsa,pwdgwryzh,pۆdgۆrytsa,Ποντγκόριτσα,Горад Падгорыца,Подгоритса,Подгорицæ,Подгорица,Подгориця,Подъгорица,Պոդգորիցա,פודגוריצה,بودغوريتسا,پودگوریتسا,پوڈگوریکا,پۆدگۆریتسا,पॉडगोरिका,ਪਾਡਗੋਰਿਤਸਾ,பொட்கொரிக்கா,พอดกอรีตซา,პოდგორიცა,ፖድጎሪጻ,ポドゴリツァ,波德戈里察,포드고리차', 42.4411100, 19.2636100, 'ME', '2016-05-08', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92998, 'Plužine', 'Pluzine', 'Pluzhina,Pluzhine,Pluzine,Pluzine vald,Plužine,Plužine vald,Plužinė,peullujine,plwzhynh,pu lu ri nei,purujine,Плужине,پلوژینه,プルジネ,普盧日內,플루지네', 43.1527800, 18.8394400, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92999, 'Pljevlja', 'Pljevlja', 'Ljevlja,Plevla,Plevlia,Plevlja,Plevlje,Pljevlja,Pljevlje,peullebeulla,plyflya,pu lie fu li ya,puryevurya,Плевля,Плєвля,Пљевља,پلیفلیا,プリェヴリャ,普列夫利亞,플레블라', 43.3567000, 19.3584300, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93000, 'Plav', 'Plav', 'Komuna e Plaves,Komuna e Plavës,Plav,Plav-Gusinje,Plavas,Plave,Plavi vald,Plavë,peullabeu,plaw,pu la fu,puravu,Плав,پلاو,پلاو، مونٹینیگرو,პლავი,プラヴ,普拉夫,플라브', 42.5969400, 19.9455600, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93001, 'Petrovac na Moru', 'Petrovac na Moru', 'Petrovac,Petrovac na Moru,Петровац', 42.2055600, 18.9425000, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93002, 'Nikšić', 'Niksic', 'Nikshic,Nikshich,Nikshik,Nikshiqi,Niksicius,Nikšičius,ni ke xi qi,nigsichi,nikh sikh,nikushitchi,nykshych,Никшич,Никшић,Никшиќ,نیکشیچ,นิคซิค,ニクシッチ,尼克希奇,닉시치', 42.7731000, 18.9444600, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93003, 'Mojkovac', 'Mojkovac', 'Mojkovac,Мойковац,Мојковац', 42.9604400, 19.5833000, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93004, 'Mojanovići', 'Mojanovici', 'Mojanovici,Mojanovići', 42.3416700, 19.2213900, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93005, 'Mataguži', 'Mataguzi', 'Mataguzi,Mataguži', 42.3236100, 19.2727800, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93006, 'Lipci', 'Lipci', 'Lipci,Липци', 42.4972200, 18.6580600, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93007, 'Kotor', 'Kotor', 'Cattaro,Cattoro,Kotor,ZKQ,kotoleu,kotoru,Котор,コトル,코토르', 42.4206700, 18.7682500, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93008, 'Kolašin', 'Kolasin', 'Kolashin,Kolasin,Kolasinas,Kolasini vald,Kolaşin,Kolašin,Kolašinas,Kolašini vald,Koloshini,ke la xin,kollasin,korashin,kwlashn,kwlashyn,Колашин,קולאשין,کولاشن,کولاشین,კოლაშინი,コラシン,科拉欣,콜라신', 42.8222900, 19.5165300, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93009, 'Berane', 'Berane', 'Beran,Berane,Beranė,IVG,Ivangrad,bei la nei,belane,berane,branh,brany,Беране,برانه,براني,ベラネ,貝拉內,베라네', 42.8425000, 19.8733300, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93010, 'Igalo', 'Igalo', 'Igalo,Игало', 42.4600700, 18.5064700, 'ME', '2010-07-20', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93011, 'Herceg-Novi', 'Herceg-Novi', 'Castelnuovo,Castelnuovo di Cattaro,Ercegnovi,HNO,Herceg Novi,Herceg-Novi,Kherceg Novi,Kherceg-Novi,Kherceg-Novij,kherceg novi,Херцег Нови,Херцег-Нови,Херцег-Новий', 42.4530600, 18.5375000, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93012, 'Golubovci', 'Golubovci', 'Golubovcai,Golubovci,gollubobeuchi,gorubovutsu~i,gwlwbwftsy,gwlwbwwtsy,Голубовци,گولوبوفتسی,گولوبووتسی,ゴルボヴツィ,골루보브치', 42.3350000, 19.2311100, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93013, 'Dobrota', 'Dobrota', 'Dobrota,Mesto Dobrota,Доброта', 42.4541700, 18.7683300, 'ME', '2012-01-19', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93014, 'Danilovgrad', 'Danilovgrad', 'Danilovgrad,Danilovgradas,Danilovgradi,da ni luo fu ge lei,danillobeugeuladeu,danirovugurado,danylwfgrad,Даниловград,دانیلوفگراد,ダニロヴグラード,達尼洛夫格勒,다닐로브그라드', 42.5538400, 19.1460800, 'ME', '2013-07-03', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93015, 'Cetinje', 'Cetinje', 'Cetina,Cetine,Cetiniѥ,Cetinje,Cetinjo,Cetinė,Cetiña,Cettigne,Cettinge,Cetynia,cai di nie,chetine,se ti neiy,stnyy,stynyh,tsu~etinye,ztynyh,Цетине,Цетинє,Цетиње,Цєтиниѥ,Ցետինե,צטיניה,ستنيي,ستینیه,เซตีเนีย,ツェティニェ,采蒂涅,체티네', 42.3906300, 18.9141700, 'ME', '2014-05-11', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93016, 'Budva', 'Budva', 'Bountva,Budua,Budva,Buedua,Butua,Büdua,QBA,bu de wa,budeuba,budovu~a,bwdwa,Μπούντβα,Будва,بودوا,ブドヴァ,布德瓦,부드바', 42.2863900, 18.8400000, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93017, 'Bijelo Polje', 'Bijelo Polje', 'Bielo pole,Bielo-Pole,Bijelo Polje,Opstina Bijelo Pole,Oпштина Бијело Поље,Биело поле,Биело-Поле,Бієло-Полє', 43.0383400, 19.7475800, 'ME', '2013-06-28', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93018, 'Bijela', 'Bijela', 'Bijela,Bjela', 42.4533300, 18.6555600, 'ME', '2016-09-29', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93019, 'Bar', 'Bar', 'Antibarium,Antivari,Bar,Bar - Bar,Bar - Бар,Baras,Bari vald,Tivari,ba er,baleu,bar,bari,baru,br,Μπαρ,Бар,בר,بار,بار، مونته‌نگرو,بار، مونٹینیگرو,ბარი,バール,巴尔,바르', 42.0930600, 19.1002800, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93020, 'Andrijevica', 'Andrijevica', 'Andrievica,Andrijevica,Andrijevitsa,Андриевица,Андријевица,Андрієвіца', 42.7338900, 19.7919400, 'ME', '2013-07-06', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93021, 'Petnjica', 'Petnjica', 'Petnica,Petnjica,Петњица', 42.9088900, 19.9644400, 'ME', '2017-04-09', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93022, 'Šušanj', 'Susanj', 'Susanj,Šušanj', 42.1155600, 19.0883300, 'ME', '2013-01-25', 149);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92691, 'Tazouta', 'Tazouta', 'Taouchet Tazouta,Tazouta', 33.6699100, -4.6339200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92692, 'Taznakht', 'Taznakht', 'Tazenakht,Tazenskht,Taznakht', 30.5783600, -7.2034100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92693, 'Tazemmourt', 'Tazemmourt', 'Tazemmourt,Tazemmourte', 30.4085400, -8.8290000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92694, 'Tazarine', 'Tazarine', 'El Kelaa n''Tazarine,El Kelaa n’Tazarine,Tazarine,Tazarine-des-Zerarda,Tazzarine', 33.8830700, -4.1862000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92695, 'Taza', 'Taza', 'Taza,ta zha,tazh,tazt,Таза,Таза қаласы,תאזה,تازة,تازه,تازہ,塔扎', 34.2100000, -4.0100000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92696, 'Tata', 'Tata', 'Tata,Tatta', 29.7440900, -7.9730000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92697, 'Tarsouat', 'Tarsouat', '', 29.5815300, -9.0266400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92698, 'Taroudant', 'Taroudant', 'Taroudannt,Taroudant,Tarudant,Tarudantas,Tarudante,ta lu dan te,tarwdant,Тарудант,تارودانت,塔魯丹特', 30.4702800, -8.8769500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92699, 'Teroual', 'Teroual', 'Taroual,Teroual,Terual', 34.6745200, -5.2733100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92700, 'Targuist', 'Targuist', '', 34.9376900, -4.3185600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92701, 'Tarfaya', 'Tarfaya', 'Cabo Juby,Cabo Yubi,Cap Juby,Talfaia,Tarfaia,Tarfaja,Tarfaya,Villa Bens,tarufaya,trfayh,trfayt,Тарфая,طرفاية,طرفایه,タルファヤ', 27.9392000, -12.9260400, 'MA', '2014-10-16', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92702, 'Taourirt', 'Taourirt', '', 34.4073100, -2.8973200, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92703, 'Taounza', 'Taounza', '', 32.0936800, -6.6060700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92704, 'Taounate', 'Taounate', 'Taounat,Taounate,Taunat,Tawnat,Таунат', 34.5366100, -4.6400900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92705, 'Taouloukoult', 'Taouloukoult', 'Taoulokoult,Taouloukoult,Zaouia Taouloukoult', 31.2221800, -9.0794300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92706, 'Taouima', 'Taouima', 'Taouima,Tauima', 35.1299000, -2.9279000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92707, 'Tan-Tan', 'Tan-Tan', 'Gorad Tan-Tan,TTA,Tan-Tan,Tantan,Tantanas,tantan,Горад Тан-Тан,Тан-Тан,طانطان,タンタン', 28.4379900, -11.1032100, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92708, 'Tangier', 'Tangier', 'TNG,Tanger,Tangeri,Tangero,Tangier,Tangiers,Tanzher,Tanĝero,Tingis,Tànger,Tánger,Tânger,tan ji ya,tnjt,Тангер,Танжер,طنجة,坦幾亞', 35.7672700, -5.7997500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92709, 'Tanalt', 'Tanalt', '', 29.7754800, -9.1679600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92710, 'Tamorot', 'Tamorot', 'Tamorot,Tamorote,Zoco es Sebtz de Tamorot', 34.9363200, -4.7794000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92711, 'Tamanar', 'Tamanar', '', 31.0008700, -9.6780200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92712, 'Talzemt', 'Talzemt', 'Talzemt,Talzent', 33.5900000, -4.1900000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92713, 'Talmest', 'Talmest', '', 31.8100000, -9.3300000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92714, 'Taliouine', 'Taliouine', 'Taliouine,Talioune', 30.5291700, -7.9126200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92715, 'Tahla', 'Tahla', 'El Ayba Tahalla,Tahala,Tahla', 34.0496500, -4.4216200, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92716, 'Tafraout', 'Tafraout', 'Tafraout,Tafraoute,Tafraut', 29.7244900, -8.9747000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92717, 'Tadrart', 'Tadrart', 'Tadrart,Tanrart', 30.7747700, -9.4595100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92718, 'Tabouda', 'Tabouda', 'Tabouda,Tabouda de l''Ouerrha,Tabouda de l’Ouerrha', 34.7192300, -5.1403000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92719, 'Tabia', 'Tabia', '', 32.0300900, -6.7998500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92720, 'Tabia', 'Tabia', '', 30.0346200, -8.8768800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92721, 'Tabant', 'Tabant', 'Tabannt,Tabant', 31.6525500, -6.4104900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92722, 'Souq Larb’a al Gharb', 'Souq Larb''a al Gharb', 'El Arba du Gharb,El Arba du Rharb,El Arbaa du Rharb,El Arboa du Rharb,Souk-el-Arba-du-Gharb,Souq Larb''a al Gharb,Souq Larb’a al Gharb', 34.6866400, -6.0027200, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92723, 'Senada', 'Senada', 'Sanadat,Senada,Snada', 35.0745200, -4.2158300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92724, 'Skoura', 'Skoura', 'Skoura,Skoura des Ahl el Oust', 31.0626200, -6.5525000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92725, 'Sidi Yahya Ou Saad', 'Sidi Yahya Ou Saad', 'Sidi Yahya Ou Saad,Sidi Yahya Ou Saoua,Sidi yahya ou saoud', 32.6801100, -5.5773800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92726, 'Sidi Yahia El Gharb', 'Sidi Yahia El Gharb', 'Sidi Yahia El Gharb,Sidi Yahia al Gharb,Sidi Yahia del Garb,Sidi Yahia el Rharb,Sidi Yahya du Rharb,Sidi Yanya du Rharb,Sidi Yaya du Rhanb,Sïdi Yaya du Rhanb', 34.3049400, -6.3040400, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92727, 'Sidi Smai’il', 'Sidi Smai''il', 'Sidi Smai''il,Sidi Smail,Sidi Smaine,Sidi Smai’il,Sidi Smaïl,Sidi Smaïne,Sidi-Smain,Sidi-Smaïn,Zaouia Sidi Smain', 32.8246100, -8.5112200, 'MA', '2016-12-05', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92728, 'Sidi Slimane', 'Sidi Slimane', 'Sidi Slamain,Sidi Sliman,Sidi Slimane,Sidi-Slimane,Сиди-Слимане', 34.2647900, -5.9259800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92729, 'Sidi Redouane', 'Sidi Redouane', 'Redouane,Sidi Redouane,Sidi Reduan', 34.6869200, -5.4453800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92730, 'Sidi Rahhal', 'Sidi Rahhal', 'Sidi Rahal,Sidi Rahhal,Zaouia Sidi Rahal,Zaouia Sidi Rahhal,Zaouia Sidi Rahkal', 31.6503100, -7.4728800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92731, 'Sidi Qacem', 'Sidi Qacem', 'Petitjean,Pettijean,Sidi Kacem,Sidi Qacem,Sidi Qasim,Sīdī Qāsim,sdy qasm,سدي قاسم', 34.2214900, -5.7077500, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92732, 'Sidi Moussa', 'Sidi Moussa', '', 32.2720900, -7.2009500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92733, 'Sidi Lamine', 'Sidi Lamine', '', 32.9078300, -6.0506900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92734, 'Sidi Jaber', 'Sidi Jaber', 'Sidi Jaber,Sidi Jabeur', 32.3895200, -6.4209500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92735, 'Sidi Ifni', 'Sidi Ifni', 'Ifni,SII,Sidi Ifni,Sidi Ifnis,Sidi-Ifni,Sidifni,sidiipeuni,sydy afny,Сиди Ифни,Сиди-Ифни,سيدي إفني,시디이프니', 29.3797500, -10.1729900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92736, 'Sidi Harazem', 'Sidi Harazem', 'Douar Sidi Harazem,Sidi Harazem', 34.0273300, -4.8834300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92737, 'Sidi Bousber', 'Sidi Bousber', 'Sidi Bousber,Sidi Bousbeur', 34.5628300, -5.3620800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92738, 'Sidi Bou Othmane', 'Sidi Bou Othmane', 'Sidi Bou Othmane,Sidi Bou Otmane,Sidi Bu Osman,Sidi Bu Osmán', 31.9022600, -7.9416900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92739, 'Sidi Bennour', 'Sidi Bennour', '', 32.6523600, -8.4276900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92740, 'Sidi Amar', 'Sidi Amar', 'Ait Ben Amar,Aït Ben Amar,Dechra Sidi Amar,Sidi Amar,Sidi Ammar', 32.9498700, -5.8322500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92741, 'Sidi Abdallah', 'Sidi Abdallah', 'Ouled Abdellah,Sidi Abdallah', 32.5354400, -7.8324300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92742, 'Settat', 'Settat', 'Azettad,Aẓeṭṭaḍ,Sattat,Setatas,Settat,sai ta te,setateu,sltat,stat,Сеттат,سطات,سلطات,სეტატი,塞塔特,세타트', 33.0010300, -7.6166200, 'MA', '2016-11-03', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92743, 'Selouane', 'Selouane', 'Selouane,Zelaun,Zelouan,Zelouane,Zeluan,Zeluán', 35.0731300, -2.9423000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92744, 'Sefrou', 'Sefrou', 'Sefrou,Sefru,Sefrú', 33.8318600, -4.8280000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92745, 'Sale', 'Sale', 'Sala,Sale,Sali,Sallee,Salé,Sla,Slà,sla,Сале,سلا', 34.0531000, -6.7984600, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92746, 'Safi', 'Safi', 'Asafi,Asfi,Gorad Safi,SFI,Safi,Safim,Safí,Sáfí,asfy,asfy  mraksh,sa fei,safi,sapi,Горад Сафі,Сафи,Սաֆի,סאפי,آسفي,اسفی,اسفی، مراکش,საფი,ⴰⵙⴼⵉ,サフィ,薩非,사피', 32.2993900, -9.2371800, 'MA', '2017-05-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92747, 'Rouadi', 'Rouadi', '', 35.1411900, -4.1363100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92748, 'Rislane', 'Rislane', 'Rislane,Rislane Thata', 34.7698700, -2.4603400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92749, 'Ghouazi', 'Ghouazi', 'Ghouazi,Rhouazi', 34.4773700, -5.3023500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92750, 'Reggada', 'Reggada', 'Er Reggada,Reggada,Souk-el-Had de Reggada', 29.5801600, -9.7008600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92751, 'Ratba', 'Ratba', '', 34.7777200, -4.9398900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92752, 'Rabat', 'Rabat', 'Gorad Rabat,RBA,Raba,Rabat,Rabata,Rabatas,Rabato,Rabatum,Rabot,Rabāt,Rabāta,Rampat,Rbat,Rbaṭ,alrbat,la ba,la ba te,labateu,raba t,rabat,rabata,rabato,rabota,rapat,rbat,Ραμπάτ,Горад Рабат,Рабат,Ռաբատ,ראבאט,רבאט,الرباط,رابات,ربات,رباط,ڕەبات,रबाट,रबात,রাবাত,ਰਬਾਤ,ରବୋଟ,ரபாத்,ราบัต,ར་བ་ཐ།,ར་བ་ཐེ།,რაბატი,ራባት,ラバト,剌八,拉巴特,라바트', 34.0132500, -6.8325500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92753, 'Ourtzagh', 'Ourtzagh', 'Ourtzagh,Ourtzarh', 34.5347700, -4.9687800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92754, 'Oulmes', 'Oulmes', 'Oulmes,Oulmes-Les Thermes,Oulmès-Les Thermes', 33.4258500, -6.0013700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92755, 'Oulad Teïma', 'Oulad Teima', 'Oulad Teima,Oulad Teïma,Ouled Teima', 30.3946700, -9.2089700, 'MA', '2016-11-10', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92756, 'Oulad Tayeb', 'Oulad Tayeb', 'Ulad Tajib,Улад Тайиб', 33.9463300, -4.9950900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92757, 'Oulad Daoud', 'Oulad Daoud', 'Douar Oulad Daoud,Oulad Daoud', 34.4043800, -4.6934200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92758, 'Oulad Ayad', 'Oulad Ayad', '', 32.2000000, -6.8000000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92759, 'Oujda-Angad', 'Oujda-Angad', 'OUD,Oudja,Oudjda,Ouja,Oujda,Oujda-Angad,Ucda,Udzda,Udzhda,Udžda,Ugda,Ujda,Uĝda,Wadzda,Wadżda,Wejda,ujida,wgdh,wjdh,wjdt,wu ji da,Уджда,Уджда қаласы,Уџда,וגדה,وجدة,وجده,وجدہ,ウジダ,乌季达,우지다', 34.6813900, -1.9085800, 'MA', '2016-12-05', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92760, 'Ouijjane', 'Ouijjane', 'Ouijjane,Souk-Sebt-Ouijjane', 29.6277700, -9.5395900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92761, 'Oued Zem', 'Oued Zem', '', 32.8627000, -6.5735900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92762, 'Oued Laou', 'Oued Laou', 'Oued Lahou,Oued Lao,Oued Laou,Oued Lou,Uad Lau', 35.4484000, -5.0962700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92763, 'Oued Amlil', 'Oued Amlil', '', 34.2000000, -4.2800000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92764, 'Ouezzane', 'Ouezzane', 'Ouazzane,Ouezzane,Quazzane,Uazan,Uazán,Wazzan', 34.7958400, -5.5784900, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92765, 'Ouarzazat', 'Ouarzazat', 'OZZ,Ouarzazat,Ouarzazate,Ouarzazte,Ouorzazate,Uarzazatas,Varzazat,Warzazat,Warzāzāt,wrzazat,wrzzat,Варзазат,ورزازات,ورززات', 30.9189400, -6.8934100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92766, 'Nouaseur', 'Nouaseur', 'Nouaceur,Nouaseur,Nwacer,Nwaçer', 33.3802000, -7.6210500, 'MA', '2012-01-19', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92767, 'Nador', 'Nador', 'NDR,Nador,Nadora,Nadoras,Nnadur,Nnaḍur,Nādora,Villa Nador,alnazwr,na zu er,nad xr,nadoleu,nazwr,Надор,الناظور,ناظور,นาดอร์,納祖爾,나도르', 35.1681300, -2.9335200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92768, 'Moulay Yacoub', 'Moulay Yacoub', 'Moulay Yacoub,Moulay Yakoub,Muley Yacub', 34.0879300, -5.1817100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92769, 'Moulay Brahim', 'Moulay Brahim', 'Moulay Brahim,Zaouia Moulay Brahim,Zaouiat Moulay Brahim', 31.2878500, -7.9683000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92770, 'Moulay Bouchta', 'Moulay Bouchta', '', 34.4892200, -5.1302300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92771, 'Moulay Abdallah', 'Moulay Abdallah', 'Tett', 33.1966400, -8.5881100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92772, 'Mohammedia', 'Mohammedia', 'Al Muhammadiyah,Al Muḩammadīyah,Al-Muhammadijja,Fadalah,Faḑālah,Fdala,Fedala,Fedalah,Fedhala,Mohamedija,Mohamedio,Mohammadia,Mohammedia,Mohammédia,Mokhammedija,Muhammediye,Məhəmmədiyyə,Sedala,alhrawyyn,almhmdyt,mhmdyh,mohamedia,mu han mo di ye,Мохаммедия,المحمدية,الهراويين,محمدیه,محمدیہ,穆罕默迪耶,모하메디아', 33.6860700, -7.3829800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92773, 'Missour', 'Missour', 'Misour,Missour', 33.0489300, -3.9894700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92774, 'Midelt', 'Midelt', 'Midelt', 32.6852000, -4.7451200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92775, 'Midar', 'Midar', 'Arba Laazib Midar,Azib de Midar,El Arba de Midar,Midar,Soko Arbaa Laazib Midar', 34.9402500, -3.5331100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92776, 'Meknès', 'Meknes', 'MEK,Mekinez,Meknes,Meknès,mei ke nei si,mekunesu,mknas,mqns,Мекнес,מקנס,مكناس,مکناس,ⴰⵎⴽⵏⴰⵙ,メクネス,梅克内斯', 33.8935200, -5.5472700, 'MA', '2017-02-01', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92777, 'Mediouna', 'Mediouna', '', 33.4516100, -7.5199500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92778, 'Mechraa Bel Ksiri', 'Mechraa Bel Ksiri', 'Ksiri,Mechra Belqsiri,Mechra al Ksiri,Mechra-bel-Kairi,Mechraa Bel Ksiri,Mechrá Belqsiri', 34.5737300, -5.9558500, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92779, 'Matmata', 'Matmata', '', 34.0991400, -4.5521900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92780, 'Martil', 'Martil', 'Martil,Rio Martin,Rio Martine,Río Martín,Wad Martin,Wād Martīn', 35.6166200, -5.2752200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92781, 'Marrakesh', 'Marrakesh', 'Marakes,Marakesh,Marakeso,Marakeŝo,Marakeš,Maraksh,Marrakech,Marrakes,Marrakesch,Marrakesh,Marrakesz,Marraqueix,Marraquexe,Marràqueix,Marrákes,Marrákeš,Merrakex,Morocco City,RAK,ma la ke shen,marakeshu,mraksh,Маракеш,Марракеш,مراكش,ⴰⵎⵓⵔⴰⴽⵓⵛ,マラケシュ,马拉喀什', 31.6341600, -7.9999400, 'MA', '2016-11-03', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92782, 'Madagh', 'Madagh', 'Madagh,Madarh', 35.0103200, -2.3370100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92783, 'Ifrane', 'Ifrane', 'Ifran,Ifrane,Lfrane,Ифран', 31.7021700, -6.3494000, 'MA', '2012-01-19', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92784, 'Larache', 'Larache', 'Al `Ara''ish,Al ‘Arā’īsh,Al-Araisz,El Aaraich,El Araish,Larache,Larasas,Larash,Larasha,Laraso,Laraxe,Laraŝo,Larašas,Larraix,Lavache,araishu,la la shen,la rach,lalasyu,Лараш,Лараша,לראצה,العرائش,عرائش,عرایش,ลารัช,アライシュ,拉臘什,라라슈', 35.1932100, -6.1557200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92785, 'Lalla Mimouna', 'Lalla Mimouna', 'Lal-la Mimuna,Lalla Mimouna,Lalla miouna-adachra', 34.8460600, -6.0664500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92786, 'Ksar El Kebir', 'Ksar El Kebir', 'Alcazarquebir,Alcazarquivir,Alcazquivir,El Ksar El Kbir,El Ksar El Kebir,Ksar El Kebir', 35.0004400, -5.9037800, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92787, 'Khouribga', 'Khouribga', 'Khouribga,Khouribja,Kouriga,Kourigha,khrybkt,خريبكة', 32.8810800, -6.9063000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92788, 'Khenifra', 'Khenifra', 'Chenifra,Chunajfira,Jenifra,Khenifra,Khénifra,Xnifra,hai ni fu la,khnyfrh,khnyfrt,Хенифра,خنيفرة,خنیفره,خنیفرہ,海尼夫拉', 32.9349200, -5.6616700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92789, 'Kerrouchen', 'Kerrouchen', 'Kerrouchen,Kerrouchene', 32.7963900, -5.3188000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92790, 'Kenitra', 'Kenitra', 'Al Qunaytirah,Al Qunayţirah,Al-Kunajtira,Gorad Kenitra,Kenitra,Kenitro,Khenifra,Kénitra,Lyautey,Mina Hassan Tani,NNA,Port Laoti,Port-Lyautey,Ville de Kenitra,alqnytrt,gai ni te la,keniteula,kenitora,qnytrh,Горад Кенітра,Кенитра,Кенитра қаласы,אל-קניטרה,القنيطرة,قنیطره,კენიტრა,ケニトラ,蓋尼特拉,케니트라', 34.2610100, -6.5802000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92791, 'Kasba Tadla', 'Kasba Tadla', 'Kasba Tadla,Kasbah Tadla,Tadla', 32.5977000, -6.2684400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92792, 'Kariat Arkmane', 'Kariat Arkmane', 'El Arba,El Arbaa,El Arbaa Soko,El Arbâa,Karia Arkeman,Karia d''Arkemane,Karia da Arkeman,Karia de Arkeman,Karia de Arkenan,Karia de Arkenán,Karia d’Arkemane,Karia-Arakmane-Afso,Kariat Arekmam,Kariat Arkmane,Kariat akmane,Kariet Arkmane,Soko el Arbaa,Souk-el-Arbaa,Souk-el-Arbâa,Zoco el Arbaa', 35.1071000, -2.7469300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92793, 'Karia Ba Mohamed', 'Karia Ba Mohamed', 'Karia Ba Mohamed,Karia Ba Mohammed', 34.3709400, -5.2138000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92794, 'Jorf', 'Jorf', 'Djorf,Jorf,Oulad Rhanem ej Jorf', 31.4944200, -4.4059800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92795, 'Jerada', 'Jerada', 'Djerada,Dzherada,Jerada,Джерада', 34.3100000, -2.1600000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92796, 'Itzer', 'Itzer', '', 32.8783000, -5.0515000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92797, 'Isseksi', 'Isseksi', '', 32.2298100, -6.2766100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92798, 'Inezgane', 'Inezgane', 'Imezgane,Inezgane,Insgane', 30.3553500, -9.5363900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92799, 'Imider', 'Imider', 'Imider,Imiter', 31.3732400, -5.7938400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92800, 'Imilchil', 'Imilchil', 'Assif-Melloul,Enilchil,Imilchil', 32.1530900, -5.6245300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92801, 'Iguidi', 'Iguidi', '', 30.8382600, -7.9029400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92802, 'Ifrane', 'Ifrane', 'Ifran,Ifranas,Ifrane,afran,ipeulan,yi fu lan,Ифран,איפראן,إفران,افران,伊夫兰,이프란', 33.5266600, -5.1101900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92803, 'Hassi Berkane', 'Hassi Berkane', 'Hasi Berkane,Hassi Berkane', 34.8389800, -2.8669900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92804, 'Zerkten', 'Zerkten', 'Had Zerektene,Had-Zerekten,Zerekten,Zerektene,Zerkten', 31.4447000, -7.3922400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92805, 'Had Kourt', 'Had Kourt', 'El Had Kourt,Had Kourt,Had-Hourt,Had-Kurt', 34.6158800, -5.7404000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92806, 'Oulad Frej', 'Oulad Frej', 'El Had,Had Oulad Frej,Had Ouled Frej Centre,Had des Oulad Frej,Oulad Frej,Souk el Had', 32.9595600, -8.2274000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92807, 'Guisser', 'Guisser', '', 32.7664500, -7.4981800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92808, 'Guercif', 'Guercif', 'Garsif,Guercif', 34.2256800, -3.3536100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92809, 'Guenfouda', 'Guenfouda', 'Guenfouda,Guenfuda,Guennfouda', 34.4836100, -2.0456200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92810, 'Guelmim', 'Guelmim', 'GLN,Gelmima,Gelmimas,Gelmīma,Gorad Gulimin,Goulimine,Guelmim,Gulimin,Kulmim,gai lei min,gelmim,gerumin,gulimimi,klmym,Горад Гулімін,Гулимин,Гулимин қаласы,كلميم,کلمیم,გულიმიმი,ゲルミン,蓋勒敏,겔밈', 28.9869600, -10.0573800, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92811, 'Goulmima', 'Goulmima', 'Goulmima,Goulmina,Guelmina', 31.6922700, -4.9525600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92812, 'Galaz', 'Galaz', 'Galaz,Golaz', 34.5442400, -4.8035500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92813, 'Al Fqih Ben Çalah', 'Al Fqih Ben Calah', 'Al Fqih Ben Calah,Al Fqih Ben Çalah,Fkih Ben Salah,Fquih Ben Salah', 32.5021300, -6.6877100, 'MA', '2017-03-05', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92814, 'Figuig (Centre)', 'Figuig (Centre)', 'Figuiq', 32.1089100, -1.2285500, 'MA', '2009-06-20', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92815, 'Fifi', 'Fifi', '', 34.9487300, -5.2479800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92816, 'Fezna', 'Fezna', '', 31.5292100, -4.4556200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92817, 'Fès al Bali', 'Fes al Bali', 'Fes al Bali,Fes le Vieux,Fes-l''Ancien,Fès al Bali,Fès le Vieux,Fès-l’Ancien,Medina,Old Fes', 34.0701000, -4.9547300, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92818, 'Fès', 'Fes', 'FEZ,Fes,Fez,Fès,fas,fezu,Фес,فاس,フェズ', 34.0331300, -5.0002800, 'MA', '2016-12-05', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92819, 'Ezzhiliga', 'Ezzhiliga', '', 33.3000000, -6.5300000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92820, 'Essaouira', 'Essaouira', 'Amegdul,As Suwayrah,As-Sawira,As-Sawíra,As-Shawirah,Aş Şuwayrah,ESU,Ehs-Suvejra,Ehssuehjra,Es Suira,Es-Suvejra,Esauira,Essaouira,Essauira,Magador,Medino de Esauiro,Medino de Esaŭiro,Mogadar,Mogador,Savira,Suira,Suvayr,Szavira,Szavíra,alswyrt,el-suvaira,es''sa''ura,esau-ila,essau~ira,suo wei la,swyrh,Ес-Сувейра,Эс-Сувейра,Эссуэйра,אסואירה,الصويرة,صویره,صویرہ,एस्साउरा,ელ-სუვაირა,エッサウィラ,索维拉,에사우이라', 31.5125000, -9.7700000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92821, 'El Ksiba', 'El Ksiba', 'El Ksiba,Ksiba', 32.5728600, -6.0194700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92822, 'El Jadid', 'El Jadid', 'Al Jadida,Al Yadida,Al-Djadida,Al-Dzadida,Al-Dżadida,Al-Džadída,Castilho Real,Dzadida,Džadida,Ehl''-Dzhadida,El Jadid,El Jadida,El-Jadida,El-Yadida,Gorad Ehl''-Dzhadzida,Mazagan,Mazagao,Mazaghan,Mazagão,Mazargan,aljdydh,aljdydt,el-jadida,ela jadida,eljadida,jie di dai,xælcha di da,Горад Эль-Джадзіда,Мазарґан,Эль-Джадида,אל-גדידה,الجديدة,الجدیده,الجدیدہ,एल जदिदा,แอลฌาดีดา,ელ-ჯადიდა,アル・ジャディーダ,杰迪代,엘자디다', 33.2568200, -8.5088200, 'MA', '2017-03-05', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92823, 'El Hajeb', 'El Hajeb', '', 33.6878600, -5.3710000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92824, 'Ouaoula', 'Ouaoula', 'Arba de Ouaouila,Arba-Ouaoula,El Arba Ouaoula,El Arba d''Aauala,El Arba d’Aauala,Ouaoula', 31.8700000, -6.7500000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92825, 'El Aïoun', 'El Aioun', 'Aioun Sidi Mellouk,Al ''Youn,Al ’Youn,El Aioun,El Aioun Sidi Mellouk,El Aïoun,El Aïoun Sidi Mellouk', 34.5831900, -2.5061200, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92826, 'Imzouren', 'Imzouren', 'Ain Zoren,Amzourhen-Khemis-Mrabten,Amzourhèn-Khémis-Mrabtèn,Aïn Zorèn,Eimoren,Einzoren,Einzorene,Imsouren,Imzouren,Imzourene,Imzoûrene,Izourene', 35.1463700, -3.8506300, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92827, 'Derdara', 'Derdara', 'Dardara,Derdara', 35.1104100, -5.2901500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92828, 'Demnate', 'Demnate', 'Demnat,Demnate,Demnot', 31.7344300, -7.0050500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92829, 'Debdou', 'Debdou', 'Dabdou,Debdau,Debdou,Debdu,Debdú,Dubdu,dbdw,דבדו,دبدو', 33.9822800, -3.0426300, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92830, 'Riah', 'Riah', 'Dar Riah,Douar Riah,Riah', 33.1512200, -7.3750400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92831, 'Dar Ould Zidouh', 'Dar Ould Zidouh', 'Dar Oulad Zidouh,Dar Ould Zidouh,Dar-Oould-Zidouh', 32.3124700, -6.9049400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92832, 'Dar Bouazza', 'Dar Bouazza', '', 33.5153500, -7.8167700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92833, 'Dar Chaoui', 'Dar Chaoui', 'Dar Chaoui,Dar Chaui,Dar Xaui,Dar ech Chaui,Der Xaui,Xauia', 35.5377000, -5.7174200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92834, 'Chichaoua', 'Chichaoua', 'Chichaoua,Chichaua,Mzala Chichaoua', 31.5435100, -8.7627500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92835, 'Chefchaouene', 'Chefchaouene', 'Chaouen,Chaouèn,Chauen,Chechaouen,Chechaouene,Chechaouèn,Chefchaouen,Chefchaouene,Chichaouene,Ech Chaouene,Scheschauen,Shefshauen,Ville de Chechaouen,Ville de Chechaouèn,Xauen,Xexauen,shfshawn,Шефшауен,شفشاون', 35.1687800, -5.2636000, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92836, 'Casablanca', 'Casablanca', 'Ad Dar al Bayda,Ad Dar al Bayda'',Ad Dār al Bayḑā’,Anafi,Anfa,CAS,Casa Branca,Casablanca,Casabranca,Dar-el-Beida,Darul Baidha,Ed Dar el Baida,Ed Dār el Baida,Gorad Kasablanka,Kasablank,Kasablanka,Kasablankae,Kazablanka,Kazablanko,Kazamplan''ka,Tigemmi Tamellalt,White House,dar albydaʾ,ka sa bu lan ka,ka sab l xng ka,kacapilanka,kasabalanka,kasabeullangka,kasablanka,kasaburanka,kazablanka,qzblnqh,Καζαμπλάνκα,Горад Касабланка,Казабланка,Касабланкæ,Касабланка,Կասաբլանկա,קזבלנקה,الدار البيضاء,دار البیضاء,کازابلانکا,کاسابلانکا,कासाब्लांका,কাসাব্লাংকা,ਕਾਸਾਬਲਾਂਕਾ,காசாபிளாங்கா,కాసాబ్లాంకా,ಕಾಸಾಬ್ಲಾಂಕಾ,കാസബ്ലങ്ക,กาซาบล็องกา,ກາຊາບັງກາ,ကာဆာဘလန်ကာမြို့,კასაბლანკა,ⴰⵏⴼⴰ,カサブランカ,卡萨布兰卡,카사블랑카', 33.5883100, -7.6113800, 'MA', '2016-11-03', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92837, 'Bzou', 'Bzou', 'Bezou,Bzou,Bzou Aghbalou', 32.0917100, -7.0478600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92838, 'Brikcha', 'Brikcha', 'Brickcha,Brikcha,Douar Brikcha', 34.9673200, -5.5729500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92839, 'Bouznika', 'Bouznika', 'Bouzhika,Bouznika,Bouzniqa,Buznike,Kasba bou Znika,Бузнике', 33.7894200, -7.1596800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92840, 'Bouskoura', 'Bouskoura', '', 33.4497600, -7.6523900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92841, 'Boumia', 'Boumia', '', 32.7236000, -5.1025000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92842, 'Boulemane', 'Boulemane', 'Boulemane,Boulmane', 33.3637600, -4.7289600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92843, 'Boulaouane', 'Boulaouane', 'Boulaouane,Guaouar Boulaouane,Kasba Bou Laouane,Kasha Bou Laouane', 32.8599500, -8.0555500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92844, 'Boudinar', 'Boudinar', 'Ain Boudinar,Boudinar,Budinar', 35.1560100, -3.6235800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92845, 'Bouarfa', 'Bouarfa', 'Bordj de Bou Arfa,Bou Arfa,Bouafra,Buarfa,UAR', 32.5337900, -1.9620900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92846, 'Bouabout', 'Bouabout', 'Bouabout,Bouaboute', 31.2655400, -9.1786500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92847, 'Bigoudine', 'Bigoudine', '', 30.7237600, -9.2109700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92848, 'Bhalil', 'Bhalil', 'Bahlil,Behalil,Bhalil', 33.8519400, -4.8722800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92849, 'Berkane', 'Berkane', 'Berkan,Berkane,Berkawe,Berkán,Birkani,bai er kan,brkan,Беркан,بركان,برکان,拜爾坎', 34.9200000, -2.3200000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92850, 'Beni Mellal', 'Beni Mellal', 'Ayt Mellal,BEM,Bani Mallal,Beni Melal,Beni Melalis,Beni Mellal,Beni-Mellal,Beni-Mellal'',Beni-Mellal-Centre,Béni Mellal,Béni-Mellal,bei ni mai la lei,benimellal,bny mlal,bny mll,Бени-Меллаль,בני מלל,بني ملال,بنی ملال,بنی‌ملال,貝尼邁拉勒,베니멜랄', 32.3372500, -6.3498300, 'MA', '2017-02-03', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92851, 'Berrechid', 'Berrechid', 'Barrechid,Berrechid,Bev-rechid', 33.2655300, -7.5875400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92852, 'Bab Taza', 'Bab Taza', 'Bab Tasa,Bab Taza,Bab Tazza', 35.0616600, -5.1982800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92853, 'Azrou', 'Azrou', 'Azrou,Azru,Azrú,ai zi lu,azrw,Азру,أزرو,ازرو,艾茲魯', 33.4344300, -5.2212600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92854, 'Azilal', 'Azilal', 'Arilal,Asila,Asilal,Azilal', 31.9615600, -6.5710900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92855, 'Azgour', 'Azgour', '', 31.1375300, -8.3148800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92856, 'Azemmour', 'Azemmour', 'Azamor,Azemmour,Azimur,Azzegour', 33.2895200, -8.3425000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92857, 'Assoul', 'Assoul', 'Assoul,Assoul Ksar', 31.9528600, -5.2081200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92858, 'Assads', 'Assads', '', 30.2300000, -8.8600000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92859, 'Asilah', 'Asilah', 'Arcila,Arcilas,Arsila,Arzila,Arzilah,Arzīlah,Asila,Asilah,Asilakh,Assila,Assilah,Augusta Zilil,Aṣīla,Colonia Augusti Iulia Constantia Zilil,Ville d''Arcila,Ville d’Arcila,ashira,asilla,asylh,asylt,sylt,Асила,Асилах,أصيلة,اصیله,صيلة,アシラー,아실라', 35.4652200, -6.0341500, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92860, 'Argana', 'Argana', 'Agana,Argana', 30.7825000, -9.1196800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92861, 'Arbaoua', 'Arbaoua', 'Arbaoua,Arbaua', 34.9023900, -5.9487100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92862, 'Arazane', 'Arazane', 'Arazane,Arazene', 30.5034600, -8.6063700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92863, 'Aourir', 'Aourir', '', 30.4923800, -9.6355000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92864, 'Aoulouz', 'Aoulouz', 'Aoulouz,Dar Caid,Dar Caïd', 30.6730700, -8.1808700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92865, 'Aoufous', 'Aoufous', 'Aoufous,Aoufouss,Centre d''Aoufous,Centre d’Aoufous', 31.6800000, -4.1700000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92866, 'Amouguer', 'Amouguer', 'Amouguear,Amouguer', 32.2749100, -4.9353500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92867, 'Amizmiz', 'Amizmiz', 'Amimiz,Amismiz,Amizmiz', 31.2167300, -8.2318400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92868, 'Amerzgane', 'Amerzgane', 'Amarzgane,Amerzgane,Anergane', 31.0437000, -7.2103700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92869, 'Amersid', 'Amersid', '', 32.7498300, -4.4706300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92870, 'Amalou', 'Amalou', '', 30.1915300, -8.7487300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92871, 'Alnif', 'Alnif', '', 31.1141100, -5.1715400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92872, 'Almis Marmoucha', 'Almis Marmoucha', 'Almis Marmoucha,Almis de Marmucha,Almis des Marmoucha,Mermoucha-Centre', 33.3200000, -4.1800000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92873, 'Khemisset', 'Khemisset', 'Al Khmissat,Khemisset,Kimisset', 33.8240400, -6.0662700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92874, 'Al Hoceïma', 'Al Hoceima', 'AHU,Al Hoceima,Al Hoceïma,Al Huceima,Al Husaymat,Al Ḩusaymāt,Al-Hoceima,Al-Husajma,Alhacemas,Alhucemas,Villa Alhucemas,Villa Sanjurjo,alhsymt,hsymh,الحسيمة,حسیمه', 35.2516500, -3.9372300, 'MA', '2016-11-03', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92875, 'Aknoul', 'Aknoul', '', 34.6537100, -3.8675400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92876, 'Ajdir', 'Ajdir', '', 34.7434700, -3.9758200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92877, 'Anergui', 'Anergui', 'Ait Ouanergui,Anergui,Aït Ouanergui', 32.0691400, -5.9396100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92878, 'Ahfir', 'Ahfir', 'Ahfir,Martimprey du Kiss', 34.9536800, -2.1002700, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92879, 'Aguelmous', 'Aguelmous', 'Aguelmous,Aguelmouss', 33.1613900, -5.8462600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92880, 'Agdz', 'Agdz', 'Agdz,Agoz,Ksar Agdz', 30.6935600, -6.4462800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92881, 'Agadir Melloul', 'Agadir Melloul', 'Agadir Jdid,Agadir Melloul', 30.2249200, -7.7960100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92882, 'Agadir', 'Agadir', 'AGA,Agadair,Agadir,Agadir - akadyr,Agadir - اكادير,Agadir Ighir,Agadiras,Agádír,Ankantir,Irhir,Santa Cruz,a jia di er,agadileu,agadira,agadiru,agadyr,aghadyr,akadyr,Αγκαντίρ,Агадир,Агадір,אגאדיר,أكادير,اغادیر,اگادیر,अगादिर,アガディール,阿加迪尔,아가디르', 30.4201800, -9.5981500, 'MA', '2017-07-17', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92883, 'Adassil', 'Adassil', '', 31.1078300, -8.4908300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92884, 'Adar', 'Adar', 'Adar,Addar', 30.1411100, -8.3722100, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92885, 'Skhirate', 'Skhirate', 'Ac Ckhirat,Aç Çkhirat,Kasba Skira,Minaret de Skhirat,Skhirat,Skhirate', 33.8527000, -7.0317100, 'MA', '2016-11-29', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92886, 'Abadou', 'Abadou', '', 31.5791700, -7.3130800, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92887, 'Mellila', 'Mellila', '', 33.3800000, -7.1400000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92888, 'Tidili Mesfioua', 'Tidili Mesfioua', '', 31.4658600, -7.6119900, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92889, 'Mhamid', 'Mhamid', 'Mhamid,Mkhamid,Мхамид', 29.8200000, -5.7200000, 'MA', '2012-01-19', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92890, 'Taghazout', 'Taghazout', 'Taghazout,Tarhazoute', 30.5425900, -9.7111500, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92891, 'Tamri', 'Tamri', '', 30.6960200, -9.8297200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92892, 'Smimou', 'Smimou', '', 31.2101400, -9.7086300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92893, 'Tizgane', 'Tizgane', '', 35.4121100, -5.0683600, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92894, 'Bouarouss', 'Bouarouss', 'Bou Arous,Bouarouss', 34.3600000, -4.8100000, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92895, 'Azla', 'Azla', '', 35.5530300, -5.2447200, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92896, 'Boukhalef', 'Boukhalef', 'Boukhalef,Tanger Boukhalef', 35.7328000, -5.8995400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92897, 'Jebel Tiskaouine', 'Jebel Tiskaouine', '', 31.0272200, -5.1164300, 'MA', '2005-04-12', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92898, 'Boujniba', 'Boujniba', 'Boujniba,Boujniba (Commune Urbaine),Boujniba (MU),ابي الجعد (البلدية)', 32.9004600, -6.7746400, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92899, 'Errachidia', 'Errachidia', 'Al-Rashidiyya,Ar-Raszidijja,ERH,Ehr-Rashidija,Er Rachidia,Er-Rachidia,Er-Rachidía,Errachidia,Imtɣeren,Ksar es-Souk,Rachidia,Rasidija,Rašidija,Rāšīdīja,alrshydyt,alrshydyt‎,ar-Rachidiya,ar-Rachīdīya,la xi di ye,Эр-Рашидия,א-רשידיה,الرشيدية,الرشيدية‎,الرشیدیہ,拉希迪耶', 31.9314000, -4.4266300, 'MA', '2016-11-02', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92900, 'Sidi Abdallah Ghiat', 'Sidi Abdallah Ghiat', '', 31.5230000, -7.8330000, 'MA', '2013-03-28', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92901, 'Dakhla', 'Dakhla', 'Dajla,Villa Cisneros,aldakhlt‎,الداخلة‎', 30.4107100, -9.5557200, 'MA', '2016-03-18', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92902, 'Mosquée', 'Mosquee', '', 34.8062200, -2.4129700, 'MA', '2014-03-14', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92903, 'Akhfennir', 'Akhfennir', '', 28.0945500, -12.0515700, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92904, 'Gueltat Zemmour', 'Gueltat Zemmour', '', 25.1427600, -12.3716800, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92905, 'Zawit Al Bour', 'Zawit Al Bour', '', 30.6747800, -8.1742400, 'MA', '2016-12-06', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(92906, 'Imlili', 'Imlili', '', 22.6558000, -15.6071900, 'MA', '2016-11-04', 151);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93023, 'Marigot', 'Marigot', 'Gorad Marygo,MSB,Marigo,Marigot,Marigoto,Marinko,Mariqo,XCJ,ma li ge,ma ri ko,maligas,maligo,marigo,marikat,marygw,Μαριγκό,Горад Марыго,Мариго,Маріго,ماریگاٹ,ماریگو,मारिगो,மரிகாட்,มารีโก,მარიგო,マリゴ,马里戈,마리갓,마리고', 18.0681900, -63.0830200, 'MF', '2017-06-22', 189);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93260, 'Miravci', 'Miravci', 'Miravci,Miravic,Mirivci,Mirovca,Mirovci,Миравци', 41.3092500, 22.4364100, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93261, 'Miletino', 'Miletino', 'Miletino,Милетино', 41.9075300, 21.0160100, 'MK', '2013-09-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93262, 'Миладиновци', 'Miladinovci', 'Adzarlar,Adžarlar,Ajalar,Aleksandrovo,Hadzarlar,Hadžarlar,Miladinovci', 41.9780600, 21.6494400, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93263, 'Mešeišta', 'Meseista', 'Mescista,Meseista,Meseiste,Mesevista,Meseviste,Mesheishta,Mesista,Mešeišta,Mešeište,Meševista,Meševište,Mešista,Meščišta,Мешеишта', 41.2381400, 20.7741400, 'MK', '2012-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93264, 'Матејче', 'Matejche', 'Matejca,Matejce,Matejche,Matejča,Metecje,Meteçjë,Матејче', 42.1255600, 21.5977800, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93265, 'Марино', 'Marino', 'Marino,Marino Selo,Марино', 41.9930600, 21.5911100, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93266, 'Lukovo', 'Lukovo', 'Dolno Lukovo,Gorno Lukovo,Lukovo,Луково', 41.3533900, 20.6063700, 'MK', '2015-04-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93267, 'Lojane', 'Lojane', 'Llojan,Lojane,Лојане', 42.2327600, 21.6655000, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93268, 'Logovardi', 'Logovardi', 'Cekrkci,Logovardi,Čekrkci,Логоварди', 41.0309600, 21.4096700, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93269, 'Ljubin', 'Ljubin', 'Ciflik Ljubin,Ljubin,Čiflik Ljubin,Љубин', 42.0013900, 21.3091700, 'MK', '2017-02-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93270, 'Lisičani', 'Lisicani', 'Lisicani,Lisichani,Lisičani,Лисичани', 41.4613900, 21.0544400, 'MK', '2014-01-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93271, 'Липково', 'Lipkovo', 'Lipkove,Lipkovo,Lipkovë,Липково', 42.1563900, 21.5852800, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93272, 'Lažani', 'Lazani', 'Lazani,Lazari,Lazhani,Lažani,Лажани', 41.4422200, 21.3158300, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93273, 'Larce', 'Larce', 'Larce,Lirce,Ларце', 41.9331900, 21.1262800, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93274, 'Лабуништа', 'Labunishta', 'Labunishta,Labunista,Labuniste,Labunište,Лабуништа', 41.2686100, 20.5961100, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93275, 'Kumanovo', 'Kumanovo', 'Gorad Kumanava,Koumanovo,Kumanova,Kumanovas,Kumanove,Kumanovo,Kumanovë,Kumanowo,ku ma nuo wo,kumanobo,kumanovu~o,kwmanwfw,Κουμάνοβο,Горад Куманава,Коуманово,Куманово,Կումանովո,קומאנובו,كومانوفو,کومانوفو,კუმანოვო,クマノヴォ,库马诺沃,쿠마노보', 42.1322200, 21.7144400, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93276, 'Kukurečani', 'Kukurecani', 'Kukurecani,Kukurechani,Kukurečani,Кукуречани', 41.0956200, 21.3245400, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93277, 'Куклиш', 'Kuklish', 'Kuklis,Kuklish,Куклиш', 41.4052800, 22.6652800, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93278, 'Крушопек', 'Krushopek', 'Krusopek,Krušopek', 41.9783300, 21.3544400, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93279, 'Крушево', 'Krushevo', 'Krusevo,Krushevo,Krusovo,Krušovo,Крушево', 41.3688900, 21.2488900, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93280, 'Krivogashtani', 'Krivogashtani', 'Krivogashtani,Krivogastane,Krivogastani,Krivogaštane,Кривогаштани', 41.3361100, 21.3330600, 'MK', '2011-08-16', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93281, 'Крива Паланка', 'Kriva Palanka', 'Kriva Palanka,Palangha,Крива Паланка', 42.2019400, 22.3319400, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93282, 'Kratovo', 'Kratovo', 'Kratova,Kratovo,Кратово', 42.0783800, 22.1807000, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93283, 'Krani', 'Krani', 'Hrani,Karahan,Krani,Крани', 40.9393400, 21.1091100, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93284, 'Kosel', 'Kosel', 'Kosel,Koselj,Косел', 41.1744400, 20.8355600, 'MK', '2012-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93285, 'Кондово', 'Kondovo', 'Kondovo', 42.0116700, 21.3136100, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93286, 'Konče', 'Konce', 'Konca,Konce,Konche,Kontche,Kontché,Konçe,Konča,Konče,Конче,კონჩე', 41.4951100, 22.3835900, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93287, 'Kochani', 'Kochani', 'Kocane,Kocani,Kochani,Kočane,Kočani,Кочани', 41.9163900, 22.4127800, 'MK', '2011-08-15', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93288, 'Клечовце', 'Klechovce', 'Klacovce,Klačovce,Klecevc,Klecevce,Klecevci,Klechevce,Kleçevc,Klečevce,Klečevci,Клечевце', 42.1161100, 21.8572200, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93289, 'Kičevo', 'Kicevo', 'Kercova,Kicevas,Kicevo,Kichevo,Kicsevo,Kiczewo,Kircova,Kitchevo,Kitsevo,Kičevas,Kičevo,Kërçova,Kırçova,ji qie wo,kichebo,kichevu~o,kychfw,kytshyfw,Κίτσεβο,Кичево,Кꙑчєво,كيتشيفو,کیچفو,კიჩევო,キチェヴォ,基切沃,키체보', 41.5126700, 20.9588600, 'MK', '2014-11-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93290, 'Kavadarci', 'Kavadarci', 'Kavadar,Kavadarci,Kavadarcis,Kavadari,Kavadartsi,Kavantartsi,Kawadarci,Tikves,Tikveš,ka wa da er qi,kabadaleuchi,kafadarchy,qbdrzy,Καβάνταρτσι,Кавадарци,Кавадарці,Կավադարցի,קבדרצי,کافادارچی,კავადარცი,卡瓦達爾奇,카바다르치', 41.4330600, 22.0119400, 'MK', '2015-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93291, 'Karbinci', 'Karbinci', 'Karabinci,Karbinci,Карбинци', 41.8175800, 22.2352900, 'MK', '2014-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93292, 'Kanatlarci', 'Kanatlarci', 'Kanatlarci,Канатларци', 41.2102800, 21.5033300, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93293, 'Kamenjane', 'Kamenjane', 'Kamenane,Kamenjan,Kamenjane,Камењане', 41.9456800, 20.9289400, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93294, 'Makedonska Kamenica', 'Makedonska Kamenica', 'Kamenica,Makedonska Kamenica,Македонска Каменица', 42.0207900, 22.5876000, 'MK', '2013-04-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93295, 'Кадино', 'Kadino', 'Kadino,Kadino Selo', 41.9688900, 21.6013900, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93296, 'Јурумлери', 'Jurumleri', 'Jurumleri,Јурумлери', 41.9672200, 21.5569400, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93297, 'Јегуновце', 'Jegunovce', 'Jegunovce,Јегуновце', 42.0736100, 21.1236100, 'MK', '2010-08-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93298, 'Jankovec', 'Jankovec', 'Jankoec,Jankovac,Jankovec,Јанковец', 41.1102800, 21.0113900, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93299, 'Извор', 'Izvor', 'Izvor,Извор', 42.2038900, 21.5783300, 'MK', '2008-02-29', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93300, 'Ivankovci', 'Ivankovci', 'Ivankovac,Ivankovci,Ivanlije,Иванковци', 41.8488900, 21.8202800, 'MK', '2014-04-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93301, 'Ilovica', 'Ilovica', 'Ilovica,Иловица', 41.4722400, 22.8048000, 'MK', '2014-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93302, 'Идризово', 'Idrizovo', 'Idrizovo', 41.9608300, 21.5755600, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93303, 'Gurgurnica', 'Gurgurnica', 'Grgurnica,Gurgurnica,Гургурница', 41.8450800, 21.1053800, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93304, 'Grnčari', 'Grncari', 'Grncare,Grncari,Grnchari,Grnčare,Grnčari,Грнчари', 41.0172200, 21.0533300, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93305, 'Грчец', 'Grchec', 'Dolni Grcec,Dolni Grčec,Grcac,Grcec,Grčac,Grčec', 41.9880600, 21.3302800, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93306, 'Gradsko', 'Gradsko', 'Gradsko,Градско', 41.5775000, 21.9427800, 'MK', '2014-04-30', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93307, 'Gradec', 'Gradec', '', 41.8961100, 20.9041700, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93308, 'Gradec', 'Gradec', 'Gradec,Градец', 41.8506800, 22.5113200, 'MK', '2015-09-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93309, 'Gostivar', 'Gostivar', 'Gostivar,Gostivar'',Gostivara,Gostivaras,Gostivari,Gostiwar,Gosztivar,Kostovon,Nkostivar,ge si di wa er,ghwstyfar,goseutibaleu,gosutivu~aru,gshtyfar,gwstybr,Γκόστιβαρ,Гостивар,Гостивар҄ь,Գոստիվար,גוסטיבר,غوستيفار,گشتیفار,გოსტივარი,ゴスティヴァル,戈斯蒂瓦尔,고스티바르', 41.7960100, 20.9081900, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93310, 'Gorobinci', 'Gorobinci', 'Gorabinc,Gorobinci,Gorovinci,Горобинци', 41.8750700, 21.8759900, 'MK', '2014-04-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93311, 'Gorno Orizari', 'Gorno Orizari', 'Gornji Orizari,Gornji-Celtiki,Gornji-Čeltiki,Gorno Orizari,Горно Оризари', 41.6858300, 21.7347500, 'MK', '2014-04-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93312, 'Gorno Orizari', 'Gorno Orizari', 'Gorno Orizari,Горно Оризари', 41.0518800, 21.3454800, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93313, 'Golema Rečica', 'Golema Recica', 'Golema Rechica,Golema Recica,Golema Rečica,Recica,Recice e Eperme,Reçicë e Epërme,Rečica,Velika Recica,Velika Rečica,Голема Речица', 41.9880300, 20.9451700, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93314, 'Gevgelija', 'Gevgelija', 'Devdelijad,Gevegeli,Gevgeli,Gevgelia,Gevgelija,Gevgeliya,Gewgelija,Gjevgjelia,Guevgueliya,Gyevgyelija,gai fu gai li ya,gbglyh,gebeugelliya,gevgelia,gevugeriya,gflya,ghyfghlya,Ðevđelijad,Γευγελή,Ђевђелија,Гевгели,Гевгелия,Гевгелија,Гевгелія,Гєѵгєла,Գևգելիա,גבגליה,غيفغليا,گفلیا,გევგელია,ゲヴゲリヤ,蓋夫蓋利亞,게브겔리야', 41.1416600, 22.5014100, 'MK', '2012-12-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93315, 'Forino', 'Forino', 'Forino,Форино', 41.8233400, 20.9617400, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93316, 'Лозово', 'Lozovo', 'Dzumajlija,Dzumali,Džumajlija,Džumali,Lozovo,Лозово', 41.7838900, 21.9055600, 'MK', '2007-08-17', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93317, 'Džepčište', 'Dzepciste', 'Dzepchishte,Dzepciste,Dzepiste,Džepište,Džepčište,Џепчиште', 42.0328700, 20.9981700, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93318, 'Другово', 'Drugovo', 'Drugovo,Другово', 41.4841700, 20.9233300, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93319, 'Gjorče Petro', 'Gjorce Petro', 'Djorce Petrov,Djorče Petrov,Dolce Petrov,Gjorce Petrov,Gjorçe Petrov,Gorc Petrov,Gorce Petrov,Gorč Petrov,Gorče Petrov', 42.0077800, 21.3530600, 'MK', '2016-03-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93320, 'Dolno Palčište', 'Dolno Palciste', 'Dolno Palchishte,Dolno Palciste,Dolno Palčište,Pallcishte,Pallçishte,Долно Палчиште', 41.9685900, 20.9289900, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93321, 'Dolno Orizari', 'Dolno Orizari', 'Dolno Orizari,Долно Оризари', 41.0502800, 21.3794400, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93322, 'Dolno Količani', 'Dolno Kolicani', 'Dolno Kolicane,Dolno Kolicani,Dolno Kolichani,Dolno Količane,Dolno Količani,Donje Kolicane,Donje Količane,Долно Количани', 41.8863900, 21.4855600, 'MK', '2013-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93323, 'Долнени', 'Dolneni', 'Dolneni,Dolnjane,Dolnjani,Долнени', 41.4252800, 21.4547200, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93324, 'Dolna Banjica', 'Dolna Banjica', 'Dolna Banica,Dolna Banjica,Долна Бањица', 41.7861100, 20.9061100, 'MK', '2012-04-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93325, 'Dobruševo', 'Dobrusevo', 'Dobrusevo,Dobrushevo,Dobruševo,Добрушево', 41.1686100, 21.4825000, 'MK', '2014-03-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93326, 'Dobrošte', 'Dobroste', 'Dobroshte,Dobroshtë,Dobroste,Dobrošte', 42.1033300, 21.0777800, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93327, 'Dobri Dol', 'Dobri Dol', 'Doberdol,Dobri Dol,Dobri-Do,Dobërdol,Добри Дол', 41.8652000, 20.8900900, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93328, 'Desovo', 'Desovo', 'Desovo,Десово', 41.4627800, 21.4911100, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93329, 'Демир Капија', 'Demir Kapija', 'Banja,Demir Kapija,Демир Капија', 41.4050000, 22.2488900, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93330, 'Delogožda', 'Delogozda', 'Delagozde,Delagožde,Delogozda,Delogozdi,Delogozhda,Delogozhdi,Delogožda,Delogoždi,Делогожда,Делогожди', 41.2572800, 20.7218000, 'MK', '2013-10-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93331, 'Delcevo', 'Delcevo', 'Carevo Selo,Delcevo,Delchevo,Делчево', 41.9672200, 22.7694400, 'MK', '2014-03-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93332, 'Debar', 'Debar', 'Bebar,Debar,Debara,Debaras,Debaru,Debre,Debur,Dibra,Dibre-i-Bala,Divri,dbar,de ba er,debaleu,debari,dybar,Δίβρη,Дебар,Дебър,Дєбаръ,دبار,ديبار,დებარი,德巴爾,데바르', 41.5244400, 20.5242100, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93333, 'Чучер - Сандево', 'Chucher - Sandevo', 'Chucher,Cucer,Cucer-Sandevo,Čučer,Čučer-Sandevo,Чучер', 42.1036100, 21.3822200, 'MK', '2007-05-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93334, 'Crnilište', 'Crniliste', 'Crnilishte,Crniliste,Crnilište,Црнилиште', 41.5302500, 21.4141600, 'MK', '2015-05-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93335, 'Црешево', 'Creshevo', '', 42.0508300, 21.5097200, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93336, 'Češinovo', 'Cesinovo', 'Cesinovis,Cesinovo,Cheshinovo,Češinovis,Češinovo,Чешиново', 41.8714800, 22.2896100, 'MK', '2014-08-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93337, 'Čelopek', 'Celopek', 'Callapek,Celopek,Chelopek,Çallapek,Čelopek,Челопек', 41.9316700, 21.0133300, 'MK', '2013-09-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93338, 'Чегране', 'Chegrane', 'Cegran,Cegrane,Chegrane,Çegran,Чегране', 41.8388900, 20.9758300, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93339, 'Čaška', 'Caska', 'Caska,Chashka,Čaška,Чашка', 41.6505600, 21.6622200, 'MK', '2013-08-07', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93340, 'Capari', 'Capari', 'Capari,Цапари', 41.0565600, 21.1788400, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93341, 'Булачани', 'Bulachani', 'Bulacane,Bulacani,Bulačane,Bulačani', 42.0705600, 21.5027800, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93342, 'Bukovik', 'Bukovik', 'Bukovik,Буковиќ', 41.9683300, 21.2369400, 'MK', '2008-03-27', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93343, 'Bučin', 'Bucin', 'Buchin,Bucin,Bučin,Бучин', 41.2737700, 21.3169200, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93344, 'Brvenica', 'Brvenica', 'Bervenice,Brvence,Brvenica,Bërvenicë,Брвеница,Брвенце', 41.9672200, 20.9808300, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93345, 'Makedonski Brod', 'Makedonski Brod', 'Brod,Brod Makedonski,Brodi,Juzni Brod,Južni Brod,Makedon''sku Brodu,Makedons''ki-Brod,Makedonska Broda,Makedonski Brod,Makedonski Brodas,Makedonski-Brod,brwd,ma qi dun bu luo de,mkdwnsky bwrd,Брод,Македонски Брод,Македонски-Брод,Македонськи-Брод,Макєдоньскъ Бродъ,برود,مکدونسکی بورد,მაკედონსკი-ბროდი,馬其頓布羅德', 41.5136100, 21.2152800, 'MK', '2013-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93346, 'Bosilovo', 'Bosilovo', 'Bosiljovo,Bosilovo,Босилово', 41.4405600, 22.7277800, 'MK', '2015-11-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93347, 'Bojane', 'Bojane', 'Bojana,Bojane,Бојане', 42.0000900, 21.1926500, 'MK', '2017-02-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93348, 'Bogovinje', 'Bogovinje', 'Bogovina,Bogovine,Bogovinje,Bogovino,Боговиње', 41.9236100, 20.9136100, 'MK', '2014-10-01', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93349, 'Богомила', 'Bogomila', 'Bogomila,Bogumil,Богомила', 41.5930600, 21.4716700, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93350, 'Богданци', 'Bogdanci', 'Bogdanci,Богданци', 41.2030600, 22.5755600, 'MK', '2007-08-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93351, 'Blatec', 'Blatec', 'Blaca,Blatac,Blatec,Блатец', 41.8366800, 22.5790900, 'MK', '2015-09-06', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93352, 'Bitola', 'Bitola', 'Bitol,Bitola,Bitolj,Bitolja,Bitolya,Manastir,Manastiri,Manastır,Monasterium,Monasteron,Monastir,Monastiri,Monastirion,Obitѣl'',QBI,bi tuo la,bitolla,bitora,bytwla,bytwlh,Μοναστήρι,Μοναστήριον,Μπίτολα,Битола,Битоля,Битољ,Бітола,Манастир,Обитѣль,ביטולה,بيتولا,بیتولا,ビトラ,比托拉,비톨라', 41.0314300, 21.3347400, 'MK', '2015-04-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93353, 'Бистрица', 'Bistrica', 'Bistrica,Feistritz,Бистрица', 40.9833300, 21.3666700, 'MK', '2010-08-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93354, 'Berovo', 'Berovo', 'Berovo,Берово', 41.7030600, 22.8577800, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93355, 'Beranci', 'Beranci', 'Beranci,Беранци', 41.1596900, 21.3596300, 'MK', '2014-02-10', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93356, 'Belčišta', 'Belcista', 'Belchishta,Belcista,Belciste,Belčišta,Belčište,Белчишта', 41.3027800, 20.8302800, 'MK', '2014-01-13', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93357, 'Bedinje', 'Bedinje', 'Bedine,Bedinje,Бедиње', 42.1416700, 21.6963900, 'MK', '2015-06-08', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93358, 'Батинци', 'Batinci', 'Batinc,Batinci,Батинци', 41.9197200, 21.4819400, 'MK', '2013-06-20', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93359, 'Арачиново', 'Arachinovo', 'Aracine,Aracinovo,Araçinë,Aračinovo', 42.0263900, 21.5619400, 'MK', '2006-10-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93360, 'Poroj', 'Poroj', 'Poroj,Порој', 42.0291300, 20.9926600, 'MK', '2014-09-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93361, 'Strimnica', 'Strimnica', 'Strimnica,Стримница', 41.9671900, 21.0359800, 'MK', '2013-09-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93362, 'Dobarce', 'Dobarce', 'Dobarce,Добарце', 41.9553000, 21.0887500, 'MK', '2013-09-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93363, 'Zelenikovo', 'Zelenikovo', 'Stanica Zelenikovo,Zelenikovo,Zeleznicka Stanica Zelenikovo,Železnička Stanica Zelenikovo,Зелениково,Станица Зелениково', 41.8733300, 21.6030600, 'MK', '2013-06-05', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93364, 'Šuto Orizare', 'Suto Orizare', 'Shuto Orizari,Suto Orizare,Šuto Orizare,Шуто Оризари', 42.0400000, 21.4250000, 'MK', '2013-08-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93365, 'Butel', 'Butel', 'Butel,Butelj,Бутел', 42.0308300, 21.4466700, 'MK', '2013-08-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93366, 'Čair', 'Cair', 'Cair,Chair,Čair,Чаир', 42.0152800, 21.4411100, 'MK', '2017-02-28', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93367, 'Ilinden', 'Ilinden', 'Belimbegovo,Ilinden,Белимбегово,Илинден', 41.9945100, 21.5800200, 'MK', '2013-11-11', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93368, 'Kisela Voda', 'Kisela Voda', 'Kisela Voda,Кисела Вода', 41.9488900, 21.5027800, 'MK', '2013-08-04', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93369, 'Centar Župa', 'Centar Zupa', 'Centar Zhupa,Centar Zsupa,Merkez Jupa,Qendra Zhupa,Tsentar Joupa,Vapa,Вапа,Центар Жупа,ცენტარ-ჟუპა', 41.4784900, 20.5594500, 'MK', '2013-08-09', 132);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93370, 'Youwarou', 'Youwarou', 'Youvarou,Youwarou', 15.3684000, -4.2628000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93371, 'Yorosso', 'Yorosso', 'Joroso,Yorosso,Йоросо', 12.3581100, -4.7768800, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93372, 'Yélimané', 'Yelimane', 'EYL,Yelimane,Yélimané', 15.1186800, -10.5772900, 'ML', '2017-06-19', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93373, 'Yanfolila', 'Yanfolila', 'Yanfolila', 11.1833300, -8.1500000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93374, 'Tominian', 'Tominian', 'Tomina,Tominian', 13.2873700, -4.5931700, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93375, 'Timbuktu', 'Timbuktu', 'TOM,Timbocto,Timboctu,Timboctó,Timboctú,Timboektoe,Timbouctou,Timbuctoo,Timbuctu,Timbuctù,Timbuctú,Timbuktu,Timbuktuo,Timbuktú,Timbúktú,Timbûktû,Timpouktou,Tiombuctu,Tombouctou,Tombuctu,Tombuctú,Tombuktu,Tombutu,Tombutum,Tonbuktu,rrimbakrru,tang pu tu,thim bak tu,tibakatu,timabuktu,timbakatu,timbaktu,timbugtu,timpaktu,ting ba ke tu,tmbktw,tonbukuto~u,tymbwktw,tymbwqtw,Τιμπουκτού,Тимбукту,Томбукту,Тімбукту,טימבוקטו,تمبكتو,تیمبوکتو,ٹمبکٹو,टिंबक्टू,टिम्बकटू,तिमबुक्तु,ਤਿੰਬਕਤੂ,ટિમ્બક્ટુ,திம்பக்து,టింబక్టు,ಟಿಂಬಕ್ಟು,റ്റിംബക്റ്റൂ,ทิมบักตู,ტომბუქტუ,トンブクトゥ,廷巴克图,廷巴克圖,湯瀑圖,팀북투', 16.7734800, -3.0074200, 'ML', '2012-06-01', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93376, 'Tessalit', 'Tessalit', 'Tesalit,Tessalit,tai sa li,Τεσσαλίτ,Тесалит,泰薩利', 20.2012600, 1.0118600, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93377, 'Ténenkou', 'Tenenkou', 'Tenenkou,Ténenkou', 14.4572200, -4.9169000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93378, 'Taoudenni', 'Taoudenni', 'Taodeni,Taodenni,Taodéni,Taoudeni,Taoudenni,Taoudéni,Taudeni,Taudenio,Taudenis,Taŭdenio,taudeni,twdny,Таоденни,تودني,タウデニ', 22.6744300, -3.9789100, 'ML', '2012-10-07', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93379, 'Sokolo', 'Sokolo', 'Soala,Sokolo,Swala,Соколо', 14.7328000, -6.1219000, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93380, 'Sikasso', 'Sikasso', 'KSS,Sikasas,Sikaso,Sikasso,shikaso,sikaso,sykasw,xi ka suo,Σικασσό,Сикасо,Сікасо,سيكاسو,سیکاسو,シカソ,錫卡索,시카소', 11.3175500, -5.6665400, 'ML', '2017-06-19', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93381, 'Séguéla', 'Seguela', 'Sagala,Segala,Segela,Seguela,Séguéla,Ségéla', 14.1126600, -6.7286500, 'ML', '2017-02-14', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93382, 'Ségou', 'Segou', 'Segi,Segou,Segu,Segú,Senkou,Ségou,sai gu,segu,sgw,syghw,Σεγκού,Сеги,Сегу,سيغو,سگو,セグー,塞古,세구', 13.4317000, -6.2157000, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93383, 'San', 'San', 'San', 13.3033500, -4.8956200, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93384, 'Sagalo', 'Sagalo', 'Sagallo,Sagalo', 12.2000000, -10.7000000, 'ML', '2013-10-30', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93385, 'Ntossoni', 'Ntossoni', 'Ntosoni,Ntossoni', 12.5304000, -5.7700300, 'ML', '2016-07-03', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93386, 'Nioro', 'Nioro', 'NIX,Nioro,Nioro du Sahel,Noiro', 15.2293200, -9.5927700, 'ML', '2014-05-29', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93387, 'Niono', 'Niono', 'Niono,Нионо', 14.2526000, -5.9930000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93388, 'Niafunké', 'Niafunke', 'Matounke,Niafounke,Niafounké,Niafunke,Niafunké', 15.9322000, -3.9906000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93389, 'Nara', 'Nara', 'NRM,Nara', 15.1687500, -7.2846600, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93390, 'Mopti', 'Mopti', 'MZI,Mopti,Moptis,mo pu ti,mobti,moputi,mwbty,mwpty,Μοπτί,Мопти,Мопті,موبتي,موپتی,موپٹی,モプティ,莫普提,몹티', 14.4843000, -4.1829600, 'ML', '2012-05-31', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93391, 'Ménaka', 'Menaka', 'Menaka,Ménaka,mei na ka,Μενακά,Менака,梅納卡', 15.9182000, 2.4022000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93392, 'Markala', 'Markala', 'Markala', 13.7021000, -6.0659000, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93393, 'Koutiala', 'Koutiala', 'KTX,Koutiala,Kutiala,ku jia la,Кутиала,庫佳拉', 12.3917300, -5.4642100, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93394, 'Koulikoro', 'Koulikoro', 'Koulikoro,Koulikoro-Liberte,Koulikoro-Liberté,Kulikoras,Kulikoro,Kulikɔrɔ,ku li ke luo,kullikolo,kurikoro,kwlykwrw,Κουλικορό,Куликоро,Кулікоро,كوليكورو,کولیکورو,クリコロ,庫利科羅,쿨리코로', 12.8627300, -7.5598500, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93395, 'Koro', 'Koro', 'Koro', 14.0640000, -3.0753900, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93396, 'Kolondiéba', 'Kolondieba', 'Kolondieba,Kolondiéba', 11.0894300, -6.8929000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93397, 'Kolokani', 'Kolokani', 'Kokolani,Kolokani,Колокани', 13.5728000, -8.0339000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93398, 'Kokofata', 'Kokofata', 'Kokofata', 12.8833300, -9.9500000, 'ML', '2013-05-05', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93399, 'Kita', 'Kita', 'Kita', 13.0349000, -9.4895000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93400, 'Kidal', 'Kidal', 'Kidal,Kidal'',Kidalis,Kintal,ji da er,kidal,kidaru,kydal,Κιντάλ,Кидаль,Кідаль,كيدال,کڈال,کیدال,キダル,基達爾,키달', 18.4411100, 1.4077800, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93401, 'Kinmparana', 'Kinmparana', 'Kemparana,Kimpanana,Kimparala,Kimparana,Kinmparana', 12.8421700, -4.9245000, 'ML', '2013-02-08', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93402, 'Ké-Macina', 'Ke-Macina', 'Ke Machine,Ke Macina,Ke Massina,Ke-Macina,Ke-Masina,Ke-Masino,Ké Macina,Ké Massina,Ké-Macina', 13.9641000, -5.3579100, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93403, 'Kayes', 'Kayes', 'Gorad Kaes,KYS,Kaes,Kagies,Kajes,Kajesas,Kayes,Kayi,ka yi,kai,kays,keseu,kyz,Καγιές,Горад Каес,Каес,Кайес,Каєс,كايس,کایس,کیز,კაესი,カイ,卡伊,케스', 14.4469300, -11.4444800, 'ML', '2012-10-07', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93404, 'Kati', 'Kati', 'Kati,Kati Ville,Katis,ka di,katy,Кати,كاتي,卡蒂', 12.7440900, -8.0725700, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93405, 'Kangaba', 'Kangaba', 'Kaba,Kangaba,Kangara,Кангаба', 11.9333300, -8.4166700, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93406, 'Kadiolo', 'Kadiolo', 'Kadiolo', 10.5500000, -5.7666700, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93407, 'Gourma Rharous', 'Gourma Rharous', 'Gourma Rharous,Gourma-Barous,Gourma-Rarous,Gourma-Rharous,Rharous', 16.8777800, -1.9230600, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93408, 'Goundam', 'Goundam', 'GUD,Goundam', 16.4145300, -3.6707500, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93409, 'Gao', 'Gao', 'GAQ,Gao,Nkao,gao,gaw,gayw,jaw,jia ao,ka xo,Γκάο,Гао,Ґао,גאו,جاو,گائو,گاو,กาโอ,ガオ,加奥,가오', 16.2716700, -0.0447200, 'ML', '2017-02-13', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93410, 'Douentza', 'Douentza', 'Douentza,Douenza', 15.0015500, -2.9497800, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93411, 'Djénné', 'Djenne', 'Djenne,Djenné,Djénné,dzhene,jnh,Джене,جنه', 13.9060800, -4.5533200, 'ML', '2007-03-01', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93412, 'Diré', 'Dire', 'Dire,Diré', 16.2570500, -3.4012600, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93413, 'Diré', 'Dire', '', 12.2833300, -10.9666700, 'ML', '2006-01-17', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93414, 'Dioila', 'Dioila', 'Dioila,Dioïla', 12.4822000, -6.7911000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93415, 'Diéma', 'Diema', 'Diema,Diena,Diéma,Diéna', 14.5400000, -9.1921000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93416, 'Bourem', 'Bourem', 'Bourem,Burem', 16.9550000, -0.3486100, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93417, 'Bougouni', 'Bougouni', 'Bougoum,Bougouni,Buguni', 11.4176900, -7.4832300, 'ML', '2012-06-08', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93418, 'Bla', 'Bla', 'Bla', 12.9500700, -5.7602400, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93419, 'Barouéli', 'Baroueli', 'Baroueli,Barouéli,Barweli,Barwéli', 13.0770000, -6.8312000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93420, 'Bankass', 'Bankass', 'Bankas,Bankass,Bankasse,Bankassi,Bankassé', 14.0775000, -3.5159400, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93421, 'Bandiagara', 'Bandiagara', 'Bandiagara', 14.3500500, -3.6103800, 'ML', '2007-03-01', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93422, 'Banamba', 'Banamba', 'Banamba', 13.5477300, -7.4480800, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93423, 'Bamako', 'Bamako', 'BKO,Bamaco - Bamako,Bamakas,Bamako,Bamaku,Bamakó,Bamakɔ,Bammaco,Bammako,Mpamako,ba ma ke,bamako,bamakw,bmqw,Μπαμάκο,Бамако,Բամակո,במקו,باماكو,باماکو,ባማኮ,バマコ,巴馬科,바마코', 12.6500000, -8.0000000, 'ML', '2015-06-03', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93424, 'Bafoulabé', 'Bafoulabe', 'Bafoulabe,Bafoulabé,Bafulabe', 13.8065000, -10.8321000, 'ML', '2013-11-09', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93425, 'Araouane', 'Araouane', 'Araouan,Araouane,Araoune,Arawan', 18.9047600, -3.5264900, 'ML', '2012-01-18', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93426, 'Ansongo', 'Ansongo', 'Ansongo', 15.6597000, 0.5022000, 'ML', '2016-06-14', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93427, 'Abeïbara', 'Abeibara', 'Abeibara,Abeïbara', 19.1166700, 1.7500000, 'ML', '2013-11-12', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93428, 'Inékar', 'Inekar', 'Inekar,Inékar', 15.9594400, 3.1411100, 'ML', '2013-05-05', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93429, 'Ti-n-Essako', 'Ti-n-Essako', 'Ti-n-Essako,Tin-Essako', 18.4505900, 2.4879500, 'ML', '2013-11-14', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93430, 'Leleni', 'Leleni', '', 12.3894400, -5.2452800, 'ML', '2016-10-13', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93431, 'Figuira-Toma', 'Figuira-Toma', '', 11.9166700, -8.3666700, 'ML', '2017-03-06', 137);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93506, 'Uyenchi Somon', 'Uyenchi Somon', 'Uinchi sumu,Uyenchi,Uyenchi Somon,Uyenchi Suma,Uyonch,Üyenchi Suma,Üyönch', 46.0500000, 92.0166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93507, 'Uujim', 'Uujim', 'Sagsai,Sagsaj,Sagsay,Sagsaï,Uujim,Сагсай', 48.9000000, 89.6166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93508, 'Urdgol', 'Urdgol', 'Chandman'',Chandmani,Chandmanĭ,Chandman’,Chindamani,Chindamani Somon,Chindamani Suma,Chindamani sumu,Urdgol', 47.8333300, 92.6500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93509, 'Uliastay', 'Uliastay', 'Chdzibkhalantu,Chzhibgalantu Somon,Chzhibkhalantu,Chzhibkholantu sumu,Djibkhlantu,Djibkhulantu,Dzhibkhalantu,Dzhibkholantu,Dzhibkhulantu,Javhlant,Javkhlant,Jawkhlant,Jibhalanta,Jibhalantu,Jibholantu,Jibhulantu,Jibkhalantu,Oulia-Sontai,ULZ,Uliassutai,Uliastai,Uliastaj,Uliastay,Uliyassutai,Uliyasutai,Uljassutai,Uljasutai,Ulyaasatay,Ulyasutay,Uriyasutai,Wu-li-ya-su-t''ai,Wu-li-ya-su-t’ai,Wu-lu-ya-su-t''ai,Wu-lu-ya-su-t’ai,awlyasty,olliaseutai,uliasutʼai,uliyasta''i,uriyasutai,wu li ya su tai cheng,Улиастай,Уліастай,اولیاستی,उलियास्ताइ,ულიასუტაი,ウリヤスタイ,烏里雅蘇臺城,올리아스타이', 47.7416700, 96.8444400, 'MN', '2016-11-02', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93510, 'Ulaantolgoy', 'Ulaantolgoy', 'Most,Möst,Ulaantolgoy', 46.6833300, 92.7833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93511, 'Ulaangom', 'Ulaangom', 'ULO,Ulaan Goom,Ulaanggom,Ulaangom,Ulaangom sumu,Ulan Kan,Ulangom,Ulankom,Wu-lan-ku-mu,Улаангом,Улангом', 49.9811100, 92.0666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93512, 'Tsetserleg', 'Tsetserleg', 'Ondor Hangay Suma,Ondorhangay,Ondorkhangai,Öndör Hangay Suma,Öndörhangay,Öndörkhangaï', 49.2712800, 94.8583600, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93513, 'Tsetsegnuur', 'Tsetsegnuur', 'Tsetseg,Tsetseg Nuur,Tsetseg Somon,Tsetseg Suma,Tsetseg nuur sumu,Tsetseg-Nur,Tsetsegnuur', 46.6000000, 93.2666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93514, 'Tsenher', 'Tsenher', 'Monhhayrhan,Monho Hayrhan Suma,Monho hayrhan,Monho hayrhan sumu,Monkhkhairkhan,Monko Khairkhan Sume,Munhe-hairuhan,Munkhe-Khayrkhan-Sumu,Munkhu Khayrkhan Somon,Munkhu-khayrkhan,Mönhhayrhan,Mönhö Hayrhan Suma,Mönhö hayrhan,Mönhö hayrhan sumu,Mönkhkhaïrkhan,Mönkö Khairkhan Sume,Tsastu Ula Somon,Tsenher', 46.9166700, 92.1166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93515, 'Tseel', 'Tseel', 'Tseel,Tseel Suma,Tseel'' Somon,Tseel'' sumu,Tseel’ Somon,Tseel’ sumu,Tsel,Tsel Sume', 45.5666700, 95.8666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93516, 'Tsalgar', 'Tsalgar', 'Malchin,Malchin Suma,Malchin Sume,Malchin somon,Malchin sumu,Tsalgar,Малчин', 49.7166700, 93.2666700, 'MN', '2014-06-27', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93517, 'Tsahir', 'Tsahir', 'Cakhir,Tsahir,Tsahir Suma,Tsahir sumu,Tsakhir,Tsakhir Sume,Tsakhir somon,Цахир', 48.0797200, 98.8516700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93518, 'Tsagaantüngi', 'Tsagaantungi', 'Altantsogts,Altantsögts,Tsagaantungi,Tsagaantüngi', 49.0500000, 90.4500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93519, 'Tsagaan-Olom', 'Tsagaan-Olom', 'Taishir,Tayshir,Taïshir,Tsagan Olom,Tsagan olon', 46.7132700, 96.5258800, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93520, 'Tsagaanchuluut', 'Tsagaanchuluut', '', 47.1119600, 96.6714500, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93521, 'Tosontsengel', 'Tosontsengel', 'Shumultain khure,Shumultuin Khure,Shumultuyn-khure,Shumuultayn Huryee,Shumuultayn Hüryee,Shumuultiin Khuree,Shumuultiin Khüree,Shumuultuiin huriye,Shumuultuiin hüriye,Shumuultuin huriye,Shumuultuïn hüriye,TNZ,Toson Tsengel Suma,Toson tsengel sumu,Tosontsengel,Tosyn tsengel somon', 48.7566700, 98.2838900, 'MN', '2013-03-02', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93522, 'Tooromt', 'Tooromt', 'Tes,Tesin Suma,Tooromt', 50.4666700, 93.5833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93523, 'Tolbo', 'Tolbo', 'Tolbo,Tolbo Nuur Hoshuun,Tolbo Nuur Suma,Tolbo nuur hoshu,Tolbo-Nur,Tolbo-Nur-Khoshu,Tolbo-Nur-Somon,Tolbonuur,Толбо', 48.4166700, 90.2833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93524, 'Tögrög', 'Togrog', 'Manhan,Manhan Suma,Manhan sumu,Mankhan,Mankhan Somon,Mankhan Sume,Mankhan-Sumu', 47.4241400, 92.2243900, 'MN', '2007-10-24', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93525, 'Tögrög', 'Togrog', 'Togorig,Togorig Suma,Torog,Tugurig,Tugurig Sume,Tugurig somon,Tugurig sumu,Tugurik,Tugurik Somon,Tögörig,Tögörig Suma,Tügürig sumu', 45.8297600, 94.8154400, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93526, 'Vlaa Vula', 'Vlaa Vula', 'Toegoel,Togol,Tögöl,Ulaan Uula Suma,Ulaan Uula sumu,Ulaan uula,Ulaan-Uul,Ulan Ula Somon,Ulan-Ula,Vlaa Vula,Улан-Ула', 50.6833300, 99.2333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93527, 'Tegsh', 'Tegsh', 'Tsetsen-Uul', 48.7513200, 95.9997400, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93528, 'Taygan', 'Taygan', 'Del''ger sumu,Delger,Delger Somon,Delger Suma', 46.3535600, 97.3663300, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93529, 'Talshand', 'Talshand', 'Chandmani,Chandmanĭ,Chindamani,Chindamani Somon,Chindamani Suma,Talshand', 45.3333300, 97.9833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93530, 'Tahilt', 'Tahilt', 'Tsogt,Tsogto Suma,Tsogtu,Tsogtu Somon,Tsogtu Sumu,Tsokt somon', 45.3466000, 96.6457000, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93531, 'Shiree', 'Shiree', 'Tsagaan Hayrhan Suma,Tsagaan hayrhan sumu,Tsagaanhayrhan,Tsagaankhairkhan,Tsagaankhaïrkhan,Tsagan Hayrhan,Tsagan Khayrkhan somon,Tsagan-Khayrkhan', 47.4971400, 96.8031100, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93532, 'Sharga', 'Sharga', 'Sharga,Tsagaan Uula Suma,Tsagaan uula,Tsagaan uula sumu,Tsagaan-Uul,Tsagan Ula Sume,Tsagan-Ula,Tsagan-Ula somon', 49.8000000, 98.8000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93533, 'Sharga', 'Sharga', 'Sharga', 46.2500000, 95.2666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93534, 'Sharbulag', 'Sharbulag', 'Dsabkhan Sume,Dzabhan Gol,Dzabhan Suma,Dzabhan gol sumu,Dzabkhan,Dzabkhan-Gol-Sumu,Dzavhan,Dzawkhan,Sharbulag,Tszabkhan somon,Дзабхан', 48.8166700, 93.1000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93535, 'Sayn-Ust', 'Sayn-Ust', 'Hohmorit,Hohmorĭt,Hoho Morito Suma,Hoho moritu,Hoho moritu sumu,Höhö Morito Suma,Höhö moritu sumu,Höhö moritü,Khokhmor''t,Khukhu-Moritu,Khukhu-Moritu Somon,Koko Moritu Sume,Kökö Möritu Sume', 47.3573200, 94.5244800, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93536, 'Sangiyn Dalay', 'Sangiyn Dalay', 'Erdene,Erdeni,Erdeni Somon,Erdeni Suma,Erdeni Sume,Erdeni sumu,Sangiyn Dalay', 45.1333300, 97.7500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93537, 'Rashaant', 'Rashaant', 'Deliin,Deluun,Delüün,Hoshog Suma,Khosak Suma,Khoshak,Khoshak Sumu,Khoshak somon,Koshag Suma,Rashaant', 47.7666700, 90.8333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93538, 'Oygon', 'Oygon', 'Oygon,Tudehvtehj,Tudentei,Tudevtey,Tüdenteï,Tüdevtey,Тудэвтэй', 48.9856200, 96.5433900, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93539, 'Telmin Suma', 'Telmin Suma', 'OEvoegdiy,Ovgodiy,Ovogdiy,Tehlmehn,Tel''min sumu,Telmen,Telmin,Telmin Suma,Telmin somon,Tel’min sumu,Övgödiy,Övögdiy,Тэлмэн', 48.6427800, 97.6186100, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93540, 'Orgil', 'Orgil', 'Dzhargalant,Ihe jirgalantu sumu,Ikhe Djirgalantu Sume,Ikhe Jirgalantu,Ikhe chzhirgalatu somon,Ikhe-chzhirgalantu somon,Jargalant,Orgil,Yihe Jirgalanta Suma,Джаргалант', 48.5872200, 99.3508300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93541, 'Ölgii', 'OElgii', 'Bayan-Ulegey,OElgii,OElgiy,Olgii,Ologey,ULG,Ul''gey,Ulegei,Ulegey,Ulegy,Ulgij,Ölgii,Ölgiy,Ölögey,Улгий,Өлгий', 48.9683300, 89.9625000, 'MN', '2016-12-11', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93542, 'Nuga', 'Nuga', 'Dzabhan Mandal Suma,Dzabkhan-Mandal,Dzavhanmandal,Dzawkhanmandal,Nuga,Дзабхан-Мандал', 48.3166700, 95.1166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93543, 'Nogoonnuur', 'Nogoonnuur', 'Nogon-Nur,Nogoonnuur,Notoonnuur,Ногон-Нур', 49.6162700, 90.2420400, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93544, 'Naranbulag', 'Naranbulag', 'Naran-Bulak,Naranbulag,Наран-Булак', 49.3666700, 92.5666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93545, 'Namir', 'Namir', 'Namir,Omnogovi,Omnogow'',Omono Gobi,Omono Gobi Suma,Omono Gobi Sume,Omono Gobi Sumu,Umne-Gobi,Umneh-Gobi,Umun Gobi,Umun-gobi somon,Ömnögovĭ,Ömnögow'',Ömönö Gobi,Ömönö Gobi Suma,Ömönö Gobi Sume,Ömönö Gobi Sumu,Умнэ-Гоби', 49.1064100, 91.7178200, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93546, 'Tsagaanhayrhan', 'Tsagaanhayrhan', 'Mondoohoo,Möndööhöö,Tsagaanhayrhan,Tsagaankhairkhan,Tsagaankhaïrkhan', 49.4000000, 94.2333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93547, 'Mandal', 'Mandal', 'Ar-Bulak,Ara Bulag Suma,Ara Buluk Sume,Ara bulag sumu,Ara-Bulag,Ara-Bulak Somon,Arbulag,Mandal,Ар-Булак', 49.9000000, 99.4333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93548, 'Jargalant', 'Jargalant', 'Dzun-Khangaj,Dzuun Hangay Suma,Dzuunhangay,Dzuunkhangai,Dzüün Hangay Suma,Dzüünhangay,Dzüünkhangaï,Jargalant,Дзун-Хангай', 49.3067700, 95.4478500, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93549, 'Jargalant', 'Jargalant', 'Jargalant', 47.1500000, 99.6333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93550, 'Jargalant', 'Jargalant', 'Bulagan Suma,Bulgan', 46.9267000, 91.0878200, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93551, 'Jargalant', 'Jargalant', 'Beger,Beger Somon,Biger,Biger Suma,Bigger,Bigger sumu', 45.7095400, 97.1759600, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93552, 'Ider', 'Ider', 'Galt,Ider,Галт', 48.7727800, 99.8738900, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93553, 'Hunt', 'Hunt', 'Hangai,Hangay,Hangay Suma,Hangay sumu,Hunt,Khangai,Khangai Sume,Khangay,Khangay Somon', 47.8666700, 99.4666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93554, 'Hungiy', 'Hungiy', 'Hungiy,Urgamal,Urgamal Suma,Urgomal,Urgomal somon,Urgomal sumu,Urgumal,Urgumal Sume,Ürgomal sumu,Ургамал', 48.5167200, 94.2942800, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93555, 'Höviyn Am', 'Hoeviyn Am', 'Gurban Bulag Suma,Gurban Bulak,Gurban Bulak Somon,Gurban Buluk Sume,Gurban bulag,Gurban bulag sumu,Gurvan-Bulak,Gurvanbulag,Gurwanbulag', 47.2312300, 98.5714000, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93556, 'Höshööt', 'Hoshoot', 'Tsengel,Tsengel Suma,Tsengel'' somon', 48.9477600, 89.1435800, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93557, 'Holboo', 'Holboo', 'Holboo,Saidamargatsa,Sandamargatsa,Sandamargatsa Suma,Sandamargatsa somon,Sandamargatsa sumu,Santa-margats somon,Santmargac,Santmargats,Сантмаргац', 48.5887600, 95.4325700, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93558, 'Höhtolgoy', 'Hohtolgoy', 'Hobdo Gol Suma,Hovd,Khowd', 49.2800100, 90.9101500, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93559, 'Hödrögö', 'Hodrogo', 'Nomorge,Nomorgo Suma,Nomrog,Numerge,Numurge,Numurge somon,Numurge-sumu,Nömrög,Nömörge,Nömörgö Suma', 48.8728400, 96.9625900, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93560, 'Havtsal', 'Havtsal', 'Havtsal,Turgehn,Turgen,Türgen,Тургэн', 50.1000000, 91.6666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93561, 'Har-Us', 'Har-Us', 'Har-Us,Olgii,Olgiy,Ulgij,Ölgiy,Ölgiï,Улгий', 49.0333300, 92.0333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93562, 'Har-Us', 'Har-Us', 'Erdeneburen,Erdenebüren,Erdeni Burin Suma,Erdeni Bürin Suma,Har-Us', 48.4833300, 91.4333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93563, 'Harmod', 'Harmod', 'Harmod,Sagil,Sagli,Sagli Suma,Sagli Sume,Sagli sumu,Sagliin somon,Сагил', 50.3413000, 91.6064100, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93564, 'Harhiraa', 'Harhiraa', 'Harhiraa,Tarialan,Tarjalan,Taryaalang Suma,Тарялан', 49.7784900, 91.9042400, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93565, 'Haliun', 'Haliun', 'Halium,Khaliun', 45.9296000, 96.1623900, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93566, 'Halban', 'Halban', 'Tsetserleg,Tsetserlig,Tsetserlig Suma,Tsetserlig somon,Tsetserlig sumu,Tsetserlik Sumu,Tsetserlik somon', 49.5287700, 97.7409000, 'MN', '2007-10-18', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93567, 'Erdenet', 'Erdenet', 'Erdenet,Shine-Ider,Shineh-Idehr,Шинэ-Идэр', 48.9487700, 99.5366500, 'MN', '2007-10-18', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93568, 'Dzüyl', 'Dzuyl', 'Tonhil,Tonhil Suma,Tonhil Sumu,Tonkhil,Tonkhil Somon', 46.3068600, 93.9040900, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93569, 'Dzuunmod', 'Dzuunmod', 'Dzuunmod,Idehr,Ider,Ider tsetserlig somon,Ider''iin sumu,Ider-tsetserleg,Ideriin Horshoo,Ideriin khorsho,Iderin Sume,Идэр', 48.2198700, 97.3744000, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93570, 'Dzüünhövöö', 'Dzuunhovoo', 'Dabasata Suma,Dabustu uula sumu,Dabusutu somon,Dabusutu uula,Davst,Dawst,Dzueuenhoevoeoe,Dzüünhövöö,Давст', 50.6097700, 92.4024000, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93571, 'Dzür', 'Dzuer', 'Tes', 49.6579600, 95.7932300, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93572, 'Dzöölön', 'Dzoolon', 'Dzoeoeloen,Dzöölön,Rehnchin-Lkhumbeh,Rinchin Lhumbu,Rinchin Lhumbu sumu,Rinchin Lumbe Suma,Rinchin Lumbe Sumu,Rinchin Lümbe Suma,Rinchin Lümbe Sumu,Rinchin Sume,Rinchin-Lkhumbu,Rinchin-Lkhumbu somon,Rinchinlhumbe,Rinchinlhümbe,Rinchinlkhumbe,Rinchinlkhümbe,Рэнчин-Лхумбэ', 51.1071900, 99.6722600, 'MN', '2007-10-18', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93573, 'Dzel', 'Dzel', 'Dzel,Dzun-Gobi,Dzuun Gobi Suma,Dzuungovi,Dzuungow,Dzüün Gobi Suma,Dzüüngovĭ,Dzüüngow,Дзун-Гоби', 49.9071300, 93.7858200, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93574, 'Dzalaa', 'Dzalaa', 'Dzalaa,Shinejinst', 44.5333300, 99.2666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93575, 'Dzag', 'Dzag', 'Dsag Baidarag,Dzag Gol Suma,Dzag Suma,Dzag gol,Dzag gol sumu,Dzag-Baydarag,Dzak,Tszag,Tszag Somon,Zaku goru', 46.9422900, 99.1668900, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93576, 'Dzadgay', 'Dzadgay', 'Bomboger sumu,Bombogor,Bombogor Suma,Bumbeger somon,Bumbuger,Bumbuger Somon,Bumbugeri,Bömböger sumu,Bömbögör,Bömbögör Suma', 46.2106100, 99.5986200, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93577, 'Duut', 'Duut', 'Duut', 47.5166700, 91.6333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93578, 'Khovd', 'Khovd', 'Chirgalantu,Chzhirgalantu,Djirgalantu,Dund-Us,Dzhaghalantu,Dzhargalantu,Dzhirgalantu,HVD,Hobdo,Hobdo Gol,Jargalant,Jirgalanta,Jirgalantu,Khobdo,Khovd,Kobdo,hobeudeu,Кобдо,Ховд,호브드', 48.0055600, 91.6419400, 'MN', '2017-06-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93579, 'Tsagaannuur', 'Tsagaannuur', 'Cagan-Nur,Dood-Nuur,Tsagaannuur,Tsagan-Nur,Цаган-Нур', 51.3563900, 99.3444400, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93580, 'Delgermörön', 'Delgermoron', 'Hureemaral,Khureemaral,Khüreemaral', 46.4094600, 98.2871200, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93581, 'Darvi', 'Darvi', 'Darbi,Darbi Suma,Darbi Sume,Darbi sumu,Daribi Somon,Dariv,Darvi,Darwi', 46.4500000, 94.1166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93582, 'Chihertey', 'Chihertey', 'Altai,Altaj,Altay,Altaï,Chihertey,Алтай', 48.3027200, 89.5155700, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93583, 'Chandmanĭ', 'Chandmani', 'Chandman'',Chandmani,Chandmanĭ,Chandman’,Chindamani Oldzeyte Suma,Chindamani Oldzeytu,Chindamani Ul''dzeytu sumu,Chindamani Ul’dzeytu sumu,Chindamani Öldzeyte Suma,Chindamani Öldzeytu,Chindimani ultszeitu somon', 48.0500000, 96.2500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93584, 'Buyant', 'Buyant', 'Bujant,Buyant,Буянт', 48.5796700, 89.5475000, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93585, 'Buyant', 'Buyant', 'Bujant,Buyant,Буянт', 48.0666700, 91.8166700, 'MN', '2012-12-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93586, 'Buyant', 'Buyant', 'Odhan Hayrhan,Odhon Hayrhan Suma,Odkhan Khairkhan,Odkhan Khayrkhan Somon,Otgon,Otgon-khayrkhan,Othan,Othan sumu', 47.2121100, 97.6066600, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93587, 'Buyant', 'Buyant', 'Buutsagaan,Buyanta Tsagaan Gol Suma,Buyantu Tsagan Gol Somon,Buyantu Tsagan gol Sumu,Buyantu tsagaan gol,Buyantu-Tsagan-Gol', 46.1664000, 98.6917300, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93588, 'Buyanbat', 'Buyanbat', 'Chzhibgalantu Somon,Chzhirgalantu Somon,Dzhargalant,Dzhirgalang,Dzhirgalant somon,Dzhirgalantu-Sumu,Jargalan,Jirgalang,Jirgalang Suma,Jirgalang sumu,Jirgalanta,Jirgalanta Suma', 46.9783800, 95.9253200, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93589, 'Bürenhayrhan', 'Burenhayrhan', 'Buergenkhe,Bulagan,Bulagan Gol Suma,Bulagan Somon,Bulagan gol sumu,Bulagan-gol,Bulgan,Bulgan-Gol,Burenhayrhan,Bürenhayrhan,Pu-erh-ken,T''u-ku-te-su-mu,Torgut Somon,Torgutin Khure,T’u-ku-te-su-mu', 46.0923700, 91.5479600, 'MN', '2013-12-01', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93590, 'Darvi', 'Darvi', 'Darbi,Darbi Somon,Darbi Suma,Darbi Sume,Darbi sumu,Darvi,Darwi,Derubi', 46.9367800, 93.6167300, 'MN', '2012-12-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93591, 'Bulgan', 'Bulgan', 'Bayan Ondor Suma,Bayan Undur Somon,Bayan Undur Sume,Bayan undur sumu,Bayan Öndör Suma,Bayan-Ondor,Bayan-Undur,Bayan-Öndör,Bulgan', 44.7833300, 98.6500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93592, 'Bugat', 'Bugat', 'Bugat,Hirgis,Hirgis Suma,Hirgis sumu,Hyargas,Khirgis,Khirgis somon,Khjargas,Khyargas,Kirgis Sume,Хяргас', 49.5333300, 93.8166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93593, 'Buga', 'Buga', 'Buga,Bugat,Бугат', 49.0166700, 90.1833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93594, 'Buga', 'Buga', 'Dorvoljin', 47.6501300, 95.0005000, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93595, 'Altay sumu', 'Altay sumu', 'Altai,Altay,Altay Somon,Altay Suma,Altay sumu,Bor-Udzuur,Bor-Üdzüür', 45.8000000, 92.2833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93596, 'Bilüü', 'Biluu', 'Bilueue,Bilüü,Ulaan Husa,Ulaan Husa Suma,Ulaan husu,Ulaan-Hushu,Ulaanhus,Ulaanhust,Ulaankhus,Ulan Khusu,Ulan husu,Ulan-Khus,Ulan-Us-Khushu,Ulan-Usu,Ulan-khusu somon,Wu-lan-wu-su,Улан-Хус', 49.0437200, 89.4379800, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93597, 'Bayshint', 'Bayshint', 'Bayshint,Bohmoron,Bokhmoron,Buhey Moron Suma,Böhmörön,Bökhmörön,Bühey Mörön Suma', 49.6666700, 90.2833300, 'MN', '2015-07-10', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93598, 'Bayan-Uhaa', 'Bayan-Uhaa', 'Ih-Uul,Ihe ula sumu,Ikh-Uul,Ikhe Ula,Ikhe Ula Sume,Ikhe ula somon,Yeke Uula camp,Yihe Uula Suma', 48.7190600, 98.7918100, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93599, 'Bayansayr', 'Bayansayr', 'Baatsagaan,Tsagaan Gol Suma,Tsagan Gol,Tsagan gol Somon', 45.5552900, 99.4331400, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93600, 'Bayan-Ovoo', 'Bayan-Ovoo', 'Altay,Bayan-Ovoo', 44.6166700, 94.9166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93601, 'Bayanhoshuu', 'Bayanhoshuu', 'Bayanhushuu,Mingat Suma,Mjangad,Myangad,Мянгад', 48.2333300, 91.9166700, 'MN', '2007-10-24', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93602, 'Bayangol', 'Bayangol', 'Bugat', 45.5565500, 94.3644900, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93603, 'Bayanbulag', 'Bayanbulag', 'Bayan Bulag Suma,Bayan Bulak,Bayan Bulak Somon,Bayan bulag sumu', 46.8098100, 98.0900600, 'MN', '2013-12-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93604, 'Bayan', 'Bayan', 'Bayan,Burentogtoh,Burentogtokh,Burin Togtahu,Burin Togtoho Suma,Burin Tohtahu sumu,Burin togtakhu somon,Burin-Tokhtakhu,Bürentogtoh,Bürentogtokh,Bürin Togtahu,Bürin Togtoho Suma', 49.4333300, 99.6000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93605, 'Bayan', 'Bayan', 'Bayan Ula Somon,Bayan Uula Suma,Bayan uula,Bayan uula sumu,Bayan-Ula,Bayan-Uul', 46.9929000, 95.1996200, 'MN', '2007-10-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93606, 'Baruunturuun', 'Baruunturuun', 'Barun-Turun,Baruunturuun,Turin Golin Sume,Turun,Turun somon,Turun-Gol,Turun-Gol-Somon,Turuun Suma,Turuun gol,Turuun gol sumu,Türüün Suma,Türüün gol,Türüün gol sumu,Барун-Турун', 49.6596300, 94.4041400, 'MN', '2007-10-25', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93607, 'Balgatay', 'Balgatay', 'Balgatay,Shilusutu,Shilusutu Sume,Shiluustei,Shiluustey,Shiluusutu,Shiluusutu sumu,Shiluusütü,Shilüüstey,Shilüüsteï,Shirusuto,Shulusete,Shulusutu-Somon,Shuluusete Suma,Shulyusut,Shulyusutu Somon,Shülüsete,Shülüüsete Suma', 46.9000000, 97.1500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93608, 'Altraga', 'Altraga', 'Altraga,Bajan-Dzurkh,Bayan Dzurihe Suma,Bayan Dzürihe Suma,Bayandzurh,Bayandzurkh,Bayandzürh,Bayandzürkh,Баян-Дзурх', 50.1791000, 98.9720500, 'MN', '2007-10-18', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93609, 'Altay', 'Altay', 'Altay,Bajan-Ula,Bayan Uula,Bayan-Ula,Bayan-Ula somon,Bayan-Ula sumu,Bayan-Uul,Bayantes,Баян-Ула', 49.7031700, 96.3592000, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93610, 'Altai', 'Altai', 'Altai,Altaj,Altay,Jusenbulag,LTI,Usan Bulag,Yosonbulag,Yusun-bulak,Yösönbulag,Алтай', 46.3722200, 96.2583300, 'MN', '2013-08-04', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93611, 'Altanteel', 'Altanteel', 'Altan Teeli Somon,Altan Teeli Suma,Altan Teeli Sumu,Altan Teli Sume,Altan teeli,Altan-Tel,Altan-Teli,Arutan teri,Dzereg', 47.1104400, 92.8437400, 'MN', '2007-10-24', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93612, 'Altanbulag', 'Altanbulag', 'Altanbulag,Bajan-Khajrkhan,Bayan Hayrhan Suma,Bayan Khairkhan,Bayan Khairkhan Sume,Bayan hayrhan sumu,Bayan khayran somon,Bayan-Khayrkhan,Bayanhayrhan,Баян-Хайрхан', 49.3068800, 96.3423700, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93613, 'Altan', 'Altan', 'Altan,Erdenehayrhan,Erdenekhairkhan,Erdenekhaïrkhan', 48.1166700, 95.7166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93614, 'Aldar', 'Aldar', 'A-lo-te-erh,Aldar Haan Suma,Aldar Khan Somon,Aldar han,Aldarhaan,Aldarhan sumu,Aldarkhaan,Aldarkhan,Aldir,Aldyr,Arudiru,Arudïru', 47.6422600, 96.5368700, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93615, 'Horgo', 'Horgo', 'Horgo,Tariat,Tarjat,Тарят', 48.1600000, 99.8755600, 'MN', '2012-01-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93616, 'Üydzen', 'UEydzen', 'Manlai,Manlai-Somon,Manlay,Manlay Somon,Manlay Suma,Manlay sumu,Manlaï,Manrai,UEydzin,Üydzin', 44.0821600, 106.8698500, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93617, 'Uubulan', 'Uubulan', 'Hayrhan,Hayrhan Suma,Hayrhan sumu,Khairkhan,Khajrkhan,Khayrkhan,Khayrkhan somon,Khaïrkhan,Uubulan,Хайрхан', 48.6088500, 101.9342400, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93618, 'Urt', 'Urt', 'Gurvantes', 43.2324500, 101.0481300, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93619, 'Uldz', 'Uldz', 'Norbolin,Norovlin,Norowlin,Norvulin,Uldz,Улдз', 48.6902800, 111.9946300, 'MN', '2007-10-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93620, 'Ulaan-Uul', 'Ulaan-Uul', 'Barun Ul''dzeytu Sumu,Barun Ultszeytu Somon,Baruun Oldzeyte,Baruun Oldzeyte Suma,Baruun Öldzeyte,Baruun Öldzeyte Suma,Oldzeytu,Oldziit,Oldziyt,Öldziyt,Öldziït', 46.0674000, 100.8172400, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93621, 'Ulaan-Uul', 'Ulaan-Uul', 'Erdene,Erdeni,Erdeni Somon,Erdeni Suma,Erdeni Sume,Erdeni sumu,Ulaan-Uul', 44.3333300, 111.2333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93622, 'Ulaanjirem', 'Ulaanjirem', 'Holodo,Holodo Suma,Holot Sumu,Horuto,Huld,Hulud,Kholod,Kholod Somon,Kholot,Khuld,Ulaanjirem', 45.0500000, 105.5666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93623, 'Ulaanhudag', 'Ulaanhudag', 'Erdenesant,Erdeni Santa,Erdeni Santa Suma,Erdeni Santu Somon,Erdeni santu sumu,Erdeni-Santu,Erudeni-santo,Ulaanhudag', 47.3333300, 104.5000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93624, 'Ulaanhad', 'Ulaanhad', 'Bayanhangay', 47.9499300, 105.5532100, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93625, 'Ulaan-Ereg', 'Ulaan-Ereg', 'Bain-munku Somon,Bayan Monho,Bayan Monho Suma,Bayan Munkhu,Bayan Munku Somon,Bayan Mönhö,Bayan Mönhö Suma,Bayan monho sumu,Bayan mönhö sumu,Bayanmonh,Bayanmonkh,Bayanmönh,Bayanmönkh,Bayn Munkhu Somon,Ulaan-Ereg', 46.9000000, 109.7500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93626, 'Ulaandel', 'Ulaandel', 'Asahatay Suma,Asgat', 46.3644600, 113.5770000, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93627, 'Ulan Bator', 'Ulan Bator', 'Da Huryee,Da Hüryee,Da Khure,Da-Kure,K''u-lun,Orgoo,Oulan Mpator,Oulan-Bator,Ourga,ULN,Ula Bator,Ulaan Baatar,Ulaan Baatar Hoto,Ulaanbaatar,Ulaanbaataro,Ulaanbaator,Ulaanbaator hota,Ulaanbaatur,Ulan Bator,Ulan Bator Hoto,Ulan Batoras,Ulan Batur,Ulan-Bator,Ulan-Bator Khoto,Ulanbatar,Ulanbator,Ulanbátar,Ulán Bator,Ulán Bátor,Ulánbátar,Ulánbátor,Ulã Bator,Uranbatoru,Urga,Uruga,Ułan Bator,awlan batwr,ulanabatara,ullanbatoleu,uranbatoru,wu lan ba tuo,xulanbatxr,Örgöö,Úlan Bator,Ουλάν Μπατόρ,Улаанбаатар,Улан Батор,Улан-Батор,אולן בטור,أولان باتور,اولان‌باتور,उलानबातर,อูลานบาตอร์,ཝུ་ལན་བ་ཐུར,ኡላዓን ባዓታር,ウランバートル,乌兰巴托,울란바토르', 47.9077100, 106.8832400, 'MN', '2016-02-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93628, 'Turt', 'Turt', 'Hanga,Hanga Suma,Hanga Sumu,Hangin,Hanh,Khanga,Khanga Sume,Khangin,Khankh,Khankha Somon,T''u-erh-t''u,Turt,Turta,Turtu,Ханх', 51.5072500, 100.6625700, 'MN', '2014-06-27', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93629, 'Tsul-Ulaan', 'Tsul-Ulaan', 'Bayannuur,Tsul-Ulaan', 47.8333300, 104.5000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93630, 'Tsoohor', 'Tsoohor', 'Hurmeiin Suma,Hurmen,Hurmiin Suma,Hürmeiin Suma,Hürmen,Hürmiin Suma,Khurmein Somon,Khurmen,Khurmeyn somon,Khurmin-Somon,Khürmen,Ondor Hurme Suma,Ondor hurme,Undur Khurmein Sume,Undur hurme''iin sumu,Öndör Hürme Suma,Öndör hürme,Ündür hürme''iin sumu', 43.3065700, 104.0741700, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93631, 'Tsomog', 'Tsomog', 'Dalanjargalan,Tsomog', 45.9166700, 109.0666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93632, 'Tsetserleg', 'Tsetserleg', 'Cecerleg,Cecerlegas,Cehcehrlehg,Cehcehrlehg khot,TSZ,Tsetserleg,Tsetserlig,Tsetserlig-khoto,Tsetserlik,Tsetserurigu,chchrlg,che che er lei ge,Цецерлег,Цэцэрлэг,Цэцэрлэг хот,چچرلگ,車車爾勒格', 47.4750000, 101.4541700, 'MN', '2017-03-10', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93633, 'Tsengel', 'Tsengel', 'Toson Tsengel Suma,Toson tsengel sumu,Toson-Cehngehl,Toson-tsengel somon,Tosontsengel,Tsengel,Тосон-Цэнгэл', 49.4783300, 100.8894400, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93634, 'Tsant', 'Tsant', 'Deren,Deren Somon,Deren Suma,Deren sumu,Dereng,Tsant', 46.1833300, 106.7166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93635, 'Tsagaan-Ovoo', 'Tsagaan-Ovoo', 'Nariin Teeli Suma,Nariinteel,Narin Teli Sume,Narin del'' Somon,Narin teeli,Narin-Teeli-Somon,Narin-Teli,Nariyntee,Nariynteel,Nariïnteel', 45.9640400, 101.4597700, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93636, 'Tsagaan-Ovoo', 'Tsagaan-Ovoo', 'Loosa sumu,Los,Lus,Lus Somon,Luus,Luusa,Luusa Suma', 45.5071900, 105.7559400, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93637, 'Tsagaandörvölj', 'Tsagaandorvolj', 'Ayrag', 45.7981700, 109.3182600, 'MN', '2007-10-11', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93638, 'Tsagaanders', 'Tsagaanders', 'Bain Tumen,Bayantumen,Bayantümen,Cagandehrs,Tsagaanders,Цагандэрс', 48.0500000, 114.3666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93639, 'Naran-mandokhu Somon', 'Naran-mandokhu Somon', 'Mandah,Mandaha Suma,Mandaho,Mandakh,Mandohu,Mandohu sumu,Naran Mandaha,Naran Mandaha Suma,Naran-Mandakhu-Somon,Naran-mandokhu Somon,Tohom,Töhöm', 44.4000000, 108.2500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93640, 'Teshig', 'Teshig', 'Tehshig,Teshig,Teshig Suma,Teshig Sume,Teshig somon,Teshig sumu,Тэшиг', 49.9466900, 102.6612300, 'MN', '2007-10-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93641, 'Teel', 'Teel', 'Ondon-Ulan,Ondor Ulaan Suma,Ondor-Ulaan,Teel,Undehr-Ulan,Undur ulaan sumu,Undur-Ulan,Undur-ulan somon,Öndör Ulaan Suma,Öndör-Ulaan,Ündür ulaan sumu,Ундэр-Улан', 48.0463900, 100.5091700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93642, 'Tavin', 'Tavin', 'Adaatsag', 46.3919400, 105.7351700, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93643, 'Tavanbulag', 'Tavanbulag', 'Todzshruuleh,Tovshruuleh,Towshruulekh,Tuvshruuleh,Tödzshrüüleh,Tövshrüüleh,Töwshrüülekh,Tüvshrüüleh', 47.3818500, 101.9081500, 'MN', '2016-10-12', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93644, 'Dashinchilling', 'Dashinchilling', 'Dashichiling,Dashichiling sumu,Dashinchilen,Dashinchilin Suma,Dashinchiling,Dashinchiling Somon,Dashinchiling Suma,Dashinchilling,Suuj,Süüj', 47.8500000, 104.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93645, 'Suugaant', 'Suugaant', 'Gurban Saikhan,Gurban Sayhan,Gurban Sayhan Suma,Gurban Saykhan Somon,Gurban sayhan sumu,Gurban-Saykhan,Gurvan-Saykhan,Gurvansayhan,Gurwansaikhan,Gurwansaïkhan,Suugant', 45.5325700, 107.0454600, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93646, 'Sümiyn Bulag', 'Sumiyn Bulag', 'Gurban Dzagaliin Suma,Gurban Dzakhaliin Somon,Gurbun Dzagal,Gurbun Dzagalyn Somon,Gurbun-Dzagal-Sumu,Gurubun Zagaran,Gurvandzgal,Gurwandzagal,Gürwandzagal,Suemiyn Bulag,Sumijn-Bulak,Sumiyn Bulag,Sümiyn Bulag,Сумийн-Булак', 49.1333300, 114.8833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93647, 'Sühbaatar', 'Suhbaatar', 'Suehbaatar,Suhbaatar,Suhe Baatar,Suhe Batar,Sukhbaatar,Sukhe Batur,Sukhe-Bator,Sukheh-Bator,Sühbaatar,Sühe Baatar,Sühe Batar,Sükhbaatar,Сухэ-Батор,Сүхбаатар', 50.2313900, 106.2077800, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93648, 'Sört', 'Sort', 'Hangal,Hangal Suma,Hangal sumu,Khangal,Khangal Somon,Soert,Sört,Хангал', 49.3175100, 104.3819600, 'MN', '2007-10-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93649, 'Shireet', 'Shireet', 'Bain-Del''gir-Somon,Bain-delger Somon,Bayan Delger Suma,Bayan delger sumu,Bayandelger,Bayn Del''gir Somon,Shireton Khid,Shiretoyn Khid,Shiretyn-khid,Shiretyyn khid,Shiretön Khid,Shiretöyn Khid,Ulan-Nur-Somon', 45.7272700, 112.3556300, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93650, 'Shiree', 'Shiree', 'Bayangol,Shiree', 45.8500000, 103.4000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93651, 'Sharïngol', 'Sharingol', '', 49.2373300, 106.4300500, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93652, 'Sharhulsan', 'Sharhulsan', 'Mandal Obo Somon,Mandal Oboo,Mandal Oboo Suma,Mandal-Obo,Mandal-Ovoo,Sharhulsan', 44.6500000, 104.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93653, 'Sharga', 'Sharga', 'Bajan-Agt,Bayan Agta,Bayan Agta Suma,Bayan Agta Sume,Bayan-Agt,Bayan-agta somon,Bayanagta sumu,Sharga,Баян-Агт', 49.0419200, 102.0892500, 'MN', '2007-10-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93654, 'Sergelen', 'Sergelen', 'Sergelen', 48.5666700, 114.0833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93655, 'Sergelen', 'Sergelen', 'Sergelen,Tebshin-Shire Somon,Tubshin Shiree Suma,Tubshin shiree,Tubshin shiree sumu,Tubshin-Shire,Tuvshinshiree,Tuwshinshiree,Tübshin Shiree Suma,Tübshin shiree,Tübshin shiree sumu,Tüvshinshiree,Tüwshinshiree', 46.2000000, 111.8166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93656, 'Senj', 'Senj', 'Orgon,Senj,Örgön', 44.7166700, 110.7666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93657, 'Selenge', 'Selenge', 'Ih-Uul,Ihe uula sumu,Ikh-Ula,Ikhe Ula Sume,Ikhe-Ula,Ikhe-ula Somon,Selenge,Yihe Uula Suma,Их-Ула', 49.4333300, 101.4666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93658, 'Saynshand', 'Saynshand', 'Saynshand,Seberei,Seberei Sume,Seberey,Seberey Suma,Seberey somon,Seberey sumu,Sevrey,Syowrei,Syöwrei', 43.6166700, 102.5333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93659, 'Sangiyn Dalay', 'Sangiyn Dalay', 'Oldzeyte,Oldzeyte Suma,Oldzeytu,Oldziit,Oldziyt,Sangiyn Dalay,Uldzeytu-Somon,Uldzit,Ultszeyto Somon,Ultszeytu Somon,Öldzeyte Suma,Öldzeytü,Öldziyt,Öldziït', 46.6500000, 103.3166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93660, 'Sangiyn Dalay', 'Sangiyn Dalay', 'Erdenedalay,Erdeni Dalai,Erdeni Dalay,Erdeni Dalay Somon,Erdeni Dalay Suma', 46.0079300, 104.9420900, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93661, 'Sangiyn Dalay', 'Sangiyn Dalay', 'Sang''iin dalay''iin hurie,Sang''iin dalay''iin hürie,Sang''iin dalay''in hurie,Sang''iin dalay''in hürie,Sangiin Dalay Hueryee,Sangiin Dalay Huree,Sangiin Dalay Hüree,Sangiin Dalay Hüryee,Sangin Dalain Khure,Sangin dalay khure,Sangin-Dalayn-Khure', 42.8419900, 105.1379600, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93662, 'Rashaant', 'Rashaant', 'Arshaanta Suma,Arshaantu,Arshant,Arshantu Khure,Arshantu Somon,Arshantu sumu,Rashaant,Аршант', 49.1266700, 101.4280600, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93663, 'Rashaant', 'Rashaant', 'Oldzit,Oldziyt,Rashaant,Öldziyt,Öldzït', 45.3000000, 106.2000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93664, 'Övt', 'Ovt', 'Bat-Oldzii,Bat-Oldziy,Bat-Öldziy,Bat-Öldziï,Ovt,Övt', 46.8166700, 102.2500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93665, 'Ovoot', 'Ovoot', 'Dariganga,Dariganga Suma,Dariganga somon,Dariganga sumu,Daringanga,Darĭganga,Shine Dariganga,Shine Dariganga Suma,Shine Dariganta Somon,Shine-dariganga Somon', 45.3042300, 113.8497700, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93666, 'Orhontuul', 'Orhontuul', 'Dedu orhon sumu,Dedu-Orkhon-Sumu,Deede Orhon Suma,Deedu orhon,Orhon Tuula Suma,Orhontuul,Orkhon-Tola,Orkhontola Somon,Orkhontuul,Орхон-Тола', 48.9497200, 104.9758300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93667, 'Örgön', 'Orgon', 'Bayangovi,Bayangovĭ,Bayangow''', 44.7363700, 100.3913500, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93668, 'Orgil', 'Orgil', 'Tseel', 48.4538000, 105.3176900, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93669, 'Onon', 'Onon', 'Binder,Bindiryaa,Bindiryaa Suma,Bindur somon,Bindur''ya sumu,Bindurya,Bindurya-Somon,Bindur’ya sumu,Onon,Онон', 48.6166700, 110.6000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93670, 'Ongon', 'Ongon', 'Burd,Buride Suma,Buridu,Buridu Somon,Buridu sumu,Bürd,Büride Suma,Büridü,Büridü sumu', 46.9825900, 103.7838900, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93671, 'Ongi', 'Ongi', 'Ongi,Ongi Suma,Ongi sumu,Ongin,Uyanga,Uyanga Somon,Uyanga Suma,Uyangh,Weng-chin', 46.4666700, 102.2833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93672, 'Ongi', 'Ongi', 'Ongi,Saikhan Obo,Saikhan Obo Somon,Saikhan Owoo,Sayhan Oboo,Sayhan Oboo Suma,Sayhan oboo sumu,Sayhan-Ovoo,Saykhan Obo Somon,Saykhan-Obo,Saïkhan Owoo', 45.4500000, 103.9000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93673, 'Öndörhoshuu', 'OEndoerhoshuu', 'Bulgan,OEndoerhushuu,Öndörhushuu', 48.0000000, 113.9333300, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93674, 'Undurkhaan', 'Undurkhaan', 'Ondorkhaan,Tsetsen Khan,Tsetsen Khan''s Palace,Tsetsen Khan’s Palace,UNR,Under-Khan,Undur Khan,Undurhan,Öndörkhaan,Өндөрхаан', 47.3194400, 110.6555600, 'MN', '2017-03-10', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93675, 'Öldziyt', 'Oldziyt', 'Ehrdehneh-Mandal,Erdenemandal,Erdeni Mandal Suma,Erdeni Mandal Sume,Erdeni Mandel Sumu,Erdeni mandal sumu,Erdeni-Mandal,Erdeni-mandal Somon,OEldziyt,Öldziyt,Эрдэнэ-Мандал', 48.5284300, 101.3739400, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93676, 'Öldziyt', 'Oldziyt', 'Oldziyt,Saikhan Dulan Sume,Saikhandulaan,Sayhan Dulaan Suma,Sayhan dulaan sumu,Sayhandulaan,Saykhan Dulan,Saykhan-dulan Somon,Saïkhandulaan,Öldziyt', 44.6833300, 109.0166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93677, 'Ögöömör', 'Ogoomor', 'Haan Hongor Suma,Han hongor sumu,Hanhongor,Hongor Suma,Khankhongor,Khongor somon', 43.7833600, 104.4806700, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93678, 'Nüden', 'Nuden', 'Nuden,Nüden,Ulaan Badaraha Suma,Ulaan Badaraha Sumu,Ulaan badarahu,Ulaan badarahu sumu,Ulaanbadrah,Ulaanbadrakh,Ulan Badarakhu,Ulan Badarkhu Somon,Ulan-Badrakh,Ulan-badarakhu-Sumu', 43.5833300, 110.4666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93679, 'Nomgon', 'Nomgon', 'Nomgon,Sayhan,Номгон', 49.2001000, 105.6658200, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93680, 'Nart', 'Nart', 'Nart,Orhon,Orkhon,Нарт', 49.1450000, 105.3883300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93681, 'Naranbulag', 'Naranbulag', 'Bayan Dun Suma,Bayan Dung Suma,Bayan Düng Suma,Bayan dung sumu,Bayan düng sumu,Bayan-Dung-Somon,Bayan-dung,Bayan-düng,Bayandun,Naranbulag,Naranbulak,Наранбулак', 49.2436000, 113.3742700, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93682, 'Murun-kuren', 'Murun-kuren', 'Moeroen,Moron,Moron''i hurie,Moronii Huryee,Moronii khuree,Moronu hurie,Mu-lin,Mu-lin-fu-lieh,Murehn,Muren,Murenfure,Muringoru,Murun-kuren,Mörön,Mörönii Hüryee,Mörönii khüree,Mörönu hurie,Mörön’i hürie,Мурэн,Мөрөн', 49.6341700, 100.1625000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93683, 'Mörön', 'Moron', 'Moron Suma,Moron Sumu,Muren-sumu,Muron,Muron Somon,Mörön Suma,Mörön Sumu', 47.3825400, 110.3164700, 'MN', '2007-10-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93684, 'Mönhbulag', 'Monhbulag', 'Dzuil,Dzuyl,Dzüyl,Dzüïl,Monhbulag,Mönhbulag', 46.7500000, 103.5166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93685, 'Modot', 'Modot', 'Modot,Tsenher Mandal Suma,Tsenher mandal sumu,Tsenhermandal,Tsenkher Landalon Somon,Tsenkher Mandaloyn Somon,Tsenkher Mandalöyn Somon,Tsenkher Mandlyin Somon,Tsenkher-Mandal,Tsenkher-Mandalyyn Somon', 47.7500000, 109.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93686, 'Mayhan', 'Mayhan', 'Sant,Santa Suma,Santo,Santu,Santu Somon,Santu sumu,Santü', 46.0912100, 103.8395100, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93687, 'Mardzad', 'Mardzad', 'Dulaan Hayrhan Suma,Dulan Khairkhan Somon,Dulan Khayrkhan somon,Hairuhan-doran,Hayrhan Dulaan Suma,Hayrhan dulan sumu,Hayrhandulaan,Khairkhandulaan,Khayrkhan-Dulan,Khaïrkhandulaan,Mardzad', 45.9500000, 102.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93688, 'Manhan', 'Manhan', 'Alag Erdeni,Alag Erdeni Suma,Alag Erdeni Sume,Alag-Ehrdehneh,Alag-Erdene,Alag-Erdeni-Sumu,Alag-erdeni somon,Manhan,Алаг-Эрдэнэ', 50.1213900, 100.0430600, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93689, 'Mandalgovi', 'Mandalgovi', 'MXW,Mandal Gobi,Mandalgov'',Mandalgovi,Mandalgovĭ,Mandalgow'',Mandalgow’,Мандалговь', 45.7625000, 106.2708300, 'MN', '2013-05-09', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93690, 'Dzüünkharaa', 'Dzuunkharaa', 'Dzun-khara,Dzuun Hara,Dzuunkharaa,Dzüün Hara,Dzüünkharaa,Mandal,Mandal Suma,Mandal somon,Mandal sumu,Zuunkharaa', 48.6333300, 106.7333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93691, 'Mandal', 'Mandal', 'Mandal,Orhon,Orkhon,Орхон', 48.6311100, 103.5291700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93692, 'Mandal', 'Mandal', 'Bata Sumber Somon,Bata Sumber Suma,Bata Sümber Somon,Bata Sümber Suma,Batsumber,Batsümber,Batu Sumbur Somon,Batu sumbur sumu,Batu sümbür sumu,Batu-Sumbur,Batur Sumbur Sume', 48.3706200, 106.7407600, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93693, 'Maanĭt', 'Maanit', 'Hishig-Ondor,Hishig-Öndör,Khishig-Ondor,Khishig-Öndör,Khushig-Undehr,Maanit,Maanĭt,Хушиг-Ундэр', 48.2966700, 103.4255600, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93694, 'Maanĭt', 'Maanit', 'Bayan,Bayan Somon,Bayan Suma,Bayan Uula Suma,Bayan ula sumu,Bayan uula,Bayan-Ula,Borchunsuma,Maanit,Maanĭt,Manita', 47.2500000, 107.5333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93695, 'Sujji', 'Sujji', 'Lun,Lun Suma,Lung,Lung Somon,Lung Suma,Lung Ula,Lung sumu,Lyun somon,Lyung Somon,Lün,Lün Suma,Lüng Suma,Lüng sumu,Rungein-buran,Sujji', 47.8666700, 105.2500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93696, 'Javhlant', 'Javhlant', 'Sumber,Sümber', 48.8018900, 105.9240000, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93697, 'Javarthushuu', 'Javarthushuu', 'Bayan Ula,Bayan Ula Sume,Bayan Uula Somon,Bayan Uula Suma,Bayan ura,Bayan uula,Bayan uula sumu,Bayan-Uul,Bayan-ula-Somon,Javarthushuu', 49.1500000, 112.7333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93698, 'Jargalant', 'Jargalant', 'Dzhargalant,Dzuunburen,Dzüünbüren,Jargalant,Джаргалант', 50.0675000, 105.8805600, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93699, 'Jargalant', 'Jargalant', 'Tomor Buluk Sume,Tomor bulag Sumu,Tomorbulag,Tumur-Bulag,Tumur-Bulak Somon,Tömör Buluk Sume,Tömör bulag Sumu,Tömörbulag', 49.2959100, 100.2571100, 'MN', '2007-10-18', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93700, 'Jargalant', 'Jargalant', 'Chzhirgalantuin-sang,Dzhargalant,Jargalant,Jirgalantayn Sang,Джаргалант', 48.5205600, 105.8683300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93701, 'Jargalant', 'Jargalant', 'Battsengel,Tamiriin Huryee,Tamiriin Hüryee,Tamiriin Khure', 47.7930900, 101.9723500, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93702, 'Jargalant', 'Jargalant', 'Chulutuin khid,Chuluut,Chuluutayn Hiid,Jargalant,Tsuretoin-fure', 47.5333300, 100.2166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93703, 'Ingettolgoy', 'Ingettolgoy', 'Ingettolgoy,Sehlehngeh,Selenga-Burin,Selenge,Selenge Burin Suma,Selenge Bürin Suma,Selenge burin,Selenge burin sumu,Selenge bürin,Selenge bürin sumu,Selenge-Burin Somon,Сэлэнгэ', 49.4616700, 103.9741700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93704, 'Ihsüüj', 'Ihsueuej', 'Bayanchandmani,Bayanchandmanĭ', 48.2257000, 106.2915200, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93705, 'Ihbulag', 'Ihbulag', 'Haan Bogdo Suma,Han bogda,Han bogda sumu,Hanbogd,Ihbulag,Khan Bogda,Khan Bogda Somon,Khan Bogdo Sume,Khan-Bogdo,Khanbogd,Tsagan Khamar', 43.2000000, 107.2000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93706, 'Huurch', 'Huurch', 'Huurch,Khurch,Tsagaannuur,Tsagan-Nur,Хурч', 50.1036100, 105.4200000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93707, 'Hutag', 'Hutag', 'Hutag,Hutag Ondor Suma,Hutag Öndör Suma,Hutag-Ondor,Hutag-Öndör,Hutug Ondor,Hutug undur sumu,Hutug Öndör,Khitug-Under,Khitug-Undur somon,Khutag,Khutug Under,Khutug Undur Sume,Khutug-Undur-Sumu,Khutug-undur somon,Хутаг', 49.3950000, 102.6933300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93708, 'Hüremt', 'Huremt', 'Hueremt,Huremt,Hüremt,Saikhan,Sajkhan,Sayhan,Sayhan Suma,Sayhan sumu,Saykhan,Saykhan somon,Сайхан', 48.6630600, 102.6227800, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93709, 'Hüremt', 'Huremt', 'Taragt,Targat,Targata,Targata Suma,Targatu,Targatu somon,Targatu sumu', 46.3024100, 102.4455400, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93710, 'Hulstay', 'Hulstay', 'Choibalsan,Choybalsan,Choïbalsan,Hulstay,Khulstaj,Хулстай', 48.4333300, 114.8666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93711, 'Hujirt', 'Hujirt', 'Tsetserleg,Tsetserlig,Tsetserlig Suma,Tsetserlig somon,Tsetserlig sumu', 48.8819900, 101.2395300, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93712, 'Khujirt', 'Khujirt', 'HJT,Haluun Usanii,Haluun Usanii Suma,Hujirtay,Khalun Usuni Somon,Khudzhirt,Khudzhurt,Khujirt,Khuzhirt,Хужирт', 46.8970400, 102.7690300, 'MN', '2013-05-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93713, 'Hujirt', 'Hujirt', 'Del''ger han sumu,Del''ger-khan-Sumu,Delger Haan Suma,Delger han,Delger somon,Delger-khan,Delger-khan Somon,Delgerhaan,Delgerkhaan,Del’ger han sumu,Del’ger-khan-Sumu,Derigeri han,Hujirt', 46.6000000, 104.5833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93714, 'Noyon Suma', 'Noyon Suma', 'Hovuun,Hövüün,Noin Somon,Noyan,Noyan Somon,Noyan Sume,Noyan sumu,Noyen,Noyin Somon,Noyon,Noyon Suma,Noyën', 43.1736100, 102.1319400, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93715, 'Khuvsget', 'Khuvsget', 'Hobsogol Suma,Hobsogol Sumu,Hovsgol,Hubsugul sumu,Höbsögöl Suma,Höbsögöl Sumu,Hövsgöl,Khowsgol,Khubsugul,Khubsugul Somon,Khubsugul Sume,Khubsugul-Sumu,Khuvsgel,Khuvsget,Khöwsgöl', 43.6063900, 109.6380600, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93716, 'Hovd', 'Hovd', 'Hobdo,Hobdo Suma,Hobdo sumu,Hovd,Khobdo,Khobdo somon,Khordo Somon,Khowd,Kobdo,Кобдо', 44.6666700, 102.3833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93717, 'Hovd', 'Hovd', 'Bogd,Khovd,Ховд', 44.6702400, 102.1749100, 'MN', '2010-01-29', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93718, 'Hotont', 'Hotont', 'Hotantu sumu,Hotonto,Hotonto Suma,Hotontu,Khotont,Khotontu Somon', 47.3627800, 102.4679400, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93719, 'Höshööt', 'Hoshoot', 'Hoeshoeoet,Höshööt,Oldzeyte,Oldziit,Oldziyt,Uldzij,Ultszeytu,Öldzeyte,Öldziyt,Öldziït,Улдзий', 48.1009000, 102.5568600, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93720, 'Horiult', 'Horiult', 'Bogd,Bogda Uula,Bogda ula somon,Bogda ula sumu,Bogdo Ula Sume,Bogdo Uula Suma,Bogdo-Ula,Bogudo-kara,Horiult', 45.2000000, 100.7666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93721, 'Tsagaan-Owoo', 'Tsagaan-Owoo', 'Hoovor,Höövör,Tsagaan-Ovoo,Tsagaan-Owoo', 48.4000000, 113.4333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93722, 'Bayan Uula Sumu', 'Bayan Uula Sumu', 'Barun Bayan Ulan somon,Baruun Bayan Uula Suma,Baruunbayan-Ulaan,Bayan Ula Sume,Bayan Uula Suma,Bayan Uula Sumu,Bayan ula sumu,Bayan uula,Bayan-ura,Hoovor,Höövör', 45.1666700, 101.4000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93723, 'Hoolt', 'Hoolt', 'Hoolt,Togorig,Togorig Nuur Suma,Togorig Suma,Togorig nuur,Togrog,Tuguric Somon,Tugurig Somon,Tugurig-Nur,Tugurig-Nur-Somon,Tugurik,Tugurik Somon,Tugurik nuur sumu,Tögrög,Tögörig,Tögörig Nuur Suma,Tögörig Suma,Tögörig nuur,Tügürik nuur sumu', 45.5333300, 102.9833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93724, 'Hongor', 'Hongor', 'Del''gerehu,Del''gir Somon,Delger,Delger Somon,Delger Suma,Delger-khid somon,Delgereh,Delgerehe Suma,Delgerehu sumu,Delgerehü sumu,Delgerekh,Delgerekhu Sume,Del’gerehu,Del’gir Somon,Hongor', 45.8000000, 111.2000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93725, 'Hongor', 'Hongor', 'Naran', 45.1350700, 113.6837800, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93726, 'Undur Sume', 'Undur Sume', 'Chandman Ondor,Chandman Öndör,Chandman'',Chandman''-Undehr,Chandmani-Ondor,Chandmanĭ-Öndör,Chandman’,Chindamani,Chindamani Ondor,Chindamani Ondor Suma,Chindamani Suma,Chindamani somon,Chindamani undur sumu,Chindamani Öndör,Chindamani Öndör Suma,Chindamani ündür sumu,Chindamani-Undur,Hoehoeoe,Hohoo,Höhöö,Undur Sume,Чандмань-Ундэр', 50.4727800, 100.9277800, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93727, 'Höhbürd', 'Hohburd', 'Bayan-Ovoo,Bayan-Owoo', 46.2857500, 100.4483400, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93728, 'Herlen', 'Herlen', 'Herlen,Kherlen', 47.3000000, 110.5666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93729, 'Haylaastay', 'Haylaastay', 'Haylaastay,Sakhe Bataar,Suhbaatar,Sukhbaatar,Sukhe Batur,Sukhe-Bator,Sühbaatar,Sükhbaatar', 46.9000000, 113.4166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93730, 'Havirga', 'Havirga', 'Elesete,Eleste,Eleste Somon,Havirga,Ongon,Ongon Elesu,Ongon Somon,Ongon Suma,Ongon Suma Elesete,Ongon sumu', 45.6666700, 113.0833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93731, 'Hatavch', 'Hatavch', 'Haldzan,Hatavch,Khaldzhan', 46.1666700, 112.9500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93732, 'Hatansuudal', 'Hatansuudal', 'Bayanleg,Legiin Goliin Horshoo,Legin golin khorsho,Legin golin yurt,Lieh-k"o,Lieh-k”o', 44.5459500, 100.8278800, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93733, 'Hashaat', 'Hashaat', 'Del''ger-khangay,Deleger Khangai Somon,Delger Hangay Suma,Delger Khaigay Somon,Delger Khangai,Delger Khangay Somon,Delger hangay sumu,Delgerhangay,Derigeru-hangai', 45.2432300, 104.8051100, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93734, 'Orhon', 'Orhon', 'Harosha,Orhon,Orkhon,Орхон', 49.8325000, 106.1363900, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93735, 'Harhorin', 'Harhorin', 'Kharkhorin,Хархорин', 47.1975300, 102.8237900, 'MN', '2009-01-10', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93736, 'Haraat', 'Haraat', 'Haraat,Tsagaan Delger Suma,Tsagaan del''ger sumu,Tsagaan del’ger sumu,Tsagaandelger,Tsagan Delger,Tsagan Delger Somon,Tsagan-Del''ger-Sumu,Tsagan-Del’ger-Sumu', 46.4166700, 107.6500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93737, 'Hanhöhiy', 'Hanhohiy', 'Hanhohiy,Hanhöhiy,Tumentsogt,Tümentsogt', 47.6166700, 112.1333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93738, 'Hajuu-Us', 'Hajuu-Us', 'Govi-Ugtaal,Govĭ-Ugtaal,Gow''-Ugtaal,Ugtaal,Ugtaal Suma,Ugtaal sumu,Ukhtal,Ukhtal Somon', 46.0498800, 107.4895500, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93739, 'Erhet', 'Erhet', 'Erhet,Mogod,Mogod Suma,Mogot,Mogot somon,Mogot sumu,Могод', 48.2739400, 102.9812000, 'MN', '2007-10-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93740, 'Ergel', 'Ergel', 'Ergel,Hatan Bulag Suma,Hatanbulag,Hatau Bulag Suma,Haton bulag sumu,Hatun Bulag,Hatün Bulag,Khatan-Bulak,Khatanbulag,Khaton Buluk Sume,Khaton-Bulag-Sumu,Khatun Bulak,Khatun-bulak Somon,Khatyn-bulak somon', 43.1500000, 109.1333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93741, 'Ereencav', 'Ereencav', 'Chuluunhoroot,Ereentsaw,Ereentsay,Eren-Tsav,Erentsab,Erientsab,Eryeen Tsab,Irintsabu Kaihyo,Irïntsābu Kaihyō', 49.8807000, 115.7252600, 'MN', '2016-04-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93742, 'Erdenetsogt', 'Erdenetsogt', 'Erdeni Tsogto Suma,Erdeni Tsogtu,Erdeni Tsogtu Somon,Erdeni Tsogtu Sume,Erdeni tsogtu sumu', 46.4184500, 100.8223900, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93743, 'Erdenetsogt', 'Erdenetsogt', 'Bayan Obo,Bayan Oboo Suma,Bayan obo Somon,Bayan-Ovoo,Bayan-Owoo', 42.9723800, 106.1186600, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93744, 'Erdenet', 'Erdenet', 'Ehrdehneht,Ehrdehneht khot,Erdenet,Erdenetas,Gorad Ehrdehneht,ardenaita,ardnt,e er deng te,eleudeneteu,erudeneto,Горад Эрдэнэт,Ерденет,Эрдэнэт,Эрдэнэт хот,ארדנט,اردنت,अर्देनैट,エルデネト,额尔登特,에르데네트', 49.0333300, 104.0833300, 'MN', '2014-04-26', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93745, 'Eg-Uur', 'Eg-Uur', 'Eg-Uur,Ehrdehneh-Bulgan,Erdenebulgan,Erdeni Bulagan Suma,Erdeni Bulagan Sume,Erdeni bulagan sumu,Erdeni-Bulagan,Erdeni-Bulgan Somon,Erdeni-bulgai somon,Эрдэнэ-Булган', 50.1094400, 101.5752800, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93746, 'Enhtal', 'Enhtal', 'Ehnkhtal,Enhtal,Sant,Энхтал', 49.2475000, 105.3736100, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93747, 'Eg', 'Eg', 'Batshireet,Batshireht,Eg,Батширэт', 48.6833300, 110.1833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93748, 'Dzuunmod', 'Dzuunmod', 'Dzun-mod,Dzun-modo,Dzuun Modo,Dzuunmod,Zun-Mod,Zuunmod,Зуунмод', 47.7069400, 106.9527800, 'MN', '2013-08-09', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93749, 'Dzüünharaa', 'Dzuunharaa', 'Dzueuenharaa,Dzunkhara,Dzuunkharaa,Dzüünharaa,Dzüünkharaa,Дзунхара', 48.8522900, 106.4578600, 'MN', '2014-06-27', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93750, 'Dzüünbulag', 'Dzuunbulag', 'Madat,Madat sumu,Mamat-Somon,Matad,Matad Suma,Matad Sume,Matad somon,Matat,Matat Somon', 46.9534300, 115.2939600, 'MN', '2007-10-28', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93751, 'Dzüünbulag', 'Dzuunbulag', 'Dzuunbulag,Dzüünbulag,Ul''-bain-munku Somon,Ul''bayn Munku Somon,Ula bayan monho Sumu,Ula bayan mönhö Sumu,Ula-Bayan-Munkhu,Ul’-bain-munku Somon,Ul’bayn Munku Somon,Uula Bayan Monho Suma,Uula Bayan Mönhö Suma,Uula bayan monho,Uula bayan mönhö,Uulbayan,Uulbayan Monh,Uulbayan Mönh', 46.3833300, 112.1833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93752, 'Dzogsool', 'Dzogsool', 'Bayan Tsagaan Suma,Bayan Tsagaan Sumu,Bayan Tsagan Somon,Bayan-Tsagan,Bayantsagaan,Dzogsool', 46.8000000, 107.1500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93753, 'Dzelter', 'Dzelter', 'Dzelter,Tsagaannuur,Tushig,Tüshig,Zehltehr,Зэлтэр', 50.3155600, 105.0458300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93754, 'Dzegstey', 'Dzegstey', 'Baisakhlin,Baissakly,Baysakhlin,Baysakhlyn-khure,K''u-lieh-pai-sa-ho-lin,Kure Baysakhlyn,Kure Beissachlin,Kure-baisaharin,Kure-baisaharïn,Ogiinuur,Ogiynuur,Pai-sa-ho-lin,Paisafurin-kure,Paisafurïn-kure,Ugey,Ugey Camp,Ugey Stanok,Ögiynuur,Ögïïnuur,Ügey', 47.6680500, 102.5499900, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93755, 'Dzaanhoshuu', 'Dzaanhoshuu', 'Dzaanhushuu,Ihe Tamir,Ihtamir,Ikh-Tamire,Ikhe Tamir Sume,Ikhe Tamiriin somon,Ikhe-Tamir,Ikhtamir,Yekhe Tamir,Yihe Tamiriin Suma', 47.4933100, 100.8780100, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93756, 'Dund-Urt', 'Dund-Urt', 'Bayan Tsogto Suma,Bayan Tsogtu,Bayan Tsogtu Somon,Bayan tsogtu sumu,Bayan-tsokuto,Bayantsogt,Dund-Urt', 48.0379100, 105.9219000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93757, 'Dundbürd', 'Dundburd', 'Bata Chorboin Khid,Bata Chorboyn Khid,Bata Chorböyn Khid,Bata Norboiin Hiid,Bata Norboyn Khid,Batnorov,Batnorow,Batu Norb''oin hurie,Batu Norb''oin hürie,Batu Norboin Khure,Batu-Norboiin hurie,Batu-Norboiin hürie,Batu-Norboyn-Khure,Batu-norubo', 47.9459000, 111.4978400, 'MN', '2007-10-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93758, 'Doloon', 'Doloon', 'Tsogt-Ovoo,Tsogt-Owoo', 44.4244600, 105.3207800, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93759, 'Delgerhaan', 'Delgerhaan', 'Dehlgehrkhan,Shaamar,Shamar,Shamor,Дэлгэрхан', 50.0857800, 106.1857800, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93760, 'Dashbalbar', 'Dashbalbar', 'Dashbalbar,Dashi Balbar Suma,Dashi Balbariin Somon,Dashi Balbaron Somon,Dashi balbar sumu,Dashi-Balbaryn-Somon,Dashibalbar,Дашбалбар', 49.5457100, 114.4028700, 'MN', '2007-10-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93432, 'Yenangyaung', 'Yenangyaung', 'Yaynangyoung,Yenangyaung,Yenangyoung', 20.4650400, 94.8712000, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93433, 'Nyaungdon', 'Nyaungdon', 'Nyanngdon,Nyaung-dun,Nyaungdon,Yandoon,Yandun', 17.0445900, 95.6395700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93434, 'Yamethin', 'Yamethin', 'Yamethin,Yamethinn', 20.4318900, 96.1387500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93435, 'Wakema', 'Wakema', 'Wagay-ma,Wagema,Wagèma,Wakema,Wancuma,Wankinna', 16.6033300, 95.1827800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93436, 'Twante', 'Twante', '', 16.7104700, 95.9286600, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93437, 'Taungoo', 'Taungoo', 'Taung-ngu,Taungngu,Taungoo,Taungu,Taungû,Toungoo,taung-u,txng xu,Таунгу,ตองอู,တောင်ငူမြို့,타웅우', 18.9429100, 96.4340800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93438, 'Thongwa', 'Thongwa', 'Thon-Khwa,Thongwa', 16.7599800, 96.5249800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93439, 'Thayetmyo', 'Thayetmyo', 'Thayetmo,Thayetmyo,Thyatmyo', 19.3207600, 95.1827200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93440, 'Thaton', 'Thaton', 'Tha-tun,Thadon,Thadôn,Thaton', 16.9186700, 97.3700100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93441, 'Tharyarwady', 'Tharyarwady', 'Tharrawaddy,Tharyarwady,Thayawadi', 17.6539900, 95.7881300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93442, 'Thanatpin', 'Thanatpin', 'Tanatpin,Thanatpin', 17.2913600, 96.5752300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93443, 'Thanatpin', 'Thanatpin', '', 17.2119400, 96.3033300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93444, 'Dawei', 'Dawei', 'Davejus,Davėjus,Dawei,TVY,Tavoj,Tavoy,Tawe,Tawè,dau~ei,dawei,dawy,dawyy,thway,tu wa,Тавой,داوئی,داوی,ทวาย,ထားဝယ်မြို့,ダウェイ,土瓦,다웨이', 14.0823000, 98.1915100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93445, 'Taunggyi', 'Taunggyi', 'Taundzhi,Taundzi,Taundzis,Taundžis,Taunggi Mong,Taunggyi,dong zhi,taungji,taunji,tawngyy,txng yi,Таунджи,Таунџи,تاونگئی,ตองยี,တောင်ကြီးမြို့,タウンジー,東枝,타웅지', 20.7891900, 97.0377600, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93446, 'Taungdwingyi', 'Taungdwingyi', 'Taungdwingyi', 20.0065000, 95.5453100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93447, 'Tachilek', 'Tachilek', 'THL,Tachajlejk,Tachileik,Tachilek,Tha Chaleak,Tha Chi Lek,Wan Ta-hki-lek,Wān Ta-hki-lēk,Тачайлейк', 20.4475000, 99.8808300, 'MM', '2016-06-30', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93448, 'Syriam', 'Syriam', '', 16.7688700, 96.2450300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93449, 'Sittwe', 'Sittwe', 'AKY,Ak''jab,Akjab,Akyab,Sittwe,Situe,Situeh,Sitve,Sitvė,shi dui,shittou~e,sitave,siteuwe,wytwy,Акьяб,Ситуэ,Сітуе,ویتوی,सितवे,စစ်တွေမြို့,シットウェ,实兑,시트웨', 20.1462400, 92.8983500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93450, 'Shwebo', 'Shwebo', 'Shwebo', 22.5692500, 95.6981800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93451, 'Sagaing', 'Sagaing', 'Sagajn,Sagang,Sitkaing,Сагайн', 21.8787000, 95.9796500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93452, 'Yangon', 'Yangon', 'Dagon,Gian''nkon,Gorad Jangon,Jangon,Jangon khot,Jangona,Jangono,Jangun,Jangún,Ngiong-kong,Ngióng-kông,RGN,Rangon,Rangoon,Rangoun,Rangum,Rangun,Rangunas,Rangún,Rangūnas,Yangjgvangh,Yangon,Yangôn,Yanqon,iangoni,iyanguna,raguna,ranguna,rngwn,yang guang,yang-gon,yanghwn,yangkung,yangon,yanguna,yangwn,yankon,Ýangon,Γιανγκόν,Јангон,Горад Янгон,Рангун,Янгон,Янгон хот,Յանգոն,יאנגון,رنگون,يانغون,یانگون,यांगून,रङ्गुन,रङ्गून,ইয়াংগুন,ਰੰਗੂਨ,யங்கோன்,యాంగోన్,യംഗോൺ,ย่างกุ้ง,ཡང་ཀོང་།,ရန်ကုန်မြို့,იანგონი,ያንጎን,យ៉ាំងហ្គូន,ヤンゴン,仰光,양곤', 16.8052800, 96.1561100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93453, 'Pyu', 'Pyu', 'Pyu', 18.4813000, 96.4374200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93454, 'Pyinmana', 'Pyinmana', 'P''inmana,Pinmana,Pjinmana,Pyinmana,Pyinmana Naypyidaw,Pyinmank,Rangun,bin ma na,nai bi duo,p yin ma na,pinmana,Пьинмана,Пїнмана,Рангун,ปยินมะนา,ပျဉ်းမနားမြို့,ピンマナ,奈比多,彬馬那,핀마나', 19.7381000, 96.2074200, 'MM', '2016-06-22', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93455, 'Pyay', 'Pyay', 'PRU,Prome,Pyay,Pye,Pyei,Pyit,Проме', 18.8246400, 95.2221600, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93456, 'Pyapon', 'Pyapon', 'P''japon,Pyabon,Pyabôn,Pyapon,Pyapun,Пьяпон', 16.2854300, 95.6788200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93457, 'Bago', 'Bago', 'Bagas,Bago,Begu,Pegou,Pegu,Pégou,bago,bagw  brma,bagw  myanmar,bo gu,peku,pha kho,Пегу,باگو، برما,باگو، میانمار,பெகு,พะโค,ပဲခူးမြို့,バゴー,勃固,바고', 17.3352100, 96.4813500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93458, 'Paungde', 'Paungde', 'Paung-deh,Paungde', 18.4916700, 95.5059100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93459, 'Pakokku', 'Pakokku', 'PKK,Pagukku,Pakkoku,Pakokku,Пакокку', 21.3348900, 95.0843800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93460, 'Hpa-an', 'Hpa-an', 'Hpa-an,PAA,Pa-an,Pan', 16.8895300, 97.6348200, 'MM', '2017-02-03', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93461, 'Nyaungshwe', 'Nyaungshwe', 'Nyaung Shwe,Yawnghwe,ညောငရေမြ,ညောင်ရွှေမြို့', 20.6608400, 96.9340500, 'MM', '2016-10-19', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93462, 'Nyaunglebin', 'Nyaunglebin', '', 17.9536300, 96.7224700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93463, 'Myitkyina', 'Myitkyina', 'M''ichina,MYT,Michina,Mjicina,Mjičina,Myitkyin,Myitkyina,Myitkyinā,mi zhi na,michina,mit ci na,mitchina,myytkyyna,Мичина,Мьичина,Мїчина,میئتکیئنا,มิตจีนา,မြစ်ကြီးနားမြို့,ミッチーナー,密支那,미치나', 25.3832700, 97.3963700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93464, 'Myingyan', 'Myingyan', 'Myingan,Myingyan', 21.4600200, 95.3884000, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93465, 'Myawadi', 'Myawadi', '', 16.6891100, 98.5089300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93466, 'Myanaung', 'Myanaung', 'Myanaung', 18.2865100, 95.3201400, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93467, 'Mudon', 'Mudon', 'Mudon', 16.2562400, 97.7246000, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93468, 'Mawlamyinegyunn', 'Mawlamyinegyunn', 'Mawlamyainggyun,Mawlamyinegyunn,Moulmeingyu,Moulmeingyun', 16.3772000, 95.2648800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93469, 'Mawlamyine', 'Mawlamyine', 'MNU,Maulamiain,Mawlamyaing,Mawlamyine,Molam''jajn,Molamjainas,Molamjajn,Molamyaing,Moulamjin,Moulmein,Mulmejn,mao dan mian,mawlamyayn,mawlamyyn,meaa la leing,moramyain,moulmein,Моламьяйн,Моламяйн,Моуламјин,ماولامیئن,ماولامیاین,เมาะลำเลิง,မောလမြင,မော်လမြိုင်,モーラミャイン,毛淡棉,모울메인', 16.4905100, 97.6282500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93470, 'Monywa', 'Monywa', 'Moniva,Monywa,Mounujua,Munywa,NYW,meng yu wa,mon''yuwa,moniwa,mony wa,mwnywa,Моунъюа,مونیوا,โมนยวา,မုံရွာ,モンユワ,蒙育瓦,모니와', 22.1085600, 95.1358300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93471, 'Mogok', 'Mogok', 'Magok,Mogok,Могок', 22.9176600, 96.5098200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93472, 'Minbu', 'Minbu', '', 20.1805900, 94.8759500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93473, 'Mikenaungea', 'Mikenaungea', '', 15.9584600, 98.4272100, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93474, 'Myeik', 'Myeik', 'MGZ,Mergui,Myeik', 12.4395400, 98.6002800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93475, 'Meiktila', 'Meiktila', 'Meiktila,Mejtkhila,Miktila,mea thi la,meikeutilla,meittira,myyktyla,Мейтхила,میئکتیلا,เมะทีลา,မိတ္ထီလာမြို့,メイッティーラ,메이크틸라', 20.8777600, 95.8584400, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93476, 'Pyin Oo Lwin', 'Pyin Oo Lwin', 'Maymo,Maymyo,Meimyu,Memyo,Pyn U Lwin', 22.0350100, 96.4568300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93477, 'Mawlaik', 'Mawlaik', '', 23.6425400, 94.4047800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93478, 'Maubin', 'Maubin', 'Ma-oo-beng,Manbin,Maubin', 16.7314800, 95.6544100, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93479, 'Martaban', 'Martaban', 'Martaban,Marteban,Moktama,Мартабан', 16.5283400, 97.6157000, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93480, 'Mandalay', 'Mandalay', 'Gorad Mandalaj,MDL,Mandalaj,Mandalaja,Mandalajo,Mandalajus,Mandalay,Mandalay piirkond,Mandale,Mandalej,man de lei,mandalay,mandale,mandallei,mandaly,mandare,mantalai,manth a ley,Горад Мандалай,Мандалай,Мандалеј,ماندالاي,ماندالی,ماندالے,मांडले,माण्डले,மண்டலை,మాండలే,มัณฑะเลย์,မန္တလေးမြို့,マンダレー,曼德勒,만달레이', 21.9747300, 96.0835900, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93481, 'Magway', 'Magway', 'MWQ,Magueh,Magway,Magwe,Магуэ', 20.1495600, 94.9324600, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93482, 'Loikaw', 'Loikaw', 'LIW,Loikaw,Lwegaw,Lwègaw', 19.6779800, 97.2097500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93483, 'Letpandan', 'Letpandan', 'Letpadan,Letpandan,Letpatan', 17.7866400, 95.7507600, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93484, 'Lashio', 'Lashio', 'LSH,Lasha,Lashio,Lasho,Lasijas,Lašijas,la qu,lashyw,lasio,rasho,Лаша,Лашо,لاشیو,လားရှိုးမြို့,ラーショー,臘戌,라시오', 22.9359000, 97.7498000, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93485, 'Kyaukse', 'Kyaukse', 'Kyaukse', 21.6056000, 96.1350800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93486, 'Kyaikto', 'Kyaikto', 'Kyaikto', 17.3085800, 97.0112400, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93487, 'Kyaiklat', 'Kyaiklat', 'Keiklat,Kyaiklat', 16.4450200, 95.7237300, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93488, 'Kyaikkami', 'Kyaikkami', 'Amherst,Kyaikkami', 16.0768600, 97.5638800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93489, 'Kayan', 'Kayan', '', 16.9080200, 96.5603700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93490, 'Kanbe', 'Kanbe', 'Kanbe,Kanhe,Канбе', 16.7072800, 96.0016800, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93491, 'Hinthada', 'Hinthada', 'HEB,Henzada,Hintada,Hinthada', 17.6494400, 95.4570500, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93492, 'Hakha', 'Hakha', 'ဟားခါးမြ,ဟားခါးမြို့', 22.6500000, 93.6166700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93493, 'Falam', 'Falam', 'Falam,Palan,Фалам', 22.9133500, 93.6777900, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93494, 'Chauk', 'Chauk', 'Chauk,Chouk,Чаук', 20.8992100, 94.8178400, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93495, 'Bogale', 'Bogale', 'Bogale', 16.2941500, 95.3974200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93496, 'Bhamo', 'Bhamo', 'BMO,Bamo,Banmaw,Banmo,Bhamo,Hsinkai,ba mo,bamo,pha mo,Бамо,Банмо,พะโม,ဗန်းမော်မြို့,バモー,八莫,바모', 24.2525600, 97.2335700, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93497, 'Pathein', 'Pathein', 'BSX,Basejn,Bassein,Bassejn,Pantejn,Patejn,Pathein,Patheinas,Puthein,bo sheng,patein,patyn,Бассейн,Пантейн,Патейн,پاتھین,پاتین,ပုသိမ်မြို့,パテイン,勃生,파테인', 16.7791900, 94.7321200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93498, 'Myaydo', 'Myaydo', 'Allanmyo,Aunglan,Aunglanmyo,Myaydo', 19.3683800, 95.2151200, 'MM', '2016-06-01', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93499, 'Nay Pyi Taw', 'Nay Pyi Taw', 'Kyatpyay,Kyetpyay,NYT,Naipidau,Nay Pyi Taw,Naypyidaw,Naypyitaw,Ne Pyi Daw,Pyinmana,naepido,nepido,내피도,네피도', 19.7450000, 96.1297200, 'MM', '2017-07-19', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93500, 'Tagondaing', 'Tagondaing', 'Tagondaing', 16.0677400, 97.9072300, 'MM', '2017-07-22', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93501, 'Tamoowoung', 'Tamoowoung', '', 16.0344700, 97.9145800, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93502, 'Dellok', 'Dellok', '', 16.0407200, 97.9177300, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93503, 'Pulei', 'Pulei', '', 16.0624300, 97.8828000, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93504, 'Klonhtoug', 'Klonhtoug', '', 15.9541100, 98.4325000, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93505, 'Mikenaungea', 'Mikenaungea', '', 15.9611200, 98.4207200, 'MM', '2017-05-11', 153);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93833, 'Macau', 'Macau', 'Aomen,Aomin'',Au-mun,Aumwnz,Aumyn,Cidade de Macau,Cidade do Santo Nome de Deus de Macau,MFM,Ma Cao,Macao,Macau,Macaum,Makaa,Makaaw,Makao,Makaou,Makau,Makaw,Makawo,Makaó,Makee,Makèë,Màkáù,O-muong,ao men,maka,maka''o,maka''u,makao,makavu,makaw,makayw,makkavu,mkaw,Àu-mûn,Ó̤-muòng,Μακάου,Аоминь,Аумын,Макаа,Макао,מקאו,ئاۋمېن,ماكاو,ماکائو,مکاؤ,މަކާއޫ,मकाउ,मकाओ,মাকাউ,ਮਕਾਉ,મકાઉ,மக்காவு,మకావు,ಮಕಾವು,മകൗ,เขตบริหารพิเศษมาเก๊า,မကာအို,მაკაო,マカオ,澳門,澳门,마카오', 22.2005600, 113.5461100, 'MO', '2011-10-27', 131);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94067, 'Karonga', 'Karonga', 'KGJ,Karonga,Каронга', -9.9333300, 33.9333300, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94068, 'Chitipa', 'Chitipa', 'Chipita,Chitipa,Fort Hill', -9.7023700, 33.2696900, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94069, 'Zomba', 'Zomba', 'Zomba,jomba,song ba,zomba,zonba,zwmba  malawy,Зомба,زومبا، مالاوی,ზომბა,ゾンバ,松巴,좀바', -15.3859600, 35.3188000, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94070, 'Thyolo', 'Thyolo', 'Cholo,Thyolo', -16.0677500, 35.1404600, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94071, 'Salima', 'Salima', 'LMB,Salima,Салима', -13.7804000, 34.4587000, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94072, 'Rumphi', 'Rumphi', 'Rumphi,Rumpi,Rumpi Boma', -11.0186300, 33.8574600, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94073, 'Phalombe', 'Phalombe', 'Palombe,Palombe Market,Phalombe', -15.8063500, 35.6506700, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94074, 'Ntchisi', 'Ntchisi', 'Nchisi,Nchisi Boma,Ntchisi', -13.5277500, 33.9149000, 'MW', '2011-06-02', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94075, 'Ntcheu', 'Ntcheu', 'Ncheu,Nitcheu,Ntcheu', -14.8202700, 34.6358600, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94076, 'Nsanje', 'Nsanje', 'Chimombi,Nsanje,Port Herald', -16.9199500, 35.2619900, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94077, 'Nkhotakota', 'Nkhotakota', 'Kota Kota,Nkhotakota,en ke ta ke ta,eunkotakota,nkhwtakwta,نخوتاکوتا,恩科塔科塔,은코타코타', -12.9274400, 34.2961400, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94078, 'Nkhata Bay', 'Nkhata Bay', 'Nkata,Nkata Bay,Nkhata Bay', -11.6065900, 34.2907300, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94079, 'Neno', 'Neno', '', -15.3980500, 34.6534300, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94080, 'Mzuzu', 'Mzuzu', 'Kaningina,Mzouzou,Mzuzo,Mzuzu,ZZU,eumjuju,mu zu zu,muzuzu,mzwzw,Μζούζου,Мзузу,مزوزو,ムズズ,姆祖祖,음주주', -11.4655600, 34.0207100, 'MW', '2013-08-05', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94081, 'Mzimba', 'Mzimba', 'Mzimba,Мзимба', -11.9000000, 33.6000000, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94082, 'Mwanza', 'Mwanza', 'Mwanza', -15.6026200, 34.5247900, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94083, 'Mulanje', 'Mulanje', 'Mlange,Mlanje,Mlanje Boma,Mulanje', -16.0316300, 35.5000000, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94084, 'Mponela', 'Mponela', 'Mponela', -13.5319400, 33.7400800, 'MW', '2012-01-18', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94085, 'Monkey Bay', 'Monkey Bay', 'Lusumbwe,MYZ,Monkey Bay', -14.0823900, 34.9165200, 'MW', '2015-12-13', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94086, 'Mchinji', 'Mchinji', 'Chimji,Fort Manning,Mchinji', -13.7984100, 32.8801900, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94087, 'Mangochi', 'Mangochi', 'Fort Johnston,MAI,Mangoche,Mangochi,Mponda,Мангочи', -14.4781500, 35.2644800, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94088, 'Machinga', 'Machinga', '', -15.1684900, 35.3000200, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94089, 'Luchenza', 'Luchenza', 'Luchenya,Luchenza,Lughenza', -16.0069300, 35.3094700, 'MW', '2012-01-18', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94090, 'Liwonde', 'Liwonde', 'Liwonde,Old Liwonde Boma,VUU', -15.0666500, 35.2254300, 'MW', '2013-04-27', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94091, 'Livingstonia', 'Livingstonia', 'Kondowe,Livingstonia,Livingstonia Mission', -10.6060200, 34.1062800, 'MW', '2012-01-18', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94092, 'Lilongwe', 'Lilongwe', 'Gorad Lilongveh,LLW,Lilon''nkoue,Lilonguee,Lilongve,Lilongvo,Lilongvė,Lilongwe,Lilongüe,Lilonhue,Lilonqve,Lílongve,li lang wei,li long gui,li lxng we,lilamgve,lilangave,lillong-gwe,lilongve,lilonve,lylwnghwy,lylwngwh,lylwngwwh,rironguu~e,Λιλόνγκουε,Горад Лілонгвэ,Лилонгве,Лілонгве,Լիլոնգվե,לילאנגווע,לילונגווה,ليلونغوي,لیلونگوه,لیلونگوے,لیلۆنگوێ,لیلیونگوے,लिलाँग्वे,ਲਿਲਾਂਗਵੇ,லிலொங்வே,ลิลองเว,ལི་ལོང་ཀུའེ།,ლილონგვე,ሊሎንጔ,リロングウェ,利隆圭,里朗威,릴롱궤', -13.9669200, 33.7872500, 'MW', '2012-01-18', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94093, 'Kasungu', 'Kasungu', 'KBQ,Kasungu,Касунгу', -13.0333300, 33.4833300, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94094, 'Dowa', 'Dowa', 'Dowa', -13.6539900, 33.9375400, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94095, 'Dedza', 'Dedza', 'Dedza', -14.3779000, 34.3332200, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94096, 'Chiradzulu', 'Chiradzulu', 'Chiradzulu,Chiradzulu Boma', -15.6746100, 35.1407100, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94097, 'Chipyela', 'Chipyela', '', -12.0661800, 34.7409200, 'MW', '2011-04-25', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94098, 'Chipoka', 'Chipoka', 'Chipoka', -13.9932900, 34.5156600, 'MW', '2012-01-18', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94099, 'Chikwawa', 'Chikwawa', 'Chikwawa', -16.0335200, 34.8009100, 'MW', '2011-11-09', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94100, 'Blantyre', 'Blantyre', 'BLZ,Blantair,Blantairas,Blantajer,Blantajr,Blantajur,Blantire,Blantyre,Blantyre-Limbe,Gorad Blantajr,Kapeni,beullaentaieo,blamtayara,blantayr,blantayr  malawy,blantyyr,blntyyr,bu lan tai er,burantaiya,Μπλαντάιρ,Блантайр,Блантайър,Блантајер,Горад Блантайр,בלנטייר,بلانتاير,بلانتایر، مالاوی,بلانتیئر,ब्लँटायर,ブランタイヤ,布兰太尔,블랜타이어', -15.7849900, 35.0085400, 'MW', '2014-07-21', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94101, 'Balaka', 'Balaka', 'Balaka,Balakas,Palaka,Балака', -14.9792800, 34.9557500, 'MW', '2011-11-08', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94102, 'Makata', 'Makata', '', -15.7872100, 35.0304600, 'MW', '2011-06-01', 134);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94044, 'Meedhoo', 'Meedhoo', '', -0.5833300, 73.2333300, 'MV', '2011-07-15', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94045, 'Male', 'Male', 'MLE,Maale,Male,Malé,Malė,ma lei,ma lu,male,malle,mare,Μαλέ,Мале,מאלה,މާލެ,माले,মালে,மாலே,มาเล,มาเล่,マレ,瑪律,馬累,말레', 4.1748000, 73.5088800, 'MV', '2015-08-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94046, 'Hithadhoo', 'Hithadhoo', 'Hitaddu,Hithadhoo', -0.6000000, 73.0833300, 'MV', '2012-01-18', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94047, 'Mahibadhoo', 'Mahibadhoo', 'Mahibadhoo', 3.7571300, 72.9689300, 'MV', '2013-04-07', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94048, 'Eydhafushi', 'Eydhafushi', '', 5.1032700, 73.0707800, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94049, 'Kudahuvadhoo', 'Kudahuvadhoo', 'DDD,Kudahuvadhoo', 2.6707500, 72.8943700, 'MV', '2017-05-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94050, 'Viligili', 'Viligili', 'Viligili,Villingili', 0.7590600, 73.4329600, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94051, 'Thinadhoo', 'Thinadhoo', 'Thinadhoo', 0.5306000, 72.9996900, 'MV', '2016-04-10', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94052, 'Fuvahmulah', 'Fuvahmulah', '', -0.2987800, 73.4240300, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94053, 'Dhidhdhoo', 'Dhidhdhoo', 'Dhidhdhoo', 6.8874400, 73.1140200, 'MV', '2015-06-29', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94054, 'Kulhudhuffushi', 'Kulhudhuffushi', '', 6.6220700, 73.0699800, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94055, 'Naifaru', 'Naifaru', '', 5.4443800, 73.3657100, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94056, 'Muli', 'Muli', 'Muli', 2.9166700, 73.5666700, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94057, 'Manadhoo', 'Manadhoo', 'Manadhoo', 5.7668700, 73.4136000, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94058, 'Ugoofaaru', 'Ugoofaaru', 'U''ngoofaaru,Ugoofaaru,U’ngoofaaru', 5.6681200, 73.0301700, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94059, 'Funadhoo', 'Funadhoo', 'Farukolhufunadhoo,Funadhoo', 6.1509100, 73.2901300, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94060, 'Veymandoo', 'Veymandoo', 'Veymandhoo,Veymandoo', 2.1877200, 73.0955600, 'MV', '2013-09-22', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94061, 'Felidhoo', 'Felidhoo', 'Felidhoo', 3.4718200, 73.5469900, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94062, 'Hulhumale', 'Hulhumale', '', 4.2116900, 73.5400800, 'MV', '2016-10-17', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94063, 'Fonadhoo', 'Fonadhoo', '', 1.8324300, 73.5025700, 'MV', '2013-07-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94064, 'Vilufushi', 'Vilufushi', '', 2.5030600, 73.3085900, 'MV', '2011-07-29', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94065, 'Madifushi', 'Madifushi', '', 2.3558200, 73.3547300, 'MV', '2011-08-04', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94066, 'Open Stage', 'Open Stage', '', 5.1053000, 73.0711500, 'MV', '2012-10-10', 136);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93879, 'Marsaxlokk', 'Marsaxlokk', 'M''Xloxx,Marsa Scirocco,Marsa Shlok,Marsashlokk,Marsaxlok,Marsaxlokk,M’Xloxx,Марсашлокк', 35.8419400, 14.5430600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93880, 'Żurrieq', 'Zurrieq', 'Casal Zurrico,Iz-Zurrieq,Iż-Żurrieq,Zebbudzh,Zouriek,Zurikas,Zurrico,Zurriek,Zurrieq,Zurrik,julikeu,zu li ge,zwryk,zwryq,zwryya,Żurrieq,Ζουριέκ,Зеббудж,Зуррик,Зуррік,زوریئا,زوریق,زوریک,祖里格,주리크', 35.8311100, 14.4741700, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93881, 'Żejtun', 'Zejtun', 'Casal Zeitun,Iz Zeitun,Iz-Zejtun,Iż-Żejtun,Zeitun,Zeitunas,Zeitūnas,Zejtun,jeitun,zi dun,zytwn  malt,Żejtun,Зейтун,Зејтун,زیتون، مالت,زیتون، مالٹا,زەیتوون، ماڵتا,榟橔,제이툰', 35.8558300, 14.5330600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93882, 'Żebbuġ', 'Zebbug', 'Iz-Zebbug,Iz-Zebbug (Gozo),Iż-Żebbuġ,Iż-Żebbuġ (Gozo),Zebbug,Zebbug (Gozo),Zebbuj,Zebudzas,Zebudžas,jebuji,zybwj  gwzw,Żebbuġ,Żebbuġ (Gozo),زیبوج، گوزو,제부지', 36.0722200, 14.2358300, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93883, 'Haz-Zebbug', 'Haz-Zebbug', 'Haz-Zebbug,Lebbug,Zebbudzh,Zebbuj,Зеббудж', 35.8719400, 14.4411100, 'MT', '2014-04-28', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93884, 'Żabbar', 'Zabbar', 'Haz-Zabbar,Haż-Żabbar,Zabar,Zabaras,Zabbar,jabaleu,zabar,zha ba er,Ħaż-Żabbar,Żabbar,Забар,Заббар,زابار,扎巴爾,자바르', 35.8761100, 14.5350000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93885, 'Xgħajra', 'Xghajra', 'Ix-Xghara,Ix-Xgħara,Sh''ayra,Shghaira,Sh’ayra,Xghaira,Xghajra,Xgħajra', 35.8855600, 14.5475000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93886, 'Xewkija', 'Xewkija', 'Ix-Xewkija,Seukidza,Showkiya,Xeuchia,Xewkija,shwkyt,shywkya,syeukiya,Šeukidža,شوكية,شیوکیا,셰우키야', 36.0327800, 14.2580600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93887, 'Xagħra', 'Xaghra', 'Caccia,Ix-Xaghra,Kacca,Kacha,Kaċċa,Shaghra,Xaghra,Xagħra', 36.0500000, 14.2644400, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93888, 'Valletta', 'Valletta', 'A Valeta,A Valletta,Baleta,Baletta,La Valet,La Valeta,La Valeto,La Valetta,La Valette,La Valletta,La Valèt,La Valëtta,La-Valeto,Vaileite,Valeta,Valetta,Valleta,Vallett,Valletta,Valletta osh,Vallettae,Waleta,balleta,baretta,bhaleta,bhalletta,falyta,hua lie ta,valaita,valerra,valletta,vheleta,wa lai ta,wal let ta,walta,wlth,Ła Vałeta,Βαλέτα,Βαλέττα,Валета,Валлеттæ,Валлетта,Валлетта ош,Ла Валета,Վալետա,וואלעטא,ולטה,فاليتا,والتا,والیٹا,ولیٹا,ڤالێتا,भलेट,व्हॅलेटा,ভাল্লেত্তা,ਵਲੈਟਾ,வல்லெட்டா,വലേറ്റ,วัลเลตตา,ཝ་ལེ་ཐ།,ვალეტა,ቫሌታ,バレッタ,瓦莱塔,華列他,발레타', 35.8997200, 14.5147200, 'MT', '2014-04-28', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93889, 'Ta’ Xbiex', 'Ta'' Xbiex', 'Ta'' Shbiesh,Ta'' Xbiex,Ta-Shbish,Tas Biesh,Tasbiesch,Ta’ Shbiesh,Ta’ Xbiex,Та-Шбиш', 35.8991700, 14.4944400, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93890, 'Tarxien', 'Tarxien', 'Casal Tarxien,Hal Tarxien,Tarscen,Tarshien,Tarshin,Tarsinas,Tarxien,Taršinas,Tirix,ta er xin,taleusin,tarshyn,tarshyyn,trzyn,Ħal Tarxien,Таршин,Таршіен,تارشیئن,تارشین,ترزین,塔爾欣,타르신', 35.8658300, 14.5150000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93891, 'Sliema', 'Sliema', 'Sliema,Slijema,Slima,Tas-Sliema,seullima,si li ma,slyma,slymh,Σλιέμα,Слима,Слијема,Сліма,סלימה,سلیما,斯利馬,슬리마', 35.9125000, 14.5019400, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93892, 'Siġġiewi', 'Siggiewi', 'Is-Siggiewi,Is-Siġġiewi,Sidzivis,Sidživis,Siggieui,Siggiewi,Sigijevi,Sijuwi,Siġġiewi,Suggeui,sijiwi,sygywy,syjjywy,syjywy,xi jie wei,Сигијеви,سیججیوی,سیجیوی,سیگیوی,錫傑維,시지위', 35.8555600, 14.4363900, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93893, 'Santa Venera', 'Santa Venera', 'Saint Venera,Santa Venera,Santa Vennera', 35.8908300, 14.4741700, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93894, 'Saint Lucia', 'Saint Lucia', 'Saint Lucia,Santa Lucia,Santa Lucija,Santa Luċia,Santa Luċija', 36.0430600, 14.2172200, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93895, 'Santa Luċija', 'Santa Lucija', 'Santa Lucia,Santa Lucija,Santa Luċija', 35.8627800, 14.5075000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93896, 'San Pawl il-Baħar', 'San Pawl il-Bahar', 'Baia di San Paolo,Saint Paul''s Bay,San Paul Amere,San Paul a Mare,San Paul à Mare', 35.9506400, 14.4156100, 'MT', '2013-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93897, 'Sannat', 'Sannat', 'Is-Sannat,Sanatas,Sannat,Ta'' Sannat,sanateu,sannat,ساننات,사나트', 36.0244400, 14.2427800, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93898, 'San Lawrenz', 'San Lawrenz', 'Saint Lawrence,San Laurenz,San Lawrenz', 36.0555600, 14.2036100, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93899, 'San Ġiljan', 'San Giljan', 'Saint Julian,Saint Julian''s,San Gilian,San Giljan,San Julian,San Julian''s,San Julián,San Ġilian,San Ġiljan,Sent-Dzhulians,St. Julian''s,Сент-Джулианс', 35.9183900, 14.4897700, 'MT', '2013-07-03', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93900, 'Safi', 'Safi', 'Casal Safi,Hal Safi,Safi,Ħal Safi', 35.8330600, 14.4847200, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93901, 'Paola', 'Paola', 'Casal Paola,Casal Paolo,Casal Paula,Paola,Paula,Pawla,Rahal Gdid,Rahal Jedid,Raħal Ġdid,bao la,paolla,paywla,Πάολα,Паола,پائولا,پائۆلا,پاولا، مالٹا,保拉,파올라', 35.8730600, 14.4988900, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93902, 'Victoria', 'Victoria', 'Ir-Rabat,Rabat,Victoria,Victoria Town,Victoria pa Gozo,Victoria på Gozo,Victòria,Viktori,Viktorija,Vittoria,bigtolia,wei duo li ya,wyktwrya  malt,wyqtwryh,Виктори,Виктория,Викторија,Вікторія,Рабат,ויקטוריה,وکٹوریہ، گوزو,ویکتوریا، مالت,ڤیکتۆریا، ماڵتا,維多利亞,빅토리아', 36.0444400, 14.2397200, 'MT', '2014-10-26', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93903, 'Rabat', 'Rabat', 'Ir-Rabat,Ir-Rabt,Rabat,Rabatas,Rabato,Rampat,alrabat,la ba te,labateu,rbat  malt,Ραμπάτ,Рабат,الرابات,رابات، مالٹا,ربات، مالت,ڕابات، ماڵتا,拉巴特,라바트', 35.8815200, 14.3987200, 'MT', '2014-10-29', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93904, 'Qrendi', 'Qrendi', 'Casal Krendi,Crendi,Il-Qrendi,Krendi,Krendis,Qrendi,aryndy,kui lun di,lendi,آریندی,奎倫迪,렌디', 35.8347200, 14.4583300, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93905, 'Qormi', 'Qormi', 'Curmi,Hal Qormi,Kormi,Kormis,Ormi,awrmy,ge er mi,kwrmy,oleumi,Ħal Qormi,Όρμι,Корми,Кормі,آورمی,قۆرمی,کورمی,戈爾米,오르미', 35.8760100, 14.4720000, 'MT', '2013-07-03', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93906, 'Qala', 'Qala', 'Casal Qala,Il-Qala,Kala,La Cala,Qala,alla,آلا، مالٹا,알라', 36.0361100, 14.3094400, 'MT', '2014-07-24', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93907, 'Pietà', 'Pieta', 'P''eta,Pieta,Pietà,Tal-Pieta,Tal-Pietà,pieta,Пьета,پیئتا، مالٹا,피에타', 35.8947200, 14.4950000, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93908, 'Naxxar', 'Naxxar', 'In-Naxxar,Nasaras,Nasciar,Nasciaro,Nashar,Naxaro,Naxxar,Našaras,na sha er,nasar,nashar,nasyaleu,ناسار,ناشار,納沙爾,나샤르', 35.9136100, 14.4436100, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93909, 'Nadur', 'Nadur', 'In-Nadur,Nadur', 36.0377800, 14.2941700, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93910, 'Munxar', 'Munxar', 'Monsciar,Munshar,Munxar', 36.0300000, 14.2333300, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93911, 'Imtarfa', 'Imtarfa', 'Imtarfa,Imtarfa Barracks,L-Imtarfa,Mtarfa', 35.8933300, 14.3988900, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93912, 'Imsida', 'Imsida', 'Imsida,L-Imsida,Misida,Msida,Мсида', 35.8925000, 14.4827800, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93913, 'Mqabba', 'Mqabba', 'Casal Micabiba,Imkabba,L-Imqabba,Micabba', 35.8476300, 14.4682400, 'MT', '2013-07-10', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93914, 'Mosta', 'Mosta', 'Il-Mosta,Masta,Mosta,Musta,Моста', 35.9091700, 14.4255600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93915, 'Mġarr', 'Mgarr', 'Imjar,L-Imgarr,L-Imġarr,Mgarr,Mġarr', 36.0252800, 14.2950000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93916, 'Imġarr', 'Imgarr', 'Imgarr,Imgiar,Imjar,Imġarr,L-Mgarr,L-Mġarr,Mgar,Mgarr,Mġarr,Мгар', 35.9205600, 14.3663900, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93917, 'Mellieħa', 'Mellieha', 'Il-Mellieha,Il-Mellieħa,Mellieha,Mellieħa,Mellikha,Меллиха', 35.9563900, 14.3622200, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93918, 'Imdina', 'Imdina', 'Citta Notabile,Citta Vecchia,Citta Vechia,Città Notabile,Imdina,L-Imdina,Mdina,Mdina a Rabat,Medina Notabile,Melita,Notabile,Мдина', 35.8869400, 14.4025000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93919, 'Marsaskala', 'Marsaskala', 'M''Skala,Marsa Scala,Marsascala,Marsaskala,Wied il Ghain,Wied il-Ghajn,Wied il-Għajn,Марсаскала', 35.8622000, 14.5670100, 'MT', '2013-10-26', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93920, 'Marsa', 'Marsa', 'Il-Marsa,Marsa,ma er sa,maleusa,marsa,Μάρσα,Марса,Մարսա,مارسا,مارسا، مالٹا,馬爾薩,마르사', 35.8791700, 14.4952800, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93921, 'Luqa', 'Luqa', 'Casal Luca,Hal Luqa,Luca,Luqa,MLA,Ħal Luqa', 35.8588900, 14.4886100, 'MT', '2013-12-25', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93922, 'Senglea', 'Senglea', 'Isla,L-Isla,Sen''nklea,Senglea,sen ge lai a,seng-geullea,snjlya,synglya,Σενγκλέα,Исла,Сенглеа,סנגלאה,سنجليا,سینگلیا,森格萊阿,셍글레아', 35.8875000, 14.5169400, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93923, 'L-Iklin', 'L-Iklin', 'Iklin,L''Inglin,L-Iclin', 35.9041400, 14.4541500, 'MT', '2013-07-23', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93924, 'Lija', 'Lija', 'Casal Lia,Hal Lija,Lia,Lidza,Lidža,Lija,liya,lyya,Ħal Lija,لییا,리야', 35.9005600, 14.4463900, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93925, 'Kirkop', 'Kirkop', 'Casal Chircop,Hal-Kirkop,Kirkop,Ħal-Kirkop', 35.8422200, 14.4852800, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93926, 'Kerċem', 'Kercem', 'Kercem,Kerchem,Kerċem', 36.0419400, 14.2266700, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93927, 'Kalkara', 'Kalkara', 'Calcara,Il-Kalkara,Kalkara', 35.8891700, 14.5327800, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93928, 'Swieqi', 'Swieqi', 'Is Suieki,Is-Swieki,Is-Swieqi,Sviji,Svikis,Swieqi,seuwii,si wei ji,swyky,swyqy,swyyay,Свийи,سویئای,سویقی,سویکی,斯維吉,스위이', 35.9225000, 14.4800000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93929, 'Gżira', 'Gzira', 'Gzira,Gżira,Il-Gzira,Il-Gżira,Гзира', 35.9058300, 14.4880600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93930, 'Floriana', 'Floriana', 'Floriana,Furjana,Il-Furjana,flwryana,peulloliana,Φλοριάνα,Флориана,Флоріана,פלוריאנה,فلوریانا,플로리아나', 35.8958300, 14.5083300, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93931, 'Vittoriosa', 'Vittoriosa', 'Birgu,Il-Birgu,Vittoriosa,Vittorioza,Биргу,Витториоза', 35.8922200, 14.5183300, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93932, 'Ħamrun', 'Hamrun', 'Ham Rum,Hamrun,Il-Hamrun,Ħamrun', 35.8847200, 14.4844400, 'MT', '2013-07-23', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93933, 'Gudja', 'Gudja', 'Gudia,Gudja,Il-Gudja', 35.8491700, 14.5030600, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93934, 'Għaxaq', 'Ghaxaq', 'Ashiak,Axiak,Casal Asciak,Ghashiak,Ghaxaq,Għaxaq,Hal Ghaxaq,Hal Ghaxiak,Ħal Għaxaq', 35.8488900, 14.5166700, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93935, 'Hal Gharghur', 'Hal Gharghur', 'Gargur,Gharghur,Għargħur', 35.9240900, 14.4511800, 'MT', '2014-09-13', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93936, 'Għarb', 'Gharb', 'Gharb,Għarb,Il-Gharb,Il-Għarb', 36.0600000, 14.2088900, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93937, 'Għajnsielem', 'Ghajnsielem', 'Ainsielem,Ghain Sielem,Ghajnsielem,Għajnsielem', 36.0263900, 14.2850000, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93938, 'Fgura', 'Fgura', 'Fgura,Figura,Il-Fgura,Kunsill Lokali Fgura,fgwra,fu gu la,peugula,Фгура,فگورا,弗古拉,프구라', 35.8702800, 14.5133300, 'MT', '2013-08-18', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93939, 'Dingli', 'Dingli', 'Casal Dingli,Dingli,Had-Dingli,Ħad-Dingli', 35.8613900, 14.3822200, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93940, 'Cospicua', 'Cospicua', 'Bormla,Cospicua,Cospiosa,Kospikoua,boleumla,kaspykwa,ke si pi kua,kwsbykw,kwspykwa,Κοσπίκουα,Бормла,Բորմլա,كوسبيكو,کاسپیکوا,کوسپیکوا,کۆسپیکوا,科斯皮夸,보름라', 35.8855600, 14.5275000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93941, 'Birżebbuġa', 'Birzebbuga', 'B''Buga,B''Bugia,Birzbbu,Birzebbu,Birzebbudzha,Birzebbuga,Birzebbugia,Birzebuggia,Birżebbuġa,B’Bugia,B’Buġa,bi er ze bu jia,Бирзеббуджа,比尔泽布贾', 35.8258300, 14.5269400, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93942, 'Birkirkara', 'Birkirkara', 'B''Kara,Birchircara,Birkirkara,B’Kara,Casal Birchircara,byrqyrqrh,Биркиркара,בירקירקרה,ቢርኪርካራ', 35.8972200, 14.4611100, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93943, 'Balzan', 'Balzan', 'Balzan,Casal Balzan,Hal Balzan,Ħal Balzan', 35.9002800, 14.4550000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93944, 'Attard', 'Attard', 'Attard,Casal Attard,H''Attard,Ħ’Attard,Аттард', 35.8897200, 14.4425000, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93945, 'Saint John', 'Saint John', 'Saint John,San Gwann,San Ġwann', 35.9055600, 14.4761100, 'MT', '2012-07-04', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93946, 'Fontana', 'Fontana', 'Fontana', 36.0375000, 14.2361100, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93947, 'Pembroke', 'Pembroke', 'Pembroke,Pembrukas,Pemproouk,pembeulokeu,Πέμπροουκ,پیمبروک، مالٹا,펨브로크', 35.9305600, 14.4763900, 'MT', '2013-08-05', 138);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93836, 'Schoelcher', 'Schoelcher', 'Burg de Case Navire,Case Navire,La case des Navires,Schœlcher', 14.6177400, -61.0990000, 'MQ', '2016-06-08', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93837, 'Saint-Pierre', 'Saint-Pierre', 'Fort Saint Pierre,Sain-Pier,Saint-Pierre,Sen Pjeras,Sen-P''er,Sen-Perr,sheng pi ai er,Σαιν-Πιερ,Сен-Пьер,Сен-Пєрр,سین-پیری، مرتینقے,სენ-პიერი,サン・ピエール,圣皮埃尔', 14.7438300, -61.1753300, 'MQ', '2016-06-08', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93838, 'Saint-Joseph', 'Saint-Joseph', 'Saint-Joseph', 14.6709900, -61.0390500, 'MQ', '2014-09-21', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93839, 'Sainte-Marie', 'Sainte-Marie', 'Bourg de Sainte Marie,Sainte-Marie,Sent-Mari,Сент-Мари', 14.7835200, -60.9922700, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93840, 'Sainte-Luce', 'Sainte-Luce', 'Sainte-Luce', 14.4684800, -60.9213800, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93841, 'Rivière-Pilote', 'Riviere-Pilote', 'River-Pilot,Riviere-Pilote,Rivière-Pilote,rybyyr-pylwt,Ривєр-Пілот,ריבייר-פילוט', 14.4873800, -60.9025700, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93842, 'Le Vauclin', 'Le Vauclin', 'Le Vauclin,Vauclin', 14.5454000, -60.8383100, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93843, 'Les Trois-Îlets', 'Les Trois-Ilets', 'Le-Trua-Ile,Les Trois-Ilets,Les Trois-Îlets,Trois-Ilets,Trois-Îlets,Ле-Труа-Іле', 14.5391200, -61.0335400, 'MQ', '2017-06-06', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93844, 'Saint-Esprit', 'Saint-Esprit', 'Saint Esprit', 14.5500000, -60.9333300, 'MQ', '2008-03-13', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93845, 'Le Robert', 'Le Robert', 'Le Rober,Le Romper,Le-Rober,Robert,lh rwbr,lw rwbr,Λε Ρομπέρ,Ле Робер,Ле-Робер,לה רובר,لو روبر', 14.6775100, -60.9422800, 'MQ', '2009-09-05', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93846, 'Le Morne-Rouge', 'Le Morne-Rouge', 'Morne Rouge', 14.7666700, -61.1333300, 'MQ', '2008-03-13', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93847, 'Le Marin', 'Le Marin', 'Le Maren,Le Marenas,Le Marin,Le-Maren,Marin,Λε Μαρέν,Ле-Марен', 14.4715800, -60.8698900, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93848, 'Le Lorrain', 'Le Lorrain', 'Bourg de la Grande Anse,Grande Anse,Le Lorrain,Lorrain', 14.8329200, -61.0566700, 'MQ', '2016-06-08', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93849, 'Le Lamentin', 'Le Lamentin', 'Lamentin,Le Lamanten,Le Lamenten,Le Lamentin,Le-Lamanten,lw lmwntn,Λε Λαμεντέν,Ле Ламантен,Ле-Ламантен,לה לאמנטין,لو لمونتن', 14.6134100, -60.9996400, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93850, 'Le François', 'Le Francois', 'Francois,François,Le Francois,Le François,Le-Fransua,Ле-Франсуа', 14.6151300, -60.9031100, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93851, 'La Trinité', 'La Trinite', 'La Trinite,La Trinité,Trinite,Trinité', 14.7380700, -60.9631900, 'MQ', '2017-07-04', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93852, 'Le Gros-Morne', 'Le Gros-Morne', '', 14.7000000, -61.0000000, 'MQ', '2011-11-02', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93853, 'Fort-de-France', 'Fort-de-France', 'Arx Gallica,FDF,Fod Fwans,For d''o Frans,For de Frans,For de Fransas,For-de-Frans,For-nte-Frans,Fordefransa,Fort Royal,Fort Royale,Fort-de-France,Fort-de-Frans,Fòd Fwans,Fôrt-de-France,Gorad Fort-deh-Frans,Le Fort-de-France,f xr-dex-fr xngs,fa lan xi bao,foru=do=furansu,fwr dw frans,fwr-dw-frans,phorta-de-phransa,pirancuk kottai,poleudeupeulangseu,por-de-pransi,Φορ-ντε-Φρανς,Горад Форт-дэ-Франс,Фор де Франс,Фор дьо Франс,Фор-де-Франс,Форт-де-Франс,Ֆոր դե Ֆրանս,פור-דה-פראנס,فور دو فرانس,فور-دو-فرانس,فورٹ ڈی فرانس,फोर्ट-दे-फ्रान्स,பிரான்சுக் கோட்டை,ฟอร์-เดอ-ฟร็องส์,ფორ-დე-ფრანსი,フォール＝ド＝フランス,法兰西堡,포르드프랑스', 14.6089200, -61.0733400, 'MQ', '2016-06-08', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93854, 'Ducos', 'Ducos', 'Ducos', 14.5752900, -60.9745300, 'MQ', '2012-01-18', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93855, 'Basse-Pointe', 'Basse-Pointe', 'Basse-Pointe,Bourg de la Basse Pointe', 14.8695400, -61.1150400, 'MQ', '2016-06-08', 140);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93856, 'Zouerate', 'Zouerate', 'Az Zuwayrat,Az Zuwayrāt,Azuwayrat,Azuwayrāt,OUZ,Zoueiratt,Zouerat,Zouerate,Zoueïratt,Zouirat,Zouérat,Zouérate,Zouîrât,Zueratas,Zuerate,Zuwirat,Zuérate,alzwyrat,azwyrat,zueratto,ازويرات,الزويرات,ズエラット', 22.7354200, -12.4713400, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93857, 'Tékane', 'Tekane', 'Tekane,Tiekane,Tiékane,Tékane', 16.5780600, -15.4597200, 'MR', '2013-05-05', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93858, 'Tidjikja', 'Tidjikja', 'Fort Cappolani,TIY,Tidjikdja,Tidjikja,Tijikja', 18.5564400, -11.4271500, 'MR', '2011-02-01', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93859, 'Sélibaby', 'Selibaby', 'SEY,Saylibabi,Saylibābī,Selibabi,Selibaby,Sélibabi,Sélibaby,sylbaby,sylybaby,سيلبابي,سيليبابي', 15.1584600, -12.1843000, 'MR', '2017-06-08', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93860, 'Rosso', 'Rosso', 'Al-Quwarib,Gorad Rosa,Roco,Rosas,Roso,Rosso,loso,luo suo,rosso,rwsw,Горад Роса,Росо,Росо қаласы,روسو,روصو,ロッソ,羅索,로소', 16.5137800, -15.8050300, 'MR', '2013-08-05', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93861, 'Nouakchott', 'Nouakchott', 'Gorad Nuakshot,NKC,Naevakjut,Nawakshot,Nawakszut,Nouakchat,Nouakchot,Nouakchott,Nouaksot,Nouaxot,Nuakchot,Nuakshot,Nuaksjott,Nuaksot,Nuaksota,Nuaksotas,Nuaksoto,Nuaksott,Nuakxot,Nuakŝoto,Nuakşot,Nuakšot,Nuakšota,Nuakšotas,Nuakšott,Nwaqcut,Nwaqcuṭ,Nävakjut,Núaksjott,huo suo,navakasuta,nu wa ke xiao te,nu''akacota,nu''oyakasuta,nuagsyoteu,nuakushotto,nuvakcut,nwakshwt,Νουακσότ,Νουαξότ,Горад Нуакшот,Нуакшот,Նուակշոտ,נואקשוט,نواكشوط,نواکشوت,نواکشوط,نواکشۆت,نوواکوٹ,नवाकसुत,নুওয়াকশুত,ਨੁਆਕਚੋਤ,நுவாக்சூத்,นูแอกชอต,ནའུ་ཀ་ཅོ་ཊི།,ნუაქშოტი,ኑዋክሾት,ヌアクショット,努瓦克肖特,或索,누악쇼트', 18.0858100, -15.9785000, 'MR', '2017-03-22', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93862, 'Nouadhibou', 'Nouadhibou', 'NDB,Nawazibu,Nouadhibou,Nouâdhibou,Nuadibu,Nuadibú,Port Etienne,Port Ettienne,Port-Etienne,Port-Étienne,nwadhybw,Нуадибу,נואדיבו,نواذيبو', 20.9418800, -17.0384200, 'MR', '2016-10-22', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93863, 'Néma', 'Nema', 'An Na`mah,An Na‘mah,EMN,En Na`ma,En Na‘ma,Nema,Néma,النعمة', 16.6170200, -7.2564900, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93864, 'Kiffa', 'Kiffa', 'Gorad Kifa,KFA,Kifa,Kifah,Kiff,Kiffa,Kîfa,Kīfa,Kīfah,ji fa,kifa,kipa,kyft,Горад Кіфа,Киффа,Киффа қаласы,كيفة,کیفہ,キファ,基法,키파', 16.6207300, -11.4020800, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93865, 'Kaédi', 'Kaedi', 'Kaedi,Kaedis,Kaehdi,Kajhajdi,Kayhaydi,Kayhaydī,Kaédi,ka ai di,ka-edi,kaedi,kyhydy,Каэди,Каэди қаласы,קאדי,كيهيدي,کیھیدی,カエディ,卡埃迪,카에디', 16.1502700, -13.5037000, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93866, '’Elb el Jmel', '''Elb el Jmel', '', 17.0105000, -13.9710200, 'MR', '2015-10-19', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93867, 'Chingueṭṭi', 'Chinguetti', 'Chingetti,Chinguetti,Chingueṭṭi,Чингетти', 20.4403600, -12.2622000, 'MR', '2012-01-18', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93868, 'Barkéwol', 'Barkewol', 'Barkeol,Barkewol,Barkéol,Barkéwol', 16.6403900, -12.4984900, 'MR', '2012-01-18', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93869, 'Aioun', 'Aioun', '''Ayoun el ''Atrous,Aioun,Aioun el Atrouss,Al `Ayun,Al `Uyun,Al ‘Ayūn,Al ‘Uyūn,Ayoun El Atrous,Ayoun el Atrous,Ayoûn el Atroûs,Aïoun,Aïoun el Atrouss,La`yun,La‘yūn,Lu`yun,Lu‘yūn,`Ayun al `Atrus,`Uyun al `Atrus,العيون,عيون العتروس,لعيون,‘Ayūn al ‘Atrūs,‘Uyūn al ‘Atrūs,’Ayoûn el ’Atroûs', 16.6614000, -9.6149000, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93870, 'Atar', 'Atar', 'ATR,Atar,Atara,Ataras,Atâr,Atāra,Aţār,Aṭar,Gorad Atar,a ta er,ataleu,atar,ataru,Атар,Горад Атар,أطار,اطار,アタール,阿塔爾,아타르', 20.5177000, -13.0485700, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93871, 'Aleg', 'Aleg', 'Alak,Aleg,Alāk,LEG,alak,ألاك', 17.0531400, -13.9131200, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93872, 'Akjoujt', 'Akjoujt', 'AJJ,Akdzawadzat,Akdżawadżat,Akjoujt,Akjout,Akjujat,Akjūjat,Fort Repoux,akjwjt,أكجوجت', 19.7465700, -14.3853100, 'MR', '2016-01-07', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93873, 'Arafat', 'Arafat', '', 18.0463900, -15.9719400, 'MR', '2017-03-21', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93874, 'Tevragh Zeina', 'Tevragh Zeina', 'Tafragh Zaynah,Tevragh Zeina,Tevragh Zeïna,tfrgh zynh,تفرغ زينه', 18.0989400, -15.9884800, 'MR', '2017-03-21', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93875, 'Dar Naim', 'Dar Naim', '', 18.1080800, -15.9266600, 'MR', '2017-03-21', 141);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93948, 'Verdun', 'Verdun', 'Verdun,Verdun Station', -20.2341700, 57.5547600, 'MU', '2016-07-16', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93949, 'Vacoas', 'Vacoas', 'Phoenix,Vacoa,Vacoas,Vacoas-Phoenix', -20.2980600, 57.4783300, 'MU', '2013-06-05', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93950, 'Triolet', 'Triolet', 'Triolet,Триолет', -20.0547200, 57.5452800, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93951, 'The Vale', 'The Vale', '', -20.0283300, 57.5877800, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93952, 'Terre Rouge', 'Terre Rouge', 'Terre Rouge', -20.1261100, 57.5244400, 'MU', '2016-10-08', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93953, 'Tamarin', 'Tamarin', '', -20.3255600, 57.3705600, 'MU', '2008-03-15', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93954, 'Surinam', 'Surinam', '', -20.5097200, 57.5052800, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93955, 'Souillac', 'Souillac', 'Port Souillac,Soullac', -20.5166700, 57.5166700, 'MU', '2008-03-15', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93956, 'Sebastopol', 'Sebastopol', '', -20.2907000, 57.6877900, 'MU', '2016-09-26', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93957, 'Saint Pierre', 'Saint Pierre', 'Saint Pierre,Saint Pierre Village', -20.2175000, 57.5208300, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93958, 'Saint Julien', 'Saint Julien', 'Julien,Saint Julien,Saint Julien Village', -20.2263900, 57.6363900, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93959, 'Saint Hubert', 'Saint Hubert', '', -20.3641700, 57.6383300, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93960, 'Saint Aubin', 'Saint Aubin', 'Saint Aubin,Sent-Oben,Union Saint Aubin,Сент-Обен', -20.4960000, 57.5500000, 'MU', '2013-08-24', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93961, 'Morcellemont Saint André', 'Morcellemont Saint Andre', 'Morcellemont Saint Andre,Morcellemont Saint André,Saint-Andre,Saint-André', -20.0730600, 57.5580600, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93962, 'Rose Belle', 'Rose Belle', 'Roz-Bel'',Роз-Бель', -20.4002800, 57.5966700, 'MU', '2013-08-24', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93963, 'Roche Terre', 'Roche Terre', '', -20.0186100, 57.6447200, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93964, 'Roches Noire', 'Roches Noire', 'Roche Noire,Roche Noires,Roches Noire,Roches Noires', -20.1111100, 57.7122200, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93965, 'Grande Rivière Noire', 'Grande Riviere Noire', 'Black River,Grand Riviere Noire,Grand Rivière Noire,Grande Riviere Noire,Grande Rivière Noire,Riviere Noire,Rivière Noire', -20.3602800, 57.3661100, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93966, 'Rivière du Rempart', 'Riviere du Rempart', '', -20.1030600, 57.6847200, 'MU', '2012-01-14', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93967, 'Rivière des Anguilles', 'Riviere des Anguilles', 'River des Anguilles,River-dez-Angij,Riviere des Anguilles,Rivière des Anguilles,Ривер-дез-Ангий', -20.4852800, 57.5508300, 'MU', '2013-08-24', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93968, 'Queen Victoria', 'Queen Victoria', '', -20.2200000, 57.7075000, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93969, 'Quatre Soeurs', 'Quatre Soeurs', 'La Coterie,Quatre Soeurs,Quatre Soeurs Br.', -20.2991700, 57.7705600, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93970, 'Quatre Bornes', 'Quatre Bornes', 'Quatre Bornes', -20.2638100, 57.4791000, 'MU', '2012-05-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93971, 'Quartier Militaire', 'Quartier Militaire', 'Quartier Militaire', -20.2479000, 57.5973700, 'MU', '2016-07-16', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93972, 'Providence', 'Providence', '', -20.2447200, 57.6122200, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93973, 'Poste de Flacq', 'Poste de Flacq', 'Post of Flacq,Poste de Flacq', -20.1630600, 57.7305600, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93974, 'Port Louis', 'Port Louis', 'Bort Lois,Gorad Port-Lui,Po-Loui,Por Loui,Por-Loui,Port Lois,Port Louis,Port Louis Town,Port Lui,Port Luis,Port Luisas,Port Luiz,Port-Louis,Port-Lui,Port-Luiso,Port-lui,Portlui,Portluī,Portus Ludovici,Puerto Louis,Pò-Loui,bwr lwys,lu yi gang,phxrt hluys,porata lu''i,port luyis,porta lu''i,porta lu''isa,poteulu-iseu,potoruisu,pwr lwʼy,Πορ Λουί,Πορ-Λουί,Горад Порт-Луі,Порт Луи,Порт Луис,Порт-Луи,Порт-Луї,Պորտ Լուի,פור לואי,بور لويس,پورت‌لوئیس,پورٹ لوئس,پورٹ لوئی,پۆرت لویس,पोर्ट लुई,पोर्ट लुईस,পোর্ট লুইস,ਪੋਰਟ ਲੂਈ,ପୋର୍ଟ ଲୁଇସ,போர்ட் லூயிஸ்,പോർട്ട് ലൂയിസ്,พอร์ตหลุยส์,ལོ་ཡི་སི་གྲུ་ཁ།,პორტ-ლუი,ፖርት ሉዊስ,ポートルイス,路易港,포트루이스', -20.1619400, 57.4988900, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93975, 'Plaine Magnien', 'Plaine Magnien', 'Plaine Magnien,Plaines Magnien', -20.4296700, 57.6696800, 'MU', '2014-08-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93976, 'Plaine des Papayes', 'Plaine des Papayes', 'Plaine des Papayes,Plaines des Papayes', -20.0650000, 57.5725000, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93977, 'Petit Raffray', 'Petit Raffray', '', -20.0133300, 57.6119400, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93978, 'Petite Rivière', 'Petite Riviere', 'Ptit-Riv''er,Птит-Ривьер', -20.1955100, 57.4459200, 'MU', '2013-08-25', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93979, 'Petite Case Noyale', 'Petite Case Noyale', '', -20.3930600, 57.3650000, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93980, 'Pamplemousses', 'Pamplemousses', 'Pamplemousses,Pamplemousses Village', -20.1038900, 57.5702800, 'MU', '2013-07-10', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93981, 'Pailles', 'Pailles', 'Pailles,Pailles Village,mauvilac', -20.1927100, 57.4882600, 'MU', '2011-04-13', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93982, 'Olivia', 'Olivia', 'Oliva,Olivia', -20.2877800, 57.7309700, 'MU', '2016-09-26', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93983, 'Nouvelle France', 'Nouvelle France', '', -20.3705600, 57.5611100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93984, 'Notre Dame', 'Notre Dame', 'Notre Dame,Notre Dame Station', -20.1405600, 57.5530600, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93985, 'New Grove', 'New Grove', 'New Grove,New Grove Station', -20.4086100, 57.6136100, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93986, 'Piton', 'Piton', 'Mont Piton,Piton', -20.0902800, 57.6302800, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93987, 'Montagne Blanche', 'Montagne Blanche', 'Blanche Mont,Mont Blanche,Montagne Blanche', -20.2853800, 57.6586500, 'MU', '2016-09-26', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93988, 'Moka', 'Moka', 'Moka,Moka Village', -20.2188900, 57.4958300, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93989, 'Midlands', 'Midlands', '', -20.3190700, 57.5701600, 'MU', '2015-12-13', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93990, 'Melrose', 'Melrose', '', -20.2697200, 57.6319400, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93991, 'Mahébourg', 'Mahebourg', 'Mahebourg,Mahébourg', -20.4080600, 57.7000000, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93992, 'Long Mountain', 'Long Mountain', 'Long Mountain,Mont Longue', -20.1430600, 57.5622200, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93993, 'Lalmatie', 'Lalmatie', '', -20.1897200, 57.6611100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93994, 'Dagotière', 'Dagotiere', 'Dagotiere,Dagotière,La Dagotiere,La Dagotière', -20.2447600, 57.5618800, 'MU', '2016-07-16', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93995, 'Grand Sable', 'Grand Sable', '', -20.3141700, 57.7644400, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93996, 'Grande Rivière Sud Est', 'Grande Riviere Sud Est', 'Grand River,Grand River South East,Grande Reviere Sud Est,Grande Riviere Sud Est,Grande Rivière Sud Est', -20.2861100, 57.7758300, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93997, 'Grand Gaube', 'Grand Gaube', 'Grand Gaube,Grande Gaube', -20.0063900, 57.6608300, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93998, 'Grand Baie', 'Grand Baie', 'Grand Baie,Grande Baie', -20.0181600, 57.5801500, 'MU', '2011-04-13', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93999, 'Grand Bois', 'Grand Bois', 'Gran-Bua,Grand Bois,Гран-Буа', -20.4188900, 57.5441700, 'MU', '2013-09-07', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94000, 'Goodlands', 'Goodlands', 'Goodlands', -20.0350000, 57.6430600, 'MU', '2012-02-02', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94001, 'Fond du Sac', 'Fond du Sac', 'Fond du Sac', -20.0430600, 57.5786100, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94002, 'Flic en Flac', 'Flic en Flac', 'Flic en Flac,Flic-en-Flacq', -20.2741700, 57.3630600, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94003, 'Espérance Trébuchet', 'Esperance Trebuchet', 'Esperance,Esperance Trebuchet,Espérance,Espérance Trébuchet', -20.0697200, 57.6419400, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94004, 'Curepipe', 'Curepipe', 'Curepipe,K''jurpajp,Kiurpipas,Kjurpajp,Kjurpip,ju er pi pu,kulepipe,kur pip,kwrybyb,kyurupippu,Кьюрпайп,Кюрпип,Кјурпајп,كوريبيب,کیورپیپہ,กูร์ปีป,キュールピップ,居爾皮普,쿠레피페', -20.3147200, 57.5202800, 'MU', '2013-08-25', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94005, 'Crève Coeur', 'Creve Coeur', '', -20.1911100, 57.5572200, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94006, 'Clémencia', 'Clemencia', '', -20.2638900, 57.7061100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94007, 'Chemin Grenier', 'Chemin Grenier', 'Chemin Grenier,Shmen-Gren''e,Шмен-Гренье', -20.4872200, 57.4655600, 'MU', '2013-08-24', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94008, 'Chamouny', 'Chamouny', '', -20.4822200, 57.4661100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94009, 'Centre de Flacq', 'Centre de Flacq', 'Centre of Flacq,Flacq', -20.1897200, 57.7144400, 'MU', '2008-03-15', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94010, 'Cascavelle', 'Cascavelle', '', -20.2869400, 57.4072200, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94011, 'Cap Malheureux', 'Cap Malheureux', 'Cap Malheureux', -19.9841700, 57.6141700, 'MU', '2012-05-05', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94012, 'Camp Thorel', 'Camp Thorel', 'Camp Thorel,Camp Thoret', -20.2147200, 57.6161100, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94013, 'Camp Diable', 'Camp Diable', '', -20.4627800, 57.5788900, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94014, 'Camp de Masque', 'Camp de Masque', 'Camp de Masque,Camp de Masque Station', -20.2369400, 57.6633300, 'MU', '2012-01-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94015, 'Brisée Verdière', 'Brisee Verdiere', '', -20.1638900, 57.6466700, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94016, 'Bon Accueil', 'Bon Accueil', '', -20.1708300, 57.6563900, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94017, 'Bois des Amourettes', 'Bois des Amourettes', '', -20.3630600, 57.7311100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94018, 'Bel Air Rivière Sèche', 'Bel Air Riviere Seche', 'Bel Air Riviere Seche,Bel Air Rivière Sèche', -20.2577700, 57.7497600, 'MU', '2014-05-18', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94019, 'Beau Vallon', 'Beau Vallon', 'Beau Vallon,Beau-Vallon', -20.4188900, 57.6952800, 'MU', '2013-07-05', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94020, 'Beau Bassin', 'Beau Bassin', 'Beau Bassin', -20.2194400, 57.4583300, 'MU', '2016-05-03', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94021, 'Albion', 'Albion', '', -20.2116700, 57.4008300, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94022, 'Laventure', 'Laventure', '', -20.1458300, 57.6766700, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94023, 'Cluny', 'Cluny', '', -20.3669400, 57.6038900, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94024, 'Cottage', 'Cottage', '', -20.0597200, 57.6291700, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94025, 'Grande Pointe aux Piments', 'Grande Pointe aux Piments', '', -20.0627800, 57.5130600, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94026, 'Congomah', 'Congomah', '', -20.1488900, 57.5908300, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94027, 'Amaury', 'Amaury', '', -20.1308300, 57.6591700, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94028, 'Plaines des Roches', 'Plaines des Roches', '', -20.1116700, 57.6908300, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94029, 'Mare La Chaux', 'Mare La Chaux', '', -20.1980600, 57.7494400, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94030, 'Quatre Cocos', 'Quatre Cocos', 'Quatre Cocos', -20.2077800, 57.7625000, 'MU', '2016-03-10', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94031, 'Camp Ithier', 'Camp Ithier', '', -20.2158300, 57.7455600, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94032, 'Ecroignard', 'Ecroignard', '', -20.2261100, 57.7361100, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94033, 'Bambous Virieux', 'Bambous Virieux', '', -20.3427800, 57.7575000, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94034, 'Ebene', 'Ebene', 'Ebene City,Ebene CyberCity', -20.2449400, 57.4916300, 'MU', '2014-08-11', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94035, 'Gros Cailloux', 'Gros Cailloux', '', -20.2072200, 57.4300000, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94036, 'Mapou', 'Mapou', 'Mapou', -20.0758300, 57.6013900, 'MU', '2012-01-20', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94037, 'Dubreuil', 'Dubreuil', '', -20.3013200, 57.5986100, 'MU', '2015-08-20', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94038, 'Le Hochet', 'Le Hochet', 'Le Hochet', -20.1350000, 57.5211100, 'MU', '2016-03-10', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94039, 'Calebasses', 'Calebasses', '', -20.1116700, 57.5538900, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94040, 'Arsenal', 'Arsenal', '', -20.1055600, 57.5352800, 'MU', '2006-01-17', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94041, 'Port Mathurin', 'Port Mathurin', 'Port Mathurin', -19.6833300, 63.4166700, 'MU', '2013-08-05', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94042, 'Baie aux Huîtres', 'Baie aux Huitres', 'Baie aux Huitres,Baie aux Huîtres,Oyster Bay', -19.6944400, 63.4083300, 'MU', '2013-05-05', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94043, 'Cargados Carajos', 'Cargados Carajos', 'Saint Brandon', -16.6032900, 59.6585100, 'MU', '2013-07-10', 142);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94103, 'Cuauhtémoc', 'Cuauhtemoc', 'Cuauhtemoc,Cuauhtémoc', 22.5440800, -98.1507400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94104, 'Santa Martha', 'Santa Martha', '', 22.3427800, -98.7063900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94105, 'Xicoténcatl', 'Xicotencatl', 'Xicohtencatl,Xicohténcatl,Xicotencate,Xicotencatl,Xicoténcatl', 22.9962300, -98.9421800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94106, 'San Fernando', 'San Fernando', 'San Fernando,San Fernando de Presas', 24.8474900, -98.1482800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94107, 'El Control', 'El Control', 'Control Cik,El Control', 25.9586700, -97.8128100, 'MX', '2015-01-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94108, 'Ciudad Díaz Ordaz', 'Ciudad Diaz Ordaz', 'Ciudad Diaz Ordaz,Ciudad Díaz Ordaz,Gustavo Diaz Ordaz,Gustavo Díaz Ordaz,San Miguel de Camargo', 26.2318600, -98.5956000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94109, 'Nueva Primavera', 'Nueva Primavera', 'Nueva Primavera', 21.9134200, -98.8578500, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94110, 'Tamcuime', 'Tamcuime', '', 21.6013700, -99.0107700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94111, 'Tampate', 'Tampate', 'Tampate,Tampote', 21.6363900, -99.0255200, 'MX', '2014-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94112, 'Zumpango', 'Zumpango', 'NLU,Zumpango,Zumpango de Ocampo,Zumpango-de-Okampo,Зумпанго-де-Окампо', 19.7967000, -99.0994600, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94113, 'Zumpango del Río', 'Zumpango del Rio', 'Xumpango,Zumpango,Zumpango del Rio,Zumpango del Río,Zumpango-del''-Rio,Зумпанго-дель-Рио', 17.6543700, -99.5272500, 'MX', '2016-02-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94114, 'Zumpahuacán', 'Zumpahuacan', 'Zumpahuacan,Zumpahuacán', 18.9164200, -99.5656800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94115, 'Zozocolco de Hidalgo', 'Zozocolco de Hidalgo', 'Bozocalco,Zozocolco,Zozocolco de Hidalgo', 20.1404800, -97.5756700, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94116, 'Zoquitlán', 'Zoquitlan', 'Zoquitlan,Zoquitlán', 18.3352300, -97.0174500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94117, 'Zoquiopan', 'Zoquiopan', 'Zoquiapan,Zoquiopan', 20.0089800, -97.5960600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94118, 'Zoogocho', 'Zoogocho', 'San Bartolome,San Bartolome Zoogocho,San Bartolomé Zoogocho,Zoogoche,Zoogocho', 17.2400900, -96.2429900, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94119, 'Zongozotla', 'Zongozotla', 'Zongozotla', 19.9793000, -97.7275100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94120, 'Zongolica', 'Zongolica', 'Zongolica', 18.6667300, -96.9970700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94121, 'Santa María Zolotepec', 'Santa Maria Zolotepec', 'Santa Maria Zolotepec,Santa María Zolotepec,Zolotepec', 19.4172800, -99.4932700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94122, 'Zitlala', 'Zitlala', 'Zitlala', 17.6904900, -99.1864200, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94123, 'Zinacantán', 'Zinacantan', 'Zinacantan,Zinacantán,Zinacatan,Zinacatán', 16.7602000, -92.7225700, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94124, 'Zimatlán de Álvarez', 'Zimatlan de Alvarez', 'Zimatlan,Zimatlan de Alvarez,Zimatlán,Zimatlán de Álvarez', 16.8693900, -96.7843500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94125, 'Zimapan', 'Zimapan', 'Zimapan,Zimapán', 20.7381400, -99.3818000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94126, 'Zempoala', 'Zempoala', 'Zempoala', 19.9158700, -98.6660000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94127, 'Villa Zempoala', 'Villa Zempoala', 'Villa Zempoala,Zempoala', 19.4442200, -96.4077300, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94128, 'General Zaragoza', 'General Zaragoza', 'General Zaragoza,Zaragoza', 23.9731900, -99.7723300, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94129, 'Zaragoza', 'Zaragoza', '', 21.2797500, -97.7205500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94130, 'Zaragoza', 'Zaragoza', 'Zaragosa,Zaragoza', 19.7709700, -97.5550600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94131, 'Zaragoza de Guadalupe', 'Zaragoza de Guadalupe', 'Zaragoza,Zaragoza de Guadalupe', 19.1483000, -99.6440500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94132, 'Zapotlán de Juárez', 'Zapotlan de Juarez', 'Zapotlan,Zapotlan de Juarez,Zapotlán,Zapotlán de Juárez', 19.9770900, -98.8642000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94133, 'Zapotitlán', 'Zapotitlan', 'Salinas,Zapotitlan,Zapotitlan Salinas,Zapotitlán,Zapotitlán Salinas', 18.3296000, -97.4739900, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94134, 'Zapotitlán Palmas', 'Zapotitlan Palmas', 'Palmas,Zapotitlan,Zapotitlan Palmas,Zapotitlán Palmas', 17.8896500, -97.8184900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94135, 'Zacualtipán', 'Zacualtipan', 'Zacualtipan,Zacualtipán', 20.6500200, -98.6562800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94136, 'Zacualpan', 'Zacualpan', 'Zacoalpan,Zacualpan', 18.7189500, -99.7760500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94137, 'Zacatlán', 'Zacatlan', 'Sakatlan,Zacatlan,Zacatlan de las Manzanas,Zacatlán,Zacatlān,Сакатлан', 19.9355000, -97.9612500, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94138, 'Zacatepec', 'Zacatepec', 'Zacatepec', 19.2663100, -97.5328000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94139, 'Zacatepec', 'Zacatepec', 'Zacatepec,Zacatepec de Hidalgo', 18.6540900, -99.1898100, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94140, 'Zacapoaxtla', 'Zacapoaxtla', 'Sakapoastla,Zacapoaxtla,Сакапоастла', 19.8727100, -97.5889900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94141, 'Zacapala', 'Zacapala', 'San Juan Evangelista Zacapala,Zacalapa,Zacapala', 18.5941500, -98.0658300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94142, 'Zacamixtle', 'Zacamixtle', 'Zacamixtle,Zacamuixtle', 21.2476200, -97.7215500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94143, 'Villa de Zaachila', 'Villa de Zaachila', 'Opstina Villa de Zaachila,Opština Villa de Zaachila,Villa de Zaachila,Zaachila', 16.9509800, -96.7493800, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94144, 'Yucuyachi', 'Yucuyachi', 'Santiago Yucuyachi,Yucuyachi', 17.6085800, -98.1967500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94145, 'San Pedro Mártir Yucuxaco', 'San Pedro Martir Yucuxaco', 'San Pedro Martir Yucuxaco,San Pedro Mártir Yucuxaco,Yucuxaca,Yucuxaco', 17.4324500, -97.6110000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94146, 'Santiago Yogana', 'Santiago Yogana', 'Santiago Yogana,Yogana', 16.4613000, -96.7878600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94147, 'Magdalena Yodocono de Porfirio Díaz', 'Magdalena Yodocono de Porfirio Diaz', 'Magdalena Yodocono de Porfirio Diaz,Magdalena Yodocono de Porfirio Díaz,Yadocono de Porfirio Diaz,Yodocono,Yodocono de Porfirio Diaz,Yodocono de Porfirio Díaz', 17.3847000, -97.3553000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94148, 'San Agustín Yatareni', 'San Agustin Yatareni', 'San Agustin Yatareni,San Agustín Yatareni,Yelateni', 17.0819800, -96.6657800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94149, 'Yehualtepec', 'Yehualtepec', 'San Simon,San Simón,Yehualtepec', 18.7951800, -97.6616000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94150, 'Yecuatla', 'Yecuatla', 'Yecuatla', 19.8661400, -96.7783600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94151, 'Yecapixtla', 'Yecapixtla', 'Yacapitztla,Yecapixilac,Yecapixtla', 18.8833300, -98.8650000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94152, 'Yaxkukul', 'Yaxkukul', 'Yaxkukul', 21.0613900, -89.4193200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94153, 'Yaxe', 'Yaxe', 'Yaxe', 16.7259500, -96.4719100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94154, 'Yaxcabá', 'Yaxcaba', 'San Pedro Yaxcaba,Yaxcaba,Yaxcabá', 20.5484600, -88.8271400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94155, 'Yautepec', 'Yautepec', '', 18.8818800, -99.0671500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94156, 'Yatzachi', 'Yatzachi', 'San Baltasar Yatzachi el Bajo,San Baltazar Yatzachi el Bajo,Yatzachi,Yatzachi el Bajo', 17.2258800, -96.2213700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94157, 'Yaonahuac', 'Yaonahuac', 'Yaonahuac,Yaonáhuac', 19.8707600, -97.4658700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94158, 'Yanga', 'Yanga', 'San Lorenzo,San Lorenzo Yanga,San Lorenzo de Cerralvo,Yanga', 18.8328800, -96.7983700, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94159, 'Yajalón', 'Yajalon', 'Yajalon,Yajalón', 17.1727600, -92.3331500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94160, 'Xoxolpa', 'Xoxolpa', 'Xoxolpa', 20.8757400, -98.4238600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94161, 'Xoxocotla', 'Xoxocotla', 'Xoxocotla', 18.6841500, -99.2457700, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94162, 'Xopilapa', 'Xopilapa', '', 18.5047200, -97.0794400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94163, 'Xonacatlán', 'Xonacatlan', 'San Francisco,San Francisco Xonacatlan,San Francisco Xonacatlán,Xonacatlan,Xonacatlan de Vicencio,Xonacatlán,Xonacatlán de Vicencio,Xonacaxtlan,Xonacaxtlán', 19.4051300, -99.5280700, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94164, 'Xometla', 'Xometla', 'Xametla,Xometla', 19.6428100, -98.8817100, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94165, 'Xocotla', 'Xocotla', 'Xocotla', 19.0151100, -97.1009200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94166, 'Xochitlan Todos Santos', 'Xochitlan Todos Santos', 'Xochitlan,Xochitlan Todos Santos,Xochitlán', 18.7039500, -97.7760900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94167, 'Xochitepec', 'Xochitepec', 'Xochiltepec,Xochitepec', 18.7808000, -99.2304900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94168, 'Xochistlahuaca', 'Xochistlahuaca', 'Xochistlahuaca', 16.7891500, -98.2417200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94169, 'Xochimilco', 'Xochimilco', 'Delegacion Xochimilco,Delegación Xochimilco,Xochimilco', 19.2546500, -99.1035600, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94170, 'Xochiltepec', 'Xochiltepec', 'San Felipe Xochiltepec,Xochiltepec', 18.6509500, -98.3445000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94171, 'Xochihuehuetlán', 'Xochihuehuetlan', 'Xochihuehuetlan,Xochihuehuetlán', 17.9061900, -98.4881800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94172, 'Xilitla', 'Xilitla', 'Xililla,Xilitla', 21.3868100, -98.9900900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94173, 'Xicotepec de Juárez', 'Xicotepec de Juarez', 'Juarez Xicotepec,Juárez Xicotepec,Villa Juarez,Villa Juárez,Xicotepec de Juarez,Xicotepec de Juárez', 20.2760500, -97.9611100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94174, 'Xico', 'Xico', 'Jico,Xico', 19.4217800, -97.0081900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94175, 'San Miguel Xico Viejo', 'San Miguel Xico Viejo', 'San Miguel Xico,San Miguel Xico Viejo,Xico', 19.2702200, -98.9358800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94176, 'Xayacatlán de Bravo', 'Xayacatlan de Bravo', 'Xayacatlan,Xayacatlan de Bravo,Xayacatlán,Xayacatlán de Bravo,Zayacatlan de Bravo,Zayacatlán de Bravo', 18.2371200, -97.9752400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94177, 'Santa María Xadani', 'Santa Maria Xadani', 'Santa Maria Xadani,Santa Maria Xandani,Santa María Xadani,Santa María Xandani,Xadani,Xandani', 16.3619800, -95.0182600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94178, 'Xaltianguis', 'Xaltianguis', 'Jaltianguis,Xaltianguis', 17.0983400, -99.7155700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94179, 'Xaltepuxtla', 'Xaltepuxtla', 'Xaltepaxtla,Xaltepuxtla', 20.1754600, -97.9720800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94180, 'Xaltepec', 'Xaltepec', 'San Miguel Xaltepec,Xaltepec,Xultepec', 18.8816300, -97.6082500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94181, 'Xalpatlahuac', 'Xalpatlahuac', 'Xalpatlahuac', 17.4706600, -98.6067500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94182, 'Xaloztoc', 'Xaloztoc', 'San Cosme,San Cosme Xalostoc,Xalostoc,Xaloxtoc,Xaloztoc', 19.4077500, -98.0460200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94183, 'Santa Ana Xalmimilulco', 'Santa Ana Xalmimilulco', 'Santa Ana Xalmimilulco,Xalmimilulco,Xalminilulco', 19.2128700, -98.3820700, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94184, 'Vista Hermosa', 'Vista Hermosa', 'Colonia Vista Hermosa,Vista Hermosa', 19.5161600, -99.2233500, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94185, 'San Antonio Virreyes', 'San Antonio Virreyes', 'San Antonio Virreyes,Virreyes', 19.4098900, -97.6369700, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94186, 'Villa Victoria', 'Villa Victoria', 'Villa Victoria', 19.4369300, -99.9958900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94187, 'Camarón de Tejeda', 'Camaron de Tejeda', 'Camaron,Camaron de Tejeda,Camarón,Camarón de Tejeda,Villa Teieda,Villa Tejeda', 19.0216600, -96.6151300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94188, 'Álvaro Obregón', 'Alvaro Obregon', 'Alvaro Obregon,Obergen Villa,Obrogen Villa,San Angel,Villa Obregon,Villa Obregón,Álvaro Obregón', 19.3586700, -99.2032900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94189, 'Villahermosa', 'Villahermosa', 'Cualnezcaltepec,VSA,Vil''jaehrmosa,Vilaermosa,Viljaermosa,Viljahermosa,Villa Hermosa,Villahermosa,bi ya ai er mo sa,biya-eleumosa,biyaerumosa,byayrmwsa,fylahyrmwsa,viliaermosa,wylahrmsa  tabaskw,Вильяэрмоса,Виляермоса,Виљаермоса,וייארמוסה,بیائرموسا,فيلاهيرموسا,ویلاهرمسا، تاباسکو,ვილიაერმოსა,ビヤエルモサ,比亚埃尔莫萨,비야에르모사', 17.9868900, -92.9302800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94190, 'Gustavo Adolfo Madero', 'Gustavo Adolfo Madero', 'Delegacion Gustavo A. Madero,Delegación Gustavo A. Madero,Guadalupe,Guadalupe Hidalgo,Gustavo A. Madero,Gustavo Adolfo Madero,Villa Gustavo A. Madero,Villa Madero,Villa de Guadalupe,Villa de Guadalupe Hidalgo', 19.4939200, -99.1107500, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94191, 'Villa Guerrero', 'Villa Guerrero', 'Tecualaya,Villa Guerrero', 18.9621100, -99.6406100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94192, 'El Triunfo', 'El Triunfo', 'El Triunfo,Villa el Triunfo', 17.9224100, -91.1694600, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94193, 'Villa del Carbón', 'Villa del Carbon', 'Villa del Carbon,Villa del Carbón', 19.7287500, -99.4636200, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94194, 'Villa Cuauhtemoc', 'Villa Cuauhtemoc', 'Cuauhtemoc,Cuauhtémoc,Pueblo Viejo,Villa Cuauhtemoc,Villa Cuauhtémoc', 22.1843900, -97.8347200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94195, 'Villa Cuauhtémoc Otzolotepec', 'Villa Cuauhtemoc Otzolotepec', 'Cuauhtemoc,Cuauhtémoc,Villa Cuauhtemoc,Villa Cuauhtemoc Otzolotepec,Villa Cuauhtémoc,Villa Cuauhtémoc Otzolotepec,Villa Cuautemoc', 19.4167600, -99.5587200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94196, 'Villa Corzo', 'Villa Corzo', 'Angel Albino Corzo,Villa Corzo', 16.1851000, -93.2688100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94197, 'Villa Comaltitlán', 'Villa Comaltitlan', 'Pubelo Nuevo,Pueblo Nuevo,Pueblo Nuevo Comaltitlan,Pueblo Nuevo Comaltitlán,Villa Comaltitlan,Villa Comaltitlán', 15.2139700, -92.5765900, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94198, 'Tesechoacan', 'Tesechoacan', 'Tesechoacan,Villa Azueta', 18.1374900, -95.6583500, 'MX', '2014-07-21', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94199, 'Villa Aldama', 'Villa Aldama', 'Villa Aldama', 19.6486100, -97.2233300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94200, 'Veracruz', 'Veracruz', 'Chalchiuhcuehcan,Chalchiuhcuehcān,Heroica Veracruz,VER,Veracruz,Veracruz Llave,Veracruz i Veracruz,Verakrus,Verakrusas,Verakruz,belakeuluseu,berakrutha,berakurusu,verakurucu,wei la ke lu si,wer a kru s,wrakrws,Веракруз,Веракрус,وراکروس,बेराक्रुथ,வேராகுரூசு,เวรากรุซ,ვერაკრუსი,ベラクルス,韦拉克鲁斯,베라크루스', 19.1809500, -96.1429000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94201, 'Venustiano Carranza', 'Venustiano Carranza', 'San Bartolo,San Bartolome,San Bartolomé,Venustiano Carranza', 16.3381500, -92.5630000, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94202, 'Veinte de Noviembre', 'Veinte de Noviembre', 'Veinte de Noviembre', 14.9773000, -92.2650900, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94203, 'Vega de Alatorre', 'Vega de Alatorre', 'Vega de Alatorre', 20.0282300, -96.6475100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94204, 'Valle Hermoso', 'Valle Hermoso', 'Valle Hermoso', 25.6720700, -97.8131300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94205, 'Valladolid', 'Valladolid', 'Val''jadolid,Valadoli,Valadolid,Vaładołì,ba li ya duo li de,Вальядолид,Вальядолід,Ваљадолид,巴利亚多利德', 20.6881200, -88.1993600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94206, 'Úrsulo Galván', 'Ursulo Galvan', 'San Carlos,Ursulo Galvan,Úrsulo Galván', 19.4053100, -96.3609000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94207, 'Unión Hidalgo', 'Union Hidalgo', '', 16.4723000, -94.8295200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94208, 'Uman', 'Uman', 'San Antonio Tedzidz,Uman,Uman'',Умань', 20.8821300, -89.7464900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94209, 'Ucú', 'Ucu', 'Ucu,Ucú', 21.0313500, -89.7446600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94210, 'Uayma', 'Uayma', 'Uayma,Uaymá', 20.7178100, -88.3169300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94211, 'Tzucacab', 'Tzucacab', 'Tzucacab,Tzucaceb', 20.0723700, -89.0502200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94212, 'San Salvador Tzompantepec', 'San Salvador Tzompantepec', 'San Salvador Tzompantepec,San Salvador Tzompatepec,Tezonpantepec,Tzompantepec', 19.3722000, -98.0870100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94213, 'Tzinacapan', 'Tzinacapan', 'Tzinacapan', 20.0294400, -97.5404700, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94214, 'Tzimol', 'Tzimol', '', 16.2666700, -92.2666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94215, 'Tuzantán', 'Tuzantan', 'Tuzantan,Tuzantan de Morelos,Tuzantán,Tuzantán de Morelos,Tuzatan,Tuzatán', 15.1471100, -92.4223700, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94216, 'Tuzamapan', 'Tuzamapan', 'Tuzamapan,Tuzamapan de Galeana', 20.0657200, -97.5752000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94217, 'Tuzamapan', 'Tuzamapan', 'Tuzamapan,Tuzanapan', 19.4025300, -96.8636000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94218, 'Tuxtla', 'Tuxtla', 'Gutierrez,TGZ,Tochtlan Gutierrez,Tochtlan Gutiérrez,Touxtla Nkoutierres,Tukstla Gutijerez,Tustla Gutieres,Tustla Gutjeresas,Tustla-Gut''erres,Tuxtla,Tuxtla Gtz,Tuxtla Gtz.,Tuxtla Gutierres,Tuxtla Gutierrez,Tuxtla Gutiérrez,tu si te la gu tie lei si,tugseuteullagutieleseu,tus tla ku ti xerres,twksla gwtyrs. chyapas,twkstla ghwtyryz,twstla gywtyrs,twstlh gwtyyrs,Τούξτλα Γκουτιέρρες,Тукстла Гутијерез,Тустла Гутиерес,Тустла-Гутьеррес,Тустла-Ґутьєррес,טוסטלה גוטיירס,توستلا گیوتیرس,توكستلا غوتيريز,توکسلا گوتیرس٬ چیاپاس,ตุซตลากูตีเอร์เรซ,ტუსტლა-გუტიერესი,トゥストラ・グティエレス,图斯特拉古铁雷斯,툭스틀라구티에레스', 16.7597300, -93.1130800, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94219, 'Tuxtla Chico', 'Tuxtla Chico', 'Tuxtla Chico', 14.9394500, -92.1673000, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94220, 'Tuxtla', 'Tuxtla', 'Tuxtla', 20.0003700, -97.6552600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94221, 'Túxpam de Rodríguez Cano', 'Tuxpam de Rodriguez Cano', 'Tuxpam,Tuxpam de Rodriguez Cano,Tuxpan,Tuxpan de Rodriguez Cano,Tuxpan de Rodríguez Cano,Túxpam,Túxpam de Rodríguez Cano', 20.9577700, -97.4080500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94222, 'Tunkas', 'Tunkas', 'Tunkas,Tunkás', 20.9029400, -88.7517100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94223, 'Tulum', 'Tulum', 'TUY,Tulum,Tulun,Tulún', 20.2117300, -87.4632500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94224, 'Tultitlán', 'Tultitlan', 'Tul''titlan,Tultitla de Mariano Escobedo,Tultitlan,Tultitlá de Mariano Escobedo,Tultitlán,Тультитлан', 19.6465500, -99.1678700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94225, 'Tultepec', 'Tultepec', 'San Pedro de Tultepec,Tultepec', 19.6850000, -99.1280600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94226, 'Tulcingo de Valle', 'Tulcingo de Valle', 'Tulcingo,Tulcingo de Valle,Tulcingo del Valle', 18.0437000, -98.4407400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94227, 'Tulancingo', 'Tulancingo', 'Tulancingo,Tulancingo de Bravo', 20.0835500, -98.3628800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94228, 'Tula de Allende', 'Tula de Allende', 'El Tule,Tula,Tula de Allende,Tula-de-Al''ende,Тула-де-Альенде', 20.0516100, -99.3439700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94229, 'Tula', 'Tula', '', 22.9964500, -99.7117100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94230, 'Trinidad Zaachila', 'Trinidad Zaachila', 'Trinidad,Trinidad Zaachila,Trinidad de Zaachila,Zaachila,Zoochila', 16.9213500, -96.7638400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94231, 'Tres Picos', 'Tres Picos', 'La Tigrera,Tres Picos', 15.8820900, -93.5286700, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94232, 'Trapiche del Rosario', 'Trapiche del Rosario', '', 19.5430600, -96.7411100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94233, 'Totutla', 'Totutla', 'Tolutla,Totutla', 19.2116900, -96.9611800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94234, 'Totontepec Villa de Morelos', 'Totontepec Villa de Morelos', 'Santa Maria Totontepec Villa de Zertuche,Santa María Totontepec Villa de Zertuche,Totontepec,Totontepec Villa de Morelos', 17.2567900, -96.0278600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94235, 'Totoltepec de Guerrero', 'Totoltepec de Guerrero', 'Totoltepec,Totoltepec de Guerrero', 18.2256000, -97.8551100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94236, 'Totolapan', 'Totolapan', 'Totolapan', 18.9848700, -98.9207300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94237, 'Totolapa', 'Totolapa', 'Totolapa', 16.5435700, -92.6801900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94238, 'San Miguel Totocuitlapilco', 'San Miguel Totocuitlapilco', 'San Miguel Totocuitlapilco,Totocuitlapilco', 19.2310700, -99.5911600, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94239, 'Santo Domingo Tomaltepec', 'Santo Domingo Tomaltepec', 'Santo Domingo Tomaltepec,Tonaltepec', 17.0611700, -96.6228000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94240, 'Tonalixco', 'Tonalixco', '', 18.7819400, -97.0597200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94241, 'Tomatlán', 'Tomatlan', 'Tomatlan,Tomatlán', 19.0310200, -97.0098600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94242, 'Toluca', 'Toluca', 'TLC,Tollohcan,Tolouka,Toluca,Toluca Lerdoensis,Toluca de Lerdo,Toluka,Toluka-de-Lerdo,Tōllohcān,to luk a,tolluka,toluka,toruka,tuo lu ka,twlwka,Τολούκα,Толука,Толука-де-Лердо,تولوکا,तोलुका,โตลูกา,ტოლუკა,トルーカ,托卢卡,톨루카', 19.2878600, -99.6532400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94243, 'Tolome', 'Tolome', '', 19.2666700, -96.3947200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94244, 'Tolcayuca', 'Tolcayuca', 'Tolcayuca', 19.9581400, -98.9194100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94245, 'Tocuila', 'Tocuila', 'Tocuila,Toquila', 18.9500000, -97.0166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94246, 'Tochtepec', 'Tochtepec', 'Tochtepec', 18.8392800, -97.8228200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94247, 'Tochimilco', 'Tochimilco', 'Tochimilco', 18.8906200, -98.5715400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94248, 'Tocatlán', 'Tocatlan', 'Santa Maria,Santa Maria Tocatlan,Santa María,Santa María Tocatlán,Tocatlan,Tocatlán', 19.3886500, -98.0274000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94249, 'Tlazala de Fabela', 'Tlazala de Fabela', 'Iturbide,Santiago,Santiago Tlasala,Santiago Tlazala,Tlasala de Favela,Tlaxala,Tlazala,Tlazala de Fabela', 19.5585700, -99.4146900, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94250, 'Tlayacapan', 'Tlayacapan', 'Tlayacapan', 18.9555600, -98.9811100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94251, 'Tlaxco', 'Tlaxco', 'San Agustin Tlaxco,San Agustín Tlaxco,Tlaxco,Tlaxco de Morelos', 19.6144200, -98.1199700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94252, 'Tlaxcoapan', 'Tlaxcoapan', 'Tlaxcoapan', 20.0916300, -99.2204200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94253, 'Tlaxco', 'Tlaxco', 'Tlaxco', 20.4234500, -98.0291700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94254, 'San Bernardino Tlaxcalancingo', 'San Bernardino Tlaxcalancingo', 'San Bernandino Tlaxcalancingo,San Bernardino Tlaxcalancingo,Tlazcalancingo', 19.0286700, -98.2769800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94255, 'Tlatlauquitepec', 'Tlatlauquitepec', 'Tatlauquitepec,Tlatlauquitepec', 19.8476500, -97.4971800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94256, 'Tlatenchi', 'Tlatenchi', 'Tlatenchi,Tlatenchu', 18.5963900, -99.1863900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94257, 'Tlaquiltenango', 'Tlaquiltenango', 'Tlaquiltenango', 18.6342900, -99.1632000, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94258, 'Tlapa de Comonfort', 'Tlapa de Comonfort', 'Tlapa,Tlapa de Comonfort,Tlapa-de-Komonfort,Тлапа-де-Комонфорт', 17.5452800, -98.5759900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94259, 'Tlapacoyan', 'Tlapacoyan', 'Tlapacoyan', 19.9626800, -97.2114100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94260, 'Tlanepantla', 'Tlanepantla', 'Santa Isabel Tlanepantla,Tlanepantla', 18.8631000, -97.8870100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94261, 'Tlanchinol', 'Tlanchinol', 'Tlanchinol', 20.9919000, -98.6571500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94262, 'Tlanalapa', 'Tlanalapa', 'Tlanalapa,Tlanalapan', 19.8186800, -98.6039600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94263, 'Tlanalapan', 'Tlanalapan', 'Tlanalapa,Tlanalapan', 19.2508400, -97.2760400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94264, 'Tlamixtlahuacan', 'Tlamixtlahuacan', '', 17.5030600, -99.2258300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94265, 'Tlamacazapa', 'Tlamacazapa', 'San Juan Tlamacazapa,Tlamacaxapa,Tlamacaxpan,Tlamacazapa', 18.4964900, -99.5003700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94266, 'Tlaltizapán', 'Tlaltizapan', 'Tlaltizapan,Tlaltizapán', 18.6863000, -99.1186800, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94267, 'Tlaltenango', 'Tlaltenango', 'Tlaltenango', 19.1716500, -98.3407200, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94268, 'Tlalpan', 'Tlalpan', 'Delegacion Tlalpan,Delegación Tlalpan,Tlalpam,Tlalpan', 19.2951300, -99.1620600, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94269, 'Tlalnepantla', 'Tlalnepantla', 'Tlalnepantla,Tlalnepantla de Comonfort,Tlalnepantla de Galeana,Tlalnepantla de baz,Tlanepantla de baz,Тлалнепантла', 19.5400500, -99.1953800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94270, 'Tlalnepantla', 'Tlalnepantla', 'Tlalnepantla,Tlanepantla,Тлалнепантла', 19.0088500, -98.9961300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94271, 'Tlalmanalco', 'Tlalmanalco', 'Tlalmanalco,Tlalmanalco de Velazquez,Tlalmanalco de Velázquez', 19.2052100, -98.8011500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94272, 'Tlalixtaquilla', 'Tlalixtaquilla', 'Tlalixtaquilla', 17.5767400, -98.3672700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94273, 'Tlalixtac de Cabrera', 'Tlalixtac de Cabrera', 'Tlalixtac,Tlalixtac de Cabrera', 17.0711200, -96.6471000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94274, 'Tlalixcoyan', 'Tlalixcoyan', '', 18.8022200, -96.0605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94275, 'San Andrés Tlalamac', 'San Andres Tlalamac', 'San Andres Tlalamac,San Andrés Tlalámac,Tlalamac', 18.9669400, -98.8077800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94276, 'Tlahuelompa (San Francisco Tlahuelompa)', 'Tlahuelompa (San Francisco Tlahuelompa)', 'Tlahuelampa,Tlahuelompa', 20.6508200, -98.5752200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94277, 'Tlahuelilpan', 'Tlahuelilpan', 'Tlahuelilpa,Tlahuelilpa de Ocampo,Tlahuelilpan,Tlanuclipa', 20.1307600, -99.2314500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94278, 'Tláhuac', 'Tlahuac', 'Delegacion Tlahuac,Delegación Tláhuac,Tlahuac,Tláhuac', 19.2868900, -99.0050700, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94279, 'Tlacuilotepec', 'Tlacuilotepec', 'Tlacuilotepec', 20.3257400, -98.0686700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94280, 'San José Tlacotitlán', 'San Jose Tlacotitlan', '', 18.9858300, -98.8061100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94281, 'Tlacotepec (San Mateo)', 'Tlacotepec (San Mateo)', '', 20.0602800, -97.8491700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94282, 'Tlacotepec de Mejía', 'Tlacotepec de Mejia', 'San Martin,San Martín,Tlacotepec,Tlacotepec de Mejia,Tlacotepec de Mejía', 19.1894600, -96.8380500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94283, 'Tlacotepec', 'Tlacotepec', 'Tlacotepec', 18.8144400, -98.7451400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94284, 'Tlacotepec', 'Tlacotepec', 'Tlacotepec,Tlacotepec de Benito Juarez,Tlacotepec de Benito Juárez', 18.6819300, -97.6560200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94285, 'Tlacotepec', 'Tlacotepec', 'Tlacotepec', 17.7897800, -99.9796100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94286, 'Tlacotalpan', 'Tlacotalpan', 'Tlacotalpan', 18.6133300, -95.6589000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94287, 'Tlacolula de Matamoros', 'Tlacolula de Matamoros', 'Opstina Tlacolula de Matamoros,Opština Tlacolula de Matamoros,Tlacolula,Tlacolula de Matamoros,Tlahcolollan Matamoros', 16.9547100, -96.4759000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94288, 'Tlacojalpan', 'Tlacojalpan', 'Tlacojalpan', 18.2309600, -95.9468200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94289, 'San Jerónimo Tlacochahuaya', 'San Jeronimo Tlacochahuaya', 'San Jeronimo,San Jeronimo Tlacochahuaya,San Jerónimo,San Jerónimo Tlacochahuaya,Tlacochahuay,Tlacochahuaya,Tlacochahuaya de Morelos', 17.0087400, -96.5827500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94290, 'Tlacoachistlahuaca', 'Tlacoachistlahuaca', 'Tlacoachistlahuaca,Tlacoachixtlahuaca', 16.8104500, -98.3007800, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94291, 'Tlachichuca', 'Tlachichuca', 'Tlachichuca', 19.1148500, -97.4191500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94292, 'Tizimín', 'Tizimin', 'TZM,Tisimin,Titzimin,Tizimin,Tizimín,Тисимин', 21.1426800, -88.1510100, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94293, 'Tizayuca', 'Tizayuca', 'Tizayuca,Tizayucan', 19.8372100, -98.9760700, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94294, 'Tixtla de Guerrero', 'Tixtla de Guerrero', 'Tikhtla-de-Gerrero,Tixtla,Тихтла-де-Герреро', 17.5673200, -99.3979900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94295, 'Tixpehual', 'Tixpehual', 'Tixpehual,Tixpeual,Tixpheual,Tixpéual', 20.9773900, -89.4420300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94296, 'Tixkokob', 'Tixkokob', 'Tishkokob,Tixkokob,Тишкокоб', 21.0022000, -89.3948400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94297, 'Tixcacaltuyub', 'Tixcacaltuyub', 'Tixcacaltuyu,Tixcacaltuyub,Tixcacaltuyú', 20.4931600, -88.9163700, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94298, 'Tinum', 'Tinum', 'Tinum,Tinun,Tinún', 20.7677900, -88.3916400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94299, 'Timucuy', 'Timucuy', 'Timucay,Timucuy,Tixmucuy', 20.8102300, -89.5138300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94300, 'Tilzapotla', 'Tilzapotla', 'Tilzapotla', 18.4891600, -99.2744200, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94301, 'Santiago Tillo', 'Santiago Tillo', 'Santiago Tillo,Tillo', 17.4608500, -97.3201900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94302, 'San Martín Tilcajete', 'San Martin Tilcajete', 'San Martin Tilcajete,San Martín Tilcajete,Tilcajete', 16.8600800, -96.6949000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94303, 'Tilapa', 'Tilapa', 'Tilapa,Tilopa,Tilspa', 18.5971700, -98.5515600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94304, 'Tila', 'Tila', 'Tila', 17.3005400, -92.4273000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94305, 'Tikuch', 'Tikuch', 'Ticuch,Tikuch', 20.7030100, -88.1127200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94306, 'Tihuatlan', 'Tihuatlan', 'Tihuatlan,Tihuatlán', 20.7144900, -97.5333500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94307, 'Tiholop', 'Tiholop', 'Tiholop', 20.3323400, -88.6895800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94308, 'Tierra Colorada', 'Tierra Colorada', 'Tierra Colorada', 17.1657100, -99.5279100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94309, 'Ticul', 'Ticul', 'Ticul', 20.3983300, -89.5354100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94310, 'Santiago Tíanguistenco', 'Santiago Tianguistenco', 'San Tianguistenco,Santiago Tianguistenco,Santiago Tíanguistenco,Tianguistenco,Tianguistenco de Galeana,Tianguistengo', 19.1802400, -99.4664400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94311, 'Tezontepec de Aldama', 'Tezontepec de Aldama', 'Texontepec,Tezontepec,Tezontepec Aldama,Tezontepec de Aldama', 20.1907300, -99.2742900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94312, 'Tezontepec', 'Tezontepec', 'Tezontepec', 19.8806300, -98.8197200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94313, 'Tezoatlán de Segura y Luna', 'Tezoatlan de Segura y Luna', 'Teosotlan,Teozatlan,Tezoatlan,Tezoatlan de Segura y Luna,Tezoatlán,Tezoatlán de Segura y Luna', 17.6538800, -97.8106800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94314, 'Teziutlan', 'Teziutlan', 'Teziutlan,Teziutlán', 19.8173000, -97.3599200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94315, 'Texistepec', 'Texistepec', 'Texistepec', 17.8947600, -94.8171100, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94316, 'Texhuacán', 'Texhuacan', 'Texhuacan,Texhuacán', 18.6223300, -97.0402500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94317, 'Texcoco', 'Texcoco', 'Texcoco,Texcoco de Mora,Tezcoco,tesukoko,テスココ', 19.5119400, -98.8829300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94318, 'Texcalyacac', 'Texcalyacac', 'San Mateo Texcalyacac,Texcaliacac,Texcalyacac,Texcalyecac', 19.1325300, -99.5016300, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94319, 'San Juan Texcalpan', 'San Juan Texcalpan', '', 18.9358300, -98.9288900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94320, 'Texcala', 'Texcala', '', 18.9344400, -98.7947200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94321, 'San Gabriel Tetzoyocán', 'San Gabriel Tetzoyocan', 'San Gabriel Tetzoyocan,San Gabriel Tetzoyocán,Tetzoyocan', 18.7572700, -97.7032400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94322, 'Tetiz', 'Tetiz', 'Tetiz', 20.9631600, -89.9338400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94323, 'Tetipac', 'Tetipac', 'Teticpac,Tetipac', 18.6477800, -99.6477800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94324, 'Tetepango', 'Tetepango', 'Telepango,Tetepango', 20.1016800, -99.1510800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94325, 'Teteltzingo', 'Teteltzingo', 'Tetelcingo,Teteltzingo,Tetelzingo', 19.0514100, -97.1446500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94326, 'Teteles de Avila Castillo', 'Teteles de Avila Castillo', 'Leteles de Avila Camacho,Leteles de Ávila Camacho,Teteles,Teteles de Avila Castillo,Teteles de Ávila Castillo', 19.8574800, -97.4570300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94327, 'Tetela de Ocampo', 'Tetela de Ocampo', 'Tetela,Tetela de Ocampo,Tetetla de Ocampo', 19.8177000, -97.8069100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94328, 'Tetela del Volcán', 'Tetela del Volcan', 'Telela del Volcan,Tetela del Volcan,Tetela del Volcán', 18.8930600, -98.7297200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94329, 'Tetecala', 'Tetecala', 'Tetecala', 18.7300900, -99.4002100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94330, 'Tesoco', 'Tesoco', 'Tesoco', 20.7225900, -88.1545600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94331, 'Terrenate', 'Terrenate', 'San Nicolas,San Nicolas Terrenate,San Nicolás Terrenate,Terrenate', 19.4766600, -97.9202000, 'MX', '2016-02-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94332, 'Tequixquiac', 'Tequixquiac', 'Santiago Tequixquiac,Tequisquiac,Tequixquiac', 19.9094400, -99.1447200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93761, 'Darhan', 'Darhan', 'Darchan,Darhan,Darkhan,da er han,Дархан,דרחאן,达尔汗', 49.4866700, 105.9227800, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93762, 'Darhan', 'Darhan', 'Boorgu hangay sumu,Bureg Hangay Suma,Bureghangay,Buregkhangai,Burg somon,Burkhe-khangay,Burug hangay,Böörgu hangay sumu,Büreg Hangay Suma,Büreghangay,Büregkhangaï,Bürüg hangay', 48.2546300, 103.8805400, 'MN', '2007-10-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93763, 'Darhan', 'Darhan', 'Darhan,Darhan Suma,Darhan sumu,Darkhan,Darkhan Somon,Darkhan Sume', 46.6166700, 109.4166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93764, 'Dalay', 'Dalay', 'Baishinte,Baishintu,Bayan Dalai Baishintu Khit,Bayandalai,Bayandalay,Bayandalaï,Bayshinta,Bayshinta Hiid,Bayshintu,Bayshintu hiid,Bayshintu khid,Bayshintuin hiid,Kumirnya Bayshinte,Pai-shen-t''ai Miao,Vaishinte', 43.4678700, 103.5128400, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93765, 'Dalandzadgad', 'Dalandzadgad', 'DLZ,Dalan Dsadagad,Dalan Dzadagad,Dalan Tszadagad,Dalan Tzadagad,Dalan-Zadagad,Dalandzadgad,Dalanzadgad,Daranzagatai,Dzadagad,Ta-lan-ken-kuo-lo,Ta-leng-keng Miao,Даланзадгад', 43.5708300, 104.4250000, 'MN', '2013-06-16', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93766, 'Choyr', 'Choyr', 'Chojr,Choyr,Sumber,Sumber Suma,Sumbur,Sumbur Somon,Sumbur Sume,Sumbur sumu,Sümber,Sümber Suma,Чойр', 46.3611100, 108.3611100, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93767, 'Choibalsan', 'Choibalsan', 'Bain Tumen,Baintomenhashu,Baintōmenhashū,Bayan Tumen,Bayn-Tumen,Brin Tumen,COQ,Choibalsan,Choibolsan,Chojbalsan,Choybalsan,Choybolsan,Herelen,K''o-lu-lun,Karulen,Kerulen,Kerulen Urgo,Kerulun,Kerulyun,Kurulun,Kyrylun,K’o-lu-lun,Pa-yin-t''u-men,Pa-yin-t’u-men,Sain Beise,San Beisa-Urgo,San Beise,San-beyse,Say-Beyse,Urgo,Чойбалсан', 48.0725700, 114.5326400, 'MN', '2014-03-22', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93768, 'Chonogol', 'Chonogol', 'Chonogol,Chonoyn Gol,Erdenetsagaan,Yagutszarin-khure,Yegudzeri''iin hurie,Yeguudzer Hiid,Yeguudzeriin Huryee,Yegüdzeri’iin hürie,Yegüüdzer Hiid,Yegüüdzeriin Hüryee,Yugodzir''-Khid,Yugodzir’-Khid,Yugodzyr,Yugodzyr-Khid,Yugudserin Khure,Yugudzeri''iin hurie,Yugudzeri''in hurie,Yugutszeroyn Khid,Yugutszeryn Khid,Yugutszeryyn Khid,Yugutszeröyn Khid,Yugüdzeri’iin hürie,Yugüdzeri’in hürie', 45.9000000, 115.3666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93769, 'Chandmanĭ', 'Chandmani', 'Altanshiree,Chandmani,Chandmanĭ', 45.5333300, 110.4666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93770, 'Saynshand', 'Saynshand', 'Buyant-Uhaa,Dalai Sain Shanda,Dalay Sayn Shanda,Darai Sain Shanda,Sain Shanda,Sain-Shand,Sajnshand,Sayn Shanda,Sayn-Shenda,Сайншанд', 44.8823900, 110.1163100, 'MN', '2010-03-04', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93771, 'Buyant', 'Buyant', 'Boendosumu,Buyant,Buyanta Suma,Buyanton Somon,Buyantoyn-Somon,Buyantu,Buyantu Sume,Buyantu sumu,Buyantyin-Somon,Buyantyn-Somon,Buyantyyn somon,Buyantön Somon,Buyantöyn-Somon', 46.2500000, 110.8333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93772, 'Burgaltay', 'Burgaltay', 'Barun-Burehn,Barun-Burin Somon,Baruun Buriin Suma,Baruun Büriin Suma,Baruunburen,Baruunbüren,Buren,Burgaltay,Burin Suma,Burin-Sumu,Büren,Bürin Suma,Барун-Бурэн', 49.2650000, 104.7434800, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93773, 'Bumbat', 'Bumbat', 'Bayan Ondor Suma,Bayan Undur Somon,Bayan Öndör Suma,Bayan-Ondor,Bayan-Undur,Bayan-unduru,Bayan-Öndör', 46.4967400, 104.1177700, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93774, 'Bulgan', 'Bulgan', 'Bulgan,Cagan-Ur,Tsagaan Uur Suma,Tsagaan uure sumu,Tsagaan Üür Suma,Tsagaan üüre sumu,Tsagaan-Uur,Tsagaan-Üür,Tsagan Ure,Tsagan Ure Sume,Tsagan-ur somon,Цаган-Ур', 50.5419400, 101.5141700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93775, 'Bulgan', 'Bulgan', 'Bulagan,Bulagan Suma,Bulagan Sumu,Bulagan somon,Bulagan-khan,Bulgan,Bulgan Han,Bulganas,UGA,balgana,blgan,bolgang,borugan,bu er gan,bulgani,bwlgan,Булган,بلگان,بولگان,बल्गान,ბულგანი,ボルガン,布爾干,볼강', 48.8125000, 103.5347200, 'MN', '2012-12-15', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93776, 'Bulgan', 'Bulgan', 'Bulagan Bulag', 44.0974500, 103.5428800, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93777, 'Bulagtay', 'Bulagtay', 'Haderi,Huder,Hüder,Khuderi,Kuderi', 49.7759400, 107.5161600, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93778, 'Bulagiyn Denj', 'Bulagiyn Denj', 'Bulgan', 47.3186900, 101.1157600, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93779, 'Bulag', 'Bulag', 'Bulag,Tunehl,Tunel,Tünel,Тунэл', 49.8594600, 100.6268700, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93780, 'Bulag', 'Bulag', 'Bulag,Mongon Morito,Mongon Morito Somon,Mongon Morito Suma,Mongon Moritu Sume,Mongon moritu,Mongonmarit,Mungen-Mor''t,Mungen-Mor’t,Mungun Moritu,Mungun-Moritu-Somon,Mungun-Moritu-Sumu,Möngön Morito,Möngön Morito Somon,Möngön Morito Suma,Möngön Moritu Sume,Möngön moritu,Möngönmarĭt', 48.2000000, 108.4833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93781, 'Bugat', 'Bugat', 'Bugat,Бугат', 49.0666700, 103.6658300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93782, 'Bugant', 'Bugant', 'Bugant,Yoroo Khoroo,Yoroohoroo,Yöröö Khoroo,Yörööhoroo', 49.5833300, 106.8500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93783, 'Bornuur', 'Bornuur', 'Bornur,Bornuur,Борнур', 48.4666700, 106.2666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93784, 'Böhöt', 'Bohot', 'Ondor Shili,Ondor Shili Suma,Ondorshil,Under-Shil,Undur Shile,Undur shili sumu,Undur-Shili,Undur-Shili Somon,Öndör Shili,Öndör Shili Suma,Öndörshil', 45.2322300, 108.2824500, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93785, 'Bodĭ', 'Bodi', 'Chzhinsetu somon,Djinsetu Sume,Dzhinsetu,Dzhinsetu somon,Dzhinsetu-Sumu,Jinsatu,Jinsete,Jinsete Suma,Jinsetu,Jinsetu sumu,Jinsetü,Jinst', 45.4117100, 100.5740000, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93786, 'Bayshint', 'Bayshint', 'Bayshint,Ondor Haan,Ondor Haan Suma,Ondorshireet,Undur Khan Somon,Öndör Haan,Öndör Haan Suma,Öndörshireet', 47.4166700, 104.8166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93787, 'Bayasgalant', 'Bayasgalant', 'Bayanjargalan', 47.1794500, 108.2599600, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93788, 'Bayasgalant', 'Bayasgalant', 'Bayasgalant,Monhhaan,Monho Haan Suma,Monho Han,Monho Han sumu,Monhö Han sumu,Monkhkhaan,Munkh-Khan,Munkh-Khany-Somon,Munkhu Khanoy Somon,Munkhu Khany,Munkhu Khanyy Somon,Munkhu Khanöy Somon,Munku-khan,Munku-khan Somon,Munku-khanoy Somon,Munku-khanyy somon,Mönhhaan,Mönhö Haan Suma,Mönhö Han,Mönkhkhaan', 46.9833300, 112.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93789, 'Bayan-Ulaan', 'Bayan-Ulaan', 'Bayan Ulaan Suma,Bayan Ulan Somon,Bayan ulaan sumu,Bayan-Ulan,Bayan-uran,Dzun-Bayan-Ulan,Dzuunbayan-Ulaan,Dzüünbayan-Ulaan', 46.5217800, 102.5942800, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93790, 'Bayantsagaan', 'Bayantsagaan', 'Bayantsagaan,Chzhirgalantu somon,Dzhargalant,Dzhirgalantu,Dzhirgalantu Somon,Jargalant,Jirgalanta Suma,Jirgalantu,Jirgalantu sumu,Джаргалант', 48.7316700, 100.7600000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93791, 'Bayantöhöm', 'Bayantohom', 'Bayantohom,Bayantöhöm,Buren,Büren', 46.9166700, 105.0500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93792, 'Bayan-Ovoo', 'Bayan-Ovoo', 'Bajan-Obo,Bayan-Ovoo,Dadal,Datal,Datal Sume,Datal sumu,Tataal,Tataal Suma,Tatal,Tatal-Somon,Баян-Обо', 49.0166700, 111.6333300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93793, 'Javhlant', 'Javhlant', 'Bain-obo Somon,Bayan Obo,Bayan Oboo,Bayan Oboo Suma,Bayan oboo sumu,Bayan-Ovoo,Bayan-obo somon,Bayn Obo Somon', 47.7833300, 112.1166700, 'MN', '2007-10-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93794, 'Bayanhoshuu', 'Bayanhoshuu', 'Bayanhushuu,Galuut', 46.7019700, 100.1433000, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93795, 'Bayanhongor', 'Bayanhongor', 'Bajankhongor,Bayan Hangor,Bayan Hongor Suma,Bayan Khongor,Bayan Khongor Somon,Bayan Khonkhor Sume,Bayan honhor sumu,Bayan-hongoru,Bayanhongor,Bayankhongor,Баянхонгор', 46.7166700, 100.1166700, 'MN', '2013-03-02', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93796, 'Bayanhongor', 'Bayanhongor', 'BYN,Bajankhongor,Bayanhongor,Dzaluuchuud,Youth City,Баянхонгор', 46.1944400, 100.7180600, 'MN', '2013-08-04', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93797, 'Bayandelger', 'Bayandelger', 'Bain-delger Somon,Bayan Delger Suma,Bayan Delger Sume,Bayan del''ger sumu,Bayan-Del''ger Somon,Bayanderigeri', 47.7273200, 108.1106200, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93798, 'Bayanbulag', 'Bayanbulag', 'Bayanbulag,Omnodelger,Omono Delger,Omono Delger Suma,Umne-Delger,Umun-delger somon,Umun-telger Somon,Ömnödelger,Ömönö Delger,Ömönö Delger Suma', 47.8666700, 109.9166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93799, 'Bayanbaraat', 'Bayanbaraat', 'Bayan Baraata Suma,Bayan Baraatayn,Bayan Baraatayn Suma,Bayan Baratuin,Bayan Baratuin Somon,Bayan Baratuyn Somon,Bayan baraatu,Bayan-Baratu,Bayanbaraat', 46.8666700, 106.2500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93800, 'Bayan', 'Bayan', 'Bajan,Bayan,Bayan-Adraga,Баян', 48.5500000, 111.0833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93801, 'Bayan', 'Bayan', 'Bayan,Holobuyr,Hölöbuyr,Kholobuir,Khölöbuïr', 47.9166700, 112.9500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93802, 'Bayan', 'Bayan', 'Bayan,Hashaat,Hashaata Suma,Hashiatu,Hashiyantu sumu,Khashaat,Khashiatu Somon,Khashiyantu', 47.4500000, 103.1500000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93803, 'Bayan', 'Bayan', 'Baan Khuduk,Bayan,Bayan Hudag,Bayanhutag,Bayankhutag', 47.1666700, 110.8166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93804, 'Bayan', 'Bayan', 'Bayan,Ihe hete,Ihe hete sumu,Ihhet,Ikhe-Khete,Ikhe-khid,Ikhe-khid Somon,Ikhkhet,Inhet,Yihe Hete Suma,Yihe Hiid,Yihe Hiid Suma', 46.2500000, 110.1666700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93805, 'Bat-Öldziyt', 'Bat-Oldziyt', 'Bat-OEldziyt,Bat-Öldziyt,Dzaamar,Dzamar,Дзамар', 48.2155200, 104.7731800, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93806, 'Baruun-Urt', 'Baruun-Urt', 'Barun Urt,Barun Urtas,Barun-Urt,Baruun Urta,Baruun-Urt,Burunurt,Dzhapkhalanta-sharga,Dzhibkhalantu-Sharga,Jibhalanta Sharga Suma,Jibholantu Sharga sumu,Jibhulantu sharga,Sharga Sume,UUN,balun-uleuteu,baruna-urta,barwn-ywrt,barwwn-awrt,xi wu er te,Барун Урт,Барун-Урт,Баруун-Урт,بارون-یورت,باروون-اورت,बरून-उर्त,ბარუუნ-ურტი,バルーン・ウルト,西烏爾特,바룬우르트', 46.6805600, 113.2791700, 'MN', '2015-11-07', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93807, 'Baruunsuu', 'Baruunsuu', 'Tsetsen Sume,Tsetsey,Tsetsey sumu,Tsogt-Tsetsey,Tsogto Tsetsey Suma,Tsogttsetsii,Tsogttsetsiy,Tsogttsetsiï,Tsogtu Tsetsey Somon,Tsogtu Tsetsi,Tsogtu-Tsetsey', 43.6559500, 105.7557700, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93808, 'Hushaat', 'Hushaat', 'Barun-Khashiatu Somon,Baruun Hashaata Suma,Bayan Khashiatu,Hashaata Suma,Hashiatu,Hashiatu sumu,Hushaat,Khashat,Khoshat', 49.5000000, 105.6166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93809, 'Badrah', 'Badrah', 'Badrah,Taralang somon,Tarialan,Taryaalan Suma,Taryaalang Suma,Taryalang,Taryalang somon,Taryalang sumu,Taryalyang somon', 49.6183300, 101.9897200, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93810, 'Avraga', 'Avraga', 'Avarga,Delger Haan Suma,Delger Han,Delger Han Sumu,Delger Khan,Delger-Khan Somon,Delgerhaan,Delgerkhaan,Delgerkhan Sume', 47.1785100, 109.1896800, 'MN', '2007-10-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93811, 'Avdzaga', 'Avdzaga', 'Avdzaga,Gurban Bulagan,Gurban Bulagiin Somon,Gurban Bulagiin Suma,Gurban-Bulag,Gurban-Bulak,Gurvanbulag,Gurwanbulag', 47.6333300, 103.5166700, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93812, 'Arvayheer', 'Arvayheer', 'AVK,Arbai Khere,Arbay Heere,Arbay Khere,Arbay hure,Arbayin Khure,Arbayin hure,Arubai gere,Arvajkhehehr,Arvayheer,Arwaikheer,Arwaïkheer,Obor Hangayin,Obor Khangai,Obör Hangayin,Ts''ai-ku-na Miao,Ts''ai-ku-na Ya-men,Ts’ai-ku-na Miao,Ts’ai-ku-na Ya-men,Ubur Khangaiin,Ubur Khangaun,Ubur Khangayin,Ubur Khangaün,Ubur-hangaajin,Ubur-hangayin,Öbör Khangai,Арвайхээр', 46.2638900, 102.7750000, 'MN', '2017-03-08', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93813, 'Arhust', 'Arhust', 'Erdene,Erdeni Sumny Horshoo', 47.7942500, 107.8833400, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93814, 'Arguut', 'Arguut', 'Guchin,Guchin Suma,Guchin Usa Suma,Guchin somon,Guchin usu sumu,Guchin-Us,Guchin-Usu,Guchin-Usu-Somon,Guchun Usu', 45.4627800, 102.4205600, 'MN', '2007-10-21', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93815, 'Argatay', 'Argatay', 'Argatay,Bain-Dzhargalanta-somon,Bain-Dzhirgalang-sumu,Bain-chzhargalanta Somon,Bayan Jirgalanta Suma,Bayan-jirugaran,Bayanjargalan,Bayn Jargalanta Somon', 45.7666700, 107.9833300, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93816, 'Argalant', 'Argalant', '', 47.9421100, 105.8958400, 'MN', '2007-10-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93817, 'Ar-Asgat', 'Ar-Asgat', 'Ar-Asgat,Ugtaaltsaydam,Ugtaastsaidam,Ugtaastsaïdam,Uhtal tsaydam sumu,Ukhtal-Tsaydam,Ukhtal-Tsaydam Somon,Ukhtal-Tsaydam-Sumu,Ар-Асгат', 48.2622200, 105.4119400, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93818, 'Amardalay', 'Amardalay', 'Del''ger tsogtu sumu,Delger Tsogto,Delger Tsogto Suma,Delger Tsogtu Somon,Delger Tsogtuin Khure,Delger tsogtu,Delgertsogt,Derigeri-tsofuta', 46.1257200, 106.3742600, 'MN', '2007-10-13', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93819, 'Altan-Ovoo', 'Altan-Ovoo', 'Tsenher,Urdtamir', 47.4474200, 101.7550300, 'MN', '2007-10-19', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93820, 'Altanbulag', 'Altanbulag', 'Altan Bulak,Altanbulag,Alton Brok,Altyn-Bulak,Ch''ia-k''o-t''u,Ch’ia-k’o-t’u,Kiachta,Kyakhta,Mai-mai-ch''eng,Mai-mai-ch’eng,Maymachen,Maymaychen,Алтанбулаг', 50.3155600, 106.4986100, 'MN', '2015-01-14', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93821, 'Altanbulag', 'Altanbulag', 'Altanbulag', 47.7000000, 106.4000000, 'MN', '2012-01-17', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93822, 'Asgat', 'Asgat', 'Asgat', 49.5108200, 96.7994400, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93823, 'Ulaanshiveet', 'Ulaanshiveet', 'Ulaanshiveet', 47.2894800, 103.8565900, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93824, 'Sümber', 'Sumber', 'Sumber,Sümber', 47.6585800, 118.5101400, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93825, 'Bayantal', 'Bayantal', 'Bayantal', 46.6213400, 108.3580400, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93826, 'Shiveegovi', 'Shiveegovi', 'Shiveegovi', 46.0908100, 108.6830600, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93827, 'Hongor', 'Hongor', 'Hongor', 49.2301200, 105.8967400, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93828, 'Jargalant', 'Jargalant', 'Jargalant', 49.1291500, 104.4080300, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93829, 'Höshigiyn-Ar', 'Hoshigiyn-Ar', 'Hoshigiyn-Ar,Höshigiyn-Ar', 47.5571700, 106.9633300, 'MN', '2012-01-20', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93830, 'Зуунмод', 'Zuunmod', '', 47.7069300, 106.9527600, 'MN', '2011-02-05', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93831, 'Kharkhorin', 'Kharkhorin', 'KHR,Kharkhorin,Хархорин', 47.1924500, 102.8134900, 'MN', '2011-02-06', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93832, 'Ulaan Khat', 'Ulaan Khat', 'Ulan Khat', 47.9825700, 89.8417300, 'MN', '2014-07-29', 148);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93876, 'Saint Peters', 'Saint Peters', 'Saint Peter''s Village', 16.7727000, -62.2172900, 'MS', '2013-07-04', 150);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93877, 'Plymouth', 'Plymouth', 'Gorad Plimut,Plimouth,Plimut,Plimutas,Plimuto,Plymouth,Plymouth pa Montserrat,Plymouth på Montserrat,blymwth,peullimeoseu,phli math,plymwt,pu li mao si,purimasu,Πλίμουθ,Горад Плімут,Плимут,Плимът,Плімут,פלימות,بليموث,پلایماؤت، مانٹسریٹ,پلی‌موث، مونتسرات,พลิมัท,პლიმუთი,プリマス,普利茅斯,플리머스', 16.7055500, -62.2129200, 'MS', '2010-07-21', 150);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93878, 'Brades', 'Brades', 'Brades Estate,Bradeso,Breidsas,Breints,Brejds,Breyds,Vjoska Brehjds,be rds,beuleijeu,breidsi,brydz,bu lai ci,bureizu,pirate,Μπρέιντς,Брейдс,Брејдс,Вёска Брэйдс,בראדס,بریدز,بریڈیس,பிராதெ,เบรดส์,ბრეიდსი,ブレイズ,布莱兹,브레이즈', 16.7918300, -62.2105800, 'MS', '2013-08-17', 150);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93834, 'San Jose Village', 'San Jose Village', 'San Jose,San Jose CDP,San Khose,Сан Хосе', 14.9682300, 145.6199800, 'MP', '2014-08-19', 165);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(93835, 'Saipan', 'Saipan', 'SPN,Saipan,saipan,사이판', 15.2123300, 145.7545000, 'MP', '2017-06-29', 165);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94333, 'Tequisquiapan', 'Tequisquiapan', 'Tequisquiapam,Tequisquiapan', 20.5225000, -99.8916700, 'MX', '2013-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94334, 'Tequila', 'Tequila', 'Roa Barcenas,San Pedro,San Pedro Tequila,Tekila,Tequila,Текила', 18.7299800, -97.0699100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94335, 'San Martín Tequesquipan (Tequesquipan)', 'San Martin Tequesquipan (Tequesquipan)', 'Tequesquipan,Tequexquipan,Tequisquiapan,Tequisquipan', 19.0580600, -99.9466700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94336, 'San Juan Tepulco', 'San Juan Tepulco', 'San Juan Tepulco,Tepulco', 19.1170900, -97.9884700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94337, 'Cuautitlán Izcalli', 'Cuautitlan Izcalli', 'Cuautitlan Izcalli,Cuautitlán Izcalli,Izcalli,San Francisco Tepoiaco,Tepujaco', 19.6438800, -99.2159800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94338, 'Tepoztlán', 'Tepoztlan', 'Tepoxtlan,Tepoxtlán,Tepoztlan,Tepoztlán', 18.9862200, -99.1005100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94339, 'Tepotzotlán', 'Tepotzotlan', 'Tepotzotlan,Tepotzotlán,Tepozotlan', 19.7211600, -99.2239100, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94340, 'Tepeyahualco', 'Tepeyahualco', 'Tepeyahualco,Tepeyahualco Cuahtemoc,Tepeyahualco Cuahtémoc,Tepeyahualco Cuauhtemoc,Tepeyahualco Cuauhtémoc', 18.8142800, -97.8770200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94341, 'Tepexi de Rodríguez', 'Tepexi de Rodriguez', 'Tepexi,Tepexi de Rodriguez,Tepexi de Rodríguez', 18.5810800, -97.9260600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94342, 'Tepetzintla', 'Tepetzintla', '', 21.1641000, -97.8523500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94343, 'Tepetzintla', 'Tepetzintla', 'Tepetzintla', 19.9672000, -97.8414300, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94344, 'Tepetlaoxtoc', 'Tepetlaoxtoc', 'Tepetlaoxtoc,Tepetlaoxtoc de Hidalgo', 19.5743700, -98.8183500, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94345, 'Tepetlacolco', 'Tepetlacolco', 'Tepetlacalco,Tepetlacolco', 18.6410400, -97.6928400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94346, 'Barrio Tepetitlán Emilio Portes Gil', 'Barrio Tepetitlan Emilio Portes Gil', 'Tepetitla,Tepetitlan,Tepetitlán', 19.6530600, -99.8866700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94347, 'Santa Cecilia Tepetitlán', 'Santa Cecilia Tepetitlan', '', 19.1925400, -97.4339500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94348, 'Tepetitla', 'Tepetitla', 'San Mateo,Tepetitla', 19.2653100, -98.3764500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94349, 'Tepepa', 'Tepepa', 'Tepepa,Tetepa', 20.1344000, -98.1713100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94350, 'Tepeojuma', 'Tepeojuma', 'San Cristobal Tepeojuma,San Cristóbal Tepeojuma,Tepeojuma', 18.7246800, -98.4463300, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94351, 'Tepeji del Río de Ocampo', 'Tepeji del Rio de Ocampo', 'Tepeji,Tepeji de Ocampo,Tepeji del Rio,Tepeji del Rio de Ocampo,Tepeji del Río,Tepeji del Río de Ocampo,Tepexi del Rio,Tepexi del Río', 19.9048100, -99.3437900, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94352, 'Tepecoacuilco de Trujano', 'Tepecoacuilco de Trujano', 'Tepecoa,Tepecoacuilco,Tepecoacuilco de Trujano,Tepecuacuilco de Trujano', 18.2875000, -99.4642300, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94353, 'Tepeapulco', 'Tepeapulco', 'Tepeapulco', 19.7884000, -98.5526600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94354, 'Tepeaca', 'Tepeaca', 'Tepeaca,Tepeaca de Negrete', 18.9668800, -97.8998000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94355, 'Tepatlaxco de Hidalgo', 'Tepatlaxco de Hidalgo', 'Tepatlaxco,Tepetlaxco', 19.0674700, -97.9659500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94356, 'Tepatlaxco', 'Tepatlaxco', 'Tepatlaxco', 19.0692700, -96.8448100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94357, 'Tepatepec', 'Tepatepec', 'Tecpatepec,Tepactepec,Tepatepec', 20.2456800, -99.0898100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94358, 'Tepango', 'Tepango', 'Tenango,Tepango,Tepango de Rodriguez,Tepango de Rodríguez', 20.0031400, -97.7965100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94359, 'Tepanco', 'Tepanco', 'Tepanco,Tepanco de Lopez,Tepanco de López', 18.5568600, -97.5613000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94360, 'Tepalcingo', 'Tepalcingo', 'Tepalcingo,Tepalcingo de Hidalgo,Tepaltzingo', 18.5949800, -98.8453700, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94361, 'Tepakan', 'Tepakan', 'Tepacan,Tepakan,Tepakán,Tepekan', 21.0488200, -89.0387300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94362, 'Teotitlán del Valle', 'Teotitlan del Valle', 'Teotitlan,Teotitlan del Valle,Teotitlán del Valle', 17.0297500, -96.5192600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94363, 'Teopisca', 'Teopisca', 'Teopisca,Teopisea', 16.5418200, -92.4740500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94364, 'Teopantlán', 'Teopantlan', 'Teopantlan,Teopantlán', 18.7121900, -98.2634100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94365, 'Teoloyucan', 'Teoloyucan', 'Teoloyucan', 19.7442300, -99.1811300, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94366, 'Teocelo', 'Teocelo', 'Teocelo', 19.3856000, -96.9737100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94367, 'Tenosique de Pino Suárez', 'Tenosique de Pino Suarez', 'Tenosique,Tenosique de Pino Suarez,Tenosique de Pino Suárez', 17.4729000, -91.4236000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94368, 'Tanetze de Zaragoza', 'Tanetze de Zaragoza', 'Tanetze de Zaragoza,Tenetze', 17.3761600, -96.3011100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94369, 'Tenejapa', 'Tenejapa', 'Tenejapa,Tenjeapa', 16.8187800, -92.5064600, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94370, 'Tenango del Aire', 'Tenango del Aire', 'Tenango', 19.1577400, -98.8568700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94371, 'Tenango de Doria', 'Tenango de Doria', 'Tenango de Doria', 20.3382800, -98.2280500, 'MX', '2014-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94372, 'Tenango de Arista', 'Tenango de Arista', 'Tenango,Tenango de Arista,Tenango del Valle', 19.1044600, -99.5898000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94373, 'San Sebastián Tenango', 'San Sebastian Tenango', 'San Sebastian Tenango,San Sebastián Tenango,Tenango', 18.6628200, -98.1739200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94374, 'Tenango', 'Tenango', '', 16.9666700, -92.4166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94375, 'Tenancingo', 'Tenancingo', 'Tenancingo,Tenancingo de Degollado', 18.9613600, -99.5903000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94376, 'Tenampulco', 'Tenampulco', 'Tenampulco', 20.1704200, -97.4049600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94377, 'Tenampa', 'Tenampa', 'Tenampa', 19.2487700, -96.8839000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94378, 'Tenabo', 'Tenabo', 'Tenabo', 20.0398100, -90.2257300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94379, 'Tempoal de Sánchez', 'Tempoal de Sanchez', 'Tempoal,Tempoal de Sanchez,Tempoal de Sánchez', 21.5199800, -98.3882900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94380, 'Temozon', 'Temozon', 'Temozon,Temozón', 20.8039300, -88.2015500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94381, 'Temoaya', 'Temoaya', 'Santiago,Santiago Temoaya,Temoaya', 19.4674700, -99.5940700, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94382, 'Temoac', 'Temoac', 'Temoac', 18.7722200, -98.7775000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94383, 'Temixco', 'Temixco', 'Temisco,Temisko,Temixco,te mi si ke,tmykskw,Темиско,تمیکسکو,特米斯科', 18.8525400, -99.2253700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94384, 'Temax', 'Temax', '', 21.1510500, -88.9403900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94385, 'Temascalcingo de José María Velazco', 'Temascalcingo de Jose Maria Velazco', 'Temascalcingo,Temascalcingo de Jose Maria Velasco,Temascalcingo de Jose Maria Velazco,Temascalcingo de José María Velasco,Temascalcingo de José María Velazco', 19.9163500, -100.0036900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94386, 'Temascalapa', 'Temascalapa', 'Temascalapa,Temaxcalapa', 19.8276600, -98.9017100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94387, 'Temapache', 'Temapache', 'Temapache', 21.0661100, -97.6420700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94388, 'Temamatla', 'Temamatla', 'Temamatla', 19.2030600, -98.8692100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94389, 'Teloloapan', 'Teloloapan', 'Teloloapan', 18.3674000, -99.8677600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94390, 'Telixtac', 'Telixtac', 'Telixtac', 18.5603100, -98.7762500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94391, 'Telchac Puerto', 'Telchac Puerto', 'Telchac,Telchac Puerto', 21.3412100, -89.2633300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94392, 'Telchac Pueblo', 'Telchac Pueblo', 'Telchac,Telchac Pueblo', 21.2031200, -89.2694500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94393, 'Tekit', 'Tekit', 'Tekit', 20.5346500, -89.3331500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94394, 'Tecax', 'Tecax', 'Ciudad Obregon,Ciudad Obregón,Obregon,Tecax,Tekax,Tekax de Alvaro Obregon,Tekax de Álvaro Obregón', 20.2052000, -89.2852200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94395, 'Tekanto', 'Tekanto', 'Tekanto', 21.0096800, -89.1072300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94396, 'San Felipe Tejalápam', 'San Felipe Tejalapam', 'San Felipe Tejalapam,San Felipe Tejalapan,Tejalapam,Tejalapan', 17.1113400, -96.8542000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94397, 'San Juan Teitipac', 'San Juan Teitipac', 'Eltipac,San Juan Teitipac,Teitipac', 16.9279900, -96.6061900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94398, 'Tehuixtla', 'Tehuixtla', 'Tehuixtla', 18.5594400, -99.2711900, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94399, 'Tehuetlán', 'Tehuetlan', 'Tehuatlan,Tehuetlan,Tehuetlán', 21.0533700, -98.5085300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94400, 'Tehuacán', 'Tehuacan', 'TCN,Tehuacan,Tehuacán,Tehuahcan,Teuakan,Tevakan,thwakan,ti wa kan,Тевакан,Теуакан,تهواکان,تیہواکان,ტეუაკანი,提瓦坎', 18.4642200, -97.3973500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94401, 'Tecpatán', 'Tecpatan', 'Tecpatan,Tecpatán', 17.1367600, -93.3113300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94402, 'Tecozautla', 'Tecozautla', 'Tecozautla', 20.5335900, -99.6344900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94403, 'San Marcos Tecomaxusco', 'San Marcos Tecomaxusco', 'Tecomaxusco,Tecomaxuxco', 18.9815200, -98.7603500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94404, 'Tecolutla', 'Tecolutla', 'Tecolutla', 20.4804900, -97.0130900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94405, 'Villa Tecolutilla', 'Villa Tecolutilla', 'Tecolutilla,Villa Tecolutilla', 18.2833800, -93.3339800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94406, 'Tekoh', 'Tekoh', 'Tecoh', 20.7436100, -89.4740600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94407, 'Barra de Tecoanapa', 'Barra de Tecoanapa', 'Barra Tecoana,Barra de Tecoanapa,Tecoanapa', 16.5086400, -98.7321600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94408, 'San Pedro Techuchulco', 'San Pedro Techuchulco', 'San Pedro Techuchulco,Techuchulco,Techuchulco de Allende', 19.1135900, -99.5242500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94409, 'Tecamachalco', 'Tecamachalco', 'Tecamachalco', 18.8835200, -97.7334400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94410, 'Tecali', 'Tecali', 'Tecali,Tecali de Herrera', 18.9006000, -97.9706400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94411, 'Tecajec', 'Tecajec', '', 18.7980600, -98.8150000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94412, 'Teapa', 'Teapa', 'Teapa', 17.5497000, -92.9521100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94413, 'Teabo', 'Teabo', 'Teabo', 20.4005900, -89.2831600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94414, 'Taxco de Alarcón', 'Taxco de Alarcon', 'Tasco,Tasko-de-Alarkon,Taxco,Taxco de Alarcon,Taxco de Alarcón,Таско-де-Аларкон', 18.5546200, -99.6059200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94415, 'Tatatila', 'Tatatila', 'Tatatila', 19.6932000, -97.1116000, 'MX', '2016-02-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94416, 'Tatahuicapan', 'Tatahuicapan', 'Tatahuicapan,Tetahuicapan', 18.2462100, -94.7612400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94417, 'Tasquillo', 'Tasquillo', 'Tasquillo', 20.5483600, -99.3135200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94418, 'Tapilula', 'Tapilula', 'Tapilula', 17.2495000, -93.0167000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94419, 'Tapachula', 'Tapachula', 'TAP,Tapachula,Tapachule,ta pa qiu la,tapachwla,Тапачула,Тапачуле,تاپاچولا,塔帕丘拉', 14.9038500, -92.2574900, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94420, 'Tantoyuca', 'Tantoyuca', 'Tantoyuca,carretera platon sanchez', 21.3506400, -98.2257000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94421, 'Tanute', 'Tanute', 'Tantate,Tanute', 21.6524300, -99.0376500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94422, 'Tanquián de Escobedo', 'Tanquian de Escobedo', 'Tanquian,Tanquian Escobedo,Tanquian de Escobedo,Tanquián Escobedo,Tanquián de Escobedo', 21.6058700, -98.6627500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94423, 'Tamulte de las Sabanas', 'Tamulte de las Sabanas', 'Tamulte de las Sabanas,Tamulté de las Sabanas', 18.1616800, -92.7835400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94424, 'Tamuin', 'Tamuin', 'Tamuin,Tamuín,Villa de Guerrero', 22.0055400, -98.7797200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94425, 'Tampico', 'Tampico', 'Gorad Tampika,TAM,Tampico,Tampikas,Tampiko,tambykw,tampiko,tampykw,tan pi ke,tanpiko,tempiko,Горад Тампіка,Тампико,تامبيكو,تامپیکو,टॅम्पिको,タンピコ,坦皮科,탐피코', 22.2781700, -97.8677200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94426, 'Tamiahua', 'Tamiahua', 'Tamiahua', 21.2788100, -97.4462000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94427, 'Tamazunchale', 'Tamazunchale', 'Tamazunchale', 21.2599300, -98.7893500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94428, 'Tamasopo', 'Tamasopo', 'La Palma,Palma,Tamasopo', 21.9242600, -99.3936500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94429, 'Tamápatz', 'Tamapatz', 'Tamapatz,Temapache', 21.5665400, -99.0776400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94430, 'Tamalín', 'Tamalin', 'Tamalin,Tamalín', 21.3393600, -97.8118800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94431, 'Tahmek', 'Tahmek', 'Tahmec,Tahmek', 20.8736000, -89.2547300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94432, 'San Juan Tahitic', 'San Juan Tahitic', '', 19.9360500, -97.5508200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94433, 'Tacotalpa', 'Tacotalpa', 'Tacotalpa,Takotalpa,Такоталпа', 17.5963800, -92.8259600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94434, 'Sultepec de Pedro Ascencio de Alquisiras', 'Sultepec de Pedro Ascencio de Alquisiras', 'Sultepec,Sultepec de Alquiciras,Sultepec de Pedro,Sultepec de Pedro Ascencio,Sultepec de Pedro Ascencio Alquisiras,Sultepec de Pedro Ascencio de Alquisiras', 18.8585500, -99.9658800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94435, 'Sucilá', 'Sucila', 'Sucila,Sucilá', 21.1565000, -88.3140500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94436, 'Brisas Barra de Suchiate', 'Brisas Barra de Suchiate', 'Brisas Barra de Suchiate,Suchiate', 14.5358800, -92.2241400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94437, 'Suchiapa', 'Suchiapa', 'Suchiapa', 16.6255500, -93.1007400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94438, 'San Francisco Soyaniquilpan', 'San Francisco Soyaniquilpan', 'San Francisco Soyaniquilpan,Soyaniquilpan', 20.0148800, -99.5302200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94439, 'Soyaló', 'Soyalo', 'Soyalo,Soyaló', 16.8913000, -92.9243300, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94440, 'Sotuta', 'Sotuta', 'Sotuta,Zotuta', 20.5967800, -89.0081500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94441, 'Soto la Marina', 'Soto la Marina', 'Soto la Marina', 23.7695300, -98.2044200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94442, 'Soteapan', 'Soteapan', 'Soleapan,Soteapan', 18.2339100, -94.8729600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94443, 'Soltepec', 'Soltepec', '', 19.1211100, -97.7086100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94444, 'Soledad de Doblado', 'Soledad de Doblado', 'Soledad de Doblado', 19.0463700, -96.4214200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94445, 'Soconusco', 'Soconusco', 'Soconusco,Socunusco', 17.9631500, -94.8809700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94446, 'Socoltenango', 'Socoltenango', 'Socoltenango', 16.2448400, -92.3503800, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94447, 'Sochiapa', 'Sochiapa', 'Sochiapa', 19.1929200, -96.9398900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94448, 'Santiago Apostol', 'Santiago Apostol', 'Santiago,Santiago Apostol,Sitio de Santiago', 16.8038100, -96.7204600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94449, 'Sisal', 'Sisal', 'Sisal,Sisal Puerto', 21.1670000, -90.0253200, 'MX', '2014-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94450, 'Singuilucan', 'Singuilucan', 'Singuilucan,Zinguilucan', 19.9687400, -98.5193500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94451, 'Simojovel de Allende', 'Simojovel de Allende', 'Simojovel,Simojovel de Allende', 17.2000000, -92.6333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94452, 'Sierra Papacal', 'Sierra Papacal', 'Papacal,Sierra,Sierra Papacal', 21.1252200, -89.7301800, 'MX', '2014-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94453, 'Seyé', 'Seye', 'Seve,Seye,Seyé', 20.8356800, -89.3717400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94454, 'Seybaplaya', 'Seybaplaya', 'Ceibaplaya,Seibaplaya,Seybaplaya', 19.6399400, -90.6870600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94455, 'Sergio Butrón Casas', 'Sergio Butron Casas', 'Butron Casas,Butrón Casas,Sergio Buitron,Sergio Buitrón,Sergio Butron Casas,Sergio Butrón Casas', 18.5139000, -88.5688300, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94456, 'San Sebastián del Monte', 'San Sebastian del Monte', '', 17.6777800, -98.0219400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94457, 'Sayula de Alemán', 'Sayula de Aleman', 'Sayula,Sayula de Aleman,Sayula de Alemán,Villa Sayula de Aleman', 17.8819100, -94.9598600, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94458, 'Xiloxoxtla', 'Xiloxoxtla', 'San Vicente Xiloxochitla,Santa Isabel,Xiloxochitla,Xiloxochtla,Xiloxoxtla,Xioxoxtla', 19.2678600, -98.2139900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94459, 'San Vicente Tancuayalab', 'San Vicente Tancuayalab', 'San Vicente,San Vicente Tancuayalab,Tancuayalab,Tanguayalab', 21.7188600, -98.5876900, 'MX', '2014-03-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94460, 'San Vicente Lachixío', 'San Vicente Lachixio', 'Lachixio,San Vicente,San Vicente Lachixio,San Vicente Lachixlo,San Vicente Lachixío', 16.7050200, -97.0186400, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94461, 'San Vicente Coatlán', 'San Vicente Coatlan', 'Coatlan,San Vicente,San Vicente Coatlan,San Vicente Coatlán', 16.3885200, -96.8439000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94462, 'Santo Tomás Jalieza', 'Santo Tomas Jalieza', 'Jalieza,Santo Tomas Jalieza,Santo Tomás Jalieza', 16.8446900, -96.6706300, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94463, 'Hueyotlipan', 'Hueyotlipan', 'Hueyotlipan,Santo Tomas,Santo Tomas Hueyotlipan,Santo Tomás Hueyotlipan', 18.8914800, -97.8657500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94464, 'Santo Tomás Chautla', 'Santo Tomas Chautla', 'Chautla,Santo Tomas Chautla,Santo Tomás Chautla', 18.9657300, -98.1528800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94465, 'Santo Tomás Atzingo', 'Santo Tomas Atzingo', 'Atzingo,Santo Tomas,Santo Tomas Atzingo,Santo Tomás Atzingo', 19.1727000, -98.7787300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94466, 'Santos Reyes Tepejillo', 'Santos Reyes Tepejillo', 'Santos Reyes Tepejillo,Tepejillo', 17.4378200, -97.9384500, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94467, 'Santo Domingo Zanatepec', 'Santo Domingo Zanatepec', 'Sonatepec,Zanatepec', 16.4830700, -94.3475400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94468, 'Xagacía', 'Xagacia', 'Santo Domingo Xagacia,Santo Domingo Xagacía,Xagacia,Xagacía,Yagacia', 17.1543600, -96.2675300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94469, 'Santo Domingo Tlatayapam', 'Santo Domingo Tlatayapam', 'Santo Domingo Tlatayapam,Santo Domingo Tlatayapan,Tlatayapan', 17.4077800, -97.3458100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94470, 'Santo Domingo Tepuxtepec', 'Santo Domingo Tepuxtepec', 'Santo Domingo,Santo Domingo Tepuxtepec,Tepuxtepec', 16.9558400, -96.0582300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94471, 'Santo Domingo Tehuantepec', 'Santo Domingo Tehuantepec', 'Ciudad Santo Domingo Tehuantepec,Santo Domingo,Santo Domingo Tecuantepec,Santo Domingo Tehuantepec,Santo Domingo Tēcuāntepēc,Santo Domingo de Tehuantepec,Santo-Domingo-Teuantepek,Tehuantepec,Санто-Доминго-Теуантепек', 16.3246300, -95.2410400, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94472, 'Santo Domingo Shomege (Shomege)', 'Santo Domingo Shomege (Shomege)', 'Santo Domingo Shomege,Santo Domingo Shomegé,Shomege,Shomeje,Shomejé', 19.8452400, -99.9016600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94473, 'Santo Domingo Huehuetlán', 'Santo Domingo Huehuetlan', 'Huehuetlan,Santo Domingo,Santo Domingo Huehuetlan,Santo Domingo Huehuetlán', 18.7394000, -98.1643800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94474, 'Santo Domingo Atoyatempan', 'Santo Domingo Atoyatempan', 'Santo Domingo,Santo Domingo Atoyatempan', 18.9044400, -98.3730600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94475, 'Albarradas', 'Albarradas', 'Albarradas,Santo Domingo,Santo Domingo Albarradas', 17.0675200, -96.2001200, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94476, 'Santo Domingo de Guzmán', 'Santo Domingo de Guzman', 'Santo Domingo,Santo Domingo de Guzman,Santo Domingo de Guzmán', 19.5930600, -99.7797200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94477, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo,Santo Domíngo', 15.0306700, -92.1036100, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94478, 'Santiago Zoochila', 'Santiago Zoochila', 'Santiago,Santiago Zoochila,Zoochila', 17.2205900, -96.2421200, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94479, 'Zautla', 'Zautla', 'Santa Cruz,Santiago Zautla,Zautla', 19.7147500, -97.6714600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94480, 'Santiago Yaitepec', 'Santiago Yaitepec', 'Santiago Yaitepec,Yaitepec,Yautepec', 16.2262800, -97.2695300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94481, 'Santiago Tuxtla', 'Santiago Tuxtla', 'Juan de la Luz Enriquez,Juan de la Luz Enríquez,Santiago Tuxtla,Tuxtla,Tuxtla Colorada', 18.4657600, -95.3006000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94482, 'Texcaltitlán', 'Texcaltitlan', 'Santiago,Santiago Texcaltitlan,Santiago Texcaltitlán,Tescatitlan,Texcaltitlan,Texcaltitlán', 18.9303200, -99.9387000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94483, 'Santiago Texcalcingo', 'Santiago Texcalcingo', 'Santiago Texcalcingo,Texcalcingo,Texcaltzingo', 18.2083500, -96.9688700, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94484, 'Sección Primera Santiago Tetla', 'Seccion Primera Santiago Tetla', 'Atipa,Santiago,Santiago Tetla,Seccion Primera Santiago Tetla,Sección Primera Santiago Tetla,Tetla,Tetla Primera Seccion,Tetla Primera Sección', 19.4327600, -98.1040700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94485, 'Santiago Suchilquitongo', 'Santiago Suchilquitongo', 'Santiago Suchilquitongo,Santiago Xuchilquitongo,Santiango Xuchilquitongo,Suchilquitongo,Suchiquiltongo', 17.2531600, -96.8782500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94486, 'Pinotepa Nacional', 'Pinotepa Nacional', 'PNO,Pinotepa,Pinotepa Nacional,Santiago Pinotepa Nacional', 16.3401400, -98.0529700, 'MX', '2017-04-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94487, 'Santiago Nuyoó', 'Santiago Nuyoo', 'Nuyoc,Santiago,Santiago Nuyoo,Santiago Nuyoó', 17.0144900, -97.7665900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94488, 'Santiago Nundíche', 'Santiago Nundiche', 'Nudiche,Nundiche,Santiago,Santiago Nundiche,Santiago Nundichi,Santiago Nundíche', 17.3313600, -97.6739200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94489, 'Santiago Nejapilla', 'Santiago Nejapilla', 'Nejapilla,Santiago,Santiago Nejapilla', 17.4198300, -97.3741100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94490, 'Santiago Miltepec', 'Santiago Miltepec', 'Miltepec,Santiago,Santiago Miltepec', 17.9846100, -97.6900600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94491, 'Miahuatlán', 'Miahuatlan', 'Miahuatlan,Miahuatlán,Santiago,Santiago Miahuatlan,Santiago Miahuatlán', 18.5498300, -97.4395300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94492, 'Santiago Matatlán', 'Santiago Matatlan', 'Matatlan,Matatlan Quialana,Matatlán Quialana,Santiago Matatatlan,Santiago Matatatlán,Santiago Matatlan,Santiago Matatlán', 16.8647000, -96.3826100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94493, 'Santiago Laxopa', 'Santiago Laxopa', 'Laxopa,Santiago Laxopa', 17.2184200, -96.3109900, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94494, 'Santiago Lalopa', 'Santiago Lalopa', 'Lalopa,Santiago Lalopa', 17.4178600, -96.2489300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94495, 'Santiago Juxtlahuaca', 'Santiago Juxtlahuaca', 'Justlahuaca,Juxtlahuaca,Santiago,Santiago Juxtlahuaca', 17.3346200, -98.0114700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94496, 'Jamiltepec', 'Jamiltepec', 'Jamiltepec,Santiago,Santiago Jamiltepec', 16.2825800, -97.8244600, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94497, 'Santiago Huauclilla', 'Santiago Huauclilla', 'Hoauclilla,Huanelilla,Santiago Huauclilla', 17.4517900, -97.0727700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94498, 'Santiago Huajolotitlán', 'Santiago Huajolotitlan', 'Huajolotitlan,Santiago Huajolotitlan,Santiago Huajolotitlán', 17.8278300, -97.7326600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94499, 'Santiago de la Peña', 'Santiago de la Pena', 'Santiago de la Pena,Santiago de la Peña', 20.9451200, -97.4049300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94500, 'Santiago Comaltepec', 'Santiago Comaltepec', 'Comaltepec,Santiago,Santiago Comaltepec', 17.5654700, -96.5487300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94501, 'Santiago Choápam', 'Santiago Choapam', 'Choapam,Choapan,Choápam,Santiago,Santiago Choapam,Santiago Choapan,Santiago Choápam', 17.3608400, -95.9221900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94502, 'Santiago Chazumba', 'Santiago Chazumba', 'Chazumba,Santiago,Santiago Chazumba', 18.1901200, -97.6798300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94503, 'Santiago Ayuquililla', 'Santiago Ayuquililla', 'Ayuquila,Ayuquililla,Santiago,Santiago Ayuquililla', 17.9331000, -97.9576900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94504, 'Santiago Atzitzihuacán', 'Santiago Atzitzihuacan', 'Atzilzihuacan,Atzitzihuacan,Santiago Atzitzihuacan,Santiago Atzitzihuacán', 18.8247200, -98.5816700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94505, 'Santiago Astata', 'Santiago Astata', 'Astata,Santiago,Santiago Astata', 15.9877500, -95.6757100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94506, 'Apoala', 'Apoala', 'Apoaja,Apoala,Santiago,Santiago Apaola,Santiago Apoala', 17.6484500, -97.1360800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94507, 'Santiago Alseseca', 'Santiago Alseseca', 'Alseseca,Santiago,Santiago Alseseca,Santiago Alsesecan', 18.8451100, -97.7071600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94508, 'Santiago Acutzilapan', 'Santiago Acutzilapan', 'Acotzilapan,Acutzilapan,Santiago Acutzilapan,Santiaguito Acultzilapan', 19.7864000, -99.7656900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94509, 'Santiago Acatlán', 'Santiago Acatlan', 'Acatlan,Acatlán,Santiago,Santiago Acatlan,Santiago Acatlán', 18.9933400, -97.9337500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94510, 'Santiago Tulantepec', 'Santiago Tulantepec', 'Santiago,Santiago Tulantepec,Santiago Tulantepec de Lugo Guerrero', 20.0361800, -98.3556300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94511, 'Santa Rosalía', 'Santa Rosalia', 'Santa Rosalia,Santa Rosalía', 18.0885100, -93.3580600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94512, 'Santa Rita Tlahuapan', 'Santa Rita Tlahuapan', 'Santa Rita Tlahuapan,Tlahuapan', 19.3321100, -98.5768800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94513, 'Santander Jiménez', 'Santander Jimenez', 'Jimenez,Jiménez,Santander,Santander Jimenez,Santander Jiménez', 24.2168200, -98.4843300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94514, 'Santa María Zoquitlán', 'Santa Maria Zoquitlan', 'Santa Maria,Santa Maria Zoquitlan,Santa María,Santa María Zoquitlán,Zoquitlan', 16.5588600, -96.3532500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94515, 'Santa María Zacatepec', 'Santa Maria Zacatepec', 'Santa Maria Zacatepec,Santa María Zacatepec,Zacatepec', 16.7636900, -97.9902800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94516, 'Santa María Yavesía', 'Santa Maria Yavesia', 'Santa Maria Yavesia,Santa María Yavesía,Yavesia', 17.2353100, -96.4306200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94517, 'Yalina', 'Yalina', 'Santa Maria,Santa Maria Yalina,Santa María,Santa María Yalina,Yalina', 17.2396900, -96.2623300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94518, 'Santa María Xonacatepec', 'Santa Maria Xonacatepec', 'Santa Maria,Santa Maria Xonacatepec,Santa María,Santa María Xonacatepec,Xonacatepec', 19.0894400, -98.1036100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94519, 'Santa María Xadani', 'Santa Maria Xadani', 'Santa Maria,Santa Maria Xabani,Santa Maria Xadani,Santa María,Santa María Xabani,Santa María Xadani,Xadani', 15.9482500, -96.0736400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94520, 'Santa María Tonameca', 'Santa Maria Tonameca', 'Santa Maria Tonameca,Santa María Tonameca,Tonameca', 15.7480500, -96.5470400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94521, 'Tlahuitoltepec', 'Tlahuitoltepec', 'Santa Maria,Santa Maria Tlahuitoltepec,Santa María,Santa María Tlahuitoltepec,Tlacuilotepec,Tlahuilotepec,Tlahuitoltepec', 17.0974600, -96.0627900, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94522, 'Santa María Tepantlali', 'Santa Maria Tepantlali', 'Santa Maria Tepantlali,Santa María Tepantlali,Tepantlali,Tepentlali', 16.9966300, -96.0088300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94523, 'Santa María Teopoxco', 'Santa Maria Teopoxco', 'Santa Maria,Santa Maria Teopoxco,Santa María,Santa María Teopoxco,Teopoxco,Tepoxco', 18.1665500, -96.9548800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94524, 'Santa María Sola', 'Santa Maria Sola', 'Santa Maria,Santa Maria Sola,Santa María,Santa María Sola,Sola,Sola de Vega', 16.5661500, -97.0129700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94525, 'Santa María Rayón', 'Santa Maria Rayon', 'Maria,Rayon,Rayón,Santa Maria Rayon,Santa María Rayón', 19.1480800, -99.5797400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94526, 'Santa María Petapa', 'Santa Maria Petapa', 'Petapa,Santa Maria,Santa Maria Petapa,Santa María Petapa', 16.8206000, -95.1191300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94527, 'Nopaltepec', 'Nopaltepec', 'Nopaltepec,Santa Maria,Santa Maria Nopaltepec,Santa María Nopaltepec', 19.7782900, -98.7104600, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94528, 'Santa María Nduayaco', 'Santa Maria Nduayaco', 'Nduayaco,Nduayoco,Santa Maria,Santa Maria Nduayaco,Santa María,Santa María Nduayaco', 17.4099600, -97.4932100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94529, 'Santa María Nativitas', 'Santa Maria Nativitas', 'Nativitas,Natívitas,Santa Maria,Santa Maria Nativitas,Santa María Nativitas', 19.5811300, -99.6085700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94530, 'Nativitas', 'Nativitas', 'Nativitas,Santa Maria,Santa Maria Nativitas,Santa Maria Natiyitas,Santa María Nativitas,Santa María Natiyitas', 17.6616000, -97.3356600, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94531, 'Moyotzingo', 'Moyotzingo', 'Moyatzingo,Moyotzingo,Santa Maria Moyotzingo,Santa María Moyotzingo', 19.2481100, -98.4048600, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94532, 'Santa María Mazatla', 'Santa Maria Mazatla', 'Mazatla,Santa Maria,Santa Maria Mazatla,Santa María Mazatla', 19.5152800, -99.3869400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94533, 'Santa María Magdalena Cahuacán', 'Santa Maria Magdalena Cahuacan', 'Cacahuacan,Cacahuacán,Cahuacan,Cahuacán,Ejido de Cahuacan,Ejido de Cahuacán,Maria Magdalena,María Magdalena,Santa Maria Magdalena Cahuacan,Santa María Magdalena Cahuacán', 19.6316100, -99.4112300, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94534, 'Santa María la Alta', 'Santa Maria la Alta', 'Santa Maria,Santa Maria la Alta,Santa María,Santa María la Alta', 18.5998200, -97.6580900, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94535, 'Santa María la Asunción', 'Santa Maria la Asuncion', 'Jiotes,Santa Maria,Santa Maria Jiotes,Santa María,Santa María Jiotes', 18.1072200, -96.8191700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94536, 'Santa María Jicaltepec', 'Santa Maria Jicaltepec', 'Jicaltepec,Santa Maria Jicaltepec,Santa María Jicaltepec', 16.3791700, -98.0433300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94537, 'Santa María Ixtiyucán', 'Santa Maria Ixtiyucan', 'Ixtayucan,Ixtiyucan,Santa Maria Ixtiyucan,Santa María Ixtiyucan,Santa María Ixtiyucán', 19.1868800, -97.8109400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94538, 'Santa María Huazolotitlán', 'Santa Maria Huazolotitlan', 'Huazolotitlan,Santa Maria,Santa Maria Huazolotitlan,Santa María Huazolotitlan,Santa María Huazolotitlán', 16.3035900, -97.9129300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94539, 'Santa María Huatulco', 'Santa Maria Huatulco', 'HUX,Huatulco,Santa Maria,Santa Maria Huatulco,Santa María,Santa María Huatulco', 15.8326700, -96.3206300, 'MX', '2016-02-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94540, 'Santa María Ecatepec', 'Santa Maria Ecatepec', 'Ecatepec,Santa Maria,Santa Maria Ecatepec,Santa María Ecatepec', 16.2849800, -95.8799700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94541, 'Santa María del Tule', 'Santa Maria del Tule', 'Santa Maria del Tule,Santa María del Tule,Tule', 17.0471200, -96.6357300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94542, 'Santa María del Monte', 'Santa Maria del Monte', 'Santa Maria,Santa Maria del Monte,Santa María del Monte', 19.2897300, -99.8235500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94543, 'Santa María Cortijo', 'Santa Maria Cortijo', 'Cortijo,Cortijos,Santa Maria Cortijo,Santa Maria Cortijos,Santa María Cortijo,Santa María Cortijos', 16.4515100, -98.2854900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94544, 'Coronango', 'Coronango', 'Coronanco,Coronango,Santa Maria,Santa Maria Coronanco,Santa Maria Coronango,Santa María Coronanco,Santa María Coronango', 19.1209000, -98.3059400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94545, 'Santa María Colotepec', 'Santa Maria Colotepec', 'Colotepec,Puerto Colotepec,Santa Maria Colotepec,Santa María Colotepec', 15.8973700, -96.9395100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94546, 'Santa María Chimalhuacán', 'Santa Maria Chimalhuacan', 'Chimalhuacan,Chimalhuacán,Santa Maria Chimalhuacan,Santa María Chimalhuacán', 19.4215500, -98.9503800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94547, 'Santa María Chilapa de Díaz', 'Santa Maria Chilapa de Diaz', 'Chilapa,Chilapa de Diaz,Chilapilla,Santa Maria,Santa Maria Chilapa de Diaz,Santa María,Santa María Chilapa de Díaz', 17.5166700, -97.6833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94548, 'Santa María Chachoápam', 'Santa Maria Chachoapam', 'Chachoapan,Santa Maria Chachoapam,Santa Maria Chachoapan,Santa María Chachoapam,Santa María Chachoapan,Santa María Chachoápam', 17.5257000, -97.2842200, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94549, 'Santa María Camotlán', 'Santa Maria Camotlan', 'Camotlan,Santa Maria Camotlan,Santa María Camotlán', 17.8968800, -97.6920000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94550, 'Ayoquezco de Aldama', 'Ayoquezco de Aldama', 'Ayoquezco,Ayoquezco de Aldama,Santa Maria,Santa Maria Ayoquezco de Aldama,Santa María Ayoquezco de Aldama', 16.6837000, -96.8428700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94551, 'Heroica Ciudad de Tlaxiaco', 'Heroica Ciudad de Tlaxiaco', 'Heroica Ciudad de Tlaxiaco,Santa Maria Asuncion Tlaxiaco,Santa María Asunción Tlaxiaco,Tlaxiaco', 17.2691600, -97.6805300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94552, 'Santa María Apazco', 'Santa Maria Apazco', 'Apasco,Apaxco,Santa Maria,Santa Maria Apasco,Santa Maria Apazco,Santa María Apasco,Santa María Apazco', 17.6343300, -97.1003400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94553, 'Santa María Ajoloapan', 'Santa Maria Ajoloapan', 'Ajoloapan,Santa Maria,Santa Maria Ajoloapan,Santa María Ajoloapan', 19.9769400, -99.0447200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94554, 'Acuexcomac', 'Acuexcomac', 'Acuescomac,Acuexcomac,Santa Maria Acuexcomac,Santa María Acuexcomac', 19.0374200, -98.3850100, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94555, 'Santa María Acú', 'Santa Maria Acu', 'Acu,Acú,Santa Maria Acu,Santa María Acú', 20.5464400, -90.1636500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94556, 'Santa María Huecatitla', 'Santa Maria Huecatitla', '', 19.7251100, -99.1691100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94557, 'Santa Rita', 'Santa Rita', '', 16.1316700, -91.9750000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94558, 'Santa Isabel Cholula', 'Santa Isabel Cholula', 'Santa Isabel,Santa Isabel Cholula', 18.9966700, -98.3794400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94559, 'Santa Inés del Monte', 'Santa Ines del Monte', 'Santa Ines,Santa Ines del Monte,Santa Inés del Monte', 16.9238700, -96.8623800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94560, 'Ahuatempan', 'Ahuatempan', 'Ahuatempan,Santa Ines,Santa Ines Ahuatempan,Santa Inés,Santa Inés Ahuatempan', 18.4126900, -98.0185000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94561, 'El Carrizal', 'El Carrizal', 'El Carrizal,Santa Gertrudis,Santa Gertrudis Miramar', 16.0643800, -95.3930800, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94562, 'Santa Gertrudis', 'Santa Gertrudis', '', 19.7333300, -99.3666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94563, 'Santa Gertrudis', 'Santa Gertrudis', 'Gertrudis,Santa Gertrudis', 16.7858000, -96.8002400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94564, 'Guillermo Zúñiga', 'Guillermo Zuniga', 'Guillermo Zuniga,Guillermo Zúñiga,Santa Engracia', 24.0154800, -99.2007400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94565, 'Santa Elena', 'Santa Elena', 'Santa Elena', 20.3289000, -89.6436300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94566, 'Santa Cruz Xoxocotlán', 'Santa Cruz Xoxocotlan', 'Santa Cruz,Santa Cruz Xoxocotlan,Santa Cruz Xoxocotlán,Xoxocotlan', 17.0295800, -96.7351800, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94567, 'Santa Cruz Xitla', 'Santa Cruz Xitla', 'Santa Cruz Xitla,Xitla', 16.3232100, -96.6736900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94568, 'Manzana Tercera de Santa Cruz Tepexpan', 'Manzana Tercera de Santa Cruz Tepexpan', 'Santa Cruz,Santa Cruz Tepexpan,Tepexpan', 19.5691700, -99.7036100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94569, 'Tecámac', 'Tecamac', 'Santa Cruz,Santa Cruz Tecamac,Tecama,Tecamac,Tecamac de Felipe Villanueva,Tecámac', 19.7128800, -98.9689500, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94570, 'Santa Cruz Tayata', 'Santa Cruz Tayata', 'Santa Cruz,Santa Cruz Tayata,Tayata', 17.3571800, -97.5684300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94571, 'Santa Cruz Nundaco', 'Santa Cruz Nundaco', 'Mundaco,Nundaco,Santa Cruz,Santa Cruz Nundaco', 17.1710900, -97.7238200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94572, 'Santa Cruz Mixtepec', 'Santa Cruz Mixtepec', 'Mixtepec,Santa Cruz,Santa Cruz Mixtepec', 16.7928300, -96.8807200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94573, 'Santa Cruz Tlaxcala', 'Santa Cruz Tlaxcala', 'Santa Cruz,Santa Cruz Guadalupe Ixcotla,Santa Cruz Tlaxcala', 19.3546800, -98.1507600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94574, 'Santa Cruz Cuauhtenco', 'Santa Cruz Cuauhtenco', 'Cuauhtenco,Cuautenco,Santa Cruz,Santa Cruz Cuauhtenca,Santa Cruz Cuauhtenco,Santa Cruz Cuautenco', 19.2490700, -99.7293900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94575, 'Santa Clara', 'Santa Clara', 'Ocoyucan,Ocuyucan,Santa Clara', 18.9761600, -98.3014000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94576, 'Santa Clara Huitziltepec', 'Santa Clara Huitziltepec', 'Huitziltepec,Santa Clara,Santa Clara Huitziltepec', 18.7689000, -97.8811700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94577, 'Santa Catarina Tlaltempan', 'Santa Catarina Tlaltempan', 'Santa Catarina,Santa Catarina Tlaltempa,Santa Catarina Tlaltempan,Tlaltempan,Tlatempan', 18.6154100, -98.0808000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94578, 'Santa Catarina Tayata', 'Santa Catarina Tayata', 'Santa Catarina,Santa Catarina Tayata,Tayata', 17.3471500, -97.5582200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94579, 'Santa Catarina Quiané', 'Santa Catarina Quiane', 'Quiane,Santa Catarina Quiane,Santa Catarina Quiané', 16.8825500, -96.7406700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94580, 'Pantelhó', 'Pantelho', 'Pantelho,Pantelhó,Santa Catarina,Santa Catarina Pantelho,Santa Catarina Pantelhó', 17.0056300, -92.4716500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94581, 'Santa Catarina Otzolotepec', 'Santa Catarina Otzolotepec', 'Otzolotepec,Santa Catarina Otzolotepec', 18.5770500, -97.2660300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94582, 'Santa Catarina Minas', 'Santa Catarina Minas', 'Minas,Santa Catarina Minas', 16.7796900, -96.6153600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94583, 'Santa Catarina Mechoacán', 'Santa Catarina Mechoacan', 'Mechoacan,Santa Catalina Mechoacan,Santa Catalina Mechoacán,Santa Catarina,Santa Catarina Mechoacan,Santa Catarina Mechoacán', 16.3359100, -97.8370700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94584, 'Santa Catarina Loxicha', 'Santa Catarina Loxicha', 'Santa Catarina,Santa Catarina Loxicha', 16.0686400, -96.7539100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94585, 'Santa Catarina Juquila', 'Santa Catarina Juquila', 'Juquila,Santa Catarina,Santa Catarina Juquila', 16.2381900, -97.2916100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94586, 'Santa Catarina Cuixtla', 'Santa Catarina Cuixtla', 'Cuixtla,Santa Catarina,Santa Catarina Cuixtla', 16.3061600, -96.6423600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94587, 'Santa Catarina Ayotzingo', 'Santa Catarina Ayotzingo', 'Ayotzingo,Santa Catarina Ayotzingo', 19.2094800, -98.9298500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94588, 'Santa Catarina', 'Santa Catarina', 'Santa Catarina,Santa Catarina Zacatepec,Santa-Katarina,Санта-Катарина', 18.9697200, -99.1402800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94589, 'Santa Ana Tlapacoyan', 'Santa Ana Tlapacoyan', 'Santa Ana,Santa Ana Tlapacoyan,Tlapacoyan', 16.7434000, -96.8368800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94590, 'Nextlalpan', 'Nextlalpan', 'Nextlalpan,Santa Ana Nextlalpan', 19.7417100, -99.0749600, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94591, 'Santa Ana Jilotzingo', 'Santa Ana Jilotzingo', 'Jilotzingo,Santa Ana,Santa Ana Jilotzingo', 19.5411600, -99.3947700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94592, 'Santa Anita Huiloac', 'Santa Anita Huiloac', 'Huiloac,Santa Ana Huiloac,Santa Anita Huiloac', 19.3884100, -98.1436200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94593, 'Santa Ana Hueytlalpan', 'Santa Ana Hueytlalpan', 'Santa Ana,Santa Ana Heytalpan,Santa Ana Hueytlalpan', 20.1748400, -98.3120900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94594, 'Santa Ana del Valle', 'Santa Ana del Valle', 'Santa Ana,Santa Ana del Valle', 16.9948800, -96.4711200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94595, 'Santa Ana Coatepec', 'Santa Ana Coatepec', 'Coatepec,Santa Ana,Santa Ana Coatepec', 18.8366700, -98.4347200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94596, 'Chiautempan', 'Chiautempan', 'Chiautempan,Santa Ana,Santa Ana Chiautempan', 19.3063300, -98.2177300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94597, 'Santa Ana Acozautla', 'Santa Ana Acozautla', 'Acozantla,Santa Ana Acozautla', 18.9555600, -98.3830600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94598, 'Santa Ana Ixtlahuatzingo (Santa Ana)', 'Santa Ana Ixtlahuatzingo (Santa Ana)', '', 18.9705600, -99.6236100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94599, 'Santa Ana', 'Santa Ana', 'Santa Ana', 17.0545500, -95.0850900, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94600, 'Santa Ana', 'Santa Ana', 'Santa Ana', 16.3413900, -96.7169700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94601, 'San Simonito', 'San Simonito', '', 18.9913900, -99.5400000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94602, 'San Simón Almolongas', 'San Simon Almolongas', 'Almoloneas,Almolongas,San Simon Almolongas,San Simón Almolongas', 16.4065900, -96.7192700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94603, 'Zinacatepec', 'Zinacatepec', 'San Sebastian,San Sebastian Zinacatepec,San Sebastián,San Sebastián Zinacatepec,Zinacatepec', 18.3351600, -97.2462100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94604, 'San Sebastián Villanueva', 'San Sebastian Villanueva', 'San Sebastian,San Sebastian Villanueva,San Sebastián,San Sebastián Villanueva,Villanueva', 19.0608500, -97.7193500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94605, 'Santa María Tutla', 'Santa Maria Tutla', 'San Sebastian,San Sebastian Tutla,San Sebastián Tutla,Santa Maria Tutla,Santa María Tutla,Tulla,Tutla', 17.7049300, -97.6401600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94606, 'San Sebastian Teitipac', 'San Sebastian Teitipac', 'San Sebastian,San Sebastian Teitipac,San Sebastian Teitipal,San Sebastián,San Sebastián Teitipac,San Sebastián Teitipal,Teitipac', 16.9519200, -96.6142700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94607, 'San Sebastián Coatlán', 'San Sebastian Coatlan', 'Coatlan,San Sebastian,San Sebastian Coatlan,San Sebastián Coatlán', 16.2021200, -96.8264500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94608, 'San Sebastián Abasolo', 'San Sebastian Abasolo', 'Abasolo,San Sebastian Abasolo,San Sebastián Abasolo', 16.9943200, -96.5870100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94609, 'Huixcolotla', 'Huixcolotla', 'Huixcolotla,Huizcolotla,San Salvador Huixcolotla', 18.9207300, -97.7716600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94610, 'San Salvador el Verde', 'San Salvador el Verde', 'San Salvador,San Salvador el Verde', 19.2700200, -98.5164800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94611, 'San Salvador El Seco', 'San Salvador El Seco', 'El Seco,San Salvador El Seco', 19.1332500, -97.6416700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94612, 'San Salvador Atenco', 'San Salvador Atenco', 'Atenco,San Salvador Atenco', 19.5517000, -98.9186700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94613, 'San Salvador', 'San Salvador', 'San Salvador', 20.2858300, -99.0145700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94614, 'San Raymundo Jalpam', 'San Raymundo Jalpam', 'Jalpan,San Raymundo Jalpam,San Raymundo Jalpan', 16.9716400, -96.7569900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94615, 'San Rafael', 'San Rafael', 'San Rafael', 20.1886200, -96.8673700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94616, 'San Pedro y San Pablo Tequistepec', 'San Pedro y San Pablo Tequistepec', 'San Miguel,San Miguel Tequixtepec,San Pablo,San Pedro y San Pablo Tequistepec,San Pedro y San Pablo Tequixtepec,Tequistepec,Tequixtepec', 18.0610600, -97.7181600, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94617, 'Villa de Etla', 'Villa de Etla', 'Etla,San Pedro,San Pedro y San Pablo Etla,Villa de Etla', 17.2061500, -96.7989000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94618, 'Ayutla', 'Ayutla', 'Ayutla,San Pablo,San Pedro y San Pablo Ayutla', 17.0275600, -96.0763200, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94619, 'San Pedro Yólox', 'San Pedro Yolox', 'San Pedro,San Pedro Yolox,San Pedro Yólox,Yolox', 17.5890700, -96.5523500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94620, 'San Pedro Topiltepec', 'San Pedro Topiltepec', 'San Pedro Topiltepec,Topiltepec', 17.4363300, -97.3440300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94621, 'San Pedro Tlanixco', 'San Pedro Tlanixco', 'San Pedro,San Pedro Tlanisco,San Pedro Tlanixco,Tlanisco,Tlanixco', 19.0625900, -99.6523700, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94622, 'San Pedro Tidaá', 'San Pedro Tidaa', 'San Pedro Tidaa,San Pedro Tidaá,Tida,Tidaa', 17.3412200, -97.3723900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94623, 'San Pedro Tetitlán', 'San Pedro Tetitlan', 'San Pedro,San Pedro Tetitlan,San Pedro Tetitlán,Tetitlan', 18.2597200, -97.3230600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94624, 'San Pedro Taviche', 'San Pedro Taviche', 'San Pedro,San Pedro Taviche,Taviche', 16.6385800, -96.5368700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94625, 'San Pedro Tapanatepec', 'San Pedro Tapanatepec', 'San Pedro,San Pedro Tapanatepec,Tapanatepec,Tepanatepec', 16.3710700, -94.1931300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94626, 'San Pedro Quiatoni', 'San Pedro Quiatoni', 'Quiatoni,San Pedro,San Pedro Quiatoni', 16.7829500, -96.0308500, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94627, 'San Pedro Pochutla', 'San Pedro Pochutla', 'PUH,Pochutla,San Pedro,San Pedro Pochutla', 15.7458700, -96.4660100, 'MX', '2017-07-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94628, 'San Pedro Mixtepec', 'San Pedro Mixtepec', 'Mixtepec,San Pedro,San Pedro Mixtepec,San Pedro Mixtepec Miahuatlan,San Pedro Mixtepec Miahuatlán', 16.2706000, -96.2840600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94629, 'San Pedro Mixtepec', 'San Pedro Mixtepec', 'Juquila,Mixtepec,Pedro,San Pedro,San Pedro Mixtepec,San Pedro Mixtepec Juquila', 15.9821100, -97.0798400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94630, 'San Pedro Mártir Quiechapa', 'San Pedro Martir Quiechapa', 'Quiechapa,San Pedro Martir,San Pedro Martir Quiechapa,San Pedro Mártir Quiechapa,San Pedro Quiechapa', 16.4151600, -96.2445100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94631, 'San Pedro Los Baños', 'San Pedro Los Banos', 'Los Banos,Los Baños,San Pedro,San Pedro Los Banos,San Pedro Los Baños', 19.6253700, -99.8217000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94632, 'San Pedro Jicayán', 'San Pedro Jicayan', 'Jicayan,San Pedro Jicayacan,San Pedro Jicayan,San Pedro Jicayán', 16.4517900, -98.0142500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94633, 'Jaltepetongo', 'Jaltepetongo', 'Jaltepetongo,San Francisco,San Francisco Jaltepetongo,San Pedro Jaltepetongo', 17.6862300, -97.0356900, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94634, 'San Pedro Ixcatlán', 'San Pedro Ixcatlan', 'Ixcatlan,San Pedro,San Pedro Ixcatlan,San Pedro Ixcatlán,Yxcatlan', 18.1457500, -96.5095300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94635, 'San Pedro Huamelula', 'San Pedro Huamelula', 'Huamelula,San Pedro,San Pedro Huamelula', 16.0269700, -95.6673500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94636, 'San Pedro el Alto', 'San Pedro el Alto', 'San Pedro,San Pedro El Alto', 19.9105600, -99.9636100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94637, 'San Pedro el Alto', 'San Pedro el Alto', 'San Pedro,San Pedro Alto,San Pedro el Alto', 19.5842900, -99.8805000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94638, 'Cajonos', 'Cajonos', 'Cajonos,San Pedro,San Pedro Cajonos', 17.1680100, -96.2617400, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94639, 'San Pedro Buenavista', 'San Pedro Buenavista', '', 16.0833300, -93.1166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94640, 'San Pedro Atoyac', 'San Pedro Atoyac', 'Atoyac,San Pedro,San Pedro Atoyac', 16.4900500, -97.9858500, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94641, 'Ciudad de Atlixco', 'Ciudad de Atlixco', 'Atlixco,Ciudad de Atlixco,San Pedro,San Pedro Atlixco', 18.9037200, -98.4392200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94642, 'San Pedro Apóstol', 'San Pedro Apostol', 'Apostol,Pedro Apostol,San Pedro Apostol,San Pedro Apóstol', 16.7369500, -96.7247400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94643, 'Yaganiza', 'Yaganiza', 'San Pablo,San Pablo Yaganiza,Yaganiza', 17.1449500, -96.2296000, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94644, 'San Pablo Villa de Mitla', 'San Pablo Villa de Mitla', 'Mitla,San Pablo,San Pablo Villa de Mitla,mitora,ミトラ', 16.9228300, -96.3599000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94645, 'San Pablo Tolimán', 'San Pablo Toliman', 'San Pablo,San Pablo Toliman,San Pablo Tolimán', 20.8570300, -99.8998500, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94646, 'San Pablo Tecalco', 'San Pablo Tecalco', 'San Pablo,San Pablo Tecalco,Tecalco', 19.6730900, -98.9583700, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94647, 'San Pablo Macuiltianguis', 'San Pablo Macuiltianguis', 'Macuiltianguis,Macuiltlanguis,San Pablo,San Pablo Macuiltianguis,San Pablo Macultianguis', 17.5334800, -96.5521200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94648, 'San Pablo Huixtepec', 'San Pablo Huixtepec', 'Huixtepec,San Pablo,San Pablo Huixtepec', 16.8194800, -96.7812800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94649, 'San Pablo Huitzo', 'San Pablo Huitzo', 'Huitzo,San Pablo Huitzo', 17.2770800, -96.8866100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94650, 'San Pablo de las Tunas', 'San Pablo de las Tunas', 'Pablo de las Tunas,San Pablo,San Pablo de las Tunas', 18.9955600, -97.7097200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94651, 'San Pablo de las Salinas', 'San Pablo de las Salinas', 'Salinas,San Pablo,San Pablo de Salinas,San Pablo de las Salinas', 19.6665800, -99.0947700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94652, 'San Pablo Coatlán', 'San Pablo Coatlan', 'Coatlan,San Pablo,San Pablo Coatlan,San Pablo Coatlán', 16.2242900, -96.7837900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94653, 'Chalchihuitán', 'Chalchihuitan', 'Chalchihuitan,Chalchihuitán,San Pablo Chalchihuitan', 16.9644500, -92.6190300, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94654, 'San Pablo Autopan', 'San Pablo Autopan', 'Autopan,San Pablo,San Pablo Autopan', 19.3563800, -99.6572400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94655, 'San Pablo Atlazalpan', 'San Pablo Atlazalpan', 'Atlazalpan,San Pablo Atlazalpan', 19.2174200, -98.9076300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94656, 'Apetatitlán Antonio Carbajal', 'Apetatitlan Antonio Carbajal', 'Apetatitlan,Apetatitlan Antonio Carbajal,Apetatitlán,Apetatitlán Antonio Carbajal,Apetatlitlan,Apetitlan,San Pablo,San Pablo Apetatitlan,San Pablo Apetatitlán', 19.3362200, -98.1791200, 'MX', '2015-07-25', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94657, 'San Nicolás de los Ranchos', 'San Nicolas de los Ranchos', 'Nicolas de los Ranchos,San Nicolas de los Ranchos,San Nicolás de los Ranchos', 19.0713900, -98.4860100, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94658, 'San Nicolas Buenos Aires', 'San Nicolas Buenos Aires', 'San Nicolas,San Nicolas Buenos Aires,San Nicolas de Buenos Aires,San Nicolás,San Nicolás de Buenos Aires', 19.1648800, -97.5513100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94659, 'San Nicolás Coatepec', 'San Nicolas Coatepec', 'Bateas,Coatepec,Coatepec de las Bateas,San Nicolas Coatepec,San Nicolás Coatepec', 19.1373500, -99.4294800, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94660, 'San Nicolás', 'San Nicolas', 'San Nicolas,San Nicolás', 20.4768900, -99.9374900, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94661, 'San Miguel Zozutla', 'San Miguel Zozutla', 'San Miguel,San Miguel Zozutla,Zozutla', 18.7543000, -97.6547800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94662, 'San Miguel Zinacantepec', 'San Miguel Zinacantepec', 'San Miguel Zicantepec,San Miguel Zinacantepec,Zinacantepec,Zinacatepec', 19.2842800, -99.7339400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94663, 'San Miguel Xoxtla', 'San Miguel Xoxtla', 'San Miguel Xoxtla,Xoxtla', 19.1676300, -98.3075800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94664, 'Tonalixco', 'Tonalixco', 'San Miguel Tonalixco,Tonalisco,Tonalixco', 19.9811100, -97.8394400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94665, 'San Miguel Contla', 'San Miguel Contla', 'San Miguel,San Miguel Tlamahuco', 19.3611100, -98.1325000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94666, 'San Miguel Tlacamama', 'San Miguel Tlacamama', 'San Miguel Tlacamama,Tlacamama,Tlacamana,Tlacamaná', 16.4154700, -98.0630100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94667, 'San Miguel Tilquiapam', 'San Miguel Tilquiapam', 'San Miguel Tilquiapam,San Miguel Tilquiapan,Tilquiapan', 16.7821800, -96.5816500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94668, 'San Miguel Tenextatiloyan', 'San Miguel Tenextatiloyan', 'San Miguel Tenextatiloyan,Tenextatiloyan', 19.7097300, -97.5976900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94669, 'San Miguel Tenango', 'San Miguel Tenango', 'San Miguel,San Miguel Tenango,Tenango', 16.2665900, -95.5953200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94670, 'Villa Talea de Castro', 'Villa Talea de Castro', 'San Miguel,San Miguel Talea de Castro,Talea,Talea de Castro,Villa Talea de Castro', 17.3598300, -96.2495300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94671, 'San Miguel Quetzaltepec', 'San Miguel Quetzaltepec', 'Quetzaltepec,Quezaltepec,San Miguel,San Miguel Quetzaltepec', 16.9738000, -95.7604500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94672, 'San Miguel Panixtlahuaca', 'San Miguel Panixtlahuaca', 'Pamixtlahuaca,Panixtlahuaca,San Miguel', 16.2484400, -97.3842700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94673, 'San Miguel Oxtotilpan', 'San Miguel Oxtotilpan', 'Los Ranchos,Ostotilpan,Oxtotilpan,San Miguel,San Miguel Oxtotilpan', 19.1508300, -99.8860500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94674, 'San Miguel Ixitlán', 'San Miguel Ixitlan', 'Ixitlan,San Miguel Ixitlan,San Miguel Ixitlán,San Miguel Ixtlan,San Miguel Ixtlán', 18.0008200, -97.7748300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94675, 'Huautepec', 'Huautepec', 'Huantla,Huautepec,Huautla,San Miguel,San Miguel Huautepec,San Miguel Huautla,San Miguel Huautla Teotitlan,San Miguel Huautla Teotitlán', 18.1013800, -96.7959000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94676, 'San Miguel Ejutla', 'San Miguel Ejutla', 'Ejutla,San Miguel,San Miguel Ejutla', 16.5805300, -96.7389700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94677, 'San Miguel del Puerto', 'San Miguel del Puerto', 'San Miguel del Puerto', 15.9216900, -96.1749900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94678, 'San Miguel Coatlinchán', 'San Miguel Coatlinchan', 'Coatlinchan,Coatlinchán,San Miguel,San Miguel Coatlinchan,San Miguel Coatlinchoan,San Miguel Coatlinchán', 19.4499900, -98.8727400, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94679, 'San Miguel Coatlán', 'San Miguel Coatlan', 'Coatlan,San Miguel,San Miguel Coatlan,San Miguel Coatlán', 16.1970100, -96.6945800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94680, 'Chapultepec', 'Chapultepec', 'Chapultepec,San Miguel Chapultepec', 19.2021600, -99.5617600, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94681, 'San Miguel Canoa', 'San Miguel Canoa', 'Canoa,San Miguel Canoa', 19.1519400, -98.1030600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94682, 'San Miguel Balderas', 'San Miguel Balderas', 'Balderas,San Miguel,San Miguel Balderas', 19.1094300, -99.6516500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94683, 'San Miguel Aloápam', 'San Miguel Aloapam', 'Aloapam,Aloapan,San Miguel,San Miguel Aloapam,San Miguel Aloapan,San Miguel Aloápam', 17.4113600, -96.6915400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94684, 'San Miguel Achiutla', 'San Miguel Achiutla', 'Achiutla,San Miguel,San Miguel Achiutla', 17.3090000, -97.4839200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94685, 'San Miguel Tenochtitlán', 'San Miguel Tenochtitlan', 'San Miguel,San Miguel Tenochtitlan,San Miguel Tenochtitlán,Tenochtitlan,Tenochtitlán', 19.7602800, -99.9225000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94686, 'San Matias Tlalancaleca', 'San Matias Tlalancaleca', 'San Matias,San Matias Tlalancaleca,San Matías,San Matías Tlalancaleca,Tlalancaleca,Tlancaleca', 19.3253600, -98.4986300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94687, 'San Mateo Xoloc', 'San Mateo Xoloc', 'San Mateo,San Mateo Xoloc', 19.7065000, -99.2481800, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94688, 'Tlaixpan', 'Tlaixpan', 'San Mateo Tlaixpan,Tlaixpan,Tlalxpan', 18.9121700, -97.7381800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94689, 'San Mateo Texcalyacac', 'San Mateo Texcalyacac', 'San Mateo Texcalyacac,Texcalyacac', 19.1666700, -99.4666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94690, 'San Mateo Piñas', 'San Mateo Pinas', 'Pinas,Piñas,San Mateo,San Mateo Pinas,San Mateo Piñas', 16.0004900, -96.3344900, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94691, 'San Mateo Parra', 'San Mateo Parra', '', 18.9913900, -97.8616700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94692, 'San Mateo Nejápam', 'San Mateo Nejapam', 'Nejapam,Nejapan,San Mateo,San Mateo Nejapam,San Mateo Nejapan,San Mateo Nejápam', 17.6560400, -98.4166200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94693, 'San Mateo Mexicaltzingo', 'San Mateo Mexicaltzingo', 'Mexicalcingo,Mexicaltzingo,San Mateo Mexicalcingo,San Mateo Mexicaltzingo', 19.2113000, -99.5846900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94694, 'San Mateo Ixtacalco', 'San Mateo Ixtacalco', 'San Mateo,San Mateo Ixtacalco', 19.6992000, -99.1715900, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94695, 'San Mateo Yoloxochitlán', 'San Mateo Yoloxochitlan', 'Huautla,San Mateo,San Mateo Eloxochitlan,San Mateo Eloxochitlán,San Mateo Huautla,San Mateo Yoloxochitlan,San Mateo Yoloxochitlán', 18.1434100, -96.8686500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94696, 'San Mateo del Mar', 'San Mateo del Mar', 'San Mateo del Mar', 16.2105400, -94.9821800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94697, 'San Mateo Cajonos', 'San Mateo Cajonos', 'Cajonos,San Mateo,San Mateo Cajones,San Mateo Cajonos', 17.1614700, -96.2077700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94698, 'San Mateo Atenco', 'San Mateo Atenco', 'Atenco,San Mateo,San Mateo Atenco', 19.2675700, -99.5321400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94699, 'San Martín Xaltocan', 'San Martin Xaltocan', 'San Martin,San Martin Xaltocan,San Martín,San Martín Xaltocan,Xaltocan', 19.4215100, -98.2174600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94700, 'Toxpalan', 'Toxpalan', 'San Martin,San Martin Toxpalam,San Martin Toxpalan,San Martín,San Martín Toxpalam,San Martín Toxpalan,Toxpalam,Toxpalan', 18.1012500, -97.0586900, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94701, 'Totoltepec', 'Totoltepec', 'San Martin,San Martin Totoltepec,San Martín,San Martín Totoltepec,Totoltepec', 18.6525500, -98.3470600, 'MX', '2016-03-15', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94702, 'San Martín Tlapala', 'San Martin Tlapala', 'San Martin Tlapala,San Martín Tlapala,Tlapala', 18.9666700, -98.4588900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94703, 'San Martin Texmelucan de Labastida', 'San Martin Texmelucan de Labastida', 'San Martin,San Martin Texmelucan,San Martin Texmelucan de Labastida,San Martín,San Martín Texmelucan,San Martín Texmelucan de Labastida,Texmelucan', 19.2843100, -98.4388500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94704, 'San Pedro la Joya', 'San Pedro la Joya', 'La Joya,San Martin la Joya,San Martín la Joya', 19.0652800, -97.8380600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94705, 'San Martín de los Canseco', 'San Martin de los Canseco', 'San Martin de los Canseco,San Martin de los Cansecos,San Martín de los Canseco', 16.6565500, -96.7277700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94706, 'San Martín de las Pirámides', 'San Martin de las Piramides', 'San Martin,San Martin de las Piramides,San Martín de las Pirámides', 19.7058200, -98.8355400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94707, 'San Marcos Tlacoyalco', 'San Marcos Tlacoyalco', 'San Marcos Tlacoyalco,Tlacoyalco', 18.6738800, -97.6035400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94708, 'Vega de San Marcos', 'Vega de San Marcos', 'San Marcos,Vega de San Marcos', 20.1853900, -96.9487700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94709, 'San Marcos', 'San Marcos', '', 20.0666700, -99.3333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94710, 'San Marcos', 'San Marcos', 'San Marcos', 16.7977200, -99.3892100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94711, 'Teolocholco', 'Teolocholco', 'San Luis Teolocholco,Teolochalco,Teolocholco', 19.2433300, -98.1908300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94712, 'San Luis Amatlán', 'San Luis Amatlan', 'Amatan,Amatlan,Amatlán,Amatán,San Luis Amatlan,San Luis Amatlán', 16.3865200, -96.4982400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94713, 'San Luis Acatlán', 'San Luis Acatlan', 'Acatlan,Luis Acatlan,Luis Acatlán,San Luis Acatlan,San Luis Acatlán', 16.8090100, -98.7333100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94714, 'San Lucas Quiavini', 'San Lucas Quiavini', 'Quiavini,Quiaxini,San Lucas,San Lucas Quiavini', 16.8955500, -96.4681300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94715, 'San Lucas Ojitlán', 'San Lucas Ojitlan', 'Ojitlan,San Lucas,San Lucas Ojitlan,San Lucas Ojitlán', 18.0576700, -96.3982500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94716, 'San Lorenzo Toxico', 'San Lorenzo Toxico', 'San Lorenzo,San Lorenzo Toxico,Toxico', 19.5091700, -99.7627800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94717, 'Texmelucan', 'Texmelucan', 'San Lorenzo,San Lorenzo Texmelucan,Texmelucan', 16.5851000, -97.1990700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94718, 'San Lorenzo Oyamel', 'San Lorenzo Oyamel', 'Oyamel,San Lorenzo,San Lorenzo Oyamel', 19.4335500, -99.5776100, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94719, 'San Lorenzo Chiautzingo', 'San Lorenzo Chiautzingo', 'Chiautzingo,San Lorenzo,San Lorenzo Chiautzingo', 19.2043200, -98.4674700, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94720, 'Almecatla', 'Almecatla', 'Almacatla,Almacatlan,Almacatlán,Almecatla,San Lorenzo,San Lorenzo Almecatla', 19.1428600, -98.2359700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94721, 'San Lorenzo Cuaunecuiltitla', 'San Lorenzo Cuaunecuiltitla', 'San Lorenzo,San Lorenzo Cuaunecuiltitla', 18.2066400, -96.9131500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94722, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 16.3948300, -97.8740300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94723, 'San Juan Yatzona', 'San Juan Yatzona', 'San Juan Yatzona,Yatzona', 17.4018400, -96.1687800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94724, 'San Juan Yaee', 'San Juan Yaee', 'San Juan Yae,San Juan Yaee,San Juan Yaé,Yae,Yaé', 17.4300000, -96.2835500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94725, 'San Juan Xiutetelco', 'San Juan Xiutetelco', 'San Juan Xiutetelco,Xiutetelco', 19.7956300, -97.3257800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94726, 'San Juan Tizahuapán', 'San Juan Tizahuapan', 'San Juan,San Juan Tizahuapan,San Juan Tizahuapán', 20.0507300, -98.6654000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94727, 'Tianguismanalco', 'Tianguismanalco', 'San Juan Tianguismanalco,Tianguismanalco', 18.9762400, -98.4486100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94728, 'San Juan Tepa', 'San Juan Tepa', '', 20.2157900, -99.0659200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94729, 'Teotihuacán', 'Teotihuacan', 'San Juan,San Juan Teotihuacan,San Juan Teotihuacán,Teotihuacan,Teotihuacan de Arista,Teotihuacán,Teotihuacán de Arista', 19.6886200, -98.8611000, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94730, 'San Juan Tejaluca', 'San Juan Tejaluca', 'San Juan Tejalucan,San Luis Tejaluca,Tejalucan', 18.8991700, -98.4047200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94731, 'San Juan Quiotepec', 'San Juan Quiotepec', 'Quiotepec,San Juan Quiotepec', 17.6015600, -96.5873100, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94732, 'San Juan Ozolotepec', 'San Juan Ozolotepec', 'San Juan,San Juan Ozolotepec', 16.1332000, -96.2592500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94733, 'San Juan Mixtepec', 'San Juan Mixtepec', 'Mixtepec,San Juan Mixtepec,Snuviko', 17.3053900, -97.8315800, 'MX', '2016-11-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94734, 'San Juan Mixtepec', 'San Juan Mixtepec', 'Mixtepec,San Agustin,San Agustin Mixtepec,San Augistin,San Augustin,San Juan Mixtepec', 16.2770900, -96.3005700, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94735, 'San Juan de los Cues', 'San Juan de los Cues', 'Los Cues,San Juan,San Juan Los Cues,San Juan de los Cues', 18.0465400, -97.0602000, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94736, 'San Juán Lachigalla', 'San Juan Lachigalla', 'Lachigalla,San Juan Lachigalla,San Juán Lachigalla', 16.5894700, -96.5505200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94737, 'San Juan Juquila Vijanos', 'San Juan Juquila Vijanos', 'Juquila Vijanos,San Juan Juquila,San Juan Juquila Vijanos', 17.3537200, -96.3038500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94738, 'Ixtenco', 'Ixtenco', 'Ixtenco,San Juan,San Juan Ixtenco', 19.2514600, -97.8941200, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94739, 'San Juan Ixcaquixtla', 'San Juan Ixcaquixtla', 'Ixcaqcixtla,Ixcaquixtla,San Juan Ixcaquixtla', 18.4606700, -97.8310300, 'MX', '2017-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94740, 'San Juan Ihualtepec', 'San Juan Ihualtepec', 'Igualtepec,San Juan,San Juan Igualtepec,San Juan Ihualtepec', 17.7402300, -98.2889000, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94741, 'San Juan Guichicovi', 'San Juan Guichicovi', 'Guichicovi,San Juan,San Juan Guichicovi', 16.9623100, -95.0941800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94742, 'San Juan Guelavía', 'San Juan Guelavia', 'Guelaria,Guelavia,San Juan,San Juan Guelavia,San Juan Guelavía', 16.9550700, -96.5435900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94743, 'San Juan Evangelista', 'San Juan Evangelista', 'San Juan Evangelista,Santana Rodriguez', 17.8861500, -95.1396100, 'MX', '2017-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94744, 'San Juan Epatlán', 'San Juan Epatlan', 'Epatlan,San Juan,San Juan Epatlan,San Juan Epatlán', 18.6427200, -98.3725000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94745, 'San Juan Diuxi', 'San Juan Diuxi', 'Diuxi,San Juan,San Juan Diuxi', 17.2859700, -97.3700500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94746, 'San Juan del Río', 'San Juan del Rio', 'San Juan del Rio,San Juan del Río', 20.3888600, -99.9957700, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94747, 'San Juan de los Reyes (Luis Valenzuela)', 'San Juan de los Reyes (Luis Valenzuela)', '', 18.5177800, -95.4488900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94748, 'San Juan del Estado', 'San Juan del Estado', 'San Juan,San Juan del Estado', 17.2743000, -96.7991200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94749, 'San Juan de las Huertas', 'San Juan de las Huertas', 'San Juan,San Juan de la Huerta,San Juan de las Huertas', 19.2475500, -99.7583400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94750, 'San Juan Cuautla', 'San Juan Cuautla', 'Cuautla,San Juan,San Juan Cuautla', 18.2441600, -96.9567300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94751, 'San Juan Chilateca', 'San Juan Chilateca', 'Chilateca,San Juan,San Juan Chilateca', 16.8304200, -96.6691500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94752, 'San Juan Cacahuatepec', 'San Juan Cacahuatepec', 'Cacahuatepec,San Juan Cacahuatepec', 16.6153200, -98.1550100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94753, 'Valle Nacional', 'Valle Nacional', 'San Juan Baustista Valle Nacional,San Juan Bautista,San Juan Bautista Valle Nacional,Valle Nacional', 17.7757900, -96.3017400, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94754, 'Tuxtepec', 'Tuxtepec', 'San Juan Bautista,San Juan Bautista Tuxtepec,San Juan Bautista Tuxtla,Tuxtepec', 18.0883000, -96.1253500, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94755, 'Tlacoatzintepec', 'Tlacoatzintepec', 'San Juan Bautista Tlacoatzintepec,Tlacoatzintepec,Tlacoazintepec', 17.8598500, -96.5864700, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94756, 'Tlachichilco', 'Tlachichilco', 'San Juan Bautista,San Juan Bautista Tlachichilco,Tlachichilco,Tlachilco', 17.6222000, -98.3431200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94757, 'Cuicatlan', 'Cuicatlan', 'Cuicatlan,San Juan Bautista Cuicatlan,San Juan Bautista Cuicatlán', 17.8027200, -96.9593900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94758, 'Coixtlahuaca', 'Coixtlahuaca', 'Coixtlahuaca,San Juan,San Juan Bautista Coixtlahuaca', 17.7202100, -97.3188000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94759, 'Animas Trujano', 'Animas Trujano', 'Animas Trujano,San Juan Bautista Animas Trujano,San Juan Bautista Ánimas Trujano,Trujano', 16.9908600, -96.7131900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94760, 'San Juan Atzompa', 'San Juan Atzompa', 'Atzompa,San Gregorio,San Gregorio Atzompa,San Juan Atzompa,San Juan Atzompan', 18.7449700, -98.0245100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94761, 'San Juan Amecac', 'San Juan Amecac', 'Amecac,San Juan Amecac', 18.8346900, -98.6590900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94762, 'San Juan Achiutla', 'San Juan Achiutla', 'Achiutla,San Juan,San Juan Achiutla', 17.3501900, -97.5080400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94763, 'San José Tenango', 'San Jose Tenango', 'San Jose,San Jose Tenango,San José,San José Tenango,Tenango', 18.1508400, -96.7174400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94764, 'Miahuatlán', 'Miahuatlan', 'Miahuatlan,Miahuatlán,San Jose Miahuatlan,San José Miahuatlán', 18.2916300, -97.2878900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94765, 'San José Lachiguirí', 'San Jose Lachiguiri', 'Lachiguiri,Lachiguirí,San Jose,San Jose Lachiguiri,San José Lachiguirí', 16.3778400, -96.3358900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94766, 'San José Estancia Grande', 'San Jose Estancia Grande', 'Estancia Grande,Jose Estancia Grande,José Estancia Grande,San Jose,San Jose Estancia Grande,San José Estancia Grande', 16.3654500, -98.2509200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94767, 'San José Chiltepec', 'San Jose Chiltepec', 'Chiltepec,San Jose,San Jose Chiltepec,San José Chiltepec', 17.9473400, -96.1695700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94768, 'San José Chiapa', 'San Jose Chiapa', 'Chapa,Chiapa,San Jose,San Jose Chiapa,San José,San José Chiapa', 19.2410500, -97.7664200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94769, 'San José Ayuquila', 'San Jose Ayuquila', 'Ayuquila,San Jose Ayuquila,San José Ayuquila', 17.9422100, -97.9686100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94770, 'San José Acateno', 'San Jose Acateno', 'Acateno,San Jose Acateno,San José Acateno', 20.1306700, -97.2099700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94771, 'San Joaquín', 'San Joaquin', 'San Joaquin,San Joaquín', 20.9156200, -99.5652000, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94772, 'San Jerónimo Xayacatlán', 'San Jeronimo Xayacatlan', 'San Jeronimo,San Jeronimo Xayacatlan,San Jerónimo,San Jerónimo Xayacatlán,Xayacatlan', 18.2203400, -97.9128800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94773, 'San Jerónimo Tecóatl', 'San Jeronimo Tecoatl', 'San Jeronimo Tecoatl,San Jerónimo Tecoatl,San Jerónimo Tecoátl,San Jerónimo Tecóatl,Tecoatl,Tecoatla', 18.1663300, -96.9125600, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94774, 'San Jerónimo Taviche', 'San Jeronimo Taviche', 'San Jeronimo Tabiche,San Jeronimo Taviche,San Jerónimo Tabiche,San Jerónimo Taviche,Taviche', 16.7146800, -96.5936000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94775, 'San Jerónimo Sosola', 'San Jeronimo Sosola', 'San Jeronimo,San Jeronimo Sosola,San Jerónimo Sosola,Sosola,Sosola Jeronimo', 17.3668500, -97.0329100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94776, 'San Jerónimo Silacayoapilla', 'San Jeronimo Silacayoapilla', 'San Jeronimo,San Jeronimo Silacayoapilla,San Jerónimo Silacayoapilla,Silacayoapilla', 17.8102100, -97.8448800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94777, 'San Jerónimo Ocotitla', 'San Jeronimo Ocotitla', 'Ocotitlan,Ocotitlán,San Jeronimo Ocotitla,San Jeronimo Ocotitlan,San Jerónimo Ocotitla,San Jerónimo Ocotitlá,San Jerónimo Ocotitlán', 19.0312700, -97.9635900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94778, 'San Jerónimo Coatlán', 'San Jeronimo Coatlan', 'Coatlan,San Geronimo,San Jeronimo,San Jeronimo Coatlan,San Jerónimo Coatlán', 16.2321100, -96.8704700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94779, 'San Jerónimo Axochitlán', 'San Jeronimo Axochitlan', 'Axochitlan,Axochitlán,San Jeronimo Axochitlan,San Jerónimo Axochitlán', 18.2783300, -97.2627800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94780, 'San Isidro Apango', 'San Isidro Apango', 'Apango,San Isidro Apango', 15.8095200, -96.3585600, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94781, 'San Isidro', 'San Isidro', '', 18.8911100, -97.1258300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94782, 'San Ildefonso Villa Alta', 'San Ildefonso Villa Alta', 'San Ildefonso,San Ildefonso Villa Alta,Valta,Villa Alta', 17.3382700, -96.1523200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94783, 'San Ildefonso Amatlán', 'San Ildefonso Amatlan', 'Amatlan,San Idefonso,San Ildefonso,San Ildefonso Amatlan,San Ildefonso Amatlán', 16.3339000, -96.4912200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94784, 'San Ildefonso', 'San Ildefonso', 'San Ildefonso,Santa Cruz', 19.5611100, -99.7858300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94785, 'San Hipólito', 'San Hipolito', 'San Hipolito,San Hipolito Xochiltenango,San Hipólito,San Hipólito Xochiltenango,Xochiltenango', 18.9406900, -97.8732200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94786, 'San Gregorio Atzompa', 'San Gregorio Atzompa', 'Atzompa,San Gregorio Atzompa,San Gregório Atzompa,San Juan Atzompa', 19.0234900, -98.3482200, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94787, 'San Gaspar Tonatico', 'San Gaspar Tonatico', 'San Gaspar Tonatico,Tonatico', 18.8067100, -99.6691700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94788, 'San Gabriel Mixtepec', 'San Gabriel Mixtepec', 'Mixtepec,San Gabriel,San Gabriel Mixtepec', 16.0959300, -97.0823700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94789, 'San Gabriel Chilac', 'San Gabriel Chilac', 'Chilac,San Gabriel Chilac', 18.3259600, -97.3469700, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94790, 'Casa Blanca', 'Casa Blanca', 'Casa Blanca,San Gabriel Casa Blanca', 18.1497600, -97.1372900, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94791, 'San Gabriel las Palmas', 'San Gabriel las Palmas', '', 18.6141700, -99.3469400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94792, 'San Francisco Zacacalco', 'San Francisco Zacacalco', 'San Francisco,San Francisco Zacacalco,Zacacalco', 19.9287500, -98.9827900, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94793, 'San Francisco Tlalcilalcalpan', 'San Francisco Tlalcilalcalpan', 'San Francisco Tlalcilalcalpa,San Francisco Tlalcilalcalpan,Tlalcilalcalpa,Tlalcilalcalpan,Tlalzilalcalpa,Tlalzilalcalpan', 19.2947400, -99.7677100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94794, 'San Francisco Tepexoxica', 'San Francisco Tepexoxica', 'San Francisco,San Francisco Tepexoxica,San Francisco Tepexoxuca,Tepexoxuca', 19.0604300, -99.5478300, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94795, 'San Francisco Telixtlahuaca', 'San Francisco Telixtlahuaca', 'Huitzo,San Francisco,San Francisco Telixtlahuaca,Telixtlahuaca', 17.2968400, -96.9052900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94796, 'San Francisco Sola', 'San Francisco Sola', 'San Francisco,San Francisco Sola,Sola,Sola San Francisco,Sola de Vega', 16.5158400, -96.9748800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94797, 'San Francisco Ozolotepec', 'San Francisco Ozolotepec', 'Ozolotepec,San Francisco,San Francisco Ozolotepec', 16.1007900, -96.2218100, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94798, 'Mixtla', 'Mixtla', 'Mixtla,San Francisco Mixtla', 18.9050200, -97.8955400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94799, 'San Francisco Lachigoló', 'San Francisco Lachigolo', 'Lachigolo,Lachigoló,Lechigalo,San Francisco Lachigolo,San Francisco Lachigoló', 17.0162400, -96.5994700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94800, 'San Francisco Huehuetlán', 'San Francisco Huehuetlan', 'Huehuetlan,Huehuetlán,San Francisco Huehuetlan,San Francisco Huehuetlán', 18.1972500, -96.9480500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94801, 'San Francisco del Mar Viejo', 'San Francisco del Mar Viejo', 'San Francisco del Mar,San Francisco del Mar Viejo', 16.2318500, -94.6329700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94802, 'San Francisco Chindúa', 'San Francisco Chindua', 'Chindua,Guadalupe Chindua,San Francisco,San Francisco Chindua,San Francisco Chindúa', 17.4280900, -97.3126600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94803, 'San Francisco Cajonos', 'San Francisco Cajonos', 'Cajonos,San Francisco,San Francisco Cajonos', 17.1709100, -96.2502400, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94804, 'Atexcatzingo', 'Atexcatzingo', 'Atexcalzingo,Atexcatzingo,Atezcatzinco,Atezcatzingo,San Francisco,San Francisco Atezcatzinco', 19.4688200, -98.1471600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94805, 'San Francisco Acuautla', 'San Francisco Acuautla', 'Acuautla,San Francisco Acuautla', 19.3456400, -98.8603400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94806, 'San Francisco', 'San Francisco', 'San Francisco', 20.5525400, -98.0020900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94807, 'Occidente (San Francisco)', 'Occidente (San Francisco)', '', 18.3313000, -93.2523800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94808, 'San Francisco Ozomatlán', 'San Francisco Ozomatlan', '', 17.9253700, -99.3390200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94809, 'San Fernando', 'San Fernando', 'San - Fernando,San Fernando,Villa Allende,Сан - Фернандо', 16.8715300, -93.2075900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94810, 'San Felipe Usila', 'San Felipe Usila', 'San Felipe,San Felipe Usila,Usila', 17.8879000, -96.5247400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94811, 'Teotlaltzingo', 'Teotlaltzingo', 'San Felipe,San Felipe Teotlalcingo,San Felipe Teotlaltzingo,Teotlalcingo,Teotlaltzingo,Teotlalzingo,Teotlancingo', 19.2308800, -98.5007700, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94812, 'San Felipe Jalapa de Díaz', 'San Felipe Jalapa de Diaz', 'Jalapa de Diaz,San Felipe,San Felipe Jalapa de Diaz,San Felipe Jalapa de Díaz,San Felipe Jalpa de Diaz', 18.0712000, -96.5356200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94813, 'Villa Mariano Matamoros', 'Villa Mariano Matamoros', 'Ixtacuistla,Ixtacuixtla,Mariano Matamoras,San Felipe,San Felipe Ixtacuixtla,Santa Justina,Villa Mariano Matamoros', 19.3266100, -98.3774600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94814, 'San Felipe del Progreso', 'San Felipe del Progreso', 'San Felipe,San Felipe del Progreso', 19.7144000, -99.9519700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94815, 'Cuautempan', 'Cuautempan', 'Cuatempan,Cuautempan,San Esteban,San Esteban Cuautempan', 19.9138000, -97.7949800, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94816, 'San Esteban Atatlahuca', 'San Esteban Atatlahuca', 'Aiatlahuca,Atatlahuca,San Esteban,San Esteban Atatlahuca', 17.0671600, -97.6783600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94817, 'San Esteban', 'San Esteban', 'San Esteban', 20.5445200, -98.0600400, 'MX', '2014-03-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94818, 'Yauhquemehcan', 'Yauhquemehcan', 'San Dionisio,San Dionisio Yauhquemehcan,Yauhquemehcan', 19.4069700, -98.1823000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94819, 'San Dionisio Ocotepec', 'San Dionisio Ocotepec', 'Ocotepec,San Dionisio,San Dionisio Ocotepec', 16.8045700, -96.3933400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94820, 'San Dionisio del Mar', 'San Dionisio del Mar', 'San Dionisio del Mar', 16.3237100, -94.7583000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94821, 'Xochimanca', 'Xochimanca', 'San Dieguito Xochimanca,Xochimanca,Xochimancan', 19.4905200, -98.8243300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94822, 'San Diego Huehuecalco', 'San Diego Huehuecalco', 'Huehuecalco,San Diego,San Diego Huehuecalco', 19.0927600, -98.7633600, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94823, 'Sanctorum', 'Sanctorum', 'Sanctorium,Sanctorum,Sanctórum', 19.4933300, -98.4715600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94824, 'Sanctorum', 'Sanctorum', 'Sanctorium,Sanctorum,Sanctórum', 19.0991700, -98.2541700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94825, 'San Cristóbal Lachirioag', 'San Cristobal Lachirioag', 'Lachiriaga,Lachirioag,San Cristobal Lachirioag,San Cristóbal Lachirioag', 17.3358200, -96.1650300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94826, 'San Cristóbal de las Casas', 'San Cristobal de las Casas', 'Ciudad Las Casas,Ciudad de las Casas,SZT,San Cristobal,San Cristobal de Las Casas,San Cristobal de las Casas,San Cristobal las Casas,San Cristóbal de Las Casas,San Cristóbal de las Casas,San Cristóbal las Casas', 16.7317600, -92.6412600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94827, 'San Cristóbal Amoltepec', 'San Cristobal Amoltepec', 'Amoltepec,Amoltepec San Cristobal,San Cristobal,San Cristobal Amoltepec,San Cristóbal Amoltepec', 17.2842800, -97.5721600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94828, 'San Cristóbal Amatlán', 'San Cristobal Amatlan', 'Amatlan,San Cristobal,San Cristobal Amatlan,San Cristóbal Amatlán', 16.3171300, -96.4078500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94829, 'San Ciro de Acosta', 'San Ciro de Acosta', 'Pedro Montoya,San Ciro,San Ciro de Acosta', 21.6507200, -99.8191600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94830, 'San Carlos Yautepec', 'San Carlos Yautepec', 'San Carlos,San Carlos Yautepec,Yautepec', 16.4969900, -96.1064800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94831, 'San Carlos', 'San Carlos', '', 17.5522100, -91.1540800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94832, 'San Buenaventura', 'San Buenaventura', 'San Buenaventura', 19.2659500, -99.6733200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94833, 'San Bernardo Mixtepec', 'San Bernardo Mixtepec', 'Mixtepec,San Bernardo,San Bernardo Mixtepec', 16.8257900, -96.8991100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94834, 'Amaxac de Guerrero', 'Amaxac de Guerrero', 'Amaxac,Amaxac de Guerrero,San Bernabe Amaxac de Guerrero,San Bernabé Amaxac de Guerrero', 19.3466100, -98.1705700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94835, 'San Bartolo Yautepec', 'San Bartolo Yautepec', 'San Bartolo,San Bartolo Yautepec,Yautepec', 16.4293500, -95.9743800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94836, 'San Bartolo Tutotepec', 'San Bartolo Tutotepec', 'San Bartolo,San Bartolo Tutotepec,Tutotepec', 20.3984100, -98.2008000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94837, 'Teontepec', 'Teontepec', 'San Bartolo,San Bartolo Teontepec,Teontepec', 18.4921700, -97.5296200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94838, 'Soyaltepec', 'Soyaltepec', 'San Bartolo Soyaltepec,Soyaltepec', 17.5917400, -97.3081900, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94839, 'San Bartolomé Loxícha', 'San Bartolome Loxicha', 'Loxicha,San Bartolome,San Bartolome Loxicha,San Bartolomé,San Bartolomé Loxicha,San Bartolomé Loxícha,Santa Catarina Loxicha', 15.9698100, -96.7095700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94840, 'San Bartolomé Ayautla', 'San Bartolome Ayautla', 'Ayautla,San Bartolo,San Bartolome Ayautla,San Bartolomé Ayautla', 18.0323900, -96.6707800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94841, 'San Bartolo del Llano', 'San Bartolo del Llano', 'San Bartolo,San Bartolo del Llano', 19.5906900, -99.7409900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94842, 'San Bartolo Cuautlalpan', 'San Bartolo Cuautlalpan', 'San Bartolo,San Bartolo Cuautlapan', 19.8151000, -99.0104400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94843, 'San Baltazar Loxicha', 'San Baltazar Loxicha', 'Loxicha,San Baltasar Loxicha,San Baltazar,San Baltazar Loxicha,San Battazar', 16.0767000, -96.7874000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94844, 'San Baltazar Chichicapam', 'San Baltazar Chichicapam', 'Chichicapam,Chichicapan,San Baltasar Chichicapan,San Baltazar Chichicapam,San Baltazar Chichicapan', 16.7615100, -96.4897000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94845, 'Xochitlaxco (San Baltazar)', 'Xochitlaxco (San Baltazar)', 'San Baltasar Xochitlaxco,Xochitlaxco', 19.9413900, -97.8636100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94846, 'San Baltazar Atlimeyaya', 'San Baltazar Atlimeyaya', 'Atlimayaya,Atlimeyaya,San Baltasar,San Baltasar Atlimeyaya,San Baltazar', 18.9869400, -98.4811100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94847, 'Nanahuatípam', 'Nanahuatipam', 'Nanahuatipac,Nanahuatipam,Nanahuatipan,Nanahuatípam,Narahuatipan,San Antonio Nanahuatipam,San Antonio Nanahuatipan', 18.1341400, -97.1250100, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94848, 'Coaxomulco', 'Coaxomulco', 'Coaxomulco,Cuajomulco,Cuajumulco,Cuaxolmulco,Cuaxomulco,San Antonio,San Antonio Cuaxomulco', 19.3526400, -98.0967000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94849, 'San Antonio la Isla', 'San Antonio la Isla', 'San Antonio,San Antonio la Isla', 19.1644100, -99.5668500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94850, 'San Andrés Yaá', 'San Andres Yaa', 'San Andres Yaa,San Andrés Yaá,Yaa', 17.2929000, -96.1538400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94851, 'San Andres Tuxtla', 'San Andres Tuxtla', 'San Andres Tuxtla,Tuxtla', 18.4487000, -95.2132700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94852, 'San Andrés Timilpan', 'San Andres Timilpan', 'San Andres Timilpan,San Andrés Timilpan,Timilpan', 19.8761000, -99.7337500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94853, 'Tepetlapa', 'Tepetlapa', 'San Andres Tepetlapa,San Andrés Tepetlapa,Tepetlapa', 17.6660100, -98.3918800, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94854, 'San Andrés Tepetitlán', 'San Andres Tepetitlan', 'San Andres,San Andres Tepetitlan,San Andrés Tepetitlán,Tepetitlan', 18.8983300, -99.9197200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94855, 'San Andrés Tenejapan', 'San Andres Tenejapan', 'San Andres Tenejapa,San Andres Tenejapan,San Andrés Tenejapa,San Andrés Tenejapan,Tenejapa', 18.7892100, -97.0939900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94856, 'San Andrés Solaga', 'San Andres Solaga', 'San Andres Solaga,San Andrés Solaga,Solaga', 17.2725400, -96.2361000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94857, 'San Andrés Sinaxtla', 'San Andres Sinaxtla', 'San Andres,San Andres Sinaxtla,San Andrés Sinaxtla,Sinaxtla', 17.4692800, -97.2829800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94858, 'San Andrés Huayápam', 'San Andres Huayapam', 'Huayapam,Huayapan,San Andres Huayapam,San Andres Huayapan,San Andrés Huayapam,San Andrés Huayapan,San Andrés Huayápam', 17.1026400, -96.6655600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94859, 'San Andrés Huaxpaltepec', 'San Andres Huaxpaltepec', 'Huaxpaltepec,San Andres,San Andres Huaxpaltepec,San Andres Nuaxpaltepec,San Andrés Huaxpaltepec,San Andrés Nuaxpaltepec', 16.3295200, -97.9164700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94860, 'San Andrés Calpan', 'San Andres Calpan', 'Calpan,San Andres Calpan,San Andrés Calpan', 19.1035600, -98.4618800, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94861, 'San Andrés Cacaloapan', 'San Andres Cacaloapan', 'Cacaloacapan,Cacaloapan,San Andres,San Andres Cacaloapan,San Andrés,San Andrés Cacaloapan', 18.5836400, -97.5871100, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94862, 'San Agustín Tlaxiaca', 'San Agustin Tlaxiaca', 'San Agustin Tlaxiaca,San Agustín Tlaxiaca,Tlaxcala,Tlaxiaca', 20.1151000, -98.8864000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94863, 'San Agustín Oapan', 'San Agustin Oapan', 'San Agustin Coapan,San Agustin Oapan,San Agustín Coapan,San Agustín Oapan', 17.9525000, -99.4380600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94864, 'San Agustín Loxicha', 'San Agustin Loxicha', 'San Agustin Laxicha,San Agustin Loxicha,San Agustin Loxichia,San Agustín Laxicha,San Agustín Loxicha,San Agustín Loxichia,San Augustin', 16.0168700, -96.6161500, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94865, 'San Agustín Huixaxtla', 'San Agustin Huixaxtla', 'San Agustin,San Agustin Huexaxtla,San Agustín,San Agustín Huexaxtla', 18.9177800, -98.3969400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94866, 'San Agustín Amatengo', 'San Agustin Amatengo', 'Amatenango,Amatengo,San Agustin Amatengo,San Agustín Amatengo', 16.5108600, -96.7891900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94867, 'Salto de Agua', 'Salto de Agua', 'Salto de Agua', 17.5543500, -92.3394100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94868, 'Saltillo', 'Saltillo', 'Saltillo', 19.2964400, -97.2966100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94869, 'Saltabarranca', 'Saltabarranca', 'Saltabarranca', 18.5911900, -95.5322600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94870, 'Salitrillo', 'Salitrillo', '', 19.4333300, -99.8500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94871, 'Salina Cruz', 'Salina Cruz', 'SCX,Salina Cruz,Salina-Krus,Салина-Крус,Саліна-Крус,サリナ・クルス', 16.1840500, -95.2014300, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94872, 'Sahcaba', 'Sahcaba', 'Sahacaba,Sahcaba,Sahcabac,Sahcabá', 20.7917400, -89.1813800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94873, 'Sacalum', 'Sacalum', 'Sacalom,Sacalum,Sakalun', 20.4974900, -89.5903500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94874, 'Sabancuy', 'Sabancuy', 'Sabancuy', 18.9727000, -91.1778300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94875, 'Saban', 'Saban', 'Saban,Sabán', 20.0345000, -88.5389100, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94876, 'Ríoverde', 'Rioverde', 'Rioverde,Ríoverde', 21.9311500, -99.9948800, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94877, 'Río Lagartos', 'Rio Lagartos', 'Rio Lagartos,Rio-Lagartos,Río Lagartos,Рио-Лагартос', 21.5967000, -88.1577300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94878, 'Río Frío de Juárez', 'Rio Frio de Juarez', 'Rio Frio,Rio Frio de Juarez,Río Frío,Río Frío de Juárez', 19.3533600, -98.6705700, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94879, 'Río Bravo', 'Rio Bravo', 'El Ebano,Rio Bravo,Rio-Bravo,Río Bravo,Рио-Браво', 25.9872900, -98.0941400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94880, 'Río Blanco', 'Rio Blanco', 'Rio Blanco,Rio-Blanko,Río Blanco,Tenango de Rio Blanco,Tenango de Río Blanco,Рио-Бланко', 18.8303600, -97.1560000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94881, 'Colonia Rincón Viejo', 'Colonia Rincon Viejo', 'Colonia Rincon Viejo,Colonia Rincón Viejo,Rincon Viejo,Rincón Viejo', 16.8867800, -95.0473100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94882, 'Rinconada', 'Rinconada', 'Rinconada', 19.3543800, -96.5658100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94883, 'Reynosa', 'Reynosa', 'REX,Reinosa,Rejnosa,Reynosa,lei nuo sa,leinosa,reinosa,rynwsa tamaywlypas,ryynwsa,ryynwsh,Рейноса,Рејноса,ריינוסה,ریئنوسا,رینوسا تامائولیپاس,რეინოსა,レイノサ,雷諾薩,레이노사', 26.0806100, -98.2883500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94884, 'Rayón', 'Rayon', 'Rayon,Rayón', 21.8432900, -99.6425800, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94885, 'Rayón', 'Rayon', 'Rayon,Rayón', 17.2013700, -93.0111000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94886, 'Rafael Lucio', 'Rafael Lucio', 'Rafael Lucio', 19.5930800, -96.9902300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94887, 'Grajales', 'Grajales', 'Grajales,Rafael Lara Grajales', 19.2279600, -97.8030700, 'MX', '2016-03-15', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94888, 'Rafael J. García', 'Rafael J. Garcia', 'Chilchotla,Rafael I. Garcia,Rafael J. Garcia,Rafael J. García', 19.2541300, -97.1831500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94889, 'Rafael Delgado', 'Rafael Delgado', 'Rafael Delgado', 18.8101400, -97.0717200, 'MX', '2016-03-15', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94890, 'Rodulfo Figueroa', 'Rodulfo Figueroa', 'Radulfo Figueroa,Rodulfo Figueroa', 15.9200600, -91.9037000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94891, 'Quintana Roo', 'Quintana Roo', 'Kintana-Roo,Quintana,Quintana Roo,Кинтана-Роо', 20.8694600, -88.6315300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94892, 'Santa Catalina Quieri', 'Santa Catalina Quieri', 'Quieri,Santa Catalina Quieri,Santa Maria,Santa María', 16.3214100, -96.2661800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94893, 'Santa María Quiegolani', 'Santa Maria Quiegolani', 'Quiegolani,Santa Mari Quiegolani,Santa Maria Quiegolani,Santa Marí Quiegolani,Santa María Quiegolani', 16.2770500, -96.0526900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94894, 'Quechultenango', 'Quechultenango', 'Quechultenango', 17.4142500, -99.2422100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94895, 'Quecholac', 'Quecholac', 'Quecholac', 18.9547100, -97.6585800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94896, 'Quebrantadero', 'Quebrantadero', 'Quebrantadero,San Jose,San José', 18.5242900, -98.7902300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94897, 'Putla Villa de Guerrero', 'Putla Villa de Guerrero', 'Putla,Putla Villa de Guerrero,Putla de Guerrero,Santa Maria,Santa María', 17.0263000, -97.9285400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94898, 'Puerto Madero', 'Puerto Madero', 'Puerto Madero,Puerto de San Benito,San Benito', 14.7207600, -92.4214600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94899, 'Puerto Escondido', 'Puerto Escondido', 'PXM,Puehrto-Ehskondido,Puerto Escondido,ai si kong di duo gang,pu''erato esakondido,pueleuto-eseukondido,pueruto・esukondido,Пуэрто-Эскондидо,ਪੂਏਰਤੋ ਏਸਕੋਂਦੀਦੋ,プエルト・エスコンディード,埃斯孔迪多港,푸에르토에스콘디도', 15.8703700, -97.0772600, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94900, 'Puente de Ixtla', 'Puente de Ixtla', '', 18.6147200, -99.3180600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94901, 'Pueblo Nuevo Jolistahuacan', 'Pueblo Nuevo Jolistahuacan', 'Pueblo Nuevo,Pueblo Nuevo Jolistahuacan,Pueblo Nuevo Solistahuacan,Pueblo Nuevo Solistahuacán', 17.1602700, -92.8997700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94902, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 19.6741900, -99.6175000, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94903, 'Puebla', 'Puebla', 'Angelopolis,Byen Puebla,Cuetlaxcoapan,Gorad Ehroika-Puehbla-deh-Saragosa,Heroica Puebla de Zaragoza,Heróica Puebla de Zaragoza,Lungsod ng Puebla,PBC,Pouempla,Puebl,Puebla,Puebla City,Puebla de Saragosa,Puebla de Zaragoza,Puebla de los Angeles,Puebla de los Ángeles,Puehbla-de-Saragosa,Puehblae-de-Saragosae,Yucha Nchu''u,bwybla,pu ai bu la,pu''aibala,pu''ebla,puebeulla,puebura,pwybla  pwybla,pwybla. pwybla,Πουέμπλα,Горад Эроіка-Пуэбла-дэ-Сарагоса,Пуебла,Пуэблæ-де-Сарагосæ,Пуэбла-де-Сарагоса,פואבלה,بويبلا,پوئبلا، پوئبلا,پوئبلا٬ پوئبلا,पुएब्ला,ਪੁਐਬਲਾ,პუებლა,プエブラ,普埃布拉,푸에블라', 19.0379300, -98.2034600, 'MX', '2016-12-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94904, 'Progreso de Alvaro Obregon', 'Progreso de Alvaro Obregon', 'Progreso,Progreso de Alvaro Obregon,Progreso de Obregon,Progreso de Obregón', 20.2492900, -99.1898800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94905, 'Progreso', 'Progreso', 'Progreso,Progreso de Castro,purogureso,Прогресо,プログレソ', 21.2830600, -89.6612300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94906, 'Progreso Industrial', 'Progreso Industrial', 'Progreso,Progreso Industrial', 19.6363500, -99.3568700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94907, 'Presidio', 'Presidio', 'Presidio', 19.0693300, -96.9720900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94908, 'Poza Rica de Hidalgo', 'Poza Rica de Hidalgo', 'PAZ,Poza Rica', 20.5331500, -97.4594600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94909, 'Potrero del Llano', 'Potrero del Llano', 'Potrero,Potrero del Llano', 21.0797000, -97.7281400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94910, 'Portezuelo', 'Portezuelo', 'Portezuelo', 20.4868700, -99.3061000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94911, 'Pomuch', 'Pomuch', 'Pomuch,Pumuch', 20.1372700, -90.1748800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94912, 'Polyuc', 'Polyuc', 'Boloyuc,Polyuc', 19.6088900, -88.5614800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94913, 'Polanco', 'Polanco', 'Col Polanco,Col. Polanco,Colonia Polanco,Polanco', 19.4333200, -99.1991900, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94914, 'Pluma Hidalgo', 'Pluma Hidalgo', 'Pluma Hidalgo', 15.9271100, -96.4185200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94915, 'Playa Vicente', 'Playa Vicente', 'Playa Vicente,Venustiano Carranza', 17.8310700, -95.8118900, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94916, 'Playa del Carmen', 'Playa del Carmen', 'PCM,Plaja-del''-Karmen,Playa del Carmen,peullayadelkaleumen,playya dyl karmyn,pu la ya de er ka man,Плая-дель-Кармен,פלאיה דל כרמן,پلائیا دیل کارمین,プラヤ・デル・カルメン,普拉亞德爾卡曼,플라야델카르멘', 20.6274000, -87.0798700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94917, 'Platón Sánchez', 'Platon Sanchez', 'Platon Sanches,Platon Sanchez,Platón Sánches,Platón Sánchez', 21.2718200, -98.3745600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94918, 'Plan de las Hayas', 'Plan de las Hayas', 'Plan de las Hayas', 19.7596300, -96.6759400, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94919, 'Piste', 'Piste', 'Piste,Pisté,Ppiste', 20.6997200, -88.5888900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94920, 'Pinotepa de Don Luis', 'Pinotepa de Don Luis', 'Pinotepa,Pinotepa de Don Luis', 16.4271600, -97.9767800, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94921, 'Pinal de Amoles', 'Pinal de Amoles', 'Amoles,Pinal de Amoles', 21.1344800, -99.6259000, 'MX', '2014-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94922, 'Pijijiapan', 'Pijijiapan', 'Pijijiapam,Pijijiápam', 15.6861800, -93.2093800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94923, 'Piedras Negras', 'Piedras Negras', 'Negras Piedras,P''edras Negras,Piedras Negras,Пьедрас Неграс', 18.7702600, -96.1717800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94924, 'Zamora Pico de Oro', 'Zamora Pico de Oro', '', 16.3320500, -90.7656000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94925, 'Pichucalco', 'Pichucalco', '', 17.5100000, -93.1159100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94926, 'Peto', 'Peto', 'Peto', 20.1277600, -88.9228200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94927, 'Petlalcingo', 'Petlalcingo', 'Petlalcingo', 18.0846300, -97.9175000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94928, 'Petaquillas', 'Petaquillas', 'Petaquilla,Petaquillas', 17.4863600, -99.4563300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94929, 'Petalcingo', 'Petalcingo', 'Petalcingo,Petalsingo', 17.2271500, -92.4151100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94930, 'Perote', 'Perote', 'Perote,Pinahuizapan', 19.5623300, -97.2423500, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94931, 'Peñamiller', 'Penamiller', 'Penamiller,Peñamiller', 21.0540800, -99.8157300, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94932, 'Colonias Pedernales', 'Colonias Pedernales', '', 20.0458300, -97.0513900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94933, 'Paxtepec', 'Paxtepec', '', 20.0527800, -98.4313900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94934, 'Paso de Ovejas', 'Paso de Ovejas', 'Paso de Ovejas', 19.2845000, -96.4403700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94935, 'Paso del Toro', 'Paso del Toro', '', 19.0350000, -96.1355500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94936, 'Paso del Macho', 'Paso del Macho', 'Paso del Macho,Villa Jara', 18.9709800, -96.7241900, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94937, 'Paraiso', 'Paraiso', 'Paraiso', 18.4011600, -93.2140600, 'MX', '2014-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94938, 'Papantla de Olarte', 'Papantla de Olarte', 'Papanila,Papantla,Papantla de Olarte', 20.4465500, -97.3249500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94939, 'Santa Cruz Papalutla', 'Santa Cruz Papalutla', 'Papaluta,Santa Cruz Papalutla', 16.9562700, -96.5831000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94940, 'Papalotla', 'Papalotla', 'Papalotla,Papalotlan,Papalutla', 19.5634100, -98.8568100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94941, 'Pánuco', 'Panuco', 'Panuco,Pánuco', 22.0537300, -98.1849800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94942, 'Panotla', 'Panotla', 'Panotla,San Nicolas Panotla,San Nicolás Panotla', 19.3161900, -98.2701300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94943, 'Panales', 'Panales', 'Panales', 20.4696500, -99.2667400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94944, 'Panabá', 'Panaba', 'Panaba,Panabá', 21.2959800, -88.2698200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94945, 'Palomares', 'Palomares', 'Palomares', 17.1383000, -95.0626600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94946, 'Palmarito Tochapan', 'Palmarito Tochapan', 'Palmarito,Palmarito Tochapan,Palmarito Tochapán', 18.9013500, -97.6383300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94947, 'Palmar de Bravo', 'Palmar de Bravo', 'Palmar,Palmar de Bravo,San Agustin del Palmar,San Agustín del Palmar', 18.8357300, -97.5470400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94948, 'Palizada', 'Palizada', 'Palizada', 18.2550300, -92.0911000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94949, 'Palenque', 'Palenque', 'PQM,Palenke,Palenkė,Palenque,Palenque/Temp,Palenqué,Ruinas de Palenque,pa lun ke,Паленке,帕伦克', 17.5095300, -91.9824800, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94950, 'Pajapan', 'Pajapan', 'Pajapan', 18.2626700, -94.6917200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94951, 'Pahuatlán de Valle', 'Pahuatlan de Valle', 'Pahuatlan,Pahuatlan de Valle,Pahuatlan del Valle,Pahuatlán de Valle,Pahuatlán del Valle', 20.2780000, -98.1499700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94952, 'Pachuquilla', 'Pachuquilla', 'Pachuquilla', 20.0709900, -98.6957200, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94953, 'Pachuca de Soto', 'Pachuca de Soto', 'Pachuca,Pachuca de Soto,Pachuka,Pachuka de Soto,Pachuka-de-Soto,Pachyohcan Soto,Pachyohcān Soto,Pacuka,Pasuca Sotoensis,Pačuka,pa qiu ka,pachuka,pachwka. aydalgw,Пачука,Пачука де Сото,Пачука-де-Сото,پاچوکا٬ ایدالگو,პაჩუკა,パチューカ,帕丘卡,파추카', 20.1169700, -98.7332900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94954, 'San Martín Pachivia (Pachivia)', 'San Martin Pachivia (Pachivia)', '', 18.4085500, -99.7875900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94955, 'Ozumba de Alzate', 'Ozumba de Alzate', 'Ozumba,Ozumba de Alzate', 19.0368900, -98.7951600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94956, 'Ozuluama', 'Ozuluama', 'Ozuluama', 21.6604000, -97.8504900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94957, 'Santo Domingo Ozolotepec', 'Santo Domingo Ozolotepec', 'Ozolotepec,Santo Domingo Ozolotepec', 16.1501700, -96.3104600, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94958, 'Oxkutzkab', 'Oxkutzkab', 'Oxkutzcab,Oxkutzkab', 20.3073400, -89.4180900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94959, 'Oxchuc', 'Oxchuc', 'Oxchuc,Teultepec', 16.7858800, -92.3445500, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94960, 'Oviedo', 'Oviedo', 'Oviedo', 22.0447800, -98.4004300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94961, 'Otumba', 'Otumba', 'Gomez,Gómez,Otumba,Otumba de Gomez Farias,Otumba de Gómez Farías', 19.6998500, -98.7563800, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94962, 'Oteapan', 'Oteapan', 'Oteapan', 18.0017300, -94.6661500, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94963, 'El Santuario', 'El Santuario', 'El Santuario,Otatitlan,Otatitlán,Ototitlan', 18.1770600, -96.0335000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94964, 'Ostuacán', 'Ostuacan', 'Ostuacan,Ostuacán,Oxtuacan', 17.4066400, -93.3364300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94965, 'San Felipe Orizatlán', 'San Felipe Orizatlan', 'Orizatlan,Orizatlán,San Felipe Orizatlan,San Felipe Orizatlán', 21.1710900, -98.6074400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94966, 'Orizaba', 'Orizaba', 'Orisaba,Orizaba,ao li sa ba,Орисаба,奧里薩巴', 18.8519500, -97.0995700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94967, 'Oriental', 'Oriental', 'Oriental', 19.3761400, -97.6205100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94968, 'Opichen', 'Opichen', 'Opichen', 20.5516900, -89.8571400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94969, 'Omitlán de Juárez', 'Omitlan de Juarez', 'Omitlan,Omitlan de Juarez,Omitlán,Omitlán de Juárez', 20.1698000, -98.6484200, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94970, 'Ometepec', 'Ometepec', 'Ometepec', 16.6900800, -98.4079700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94971, 'Omealca', 'Omealca', 'Omealca,Omealco', 18.7473200, -96.7852000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94972, 'Oluta', 'Oluta', 'Oluta', 17.9297200, -94.8966200, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94973, 'Olinalá', 'Olinala', 'Olinala,Olinalá', 17.7786100, -98.7394400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94974, 'Olcuatitán', 'Olcuatitan', 'Olcuatitan,Olcuatitán', 18.1904500, -92.9611400, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94975, 'Ocuituco', 'Ocuituco', 'Ocuituco', 18.8773100, -98.7732300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94976, 'Ocuílan de Arteaga', 'Ocuilan de Arteaga', 'Ocuilan,Ocuilan de Arteaga,Ocuilán de Arteaga,Ocuílan de Arteaga', 18.9778400, -99.4198600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94977, 'Ocozocoautla de Espinosa', 'Ocozocoautla de Espinosa', 'La Ventosa,Ocozocoautla,Ocozocoautla de Espinosa,Ocozocuautla', 16.7623100, -93.3747600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94978, 'Ocoyoacac', 'Ocoyoacac', 'Ocoyoacac', 19.2712700, -99.4578700, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94979, 'Ocotlán de Morelos', 'Ocotlan de Morelos', 'Ocotlan,Ocotlan de Morelos,Ocotlán,Ocotlán de Morelos', 16.7915100, -96.6745500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94980, 'San Francisco Ocotlán', 'San Francisco Ocotlan', 'Ocotlan,Ocotlán,San Francisco Ocotlan,San Francisco Ocotlán', 19.1341100, -98.2834500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94981, 'Ocotlamanic', 'Ocotlamanic', 'Ocotlamanic,Ocotlaminic,Ocotlamánic,Ocotlomani', 18.3238900, -97.0966700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94982, 'Santa María Magdalena Ocotitlán', 'Santa Maria Magdalena Ocotitlan', 'Ocotitlan,Ocotitlán,Santa Maria Magdalena Ocotitlan,Santa Maria Ocotitlan,Santa María Magdalena Ocotitlán,Santa María Ocotitlán', 19.2371300, -99.6241800, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94983, 'Ocotepec', 'Ocotepec', 'Ocotepec', 17.2262000, -93.1644000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94984, 'Ocosingo', 'Ocosingo', 'Ocosingo', 16.9063900, -92.0937400, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94985, 'Ocampo', 'Ocampo', 'Ciudada Ocampo,Ocampo', 22.8469500, -99.3386600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94986, 'Oaxtepec', 'Oaxtepec', 'Oaxtepec', 18.9182500, -98.9564400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94987, 'Oaxaca', 'Oaxaca', 'Byen Oaxaca,Guaxaca,Huaxyacac Juarez,Huaxyacac Juárez,Lungsod ng Oaxaca,Ndua,OAX,Oachaka,Oachaka nte Chouares,Oahaka,Oakhaka,Oakhaka de Khuares,Oakhaka-de-Khuares,Oakhakae-de-Khuares,Oaksaka de Khuarez,Oaxaca,Oaxaca City,Oaxaca by,Oaxaca de Juarez,Oaxaca de Juárez,Oaxaka de Juarez,Oaxaka de Juárez,Oaxaka de Xuares,Santa Maria,awakhaka d khwarz,awkhaka,oagsaka,oahaka,vahaka de ju''ereza,vahaka de khu''arisa,vasaka de hu''arejha,wa ha ka,wa ha ka shi,Οαχάκα ντε Χουάρες,Оаксака де Хуарез,Оахакæ-де-Хуарес,Оахака,Оахака де Хуарес,Оахака-де-Хуарес,Օախակա դե Խուարես,אואחאקה,أوخاكا,اوآخاکا د خوارز,اوکساکا سٹی,ܘܐܟܐܩܐ ܕܝ ܟܘܐܪܝܣ,वाशाका दे हुआरेझ,वाहाका डे जुएरेज़,ਵਾਹਾਕਾ ਦੇ ਖ਼ੁਆਰਿਸ,วาฮากา,གའཀགྲོང་།,ოახაკა-დე-ხუარესი,ወሓካ ዴ ዋሬዝ,オアハカ,瓦哈卡市,오악사카', 17.0654200, -96.7236500, 'MX', '2016-11-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94988, 'Nunkiní', 'Nunkini', 'Nunkini,Nunkiní', 20.4004600, -90.1480300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94989, 'Osumacinta', 'Osumacinta', 'Nuevo Usumacinta,Osumacinta,Usumacinta', 16.9361100, -93.0902800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94990, 'Nuevo Progreso', 'Nuevo Progreso', 'La Gaviota,Nuevo Progreso', 23.1760500, -97.9500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94991, 'Nuevo Padilla', 'Nuevo Padilla', 'Nuevo Ciudad Padilla,Nuevo Padilla,Padilla', 24.0478400, -98.9008500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94992, 'Nuevo Laredo', 'Nuevo Laredo', 'NLD,Novo Laredo,Novum Laredum,Nuehvo-Laredo,Nuevo Laredas,Nuevo Laredo,Opstina Nuevo Laredo,Opština Nuevo Laredo,nuebolaledo,nuevo-laredo,nwyww lardw,nwyww larydw,xin la lei duo,Нуево Ларедо,Нуэво-Ларедо,נואבו לארדו,نوئوو لاردو,نوئوو لاریدو,ნუევო-ლარედო,ヌエボ・ラレド,新拉雷多,누에보라레도', 27.4762900, -99.5163900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94993, 'Nueva Palestina', 'Nueva Palestina', 'Nueva Palestina', 15.8061000, -92.7506700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94994, 'Nueva Ciudad Guerrero', 'Nueva Ciudad Guerrero', 'Ciudad Nueva Guerrero,Nueva Ciudad Guerrero', 26.5621900, -99.2286300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94995, 'Nopalucán', 'Nopalucan', 'Nopalucan,Nopalucan de la Granja,Nopalucán,Nopalucán de la Granja', 19.2184000, -97.8227200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94996, 'Nogales', 'Nogales', 'Nogales,nuo jia lai si,Ногалес,諾加萊斯', 18.8277600, -97.1631100, 'MX', '2016-03-15', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94997, 'Niltepec', 'Niltepec', 'Miltepec,Niltepec', 16.5640100, -94.6137300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94998, 'Nicolás Ruiz', 'Nicolas Ruiz', 'Nicolas Ruiz,Nicolás Ruiz', 16.4371400, -92.5852200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(94999, 'Nicolás Romero', 'Nicolas Romero', 'Ciudad Nicolas Romero,Ciudad Nicolás Romero,Lista de municipios do Mexico,Lista de municípios do México,Nicolas Romero,Nicolás Romero,Sijudad Nikolas Romero,Siudad Nikolas Romero,Villa Nicolas Romero,Villa Nicolás Romero,ni gu la si luo mei luo,nykwlas rwmrw  mkzykw,Сиудад Николас Ромеро,Сијудад Николас Ромеро,نیکولاس رومرو، مکزیکو,尼古拉斯羅梅羅', 19.6417700, -99.3068000, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95000, 'Nicolás Bravo', 'Nicolas Bravo', 'Nicolas Bravo,Nicolás Bravo', 18.4591000, -88.9280200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95001, 'Nepantla de Sor Juana Inés de la Cruz', 'Nepantla de Sor Juana Ines de la Cruz', 'Nepantla,Nepantla de Sor Juana Ines de la Cruz,Nepantla de Sor Juana Inés de la Cruz', 18.9802800, -98.8408300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95002, 'Necaxa', 'Necaxa', 'Necaxa', 20.2127100, -98.0118800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95003, 'Nealtican', 'Nealtican', 'Nealtican,San Buenaventura Nealtican', 19.0499000, -98.4272000, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95004, 'Nautla', 'Nautla', 'Nautla', 20.2079500, -96.7730500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95005, 'Naupan', 'Naupan', 'Naupan', 20.2313100, -98.1088100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95006, 'Naucalpan de Juárez', 'Naucalpan de Juarez', 'Municipio Naucalpan de Juarez,Municipio Naucalpan de Juárez,Naoukalpan,Naucalpan,Naucalpan de Juarez,Naucalpan de Juárez,Nauhcalpan Juarez,Nauhcalpan Juárez,Naukal''pan,Naukal''pan-de-Khuares,Naukalpan,Naukalpan de Khuarez,San Bartolo Naucalpan,kawkalpan,nao ka er pan,naukalpan,naukarupan,nawkalban dy khwaryz,nawkalpan d khwarz  astadw d mkhykw,Ναουκάλπαν,Наукалпан,Наукалпан де Хуарез,Наукальпан,Наукальпан-де-Хуарес,ناوكالبان دي خواريز,ناوکالپان د خوارز، استادو د مخیکو,کاوکالپان,ნაუკალპანი,ナウカルパン,瑙卡尔潘,나우칼판', 19.4785100, -99.2396300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95007, 'Natívitas', 'Nativitas', 'Nativitas,Santa Maria,Santa Maria Nativitas,Santa María Nativitas', 19.2333300, -98.3147200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95008, 'Naranjos', 'Naranjos', 'Naranjas,Naranjos', 21.3508700, -97.6865600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95009, 'Naolinco de Victoria', 'Naolinco de Victoria', 'Moalinco,Naolinco,Naolinco de Victoria', 19.6547400, -96.8732000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95010, 'Villa Nanchital', 'Villa Nanchital', 'Nanchital,Villa Nanchital', 18.0711700, -94.4075600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95011, 'Ciudad de Nanacamilpa', 'Ciudad de Nanacamilpa', 'Nanacamilpa,San Jose,San José', 19.4924100, -98.5352600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95012, 'Nacajuca', 'Nacajuca', 'Nacajuca,Nacanica', 18.1697100, -93.0184300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95013, 'Muna', 'Muna', 'Muna', 20.4879400, -89.7138700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95014, 'Motzorongo', 'Motzorongo', 'Motzorongo', 18.6425200, -96.7294900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95015, 'Motul', 'Motul', 'Motul,Motul de Carrillo Puerto,Motul de Felipe Carrillo Puerto,Motul'',Мотуль', 21.0957100, -89.2833200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95016, 'Motozintla', 'Motozintla', 'Motozintla,Motozintla de Mendoza,San Francisco Motozintla,Villa de Motozintla de Mendoza', 15.3669400, -92.2460500, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95017, 'Morelos Cañada', 'Morelos Canada', 'Canada Morelos,Cañada Morelos,Morelos,Morelos Canada,Morelos Cañada', 18.7354900, -97.4206800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95018, 'Moralillo', 'Moralillo', '', 22.2255200, -97.9121300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95019, 'Monte Redondo', 'Monte Redondo', 'Monte Redondo', 15.6521700, -92.0504500, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95020, 'Montemorelos', 'Montemorelos', 'Montemorelos', 25.1890900, -99.8286500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95021, 'Montecillo', 'Montecillo', 'Montecillo', 19.4571100, -98.9083500, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95022, 'La Laguna y Monte del Castillo', 'La Laguna y Monte del Castillo', 'La Laguna,Monte Castillo', 18.9833400, -96.0780600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95023, 'Monte Blanco', 'Monte Blanco', 'Monte Blanco', 18.9664200, -97.0168400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95024, 'Santiago Momoxpan', 'Santiago Momoxpan', '', 19.0736100, -98.2669400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95025, 'Moloacán', 'Moloacan', 'Moloacan,Moloacán', 17.9854400, -94.3471400, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95026, 'Molango', 'Molango', 'Molango', 20.7869300, -98.7287800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95027, 'Mohoneras', 'Mohoneras', 'Cuadrilla Mohonera,Mohoneras,Mojoneras', 17.2350000, -99.5161100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95028, 'Mococha', 'Mococha', 'Mococha', 21.1062100, -89.4521700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95029, 'Santa María Mixtequilla', 'Santa Maria Mixtequilla', 'Mixtequilla,Santa Maria Mixtequilla,Santa María Mixtequilla', 16.3749600, -95.2603400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95030, 'Mixquiahuala de Juarez', 'Mixquiahuala de Juarez', 'Mixquiahuala,Mixquiahuala de Juarez', 20.2303100, -99.2139600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95031, 'Misantla', 'Misantla', 'Misantla', 19.9299200, -96.8519400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95032, 'Miramar', 'Miramar', 'Miramar', 22.3208500, -97.8595000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95033, 'Miquihuana', 'Miquihuana', 'Miquihuana', 23.5767700, -99.7538500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95034, 'Mineral del Monte', 'Mineral del Monte', 'Mineral del Monte,Mineral del Real del Monte,Real del Monte', 20.1383000, -98.6736400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95035, 'Minatitlán', 'Minatitlan', 'MTT,Minatitlan,Minatitlán,mi na di te lan,mynatytlan,Минатитлан,میناتیتلان,米納蒂特蘭', 18.0001100, -94.5569000, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95036, 'Milpa Alta', 'Milpa Alta', 'Milpa Alta', 19.1925100, -99.0231700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95037, 'Mier', 'Mier', 'Ciudad Mier,Mier', 26.4296900, -99.1521200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95038, 'Miahuatlán de Porfirio Díaz', 'Miahuatlan de Porfirio Diaz', 'Miahuatlan,Miahuatlan de Porfirio Diaz,Miahuatlán de Porfirio Díaz,San Andres,San Andres Miahuatlan,San Andrés,San Andrés Miahuatlán', 16.3327600, -96.5956200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95039, 'Miacatlán', 'Miacatlan', 'Miacatlan,Miacatlán', 18.7620300, -99.3594400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95040, 'Mezcala', 'Mezcala', 'Mexcala', 17.9324000, -99.6025700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95041, 'Mezquititlán', 'Mezquititlan', 'Metzquititlan,Metzquititlau,Metzquititlán,San Agustin,San Agustín', 20.5330700, -98.6374900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95042, 'Metlatónoc', 'Metlatonoc', 'Metlatonoc,Metlatónoc', 17.1948200, -98.4070600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95043, 'Metlaltoyuca', 'Metlaltoyuca', 'Metlaltoyuca,Metlatoyuca', 20.7355600, -97.8519400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95044, 'Metepec', 'Metepec', 'Metepec', 20.2376200, -98.3212200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95045, 'Metepec', 'Metepec', 'Metepec,Metepek,Metepēc,Municipio Metepec,Municipio de Metepec,mei te pei ke,mtpk,Метепек,متپک,梅特佩克', 19.2593400, -99.6017500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95046, 'Metapa', 'Metapa', 'Metapa,Metapa de Dominguez,Metapa de Domínguez', 14.8362400, -92.1918600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95047, 'Mérida', 'Merida', 'Ciudad de Merida,Ciudad de Mérida,Emerita,Gorad Meryda,MID,Merida,Merida i Yucatan,Mérida,Mérida i Yucatán,mardt,mei li da,melida,merida,mryda  ywkatan,Μέριδα,Горад Мерыда,Мерида,Меріда,ماردة,مریدا، یوکاتان,მერიდა,メリダ,梅里达,梅里達,메리다', 20.9753700, -89.6169600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95048, 'Mecayapan', 'Mecayapan', 'Mecayapan', 18.2200100, -94.8379400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95049, 'Mazatlán Villa de Flores', 'Mazatlan Villa de Flores', 'Mazatlan,Mazatlan Villa de Flores,Mazatlan de Flores,Mazatlán,Mazatlán Villa de Flores,Mazatlán de Flores,San Cristobal Mazatlan,San Cristóbal Mazatlán', 18.0326400, -96.9140400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95050, 'Mazatlán', 'Mazatlan', 'Masatlan,Mazatlan,Mazatlán,Mochitlan,Mochitlán,Масатлан', 17.4362000, -99.4648300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95051, 'Mazatepec', 'Mazatepec', 'Mazatepec', 18.7279500, -99.3633900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95052, 'Mazatecochco', 'Mazatecochco', 'Jose Maria Morelos,José María Morelos,Mazatecochco,Mazatecocho,San Cosme,San Cosme Mazatecochco,San Cosme Mazatocoxco', 19.1786500, -98.1867700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95053, 'Mazatán', 'Mazatan', 'Mazatan,Mazatlan,Mazatán', 14.8631900, -92.4503000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95054, 'Mazapa', 'Mazapa', 'Mazapa,Mazapa de Madero,San Martin Mazapa,San Martín Mazapa', 15.3877300, -92.1878000, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95055, 'Mayanalán', 'Mayanalan', 'Mayanalan,Mayanalán', 18.1729000, -99.4325900, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95056, 'Maxcanú', 'Maxcanu', 'Maxcanu,Maxcanú', 20.5845600, -90.0010000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95057, 'Matías Romero', 'Matias Romero', 'Matias Romero,Matías Romero', 16.8790200, -95.0393900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95058, 'Mata Tenatito (Casco Hacienda)', 'Mata Tenatito (Casco Hacienda)', 'Matatenatito,Metatematito', 18.7218700, -96.6628800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95059, 'Heroica Matamoros', 'Heroica Matamoros', 'Heroica Matamoros,MAM,Matamoros,Матаморос', 25.8797200, -97.5041700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95060, 'Martínez de la Torre', 'Martinez de la Torre', 'Martinez de la Torre,Martínez de la Torre', 20.0708200, -97.0607800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95061, 'Maitinez', 'Maitinez', '', 22.3716700, -99.2930600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95062, 'Mariano Escobedo', 'Mariano Escobedo', 'Mariano Escobedo', 18.9133300, -97.1300000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95063, 'Mapastepec', 'Mapastepec', 'Mapastepec', 15.4335800, -92.9003900, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95064, 'Manuel Lazos', 'Manuel Lazos', 'Manuel Lazos', 14.9715900, -92.1872600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95065, 'Colonia Manuel Gonzalez', 'Colonia Manuel Gonzalez', 'Colonia Manuel Gonzalez,Colonia Manuel González,Manuel Gonzalez,Manuel González', 19.1149500, -96.8593900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95066, 'Ursulo Galván', 'Ursulo Galvan', 'Ejido Manuel,Estacion Manuel,Estación Manuel,Manuel,Ursulo Galvan,Ursulo Galván', 22.7277900, -98.3219100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95067, 'Manlio Fabio Altamirano', 'Manlio Fabio Altamirano', 'Altamirano,Manlio Fabio Altamirano,Manlio Favio Altamirano,Purga', 19.0942500, -96.3335100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95068, 'Mani', 'Mani', 'Mani', 20.3877400, -89.3918900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95069, 'Mama', 'Mama', 'Mama,Mamá', 20.4785700, -89.3649800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95070, 'Maltrata', 'Maltrata', 'Maltrata', 18.8109100, -97.2753800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95071, 'Malinaltepec', 'Malinaltepec', 'Malinaltepec', 17.2450100, -98.6709100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95072, 'Malinalco', 'Malinalco', 'Malinal''ko,Malinalco,marinaruko,Малиналько,マリナルコ', 18.9484700, -99.4961900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95073, 'Santa María Malacatepec', 'Santa Maria Malacatepec', 'Malacatepec,Santa Maria Malacatepec,Santa María Malacatepec', 18.9414700, -98.3021800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95074, 'Tequisquiapan', 'Tequisquiapan', 'La Magdalena,Magdalena Tequisquiapan,Tequisquiapam,Tequisquiapan', 20.5244700, -99.8922800, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95075, 'Magdalena Tequisistlán', 'Magdalena Tequisistlan', 'Magdalena Tequisistlan,Magdalena Tequisistlán,Magdalena Tequistlan,Magdalena Tequistlán,Mixtequilla', 16.3992900, -95.6020400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95076, 'Magdalena Teitipac', 'Magdalena Teitipac', 'Magdalena Teitipac,Magdalena Teitipal,Teitipac', 16.9039300, -96.5584000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95077, 'Magdalena Mixtepec', 'Magdalena Mixtepec', 'Magdalena,Magdalena Mixtepec,Mixtepec', 16.8965900, -96.9061800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95078, 'Magdalena Jaltepec', 'Magdalena Jaltepec', 'Jaltepec,Magdalena,Magdalena Jaltepec', 17.3231800, -97.2212200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95079, 'Magdalena Cuayucatepec', 'Magdalena Cuayucatepec', 'Cuayacatepec,Cuayucatepec,Magdalena Cuayucatepec', 18.5497200, -97.4847200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95080, 'Magdalena Contreras', 'Magdalena Contreras', 'Magdalena Contreras', 19.3321200, -99.2111800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95081, 'Macuspana', 'Macuspana', 'Macuspana,San-Francisko Makushpana,ma ku si pa na,makwspana,Сан-Франциско Макушпана,ماکوسپانا,馬庫斯帕納', 17.7605200, -92.5953900, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95082, 'Macultepec', 'Macultepec', 'Macultepec', 18.1502600, -92.8609200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95083, 'Luis Gil Pérez', 'Luis Gil Perez', 'Luis Gil Perez,Luis Gil Pérez', 17.8754100, -93.0712400, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95084, 'Reyes Acozac', 'Reyes Acozac', 'Los Reyes Acozac,Los Reyes Xoloc,Reyes,Reyes Acozac', 19.7755000, -98.9807900, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95085, 'Los Reyes', 'Los Reyes', 'Los Reyes', 20.1552900, -98.1642400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95086, 'Los Reyes Acaquilpan', 'Los Reyes Acaquilpan', 'Los Reyes,Los Reyes Acaquilpan,Los Reyes La Paz,Reyes,Reyes la Paz', 19.3635700, -98.9770700, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95087, 'Los Reyes de Juárez', 'Los Reyes de Juarez', 'Los Reyes,Los Reyes de Juarez,Los Reyes de Juárez', 18.9491800, -97.8037900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95088, 'Los Ramones', 'Los Ramones', 'Los Ramones,Ramones', 25.6971600, -99.6252900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95089, 'Los Herreras', 'Los Herreras', 'Los Herreras', 25.9079700, -99.4047900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95090, 'Los Altos', 'Los Altos', 'Los Altos', 21.5097600, -97.7570500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95091, 'Almagres', 'Almagres', 'Almagre,Almagres,Los Almagres', 17.8075000, -94.9175000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95092, 'Loma Grande', 'Loma Grande', '', 18.9225000, -97.2308300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95093, 'Loma de Sogotegoyo', 'Loma de Sogotegoyo', 'Loma de Zogotegoyo,Sogotegoyo', 18.2189600, -94.9737300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95094, 'Loché', 'Loche', 'Loche,Loché', 21.3882800, -88.1456600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95095, 'Llera de Canales', 'Llera de Canales', 'Llera,Llera de Canales', 23.3177400, -99.0260800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95096, 'Llano de Enmedio', 'Llano de Enmedio', 'Llano Enmedio,Llano de Enmedio', 20.7832800, -98.0136400, 'MX', '2014-03-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95097, 'Linares', 'Linares', 'Linares,Линарес', 24.8579800, -99.5676800, 'MX', '2015-03-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95098, 'Libres', 'Libres', 'Libres,San Juan de los Llanos', 19.4657400, -97.6873700, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95099, 'Lerma de Villada', 'Lerma de Villada', 'Lerma,Lerma de Villada,Zerma de Villada', 19.2888100, -99.5116300, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95100, 'Lerdo de Tejada', 'Lerdo de Tejada', 'Lerdo de Tejada', 18.6293600, -95.5196800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95101, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Cardenas,Colonia Lazaro Cardenas,Colonia Lázaro Cárdenas,Lazaro Cardenas,Lázaro Cárdenas', 19.6403200, -98.4716600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95102, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Lazaro Cardenas,Lázaro Cárdenas', 15.7168000, -92.2545800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95103, 'La Trinitaria', 'La Trinitaria', 'La Trinitaria,Zapaluta', 16.1185900, -92.0520100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95104, 'Las Vigas de Ramírez', 'Las Vigas de Ramirez', 'Las Vigas,Las Vigas de Ramirez,Las Vigas de Ramírez,Vigas', 19.6372200, -97.0982100, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95105, 'Vegas de la Soledad y Soledad Dos', 'Vegas de la Soledad y Soledad Dos', '', 20.9447600, -97.8327300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95106, 'Las Minas', 'Las Minas', 'Las Minas', 19.6909100, -97.1459700, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95107, 'Las Margaritas', 'Las Margaritas', 'Las Margaritas', 16.3126500, -91.9810700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95108, 'Las Lomas', 'Las Lomas', 'Las Lomas,Loma', 19.4474500, -96.9061000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95109, 'Las Choapas', 'Las Choapas', 'Las Choapas', 17.9117700, -94.0964600, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95110, 'Las Amilpas', 'Las Amilpas', 'Amilpas,Las Amilpas', 16.3666700, -94.6166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95111, 'Larráinzar', 'Larrainzar', 'Larrainzar,Larráinzar,San Andres,San Andrés', 16.8839200, -92.7132900, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95112, 'La Reforma', 'La Reforma', 'La Reforma', 24.6982200, -99.5412700, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95113, 'La Perla', 'La Perla', 'La Perla,Perla', 18.9281700, -97.1336200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95114, 'La Pedrera', 'La Pedrera', 'La Pedrera', 22.3935300, -97.8821000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95115, 'La Misión', 'La Mision', 'La Mision,La Misión', 23.8032600, -99.1702500, 'MX', '2014-01-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95116, 'La Magdalena Yancuitlalpan', 'La Magdalena Yancuitlalpan', 'La Magdalena Yancuitlalpan,La Magdalena Yancuitlapan,Yancuitlalpan', 18.9108300, -98.5894400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95117, 'La Libertad', 'La Libertad', 'La Libertad', 14.5916700, -92.1931500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95118, 'La Joya', 'La Joya', 'La Joya', 19.6109900, -97.0268700, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95119, 'La Joya', 'La Joya', '', 18.6666700, -99.4666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95120, 'La Isla', 'La Isla', 'Isla,La Isla', 18.6000000, -96.1500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95121, 'Laguna Chica (Pueblo Nuevo)', 'Laguna Chica (Pueblo Nuevo)', '', 18.5430600, -96.7330600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95122, 'La Guadalupe', 'La Guadalupe', 'Guadalupe,La Guadalupe', 16.6888300, -98.2622200, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95123, 'La Defensa', 'La Defensa', 'Defensa,La Defensa', 20.1050700, -96.9607900, 'MX', '2014-03-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95124, 'Santo Tomás la Concordia', 'Santo Tomas la Concordia', '', 19.2291700, -98.3194400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95125, 'La Concordia', 'La Concordia', 'La Concordia,Nueva Concordia', 16.1177400, -92.6901800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95126, 'La Concepción de los Baños', 'La Concepcion de los Banos', 'Concepcion de los Banos,Concepcion de los Baños,La Concepcion,La Concepcion de los Banos,La Concepcion los Banos,La Concepción,La Concepción de los Baños,La Concepción los Baños', 19.6824900, -99.8610400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95127, 'La Concepción Coatipac (La Conchita)', 'La Concepcion Coatipac (La Conchita)', 'Coatipac,Concepcion,Concepción,La Concepcion,La Concepcion Coatipac,La Concepción,La Concepción Coatipac', 19.1818800, -99.5683300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95128, 'La Ceiba', 'La Ceiba', 'La Ceiba', 20.7528700, -97.9084000, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95129, 'La Capilla', 'La Capilla', 'La Capilla', 19.7275600, -99.5236600, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95130, 'Komchén', 'Komchen', 'Komchen,Komchén', 21.1034200, -89.6624200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95131, 'Kinchil', 'Kinchil', 'Kinchil', 20.9151900, -89.9482500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95132, 'Kantunil', 'Kantunil', 'Kantunil', 20.7964500, -89.0353900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95133, 'Kanasín', 'Kanasin', 'Kanacin,Kanacín,Kanasin,Kanasín,Kanazin', 20.9348200, -89.5587100, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95134, 'Juchitepec de Mariano Riva Palacio', 'Juchitepec de Mariano Riva Palacio', 'Juchitepec,Juchitepec de Mariano Riva Palacio,Xuchitepec', 19.1005900, -98.8788000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95135, 'Juchitán de Zaragoza', 'Juchitan de Zaragoza', 'Juchitan,Juchitan de Zaragoza,Juchitán,Juchitán de Zaragoza,Khuchitan-de-Saragosa,Opstina Heroica Ciudad de Juchitan de Zaragoza,Opština Heroica Ciudad de Juchitán de Zaragoza,Xochitlan Zaragoza,Хучитан-де-Сарагоса', 16.4360300, -95.0197500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95136, 'Juchique de Ferrer', 'Juchique de Ferrer', 'Juchique de Ferrer', 19.8398500, -96.6946300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95137, 'Colonia Juárez', 'Colonia Juarez', '', 16.2096700, -95.0272200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95138, 'Juan Marcos (San José Buenavista)', 'Juan Marcos (San Jose Buenavista)', '', 19.7291700, -97.1966700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95139, 'Joquicingo de León Guzmán', 'Joquicingo de Leon Guzman', 'Joquicingo,Joquicingo de Leon Guzman,Joquicingo de León Guzmán', 19.0503200, -99.5337500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95140, 'Jonuta', 'Jonuta', 'Jonuta', 18.0898400, -92.1380700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95141, 'Jonotla', 'Jonotla', 'Jonotla,Opstina Jonotla,Opština Jonotla', 20.0303200, -97.5753000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95142, 'Jonacatepec', 'Jonacatepec', 'Jonacatepec,Jonacatepec de Leandro Valle', 18.6808100, -98.8033600, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95143, 'Jojutla', 'Jojutla', 'Jojutla,Jojutla de Juarez,Jojutla de Juárez', 18.6147200, -99.1802800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95144, 'Jocotitlán', 'Jocotitlan', 'Jocotitlan,Jocotitlán,Xocotitlan,Xocotitlán', 19.7099100, -99.7886700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95145, 'Jiutepec', 'Jiutepec', 'Jiutepec,Xiutepec', 18.8813900, -99.1777800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95146, 'Jitotol de Zaragoza', 'Jitotol de Zaragoza', 'Jitotol,Jitotol de Zaragoza', 17.0672300, -92.8611100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95147, 'Jiquipilco', 'Jiquipilco', 'Jiquipilco,San Juan Jiquipilco,Xiquipilco', 19.5564400, -99.6083300, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95148, 'Jiquipilas', 'Jiquipilas', 'Jianipilas,Jiquipilas,Jiquipilla', 16.6680600, -93.6466700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95149, 'Jilotzingo', 'Jilotzingo', 'Jilotaingo,Jilotzingo,San Marcos Jilotzingo', 19.8688900, -99.0619400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95150, 'Jilotepec de Molina Enríquez', 'Jilotepec de Molina Enriquez', 'Jilotepec,Jilotepec de Abasolo', 19.9519400, -99.5327800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95151, 'Jilotepec', 'Jilotepec', 'Jilotepec', 19.6118400, -96.9516900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95152, 'Jesús del Monte', 'Jesus del Monte', 'Jesus del Monte,Jesús del Monte', 19.1208900, -99.9878600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95153, 'Jesús Carranza', 'Jesus Carranza', 'Jesus Carranza,Jesús Carranza,Santa Lucrecia', 17.4352600, -95.0263700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95154, 'San Juan Bautista Jayacatlán', 'San Juan Bautista Jayacatlan', 'Jayacatlan,Jayacatlán,San Juan Bautista Jayacatlan,San Juan Bautista Jayacatlán', 17.4244300, -96.8230900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95155, 'Jaumave', 'Jaumave', 'Jaumave', 23.4062100, -99.3807200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95156, 'Jantetelco', 'Jantetelco', 'Jantetelco,San Pedro', 18.7182800, -98.7776000, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95157, 'Jamapa', 'Jamapa', 'Jamapa', 19.0417900, -96.2414300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95158, 'Jaltocan', 'Jaltocan', 'Jaltocan,Jaltocán,Xaltocan', 21.1328400, -98.5389800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95159, 'Jáltipan de Morelos', 'Jaltipan de Morelos', 'Jaltipan,Jaltipan de Morelos,Jáltipan,Jáltipan de Morelos', 17.9654200, -94.7139600, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95160, 'Jaltepec', 'Jaltepec', 'Jaltepec,Xaltepec', 19.7296000, -98.6345600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95161, 'Jaltenco', 'Jaltenco', 'Jaltenco,Jaltengo,San Andres Jaltenco,San Andres Jaltengo,San Andrés Jaltenco,San Andrés Jaltengo,Xaltenco', 19.7529800, -99.0939000, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95162, 'Jalpan', 'Jalpan', 'Jalpan', 21.2180200, -99.4715200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95163, 'Jalpa de Méndez', 'Jalpa de Mendez', 'Jalpa,Jalpa de Mendez,Jalpa de Méndez', 18.1763300, -93.0630000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95164, 'Jalcomulco', 'Jalcomulco', 'Jalcomulco,Jalconiulco', 19.3318500, -96.7625000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95165, 'Xalatlaco', 'Xalatlaco', 'Jalatiaco,Jalatlaco,Xalatlaco', 19.1831400, -99.4184400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95166, 'Jalapilla', 'Jalapilla', 'Jalapilla,Jalapillo', 18.8264200, -97.0886500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95167, 'Xalapa de Enríquez', 'Xalapa de Enriquez', 'JAL,Jalapa,Jalapa Enriques,Jalapa Enriquez,Jalapa Enríquez,Xalapa,Xalapa de Enriquez,Xalapa de Enríquez,Xalapa-Enriquez,Xalapa-Enríquez', 19.5312400, -96.9158900, 'MX', '2013-11-24', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95168, 'Jalapa', 'Jalapa', 'Jalapa,Jalapa de Diaz,Khalapa,Халапа', 16.5000000, -95.4666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95169, 'Jalacingo', 'Jalacingo', 'Jalacingo', 19.8033300, -97.3083000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95170, 'Jacala', 'Jacala', 'Jacala,Jacala de Ledesma,Xacala', 21.0095200, -99.1913400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95171, 'Izúcar de Matamoros', 'Izucar de Matamoros', 'Isukar-de-Matamoros,Izucar,Izucar de Matamoros,Izúcar,Izúcar de Matamoros,Matamoros,Matamoros de Izucar,Matamoros de Izúcar,Исукар-де-Матаморос', 18.6015700, -98.4615200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95172, '1ra. Sección de Izapa', '1ra. Seccion de Izapa', 'Izapa', 14.9208300, -92.1708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95173, 'Izamal', 'Izamal', 'Izamal', 20.9353700, -89.0180200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95174, 'Ixtlahuaca de Rayón', 'Ixtlahuaca de Rayon', 'Ixtlahuaca,Ixtlahuaca de Rayon,Ixtlahuaca de Rayón', 19.5688900, -99.7669400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95175, 'San Jerónimo Ixtepec', 'San Jeronimo Ixtepec', 'IZT,Ixtepec,San Geronimo Ixtepec', 16.5785500, -95.1022300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95176, 'Ixtapan de la Sal', 'Ixtapan de la Sal', 'Ixtapan de la Sal', 18.8436900, -99.6767100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95177, 'Ixtapaluca', 'Ixtapaluca', 'Ixtapaluca,Iztapaluca', 19.3155600, -98.8828400, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95178, 'Iztapalapa', 'Iztapalapa', 'Delegacion Iztapalapa,Delegación Iztapalapa,Delegazione Iztapalapa,Istapalapa,Ixtapalapa,Iztaoalaoa,Iztapalapa,Iztapalapan,Iztapalāpan,yi si ta pa la pa,Истапалапа,伊斯塔帕拉帕', 19.3552900, -99.0622400, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95179, 'Ixtapa', 'Ixtapa', 'Ixtapa', 16.8032000, -92.9053200, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95180, 'Ixtaczoquitlán', 'Ixtaczoquitlan', 'Ixtac Zoquitlan,Ixtac Zoquitlán,Ixtaczoquitlan,Ixtaczoquitlán', 18.8536400, -97.0622900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95181, 'Ixtacomitán', 'Ixtacomitan', 'Ixtacomitan,Ixtacomitán', 17.4309300, -93.0970400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95182, 'Ixtacamaxtitlán', 'Ixtacamaxtitlan', 'Ixtacamaxtitlan,Ixtacamaxtitlán,San Francisco', 19.6235200, -97.8153900, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95183, 'Iztacalco', 'Iztacalco', 'Delegacion de Ixtacalco,Delegación de Ixtacalco,Ixtacalco,Iztacalco', 19.3952800, -99.0977800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95184, 'Ixmiquilpan', 'Ixmiquilpan', 'Iximiquilpan,Ixmiquilpan', 20.4784100, -99.2169700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95185, 'Ixil', 'Ixil', 'Ixil', 21.1523500, -89.4818200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95186, 'Ixhuatlán del Café', 'Ixhuatlan del Cafe', 'Ixhuatlan,Ixhuatlan del Cafe,Ixhuatlan-Cordoba,Ixhuatlán,Ixhuatlán del Café,Ixhuatlán-Córdoba', 19.0511800, -96.9839100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95187, 'Ixhuatlancillo', 'Ixhuatlancillo', 'Ixhuatlancillo', 18.8976600, -97.1489900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95188, 'San Francisco Ixhuatan', 'San Francisco Ixhuatan', 'Ixhuatan,Ixhuatán,San Francisco Ixhuatan', 16.3510900, -94.4840200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95189, 'Ixcatlán', 'Ixcatlan', '', 21.0813400, -98.5346800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95190, 'Ixcatepec', 'Ixcatepec', 'Ixcatepec,Santa Maria Ixcatepec', 21.2369500, -98.0068900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95191, 'Ixcateopan de Cuauhtémoc', 'Ixcateopan de Cuauhtemoc', 'Ichcateopan,Ixcateopan,Ixcateopan de Cuauhtemoc,Ixcateopan de Cuauhtémoc', 18.5013900, -99.7913900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95192, 'Ixcapuzalco', 'Ixcapuzalco', 'Ixcapuzalco', 18.5120400, -99.8875500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95193, 'Isla Mujeres', 'Isla Mujeres', 'ISJ,Mujeres', 21.2311400, -86.7310500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95194, 'Isla Aguada', 'Isla Aguada', 'Aguada,Isla Aguada,Isla de Aguada,La Aguada', 18.7871400, -91.4927700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95195, 'Ixhuatán', 'Ixhuatan', 'Ishuatan,Ishuatán,Ixhuatan,Ixhuatán', 17.2934100, -93.0082900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95196, 'Iguala de la Independencia', 'Iguala de la Independencia', 'Iguala,Iguala de la Independencia,Iguala-de-la-Independensija,aygwala,yi gua la zi zhi shi,Игуала-де-ла-Индепенденсия,ایگوالا,伊瓜拉自治市', 18.3453600, -99.5413000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95197, 'Mixtequilla', 'Mixtequilla', 'Ignacio de la Llave,Mixtequilla,San Cristobal Llave,San Cristobal de la Llave,San Cristóbal Llave', 18.7258000, -95.9869600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95198, 'Itzincab Palomeque', 'Itzincab Palomeque', 'Idzincab,Itzincab,Itzincab Palomeque', 20.9164400, -89.6982300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95199, 'Hunucmá', 'Hunucma', 'Hunucma,Hunucmá', 21.0172300, -89.8755100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95200, 'Huixtla', 'Huixtla', 'Huixtla', 15.1391500, -92.4641000, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95201, 'Huixtán', 'Huixtan', 'Huistan,Huistán,Huixtan,Huixtán', 16.7106200, -92.4531700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95202, 'Huixquilucan de Degollado', 'Huixquilucan de Degollado', 'Huixouilucan de Degollado,Huixquilucan,Huixquilucan de Degollado', 19.3602800, -99.3498000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95203, 'Ciudad de Huitzuco', 'Ciudad de Huitzuco', 'Ciudad Huitzuco,Ciudad de Huitzuco,Huitzuco,Huitzuco de los Figueroa,Huizuco', 18.3033400, -99.3337600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95204, 'Huitziltepec', 'Huitziltepec', 'Huitziltepec,Huixiltepec', 17.7561000, -99.4798300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95205, 'Huitzilan', 'Huitzilan', 'Huitzilan,Huitzilan de Serdan,Huitzilán de Serdán,Huitzitlan', 19.9675000, -97.6944100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95206, 'Huitzilac', 'Huitzilac', 'Huitzilac', 19.0298300, -99.2678800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95207, 'Huitiupán', 'Huitiupan', 'Huitiupan', 17.1717400, -92.6857800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95208, 'Huixtepec', 'Huixtepec', 'Huistepec,Huitepec,Huixtepec', 16.6536100, -98.3045500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95209, 'Huimanguillo', 'Huimanguillo', 'Huimanguillo', 17.8336600, -93.3892600, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95210, 'Huiloapan de Cuauhtémoc', 'Huiloapan de Cuauhtemoc', '', 18.8172200, -97.1544400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95211, 'Huiloapan', 'Huiloapan', '', 18.7500000, -97.3166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95212, 'Huichapan', 'Huichapan', 'Huichapan', 20.3759300, -99.6486900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95213, 'Huhi', 'Huhi', 'Huhi,Huhí', 20.7260300, -89.1607200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95214, 'Hueytamalco', 'Hueytamalco', 'Hueytamalco', 19.9402900, -97.2884800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95215, 'Hueypoxtla', 'Hueypoxtla', 'Hueypoxtla', 19.9130100, -99.0738400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95216, 'Hueyotlipan', 'Hueyotlipan', 'Hueyotlipan,Hueyotlipan de Hidalgo,San Ildefonso,San Ildefonso Hueyotlipan', 19.4708800, -98.3477800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95217, 'Hueyapan de Ocampo', 'Hueyapan de Ocampo', 'Hueyapan', 18.1447900, -95.1487300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95218, 'Hueyapan', 'Hueyapan', 'Huayapan,Hueyapan', 18.8897000, -98.6820000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95219, 'Huepalcalco (San Miguel)', 'Huepalcalco (San Miguel)', '', 18.9088900, -98.7500000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95220, 'Huejutla de Reyes', 'Huejutla de Reyes', 'Huejutla,Huejutla de Reyes,Uehkhutla-de-Rejes,Уэхутла-де-Рейес', 21.1400000, -98.4194400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95221, 'Huejotzingo', 'Huejotzingo', 'Huejotzingo', 19.1589200, -98.4082400, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95222, 'Huehuetoca', 'Huehuetoca', 'Huehuetoca', 19.8356700, -99.2013100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95223, 'Huehuetla', 'Huehuetla', 'Huehuetla', 20.4605000, -98.0762700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95224, 'Huehuetla', 'Huehuetla', 'Huehuetla,Huehuetlan', 20.1057800, -97.6251700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95225, 'Huehuetán', 'Huehuetan', 'Huehuetan,Huehuetán', 15.0198100, -92.3824900, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95226, 'Huazuntlán', 'Huazuntlan', 'Guasuntlan,Huazuntlan,Huazuntlán', 18.1566700, -94.7930600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95227, 'Huazulco', 'Huazulco', 'Huazulco', 18.7529900, -98.7753500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95228, 'Huautla de Jiménez', 'Huautla de Jimenez', 'Huautla', 18.1315000, -96.8408800, 'MX', '2008-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95229, 'Huautla', 'Huautla', 'Huautla', 21.0310500, -98.2868500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95230, 'San Miguel Huautla', 'San Miguel Huautla', 'Huaulla,Huautla,San Miguel Huautla', 17.7453800, -97.1371200, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95231, 'Huauchinango', 'Huauchinango', 'Huauchinango', 20.1737600, -98.0549100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95232, 'Huatusco de Chicuellar', 'Huatusco de Chicuellar', 'Huatusco,Huatusco de Chicuellar', 19.1487600, -96.9676000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95233, 'Huatlatlauca', 'Huatlatlauca', 'Huatlatlahuac,Huatlatlahuca,Huatlatlauca', 18.6814700, -98.0504200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95234, 'Huasca de Ocampo', 'Huasca de Ocampo', 'Huasca,Huasca de Ocampo,Huasco,Huaxca', 20.2035700, -98.5760300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95235, 'Huaquechula', 'Huaquechula', 'Huaquechula', 18.7711600, -98.5446000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95236, 'Huamuxtitlán', 'Huamuxtitlan', 'Huamuctitilan,Huamuxtitan,Huamuxtitlan,Huamuxtitlán', 17.8028700, -98.5641700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95237, 'Hualahuises', 'Hualahuises', 'Hualahuises', 24.8829500, -99.6749000, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95238, 'Ciudad de Huajuapan de León', 'Ciudad de Huajuapan de Leon', 'Ciudad de Huajuapam de Leon,Ciudad de Huajuapam de León,Heroica Ciudad de Huajuapan de Leon,Heroica Ciudad de Huajuapan de León,Huajuapam,Huajuapam de Leon,Huajuapan,Huajuapan de Leon,Huajuapan de León,Huajuápam,Huajuápam de León,Seen', 17.8078700, -97.7795600, 'MX', '2016-11-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95239, 'Ex-Hacienda el Hospital', 'Ex-Hacienda el Hospital', '', 18.8311100, -98.9966700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95240, 'Hornitos', 'Hornitos', '', 19.4608300, -96.4211100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95241, 'Hopelchén', 'Hopelchen', 'Hopelchen,Hopelchén', 19.7467100, -89.8443700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95242, 'Homun', 'Homun', 'Homun,Homún', 20.7391800, -89.2849000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95243, 'Hoctun', 'Hoctun', 'Hoctun,Hoctún', 20.8651300, -89.2012500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95244, 'Hocaba', 'Hocaba', 'Hocaba,Hocabá', 20.8162000, -89.2462600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95245, 'Villa Hidalgo', 'Villa Hidalgo', 'Hidalgo,Hidalgo Yalalag,Villa Hidalgo,Villa Hidalgo Yalag,Yalalag', 17.1840900, -96.1783100, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95246, 'Hidalgotitlán', 'Hidalgotitlan', 'Hidalgotitlan,Hidalgotitlán', 17.7705100, -94.6470300, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95247, 'Hidalgo', 'Hidalgo', '', 26.0500000, -98.2000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95248, 'Santa Cruz Hidalgo', 'Santa Cruz Hidalgo', 'Hidalgo,Santa Cruz Hidalgo', 19.9666300, -96.8799800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95249, 'Hecelchakán', 'Hecelchakan', 'Hecelchacan,Hecelchakan,Hecelchakán', 20.1773500, -90.1335700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95250, 'Halachó', 'Halacho', 'Halacho,Halachó', 20.4777000, -90.0810400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95251, 'Gutiérrez Zamora', 'Gutierrez Zamora', 'Guetierrez Zamora,Gutierrez Zamora,Gutiérrez Zamora', 20.4534700, -97.0858800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95252, 'Nuevo Juan del Grijalva', 'Nuevo Juan del Grijalva', '', 17.4272200, -93.3722200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95253, 'Graciano Sánchez', 'Graciano Sanchez', 'Graciano Sanchez,Graciano Sánchez', 23.9256900, -99.2961000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95254, 'General Teran', 'General Teran', 'General Teran,General Terán', 25.2585700, -99.6837100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95255, 'Tancanhuitz de Santos', 'Tancanhuitz de Santos', 'Ciudad Santos,General Pedro Antonio Santos,Pedro Antonio Santos,Pedro Antonio de Santos,Tancanhuitz,Tancanhuitz de Santos', 21.5979000, -98.9677300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95256, 'General Bravo', 'General Bravo', 'General Bravo', 25.7923900, -99.1814700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95257, 'Frontera Hidalgo', 'Frontera Hidalgo', 'Frontera Hidalgo', 14.7774400, -92.1774100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95258, 'Comalapa', 'Comalapa', 'Comalapa,Frontera Comalapa,Laguna Camalapa', 15.6592400, -92.1423700, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95259, 'Frontera', 'Frontera', 'Alvaro Obregon,Frontera,Ponta Frontera,Puerto Alvaro Obregon,Puerto Obregon,Puerto Álvaro Obregon,Álvaro Obregón,Фронтера', 18.5432600, -92.6453000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95260, 'Francisco I. Madero', 'Francisco I. Madero', 'Francisco I. Madero', 15.0699600, -92.5443500, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95261, 'Fortín de las Flores', 'Fortin de las Flores', 'El Fortin,El Fortín,Fortin,Fortin de las Flores,Fortín,Fortín de las Flores', 18.9080600, -97.0000000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95262, 'Fontezuelas', 'Fontezuelas', '', 20.4886100, -98.8730600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95263, 'Flor de Cacao', 'Flor de Cacao', '', 16.1288900, -90.4511100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95264, 'Filomeno Mata', 'Filomeno Mata', 'Filomeno Mata,Santo Domingo', 20.2000400, -97.7039200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95265, 'Felipe Carrillo Puerto', 'Felipe Carrillo Puerto', 'Felipe Carillo Puerto,Felipe Carrillo Puerto,Santa Cruz de Bravo', 19.5775000, -88.0452900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95266, 'Ezequiel Montes', 'Ezequiel Montes', 'Corrat Blanco,Ezequiel Montes', 20.6648100, -99.8996000, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95267, 'Puntilla Aldama', 'Puntilla Aldama', 'Estero,Puntilla Aldama', 20.1891500, -96.9069300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95268, 'Espita', 'Espita', 'Ehspita,Espita,Эспита', 21.0109800, -88.3068100, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95269, 'El Espinal', 'El Espinal', 'El Espinal,Espinal,Santa Cruz', 16.4852500, -95.0399500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95270, 'Esperanza', 'Esperanza', 'Esperanza', 18.8585300, -97.3764100, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95271, 'Españita', 'Espanita', 'Espanita,Españita', 19.4628600, -98.4243400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95272, 'Escuintla', 'Escuintla', 'Escuintla', 15.3194400, -92.6583300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95273, 'Escárcega', 'Escarcega', 'Ehskarsega,Escarcega de Matamoros,Francisco Escarcega,Francisco Escárcega,Kilometro 45,Kilómetro 45,Эскарсега', 18.6089100, -90.7454400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95274, 'Epazoyucan', 'Epazoyucan', 'Epazoyuca,Epazoyucan', 20.0180100, -98.6362300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95275, 'Villa Emilio Carranza', 'Villa Emilio Carranza', 'Emilio Carranza,Santa Barbara,Santa Bárbara,Villa Emilio Carranza', 19.9702000, -96.6116200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95276, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 19.6549000, -98.5449700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95277, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 18.8406500, -99.1846300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95278, 'Emiliano Zapata', 'Emiliano Zapata', 'Ehmiliano Sapata,Emiliano Zapata,Montecristo,Montecrito,Эмилиано Сапата', 17.7405800, -91.7663500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95279, 'San Lucas', 'San Lucas', 'El Zapotal,San Lucas', 16.6116700, -92.7180600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95280, 'El Tejar', 'El Tejar', '', 19.0743300, -96.1609700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95281, 'El Rincón', 'El Rincon', 'El Rincon,El Rincón,Rincon,Rincón', 20.7411100, -99.7847200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95282, 'El Porvenir de Velasco Suárez', 'El Porvenir de Velasco Suarez', 'El Porvenir,El Porvenir de Velasco Suarez,El Porvenir de Velasco Suárez,Porvenir', 15.4569500, -92.2798700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95283, 'San Marcos Eloxochitlán', 'San Marcos Eloxochitlan', '', 20.0252800, -97.8719400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95284, 'Eloxochitlán de Flores Magón', 'Eloxochitlan de Flores Magon', 'Eloxochitlan,Eloxochitlan de Flores Magon,Eloxochitlán,Eloxochitlán de Flores Magón,San Antonio Eloxochitlan,San Antonio Eloxochitlan de Flores Magon,San Antonio Eloxochitlán,San Antonio Eloxochitlán de Flores Magon', 18.1772400, -96.8753800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95285, 'El Ocotito', 'El Ocotito', 'El Ocotito,Ocotito', 17.2460300, -99.5152500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95286, 'El Nopal', 'El Nopal', 'El Nopal,Nopal', 16.9116100, -92.8447100, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95287, 'Ciudad Mante', 'Ciudad Mante', 'Ciudad Mante,El Mante,Juarez,Juárez,MMC,Villa Juarez,Villa Juárez,Villa Mante', 22.7430400, -98.9739000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95288, 'El Llano', 'El Llano', 'El Llano', 20.0653700, -99.3197600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95289, 'El Limonar', 'El Limonar', 'El Limonar', 16.9702600, -91.3782000, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95290, 'El Higo', 'El Higo', 'El Higo', 21.7670800, -98.4518600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95291, 'El Espinal', 'El Espinal', 'El Espinal,Espinal', 16.3686200, -94.1044900, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95292, 'El Cazadero', 'El Cazadero', 'Cazadero,El Cazadero', 20.3001100, -99.8718600, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95293, 'El Castillo', 'El Castillo', 'El Castillo', 19.5466100, -96.8642500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95294, 'El Carmen Aztama', 'El Carmen Aztama', 'Carmen,El Carmen Aztama', 19.2297200, -98.2194400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95295, 'El Bosque', 'El Bosque', 'El Bosque,San Juan', 17.0627300, -92.7214700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95296, 'El Arenal', 'El Arenal', 'Arenal,El Arenal', 20.2225800, -98.9095700, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95297, 'Ejutla de Crespo', 'Ejutla de Crespo', 'Ejutla,Ejutla de Crespo', 16.5662300, -96.7312300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95298, 'Ecatzingo de Hidalgo', 'Ecatzingo de Hidalgo', 'Ecatzingo,Ecatzingo de Hidalgo', 18.9550800, -98.7519800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95299, 'Ecatepec', 'Ecatepec', 'Ecatepec,Ecatepec Morelos,Ecatepec de Morelos,Morelos,San Cristobal,San Cristobal Ecatepec,San Cristobal Ecatepec de Morelos,San Cristóbal,San Cristóbal Ecatepec,San Cristóbal Ecatepec de Morelos', 19.6049200, -99.0606400, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95300, 'Dzitnup', 'Dzitnup', 'Dzitnup', 20.6472500, -88.2445300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95301, 'Dzitbalché', 'Dzitbalche', 'Dzibalche,Dzibalché,Dzitbalche,Dzitbalché,Tzitbalche,Tzitbalché', 20.3185700, -90.0561100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95302, 'Dzitás', 'Dzitas', 'Dzitas,Dzitás,Tzitas', 20.8408900, -88.5290800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95303, 'Dzilam González', 'Dzilam Gonzalez', 'Dzilam,Dzilam Gonzalez,Dzilam González,Tzilam Gonzalez,Tzilam González', 21.2809800, -88.9295700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95304, 'Dzilam de Bravo', 'Dzilam de Bravo', 'Dzilam,Dzilam de Bravo,Tzilam de Bravo', 21.3919400, -88.8941000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95305, 'Dzidzantun', 'Dzidzantun', 'Dzidzantum,Dzidzantun,Dzidzantún,Tzitzantun,Tzitzantún', 21.2489800, -89.0420500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95306, 'Dzibalchén', 'Dzibalchen', 'Dzibalchen,Dzibalchén,Dzitbalchen', 19.4584700, -89.7311100, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95307, 'Dzemul', 'Dzemul', 'Dzemul,Tzemul', 21.2103600, -89.3095600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95308, 'Dzan', 'Dzan', 'Dzan', 20.3888800, -89.4685500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95309, 'Doxhicho', 'Doxhicho', 'Doxhicho', 19.9287800, -99.5580400, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95310, 'Doxey', 'Doxey', 'Doxey,Doxhey', 20.0916900, -99.2436200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95311, 'Dos Ríos', 'Dos Rios', '', 19.4841700, -96.7994400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95312, 'Domingo Arenas', 'Domingo Arenas', 'Domingo Arenas', 19.1399800, -98.4567800, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95313, 'Doctor Coss', 'Doctor Coss', 'Doctor Cos,Doctor Coss', 25.9249200, -99.1831600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95314, 'Villa Díaz Ordaz', 'Villa Diaz Ordaz', 'Diaz Ordaz,Díaz Ordaz,Villa Diaz Ordaz,Villa Díaz Ordaz', 16.9957800, -96.4323100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95315, 'Cuzama', 'Cuzama', 'Cuzama,Cuzamá,Guzama', 20.7420200, -89.3173200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95316, 'Cunduacán', 'Cunduacan', 'Conduacan,Conduacán,Cunduacan,Cunduacán', 18.0655700, -93.1730200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95317, 'Cuitláhuac', 'Cuitlahuac', 'Cuitlahuac,Cuitláhuac,San Juan de la Punta', 18.8142900, -96.7228100, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95318, 'Cuilapan de Guerrero', 'Cuilapan de Guerrero', 'Cuilapam,Cuilapan,Cuilapan de Guerrero,Cuilápam', 16.9775600, -96.7808100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95319, 'Cuichapa', 'Cuichapa', 'Cinchapa,Cuichapa', 18.7715000, -96.8689000, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95320, 'Cuetzalan', 'Cuetzalan', 'Chetzalan,Chetzalán,Ciudad de Cuetzalan,Coetzalan,Cuetzalan,Cuetzalan del Progreso,Cuetzalán del Progreso,Cuetzan del Progreso,San Francisco', 20.0176600, -97.5227700, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95321, 'Cuetzala del Progreso', 'Cuetzala del Progreso', 'Cuetzala,Cuetzala de Progreso,Cuetzala del Progreso,Cuetzalá de Progreso', 18.1347200, -99.8319000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95322, 'Cuernavaca', 'Cuernavaca', 'CVJ,Cuauhnahuac,Cuauhnāhuac,Cuernavaca,Gorad Kuehrnavaka,Kuehrnavaka,Kuernavaka,ku ai na wa ka,kueleunabaka,kuerunabaka,kwrnawak,Горад Куэрнавака,Куернавака,Куэрнавака,کورناواک,കെർണവാക്കാ,კუერნავაკა,クエルナバカ,庫埃納瓦卡,쿠에르나바카', 18.9261000, -99.2307500, 'MX', '2013-10-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95323, 'Cuautlapán', 'Cuautlapan', 'Cuautlapan,Cuautlapán', 18.8774700, -97.0229100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95324, 'Cuautlancingo', 'Cuautlancingo', 'Cuautlancingo,San Juan B. Cuautlancingo,San Juan Cuautlancingo', 19.0899500, -98.2731900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95325, 'Cuautla', 'Cuautla', 'Cuautla,Cuautla Morelos', 18.8106000, -98.9352500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95326, 'Santiago Cuautlalpan', 'Santiago Cuautlalpan', 'Cuautlalpan,Santiago Cuautlalpan', 19.6841700, -99.2887000, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95327, 'Cuautitlán', 'Cuautitlan', 'Cuautitlan,Cuautitlan de Romero Rubio,Cuautitlán,Cuautitlán de Romero Rubio,Kuautitlan,Куаутитлан', 19.6705200, -99.1798900, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95328, 'Cuautepec de Hinojosa', 'Cuautepec de Hinojosa', 'Cuautepec,Cuautepec de Hinojosa', 20.0355700, -98.3101500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95329, 'Cuautepec', 'Cuautepec', 'Cuautepec', 16.7500400, -99.0024000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95330, 'Cuauchichinola', 'Cuauchichinola', '', 18.6638900, -99.3758300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95331, 'Cuapiaxtla de Madero', 'Cuapiaxtla de Madero', 'Cuapiaxtla,Cuapiaxtla de Madero,Cuapixtla de Madero,Santa Catarina Cuapiaxtla', 18.9154400, -97.8238200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95332, 'Cuapiaxtla', 'Cuapiaxtla', 'Cuapiaxtla,Cuapixtla,San Lorenzo Cuapiaxtla', 19.2958800, -97.7688000, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95333, 'Cuanalá', 'Cuanala', 'Cuanala,Cuanalapa,Cuanalá,San Mateo,San Mateo Cuanala,San Matéo Cuanalá', 19.1091700, -98.3278800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95334, 'Cualác', 'Cualac', 'Cualac,Cualác', 17.7435000, -98.6603900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95335, 'Cuajinicuilapa de Santa Maria', 'Cuajinicuilapa de Santa Maria', 'Cuajinicualapa,Cuajinicuilapa,Cuajinicuilapa de Santa Maria,Cuajiniouilapan', 16.4734700, -98.4138900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95336, 'Delegación Cuajimalpa de Morelos', 'Delegacion Cuajimalpa de Morelos', 'Cuajimalpa,Cuajimalpa de Morelos,Delegacion Cuajimalpa de Morelos,Delegación Cuajimalpa de Morelos,Guajimalpa', 19.3692000, -99.2908900, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95337, 'Cuacnopalan', 'Cuacnopalan', 'Cuacnopalan,Cuagnopalan', 18.8175800, -97.5111600, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95338, 'Cruz Grande', 'Cruz Grande', 'Cruz Grande,Florencio Villarreal', 16.7224100, -99.1235600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95339, 'Cruz del Milagro', 'Cruz del Milagro', '', 17.9083300, -95.0108300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95340, 'Nuevo Crucitas', 'Nuevo Crucitas', '', 22.1083300, -99.2044400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95341, 'Cristóbal Obregón', 'Cristobal Obregon', '', 16.3500000, -93.5333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95342, 'San Miguel de Cozumel', 'San Miguel de Cozumel', 'CZM,Conzumel,Cozumel,San Miguel Cozumel,San Miguel de Cozumel', 20.5010000, -86.9459800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95343, 'Coyutla', 'Coyutla', 'Coyutla', 20.2472000, -97.6582400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95344, 'Coyotepec', 'Coyotepec', 'Coyotepec', 19.7772200, -99.2129500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95345, 'Coyoacán', 'Coyoacan', 'Coyoacan,Coyoacán,koyoakan,コヨアカン', 19.3467000, -99.1617400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95346, 'Coxquihui', 'Coxquihui', 'Cosquihui,Coxquihui', 20.1839800, -97.5856800, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95347, 'Coxcatlán', 'Coxcatlan', 'Coxcatlan,Coxcatlán', 18.2670900, -97.1507800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95348, 'Cosoleacaque', 'Cosoleacaque', 'Cosoleacaque', 17.9991300, -94.6359000, 'MX', '2017-03-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95349, 'Cosolapa', 'Cosolapa', 'Cosolapa,Cozolapa,Cusalapa,Gusalapa', 18.6005500, -96.6852400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95350, 'Heroica Coscomatepec de Bravo', 'Heroica Coscomatepec de Bravo', 'Coscomatepec,Coscomatepec de Bravo,Coseo Matepec,Heroica Coscomatepec de Bravo,San Juan Coscomatepec', 19.0727500, -97.0468500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95351, 'Cosautlán de Carvajal', 'Cosautlan de Carvajal', 'Cosautlan,Cosautlan de Carbajal,Cosautlan de Carvajal,Cosautlán,Cosautlán de Carbajal,Cosautlán de Carvajal', 19.3319600, -96.9903000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95352, 'Cosamaloapan de Carpio', 'Cosamaloapan de Carpio', 'Cosamaloapan,Cosamaloapan de Carpio', 18.3675900, -95.7985700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95353, 'Corral Nuevo', 'Corral Nuevo', '', 18.1146100, -95.1154200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95354, 'Corralillos', 'Corralillos', 'Corralillo,Corralillos,Corralito', 20.4827300, -97.5258200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95355, 'Córdoba', 'Cordoba', 'Cordoba,Córdoba,Huilonco,Kordoba,Kordov,Kordova,ke er duo wa,kwrdwba  wrakrwz,kwrdwba  wyrakrwz,Кордова,کوردوبا، وراکروز,کوردوبا، ویراکروز,科爾多瓦', 18.8842000, -96.9255900, 'MX', '2015-08-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95356, 'Copoya', 'Copoya', 'Copoya', 16.7119100, -93.1208900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95357, 'Copalillo', 'Copalillo', 'Copalillo', 18.0342700, -99.0412400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95358, 'Copala', 'Copala', 'Copala', 16.6077400, -98.9782100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95359, 'Copainalá', 'Copainala', 'Copainala,Copainalá', 17.0936600, -93.2105900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95360, 'San Bernardino Contla', 'San Bernardino Contla', 'Contla,San Bernardino,San Bernardino Contla', 19.3293200, -98.1664000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95361, 'Constancia del Rosario', 'Constancia del Rosario', 'Constancia,Constancia del Rosario', 17.0382000, -97.9412500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95362, 'Conkal', 'Conkal', 'Conkal', 21.0736500, -89.5199500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95363, 'Concepción Capulac (La Ex-Hacienda)', 'Concepcion Capulac (La Ex-Hacienda)', 'Capulac,Concepcion Capulac,Concepción Capulac', 19.0944400, -98.0613900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95364, 'Comoapan', 'Comoapan', '', 18.4068400, -95.1741500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95365, 'Comitán', 'Comitan', 'CJT,Comitan,Comitan de Dominguez,Comitán,Comitán de Domínguez,Komitan-de-Dominges,Комитан-де-Домингес', 16.2447100, -92.1342500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95366, 'San Pedro Comitancillo', 'San Pedro Comitancillo', 'Comitancillo,San Pedro Comitancillo', 16.4913400, -95.1564900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95367, 'Comapa', 'Comapa', 'Comapa', 19.1640400, -96.8866000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95368, 'Comales', 'Comales', 'Comales,Los Comales', 26.1818700, -98.9203700, 'MX', '2015-05-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95369, 'Comalcalco', 'Comalcalco', 'Comalcalco', 18.2631600, -93.2239700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95370, 'Colotepec', 'Colotepec', 'Colotepec', 17.0410400, -99.2127300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95371, 'Colipa', 'Colipa', 'Colipa', 19.9232300, -96.7271300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95372, 'Cocula', 'Cocula', 'Cocula', 18.2411600, -99.6620200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95373, 'Cocoyoc', 'Cocoyoc', 'Cocoyoc', 18.8841700, -98.9819400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95374, 'Cocotitlán', 'Cocotitlan', 'Cocotitlan,Cocotitlán', 19.2333600, -98.8659600, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95375, 'Coba', 'Coba', 'Coba,Cobá,Koba,Коба', 20.4829800, -87.7388800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95376, 'Coatzintla', 'Coatzintla', 'Coatzintla,Coazintla', 20.4869900, -97.4682300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95377, 'Coatzingo', 'Coatzingo', 'Coatzingo', 18.6119900, -98.1726700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95378, 'Coatzacoalcos', 'Coatzacoalcos', 'Coatzacoalcos,Koacakoal''kos,Koacakoalkos,Koacakoalkosas,Puerto Mexico,QTZ,koateusakoalkoseu,koatsu~akoarukosu,kua cha kua er ke si,kwatzakwalkws,Коацакоалкос,Коацакоалькос,کواتزاکوالکوس,კოაცაკოალკოსი,コアツァコアルコス,夸察夸爾科斯,코아트사코알코스', 18.1334600, -94.4424200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95379, 'Coatlán del Río', 'Coatlan del Rio', 'Coatlan del Rio,Coatlán del Río', 18.7442300, -99.4332400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95380, 'Coatetelco', 'Coatetelco', 'Coatetelco', 18.7296300, -99.3260500, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95381, 'Coatepec Harinas', 'Coatepec Harinas', 'Coatepec,Harinas', 18.8949200, -99.7215300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95382, 'Coatepec', 'Coatepec', 'Coatepec', 19.4522900, -96.9614800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95383, 'Santa Maria Coatepec', 'Santa Maria Coatepec', 'Coatepec,Santa Maria Coatepec', 19.1092400, -97.5925300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95384, 'Coatecas Altas', 'Coatecas Altas', 'Coateca,Coatecas,Coatecas Altas', 16.5392600, -96.6687800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95385, 'Coapilla', 'Coapilla', 'Coapilla', 17.1313700, -93.1594600, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95386, 'San Juan Coajomulco', 'San Juan Coajomulco', 'Coajomulco,San Juan Coajomulco', 19.7530600, -99.9686100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95387, 'Coacotzintla', 'Coacotzintla', 'Coacoatzintla,Coacoazintla,Coacotzintla', 19.6516300, -96.9404300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95388, 'Coacalco', 'Coacalco', 'Coacalco,Coacalco de Berriozabal,Coacalco de Berriozaval,Coacalco de Berriozábal,Coacalco de Berriozával', 19.6292300, -99.1068900, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95389, 'Ciudad Victoria', 'Ciudad Victoria', 'Altepetl Victoria,CVM,Cd. Victoria,Ciudad Victoria,Lungsod ng Victoria,S''judad-Viktorija,Sijudad Viktorija,Siudad Viktorija,Victoria,Victoria llaqta,shiudabikutoria,siudadeubigtolia,siw dad wik to reiy,sywdad wyktwrya,sywdd wyqtwryh,wei duo li ya cheng,Сиудад Виктория,Сијудад Викторија,Сьюдад-Виктория,סיודד ויקטוריה,سیوداد وکٹوریہ,سیوداد ویکتوریا,ซิวดัดวิกโตเรีย,სიუდად-ვიქტორია,シウダービクトリア,維多利亞城,시우다드빅토리아', 23.7417400, -99.1459900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95390, 'Ciudad Valles', 'Ciudad Valles', 'Cd Valles,Cd. Valles,Ciudad Valles,Ciudad de Valles,S''judad-Val''es,Valles,Сьюдад-Вальес', 21.9833300, -99.0166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95391, 'Ciudad Serdán', 'Ciudad Serdan', 'Chalchicomula,Chalchicomula de Sesma,Ciudad Serdan,Ciudad Serdán', 18.9885600, -97.4464300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95392, 'Ciudad Sahagun', 'Ciudad Sahagun', 'Bernardino de Sahagun,Bernardino de Sahagún,Ciudad Bernardino de Sahagun,Ciudad Bernardino de Sahagún,Ciudad Fray Bernardino Sahagun,Ciudad Fray Bernardino Sahagún,Ciudad Sahagun,Ciudad Sahagún,Sahagun,Sahagún', 19.7755700, -98.5747100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95393, 'Ciudad Pemex', 'Ciudad Pemex', 'Ciudad Pemex,Ciudad Penex,Pemex', 17.8826800, -92.4840600, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95394, 'Ciudad Nezahualcoyotl', 'Ciudad Nezahualcoyotl', 'Cd. Neza,Cd. Nezahualcoyotl,Cd. Nezahualcóyotl,Ciudad Netzahualcoyotl,Ciudad Netzahualcóyotl,Ciudad Neza,Ciudad Nezahualcoyotl,Ciudad Nezahualcóyotl,Nesahualkojotlis,Nesaual''kojotl'',Netzahualcoyotl,Netzahualcóyotl,Neza,Nezahualcoyotl,Nezahualcóyotl,Rancheria Netzahualcoyotl,Ranchería Netzahualcóyotl,Несауалькойотль', 19.4006100, -99.0148300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95395, 'Ciudad Miguel Alemán', 'Ciudad Miguel Aleman', 'Ciudad Aleman,Ciudad Alemán,Ciudad Miguel Alaman,Ciudad Miguel Alamán,Ciudad Miguel Aleman,Ciudad Miguel Alemán,Miguel Aleman,Miguel Alemán', 26.3995200, -99.0283600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95396, 'Ciudad Mendoza', 'Ciudad Mendoza', 'Camerino Z. Mendoza,Ciudad Mendoza,S''judad-Mendosa,Santa Rosa,Сьюдад-Мендоса', 18.8064500, -97.1787000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95397, 'Ciudad Madero', 'Ciudad Madero', 'Cd Madero,Cd. Madero,Ciudad Madero,S''judad-Madero,Siudad Maderas,Siudad Madero,Villa de Cecilia,ma de luo cheng,sywdad madrw,Сиудад Мадеро,Сьюдад-Мадеро,سیوداد مادرو,馬德羅城', 22.2722800, -97.8362300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95398, 'Ciudad Hidalgo', 'Ciudad Hidalgo', 'Ciudad Hidalgo,Frontera Diaz,Mariscal Suchiate,Suchiate', 14.6814800, -92.1521700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95399, 'Ciudad Fernández', 'Ciudad Fernandez', 'Ciudad Fernandez,Ciudad Fernández,Fernandez,Fernández,S''judad-Fernandes,Сьюдад-Фернандес', 21.9404500, -100.0115300, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95400, 'Mexico City', 'Mexico City', 'Cidade de Mexico,Cidade de México,Cidade do Mexico,Cidade do México,Cita du Messicu,Citta del Messico,Città del Messico,Cità dû Messicu,Cità dû Mèssicu,Ciudad Mexico,Ciudad de Mejico,Ciudad de Mexico,Ciudad de Méjico,Ciudad de México,Ciutat de Mexic,Ciutat de Mèxic,Lungsod ng Mexico,Lungsod ng México,MEX,Mehiko,Mekhiko,Meksikas,Meksiko,Meksiko Siti,Meksikurbo,Meksyk,Mexico,Mexico City,Mexico D.F.,Mexico DF,Mexico Distrito Federal,Mexico by,Mexico-stad,Mexicopolis,Mexiko,Mexiko Hiria,Mexiko-Stadt,Mexikoborg,Mexíkóborg,México,México Distrito Federal,Nkoyo,Pole tou Mexikou,Valle de Mexico,Valle de México,mdynt mksykw,megsiko si,megsikositi,mekishikoshiti,meksiko siti,meksikositi,mkzykw,mkzykwsyty,mo xi ge cheng,mqsyqw syty,Πόλη του Μεξικού,Мексико,Мексико Сити,Мехико,Мехіко,מקסיקו סיטי,مدينة مكسيكو,مکزیکو,مکزیکوسیتی,مېكسىكا شەھىرى,मेक्सिको सिटी,เม็กซิโกซิตี,მეხიკო,メキシコシティ,墨西哥城,멕시코 시,멕시코시티', 19.4284700, -99.1276600, 'MX', '2017-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95401, 'Ciudad del Maiz', 'Ciudad del Maiz', 'Ciudad del Maiz,Ciudad del Maíz,General Magdaleno Cedillo', 22.4018700, -99.6046800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95402, 'Ciudad del Carmen', 'Ciudad del Carmen', 'Altepetl Carmen,CME,Carmen,Cd Carmen,Cd del Carmen,Cd. Carmen,Cd. del Carmen,Ciudad del Carmen,S''judad-del''-Karmen,ka men cheng,sywdad dl karmn,Сьюдад-дель-Кармен,سیوداد دل کارمن,卡門城', 18.6459200, -91.8299100, 'MX', '2014-08-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95403, 'Cintalapa de Figueroa', 'Cintalapa de Figueroa', 'Cintalapa,Cintalapa de Figueroa', 16.6839300, -93.7181400, 'MX', '2014-07-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95404, 'Cieneguilla', 'Cieneguilla', 'Cieneguilla', 16.3235300, -97.3176200, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95405, 'Ciénega de Zimatlán', 'Cienega de Zimatlan', 'Cienaga,Cienega,Cienega de Zimatlan,Ciénaga,Ciénega,Ciénega de Zimatlán,La Cienega', 16.8934300, -96.7675600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95406, 'Chunhuhub', 'Chunhuhub', 'Chunhuhu,Chunhuhub', 19.5853300, -88.5922000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95407, 'Chumayel', 'Chumayel', '', 20.4283300, -89.3011100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95408, 'Chumatlán', 'Chumatlan', 'Chumatlan,Chumatlán', 20.2061000, -97.5940200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95409, 'Chontalpa', 'Chontalpa', 'Chontalpa,La Chontalpa', 17.6661400, -93.4811500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95410, 'San Pedro Chochula', 'San Pedro Chochula', 'Cholula,San Pedro Chochula,San Pedro Cholula', 19.2635900, -99.4859000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95411, 'Cholula', 'Cholula', 'Cholula,Cholula de Riva dabia,Colula,San Andres Cholula,San Andrés Cholula,San Pedro Cholula,San-Pedro-Cholula,chollulla,chwlwla,Čolula,Сан-Педро-Чолула,Чолула,چولولا,サン・ペドゥロ・チョルラ,촐룰라', 19.0640600, -98.3035200, 'MX', '2016-02-19', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95412, 'Cholul Cantón', 'Cholul Canton', 'Cholul,Cholul Canton,Cholul Cantón', 21.0107800, -89.2914700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95413, 'Chochola', 'Chochola', 'Chochola', 20.7508700, -89.8304100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95414, 'Chocaman', 'Chocaman', 'Chocaman,Chocamán', 19.0121400, -97.0329100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95415, 'Chiquihuitlán de Benito Juárez', 'Chiquihuitlan de Benito Juarez', 'Chiquihuitlan,Chiquihuitlan de Benito Juarez,Chiquihuitlán,Chiquihuitlán de Benito Juárez,San Juan Chiquihuitlan,San Juan Chiquihuitlán,Santa Ana Chiquihuitlan', 17.9958200, -96.7447400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95416, 'Chinampa de Gorostiza', 'Chinampa de Gorostiza', 'Chinampa,Chinampa de Gorostiza,Chinanpa de Gorostiza,San Antonio,San Antonio Chinanpa', 21.3595900, -97.7348400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95417, 'Chinameca', 'Chinameca', 'Chinameca', 18.0219500, -94.6794500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95418, 'China', 'China', 'China', 25.6999700, -99.2345400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95419, 'Chiná', 'China', 'China,Chiná', 19.7699300, -90.4959500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95420, 'Santiago Camotlán', 'Santiago Camotlan', 'Chimotlan,Santiago Camotlan,Santiago Camotlán', 17.4454100, -96.1850900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95421, 'San Francisco Chimalpa', 'San Francisco Chimalpa', 'Chimalpa,San Francisco Chimalpa', 19.4427900, -99.3439800, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95422, 'Chilpancingo', 'Chilpancingo', 'Chilpancingo,Chilpancingo de los Bravo,Chilpancingo de los Bravos,Ciudad Bravos', 17.5506000, -99.5057800, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95423, 'Chilón', 'Chilon', '', 17.2333300, -92.4166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95424, 'Chilcuautla', 'Chilcuautla', 'Chilcuautla', 20.3305900, -99.2311700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95425, 'Chilapa', 'Chilapa', '', 18.9886100, -97.1541700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95426, 'Chilapa de Alvarez', 'Chilapa de Alvarez', 'Chilapa,Chilapa de Alvarez', 17.5945900, -99.1763900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95427, 'Chila de la Sal', 'Chila de la Sal', 'Chila,Chila de la Sal', 18.1097500, -98.4857400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95428, 'Chikindzonot', 'Chikindzonot', 'Chicintzonot,Chikindzonot', 20.3343600, -88.4863000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95429, 'Chinautla', 'Chinautla', 'Chignautla,Chinautla', 19.8199600, -97.3885900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95430, 'Chignahuapan', 'Chignahuapan', 'Chignahuapan', 19.8386600, -98.0317100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95431, 'Chigmecatitlán', 'Chigmecatitlan', 'Chiginecatitlan,Chigmecatitlan,Chigmecatitlán,Chimecatitlan', 18.6463400, -98.0720300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95432, 'Chietla', 'Chietla', '', 18.5202800, -98.5788900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95433, 'Chicxulub Pueblo', 'Chicxulub Pueblo', 'Chicxulub,Chicxulub Pueblo,Pueblo Chicxulub', 21.1361700, -89.5162500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95434, 'Chicualoque', 'Chicualoque', '', 20.3827200, -97.6616300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95435, 'Chicontepec de Tejada', 'Chicontepec de Tejada', 'Chicontepec,Chicontepec de Tejada', 20.9721400, -98.1723900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95436, 'Chiconcuac', 'Chiconcuac', 'Chiconcuac,Chiconcuac de Juarez,Chiconcuac de Juárez,San Miguel Chiconcuac,Suarez,Suárez', 19.5593900, -98.8988400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95437, 'Chicomuselo', 'Chicomuselo', 'Chicomucelo,Chicomuselo', 15.7442000, -92.2833000, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95438, 'Chicoloapan', 'Chicoloapan', 'Chicoloapan,Chicoloapan de Juarez,Chicoloapan de Juárez,San Vicente Chicoloapan,San Vicente Chiloloapan', 19.4168700, -98.9020200, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95439, 'Chicola', 'Chicola', '', 18.9013900, -97.1080600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95440, 'Chichiquila', 'Chichiquila', 'Chichiquila', 19.2007300, -97.0669100, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95441, 'Chichimila', 'Chichimila', 'Chichimila,Chichimilá', 20.6317600, -88.2168900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95442, 'Chichihualco', 'Chichihualco', 'Chichihualco', 17.6590200, -99.6762400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95443, 'Chichén-Itzá', 'Chichen-Itza', 'Chichen Itza,Chichen-Ica,Chichen-Itza,Chichén-Itzá,Чичен-Ица', 20.6666700, -88.5666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95444, 'Chiautla de Tapia', 'Chiautla de Tapia', 'Chiautla,Chiautla de Tapia', 18.3014900, -98.6033900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95445, 'Chiautla', 'Chiautla', 'San Andres Chiautla,San Andrés Chiautla', 19.5489500, -98.8823600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95446, 'Chiaucingo', 'Chiaucingo', 'Chapancingo', 17.7420700, -98.6972000, 'MX', '2016-04-25', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95447, 'Chiapilla', 'Chiapilla', 'Chiapilla', 16.5697500, -92.7203700, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95448, 'Chiapa de Corzo', 'Chiapa de Corzo', 'Ch''japa-de-Korso,Chiapa,Chiapa de Corza,Chiapa de Corzo,Chiapas,Chiyapan Corzo,Ciapa de Korsas,Čiapa de Korsas,Чьяпа-де-Корсо', 16.7077000, -93.0118400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95449, 'Chetumal', 'Chetumal', 'CTM,Cetumalis,Chetumal,Chetumal'',Ciudad Chetumal,Payo Obispo,che tuma l,cheto~umaru,chetumal,chtwmal,chtwmal. kyntana rw,qie tu ma er,ztwml,Četumalis,Четумал,Четумаль,צטומל,چتومال,چتومال٬ کینتانا رو,เชตูมัล,ჩეტუმალი,チェトゥマル,切图马尔,체투말', 18.5141300, -88.3038100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95450, 'Chenalhó', 'Chenalho', 'Chenalho,Chenalhó,Chenalo,San Pedro Chenalho,San Pedro Chenalhó', 16.8936700, -92.6265100, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95451, 'Chemax', 'Chemax', 'Chemax', 20.6561300, -87.9364000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95452, 'Chelem', 'Chelem', 'Chelem,Chelen', 21.2696700, -89.7400600, 'MX', '2014-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95453, 'San Agustín Chayuco', 'San Agustin Chayuco', 'Chayuco,San Agustin,San Agustin Chayuco,San Agustín,San Agustín Chayuco', 16.4023400, -97.8082300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95454, 'Chapulhuacán', 'Chapulhuacan', 'Capulhuacan,Chapulhuacan,Chapulhuacán', 21.1573100, -98.9036100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95455, 'Chanal', 'Chanal', 'Chanal,San Pedro Chanal', 16.7166700, -92.4000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95456, 'Chamula', 'Chamula', 'Bohom,Chamula,Чамула', 16.7841600, -92.6895900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95457, 'Champotón', 'Champoton', 'Chakanputun,Champoton,Champotón,Chanputun,Чампотон', 19.3444100, -90.7257600, 'MX', '2013-08-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95458, 'Chalco', 'Chalco', 'Chalco,Chalco de Diaz Covarrubias,Chalco de Díaz Covarrubias', 19.2617400, -98.8977500, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95459, 'Chahuite', 'Chahuite', 'Chahuite,Chahuites', 16.3000000, -94.1833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95460, 'Chacaltianguis', 'Chacaltianguis', 'Chacaltianguis,Tecuanapa', 18.3052800, -95.8416700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95461, 'Chacalapa', 'Chacalapa', 'Chacalapa,Chacolapa', 18.0786000, -94.7028000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95462, 'Cerro Gordo', 'Cerro Gordo', 'Cerro Gordo', 19.5695100, -96.6483500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95463, 'Cerro Azul', 'Cerro Azul', 'Cerro Azul', 21.1920000, -97.7408800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95464, 'San Miguel Cerezo (El Cerezo)', 'San Miguel Cerezo (El Cerezo)', '', 20.1590900, -98.7285300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95465, 'Cepeda', 'Cepeda', 'Cepeda', 20.5060000, -90.1097900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95466, 'Cenotillo', 'Cenotillo', 'Cenotillo', 20.9662100, -88.6043800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95467, 'Celestún', 'Celestun', 'Celestun,Celestún', 20.8597300, -90.3990200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95468, 'Cazones de Herrera', 'Cazones de Herrera', 'Cazones,Cazones de Herrera,Villa de Cazones,Villa de Cazones de Herrera', 20.7042300, -97.3099400, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95469, 'Caxhuacán', 'Caxhuacan', 'Caxhuacan,Caxhuacán', 20.0635900, -97.6068800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95470, 'Caucel', 'Caucel', 'Caucel', 21.0153900, -89.7034700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95471, 'Catemaco', 'Catemaco', 'Catemaco', 18.4213100, -95.1139800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95472, 'Castillo de Teayo', 'Castillo de Teayo', 'Castillo de Teayo', 20.7492700, -97.6303000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95473, 'Carlos A. Carrillo', 'Carlos A. Carrillo', 'Carlos A. Carrillo,San Cristobal,San Cristóbal', 18.3747700, -95.7544400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95474, 'Cardenas', 'Cardenas', 'Cardenas,Cárdenas,Kardenas,Карденас', 22.0014400, -99.6424700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95475, 'Cárdenas', 'Cardenas', 'Cardenas,Cárdenas,Kardenas,Карденас', 18.0013500, -93.3755900, 'MX', '2014-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95476, 'Capulhuac', 'Capulhuac', 'Capulhuac,Capulhuac de Mirafuentes,Mirafuentes', 19.1935400, -99.4658500, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95477, 'Cansahcab', 'Cansahcab', 'Cansahcab', 21.1574900, -89.1013100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95478, 'Candelaria Loxicha', 'Candelaria Loxicha', 'Candelaria,Candelaria Loxicha,Candeloria,Loxicha', 15.9263800, -96.4926800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95479, 'Cancún', 'Cancun', 'CUN,Cancun,Cancún,Ciudad Cancun,Ciudad Cancún,Gorad Kankun,Kan''koun,Kankun,Kankuna,Kankunas,gang guan,kan kun,kang kun,kangkun,kankun,kankuna,kankwn,kankwn. kyntana rw,qnqwn,Κανκούν,Горад Канкун,Канкун,Կանկուն,קנקון,كانكون,کانکون,کانکون٬ کینتانا رو,कान्कुन,กังกุน,ကင်န်ကွန်မြို့,კანკუნი,カンクン,坎昆,港觀,칸쿤,캉쿤', 21.1742900, -86.8465600, 'MX', '2017-06-29', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95480, 'Cancuc', 'Cancuc', 'Cancuc,Canuc', 16.9166700, -92.4833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95481, 'Campeche', 'Campeche', 'CPE,Campeche,Kampeche,San Francisco de Campeche,Кампече', 19.8438600, -90.5255400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95482, 'Camargo', 'Camargo', '', 26.2545700, -98.8435300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95483, 'San Martín Caltenco', 'San Martin Caltenco', 'Caltenco,San Martin Caltenco,San Martín Caltenco', 18.8848700, -97.8188700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95484, 'Calpulalpan', 'Calpulalpan', 'Calpulalpam,Calpulalpan,Calpulapam,Calpulápam,Kal''pulal''pane,San Antonio Calpulapam,San Antonio Calpulápam,Кальпулальпане', 19.5886700, -98.5697200, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95485, 'Calotmul', 'Calotmul', 'Calatmul,Calotmul', 21.0205000, -88.1772300, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95486, 'Calnali', 'Calnali', 'Calnali,Calnalí', 20.8968700, -98.5851100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95487, 'Calmeca', 'Calmeca', 'Calmeca,San Juan Calmeca', 18.6350100, -98.6341400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95488, 'Calkiní', 'Calkini', 'Calkini,Calkiní,Kalkini', 20.3690500, -90.0511900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95489, 'Calixtlahuaca', 'Calixtlahuaca', 'Calixtlahuaca', 19.3365100, -99.6892300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95490, 'Calimaya de Díaz González', 'Calimaya de Diaz Gonzalez', 'Calimaya,Calimaya Diaz Gonzalez,Calimaya Díaz González,Calimaya de Diaz Gonzalez,Calimaya de Díaz González', 19.1632400, -99.6181000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95491, 'Calihualá', 'Calihuala', 'Calihuala,Calihualá,Colihuala', 17.5313400, -98.2779200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95492, 'Calderitas', 'Calderitas', 'Calderas,Calderitas', 18.5556400, -88.2551800, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95493, 'Cadereyta', 'Cadereyta', 'Cadereyta,Cadereyta de Montes', 20.6970100, -99.8162400, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95494, 'Cadereyta', 'Cadereyta', '', 25.5833300, -99.9833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95495, 'San Lorenzo Cacaotepec', 'San Lorenzo Cacaotepec', 'Cacaotepec,San Lorenzo Cacaotepec', 17.1277400, -96.8024400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95496, 'Santiago Cacaloxtepec', 'Santiago Cacaloxtepec', 'Cacalotepec,Cacaloxtepec,Santiago Cacaloxtepec', 17.7215800, -97.7404400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95497, 'Cacalotenango', 'Cacalotenango', '', 18.5463900, -99.6436100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95498, 'Cacaloxúchitl', 'Cacaloxuchitl', 'Cacalosuchil,Cacalosúchil,Cacaloxuchil,Cacaloxúchil,Cacalxochitl', 18.7874700, -98.4861400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95499, 'Cacalomacan', 'Cacalomacan', 'Cacalomacan', 19.2531100, -99.7062300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95500, 'Cacalchen', 'Cacalchen', 'Cacalchen,Cacalchén', 20.9835800, -89.2268600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95501, 'Cacahoatán', 'Cacahoatan', 'Cacahoatan,Cacahoatán,Cacahuatan,Cacahuatán', 14.9920100, -92.1637600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95502, 'Bustamante', 'Bustamante', 'Bustamante,Bustamente,Villa de Bustamante', 23.4352400, -99.7587500, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95503, 'Buenavista de Cuéllar', 'Buenavista de Cuellar', 'Buenavista,Buenavista de Cuellar,Buenavista de Cuéllar', 18.4595800, -99.4086800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95504, 'Buena Vista', 'Buena Vista', '', 19.0427800, -96.8566700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95505, 'Buenavista', 'Buenavista', '', 17.9166700, -92.5333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95506, 'Buctzotz', 'Buctzotz', 'Buctzot,Buctzotz', 21.2030300, -88.7927100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95507, 'Bochil', 'Bochil', 'Bochil', 16.9962500, -92.8921800, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95508, 'Miguel Bocanegra', 'Miguel Bocanegra', 'Bocanegra,Miguel Bocanegra,San Miguel Bocanegra', 19.8457400, -99.1119300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95509, 'Boca del Río', 'Boca del Rio', 'Boca del Rio,Boca del Río,Boka del Rio,Boka-del''-Rio,bo ka de er li ao,bwk dl ryw  wrakrwz,bwka dyl ryw  wyrakrwz,Бока дел Рио,Бока-дель-Рио,بوک دل ریو، وراکروز,بوکا دیل ریو، ویراکروز,博卡德爾里奧', 19.1000000, -96.1000000, 'MX', '2012-05-17', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95510, 'Boca del Monte', 'Boca del Monte', 'Boca del Monte', 19.1545100, -96.8327000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95511, 'Blasillo 1ra. Sección (Nicolás Bravo)', 'Blasillo 1ra. Seccion (Nicolas Bravo)', 'Blasill,Blasillo', 18.0786100, -93.9183300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95512, 'San Melchor Betaza', 'San Melchor Betaza', 'Betaza,Betaza San Melchor,San Melchor Betaza', 17.2526700, -96.1528400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95513, 'Berriozábal', 'Berriozabal', 'Berriozaba,Berriozabal,Berriozábal', 16.7985300, -93.2716300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95514, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez,Santa Cruz,Santa Cruz de Juarez', 20.8863500, -98.2059400, 'MX', '2014-03-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95515, 'Benito Juárez', 'Benito Juarez', '', 19.8165400, -97.7910800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95516, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez', 19.3739100, -97.9090000, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95517, 'Belén', 'Belen', 'Belen,Belén', 17.7890700, -92.6113700, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95518, 'Bejucal de Ocampo', 'Bejucal de Ocampo', 'Bejucal,Bejucal de Ocampo,Brejucal', 15.4553500, -92.1583500, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95519, 'Bécal', 'Becal', 'Becal,Bécal', 20.4417200, -90.0273800, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95520, 'Banderilla', 'Banderilla', 'Banderilla', 19.5889300, -96.9372700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95521, 'Nuevo Balsas', 'Nuevo Balsas', '', 18.0325300, -99.7591300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95522, 'Balancán', 'Balancan', 'Balancan,Balancan de Dominguez,Balancán,Balancán de Domínguez', 17.8090300, -91.5368200, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95523, 'Bajos del Ejido', 'Bajos del Ejido', 'Bajos del Ejido', 16.9608600, -99.9716900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95524, 'Bacalar', 'Bacalar', 'Bacalar,Bakalar,bakararu,Бакалар,バカラル', 18.6810900, -88.3933300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95525, 'Baca', 'Baca', 'Baca', 21.1087400, -89.3986600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95526, 'Azoyú', 'Azoyu', 'Azoyu,Azoyú', 16.7331400, -98.6016600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95527, 'Azcapotzalco', 'Azcapotzalco', 'Atzapotzalco,Atzcapotzalco,Azcapotzalco', 19.4869800, -99.1859400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95528, 'Ayutla de los Libres', 'Ayutla de los Libres', 'Ayutla,Ayutla de los Libres', 16.9637600, -99.0961600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95529, 'Ayutla', 'Ayutla', 'Ayutla', 18.5450300, -98.5053700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95530, 'Ayotzintepec', 'Ayotzintepec', 'Ayotzintepec', 17.6726100, -96.1285500, 'MX', '2017-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95531, 'Ayotoxco de Guerrero', 'Ayotoxco de Guerrero', 'Ayotoxco,Ayotoxco de Guerrero,Ayotoxoc', 20.0958900, -97.4096100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95532, 'Ayometitla', 'Ayometitla', 'Ayometitla,Ayometla', 19.2072200, -98.1930600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95533, 'Ayapango', 'Ayapango', 'Ayapango', 19.1269200, -98.7998800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95534, 'Ayapa', 'Ayapa', 'Anapa,Ayapa', 18.2241000, -93.1115800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95535, 'Ciudad Ayala', 'Ciudad Ayala', 'Ayala', 18.7669400, -98.9822200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95536, 'Ayahualulco', 'Ayahualulco', 'Ayahualulco', 19.3511300, -97.1487400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95537, 'Axutla', 'Axutla', 'Axutia,Axutla', 18.1893800, -98.3893500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95538, 'San Miguel Axoxuca', 'San Miguel Axoxuca', '', 17.5493000, -98.6616300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95539, 'Axochiapan', 'Axochiapan', 'Axochiapan', 18.5024600, -98.7535800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95540, 'Axixintla', 'Axixintla', '', 18.6022200, -99.5180600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95541, 'Axapusco', 'Axapusco', 'Axapusco', 19.7245600, -98.7586300, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95542, 'Soledad Atzompa', 'Soledad Atzompa', 'Atzompa,Soledad,Soledad Atzompa', 18.7549900, -97.1504000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95543, 'Atzitzintla', 'Atzitzintla', 'Ataiziutla,Atzintzintla,Atzitzintla,Atzizintla,Atziziutla', 18.8991500, -97.3244000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95544, 'Atzala', 'Atzala', '', 18.5463900, -98.5530600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95545, 'Atzacan', 'Atzacan', 'Atacan,Atzacan,Atzacán', 18.9072400, -97.0830700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95546, 'Atoyatempan', 'Atoyatempan', 'Atoyateinpan,Atoyateipan,Atoyatempan,San Salvador', 18.8192500, -97.9139000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95547, 'Atotonilco el Grande', 'Atotonilco el Grande', 'Atotonilco,Atotonilco el Grande', 20.2863200, -98.6685000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95548, 'Atlzayanca', 'Atlzayanca', 'Atltzayanca de Hidalgo,Atlzayanca', 19.4311100, -97.7955600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95549, 'Atlixco', 'Atlixco', 'Atliksko,Atlixco,Атликско', 18.9081500, -98.4361300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95550, 'Atliaca', 'Atliaca', 'Atiaca,Atliaca', 17.6516800, -99.3747100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95551, 'Atlequizayan', 'Atlequizayan', 'Atlequizayan', 20.0121400, -97.6242300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95552, 'Atlautla', 'Atlautla', 'Atlautla,San Miguel Atlautla', 19.0218800, -98.7785900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95553, 'Atlatongo', 'Atlatongo', 'Atlatongo,Santiago Atlatongo', 19.6677600, -98.9040200, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95554, 'Atlatlahucan', 'Atlatlahucan', 'Atlatlahuacan,Atlatlahucan', 18.9341300, -98.8982000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95555, 'San Bartolomé Atlatlahuca', 'San Bartolome Atlatlahuca', 'Atlatlahuaca,Atlatlahuca,Atlatlauca,San Bartolome Atlatlahuca,San Bartolomé Atlatlahuca', 19.0696300, -99.6098100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95556, 'Atlacomulco de Fabela', 'Atlacomulco de Fabela', 'Atlacomolco,Atlacomulco,Atlacomulco de Fabela,Atlakomul''ko,Municipio Atlacomulco,Ātlacomōlco,Атлакомулько', 19.7991900, -99.8750000, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95557, 'Adolfo López Mateos', 'Adolfo Lopez Mateos', 'Adolfo Lopez Mateos,Adolfo López Mateos,Atizapan,Atizapan de Zaragoza,Atizapán de Zaragoza,Ciudad Lopez Mateos,Ciudad López Mateos,Lopez Mateos,López Mateos,S''judad-Lopes-Mateus,Сьюдад-Лопес-Матеус', 19.5872200, -99.2635600, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95558, 'Atizapán', 'Atizapan', '', 19.2500000, -99.5500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95559, 'Atitalaquia', 'Atitalaquia', 'Atitalaquia', 20.0596400, -99.2216300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95560, 'Atengo', 'Atengo', 'Atengo', 20.1752600, -99.3271400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95561, 'Atencingo', 'Atencingo', 'Atencingo', 18.5134700, -98.6054200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95562, 'Atempan', 'Atempan', 'Atempan', 19.8394500, -97.4585500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95563, 'Asunción Tlacolulita', 'Asuncion Tlacolulita', 'Asuncion Tlacolulita,Asunción Tlacolulita,Tlacolulita', 16.2994200, -95.7266800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95564, 'Asunción Ocotlán', 'Asuncion Ocotlan', 'Asuncion,Asuncion Ocotlan,Asunción Ocotlán,La Asuncion Ocotlan,La Asunción Ocotlán,Ocotlan', 16.7619500, -96.7213700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95565, 'Asunción Nochixtlán', 'Asuncion Nochixtlan', 'Asuncion,Asuncion Nochixtlan,Asunción,Asunción Nochixtlán,Nochistlan,Nochixtlan', 17.4591600, -97.2260500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95566, 'Asunción Ixtaltepec', 'Asuncion Ixtaltepec', 'Asuncion,Asuncion Ixtaltepec,Asunción,Asunción Ixtaltepec,Ixtaltepec', 16.5031500, -95.0612100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95567, 'Arroyo Seco', 'Arroyo Seco', 'Arroyo Seco', 21.5477700, -99.6883200, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95568, 'Aquixtla', 'Aquixtla', 'Aquixtla', 19.7958200, -97.9355300, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95569, 'Aquiles Serdán', 'Aquiles Serdan', '', 17.7833300, -92.2833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95570, 'Aquila', 'Aquila', 'Aguila,Aquila', 18.7956500, -97.3084500, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95571, 'Apizaco', 'Apizaco', 'Apisako,Apitzauhco,Apizaco,Аписако', 19.4133300, -98.1435800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95572, 'Apazapan', 'Apazapan', 'Apasapan,Apazapam,Apazapan,Apazapán', 19.3207200, -96.7187400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95573, 'Apaxtla de Castrejón', 'Apaxtla de Castrejon', 'Apaxtla,Apaxtla de Castrejon,Apaxtla de Castrejón', 18.1312700, -99.9325500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95574, 'Apaxco de Ocampo', 'Apaxco de Ocampo', 'Apaxco,Apaxco de Ocampo', 19.9751200, -99.1711200, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95575, 'San Pedro Apatlaco', 'San Pedro Apatlaco', '', 18.7930600, -98.9597200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95576, 'Mártir de Cuilapan', 'Martir de Cuilapan', 'Apango,Martir de Cuilapan,Mártir de Cuilapan', 17.7412100, -99.3290900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95577, 'Apan', 'Apan', 'Apam,Apan', 19.7112800, -98.4508600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95578, 'Antón Lizardo', 'Anton Lizardo', 'Anton Lizardo,Antón Lizardo', 19.0596200, -95.9927200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95579, 'Antiguo Morelos', 'Antiguo Morelos', '', 22.5495000, -99.0812300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95580, 'Angel R. Cabadas', 'Angel R. Cabadas', 'Angel R. Cabada,Angel R. Cabadas,Angel R. Cavada,El Meson,El Mesón,Meson,R. Cabada,Ángel R. Cabada', 18.5960100, -95.4458000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95581, 'Angel Albino Corzo', 'Angel Albino Corzo', 'Angel Albino Corzo,Jaltenango,Jaltenango de la Paz,Santa Rosa Jaltenango,Ángel Albino Corzo', 15.8731400, -92.7243700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95582, 'Anenecuilco', 'Anenecuilco', 'Anenecuilco', 18.7773800, -98.9890700, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95583, 'Anahuac', 'Anahuac', 'Anahuac,Anáhuac,El Humo,Pueblo Viejo', 22.2027500, -97.8550600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95584, 'San Pedro Amuzgos', 'San Pedro Amuzgos', 'Amusgos,San Pedro Amuzgos', 16.6538800, -98.0917500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95585, 'Amozoc de Mota', 'Amozoc de Mota', 'Amozoc,Amozoc de Mota', 19.0461100, -98.0450000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95586, 'San Miguel Ameyalco', 'San Miguel Ameyalco', 'Ameyalco,San Miguel Ameyalco', 19.3068100, -99.4588000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95587, 'Ameluca', 'Ameluca', 'Ameluca', 20.5634400, -97.8257100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95588, 'Amecameca', 'Amecameca', 'Amecameca,Amecameca de Juarez,Amecameca de Juárez', 19.1238400, -98.7664900, 'MX', '2015-08-20', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95589, 'Amayuca', 'Amayuca', 'Amayuca', 18.7240800, -98.7981200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95590, 'Amatlán de los Reyes', 'Amatlan de los Reyes', 'Amatlan,Amatlan de los Reyes,Amatlán,Amatlán de los Reyes', 18.8465800, -96.9159500, 'MX', '2017-06-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95591, 'Amatenango del Valle', 'Amatenango del Valle', 'Amatenango,Amatenango del Valle', 16.5272200, -92.4347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95592, 'Amatenango de la Frontera', 'Amatenango de la Frontera', 'Amatenango,Amatenango de la Frontera,Atenango de la Frontera', 15.4343800, -92.1157000, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95593, 'Amatán', 'Amatan', 'Amatan,Amatán', 17.3742900, -92.8189300, 'MX', '2014-10-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95594, 'Amacuzac', 'Amacuzac', 'Amacuzac', 18.5986100, -99.3694400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95595, 'Álvaro Obregón', 'Alvaro Obregon', 'Alvaro Obregon,Colonia Alvaro Obregon,Colonia Alvaro Obregón,Álvaro Obregón', 14.9223100, -92.3781300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95596, 'Heroica Alvarado', 'Heroica Alvarado', 'Al''varado,Alvarado,Heroica Alvarado,Loma el Rosario,Альварадо', 18.7714300, -95.7618100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95597, 'Altotonga', 'Altotonga', 'Altotonga', 19.7661300, -97.2451400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95598, 'Alto Lucero', 'Alto Lucero', 'Alto Lucero,Alto del Lucero', 19.6244200, -96.7340900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95599, 'Altepexi', 'Altepexi', 'Altepexi,San Francisco Altepexi', 18.3703500, -97.2996600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95600, 'Altamirano', 'Altamirano', 'Altamirano,Enriquez,Enríquez,San Carlos,Villa Enriquez,Villa Enríquez', 16.8833300, -92.1500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95601, 'Altamira', 'Altamira', 'Al''tamira,Altamira,Альтамира', 22.3921500, -97.9386700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95602, 'Alpuyeca', 'Alpuyeca', 'Alpuyeca', 18.7400600, -99.2593700, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95603, 'Alpoyeca', 'Alpoyeca', 'Alpoyeca', 17.6704100, -98.5097400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95604, 'San Antonio Alpanocan', 'San Antonio Alpanocan', 'Alpanocan,San Antonio', 18.8772200, -98.7108300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95605, 'Villa de Almoloya de Juárez', 'Villa de Almoloya de Juarez', 'Almoloya,Almoloya de Juarez,Almoloya de Juárez', 19.3691500, -99.7583600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95606, 'Almoloya de Alquisiras', 'Almoloya de Alquisiras', 'Almolaya,Almoloya de Alquisiras', 18.8656400, -99.8945200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95607, 'Almoloya', 'Almoloya', 'Almoloya', 19.7043500, -98.4037900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95608, 'Almoloya del Río', 'Almoloya del Rio', 'Almoloya,Almoloya del Rio,Almoloya del Río,Almoloyita', 19.1604600, -99.4874000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95609, 'San Miguel Almaya', 'San Miguel Almaya', 'Almaya,San Miguel Almaya', 19.2104700, -99.4419500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95610, 'Ignacio Allende', 'Ignacio Allende', '', 18.3829900, -92.8441800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95611, 'Allende', 'Allende', 'Allende,Gavilan de Allende', 18.1551400, -94.3928900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95612, 'Aljojuca', 'Aljojuca', 'Aljojuca', 19.0993300, -97.5297300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95613, 'Villa Terrazas', 'Villa Terrazas', 'Alfredo M. Terrazas,Axtla,Villa Terrazas', 21.4392300, -98.8750800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95614, 'Aldama', 'Aldama', 'Aldama', 22.9215700, -98.0751900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95615, 'Alaquines', 'Alaquines', 'Alaquines', 22.1297300, -99.6009300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95616, 'Álamo', 'Alamo', 'Alamo,Álamo', 20.9115400, -97.6755400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95617, 'Akil', 'Akil', 'Akil', 20.2654700, -89.3478700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95618, 'Ajalpan', 'Ajalpan', 'Ajalpan', 18.3790800, -97.2586700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95619, 'Ahuehuetzingo', 'Ahuehuetzingo', 'Ahuehuecingo', 18.6802400, -99.3083400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95620, 'Ahuazotepec', 'Ahuazotepec', 'Ahuazotepec', 20.0453500, -98.1633200, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95621, 'Ahuatlán', 'Ahuatlan', 'Ahuatlan,Ahuatlán', 18.5727600, -98.2569200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95622, 'Ahuatlán', 'Ahuatlan', '', 18.5747200, -98.2561100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95623, 'Lomas de Ahuatepec', 'Lomas de Ahuatepec', '', 18.9713900, -99.1897200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95624, 'Ahuacatitlán Cuarto y Quinto Cuartel', 'Ahuacatitlan Cuarto y Quinto Cuartel', '', 19.9622200, -99.9869400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95625, 'Agua Dulce', 'Agua Dulce', '', 20.3633700, -97.2931500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95626, 'Agua Dulce', 'Agua Dulce', 'Agua Dulce', 18.1390900, -94.1452700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95627, 'Acultzingo', 'Acultzingo', 'Acultzingo', 18.7189400, -97.3036700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95628, 'Actopan', 'Actopan', 'Actopan', 20.2696100, -98.9437700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95629, 'Actopan', 'Actopan', 'Actopam,Actopan,Actópam', 19.5042700, -96.6166800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95630, 'Villa Atltzayanca de Hidalgo', 'Villa Atltzayanca de Hidalgo', 'Actlzayanca,Actlzayanca de Hidalgo,Altzayanca,Alzayacan,Alzayacán,Alzayanca,Atltzayanca de Hidalgo,Atlzayanca,Villa Atltzayanca de Hidalgo', 19.4312100, -97.7955500, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95631, 'Acteopan', 'Acteopan', 'Acteopan,Actiopan,San Marcos', 18.7638800, -98.7136600, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95632, 'Acoyotla', 'Acoyotla', 'Acoyotla,Axoyotla', 21.1255100, -98.7772900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95633, 'Achichipico', 'Achichipico', 'Achichipico,Achichipilco', 18.9486100, -98.8261100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95634, 'San Jerónimo Acazulco', 'San Jeronimo Acazulco', 'Acazulco,San Jeronimo Acazulco,San Jerónimo Acazulco', 19.2656300, -99.4162900, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95635, 'Acayucan', 'Acayucan', 'Acayucan', 17.9497900, -94.9138600, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95636, 'Acayuca', 'Acayuca', 'Acayuca', 20.0256700, -98.8411000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95637, 'Acaxtlahuacán de Albino Zertuche', 'Acaxtlahuacan de Albino Zertuche', 'Acaxtlahuacan,Acaxtlahuacan de Albino Zertuche,Acaxtlahuacán,Acaxtlahuacán de Albino Zertuche', 18.0171400, -98.5401800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95638, 'Acaxochitlán', 'Acaxochitlan', 'Acaxochitlan,Acaxochitlán', 20.1578900, -98.2017200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95639, 'Acatzingo', 'Acatzingo', 'Acatzingo,Acatzingo de Hidalgo,San Juan Acatzingo', 18.9819600, -97.7836300, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95640, 'Acatlán de Pérez Figueroa', 'Acatlan de Perez Figueroa', 'Acatlan,Acatlan de Perez Figueroa,Acatlán de Pérez Figueroa,San Pedro', 18.5397300, -96.6056800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95641, 'Acatlán de Osorio', 'Acatlan de Osorio', 'Acatlan,Acatlan de Osorio,Acatlán,Acatlán de Osorio', 18.2025000, -98.0486400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95642, 'Acatlán', 'Acatlan', 'Acatlan,Acatlán', 20.1456200, -98.4395900, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95643, 'Acatepec', 'Acatepec', 'Acatepec', 16.7375000, -98.4275000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95644, 'Acatempan', 'Acatempan', 'Acatempa,Acatempan', 18.3180900, -99.8829800, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95645, 'Acapulco de Juárez', 'Acapulco de Juarez', 'ACA,Acapolco Juarez,Acapolco Juárez,Acapulco,Acapulco de Juarez,Acapulco de Juárez,Acapulco  Acapulco de Juarez,Acapulcum,Akapoulko,Akapul''ko,Akapulkas,Akapulko,Akapúlkó,Gorad Akapul''ka,a ka pu er ke,akabwlkw,akapulko,akapuruko,akapwlkw  gwyrrw,xa ka pul ko,Ακαπούλκο,Акапулко,Акапулько,Горад Акапулька,אקפולקו,آکاپولکو، گوئررو,أكابولكو,അക്കാപുൽകോ,อากาปุลโก,აკაპულკო,アカプルコ,阿卡普尔科,아카풀코', 16.8633600, -99.8901000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95646, 'Acapetahua', 'Acapetahua', 'Acapetagua,Acapetahua,Acapeteahua', 15.2818900, -92.6898700, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95647, 'Acanceh', 'Acanceh', 'Acanceh', 20.8126900, -89.4529500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95648, 'Acamixtla', 'Acamixtla', 'Acamixtla,Acamixtlan', 18.5651200, -99.5659900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95649, 'Acambay', 'Acambay', 'Acambay,San Miguel,San Miguel Acambay', 19.9552200, -99.8442800, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95650, 'Acala', 'Acala', 'Acala', 16.5562500, -92.8044900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95651, 'Acajete', 'Acajete', 'Acajete,Salvador Acajete,San Salvador,San Salvador Acajete', 19.5864600, -97.0099500, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95652, 'Acajete', 'Acajete', 'Acajete', 19.1115400, -97.9523100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95653, 'Acahuizotla', 'Acahuizotla', '', 17.3605400, -99.4675900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95654, 'San Antonio Acahualco', 'San Antonio Acahualco', 'Acahualco,San Antonio Acahualco', 19.2740000, -99.7716900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95655, 'Acacoyagua', 'Acacoyagua', 'Acacoyagua,Acacoyahua', 15.3405400, -92.6751900, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95656, 'Abasolo del Valle', 'Abasolo del Valle', '', 17.7830600, -95.5455600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95657, 'Abasolo', 'Abasolo', 'Abasolo,Santillana,Абасоло', 24.0584400, -98.3733300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95658, 'Talismán', 'Talisman', '', 14.9633300, -92.1472200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95659, 'San Nicolás Tecomatlán', 'San Nicolas Tecomatlan', '', 20.1794400, -99.0363900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95660, 'Ajacuba', 'Ajacuba', 'Ajacuba', 20.0917000, -99.1224600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95661, 'San Pablo de los Remedios', 'San Pablo de los Remedios', '', 19.6411100, -99.8383300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95662, 'Miraflores', 'Miraflores', 'Miraflores,San Mateo Tezoquipan', 19.2221000, -98.8074100, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95663, 'San Miguel Tecomatlán', 'San Miguel Tecomatlan', '', 18.9783300, -99.5286100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95664, 'Higuerón', 'Higueron', '', 18.5775000, -99.1805600, 'MX', '2013-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95665, 'Cuauhtempan (San Andrés Cuauhtempan)', 'Cuauhtempan (San Andres Cuauhtempan)', '', 18.9747200, -98.9463900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95666, 'Tlaltetelco (San Miguel Tlaltetelco)', 'Tlaltetelco (San Miguel Tlaltetelco)', '', 18.9522200, -98.8880600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95667, 'Huecahuasco', 'Huecahuasco', '', 18.9369400, -98.7825000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95668, 'San Lorenzo Cacaotepec', 'San Lorenzo Cacaotepec', 'San Lorenzo Cacaotepec', 17.1283300, -96.8000000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95669, 'Santiago Tlacotepec', 'Santiago Tlacotepec', 'Santiago Tlacotepec', 19.2270800, -99.6708300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95670, 'San José Río Manzo', 'San Jose Rio Manzo', '', 17.6700300, -95.8801200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95671, 'San Juan del Río', 'San Juan del Rio', '', 17.4927800, -95.7602800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95672, 'Santa María Temaxcalapa', 'Santa Maria Temaxcalapa', 'Santa Maria Temaxcalapa,Santa Maria Temaycalapan,Santa María Temaxcalapa', 17.3803600, -96.1613700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95673, 'Yucuita', 'Yucuita', 'San Juan Yucuita,Yucuita', 17.5107300, -97.2696500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95674, 'Santa María Puxmetacán', 'Santa Maria Puxmetacan', '', 17.2686100, -95.6233300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95675, 'Santiago Malacatepec', 'Santiago Malacatepec', '', 17.0163900, -95.6075000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95676, 'Santo Domingo Tomaltepec', 'Santo Domingo Tomaltepec', 'Santo Domingo Tomaltepec', 17.0605600, -96.6227800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95677, 'San Antonio de la Cal', 'San Antonio de la Cal', 'San Antonio de la Cal', 17.0283300, -96.7005600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95678, 'San Agustin de las Juntas', 'San Agustin de las Juntas', 'San Agustin de las Juntas', 17.0038900, -96.7080600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95679, 'Magdalena Apasco', 'Magdalena Apasco', 'Magdalena Apasco', 17.2408300, -96.8208300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95680, 'San Miguel Tecomatlán', 'San Miguel Tecomatlan', 'San Miguel Tecomatlan,San Miguel Tecomatlán', 17.3945400, -97.2684500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95681, 'Congregación Calles', 'Congregacion Calles', 'Congregacion Calles,Congregación Calles', 25.2252800, -99.9347200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95682, 'Hidalgo', 'Hidalgo', 'Hidalgo', 25.8579000, -99.6189800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95683, 'Atarjea', 'Atarjea', 'Atarjea', 21.2677700, -99.7191400, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95684, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa de Lima', 16.3165500, -95.0994400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95685, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Lazaro Cardenas,Lázaro Cárdenas', 16.7281800, -94.8598100, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95686, 'El Bajío', 'El Bajio', 'El Bajo', 16.8891700, -95.0352800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95687, 'San Nicolás', 'San Nicolas', 'San Nicolas,San Nicolás', 16.4201000, -96.7413300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95688, 'El Arador', 'El Arador', 'El Arador', 16.5411100, -97.1819400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95689, 'San Agustín Chayuco', 'San Agustin Chayuco', 'San Agustin,San Agustín', 16.4013900, -97.8069400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95690, 'San Juan Colorado', 'San Juan Colorado', 'San Juan Colbrado,San Juan Colorado', 16.4606600, -97.9543100, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95691, 'San Juan Jicayán', 'San Juan Jicayan', 'San Juan Jicayan,San Juan Jicayán', 16.4758300, -98.0125000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95692, 'Santiago Llano Grande', 'Santiago Llano Grande', 'Santiago Llano Grande', 16.4883300, -98.2897200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95693, 'Santo Domingo Armenta', 'Santo Domingo Armenta', 'Santo Domingo Armenta', 16.3319400, -98.3777800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95694, 'José María Morelos', 'Jose Maria Morelos', 'Jose Maria Morelos,José María Morelos', 16.2038900, -97.9300000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95695, 'Santiago Tetepec', 'Santiago Tetepec', 'Santiago,Santiago Tetepac,Santiago Tetepec,Tetepec', 16.3217200, -97.7479400, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95696, 'Tataltepec de Valdés', 'Tataltepec de Valdes', 'Asuncion Tataltepec,Asunción Tataltepec,Santa Maria,Tataltepec,Tataltepec de Valdes,Tataltepec de Valdés', 16.3054900, -97.5461500, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95697, 'Santiago Yaitepec', 'Santiago Yaitepec', 'Santiago Yaitepec', 16.2255600, -97.2691700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95698, 'San Cristóbal Honduras', 'San Cristobal Honduras', 'San Cristobal Honduras,San Cristóbal Honduras', 16.3252800, -97.0411100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95699, 'Sitio de Xitlapehua', 'Sitio de Xitlapehua', 'Sitio de Xitlapehua,Xitlapehua', 16.3513900, -96.5321500, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95700, 'Santos Reyes Nopala', 'Santos Reyes Nopala', 'Nopala,Santos Reyes Nopala', 16.1069400, -97.1443500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95701, 'Santo Domingo de Morelos', 'Santo Domingo de Morelos', 'Santo Domingo de Morelos', 15.8339700, -96.6669500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95702, 'San Miguel Figueroa', 'San Miguel Figueroa', 'San Miguel Figueroa', 15.7863900, -96.4041700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95703, 'San Pablo Cuatro Venados', 'San Pablo Cuatro Venados', 'San Pablo Cuatro Venados', 16.9812000, -96.8910300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95704, 'San Antonio Huitepec', 'San Antonio Huitepec', 'San Antonio Huitepec', 16.9266700, -97.1469400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95705, 'San Miguel Mixtepec', 'San Miguel Mixtepec', 'San Miguel Mixtepec', 16.7771900, -96.9572600, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95706, 'Santiago Textitlán', 'Santiago Textitlan', 'Santiago Textitlan,Santiago Textitlán', 16.6926400, -97.2588400, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95707, 'Santa María Lachixío', 'Santa Maria Lachixio', 'Lachixio,San Vicente Lachixlo,Santa Maria,Santa Maria Lachixio,Santa María,Santa María Lachixío', 16.7269400, -97.0188900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95708, 'Teojomulco', 'Teojomulco', 'Santo Domingo,Santo Domingo Teojomulco,Teojomulco', 16.5903200, -97.2249300, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95709, 'Santa María Yucuhiti', 'Santa Maria Yucuhiti', 'San Juan,San Juan Jucuita,San Juan Yucuita,Santa Maria Yuchiti,Santa Maria Yucuhiti,Santa María Yuchiti,Santa María Yucuhiti,Yucuite,Yucuiti,Yucuití,Yucupino', 17.0187300, -97.7695100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95710, 'El Jicaral', 'El Jicaral', 'El Jicaral', 17.1261700, -98.1969700, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95711, 'San Juan Ñumí', 'San Juan Numi', 'San Juan Numi,San Juan Ñumí', 17.3973400, -97.7062400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95712, 'Santa María del Rosario', 'Santa Maria del Rosario', 'El Rosario,Santa Maria Rosario,Santa Maria del Rosario,Santa María Rosario,Santa María del Rosario,Tayata,Tayata Santa Maria Rosario,Tayata Santa María Rosario', 17.3527600, -97.5948000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95713, 'Santiago Tilantongo', 'Santiago Tilantongo', 'Santiago,Santiago Tilantongo,Tilantongo,Tulantonga', 17.2846400, -97.3387900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95714, 'Santiago Tenango', 'Santiago Tenango', 'Santiago Tenango', 17.3248900, -97.0046700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95715, 'San Pedro Coxcaltepec Cántaros', 'San Pedro Coxcaltepec Cantaros', 'San Pedro Cantaros,San Pedro Coxcaltepec Cantaros,San Pedro Coxcaltepec Cántaros,San Pedro Cántaros', 17.4993300, -97.1380200, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95716, 'Magdalena Zahuatlán', 'Magdalena Zahuatlan', 'Magdalena Zahuatlan,Magdalena Zahuatlán', 17.3897800, -97.2274700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95717, 'San Francisco Jaltepetongo', 'San Francisco Jaltepetongo', 'San Francisco Jaltepetongo', 17.3857900, -97.2648100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95718, 'San Francisco Nuxaño', 'San Francisco Nuxano', 'San Francisco Nuxano,San Francisco Nuxaño', 17.3817300, -97.3426200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95719, 'San Mateo Etlatongo', 'San Mateo Etlatongo', 'San Mateo Etlatongo', 17.4160900, -97.2738900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95720, 'San Juan Sayultepec', 'San Juan Sayultepec', 'San Juan Sayultepec,San Juan Suyultepec,Sayoltepec,Soyaltepec', 17.4530600, -97.2848100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95721, 'San Vicente Nuñu', 'San Vicente Nunu', 'Nuno,Nuño,San Vicente,San Vicente Nunu,San Vicente Nuñu', 17.4564800, -97.4431900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95722, 'Santiago Yolomécatl', 'Santiago Yolomecatl', 'Santiago,Santiago Yolomecatl,Santiago Yolomécatl,Yolomecatl,Yolomécatl', 17.4723700, -97.5698100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95723, 'San Miguel Tlacotepec', 'San Miguel Tlacotepec', 'San Miguel Tlacotepec', 17.4562100, -98.0054700, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95724, 'Silacayoápam', 'Silacayoapam', 'Silacayoapam,Silacayoapan,Silacayoápam,Villa Silacayoapan', 17.5029700, -98.1396600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95725, 'Ixpantepec Nieves', 'Ixpantepec Nieves', 'Ixpantepec Nieves,Nieves Ixpantepec', 17.5069000, -98.0426400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95726, 'San Sebastián Nicananduta', 'San Sebastian Nicananduta', 'San Sebastian Nicanandula,San Sebastian Nicananduta,San Sebastián Nicanandula,San Sebastián Nicananduta', 17.5182800, -97.6835000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95727, 'Chicahua', 'Chicahua', 'Chicahua,San Miguel Chicahua', 17.6366700, -97.1949700, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95728, 'Santo Domingo Yodohino', 'Santo Domingo Yodohino', 'Santo Domingo Yodohino', 17.6169400, -97.6828900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95729, 'Santa Cruz de Bravo', 'Santa Cruz de Bravo', 'Santa Cruz de Bravo', 17.5809600, -98.2237800, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95730, 'Ahuehuetitlán', 'Ahuehuetitlan', 'Ahuehuetitlan,Ahuehuetitlán,San Miguel Ahuehuetitlan,San Miguel Ahuehuetitlán', 17.6713000, -98.3202400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95731, 'Tamazola', 'Tamazola', 'Santiago Tamazola,Tamazola', 17.6702000, -98.2208400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95732, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo,San Lorenzo Victoria', 17.6686700, -98.1198600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95733, 'San Jorge Nuchita', 'San Jorge Nuchita', 'San Jorge Nuchita', 17.6566900, -98.1038300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95734, 'San Agustín Atenango', 'San Agustin Atenango', 'San Agustin Atenango,San Agustin Tenango,San Agustín Atenango,San Agustín Tenango', 17.6115000, -98.0109500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95735, 'Santo Domingo Tonalá', 'Santo Domingo Tonala', 'Santo Domingo Tonala,Santo Domingo Tonalá', 17.6735200, -97.9655600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95736, 'San Marcos Arteaga', 'San Marcos Arteaga', 'San Marcos Arteaga', 17.7223800, -97.8603400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95737, 'San Andrés Dinicuiti', 'San Andres Dinicuiti', 'San Andres Dinicuiti,San Andrés Dinicuiti', 17.6881200, -97.7266900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95738, 'Tamazulapam Villa del Progreso', 'Tamazulapam Villa del Progreso', 'Tamasulapa,Tamazulapam,Tamazulapam Villa del Progreso,Tamazulapam del Progreso,Tamazulapan,Tamazulapan del Progreso,Tamazulapán,Tamazulápam del Progreso,Villa de Tamazulapan', 17.6771000, -97.5731500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95739, 'Texcatitlán', 'Texcatitlan', 'Santa Maria Texcatitlan,Santa María Texcatitlan,Santa María Texcatitlán,Texcatitlan,Texcatitlán', 17.7125900, -97.0662500, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95740, 'Mariscala de Juárez', 'Mariscala de Juarez', '', 17.8597200, -98.1408300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95741, 'San Lorenzo Vista Hermosa', 'San Lorenzo Vista Hermosa', 'San Lorenzo Villahermosa', 17.9588800, -98.0685200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95742, 'Teotitlán', 'Teotitlan', 'Teotitlan,Teotitlan de Flores Magon,Teotitlan del Camino,Teotitlán,Teotitlán de Flores Magón,Teotitlán del Camino', 18.1317900, -97.0705600, 'MX', '2017-03-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95743, 'Chila', 'Chila', 'Chila,Chila de las Flores', 17.9696200, -97.8607200, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95744, 'Cosoltepec', 'Cosoltepec', 'Cosoltepec', 18.1425500, -97.7908400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95745, 'San Lucas Zoquiápam', 'San Lucas Zoquiapam', 'San Lucas Zoquiapam,San Lucas Zoquiapan,San Lucas Zoquiápam', 18.1366900, -96.9054500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95746, 'San Pedro Ocopetatillo', 'San Pedro Ocopetatillo', 'Ocopetlatzingo,San Pedro Ocopetatillo', 18.1863800, -96.9116600, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95747, 'Santa Cruz Acatepec', 'Santa Cruz Acatepec', 'Santa Cruz Acatepec', 18.1636900, -96.8750300, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95748, 'Tezonapa', 'Tezonapa', 'Tetzonapa,Tezonapa', 18.6070600, -96.6841700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95749, 'Piedra de Amolar', 'Piedra de Amolar', 'Piedra de Amolar', 18.1200000, -96.4512200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95750, 'Isla Soyaltepec', 'Isla Soyaltepec', 'Isla San Miguel Soyaltepec,Isla Soyaltepec,San Miguel,San Miguel Soyaltepec,Soyaltepec', 18.2010700, -96.4832500, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95751, 'Tetela', 'Tetela', 'Tetela,Tetetla', 18.5088700, -96.4588000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95752, 'Benemérito Juárez', 'Benemerito Juarez', 'Benito Juarez,Benito Juárez', 18.1194400, -96.0019400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95753, 'Macín Chico', 'Macin Chico', 'Mazin Chico,Mazín Chico', 18.0682000, -96.2718400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95754, 'San Pedro Sochiápam', 'San Pedro Sochiapam', 'San Pedro Sochiapam,San Pedro Sochiapan,San Pedro Sochiápam', 17.8280300, -96.6627400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95755, 'San Juan Petlapa', 'San Juan Petlapa', 'San Juan Petlapa', 17.4691600, -96.0361000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95756, 'Tanetze de Zaragoza', 'Tanetze de Zaragoza', 'Tanetze de Zaragoza', 17.3755600, -96.3008300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95757, 'Santo Domingo Roayaga', 'Santo Domingo Roayaga', 'Roayaga,Roayago,Santo Domingo Roayaga', 17.3378200, -96.1150600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95758, 'San Juan Tabaá', 'San Juan Tabaa', 'San Juan Tabaa,San Juan Tabaá,Tabaa,Tabaá', 17.3049500, -96.2071800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95759, 'Tamazulapam', 'Tamazulapam', 'Espiritu Santo Tamazulapan,Espíritu Santo Tamazulapan,Tamazulapam,Tamazulapam del Espiritu Santo,Tamazulapam del Espíritu Santo', 17.0548500, -96.0653400, 'MX', '2016-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95760, 'San Felipe Cihualtepec', 'San Felipe Cihualtepec', 'San Felipe Cihualtepec,San Felipe Zihualtepec', 17.4776300, -95.3676700, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95761, 'El Paraíso', 'El Paraiso', 'El Paraiso,El Paraíso', 17.5159200, -95.1427100, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95762, 'Paso Real de Sarabia', 'Paso Real de Sarabia', 'Sarabia', 17.0738900, -95.0466700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95763, 'Rojas de Cuauhtémoc', 'Rojas de Cuauhtemoc', 'Rojas de Cuauhtemoc,Rojas de Cuauhtémoc', 17.0058700, -96.6191900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95764, 'Guadalupe Etla', 'Guadalupe Etla', 'Etla,Guadalupe Etla,Nazareno,Nazareno Etla,Soledad', 17.1726800, -96.8102200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95765, 'Santa Ana Zegache', 'Santa Ana Zegache', 'Santa Ana Zegache', 16.8370600, -96.7294800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95766, 'San Bartolomé Quialana', 'San Bartolome Quialana', 'San Bartolome Quialana,San Bartolomé Quialana', 16.9030200, -96.5016900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95767, 'San Antonino Castillo Velasco', 'San Antonino Castillo Velasco', 'San Antonino Castillo Velasco,San Antonio Castillo Velasco', 16.8014300, -96.6828300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95768, 'Santa Inés Yatzeche', 'Santa Ines Yatzeche', 'Santa Ines Tarzeche,Santa Ines Yatzeche,Santa Inés Tarzeche,Santa Inés Yatzeche', 16.8065800, -96.7571900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95769, 'Santa María Coyotepec', 'Santa Maria Coyotepec', 'Coyotepec,San Bartolo,San Bartolo Coyotepec,Santa Maria Coyotepec,Santa María Coyotepec', 16.9666300, -96.7051300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95770, 'Santa María Jalapa del Marqués', 'Santa Maria Jalapa del Marques', 'Santa Maria Jalapa del Marques,Santa María Jalapa del Marqués', 16.4402700, -95.4445400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95771, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 16.8962700, -95.8498100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95772, 'Santo Domingo Tepuxtepec', 'Santo Domingo Tepuxtepec', 'Santo Domingo Tepuxtepec', 16.9555600, -96.0552800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95773, 'San Lorenzo Albarradas', 'San Lorenzo Albarradas', 'San Lorenzo Albarradas', 16.9112900, -96.2582600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95774, 'Santiago Xanica', 'Santiago Xanica', 'Santiago,Santiago Xanica,Xanica', 16.0100900, -96.2246200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95775, 'El Coyul', 'El Coyul', 'Coyol,El Coyul', 15.9147200, -95.8102800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95776, 'La Erradura', 'La Erradura', 'La Herradura', 15.8340200, -96.3347800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95777, 'Santa María Guelacé', 'Santa Maria Guelace', 'Santa Maria Guelace,Santa Maria Guelaxe,Santa María Guelacé,Santa María Guelaxé', 17.0011900, -96.6034600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95778, 'La Pe', 'La Pe', 'La Pe', 16.6302700, -96.7976600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95779, 'Taniche', 'Taniche', 'Taniche', 16.5686000, -96.7551400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95780, 'La Blanca', 'La Blanca', 'La Blanca', 16.5948200, -94.6925600, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95781, 'San Blas Atempa', 'San Blas Atempa', 'San Blas Atempa,Villa de San Blas Atempa', 16.3310300, -95.2255900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95782, 'Occidente 4ta. Sección', 'Occidente 4ta. Seccion', 'Occidente', 18.3034700, -93.2338800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95783, 'Miguel Hidalgo', 'Miguel Hidalgo', 'Miguel Hidalgo', 18.2569100, -93.3107300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95784, 'Aquiles Serdán', 'Aquiles Serdan', 'Aquiles Serdan,Aquiles Serdán', 18.4135000, -93.0134000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95785, 'Oriente 1ra. Sección', 'Oriente 1ra. Seccion', 'Oriente Segunda Seccion,Oriente Segunda Sección', 18.3388900, -93.2005600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95786, 'Tecoluta 2da. Sección', 'Tecoluta 2da. Seccion', 'Tecolma Segunda Seccion,Tecolma Segunda Sección', 18.2440800, -93.0195600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95787, 'Gobernador Cruz', 'Gobernador Cruz', 'Gobernador Cruz', 18.4336400, -92.8718000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95788, 'Villa la Venta', 'Villa la Venta', 'Villa la Venta', 18.0986300, -94.0459300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95789, 'Poblado C-11 José María Morelos y Pavón', 'Poblado C-11 Jose Maria Morelos y Pavon', 'General Jose Maria Morelos y Pavon,General José María Morelos y Pavon', 18.1741900, -93.6235600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95790, 'El Tular', 'El Tular', 'El Tular', 18.1542900, -93.3382000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95791, 'Cúlico 2da. Sección', 'Culico 2da. Seccion', 'Calico Primera Seccion,Calico Primera Sección', 18.1411600, -93.1322200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95792, 'Cumuapa 1ra. Sección', 'Cumuapa 1ra. Seccion', 'Cumuapa', 17.9851900, -93.1380600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95793, 'Saloya 2da. Sección', 'Saloya 2da. Seccion', 'Saloya Tercera Seccion,Saloya Tercera Sección', 18.0530600, -92.9363900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95794, 'Tres Bocas 1ra. Sección', 'Tres Bocas 1ra. Seccion', 'Tres Bocas Segunda Seccion,Tres Bocas Segunda Sección', 17.9323100, -93.8744400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95795, 'Huapacal 1ra. Sección', 'Huapacal 1ra. Seccion', 'Huapacal Primera Seccion,Huapacal Primera Sección', 17.9266700, -93.7663900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95796, 'Paso de la Mina 3ra. Sección', 'Paso de la Mina 3ra. Seccion', 'Paso de la Mina Segunda Seccion,Paso de la Mina Segunda Sección', 17.9633500, -93.6658200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95797, 'Parilla', 'Parilla', 'Parilla,Parilla Primera Seccion,Parilla Primera Sección,Parrilla,Villa Parrilla', 17.9155200, -92.9161200, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95798, 'Río de Teapa', 'Rio de Teapa', 'Rio de Teapa,Río de Teapa', 17.7834200, -92.9003300, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95799, 'Aquiles Serdán 1ra. Sección', 'Aquiles Serdan 1ra. Seccion', 'Aquiles Serdan,Aquiles Serdán', 17.8247400, -92.7397700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95800, 'Jalapa', 'Jalapa', 'Jalapa,Khalapa,Халапа', 17.7216800, -92.8127200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95801, 'Palomas', 'Palomas', 'Paloma,Palomas', 17.6546600, -92.4780000, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95802, 'Libertad', 'Libertad', 'Libertad', 17.4102700, -92.7150200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95803, 'Tepehuacán de Guerrero', 'Tepehuacan de Guerrero', 'Tepehuacan de Guerrero,Tepehuacán de Guerrero', 21.0136100, -98.8427800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95804, 'Zacualtipanito', 'Zacualtipanito', 'Zacualtipanito', 21.1540700, -98.7999700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95805, 'Chalahuiyapa', 'Chalahuiyapa', 'Chalahuiyapa,Chatahuiyapa', 21.1508800, -98.3642900, 'MX', '2014-03-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95806, 'Tecacahuaco', 'Tecacahuaco', 'Tecacahuaco', 20.9413300, -98.3388900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95807, 'Zoquitipán', 'Zoquitipan', 'Zoquitipan,Zoquitipán', 20.9090200, -98.4324200, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95808, 'Barrio Aztlán', 'Barrio Aztlan', 'Aztlan,Aztlán', 20.4656200, -98.0855300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95809, 'Santa María Amajac', 'Santa Maria Amajac', 'Santa Maria Amajac,Santa María Amajac', 20.3238900, -98.7422200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95810, 'Pozuelos', 'Pozuelos', 'Pozuelos', 20.4933300, -99.0597200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95811, 'Taxadho', 'Taxadho', 'Tatxadho,Tatxadhó,Taxadho', 20.4333000, -99.1493400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95812, 'El Nith', 'El Nith', 'El Nith', 20.4877800, -99.1919400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95813, 'San Bartolo Ozocalpan', 'San Bartolo Ozocalpan', 'Ozocalpan', 20.2233600, -99.4890600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95814, 'General Pedro María Anaya', 'General Pedro Maria Anaya', 'General Pedro Maria Apaya,General Pedro María Apaya', 20.1560000, -99.3480000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95815, 'Tenango', 'Tenango', 'Tenango', 20.2271400, -99.2906800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95816, 'Presas', 'Presas', 'Presas', 20.1594600, -99.2524200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95817, 'La Cruz', 'La Cruz', 'La Cruz', 20.1760300, -99.2415600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95818, 'Ocampo', 'Ocampo', 'Ocampo', 20.0089600, -99.2392600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95819, 'Munitepec de Madero', 'Munitepec de Madero', 'Munitepec', 20.1285800, -99.1994800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95820, 'Colonia Teñhe', 'Colonia Tenhe', 'Tenhe,Teñhé', 20.1929100, -99.1786600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95821, 'El Huixmí', 'El Huixmi', 'Huixmi,Huixmí', 20.0756900, -98.8197200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95822, 'Nuevo Centro de Población Agrícola el Chacón', 'Nuevo Centro de Poblacion Agricola el Chacon', 'El Chacon,El Chacón', 20.0702800, -98.7394400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95823, 'Carboneras', 'Carboneras', 'Carboneras', 20.0900000, -98.7052800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95824, 'Camelia (Barrio la Camelia)', 'Camelia (Barrio la Camelia)', 'Camelia', 20.1491700, -98.7222200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95825, 'Ahuehuetitla', 'Ahuehuetitla', 'Ahuehuetilla', 20.0844400, -98.4166700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95826, 'Santa María Nativitas', 'Santa Maria Nativitas', 'Santa Maria Nativitas,Santa María Nativitas', 20.0388900, -98.2963900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95827, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 19.6541700, -98.5463900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95828, 'Vicente Guerrero (San Javier)', 'Vicente Guerrero (San Javier)', 'Vicente Guerrero', 19.9499100, -98.9013500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95829, 'Emiliano Zapata', 'Emiliano Zapata', '', 19.5586100, -97.9166700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95830, 'Lázaro Cárdenas', 'Lazaro Cardenas', '', 19.5375000, -97.9822200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95831, 'San José Tepeyahualco', 'San Jose Tepeyahualco', '', 19.5994400, -98.2688900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95832, 'Lagunilla', 'Lagunilla', 'Lagunilla', 19.6360700, -98.2743400, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95833, 'La Soledad', 'La Soledad', 'La Soledad', 19.5384100, -98.6175000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95834, 'Muñoz Arenas de Domingo', 'Munoz Arenas de Domingo', 'Munoz,Munoz Arenas de Domingo,Muñoz,Muñoz Arenas de Domingo', 19.4745800, -98.2096300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95835, 'San José Teacalco', 'San Jose Teacalco', '', 19.3355800, -98.0645500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95836, 'Colonia Venustiano Carranza', 'Colonia Venustiano Carranza', '', 19.4000500, -98.0582200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95837, 'Santa Cruz Pocitos', 'Santa Cruz Pocitos', '', 19.3792400, -97.7611600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95838, 'El Carmen Tequesquitla', 'El Carmen Tequesquitla', 'El Carmen,El Carmen Tequesquitla,Tequixquitla', 19.3242600, -97.6535000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95839, 'Huamantla', 'Huamantla', 'Cuammantlah,Heroica Huamantla,Huamantla,Huamantla de Juarez,Huamantla de Juárez,San Luis,Uamantla,uamanto~ura,Уамантла,ウアマントゥラ', 19.3145100, -97.9252000, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95840, 'Ixtenco', 'Ixtenco', '', 19.2511100, -97.8947200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95841, 'Zitlaltépec', 'Zitlaltepec', 'San Pablo,San Pablo Zitlaltepec,Zitlaltepec,Zitlaltepetl', 19.2038900, -97.9072200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95842, 'Colonia Cuauhtémoc', 'Colonia Cuauhtemoc', '', 19.3318200, -97.9648700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95843, 'Tetlanohcán', 'Tetlanohcan', 'San Francisco Tetlanohca,Tetlanohca,Tetlanohcan,Tetlanohcán,Tetlanolican', 19.2603000, -98.1643300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95844, 'Mazatecochco', 'Mazatecochco', '', 19.1786100, -98.1891700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95845, 'Xicohtzinco', 'Xicohtzinco', 'Santo Toribio Xicohtzinco,Santo Toribio Xicohtzingo,Santo Toribio Xicotzinco,Xicohtzinco,Xicohtzingo,Xicotzingo', 19.1737100, -98.2337700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95846, 'Concepción Chimalpa', 'Concepcion Chimalpa', '', 19.2163900, -98.1980600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95847, 'Acuamanala', 'Acuamanala', 'Acuamanala,Cuamanola', 19.2236100, -98.2005600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95848, 'La Magdalena Tlaltelulco', 'La Magdalena Tlaltelulco', 'La Magdalena Tlaltelulco,Magdalena Tlaltelulco,Tlaltelolco,Tlaltelulco', 19.2828700, -98.1960900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95849, 'Tepeyanco', 'Tepeyanco', 'San Francisco,San Francisco Tepeyanco,Tepeyanco', 19.2455800, -98.2340900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95850, 'San Jerónimo Zacualpan', 'San Jeronimo Zacualpan', '', 19.2408300, -98.2613900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95851, 'Zacatelco', 'Zacatelco', 'Cakatelko,Santa Ines Zacatelco,Santa Inés Zacatelco,Zacatelco,Zacatlatelco,Цакателко', 19.2158300, -98.2397200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95852, 'Tetlatlahuca', 'Tetlatlahuca', 'Santa Isabel,Santa Isabel Tetlatlahuca,Santa Isabel Tetlatlauhca,Santa Isabel Tetlauhca,Tetlatlahuaca,Tetlatlahuca', 19.2323200, -98.2956100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95853, 'Tetlatlahuca', 'Tetlatlahuca', '', 19.2305600, -98.2952800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95854, 'Santa Cruz Aquiahuac', 'Santa Cruz Aquiahuac', '', 19.2394400, -98.2822200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95855, 'Tlaxcala', 'Tlaxcala', 'Tlaskala,Tlaxcala,Tlaxcala City,Tlaxcala de Xicohtencatl,Tlaxcala de Xicohténcatl,Tlaxcala de Xicotencatl,Tlaxcala de Xicoténcatl,Тласкала', 19.3190500, -98.1998200, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95856, 'Totolac', 'Totolac', 'San Juan,San Juan Totolac,Totolac', 19.3258000, -98.2583400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95857, 'Papalotla', 'Papalotla', 'Papalotla,San Fransico Papalotla', 19.1686100, -98.2038900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95858, 'Tenancingo', 'Tenancingo', 'San Miguel Tenancingo,Tenancingo', 19.1472500, -98.2013200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95859, 'Villa Vicente Guerrero', 'Villa Vicente Guerrero', 'San Pablo del Monte,Vicente Guerrero,Villa Vicente Guerrero', 19.1212300, -98.1657200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95860, 'Guadalupe Texcalac', 'Guadalupe Texcalac', 'Guadalupe,Guadalupe Texcalac,Texcalac', 19.4383900, -98.0780600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95861, 'Pueblo Juárez', 'Pueblo Juarez', 'Juarez,Juárez,Pueblo Juarez,Pueblo Juárez', 17.6434100, -93.1596400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95862, 'Nuevo Nicapa', 'Nuevo Nicapa', 'Nuevo Nicapa', 17.6346400, -93.0723800, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95863, 'Catazajá', 'Catazaja', '', 17.7250000, -92.0141700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95864, 'Lacandón', 'Lacandon', 'Lacandon,Lacandón', 17.0214100, -91.5952300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95865, 'Nuevo Limar', 'Nuevo Limar', 'Nuevo Limar', 17.4551400, -92.3989000, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95866, 'El Limar', 'El Limar', '', 17.4149100, -92.4029300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95867, 'Nuevo Sitalá', 'Nuevo Sitala', 'Nuevo Sitala,Nuevo Sitalá,Pueblo Nuevo Sitala,Pueblo Nuevo Sitalá', 17.1393600, -92.4828700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95868, 'Pantelhó', 'Pantelho', 'Pantelho,Pantelhó', 17.0055600, -92.4688900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95869, 'José María Morelos y Pavón', 'Jose Maria Morelos y Pavon', '', 17.2410500, -92.7023100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95870, 'Rincón Chamula', 'Rincon Chamula', 'Rincon Chamula,Rincón Chamula', 17.2071800, -92.9391200, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95871, 'San Miguel la Sardina', 'San Miguel la Sardina', '', 17.2941700, -93.3525000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95872, 'Adolfo López Mateos', 'Adolfo Lopez Mateos', 'Adolfo Lopez Mateos,Adolfo López Mateos', 17.2160000, -93.4789500, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95873, 'José María Pino Suárez', 'Jose Maria Pino Suarez', 'Jose Maria Pino Suarez,José María Pino Suárez', 16.5057100, -93.7391000, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95874, 'Cuauhtémoc', 'Cuauhtemoc', '', 16.5500000, -93.7161100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95875, 'Lázaro Cárdenas', 'Lazaro Cardenas', '', 16.6041700, -93.7913900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95876, 'Alfonso Moguel', 'Alfonso Moguel', '', 16.6675000, -93.5063900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95877, 'Vicente Guerrero', 'Vicente Guerrero', '', 16.6602800, -93.5830600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95878, 'Hermenegildo Galeana', 'Hermenegildo Galeana', '', 16.5772200, -93.3594400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95879, 'Ignacio Zaragoza (El Morro)', 'Ignacio Zaragoza (El Morro)', '', 16.5994400, -93.3508300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95880, 'Larráinzar', 'Larrainzar', '', 16.8836100, -92.7133300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95881, 'San Juan Cancuc', 'San Juan Cancuc', 'San Juan Cancuc', 16.8927200, -92.3700600, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95882, 'Altamirano', 'Altamirano', 'Altamirano', 16.7345700, -92.0384300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95883, 'Benemérito', 'Benemerito', 'Benemerito,Benemerito de las Americas,Benemérito,Benemérito de las Américas', 16.5159900, -90.6537100, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95884, 'Emiliano Zapata', 'Emiliano Zapata', '', 16.2891700, -90.6208300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95885, 'Chihuahua', 'Chihuahua', 'Chihuahua', 16.0296600, -91.9733100, 'MX', '2017-07-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95886, 'La Independencia', 'La Independencia', 'La Independencia', 16.2526300, -92.0237100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95887, 'Yasha', 'Yasha', 'Yasha,Yashá', 16.3914100, -92.0687800, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95888, 'Mariano Matamoros', 'Mariano Matamoros', '', 16.4811900, -92.5847200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95889, 'Ricardo Flores Magón', 'Ricardo Flores Magon', '', 16.3939700, -92.6961800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95890, 'Miguel Hidalgo', 'Miguel Hidalgo', 'Miguel Hidalgo', 16.3506000, -92.6285200, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95891, 'Presidente Echeverría (Laja Tendida)', 'Presidente Echeverria (Laja Tendida)', 'Laja Tendida,Presidente Echeverria,Presidente Echeverría', 16.3358300, -92.6686100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95892, 'Nueva Libertad', 'Nueva Libertad', 'El Nanchal,Nueva Libertad', 16.0903800, -92.8081300, 'MX', '2016-09-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95893, 'Unión Buena Vista', 'Union Buena Vista', 'Union Buena Vista,Unión Buena Vista', 16.4858200, -92.8182300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95894, 'Manuel Ávila Camacho', 'Manuel Avila Camacho', 'Manuel Avila Camacho,Manuel Ávila Camacho', 16.1464700, -93.0170100, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95895, 'Doctor Domingo Chanona', 'Doctor Domingo Chanona', '', 16.3461100, -93.4166700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95896, 'Joaquín Miguel Gutiérrez', 'Joaquin Miguel Gutierrez', '', 16.3700000, -93.3655600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95897, 'Nuevo México', 'Nuevo Mexico', '', 16.4694400, -93.4380600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95898, 'Cristóbal Obregón', 'Cristobal Obregon', '', 16.4324600, -93.4568900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95899, 'Libertad Melchor Ocampo', 'Libertad Melchor Ocampo', '', 16.3738900, -93.4750000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95900, 'Agrónomos Mexicanos', 'Agronomos Mexicanos', '', 16.3500000, -93.5300000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95901, 'Nueva Palestina', 'Nueva Palestina', '', 16.4927800, -93.6336100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95902, 'Julián Grajales', 'Julian Grajales', '', 16.4291700, -93.7141700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95903, 'Tonalá', 'Tonala', 'Tonala,Tonalá,tuo na la,Тонала,托納拉', 16.0887000, -93.7558800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95904, 'Tierra y Libertad', 'Tierra y Libertad', '', 16.3788900, -93.8605600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95905, 'Tiltepec', 'Tiltepec', '', 16.3938900, -93.8697200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95906, 'Villamorelos', 'Villamorelos', '', 16.4800000, -93.9277800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95907, 'Arriaga', 'Arriaga', 'Arriaga', 16.2375000, -93.9018400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95908, 'San Luqueño', 'San Luqueno', '', 16.0127800, -93.8458300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95909, 'Paredón', 'Paredon', '', 16.0508300, -93.8666700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95910, 'Doctor Belisario Domínguez (La Barra)', 'Doctor Belisario Dominguez (La Barra)', '', 15.8894700, -93.7040400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95911, 'Manuel Ávila Camacho (Ponte Duro)', 'Manuel Avila Camacho (Ponte Duro)', '', 15.8097300, -93.5893300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95912, 'El Palmarcito', 'El Palmarcito', '', 15.4972800, -93.2138700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95913, 'Pilcaya', 'Pilcaya', 'Pilcaya', 18.7469100, -99.6750100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95914, 'San Gaspar', 'San Gaspar', '', 18.7775000, -99.5486100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95915, 'San Andrés Nicolás Bravo', 'San Andres Nicolas Bravo', '', 18.7677800, -99.4652800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95916, 'El Terrero', 'El Terrero', '', 18.7902800, -99.6452800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95917, 'San José Chalmita', 'San Jose Chalmita', '', 18.8586200, -99.5483100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95918, 'San Pablo Tejalpa', 'San Pablo Tejalpa', '', 18.8666700, -99.5911100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95919, 'La Finca', 'La Finca', '', 18.8904700, -99.6402800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95920, 'Buenavista', 'Buenavista', '', 18.9455600, -99.6569400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95921, 'Acatzingo (Acatzingo de la Piedra)', 'Acatzingo (Acatzingo de la Piedra)', '', 18.9238900, -99.5886100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95922, 'El Carmen (El Desierto del Carmen)', 'El Carmen (El Desierto del Carmen)', '', 18.9202800, -99.5566700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95923, 'San Nicolás', 'San Nicolas', '', 18.9333300, -99.5683300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95924, 'Tepalcatepec', 'Tepalcatepec', '', 18.9355600, -99.5991700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95925, 'Jesús Carranza (Rancho de Jesús)', 'Jesus Carranza (Rancho de Jesus)', '', 18.9452800, -99.6305600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95926, 'Villa Guerrero', 'Villa Guerrero', '', 18.9600000, -99.6400000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95927, 'Santiago Oxtotitlán', 'Santiago Oxtotitlan', 'Santiago Oxtotitlan,Santiago Oxtotitlán', 18.9614600, -99.6682700, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95928, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', 18.9422400, -99.9391300, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95929, 'Texcapilla', 'Texcapilla', 'Texcapilla', 18.9457400, -99.8953500, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95930, 'El Salitre', 'El Salitre', '', 18.9525000, -99.5897200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95931, 'Chalchihuapan', 'Chalchihuapan', '', 18.9769400, -99.5747200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95932, 'Tepoxtepec', 'Tepoxtepec', '', 18.9627800, -99.5563900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95933, 'San Miguel', 'San Miguel', '', 18.9938900, -99.6663900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95934, 'Santa Cruz Pueblo Nuevo (Pueblo Nuevo)', 'Santa Cruz Pueblo Nuevo (Pueblo Nuevo)', '', 19.1000000, -99.6580600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95935, 'Cerro La Calera', 'Cerro La Calera', '', 19.1833300, -99.8166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95936, 'Santa Cruz Atizapán', 'Santa Cruz Atizapan', 'Atizapan,Atizapán,Santa Cruz Atizapan,Santa Cruz Atizapán', 19.1769200, -99.4885200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95937, 'San Juan Tlacotompa (Tlacotompa)', 'San Juan Tlacotompa (Tlacotompa)', '', 18.9411100, -98.7905600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95938, 'San Juan Tepecoculco', 'San Juan Tepecoculco', '', 18.9830600, -98.7875000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95939, 'Tepetlixpa', 'Tepetlixpa', 'San Esteban,San EstebanTepetlixpa,Tepe,Tepetlixpa,Tepetlixpac', 19.0289300, -98.8212900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95940, 'Tezoyuca', 'Tezoyuca', 'Tezoyuca,Villa Altezoyuca', 19.5928300, -98.9108400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95941, 'Acolman', 'Acolman', '', 19.6237500, -98.9240700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95942, 'San Pablo Ixquitlán', 'San Pablo Ixquitlan', '', 19.7094400, -98.7883300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95943, 'San Antonio de las Palmas', 'San Antonio de las Palmas', 'San Antonio de las Palmas', 19.7180600, -98.8568400, 'MX', '2014-05-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95944, 'Ixtlahuaca de Cuauhtémoc', 'Ixtlahuaca de Cuauhtemoc', '', 19.8813900, -98.8602800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95945, 'La Soledad Barrio', 'La Soledad Barrio', '', 20.0919400, -99.8230600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95946, 'San Juan Daxthi', 'San Juan Daxthi', 'San Juan Daxhi,San Juan Daxthi', 20.0983800, -99.5259900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95947, 'La Comunidad', 'La Comunidad', '', 20.0211100, -99.5761100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95948, 'Ganzda', 'Ganzda', '', 19.9900000, -99.8475000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95949, 'Bobashi de Guadalupe', 'Bobashi de Guadalupe', '', 19.8758300, -99.9116700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95950, 'San Luis Anáhuac (Toriles)', 'San Luis Anahuac (Toriles)', '', 19.7967900, -99.4002900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95951, 'Santiago Casandeje', 'Santiago Casandeje', '', 19.7697200, -99.9691700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95952, 'Santa Ana Ixtlahuaca (Santa Ana Ixtlahuacingo)', 'Santa Ana Ixtlahuaca (Santa Ana Ixtlahuacingo)', '', 19.5847200, -99.8875000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95953, 'Jaltocan', 'Jaltocan', '', 20.6196800, -97.8178700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95954, 'Venustiano Carranza', 'Venustiano Carranza', '', 20.5066700, -97.6680600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95955, 'Atla', 'Atla', 'Atla', 20.2752700, -98.1246900, 'MX', '2014-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95956, 'San Pedro Tlaolantongo', 'San Pedro Tlaolantongo', '', 20.2313900, -97.8013900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95957, 'Tlaola', 'Tlaola', '', 20.1386100, -97.9230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95958, 'Ixtepec', 'Ixtepec', 'Ixtepec', 20.0246100, -97.6461200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95959, 'Ciudad de Tlatlauquitepec', 'Ciudad de Tlatlauquitepec', '', 19.8527800, -97.4952800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95960, 'San Andrés Cholula', 'San Andres Cholula', 'San Andres Cholollan,San Andres Cholula,San Andrés Cholula,San Andrés Cholōllān,san andrys chwlwla  pwybla,سان آندریس چولولا، پوئبلا,サン・アンドゥレス・チョルラ', 19.0514400, -98.2952600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95961, 'Mazapiltepec', 'Mazapiltepec', 'Mazapiltepec,Mazapiltepec de Juarez,Mazapiltepec de Juárez', 19.1191200, -97.7028000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95962, 'González Ortega', 'Gonzalez Ortega', 'Gonzalez Ortega,González Ortega', 19.3426800, -97.2702300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95963, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 19.2911000, -97.3429000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95964, 'José María Morelos', 'Jose Maria Morelos', 'Jose Maria Morelos,José María Morelos', 19.1414700, -97.4680900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95965, 'San Miguel Zoapan', 'San Miguel Zoapan', 'San Miguel Zoapan', 19.0843300, -97.3535900, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95966, 'San José Cuyachapa', 'San Jose Cuyachapa', 'San Jose Cuyachapa,San José Cuyachapa', 18.8546600, -97.3139800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95967, 'Chapulco', 'Chapulco', 'Chapuco,Chapulco', 18.6258600, -97.4047400, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95968, 'San Pedro Temamatla', 'San Pedro Temamatla', 'San Pedro Temamatla', 18.9255300, -97.5119800, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95969, 'Actipan de Morelos', 'Actipan de Morelos', 'Actipan,Actipan de Morelos,Santa Maria Actipan,Santa María Actipan', 18.9600300, -97.7990400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95970, 'Dolores Hidalgo', 'Dolores Hidalgo', 'Dolores Hidalgo', 18.7569700, -97.8606200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95971, 'Santa Cruz Ajajalpan', 'Santa Cruz Ajajalpan', 'Santa Cruz Ajajalpan', 18.9516900, -97.9499800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95972, 'San Antonio Juárez', 'San Antonio Juarez', '', 18.7937900, -97.9896400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95973, 'Santa Lucía Cosamaloapan', 'Santa Lucia Cosamaloapan', '', 18.8836100, -98.3519400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95974, 'San Pablo Ahuatempa', 'San Pablo Ahuatempa', '', 18.9813900, -98.3588900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95975, 'San Isidro Huilotepec', 'San Isidro Huilotepec', '', 18.8808300, -98.3830600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95976, 'Teacalco de Dorantes (San José Teacalco)', 'Teacalco de Dorantes (San Jose Teacalco)', '', 18.8044400, -98.5072200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95977, 'San Juan Raboso', 'San Juan Raboso', 'El de Raboso,Rabosa,Raboso,San Juan Raboso', 18.5715300, -98.4396200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95978, 'Tlapanalá', 'Tlapanala', 'Tlapanala,Tlapanalá,Tlapenala,Tlapenalá', 18.6958500, -98.5356100, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95979, 'San Diego el Organal', 'San Diego el Organal', '', 18.7308300, -98.5166700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95980, 'Santa Cruz Cuautomatitla', 'Santa Cruz Cuautomatitla', '', 18.8891700, -98.6591700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95981, 'Huehuetlan el Chico', 'Huehuetlan el Chico', 'Huehuetlan El Chico,Huehuetlan el Chico,Huehuetlán El Chico', 18.3734700, -98.6900200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95982, 'Tlancualpican', 'Tlancualpican', '', 18.4333300, -98.7000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95983, 'Teotlalco', 'Teotlalco', 'Teotlalco', 18.4691000, -98.7782200, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95984, 'Xochitepec', 'Xochitepec', '', 18.2283300, -98.8761100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95985, 'Ciudad de Chiautla de Tapia', 'Ciudad de Chiautla de Tapia', 'Chiautla de Tapia', 18.3000000, -98.6038900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95986, 'Ixcamilpa', 'Ixcamilpa', 'Ixcamilpa', 18.0276900, -98.6964300, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95987, 'Acaxtlahuacán de Albino Zertuche', 'Acaxtlahuacan de Albino Zertuche', '', 18.0186100, -98.5411100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95988, 'Xicotlán', 'Xicotlan', 'Xicotlan,Xicotlán', 18.0591800, -98.5245700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95989, 'Hermenegildo Galeana', 'Hermenegildo Galeana', '', 18.2566700, -98.1022200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95990, 'Telpatlán', 'Telpatlan', '', 18.4841700, -97.1522200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95991, 'Calipan', 'Calipan', 'Caipan,Calipa,Calipan,Catipan', 18.2951900, -97.1637600, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95992, 'Jolalpan', 'Jolalpan', 'Jolalpan', 18.3249500, -98.8448900, 'MX', '2017-04-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95993, 'Villa Madero', 'Villa Madero', '', 19.5283300, -90.6991700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95994, 'La Joya', 'La Joya', '', 19.4802800, -90.6733300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95995, 'Santo Domingo Kesté', 'Santo Domingo Keste', '', 19.4997200, -90.5113900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95996, 'San Pablo Pixtún', 'San Pablo Pixtun', '', 19.1336100, -90.7319400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95997, 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', '', 18.6650400, -92.3108800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95998, 'Haro', 'Haro', 'Haro', 18.4441800, -90.7915300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(95999, 'San Juan de Dios (Naranjas de Dios)', 'San Juan de Dios (Naranjas de Dios)', '', 18.5497200, -99.5558300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96000, 'Tecuexcontitlán (Tecoescontitlán)', 'Tecuexcontitlan (Tecoescontitlan)', '', 18.1425400, -99.5778700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96001, 'Maxela', 'Maxela', 'Maxela', 18.0534700, -99.5935100, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96002, 'Axaxacualco', 'Axaxacualco', 'Axaxacualco', 17.8038700, -99.4617500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96003, 'El Fresno', 'El Fresno', '', 17.4314300, -99.5860500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96004, 'Julián Blanco (Dos Caminos)', 'Julian Blanco (Dos Caminos)', '', 17.2188900, -99.5247200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96005, 'Lomas de Chapultepec', 'Lomas de Chapultepec', 'Lomas de Chapultepec', 16.7161500, -99.6102100, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96006, 'Cerro de Piedra', 'Cerro de Piedra', 'Cerro de Piedra', 16.7764600, -99.6303700, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96007, 'Llano de la Puerta', 'Llano de la Puerta', 'Llano de la Puerta', 16.7435500, -99.5272100, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96008, 'Campanario', 'Campanario', 'Campanario', 16.8353400, -99.5717800, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96009, 'Llano Grande', 'Llano Grande', 'Llano Grande', 16.9401000, -99.4335300, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96010, 'Ocotlán', 'Ocotlan', 'Ocotitlan,Ocotitlán,Ocotlan,Ocotlán', 16.9394700, -99.3691900, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96011, 'Tecolcuautla', 'Tecolcuautla', 'Tecolcuautla', 17.7865000, -98.9482800, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96012, 'Pochutla', 'Pochutla', 'Pochultla,Pochutla', 17.6590700, -98.8979800, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96013, 'Santa Catarina', 'Santa Catarina', 'Santa Catarina', 17.5483500, -99.1750000, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96014, 'San Francisco', 'San Francisco', '', 17.0058300, -99.2830600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96015, 'La Dicha', 'La Dicha', 'La Dicha', 16.7672000, -99.0105800, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96016, 'Las Vigas', 'Las Vigas', 'Las Vigas', 16.7614400, -99.2294200, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96017, 'Marquelia', 'Marquelia', 'Marquelia', 16.5833500, -98.8168600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96018, 'Xalatzala', 'Xalatzala', 'Xalatzala', 17.4735500, -98.5735500, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96019, 'Paraje Montero (Paraje Montero de Zaragoza)', 'Paraje Montero (Paraje Montero de Zaragoza)', '', 17.1634900, -98.7039400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96020, 'San Pablo Atzompa', 'San Pablo Atzompa', '', 17.2472200, -98.3700000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96021, 'Rancho Viejo (Rancho Nuevo de la Democracia)', 'Rancho Viejo (Rancho Nuevo de la Democracia)', '', 17.0325700, -98.2238900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96022, 'San Luis Acatlán', 'San Luis Acatlan', '', 16.8072200, -98.7341700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96023, 'El Pitahayo', 'El Pitahayo', 'El Pitahayo', 16.5323600, -98.5276000, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96024, 'Panabá', 'Panaba', 'Panaba,Panabá', 21.2963900, -88.2705600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96025, 'Sucilá', 'Sucila', '', 21.1544400, -88.3136100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96026, 'Tixhualactún', 'Tixhualactun', 'Tixhualactun,Tixhualactún,Tixhualahtun,Tixhualahtún', 20.6440300, -88.1430800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96027, 'Kinil', 'Kinil', 'Kinil', 20.3237900, -89.1328500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96028, 'Xul', 'Xul', '', 20.1022200, -89.4600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96029, 'Kantunilkin', 'Kantunilkin', 'Kantunilkin', 21.1018200, -87.4864400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96030, 'Alfredo V. Bonfil', 'Alfredo V. Bonfil', 'Alfredo V. Bonfil', 21.0877600, -86.8470600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96031, 'Leona Vicario', 'Leona Vicario', 'Leona Vicario', 20.9897000, -87.2022400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96032, 'X Cabil', 'X Cabil', 'X Cabil,X-Cabil', 20.1654200, -88.4639800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96033, 'La Presumida', 'La Presumida', '', 19.8008300, -88.7538900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96034, 'Kancabchén', 'Kancabchen', '', 19.7138900, -88.8616700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96035, 'X-Hazil Sur', 'X-Hazil Sur', 'X-Hazil Sur', 19.3916700, -88.0741700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96036, 'Los Divorciados', 'Los Divorciados', 'Los Divorciados', 19.0768700, -88.4564700, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96037, 'Francisco I. Madero', 'Francisco I. Madero', 'Francisco I. Madero', 19.5271800, -97.2706700, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96038, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 19.5416700, -97.2778900, 'MX', '2016-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96039, 'El Espinal', 'El Espinal', '', 19.6244400, -96.8725000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96040, 'El Paraíso (La Charca)', 'El Paraiso (La Charca)', '', 19.4288900, -96.3550000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96041, 'Cabezas', 'Cabezas', '', 19.3716700, -96.3827800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96042, 'El Hatito', 'El Hatito', '', 19.2775000, -96.3936100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96043, 'Plan del Río', 'Plan del Rio', '', 19.4018400, -96.6525000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96044, 'Bella Esperanza', 'Bella Esperanza', 'Bella Esperanza', 19.4332900, -96.8664800, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96045, 'Tlaltetela', 'Tlaltetela', 'Tlaltetela', 19.3142100, -96.9010500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96046, 'Ixhuacán de los Reyes', 'Ixhuacan de los Reyes', 'Ixhuacan de los Reyes,Ixhuacán de los Reyes', 19.3552600, -97.1175100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96047, 'Cuiyachapa', 'Cuiyachapa', 'Cuiyachapa', 19.0456900, -97.1743600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96048, 'Tetlaxco', 'Tetlaxco', 'Tetlaxco', 19.0404400, -97.0639300, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96049, 'Ixcatla', 'Ixcatla', '', 19.0752800, -96.9188900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96050, 'San José Tenejapa', 'San Jose Tenejapa', '', 19.0155600, -96.8430600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96051, 'Mata de Indio', 'Mata de Indio', 'Mata de Indio', 19.2302800, -96.8413600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96052, 'Sonora', 'Sonora', 'Sonora', 19.1121900, -96.6353100, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96053, 'San Francisco Nacaxtle', 'San Francisco Nacaxtle', '', 19.1108300, -96.5958300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96054, 'Las Amapolas', 'Las Amapolas', '', 19.1519400, -96.1977800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96055, 'Paraje Nuevo', 'Paraje Nuevo', 'Paraje Nuevo', 18.8788600, -96.8606600, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96056, 'Veinte de Noviembre', 'Veinte de Noviembre', '', 18.8650000, -96.9547200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96057, 'Trapiche Viejo', 'Trapiche Viejo', '', 18.8430600, -96.9455600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96058, 'Rincón de Buena Vista', 'Rincon de Buena Vista', '', 18.7555600, -96.8686100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96059, 'San José de Tapia', 'San Jose de Tapia', '', 18.8472200, -96.9538900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96060, 'Monte Salas', 'Monte Salas', '', 18.9372200, -97.0183300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96061, 'Buenavista', 'Buenavista', '', 18.8930600, -97.0369400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96062, 'Campo Chico', 'Campo Chico', 'Campo Chico', 18.8363900, -97.0280200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96063, 'La Perla', 'La Perla', '', 18.9275000, -97.1325000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96064, 'Tlilapan', 'Tlilapan', 'Tlilapan,Tlilapán', 18.8056000, -97.0986700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96065, 'La Cuesta', 'La Cuesta', '', 18.7902800, -97.1680600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96066, 'San Isidro el Berro', 'San Isidro el Berro', '', 18.9272200, -97.2055600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96067, 'San José Súchil', 'San Jose Suchil', '', 18.8877800, -97.2372200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96068, 'El Aguacate', 'El Aguacate', '', 18.1977800, -94.9702800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96069, 'Ixhuapan', 'Ixhuapan', '', 18.0133300, -94.8766700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96070, 'Tlacuilolapan', 'Tlacuilolapan', '', 17.9777800, -94.2630600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96071, 'Zaragoza', 'Zaragoza', 'Zaragoza', 17.9578300, -94.6423100, 'MX', '2017-03-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96072, 'Coacotla', 'Coacotla', '', 17.9361100, -94.6666700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96073, 'Las Lomas de Tacamichapan', 'Las Lomas de Tacamichapan', '', 17.8661100, -94.7083300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96074, 'Colonia Lealtad', 'Colonia Lealtad', '', 17.9630600, -94.9025000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96075, 'Congregación Hidalgo', 'Congregacion Hidalgo', '', 17.9375000, -94.9705600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96076, 'Dehesa', 'Dehesa', '', 17.9416700, -94.9980600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96077, 'Tampico', 'Tampico', 'Gorad Tampika,Tampeks,Tampikas,Tampiko,Tampėks,tam pi ko,tambykw,tampiko,tampykw,tan pi ke,tanpiko,tempiko,tmpyqw,Горад Тампіка,Тампико,Տամպիկո,טמפיקו,تامبيكو,تامپیکو,टॅम्पिको,ตัมปีโก,タンピコ,坦皮科,탐피코', 22.2552800, -97.8686100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96078, 'San Vicente Tancuayalab', 'San Vicente Tancuayalab', '', 21.7183300, -98.5877800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96079, 'San Pedro Coyutla', 'San Pedro Coyutla', 'San Pedro Coyutla', 21.2241000, -98.4300200, 'MX', '2014-03-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96080, 'Texcatepec', 'Texcatepec', 'Texcatepec', 20.5841700, -98.3652800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96081, 'Otatitlán', 'Otatitlan', '', 20.6355600, -98.1402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96082, 'Tenantitla', 'Tenantitla', 'Tenantilla,Tenantitla', 20.7703100, -98.1443300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96083, 'Xochimilco', 'Xochimilco', 'Xochimilco', 20.8630200, -98.0696700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96084, 'Pisaflores', 'Pisaflores', 'Pisaflores', 20.6094100, -97.9278200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96085, 'Tincontlán', 'Tincontlan', 'Tincontlan,Tincontlán', 20.8214100, -97.6908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96086, 'Alto Lucero', 'Alto Lucero', '', 20.9536100, -97.4419400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96087, 'La Victoria (La Peñita)', 'La Victoria (La Penita)', '', 20.9369400, -97.3725000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96088, 'Barra de Cazones', 'Barra de Cazones', '', 20.7222200, -97.2025000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96089, 'Polutla', 'Polutla', 'Polutla', 20.5279900, -97.2588400, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96090, 'Las Lomas', 'Las Lomas', '', 20.2606700, -97.6152800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96091, 'Macedonio Alonso', 'Macedonio Alonso', '', 20.2741700, -97.6919400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96092, 'Mecatlán', 'Mecatlan', '', 20.2091700, -97.6808300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96093, 'Hueytamalco', 'Hueytamalco', '', 19.9388900, -97.2872200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96094, 'Ignacio Zaragoza', 'Ignacio Zaragoza', '', 19.7122200, -97.2250000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96095, 'Gutiérrez Zamora', 'Gutierrez Zamora', '', 19.7241700, -97.2150000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96096, 'San Marcos Atesquilapan', 'San Marcos Atesquilapan', '', 19.6897200, -96.8853700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96097, 'Monte Verde Chivería', 'Monte Verde Chiveria', '', 19.7030400, -96.6960100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96098, 'Palma Sola', 'Palma Sola', 'Palma Sola', 19.7713200, -96.4322500, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96099, 'Manuel María Contreras', 'Manuel Maria Contreras', 'Manuel Maria Contreras,Manuel María Contreras', 20.4461700, -97.4832900, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96100, 'Tapalapan', 'Tapalapan', 'Tapalapan', 18.5325000, -95.3063100, 'MX', '2013-12-14', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96101, 'Cosolapa', 'Cosolapa', 'Cosolapa', 18.6019400, -96.6827800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96102, 'Presidio (Plan de Libres)', 'Presidio (Plan de Libres)', '', 18.6805600, -96.7719400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96103, 'Tlapacoyan', 'Tlapacoyan', '', 18.4566700, -95.4005600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96104, 'Santa Rosa Abata', 'Santa Rosa Abata', '', 18.4619000, -95.1676500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96105, 'Juan Jacobo Torres [Bodega de Totontepec]', 'Juan Jacobo Torres [Bodega de Totontepec]', '', 18.3364500, -95.2603300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96106, 'Tilapan', 'Tilapan', '', 18.3491700, -95.3280600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96107, 'Estación Juanita', 'Estacion Juanita', '', 17.8088900, -95.2175000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96108, 'Juan Rodríguez Clara', 'Juan Rodriguez Clara', 'Juan Rodriguez Clara,Juan Rodríguez Clara', 17.9938900, -95.4013900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96109, 'Vista Hermosa', 'Vista Hermosa', '', 17.9236100, -95.0608300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96110, 'Aguilera', 'Aguilera', '', 17.8108300, -95.0150000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96111, 'Venustiano Carranza (Peña Blanca)', 'Venustiano Carranza (Pena Blanca)', '', 17.6419400, -94.7541700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96112, 'San Lorenzo Tenochtitlán', 'San Lorenzo Tenochtitlan', '', 17.7550000, -94.7602800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96113, 'Poblado Cinco', 'Poblado Cinco', 'Poblado Cinco', 17.2745300, -94.5515200, 'MX', '2014-10-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96114, 'Boxasní', 'Boxasni', '', 20.6708300, -99.8486100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96115, 'La Llave', 'La Llave', 'La Llave', 20.4662800, -99.9937300, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96116, 'Santa Cruz Escandón', 'Santa Cruz Escandon', 'Santa Cruz Escandon,Santa Cruz Escandón', 20.4160300, -99.9556300, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96117, 'Paso de Mata', 'Paso de Mata', 'Paso de Mata', 20.3423000, -99.9271200, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96118, 'Yosphí', 'Yosphi', '', 20.1708300, -99.9522200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96119, 'San Bartolo el Viejo', 'San Bartolo el Viejo', '', 19.2988900, -99.8238900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96120, 'San Pedro de la Hortaliza (Ejido Almoloyán)', 'San Pedro de la Hortaliza (Ejido Almoloyan)', 'San Pedro La Hortaliza,San Pedro de la Hortaliza', 19.3880600, -99.8177800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96121, 'Las Peñas', 'Las Penas', '', 19.4497200, -99.9994400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96122, 'El Rincón de los Perales', 'El Rincon de los Perales', '', 19.5422200, -99.8280600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96123, 'Guadalupe Cachi', 'Guadalupe Cachi', '', 19.6011100, -99.8250000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96124, 'Emiliano Zapata (Santo Domingo)', 'Emiliano Zapata (Santo Domingo)', '', 19.5797200, -99.7880600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96125, 'San Francisco de Guzmán', 'San Francisco de Guzman', 'San Francisco,San Francisco Ixtlahuaca', 19.6202800, -99.7747200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96126, 'Fresno Nichi', 'Fresno Nichi', '', 19.5669400, -99.9488900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96127, 'Mina Vieja', 'Mina Vieja', '', 19.5525000, -99.9438900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96128, 'Palos Amarillos (Palos Amarillos Yebuciví)', 'Palos Amarillos (Palos Amarillos Yebucivi)', '', 19.5394400, -99.9166700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96129, 'Cuadrilla Vieja', 'Cuadrilla Vieja', '', 19.5120500, -99.9869200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96130, 'Barrio de San Isidro', 'Barrio de San Isidro', '', 19.5213900, -99.9586100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96131, 'San Antonio de las Huertas', 'San Antonio de las Huertas', '', 19.5622200, -99.9711100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96132, 'San Juan Cote Ejido', 'San Juan Cote Ejido', '', 19.6051600, -99.9591300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96133, 'San Jerónimo Bonchete', 'San Jeronimo Bonchete', '', 19.6310600, -99.9494900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96134, 'Santa Cruz Mextepec', 'Santa Cruz Mextepec', '', 19.6597200, -99.9530600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96135, 'Dolores Hidalgo', 'Dolores Hidalgo', '', 19.6552800, -99.9263900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96136, 'Ejido del Tunal Nenaxi', 'Ejido del Tunal Nenaxi', 'El Tunal Nenaxi,Nenaxi', 19.7438900, -99.9088900, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96137, 'San Lucas Ocotepec', 'San Lucas Ocotepec', '', 19.6783300, -99.9719400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96138, 'El Carmen Ocotepec', 'El Carmen Ocotepec', '', 19.6872200, -99.9741700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96139, 'San Juan Jalpa Centro', 'San Juan Jalpa Centro', '', 19.6980600, -99.9300000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96140, 'San Agustín Mextepec', 'San Agustin Mextepec', 'San Agustin Mextepec,San Agustín Mextepec', 19.6329200, -99.9265400, 'MX', '2016-08-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96141, 'Santa Ana la Ladera', 'Santa Ana la Ladera', '', 19.5958300, -99.8700000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96142, 'San Isidro Boxipe', 'San Isidro Boxipe', 'Boxipe,San Isidro Boxipe', 19.6011100, -99.8908300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96143, 'Santa María Endare', 'Santa Maria Endare', 'Endare,Endaré,Santa Maria Endare,Santa María Endaré', 19.7255600, -99.8158300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96144, 'Mavoro', 'Mavoro', 'Maboro,Mavoro', 19.7041700, -99.8222200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96145, 'Emilio Portes Gil', 'Emilio Portes Gil', '', 19.6444400, -99.9166700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96146, 'San Juan de las Manzanas', 'San Juan de las Manzanas', '', 19.5511100, -99.8383300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96147, 'La Concepción Enyege', 'La Concepcion Enyege', '', 19.5647200, -99.8413900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96148, 'San Andrés del Pedregal', 'San Andres del Pedregal', '', 19.5813900, -99.8688900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96149, 'Santiago Citendejé', 'Santiago Citendeje', '', 19.7813900, -99.9291700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96150, 'Cuendo', 'Cuendo', '', 19.8002800, -99.9477800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96151, 'San Lorenzo Tlacotepec', 'San Lorenzo Tlacotepec', '', 19.8125000, -99.9122200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96152, 'San Juan de los Jarros', 'San Juan de los Jarros', '', 19.8619400, -99.9161100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96153, 'San Luis Boro', 'San Luis Boro', '', 19.8131600, -99.8558000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96154, 'Tecoac (Santa María Nativitas)', 'Tecoac (Santa Maria Nativitas)', '', 19.7891700, -99.8530600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96155, 'San Bartolo Lanzados', 'San Bartolo Lanzados', '', 19.8663900, -99.8938900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96156, 'San José del Tunal', 'San Jose del Tunal', '', 19.7905600, -99.8400000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96157, 'El Rincón de la Candelaria', 'El Rincon de la Candelaria', '', 19.7900000, -99.8430600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96158, 'San Francisco Chalchihuapan', 'San Francisco Chalchihuapan', '', 19.7700000, -99.8216700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96159, 'San Antonio Enchisi', 'San Antonio Enchisi', '', 19.7547200, -99.8166700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96160, 'San Pedro del Rosal', 'San Pedro del Rosal', '', 19.7780600, -99.8125000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96161, 'San Felipe Pueblo Nuevo', 'San Felipe Pueblo Nuevo', '', 19.7677800, -99.7583300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96162, 'Santiago Acutzilapan', 'Santiago Acutzilapan', 'Santiago Acutzilapan,Santiaguito Acultzilapan', 19.7822200, -99.7641700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96163, 'Tixmadeje Chiquito', 'Tixmadeje Chiquito', '', 19.9655600, -99.9144400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96164, 'Detiña (San Antonio Detiña)', 'Detina (San Antonio Detina)', '', 19.9702800, -99.8838900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96165, 'La Caridad', 'La Caridad', '', 19.9477800, -99.8369400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96166, 'San Mateo el Viejo', 'San Mateo el Viejo', 'San Mateo el Viejo', 19.9144100, -99.9108000, 'MX', '2016-08-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96167, 'San Jerónimo de los Jarros', 'San Jeronimo de los Jarros', '', 19.8786100, -99.9233300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96168, 'Chosto de los Jarros', 'Chosto de los Jarros', '', 19.8633300, -99.9100000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96169, 'San José Toxi', 'San Jose Toxi', '', 19.8663900, -99.9386100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96170, 'Santa Cruz Bombatevi', 'Santa Cruz Bombatevi', '', 19.8050000, -99.8866700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96171, 'Tercera Manzana de Zaragoza', 'Tercera Manzana de Zaragoza', '', 19.8955600, -99.7527800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96172, 'Las Huertas', 'Las Huertas', '', 19.9722200, -99.5561100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96173, 'San Bartolo Morelos', 'San Bartolo Morelos', 'San Bartolo Morelos', 19.7864300, -99.6687900, 'MX', '2016-08-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96174, 'Jalpa de los Baños', 'Jalpa de los Banos', '', 19.6783300, -99.8738900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96175, 'San Marcos Tlazalpan', 'San Marcos Tlazalpan', 'San Marcos Tlazalpa,San Marcos Tlazalpan', 19.8061100, -99.7175000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96176, 'San José Boqui', 'San Jose Boqui', '', 19.7016700, -99.7286100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96177, 'Huemetla', 'Huemetla', '', 19.7150000, -99.7358300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96178, 'Barrio de Boyecha', 'Barrio de Boyecha', '', 19.7077800, -99.6844400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96179, 'Los Arana', 'Los Arana', '', 19.7094400, -99.5013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96180, 'San Antonio Nixini', 'San Antonio Nixini', 'Nigini,Niginí,San Antonio Nigini,San Antonio Niginí', 19.6747200, -99.6847200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96181, 'San Lorenzo Malacota', 'San Lorenzo Malacota', 'Malacota,San Lorenzo Malacota', 19.6497200, -99.6133300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96182, 'Rancho Alegre', 'Rancho Alegre', '', 19.6252800, -99.6836100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96183, 'Santa María del Llano', 'Santa Maria del Llano', '', 19.6344400, -99.7250000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96184, 'Barrio de San Pedro la Cabecera', 'Barrio de San Pedro la Cabecera', '', 19.5652800, -99.7500000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96185, 'San Miguel Yuxtepec', 'San Miguel Yuxtepec', 'San Miguel Yustepec,Yustepec', 19.5405600, -99.7125000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96186, 'Enthavi', 'Enthavi', 'Enthavi', 19.4984200, -99.5750200, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96187, 'Pothé', 'Pothe', '', 19.4741700, -99.6030600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96188, 'San Pedro Abajo', 'San Pedro Abajo', 'San Pedro Abajo,San Pedro de Abajo', 19.4809300, -99.5670000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96189, 'San Mateo Capulhuac', 'San Mateo Capulhuac', '', 19.4702800, -99.5261100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96190, 'Ejido de Dolores', 'Ejido de Dolores', '', 19.4308300, -99.6127800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96191, 'San José Pathé', 'San Jose Pathe', '', 19.4352800, -99.6311100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96192, 'La Cabecera', 'La Cabecera', '', 19.3561100, -99.7480600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96193, 'San Martín Toltepec', 'San Martin Toltepec', '', 19.3519400, -99.7058300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96194, 'San Marcos Yachihuacaltepec', 'San Marcos Yachihuacaltepec', 'San Marcos Yachihuacaltepec,Yachihuacaltepec', 19.3231900, -99.6791000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96195, 'San Mateo Otzacatipan', 'San Mateo Otzacatipan', 'San Mateo Otzacatipan', 19.3327300, -99.6034500, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96196, 'Santa María Totoltepec', 'Santa Maria Totoltepec', 'San Maria Totoltepec,San María Totoltepec,Santa Maria Totoltepec,Santa María Totoltepec', 19.3065300, -99.5927900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96197, 'El Cerrillo Vista Hermosa', 'El Cerrillo Vista Hermosa', '', 19.3233700, -99.5425000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96198, 'San Antonio Buenavista', 'San Antonio Buenavista', '', 19.2608300, -99.7119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96199, 'San Pedro Tultepec', 'San Pedro Tultepec', 'San Pedro Tultepec', 19.2651400, -99.5093400, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96200, 'San Bartolomé Tlaltelulco', 'San Bartolome Tlaltelulco', 'San Bartolome Tlaltelulco,San Bartolomé Tlaltelulco', 19.2273800, -99.6296400, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96201, 'San Juan Tilapa', 'San Juan Tilapa', 'San Juan Tilapa', 19.2202100, -99.6601200, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96202, 'Santa María Nativitas', 'Santa Maria Nativitas', '', 19.2113900, -99.6294400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96203, 'San Pedro Tlaltizapan', 'San Pedro Tlaltizapan', 'San Pedro Tlaltizapan', 19.1997300, -99.4995600, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96204, 'San Andrés Ocotlán', 'San Andres Ocotlan', 'San Andres Ocotlan,San Andrés Ocotlán', 19.1929700, -99.5861200, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96205, 'San Francisco Putla', 'San Francisco Putla', '', 19.1277800, -99.6355600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96206, 'San Gabriel Zepayautla', 'San Gabriel Zepayautla', '', 19.0130600, -99.5519400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96207, 'San Pedro Zictepec', 'San Pedro Zictepec', 'San Pedro Zictepec', 19.0365900, -99.5777100, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96208, 'Maxtleca de Galeana', 'Maxtleca de Galeana', '', 19.0288900, -99.5572200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96209, 'Santa María Jajalpa', 'Santa Maria Jajalpa', '', 19.1116700, -99.5358300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96210, 'San Antonio la Isla', 'San Antonio la Isla', 'La Isla,San Antonio La Isla', 19.1630600, -99.5672200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96211, 'Tlacomulco', 'Tlacomulco', '', 19.1211100, -99.4475000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96212, 'San Lorenzo Huehuetitlán', 'San Lorenzo Huehuetitlan', '', 19.1341700, -99.4822200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96213, 'Santiago Tílapa', 'Santiago Tilapa', 'Santiago Tilapa,Santiago Tílapa', 19.1895300, -99.4208900, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96214, 'San Miguel Almaya', 'San Miguel Almaya', '', 19.2094400, -99.4425000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96215, 'Tres Marías', 'Tres Marias', 'Tres Cumbres,Tres Marias,Tres Marías', 19.0549000, -99.2430100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96216, 'San Pedro Cholula', 'San Pedro Cholula', '', 19.2644400, -99.4863900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96217, 'San Jerónimo Acazulco', 'San Jeronimo Acazulco', '', 19.2650000, -99.4158300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96218, 'San Miguel Ameyalco', 'San Miguel Ameyalco', '', 19.3063900, -99.4580600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96219, 'San Mateo Atarasquíllo', 'San Mateo Atarasquillo', 'San Mateo Atarasquillo,San Mateo Atarasquíllo', 19.3230400, -99.4615600, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96220, 'San Lorenzo Acopilco', 'San Lorenzo Acopilco', '', 19.3288900, -99.3255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96221, 'Benito Juarez', 'Benito Juarez', '', 19.3984000, -99.1576600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96222, 'Venustiano Carranza', 'Venustiano Carranza', 'Venustiano Carranza', 19.4436100, -99.1049900, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96223, 'Miguel Hidalgo', 'Miguel Hidalgo', 'Delegacion Miguel Hidalgo,Delegación Miguel Hidalgo,Miguel Hidalgo', 19.4341100, -99.2002400, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96224, 'Cuauhtémoc', 'Cuauhtemoc', 'Cuauhtemoc,Cuauhtémoc', 19.4450600, -99.1461200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96225, 'Huixquilucan', 'Huixquilucan', 'Huixquilucan', 19.3598500, -99.3501600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96226, 'Zacamulpa', 'Zacamulpa', 'Zacamulpa', 19.3556500, -99.3314500, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96227, 'San Bartolomé Coatepec', 'San Bartolome Coatepec', 'San Bartolito,San Bartolome Coatepec,San Bartolomé Coatepec', 19.3977600, -99.3121100, 'MX', '2017-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96228, 'Santa Cruz Huitzizilapan', 'Santa Cruz Huitzizilapan', 'Sacamulpa Huitzitzilapa,Sacamulpa Huitzitzilapan', 19.3969400, -99.4480600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96229, 'San Francisco Chimalpa', 'San Francisco Chimalpa', '', 19.4419400, -99.3419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96230, 'Loma del Río', 'Loma del Rio', '', 19.6005600, -99.3505600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96231, 'San Miguel Hila', 'San Miguel Hila', '', 19.5936100, -99.3252800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96232, 'San José el Vidrio', 'San Jose el Vidrio', '', 19.6533300, -99.3841700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96233, 'San Luis Taxhimay', 'San Luis Taxhimay', '', 19.8397200, -99.3986100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96234, 'San Ignacio Nopala', 'San Ignacio Nopala', '', 19.8352800, -99.3455600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96235, 'Santiago Tlapanaloya', 'Santiago Tlapanaloya', 'Santiago Tlapanaloya,Santiago Tlapanoloya', 19.8705600, -99.3508300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96236, 'Cantera de Villagrán', 'Cantera de Villagran', '', 19.8408300, -99.3091700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96237, 'Santiago Tlautla', 'Santiago Tlautla', '', 19.9644400, -99.3722200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96238, 'Santa María Ilucan', 'Santa Maria Ilucan', '', 19.9888900, -99.3388900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96239, 'San Miguel Vindho', 'San Miguel Vindho', 'San Miguel Vindho', 19.9944700, -99.3178200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96240, 'Unidad San Miguel Jagüeyes', 'Unidad San Miguel Jagueeyes', '', 19.8236100, -99.2888900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96241, 'Emiliano Zapata (San José Bata)', 'Emiliano Zapata (San Jose Bata)', '', 19.9111100, -99.0066700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96242, 'San Pedro Xalpa', 'San Pedro Xalpa', 'San Pedro Xalpa', 19.8266600, -99.1846600, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96243, 'Melchor Ocampo', 'Melchor Ocampo', 'Melchor Ocampo', 19.7018600, -99.1448500, 'MX', '2017-05-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96244, 'Huilango', 'Huilango', '', 19.6805600, -99.2563900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96245, 'Santiago Teyahualco', 'Santiago Teyahualco', 'Santiago Atocan,Santiago Teyahualco,Teyahualco', 19.6598500, -99.1249300, 'MX', '2017-05-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96246, 'Tonanitla', 'Tonanitla', 'Santa Maria Tonanitla,Santa Maria Tonatitla,Santa María Tonanitla,Santa María Tonatitla,Tonanitla', 19.6879400, -99.0534200, 'MX', '2017-05-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96247, 'Ojo de Agua', 'Ojo de Agua', '', 19.6802800, -99.0100000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96248, 'Santo Tomás Chiconautla', 'Santo Tomas Chiconautla', 'Santo Tomas Chiconautla,Santo Tomás Chiconautla', 19.6389400, -99.0075500, 'MX', '2017-05-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96249, 'Buenavista', 'Buenavista', 'Buenavista', 19.6083300, -99.1694400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96250, 'San Ignacio Río Muerto', 'San Ignacio Rio Muerto', 'Rio Muerto,Río Muerto,San Ignacio Rio Muerto,San Ignacio Río Muerto', 27.4165600, -110.2458400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96251, 'Rosario', 'Rosario', 'Rosario', 27.8411100, -109.3680600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96252, 'Vicam', 'Vicam', 'Vicam', 27.6435400, -110.2935100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96253, 'Antonio Rosales', 'Antonio Rosales', 'Antonio Rosales', 28.0788900, -110.6134900, 'MX', '2016-12-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96254, 'Miguel Alemán (La Doce)', 'Miguel Aleman (La Doce)', 'La Doce,Miguel Aleman,Miguel Alemán', 28.8402800, -111.4775000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96255, 'El Diamante (La Retranca)', 'El Diamante (La Retranca)', '', 30.8455600, -112.6397200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96256, 'El Nigromante', 'El Nigromante', '', 22.1537300, -101.7105600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96257, 'Colonia José María Morelos', 'Colonia Jose Maria Morelos', '', 22.3679400, -101.7944900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96258, 'Piedra Gorda', 'Piedra Gorda', 'Piedra Gorda', 22.5075900, -102.3318700, 'MX', '2014-08-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96259, 'Genaro Codina', 'Genaro Codina', 'Genaro Codina,San Jose de la Isla,San José de la Isla', 22.4875500, -102.4575400, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96260, 'General Pánfilo Natera', 'General Panfilo Natera', 'General Panfilo Natera,General Pánfilo Natera', 22.6646100, -102.1100700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96261, 'Pozo de Jarillas', 'Pozo de Jarillas', '', 22.6527900, -102.1978200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96262, 'La Luz', 'La Luz', '', 22.8800000, -102.3102800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96263, 'El Lampotal', 'El Lampotal', '', 22.8958300, -102.4194400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96264, 'General Enrique Estrada', 'General Enrique Estrada', 'General Enrique Estrada', 22.9974700, -102.7425500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96265, 'Las Catarinas', 'Las Catarinas', 'Las Catarinas', 23.0911500, -102.6159700, 'MX', '2014-08-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96266, 'Cañas', 'Canas', 'Canas,Cañas', 23.7436600, -103.2440000, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96267, 'Cerro Gordo', 'Cerro Gordo', 'Cerro Gordo', 21.9744800, -100.8066100, 'MX', '2014-09-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96268, 'Villa Juarez', 'Villa Juarez', 'Villa Juarez', 22.3261700, -100.2668900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96269, 'La Esperanza', 'La Esperanza', 'La Esperanza', 22.0078800, -100.7649600, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96270, 'Los Zacatones', 'Los Zacatones', '', 22.9613900, -102.0555600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96271, 'Dulce Grande', 'Dulce Grande', 'Dulce Grande', 23.0017500, -102.1740500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96272, 'Praxédis Guerrero', 'Praxedis Guerrero', 'Praxedis Guerrero,Praxédis Guerrero', 31.3666700, -106.0166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96273, 'Matamoros', 'Matamoros', 'Mariano Matamoros,Matamoros,Villa Matamoros', 26.7620900, -105.5852300, 'MX', '2016-10-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96274, 'Julimes', 'Julimes', 'Julimes', 28.4237600, -105.4272700, 'MX', '2016-12-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96275, 'José Esteban Coronado', 'Jose Esteban Coronado', 'Coronado', 26.7372200, -105.1583300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96276, 'Ejido Benito Juárez', 'Ejido Benito Juarez', '', 30.1493700, -106.8836200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96277, 'Adolfo López Mateos', 'Adolfo Lopez Mateos', '', 28.4666700, -107.3000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96278, 'Ojo de Agua de Palmillas', 'Ojo de Agua de Palmillas', '', 22.6197200, -105.6038900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96279, 'Cristo Rey', 'Cristo Rey', '', 22.5816700, -105.7244400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96280, 'Tecualilla', 'Tecualilla', '', 22.7666700, -105.6716700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96281, 'Isla del Bosque', 'Isla del Bosque', '', 22.7330600, -105.8455600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96282, 'El Huajote', 'El Huajote', '', 23.1288900, -106.0588900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96283, 'Concordia', 'Concordia', 'Concordia', 23.2869400, -106.0638900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96284, 'Eldorado', 'Eldorado', '', 24.3244400, -107.3672200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96285, 'Las Aguamitas', 'Las Aguamitas', '', 24.5755600, -107.8005600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96286, 'Lo de Jesús (Campo Romero)', 'Lo de Jesus (Campo Romero)', '', 24.6800000, -107.5455600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96287, 'El Limón de los Ramos', 'El Limon de los Ramos', '', 24.9136100, -107.5233300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96288, 'Dautillos', 'Dautillos', 'Dautillos', 24.7216700, -107.9752800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96289, 'Leyva Solano', 'Leyva Solano', 'Gabriel Leyva Solano,Leyva Solano', 25.6616300, -108.6370000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96290, 'El Huitusi', 'El Huitusi', '', 25.5097400, -108.7787500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96291, 'Benito Juárez (Vinatería)', 'Benito Juarez (Vinateria)', '', 25.9737600, -108.8731500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96292, 'El Refugio', 'El Refugio', 'El Refugio', 25.9961900, -109.2999000, 'MX', '2014-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96293, 'Cihuatlán', 'Cihuatlan', '', 19.2366000, -104.5651200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96294, 'Jaboncillo', 'Jaboncillo', 'Jaboncillo', 25.7480900, -103.2655000, 'MX', '2014-04-29', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96295, 'Minas de Barroterán', 'Minas de Barroteran', 'Congregacion Minera,Congregación Minera,Minas de Barroteran,Minas de Barroterán', 27.6514400, -101.2821200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96296, 'Seis de Octubre', 'Seis de Octubre', 'Seis de Octubre', 25.8136100, -103.5733300, 'MX', '2014-04-29', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96297, 'Camalú', 'Camalu', 'Camalu,Camalú', 30.8422200, -116.0632800, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96298, 'Primo Tapia', 'Primo Tapia', '', 32.2222600, -116.9139000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96299, 'Progreso', 'Progreso', '', 32.5803900, -115.5847900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96300, 'Estación Coahuila', 'Estacion Coahuila', '', 32.1930400, -114.9993300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96301, 'Doctor Alberto Oviedo Mota', 'Doctor Alberto Oviedo Mota', 'Alberto Oviedo Mota,Doctor Alberto Oviedo Mota,Ejido Doctor Alberto Oviedo Mota', 32.2275600, -115.1679200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96302, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 32.2892400, -115.1053400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96303, 'Delta', 'Delta', '', 32.3549700, -115.1961700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96304, 'Islas Agrarias Grupo A', 'Islas Agrarias Grupo A', 'Islas Agrarias,Islas Agrarias Grupo A', 32.6109600, -115.3315100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96305, 'Zirándaro', 'Zirandaro', 'Zirandara,Zirandaro,Zirándaro', 18.4776300, -100.9785700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96306, 'Zinapécuaro', 'Zinapecuaro', 'Zinapecuaro,Zinapecuaro de Figueroa,Zinapécuaro,Zinapécuaro de Figueroa', 19.8600600, -100.8285700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96307, 'Zináparo', 'Zinaparo', 'Zinaparo,Zináparo', 20.1725200, -101.9977100, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96308, 'Ixtapa-Zihuatanejo', 'Ixtapa-Zihuatanejo', 'Ixtapa Zihuatanejo,Ixtapa-Zihuatanejo,Jose Azueta,José Azueta,Siuatanekho,ZIH,Zihuatanejo,khwzh azwta  gwyrrw,xi wa ta nei huo,Сиуатанехо,خوزه ازوتا، گوئررو,锡瓦塔内霍', 17.6434400, -101.5521200, 'MX', '2013-12-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96309, 'Zaragoza', 'Zaragoza', 'Zaragoza', 28.4932000, -100.9223000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96310, 'Villa Zaragoza', 'Villa Zaragoza', 'Villa Zaragoza,Villa de Zaragoza,Zaragoza', 22.0371600, -100.7308800, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96311, 'Zapotlanejo', 'Zapotlanejo', 'Zapotlanejo', 20.6224800, -103.0676600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96312, 'Zapotlán del Rey', 'Zapotlan del Rey', '', 20.4663900, -102.9261100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96313, 'Zapotiltic', 'Zapotiltic', '', 19.6274900, -103.4175200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96314, 'El Zapote', 'El Zapote', 'El Zapote,Zapote', 21.1125700, -102.8055500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96315, 'Zapopan', 'Zapopan', 'Gorad Sapapan,Sapopan,Sapopanas,Tzapopan,Zapopan,sa bo pan,sabwban  khalyskw,sapopan,zapwpan  khalyskw,Σαπόπαν,Горад Сапапан,Запопан,Сапопан,زاپوپان، خالیسکو,سابوبان، خاليسكو,საპოპანი,サポパン,萨波潘', 20.7235600, -103.3847900, 'MX', '2013-08-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96316, 'Zamora', 'Zamora', 'Samora-de-Idal''go,ZMM,Zamora,Zamora de Hidalgo,Самора-де-Идальго', 19.9855000, -102.2838700, 'MX', '2017-02-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96317, 'Zacualpan', 'Zacualpan', 'Zacoalpan,Zacoalpán,Zacualpa,Zacualpam,Zacualpan', 21.2471500, -105.1657000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96318, 'Zacualpan', 'Zacualpan', 'Zacualpa,Zacualpan', 17.0889500, -100.3259000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96319, 'Zacoalco de Torres', 'Zacoalco de Torres', 'Zacoalco,Zacoalco de Torre,Zacoalco de Torres', 20.2281600, -103.5687000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96320, 'Zacatecas', 'Zacatecas', 'Altepetl Zacatecah,Sakatekas,ZCL,Zacatecas,Zacatecas City,sa ka te ka si,sakatekaseu,sakatekasu,sqtqs,zakatkas .zakatkas,Сакатекас,Սակատեկաս,סקטקס,زاکاتکاس ٬زاکاتکاس,زاکاٹیکاس,საკატეკასი,サカテカス,萨卡特卡斯,사카테카스', 22.7684300, -102.5814100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96321, 'Zacapú', 'Zacapu', 'Sakapu,Zacapu,Zacapu de Mier,Zacapú,Zacapú de Mier,Сакапу', 19.8139600, -101.7915700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96322, 'Yuriria', 'Yuriria', 'Villa Yuriria,Yuriria', 20.2108100, -101.1321200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96323, 'Yurécuaro', 'Yurecuaro', 'Yurecuaro,Yurécuaro', 20.3360600, -102.2838200, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96324, 'Yerbabuena', 'Yerbabuena', 'Yerbabuena', 20.9631900, -101.2744800, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96325, 'Yavaros', 'Yavaros', 'Isla las Viejas,Yabaros,Yavaros', 26.7048300, -109.5210300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96326, 'Yahualica de González Gallo', 'Yahualica de Gonzalez Gallo', 'Yahualica,Yahualica de Gonzalez Gallo,Yahualica de González Gallo', 21.1797800, -102.8861100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96327, 'Yago', 'Yago', '', 21.8360100, -105.0645100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96328, 'Vista Hermosa de Negrete', 'Vista Hermosa de Negrete', 'Vista Hermosa,Vista Hermosa de Negrete,Vistahermosa de Negrete', 20.2716900, -102.4748800, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96329, 'Villa Unión', 'Villa Union', 'Ejido Villa Union,La Union,La Unión,Rosales,Villa Union,Villa Unión', 28.2222800, -100.7262400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96330, 'Villa Union', 'Villa Union', '', 28.2166700, -100.7166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96331, 'Villa Unión', 'Villa Union', 'Villa Union,Villa Unión', 23.9746000, -104.0470500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96332, 'Villa Unión', 'Villa Union', 'Villa Union,Villa Unión', 23.1899200, -106.2194700, 'MX', '2015-08-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96333, 'Villa Ocampo', 'Villa Ocampo', 'Villa Ocampo', 26.4408500, -105.5064000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96334, 'Villanueva', 'Villanueva', 'Villanueva', 22.3552700, -102.8826400, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96335, 'Villamar', 'Villamar', 'Guarachita,Villamar', 20.0204000, -102.5965500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96336, 'Villa Madero', 'Villa Madero', 'Villa Madero', 19.3915000, -101.2788300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96337, 'Villa Juarez', 'Villa Juarez', 'Irrigacion,Irrigación,Villa Juarez,Villa Juárez', 27.1285100, -109.8392100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96338, 'Villa Juárez', 'Villa Juarez', 'La Trozada,Villa Juarez,Villa Juárez', 21.6891700, -105.3897200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96339, 'Villa Hidalgo', 'Villa Hidalgo', 'Santa Rita,Villa Hidalgo', 22.3568200, -101.7125900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96340, 'Villa Hidalgo', 'Villa Hidalgo', 'Villa Hidalgo', 21.7418500, -105.2309600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96341, 'Villa Hidalgo', 'Villa Hidalgo', 'Paso de Sotos,Raso de Sotos,Villa Hidalgo', 21.6761600, -102.5880300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96342, 'Villa Guerrero', 'Villa Guerrero', 'Villa Guerrero', 21.9834100, -103.5950600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96343, 'Villagrán', 'Villagran', 'El Guaje,Vil''jagran,Villagran,Villagrán,Вильягран', 20.5145200, -100.9974500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96344, 'Villa González Ortega', 'Villa Gonzalez Ortega', 'Carro,El Carro,Villa Gonzalez Ortega,Villa González Ortega', 22.5122200, -101.9161600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96345, 'Villa García', 'Villa Garcia', 'Villa Garcia,Villa García', 22.1616900, -101.9555600, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96346, 'Ciudad Frontera', 'Ciudad Frontera', 'Ciudad Frontera,Frontera,Villa Frontera,Villa-Frontera,Вилла-Фронтера', 26.9281400, -101.4521200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96347, 'Santa Clara del Cobre', 'Santa Clara del Cobre', 'Santa Clara de Portugal,Santa Clara del Cobre,Villa Escalante', 19.4058000, -101.6399800, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96348, 'Villa de Reyes', 'Villa de Reyes', 'Reyes,Villa Reyes,Villa de Reyes', 21.8030900, -100.9341800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96349, 'Villa de Guadalupe', 'Villa de Guadalupe', 'Guadalupe,Raymundo Sanchez,Raymundo Sánchez,Villa de Guadalupe', 23.3738400, -100.7570300, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96350, 'García', 'Garcia', 'Garcia,García,Vil''ja-de-Garsia,Villa de Garcia,Villa de García,Вилья-де-Гарсиа', 25.8120100, -100.5987400, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96351, 'Villa de Cos', 'Villa de Cos', 'Villa de Cos', 23.2932900, -102.3502000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96352, 'Ciudad de Villa de Álvarez', 'Ciudad de Villa de Alvarez', 'Vil''ja-de-Al''vares,Villa de Alvarez,Вилья-де-Альварес', 19.2672200, -103.7377800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96353, 'Villa Corona', 'Villa Corona', 'Tizapanito,Villa Corona', 20.4156400, -103.6641600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96354, 'Villachuato', 'Villachuato', 'Villachuato', 20.1484800, -101.6346000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96355, 'San José Villa de Allende', 'San Jose Villa de Allende', 'Malacatepec Allende,San Jose,San Jose Allende,San Jose Villa de Allende,San José,San José Allende,San José Villa de Allende,Villa Allende,Villa de Allende', 19.3752100, -100.1485000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96356, 'Miguel Ahumada', 'Miguel Ahumada', 'Ahumada,Gonzalez,Villa Ahumada', 30.6186100, -106.5122200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96357, 'El Vegil', 'El Vegil', 'Vegil', 20.4311100, -100.3502400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96358, 'Viesca', 'Viesca', 'Viesca', 25.3392300, -102.8049300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96359, 'El Vergel', 'El Vergel', 'El Vergel,Vergel', 25.6396500, -103.5213900, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96360, 'Ejido Venustiano Carranza', 'Ejido Venustiano Carranza', 'Ejido Venustiano Carranza,Hacienda de Hornos,Venustiano Carranza', 25.3509100, -102.9569800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96361, 'Venustiano Carranza', 'Venustiano Carranza', 'San Pedro Caro,Venustiano Carranza', 20.1155300, -102.6539100, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96362, 'Veinte de Noviembre', 'Veinte de Noviembre', 'Veinte de Noviembre', 25.7119300, -103.3296000, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96363, 'Valtierrilla', 'Valtierrilla', 'Andres Delgado,Andrés Delgado,Pueblo Andres Delgado,Pueblo Andrés Delgado,Valtierrilla', 20.5324400, -101.1276100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96364, 'Valparaíso', 'Valparaiso', 'Val''paraiso,Valparaiso,Valparaíso,falbaraysw,Вальпараисо,فالبارايسو', 22.7710400, -103.5699100, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96365, 'Valle de Santiago', 'Valle de Santiago', 'Ciudad Valle de Santiago,Val''e-de-Sant''jago,Valle de Santiago,Валье-де-Сантьяго', 20.3914000, -101.1922200, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96366, 'Valle de Juárez', 'Valle de Juarez', 'Valle de Juarez,Valle de Juárez', 19.9324800, -102.9435800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96367, 'Valle de Guadalupe', 'Valle de Guadalupe', 'Valle de Guadalupe', 21.0111400, -102.6168300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96368, 'Valle de Bravo', 'Valle de Bravo', 'Temazcaltepec Bravo,Val''e-de-Bravo,Valle de Bravo,Валье-де-Браво,バジェ・デ・ブラボ', 19.1950100, -100.1313200, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96369, 'Valle de Banderas', 'Valle de Banderas', 'Valle de Banderas', 20.8079200, -105.2481300, 'MX', '2014-08-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96370, 'Valle de Allende', 'Valle de Allende', 'Allende,Valle de Allende,Valle de Ignacio Allende,Villa de Allende', 26.9352700, -105.3927100, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96371, 'Valentín Gómez Farías', 'Valentin Gomez Farias', 'Portillo,Valentin Gomez Farias,Valentín Gómez Farías', 28.2166700, -106.5833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96372, 'Valencia de Cerro Gordo', 'Valencia de Cerro Gordo', 'Valencia,Valencia de Cerro Gordo', 20.6013300, -101.0817300, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96373, 'Usmajac', 'Usmajac', 'Usmajac', 19.8745800, -103.5408500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96374, 'Uruapan', 'Uruapan', 'Opstina Uruapan,Opština Uruapan,Ourouapan,UPN,Uruapan,Uruapan del Progreso,awrwapan,uluapan,wu lu a pan,Ουρουάπαν,Уруапан,Уруапан дел Прогресо,اورواپان,烏魯阿潘,우루아판', 19.4111600, -102.0564400, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96375, 'Uriangato', 'Uriangato', 'Puriangato,Uriangato', 20.1408500, -101.1825100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96376, 'Ures', 'Ures', 'Opstina Ures,Opština Ures,Ures,Урес', 29.4270800, -110.3876000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96377, 'Unión de Tula', 'Union de Tula', 'Union de Tula,Unión de Tula', 19.9564600, -104.2680500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96378, 'Unión de San Antonio', 'Union de San Antonio', 'Union de San Antonio,Unión de San Antonio', 21.1271400, -102.0061900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96379, 'Tzitzio', 'Tzitzio', 'Tzitzio,Zitzio', 19.5858200, -100.9247200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96380, 'Tzintzuntzán', 'Tzintzuntzan', 'Tzintzuntzan,Tzintzuntzán', 19.6284700, -101.5783100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96381, 'Tuxpan', 'Tuxpan', 'Tuxpan', 19.5678800, -100.4618900, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96382, 'Tuxpan', 'Tuxpan', 'Tuxpan', 19.5555500, -103.3758700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96383, 'Turicato', 'Turicato', 'Turicato', 19.0540200, -101.4189900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96384, 'Tumbiscatío de Ruiz', 'Tumbiscatio de Ruiz', 'Tumbiscatio,Tumbiscatio de Ruiz,Tumbiscatío de Ruiz', 18.5266700, -102.3782300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96385, 'Tres Mezquites', 'Tres Mezquites', 'Tres Mezquites', 20.2620300, -101.6273500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96386, 'Trapiche de Abra', 'Trapiche de Abra', '', 20.5395800, -103.8197700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96387, 'Trancoso', 'Trancoso', 'Trancoso,Troncoso', 22.7354200, -102.3669700, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96388, 'Tototlán', 'Tototlan', '', 20.5421700, -102.7922200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96389, 'Totatiche', 'Totatiche', 'Totatiche', 21.9284000, -103.4440500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96390, 'Torreon', 'Torreon', 'TRC,Toreon,Toreonas,Torreon,Torreón,toreon,tuo lei weng,twrywn. kwawyla,Τορρεόν,Тореон,Торреон,تورئون٬ کواویلا,ტორეონი,トレオン,托雷翁', 25.5438900, -103.4189800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96391, 'Topolobampo', 'Topolobampo', 'Topolobampo', 25.6008400, -109.0523000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96392, 'Tonila', 'Tonila', '', 19.4336500, -103.5165700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96393, 'Tonaya', 'Tonaya', 'Tonaya', 19.7863400, -103.9712200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96394, 'Tonalá', 'Tonala', 'Opstina Tonala,Opština Tonalá,Tonala,Tonallan,Tonalá,Tōnallān,tuo na la,twnala  khalyskw,Тонала,تونالا، خالیسکو,ტონალა,托納拉', 20.6244500, -103.2342300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96395, 'Tomendán', 'Tomendan', 'Tomendan,Tomendán', 19.3114200, -101.8603000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96396, 'Tomatlán', 'Tomatlan', 'Tomatlan,Tomatlán', 19.9366400, -105.2501000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96397, 'Tolimán', 'Toliman', 'Toliman,Tolimán', 19.6014000, -103.9152200, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96398, 'Todos Santos', 'Todos Santos', 'Todos Santos', 23.4468800, -110.2230800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96399, 'Tlazazalca', 'Tlazazalca', 'Tlazazalca', 19.9708500, -102.0584200, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96400, 'Tlaquepaque', 'Tlaquepaque', 'San Pedro Tlaquepaque,Tlakepake,Tlakepakė,Tlaquepaque,te la ke pa ke,tlakwpakw,torakepake,Тлакепаке,تلاکوپاکو,ტლაკეპაკე,トラケパケ,特拉克帕克', 20.6409100, -103.2932700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96401, 'Tlapehuala', 'Tlapehuala', 'Tlalpehuala,Tlapehuala', 18.2410100, -100.5379000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96402, 'Tlalpujahua de Rayón', 'Tlalpujahua de Rayon', 'Tlalpujahua,Tlalpujahua de Rayon,Tlalpujahua de Rayón', 19.8052300, -100.1740900, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96403, 'Tlalchapa', 'Tlalchapa', 'Talchapa,Tlalchapa', 18.4102700, -100.4762300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96404, 'Tlajomulco de Zúñiga', 'Tlajomulco de Zuniga', 'Tlajomulco,Tlajomulco de Zuniga,Tlajomulco de Zúñiga', 20.4742100, -103.4465400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96405, 'Tlahualilo de Zaragoza', 'Tlahualilo de Zaragoza', 'Tlahualilo,Tlahualilo de Zaragoza,Zaragoza', 26.1059300, -103.4425700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96406, 'Tlacote el Bajo', 'Tlacote el Bajo', 'Tlacote Bajo,Tlacote el Bajo', 20.6613900, -100.5076900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96407, 'Tizapán el Alto', 'Tizapan el Alto', 'Tizapan,Tizapan el Alto,Tizapán el Alto', 20.1613700, -103.0439700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96408, 'Tiquicheo', 'Tiquicheo', 'Tiquicheo', 18.9030100, -100.7373100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96409, 'Tingüindín', 'Tingueindin', 'Tinguindin,Tinguindin de Argandar,Tingüindín,Tingüindín de Argándar', 19.7392100, -102.4812000, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96410, 'Tingambato', 'Tingambato', 'Santiago Tingambato,Tingambato', 19.5010900, -101.8532700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96411, 'Tijuana', 'Tijuana', 'Gorad Tykhuana,TIJ,Tia Juana,Tichouana,Tichuana,Tihuana,Tijuana,Tikhuana,Tikhuanae,Tíjúana,Zaragoza,di hua na,tifuana,tihaw na,tihu''ana,tihuana,tihvana,tikhavana,tykhwana,Τιχουάνα,Горад Тыхуана,Тихуанæ,Тихуана,Тіхуана,טיחואנה,تيخوانا,تیخوانا,तिहुआना,ਤੀਖ਼ਵਾਨਾ,ടീഹ്വാന,ตีฮัวนา,ტიხუანა,ティフアナ,蒂華納,티후아나', 32.5027000, -117.0037100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96412, 'Tierra Nueva', 'Tierra Nueva', 'San Juan,Tierra Nueva,Tierranueva', 21.6690400, -100.5728700, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96413, 'Tierra Blanca', 'Tierra Blanca', 'Tierra Blanca,Tierrablanca', 21.1000600, -100.1593100, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96414, 'Teul de González Ortega', 'Teul de Gonzalez Ortega', 'San Juan Bautista del Teul,Teul,Teul de Gonzalez Ortega,Teul de González Ortega', 21.4634000, -103.4613100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96415, 'Teuchitlán', 'Teuchitlan', 'Teuchitlan,Teuchitlán', 20.6847600, -103.8492000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96416, 'Tesistán', 'Tesistan', 'San Francisco Tesistan,San Francisco Tesistán,Tesistan,Tesistán', 20.8005100, -103.4699300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96417, 'Tequila', 'Tequila', 'Municipio Tequila,Opstina Tequila,Opština Tequila,Santiago de Tequila,Tekila,Tequila,Tequillan,te ji la,tekilla,tekira,tkyla  khalyskw,tykyla,Текила,Текіла,تيكيلا,تکیلا، خالیسکو,ტეკილა,テキーラ,特基拉,테킬라', 20.8820500, -103.8359900, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96418, 'Tepic', 'Tepic', 'Nayarit,TPQ,Tepic,Tepik,Tepikas,Tepīc,te pi ke,tepig,tepiku,tpyq,Тепик,טפיק,ტეპიკი,テピク,特皮克,테픽', 21.5095100, -104.8956900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96419, 'Tepezalá', 'Tepezala', 'Tepezala,Tepezalá', 22.2166700, -102.1666700, 'MX', '2013-08-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96420, 'Tepechitlán', 'Tepechitlan', 'Tepechitlan,Tepechitlán', 21.6706300, -103.3264000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96421, 'Tepec', 'Tepec', 'Tepec', 19.9896400, -103.6411600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96422, 'Tepatitlán de Morelos', 'Tepatitlan de Morelos', 'Tepatitlan,Tepatitlan de Morelos,Tepatitlán de Morelos', 20.8169200, -102.7634700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96423, 'Tepalcatepec', 'Tepalcatepec', 'Tepalcatepec', 19.1866600, -102.8493000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96424, 'Teocuitatlán de Corona', 'Teocuitatlan de Corona', 'Teocuitatlan,Teocuitatlan de Corona,Teocuitatlán de Corona', 20.0922300, -103.3780000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96425, 'Teocaltiche', 'Teocaltiche', '', 21.4342100, -102.5744900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96426, 'Tenería del Santuario', 'Teneria del Santuario', 'Teneria,Teneria del Santuario,Tenería,Tenería del Santuario', 20.5995500, -100.7979000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96427, 'Tenamaxtlán', 'Tenamaxtlan', 'Tenamaxtlan,Tenamaxtlán', 20.2174200, -104.1645900, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96428, 'Temascaltepec de González', 'Temascaltepec de Gonzalez', 'Temascaltepec,Temascaltepec de Gonzalez,Temascaltepec de González', 19.0440900, -100.0423600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96429, 'Tejupilco de Hidalgo', 'Tejupilco de Hidalgo', 'Teiupilco,Tejupilco,Tejupilco de Hidalgo', 18.9047500, -100.1527500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96430, 'Tecuala', 'Tecuala', 'Tecuala', 22.3981500, -105.4580800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96431, 'Técpan de Galeana', 'Tecpan de Galeana', 'Tecpan,Tecpan de Galeana,Tecpan de Galena,Técpan de Galeana', 17.2197600, -100.6303200, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96432, 'Tecomatán', 'Tecomatan', 'Tecomatan,Tecomatán', 20.1151400, -102.4963400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96433, 'Tecoman', 'Tecoman', 'Tecoman,Tekomane,Текомане', 18.9167800, -103.8778600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96434, 'Tecolots', 'Tecolots', '', 32.5666700, -114.9833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96435, 'Tecolotlán', 'Tecolotlan', 'Tecolotan,Tecolotlan,Tecolotlán', 20.2016700, -104.0474800, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96436, 'Tecate', 'Tecate', 'Tecate,Tekate,te ka te,tekate,tkt,Текате,تکت,تیکاتے,テカテ,特卡特,테카테', 32.5671700, -116.6250900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96437, 'Tecalitlan', 'Tecalitlan', 'Tecalitlan,Tecaltitlan,Tecaltitlán', 19.4718200, -103.3072000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96438, 'Teacapan', 'Teacapan', 'Teacapan', 22.5395900, -105.7362300, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96439, 'Tayoltita', 'Tayoltita', 'Tayoltita', 24.1027800, -105.9308300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96440, 'Tarimoro', 'Tarimoro', 'Tarimoro', 20.2870400, -100.7561200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96441, 'Campestre Tarímbaro', 'Campestre Tarimbaro', 'Tarimbaro,Tarímbaro', 19.7750000, -101.1291700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96442, 'Taretán', 'Taretan', 'Taretan,Taretán', 19.3342000, -101.9184900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96443, 'Tarandacuao', 'Tarandacuao', 'Tarandacuao', 20.0009400, -100.5185600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96444, 'Tapeixtles', 'Tapeixtles', 'Tapeixtles', 19.0691200, -104.2833900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96445, 'Tapalpa', 'Tapalpa', 'Tapalpa', 19.9456300, -103.7595400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96446, 'Tanhuato de Guerrero', 'Tanhuato de Guerrero', 'Tanhuato,Tanhuato de Guerrero', 20.2855200, -102.3311300, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96447, 'Tangancícuaro de Arista', 'Tangancicuaro de Arista', 'Tangacicuaro,Tangacícuaro,Tangancicuaro,Tangancicuaro de Arista,Tangancícuaro de Arista', 19.8873300, -102.2063600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96448, 'Tancítaro', 'Tancitaro', 'Tancitaro,Tancitaro de Medellin,Tancítaro,Tancítaro de Medellin', 19.3384300, -102.3626400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96449, 'Tamazula de Gordiano', 'Tamazula de Gordiano', 'Tamazula de Gordiano', 19.6800600, -103.2514000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96450, 'Tamazula', 'Tamazula', '', 25.4463900, -108.4552800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96451, 'Tamándaro', 'Tamandaro', 'Tamandaro,Tamándaro,Taramacuaro,Taramácuaro', 19.9494100, -102.2841600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96452, 'Talpa de Allende', 'Talpa de Allende', 'Talpa,Talpa de Allende', 20.3808400, -104.8221300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96453, 'Tala', 'Tala', 'Opstina Tala,Opština Tala,Tala', 20.6536000, -103.7009200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96454, 'Tacuro (Santa María Tacuro)', 'Tacuro (Santa Maria Tacuro)', '', 19.8569600, -102.0508400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96455, 'Tacoaleche', 'Tacoaleche', 'Tacoaleche,Tacualeche,Tlacoaleche', 22.8201000, -102.4047600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96456, 'Tacámbaro de Codallos', 'Tacambaro de Codallos', 'Tacambaro,Tacambaro de Codallos,Tacambaro de Collados,Tacámbaro de Codallos,Tacámbaro de Collados', 19.2350200, -101.4582400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96457, 'Tabasco', 'Tabasco', 'Garcia de la Cadena,Tabasco,Tabasko,Villa Garcia de la Cadena,Villa García de la Cadena,Villa del Refugio,Табаско', 21.8628600, -102.9110500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96458, 'Susupuato de Guerrero', 'Susupuato de Guerrero', 'Susupuato,Susupuato de Guenero,Susupuato de Guerrero', 19.2150500, -100.4079800, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96459, 'Suchitlán', 'Suchitlan', 'Suchitlan,Suchitlán', 20.5332000, -101.0236000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96460, 'Suchitlán', 'Suchitlan', 'Suchitlan,Suchitlán', 19.3754100, -103.7114100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96461, 'Soyatlán del Oro', 'Soyatlan del Oro', '', 20.3019400, -104.2805600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96462, 'Sonoyta', 'Sonoyta', 'Sonoita,Sonoyta', 31.8616500, -112.8512900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96463, 'Sombrerete', 'Sombrerete', 'Sombrerete', 23.6346600, -103.6424400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96464, 'Soledad de Graciano Sánchez', 'Soledad de Graciano Sanchez', 'Diaz Gutierrez,Diez Gutierrez,Diez Gutiérrez,Díaz Gutiérrez,Soledad Diaz Gutierrez,Soledad Diez Gutierrez,Soledad Díaz Gutiérrez,Soledad Díez Gutiérrez,Soledad de Diez Gutierrez,Soledad de Díez Gutiérrez,Soledad de Graciano Sanchez,Soledad de Graciano Sánchez', 22.1891200, -100.9379200, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96465, 'Socavón (El Carmen)', 'Socavon (El Carmen)', '', 21.8513900, -100.8718400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96466, 'Siqueros', 'Siqueros', 'Siqueros', 23.3417700, -106.2412400, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96467, 'Sinaloa de Leyva', 'Sinaloa de Leyva', 'Cinaloa,Sinaloa,Sinaloa de Leyva,Sinaloita', 25.8219000, -108.2226100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96468, 'Sinahuiza', 'Sinahuiza', 'Sinahuisa,Sinahuiza', 26.9110500, -109.4390100, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96469, 'Silao', 'Silao', 'Silao', 20.9435600, -101.4270300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96470, 'Sevina', 'Sevina', 'Sevina', 19.6289800, -101.9005700, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96471, 'Serrano', 'Serrano', 'Serrano', 20.7783000, -101.3954000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96472, 'Senguio', 'Senguio', 'Sengio,Senguio', 19.7341700, -100.3538500, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96473, 'Sayula', 'Sayula', 'Sayula', 19.8822500, -103.6002700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96474, 'Saucillo', 'Saucillo', 'Saucillo', 28.0305500, -105.2937600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96475, 'Sapioris', 'Sapioris', 'Sapiori,Sapioris', 25.4524800, -103.7161200, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96476, 'San Vicente', 'San Vicente', 'San Vicente', 21.9504300, -105.2971000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96477, 'Santo Tomás de los Plátanos', 'Santo Tomas de los Platanos', 'Nuevo Santo Tomas,Nuevo Santo Tomás,Santo Tomas,Santo Tomas Platanos,Santo Tomas de los Platanos,Santo Tomás de los Plátanos', 19.1817900, -100.2602600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96478, 'Santo Tomás Huatzindeo', 'Santo Tomas Huatzindeo', '', 20.2220500, -100.9206800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96479, 'Santo Tomás', 'Santo Tomas', 'Santo Tomas,Santo Tomás', 19.8452400, -102.0857100, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96480, 'Ejido la Pitahaya (Santo Domingo)', 'Ejido la Pitahaya (Santo Domingo)', '', 21.6061100, -100.7611100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96481, 'Santiaguito (Santiaguito de Velázquez)', 'Santiaguito (Santiaguito de Velazquez)', '', 20.7253300, -102.2371600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96482, 'Santiago Tangamandapio', 'Santiago Tangamandapio', 'Santiago Tangamandapio,Tangamandapio', 19.9556800, -102.4354600, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96483, 'Santiago Papasquiaro', 'Santiago Papasquiaro', 'Santiago Papasquiaro', 25.0438900, -105.4191700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96484, 'Santiago Ixcuintla', 'Santiago Ixcuintla', 'Santiago,Santiago Ixcuintla', 21.8129500, -105.2084400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96485, 'Santiago de Cuenda', 'Santiago de Cuenda', 'Santiago,Santiago Cuenda,Santiago de Cuenda', 20.5995600, -100.9940500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96486, 'Santiago', 'Santiago', 'Sant''jago,Santiago,Villa de Santiago,Сантьяго', 25.4253300, -100.1520500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96487, 'Santiago', 'Santiago', 'Santiago', 22.4547700, -101.4589800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96488, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 22.4973000, -104.7654700, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96489, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 20.9597300, -101.3164400, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96490, 'Santa Rosalia', 'Santa Rosalia', 'Cachania,El Boleo,SRL,Santa Rosalia,Santa Rosalía', 27.3404500, -112.2676100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96491, 'Santa Rosa Jauregui', 'Santa Rosa Jauregui', 'Santa Rosa,Santa Rosa Jauregui,Santa Rosa Jáuregui,Santa Rosa de Jauregui,Santa Rosa de Jáuregui', 20.7412200, -100.4484300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96492, 'José María Morelos (Santa Mónica)', 'Jose Maria Morelos (Santa Monica)', '', 23.6055600, -103.1102800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96493, 'Santa María del Río', 'Santa Maria del Rio', 'Rio,Santa Maria del Rio,Santa María del Río', 21.7961500, -100.7381500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96494, 'Santa María del Oro', 'Santa Maria del Oro', 'El Oro,Santa Maria del Oro,Santa María del Oro', 25.9494400, -105.3644400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96495, 'Santa María del Oro', 'Santa Maria del Oro', 'El Oro,Santa Maria,Santa Maria del Oro,Santa María del Oro', 21.3339000, -104.5869600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96496, 'Santa María de la Paz', 'Santa Maria de la Paz', 'Santa Maria,Santa Maria de la Paz,Santa María,Santa María de la Paz', 21.5116700, -103.4061100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96497, 'Veinte de Noviembre (Santa Lucía)', 'Veinte de Noviembre (Santa Lucia)', '', 25.7892300, -103.1512700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96498, 'José Guadalupe Aguilera (Santa Lucía)', 'Jose Guadalupe Aguilera (Santa Lucia)', '', 24.4542000, -104.7088800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96499, 'Santa Fé de la Laguna', 'Santa Fe de la Laguna', 'Santa Fe,Santa Fe de la Laguna,Santa Fe la Laguna,Santa Fé de la Laguna', 19.6725700, -101.5548700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96500, 'Santa Cruz el Grande', 'Santa Cruz el Grande', 'Santa Cruz,Santa Cruz el Grande,Santa Cruz la Grande', 20.3751400, -102.8638200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96501, 'Santa Cruz del Valle', 'Santa Cruz del Valle', 'Santa Cruz,Santa Cruz del Valle', 20.5333300, -103.4333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96502, 'Santa Cruz de las Flores', 'Santa Cruz de las Flores', 'Santa Cruz,Santa Cruz de las Flores', 20.4805600, -103.5027800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96503, 'Santa Clara', 'Santa Clara', 'Santa Clara', 24.4750000, -103.3569400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96504, 'Santa Catarina de Tepehuanes', 'Santa Catarina de Tepehuanes', 'Santa Catarina de Tepehuanes,Tepehuanes', 25.3396100, -105.7244500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96505, 'Santa Catarina', 'Santa Catarina', '', 25.6732500, -100.4581300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96506, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 26.8038100, -105.8202400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96507, 'Santa Anita', 'Santa Anita', '', 20.5509000, -103.4439600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96508, 'Santa Anita', 'Santa Anita', '', 20.5505600, -103.4400000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96509, 'Santa Ana Zirosto', 'Santa Ana Zirosto', 'Santa Ana Zirosto', 19.5351200, -102.3244200, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96510, 'Santa Ana Pacueco', 'Santa Ana Pacueco', 'Santa Ana,Santa Ana Pacheco,Santa Ana Pacueco', 20.3472200, -102.0158300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96511, 'Santa Ana Maya', 'Santa Ana Maya', 'Santa Ana Maya', 20.0069000, -101.0218900, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96512, 'Santa Ana Amatlán', 'Santa Ana Amatlan', 'Amatlan,Amatlán,Santa Ana,Santa Ana Amatlan,Santa Ana Amatlán', 19.1609700, -102.5405900, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96513, 'Santa Ana', 'Santa Ana', 'Santa Ana', 30.5407500, -111.1188800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96514, 'San Simón de la Laguna', 'San Simon de la Laguna', 'San Simon,San Simon de Laguna,San Simon de la Laguna,San Simón,San Simón de Laguna,San Simón de la Laguna', 19.2927300, -100.0807000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96515, 'San Simón de Guerrero', 'San Simon de Guerrero', 'San Simon de Guerrero,San Simón de Guerrero', 19.0227600, -100.0064500, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96516, 'San Sebastián el Grande', 'San Sebastian el Grande', '', 20.5166700, -103.4166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96517, 'San Roque de Torres', 'San Roque de Torres', 'San Roque,San Roque de Torres', 20.9713800, -101.8529000, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96518, 'San Quintín', 'San Quintin', 'SNQ,Saint-Quentin,San Quintin,San Quintín', 30.5606000, -115.9446400, 'MX', '2017-02-26', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96519, 'San Pedro Piedra Gorda', 'San Pedro Piedra Gorda', 'Ciudad Cuauhtemoc,Ciudad Cuauhtémoc,Cuauhtemoc,Cuauhtémoc,San Pedro,San Pedro Piedra Gorda', 22.4475300, -102.3487500, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96520, 'San Pedro Lagunillas', 'San Pedro Lagunillas', 'Lagunillas,San Pedro,San Pedro Lagunas,San Pedro Lagunillas', 21.2192000, -104.7522800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96521, 'San Pedro Itzicán', 'San Pedro Itzican', 'Itzican,San Pedro Itzican,San Pedro Itzicán,San Pedro Ixcatlan,San Pedro Ixcatlán', 20.3172400, -102.9540600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96522, 'San Pedro de los Naranjos', 'San Pedro de los Naranjos', 'San Pedro,San Pedro de los Naranjos', 20.2283000, -100.9387500, 'MX', '2012-08-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96523, 'San Pedro de Las Colonias', 'San Pedro de Las Colonias', 'San Pedro,San Pedro de Las Colonias', 25.7560200, -102.9838500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96524, 'San Pedro de La Cueva', 'San Pedro de La Cueva', 'San Pedro,San Pedro de La Cueva', 29.2868400, -109.7369600, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96525, 'Apulco', 'Apulco', 'Apulco,San Pedro Apulco', 21.3882400, -102.6821900, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96526, 'San Pedro', 'San Pedro', '', 25.4333300, -103.2166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96527, 'San Patricio', 'San Patricio', 'Melaque,San Patricio', 19.2253400, -104.7044700, 'MX', '2016-02-20', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96528, 'San Nicolás de los Garza', 'San Nicolas de los Garza', 'San Nicolas de los Garsas,San Nicolas de los Garza,San Nicolas de los Garzas,San Nicolás de los Garsas,San Nicolás de los Garza,San Nicolás de los Garzas,San Nikolas de los Garsa,San Nikolas de los Garza,sheng ni gu la si shi,sn nykwlas d lws garza,Сан Николас де лос Гарза,Сан Николас де лос Гарса,سن نیکولاس د لوس گارزا,სან-ნიკოლას-დე-ლოს-გარსა,聖尼古拉斯市', 25.7416700, -100.3022200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96529, 'San Nicolás Tolentino', 'San Nicolas Tolentino', '', 19.1847200, -100.2411100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96530, 'San Miguel Zapotitlan', 'San Miguel Zapotitlan', 'San Miguel,San Miguel Zapotitlan,San Miguel Zapotitlán,Zapotitan,Zapotitán', 25.9483100, -109.0473800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96531, 'San Miguel Octopan', 'San Miguel Octopan', 'Octopan,San Miguel Actopan,San Miguel Octopan', 20.5742800, -100.7478000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96532, 'San Miguel el Alto', 'San Miguel el Alto', 'San Miguel,San Miguel el Alto', 21.0301100, -102.4041400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96533, 'San Miguel de Papasquiaro', 'San Miguel de Papasquiaro', 'Papasquiaro,San Miguel Papasquiaro,San Miguel de Papasquiaro,Santiago Papasquiaro', 24.8307800, -105.3364000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96534, 'San Miguel de Allende', 'San Miguel de Allende', 'San Migel de Aljende,San Migel de Aljendė,San Miguel Allende,San Miguel de Allende,San-Migel''-de-Al''ende,san-migel-de-aliende,sanmigeldeayende,sheng mi ge er de a lian de,sn mygwl d alnd,Сан-Мигель-де-Альенде,Сан-Міґель-де-Альєнде,סן מיגל דה איינדה,سن میگول د الند,სან-მიგელ-დე-ალიენდე,サン・ミゲル・デ・アジェンデ,聖米格爾德阿連德,산미겔데아옌데', 20.9152800, -100.7438900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96535, 'San Martín Hidalgo', 'San Martin Hidalgo', 'San Martin de Hidalgo,San Martín de Hidalgo', 20.4353800, -103.9287800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96536, 'San Marcos', 'San Marcos', 'San Marcos', 25.6666700, -103.0091000, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96537, 'San Marcos', 'San Marcos', 'San Marcos', 20.7926900, -104.1968200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96538, 'San Marcos', 'San Marcos', '', 19.4461100, -103.5063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96539, 'San Luis Río Colorado', 'San Luis Rio Colorado', 'San Luis,San Luis Rio Colorado,San Luis Río Colorado,San-Luis-Rio-Kolorado,UAC,san lwys ryw kwlwradw,sheng lu yi si li ao ke luo la duo,sn lwyys ryw klradw,Сан-Луис-Рио-Колорадо,سان لویس ریو کولورادو,سن لوئیس ریو کلرادو,聖路易斯里奧科羅拉多', 32.4561200, -114.7718600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96540, 'San Luis Potosí', 'San Luis Potosi', 'Altepetl San Luis Potosi,Altepetl San Luis Potosí,Gorad San-Luis-Patasi,SLP,San Louis Potosi,San Luis,San Luis Potosi,San Luis Potosi City,San Luis Potosí,San Luis Potosí City,San-Luis-Potosi,san lwyys pwtwsy  san lwyys pwtwsy,sanlu-iseupotosi,sheng lu yi si bo tuo xi shi,Σαν Λουίς Ποτοσί,Горад Сан-Луіс-Патасі,Сан Луис Потоси,Сан-Луис-Потоси,Սան Լուիս,סן לואיס פוטוסי,سان لوئیس پوتوسی سٹی,سان لوئیس پوتوسی، سان لوئیس پوتوسی,სან-ლუის-პოტოსი,サン・ルイス・ポトシ,圣路易斯波托西市,산루이스포토시', 22.1498200, -100.9791600, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96541, 'San Luis de la Paz', 'San Luis de la Paz', '', 21.2986100, -100.5163900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96542, 'San Luis de la Paz', 'San Luis de la Paz', 'San Luis de la Paz', 21.2977100, -100.5173600, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96543, 'San Luis', 'San Luis', '', 28.4333300, -113.7500000, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96544, 'San Lucas del Pulque', 'San Lucas del Pulque', 'San Lucas,San Lucas del Pulque', 19.1013900, -100.0280600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96545, 'Cabo San Lucas', 'Cabo San Lucas', 'Cabo San Lucas,Kabo San Lukas,Kabo-San-Lukas,San Lucas,kabosanlukaseu,kabw san lwkas,kabw sn lwkas,sanrukasu jia,Кабо Сан Лукас,Кабо-Сан-Лукас,كابو سان لوكاس,کابو سن لوکاس,サンルーカス岬,카보산루카스', 22.8908800, -109.9123800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96546, 'San Lucas Evangelista', 'San Lucas Evangelista', 'San Lucas,San Lucas Evangelista', 20.4081500, -103.3608000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96547, 'San Lucas', 'San Lucas', 'Kabo-San-Lukas,San Lucas,Кабо-Сан-Лукас', 18.5903100, -100.7852900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96548, 'San Julián', 'San Julian', 'San Julian,San Julián', 21.0103500, -102.1796700, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96549, 'San Juan de los Lagos', 'San Juan de los Lagos', 'San Juan de los Lagos', 21.2489300, -102.3303600, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96550, 'San Juan de la Vega', 'San Juan de la Vega', 'San Juan de la Vega', 20.6252100, -100.7614100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96551, 'San Juan de Abajo', 'San Juan de Abajo', '', 20.8148400, -105.1915400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96552, 'San Juan Cosalá', 'San Juan Cosala', 'San Juan,San Juan Cosala,San Juan Cosalá', 20.2875600, -103.3410900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96553, 'San Juan de la Vaquería', 'San Juan de la Vaqueria', '', 25.2533300, -101.2183300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96554, 'Xoconoxtle el Grande', 'Xoconoxtle el Grande', 'El Pueblito,Joconoxtle Grande,San Jose Xoconoxtle,San José Xoconoxtle,Xoconoxtle,Xoconoxtle el Grande', 20.9385700, -100.9814900, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96555, 'San José Temascatío', 'San Jose Temascatio', 'San Jose Temascatio,San José Temascatío,Temascalio,Temascatio,Temaxcatio', 20.6953600, -101.2648700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96556, 'San José Iturbide', 'San Jose Iturbide', 'Alvaro Obregon,Iturbide,San Jose Iturbide,San Jose de Iturbide,San José Iturbide', 21.0015300, -100.3841600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96557, 'San José el Alto', 'San Jose el Alto', 'San Jose el Alto,San José el Alto', 20.6533900, -100.3821800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96558, 'San José de Viñedo', 'San Jose de Vinedo', 'San Jose,San Jose de Vinedo,San José,San José de Viñedo', 25.6486500, -103.4025500, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96559, 'San José del Castillo', 'San Jose del Castillo', 'San Jose del Castillo,San José del Castillo', 20.5140500, -103.2379600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96560, 'San José del Cabo', 'San Jose del Cabo', 'SJD,San Jose del Cabo,San José del Cabo,San Khose del Kabo,San-Khose-del''-Kabo,sana hoje dela kabo,Сан Хосе дел Кабо,Сан-Хосе-дель-Кабо,सान होजे देल काबो', 23.0588800, -109.6977100, 'MX', '2014-08-19', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96561, 'San José de Gracia', 'San Jose de Gracia', 'San Jose de Gracia,San José de Gracia', 20.6747400, -102.5698900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96562, 'San José de Aura', 'San Jose de Aura', 'Aura,San Jose de Aura,San José de Aura', 27.5877800, -101.3725000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96563, 'Estación San José', 'Estacion San Jose', '', 23.1897200, -102.7847200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96564, 'San Jerónimo Totoltepec', 'San Jeronimo Totoltepec', 'San Jeronimo,San Jeronimo Totoltepec,San Jerónimo,San Jerónimo Totoltepec', 19.3149400, -100.2029000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96565, 'San Jerónimo de Juárez', 'San Jeronimo de Juarez', 'San Jeronimo,San Jeronimo de Juarez,San Jerónimo,San Jerónimo de Juárez', 17.1391500, -100.4706700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96566, 'San Jeronimito', 'San Jeronimito', 'El Barrio,San Goronimito,San Jeronimito,San Jeronimo,San Jerónimo', 17.5681800, -101.3456200, 'MX', '2017-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96567, 'San Ignacio de Hidalgo', 'San Ignacio de Hidalgo', 'San Ignacio,San Ignacio Penuelas,San Ignacio Peñuelas,San Ignacio de Penuelas,San Ignacio de Peñuelas', 20.9116700, -101.8605600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96568, 'San Ignacio', 'San Ignacio', 'San Ignacio', 23.9410500, -106.4246700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96569, 'Doctor Miguel Silva (San Guillermo)', 'Doctor Miguel Silva (San Guillermo)', '', 19.9658300, -101.1741700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96570, 'San Gabriel', 'San Gabriel', '', 21.0188000, -103.0141700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96571, 'San Gabriel', 'San Gabriel', 'San Gabriel', 19.7666700, -104.0000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96572, 'Pichátaro', 'Pichataro', 'Pichataro,Pichátaro,Pinchataro,Pinchátaro,San Francisco Pichataro,San Francisco Pichátaro', 19.5728900, -101.8073700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96573, 'San Francisco Peribán', 'San Francisco Periban', 'Periban,San Francisco,San Francisco Periban,San Francisco Peribán', 19.5560100, -102.3984400, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96574, 'San Francisco del Rincón', 'San Francisco del Rincon', 'San Francisco del Rincon,San Francisco del Rincón', 21.0184300, -101.8551500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96575, 'San Francisco de los Romos', 'San Francisco de los Romos', 'San Francisco de Romos,San Francisco de los Romos', 22.0833300, -102.2666700, 'MX', '2013-08-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96576, 'El Oro', 'El Oro', 'El Oro,San Francisco,San Francisco del Oro', 26.8632000, -105.8483800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96577, 'San Francisco de Horizonte (Horizonte)', 'San Francisco de Horizonte (Horizonte)', 'Horizonte,San Francisco de Hoaizonte', 25.9369000, -103.4168800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96578, 'San Felipe', 'San Felipe', 'SFH,San Felipe', 31.0246800, -114.8391900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96579, 'San Felipe de Jesús', 'San Felipe de Jesus', 'San Felipe,San Felipe de Jesus,San Felipe de Jesús', 29.8500000, -110.2333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96580, 'San Felipe Aztatán', 'San Felipe Aztatan', 'San Felipe,San Felipe Aztatan,San Felipe Aztatán', 22.3837400, -105.4198000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96581, 'San Felipe', 'San Felipe', 'Ciudad Doctor Hernandez Alvarez,Ciudad Doctor Hernández Alvarez,Ciudad Gonzales,Doctor Hernandez Alvarez,Gonzales,San Felipe,San Felipe Torres Mochas', 21.4783100, -101.2156600, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96582, 'San Felipe de los Herreros', 'San Felipe de los Herreros', '', 19.6170100, -102.1812800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96583, 'San Diego de la Unión', 'San Diego de la Union', 'Diego de la Union,San Diego de la Union,San Diego de la Unión', 21.4674900, -100.8731000, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96584, 'San Diego de Alejandría', 'San Diego de Alejandria', 'San Diego de Alejandria,San Diego de Alejandría', 20.9937000, -101.9954900, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96585, 'San Cristóbal', 'San Cristobal', 'San Cristobal,San Cristóbal', 20.6578700, -101.4768300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96586, 'Tlaltenango de Sánchez Román', 'Tlaltenango de Sanchez Roman', 'Sanchez Roman,Sánchez Román,Tlaltenango,Tlaltenango de Sanchez Roman,Tlaltenango de Sánchez Román', 21.7822100, -103.3029800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96587, 'San Buenaventura', 'San Buenaventura', 'San Buenaventura', 27.0619300, -101.5489100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96588, 'San Blas', 'San Blas', 'San Blas', 26.0801900, -108.7611000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96589, 'San Blas', 'San Blas', 'San Blas', 21.5433300, -105.2855800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96590, 'Francisco Serrato (San Bartolo)', 'Francisco Serrato (San Bartolo)', 'San Bartolo,Tercera Manzana Francisco Serrato', 19.5068000, -100.2600000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96591, 'San Bartolo', 'San Bartolo', 'San Bartolo', 19.2449600, -100.0532900, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96592, 'San Antonio la Labor', 'San Antonio la Labor', 'San Antonio la Labor', 19.0294200, -102.3007500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96593, 'San Antonio', 'San Antonio', '', 25.6386800, -100.0584400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96594, 'San Andrés Ixtlán', 'San Andres Ixtlan', 'San Andres Ixtlan,San Andrés Ixtlán', 19.8198800, -103.4690600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96595, 'San Andrés Ziróndaro', 'San Andres Zirondaro', 'San Andres,San Andres de Zirondaro,San Andrés,San Andrés de Ziróndaro', 19.6694300, -101.6322100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96596, 'Sanalona', 'Sanalona', '', 24.8022200, -107.1400000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96597, 'San Agustín del Pulque', 'San Agustin del Pulque', 'Agustin,San Agustin,San Agustin del Pulque,San Agustín del Pulque', 19.9626700, -101.0732700, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96598, 'Nicolás R Casillas', 'Nicolas R Casillas', 'Nicolas R Casillas,Nicolás R Casillas,San Agustin,San Agustín', 20.5463800, -103.4662200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96599, 'Salvatierra', 'Salvatierra', 'Ciudad Salvatierra,Sal''vat''erra,Salvatiera,Salvatierra,Сальватьерра', 20.2124900, -100.8792300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96600, 'Tepuxtepec', 'Tepuxtepec', 'Salto de Tepuxtepec,Tepuxtepec', 19.9913500, -100.2256600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96601, 'Saltillo', 'Saltillo', 'SLW,Sal''til''jo,Sal''til''o,Saltil''o,Saltillo,Saltilo,sa er di yue,saltiyo,saltyw,saltyyw  kwawyla,sarutiyo,sltyw,Салтилло,Салтильо,Салтиљо,Сальтильо,Сальтільйо,סלטיו,سالتيو,سالتیو,سالتییو، کواویلا,სალტილიო,サルティーヨ,萨尔蒂约,살티요', 25.4232100, -101.0053000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96602, 'El Salitre', 'El Salitre', '', 20.6659600, -100.4228800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96603, 'Salitral de Carrera', 'Salitral de Carrera', 'Salitral,Salitral de Carreras', 22.8660500, -102.0830500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96604, 'Salinas Victoria', 'Salinas Victoria', 'Salinas Victoria', 25.9632900, -100.2909100, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96605, 'Salinas de Hidalgo', 'Salinas de Hidalgo', 'Salinas,Salinas de Hidalgo,Salinas del Penon Blanco,Salinas del Peñón Blanco', 22.6279500, -101.7141700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96606, 'Salamanca', 'Salamanca', 'Ciudad Salamanca,Salamanca,Salamanka,sa la man ka,salamanka  gwanakhwatw,slamanka  gwanakhwatw,slamnka,Саламанка,سالامانکا، گواناخواتو,سلامانکا، گوآناخوآتو,سلامنكا,薩拉曼卡', 20.5719600, -101.1915400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96607, 'Sain Alto', 'Sain Alto', 'Sain Alto', 23.5808600, -103.2480700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96608, 'Sahuayo de Morelos', 'Sahuayo de Morelos', 'Sahuayo,Sahuayo de Diaz,Sahuayo de Díaz,Sahuayo de Jose Maria Morelos,Sahuayo de José María Morelos,Sahuayo de Morelos,Sahuayo de Porfirio Diaz,Sahuayo de Porfirio Díaz', 20.0585900, -102.7157500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96609, 'Sahuaripa', 'Sahuaripa', 'Sahuaripa', 29.0540800, -109.2339900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96610, 'Sabinas Hidalgo', 'Sabinas Hidalgo', 'Sabinas Hidalgo', 26.5035800, -100.1818700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96611, 'Ciudad Sabinas', 'Ciudad Sabinas', 'Ciudad Sabinas,Sabinas', 27.8559100, -101.1173800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96612, 'Estación Ruiz', 'Estacion Ruiz', 'Estacion Ruiz,Estación Ruiz,Ruiz', 21.9510700, -105.1438000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96613, 'Rosarito', 'Rosarito', 'Ejido Mazatlan El Rosarito,Rosario,Rosarito,Rosarito Beach Baja,Росарито', 32.3604400, -117.0464500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96614, 'El Rosario', 'El Rosario', 'El Rosario,Rosario', 22.9920700, -105.8569700, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96615, 'Rosamorada', 'Rosamorada', 'Rosamorada', 22.1220800, -105.2064000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96616, 'Rosales', 'Rosales', 'Rosales,Santa Cruz de Rosales', 28.1875300, -105.5571700, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96617, 'Roque', 'Roque', 'Molino,Roque', 20.5822800, -100.8372700, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96618, 'Romita', 'Romita', 'Romita', 20.8712700, -101.5168300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96619, 'Romero de Guzmán', 'Romero de Guzman', '', 20.0297400, -102.2587600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96620, 'Rodeo', 'Rodeo', 'Rodeo', 25.1786000, -104.5595000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96621, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', 23.8264700, -103.0303400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96622, 'Rincón de Tamayo', 'Rincon de Tamayo', 'Pueblo Rincon de Tamayo,Rincon,Rincon de Tamayo,Rincón de Tamayo', 20.4240300, -100.7551300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96623, 'Rincón de Romos', 'Rincon de Romos', 'Rincon de Romos,Rincón de Romos,Rinkon-de-Romos,Ринкон-де-Ромос', 22.2281900, -102.3221600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96624, 'Rayones', 'Rayones', 'Rayon,Rayones', 25.0179900, -100.0736200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96625, 'Lázaro Cárdenas (Rancho Grande)', 'Lazaro Cardenas (Rancho Grande)', '', 23.4505600, -102.9625000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96626, 'El Coyote', 'El Coyote', '', 30.8287700, -112.6153100, 'MX', '2017-01-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96627, 'Ramos Arizpe', 'Ramos Arizpe', 'Arizpe,Ramos Arizpe,Ramos-Arispe,SLW,Рамос-Ариспе', 25.5392800, -100.9474200, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96628, 'Quitupán', 'Quitupan', 'Quitupan,Quitupán', 19.9272800, -102.8727100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96629, 'Quiroga', 'Quiroga', 'Quiroga', 19.6655700, -101.5228700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96630, 'Quiriego', 'Quiriego', 'Quiriego', 27.5198700, -109.2523300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96631, 'Quila', 'Quila', 'Quila,Quilla', 24.4236200, -107.2218600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96632, 'Santiago de Querétaro', 'Santiago de Queretaro', 'Ciudad Queretaro,Kepetapo,Kepeтapo,Keretaro,QRO,Queretaro,Queretaro City,Queretarum,Querétaro,Querétaro City,Sant''jago-de-Keretaro,Santiago Tlachco,Santiago nte Keretaro,Santiagu di Queretaro,Santiagu di Querétaro,Santijago de Keretaro,Santjago de Keretaras,Santjago de Keretaro,ke lei ta luo,keletalo,kere ta ro,keretaro,krtarw  krtarw,kwartarw  kwartarw,qrtrw,santiyago de keretaro,santʼiago-de-kʼeretʼaro,Σαντιάγο ντε Κερέταρο,Керетаро,Сантијаго де Керетаро,Сантьяго-де-Керетаро,Сантяго де Керетаро,קרטרו,کرتارو، کرتارو,کوارتارو، کوارتارو,सान्तियागो दे केरेतारो,เกเรตาโร,სანტიაგო-დე-კერეტარო,ケレタロ,克雷塔罗,케레타로', 20.5880600, -100.3880600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96633, 'Estación Queréndaro', 'Estacion Querendaro', 'Estacion Querendaro,Estación Queréndaro,Querendaro,Queréndaro', 19.8828500, -100.9486100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96634, 'Queréndaro', 'Querendaro', 'Querendaro,Queréndaro', 19.8095400, -100.8906000, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96635, 'Quetchehueca', 'Quetchehueca', 'Quechehueca', 27.2636500, -109.9492000, 'MX', '2016-12-23', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96636, 'Puruarán', 'Puruaran', 'Puruaran,Puruarán', 19.0963000, -101.5223400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96637, 'Puruándiro', 'Puruandiro', 'Ciudad Puruandiro,Puruandiro,Puruandiro de Calderon,Puruándiro,Puruándiro de Calderón', 20.0888600, -101.5157900, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96638, 'Purificación', 'Purificacion', '', 19.7173800, -104.6053400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96639, 'Puréparo de Echaíz', 'Pureparo de Echaiz', 'Pureparo de Echaiz,Purepero,Puréparo de Echaíz,Purépero', 19.9103900, -102.0062500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96640, 'Puga', 'Puga', '', 21.5844300, -104.8231800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96641, 'Puerto Vallarta', 'Puerto Vallarta', 'Las Penas,Las Peñas,PVR,Pto Vallarta,Puehrto-Val''jarta,Puerto Valjarta,Puerto Vallarta,ba ya er ta gang,pueleutobayaleuta,pwrtw bayarta  khalyskw,Пуерто Валярта,Пуэрто-Вальярта,پورتو بایارتا، خالیسکو,巴亚尔塔港,푸에르토바야르타', 20.6170000, -105.2301800, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96642, 'Puerto Peñasco', 'Puerto Penasco', 'PPE,Puehrto-Pen''jasko,Puerto Penasco,Puerto Peñasco,Punta Penasca,Punta Penasco,Punta Peñasco,Пуэрто-Пеньяско', 31.3171600, -113.5379900, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96643, 'Puerto Palomas', 'Puerto Palomas', 'Puerto Palomas', 31.7771800, -107.6343900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96644, 'Puerta de Mangos', 'Puerta de Mangos', 'Puerta de Mangos', 21.7185300, -105.3353400, 'MX', '2014-08-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96645, 'Pueblo Yaqui', 'Pueblo Yaqui', 'Pueblo Yaqui', 27.3552100, -110.0344400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96646, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 20.5251600, -101.3719600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96647, 'La Providencia', 'La Providencia', 'La Providencia,Providencia', 28.7226800, -111.5868700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96648, 'Pozos de Gamboa', 'Pozos de Gamboa', 'Pozo Gamboa,Pozo de Gamboa,Pozos de Gamboa', 22.9486100, -102.5701000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96649, 'Potam', 'Potam', 'Potam', 27.6260000, -110.4158000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96650, 'Poncitlán', 'Poncitlan', '', 20.3796300, -102.9255700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96651, 'Poanas', 'Poanas', 'Poanas', 25.7704600, -103.6070700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96652, 'Plateros', 'Plateros', 'Plateros', 23.2292200, -102.8429000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96653, 'Plan de Ayala (Campo Cinco)', 'Plan de Ayala (Campo Cinco)', '', 25.7691000, -109.0412100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96654, 'Pitiquito', 'Pitiquito', 'Pitiquito,Pititquito', 30.6766300, -112.0546600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96655, 'Santa María Pipioltepec (Pipioltepec)', 'Santa Maria Pipioltepec (Pipioltepec)', 'Pipioltepec,Santa Maria', 19.2405600, -100.0975000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96656, 'Pinos', 'Pinos', 'Pinos', 22.2957100, -101.5757900, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96657, 'Pihuamo', 'Pihuamo', 'Piguama,Piguamo', 19.2499100, -103.3827500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96658, 'Piedras Negras', 'Piedras Negras', 'PDS,Piedras Negras,Piedrasnegras,پیئدراس نیگراس، كواہويلا', 28.7000700, -100.5235300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96659, 'Picardías', 'Picardias', 'Estacion Picardias,Estación Picardías,Picardias,Picardías', 25.3246600, -103.4858800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96660, 'Petatlán', 'Petatlan', 'Petatlan,Petatlán,Petlatlan,Petlatlán,Potatlan,Петатлан', 17.5376800, -101.2679800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96661, 'Pesquería', 'Pesqueria', 'Pesqueria,Pesqueria Chica,Pesqueria Chico,Pesquería,Pesquería Chica,Pesquería Chico', 25.7854300, -100.0509800, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96662, 'Pesqueira', 'Pesqueira', '', 29.3797200, -110.8961100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96663, 'Pericos', 'Pericos', '', 22.0492500, -105.3540200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96664, 'Peribán de Ramos', 'Periban de Ramos', 'Periban,Periban de Ramos,Peribán de Ramos', 19.5201000, -102.4139700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96665, 'Peñón Blanco', 'Penon Blanco', 'Penon Blanco,Peñón Blanco', 24.7928900, -104.0265900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96666, 'Pénjamo', 'Penjamo', 'Panjamo,Penjamo,Pánjamo,Pénjamo', 20.4310800, -101.7226100, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96667, 'Penjamillo de Degollado', 'Penjamillo de Degollado', 'Penjamillo,Penjamillo de Degollado', 20.1041000, -101.9344400, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96668, 'Pedro Escobedo', 'Pedro Escobedo', 'Pedro Escobedo', 20.4996300, -100.1427800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96669, 'Pedernales', 'Pedernales', 'Pedernales', 19.1413300, -101.4688900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96670, 'Pátzcuaro', 'Patzcuaro', 'Packuaro,Patzcuaro,Pátzcuaro,pats kwa ro,Пацкуаро,ปัตซ์กวาโร', 19.5159400, -101.6088700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96671, 'Patuán', 'Patuan', 'Patuan,Patuán', 19.3923100, -101.9165100, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96672, 'Pastoría', 'Pastoria', 'Pastoria,Pastoría', 22.4861500, -102.0818400, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96673, 'Paso de Hidalgo (Paso de Álamos)', 'Paso de Hidalgo (Paso de Alamos)', '', 20.2727800, -102.5452800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96674, 'Parras de la Fuente', 'Parras de la Fuente', 'Parras,Parras de la Fuente,Паррас', 25.4418500, -102.1780800, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96675, 'El Paredoncito', 'El Paredoncito', 'El Paredoncito,El Tobari,El Tóbari,Paredoncito', 27.0592000, -109.9128600, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96676, 'Parácuaro', 'Paracuaro', '', 20.1447300, -100.7621100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96677, 'Paracho de Verduzco', 'Paracho de Verduzco', 'Paracho,Paracho de Verduzco', 19.6474500, -102.0489700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96678, 'Pánuco de Coronado', 'Panuco de Coronado', 'Panuco,Panuco de Coronado,Pánuco de Coronado', 24.5397200, -104.3270700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96679, 'Panindícuaro', 'Panindicuaro', 'Panindicuaro,Panindicuaro de la Reforma,Panindícuaro,Panindícuaro de la Reforma,Punindicuaro,Punindícuaro', 19.9851800, -101.7609600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96680, 'Palo Alto', 'Palo Alto', 'Palo Alto', 21.9180100, -101.9645300, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96681, 'Palmito del Verde', 'Palmito del Verde', 'Isla de Palmito del Verde,Palmarito del Verde,Palmito,Palmito Verde,Palmito del Verde', 22.6586100, -105.7711100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96682, 'Palau', 'Palau', 'Palahu,Palahú,Palau', 27.8923200, -101.4231900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96683, 'Pajacuarán', 'Pajacuaran', 'Pajacuaran,Pajacuarán', 20.1190900, -102.5662300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96684, 'Pabellón de Hidalgo', 'Pabellon de Hidalgo', 'Pabellon,Pabellon de Arteaga,Pabellon de Hidalgo,Pabellón,Pabellón de Arteaga,Pabellón de Hidalgo', 22.1787100, -102.3401400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96685, 'San José de Gracia', 'San Jose de Gracia', 'Ornelas,San Jose de Gracia,San José de Gracia', 19.9896600, -103.0219800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96686, 'Orduña de Abajo', 'Orduna de Abajo', '', 20.7580600, -100.7827800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96687, 'Oquitoa', 'Oquitoa', 'Oquitoa', 30.7419700, -111.7346300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96688, 'Opopeo', 'Opopeo', 'Opopeo', 19.4116300, -101.6051500, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96689, 'Ojuelos de Jalisco', 'Ojuelos de Jalisco', 'Ojuelos de Jalisco', 21.8661400, -101.5926900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96690, 'Ojo Caliente', 'Ojo Caliente', 'Ojo Caliente', 21.8467800, -100.7537500, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96691, 'Ojinaga', 'Ojinaga', 'Fuerte del Norte,Ojinaga,Presidio del Juntas,Presidio del Norte,Villa de Ojinaga', 29.5668900, -104.5448700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96692, 'Ocotlán', 'Ocotlan', 'Ocotlan,Ocotlán', 20.3553000, -102.7735800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96693, 'Ocho de Enero', 'Ocho de Enero', '', 26.9955800, -101.4975500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96694, 'Ocampo', 'Ocampo', 'Ocampo,Villa Ocampo', 27.3147700, -102.3966000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96695, 'Ocampo', 'Ocampo', 'Ocampo', 21.6465300, -101.4801200, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96696, 'Ocampo', 'Ocampo', 'Ocampo', 19.5824100, -100.3391300, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96697, 'Obrajuelo', 'Obrajuelo', 'Obrajuelo,Obrajuelos', 20.1085400, -100.8494300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96698, 'Numarán', 'Numaran', 'Aumaran,Aumarán,Numaran,Numarán', 20.2558000, -101.9498800, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96699, 'Nuevo Zirosto', 'Nuevo Zirosto', '', 19.5480600, -102.3483300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96700, 'Nuevo Urecho', 'Nuevo Urecho', 'Nuevo Urecho', 19.1660200, -101.8681600, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96701, 'Nuevo San Juan Parangaricutiro', 'Nuevo San Juan Parangaricutiro', 'Nuevo San Juan Parangaricutiro', 19.4185700, -102.1308700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96702, 'Nuevo México', 'Nuevo Mexico', 'Nuehvo-Meksiko,Nuevo Mexico,Nuevo México,Нуэво-Мексико', 20.7565000, -103.4429700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96703, 'Nuevo Ideal', 'Nuevo Ideal', 'Nuevo Ideal,Patos', 24.8854400, -105.0755200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96704, 'Churumuco de Morelos', 'Churumuco de Morelos', 'Churumuco,Churumuco de Morelos,Nuevo Churumuco', 18.6633300, -101.6474100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96705, 'Nuevo Casas Grandes', 'Nuevo Casas Grandes', 'NCG,Nuehvo-Kasas-Grandes,Nueva Casa Grande,Nueva Casas Grandes,Nuevo Casas Grandes,Нуэво-Касас-Грандес', 30.4155200, -107.9116600, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96706, 'Nueva Rosita', 'Nueva Rosita', 'Nuehva-Rosita,Nueva Rosita,Rosita,Нуэва-Росита', 27.9402800, -101.2181200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96707, 'Nueva Italia de Ruiz', 'Nueva Italia de Ruiz', 'Nueva Italia,Nueva Italia de Ruiz,Villa de Nueva Italia de Ruiz', 19.0249200, -102.0931800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96708, 'Santa Cruz', 'Santa Cruz', 'Noria de Santa Cruz,Santa Cruz', 31.2336200, -110.5961800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96709, 'Nombre de Dios', 'Nombre de Dios', 'Nombre de Dios', 23.8489100, -104.2471200, 'MX', '2015-01-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96710, 'Nocupétaro', 'Nocupetaro', 'Nocupetaro,Nocupétaro', 19.0439200, -101.1618700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96711, 'Nochistlán de Mejía', 'Nochistlan de Mejia', 'Nochistlan,Nochistlan de Mejia,Nochistlán,Nochistlán de Mejía', 21.3643500, -102.8459000, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96712, 'Nieves', 'Nieves', 'Francisco R. Murguia,Las Nieves,Nieves', 23.9960900, -103.0201300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96713, 'Nazas', 'Nazas', 'Nazas', 25.2246200, -104.1145800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96714, 'Nazas', 'Nazas', 'Nazas', 25.2275000, -104.1138900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96715, 'Nazareno', 'Nazareno', '', 25.3991600, -103.4206500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96716, 'Navolato', 'Navolato', 'Navolato', 24.7661000, -107.7022500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96717, 'Navojoa', 'Navojoa', 'Navoioa,Navojoa,Navokhoa,na wo hua,nawwkhwa,nawwywa,Навохоа,ناووخوا,ناوویوا,納沃華', 27.0702800, -109.4437200, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96718, 'Nava', 'Nava', 'Nava', 28.4207100, -100.7656500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96719, 'El Naranjillo', 'El Naranjillo', '', 20.7141700, -101.0005600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96720, 'Naranja de Tapia', 'Naranja de Tapia', 'Naranja,Naranja de Tapia', 19.7770800, -101.7594700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96721, 'Naica', 'Naica', 'Naica', 27.8573600, -105.4923300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96722, 'Nahuatzén', 'Nahuatzen', 'Nahuatzen,Nahuatzén', 19.6550600, -101.9170400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96723, 'Nacozari Viejo', 'Nacozari Viejo', 'Nacozari,Nacozari Viejo,Nacozari de Garcia,Nacozari de García', 30.4000000, -109.6500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96724, 'Naco', 'Naco', 'Maco,Naco', 31.3270100, -109.9466900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96725, 'Mulegé', 'Mulege', 'MUG,Mulege,Mulegé,Muleje,Mulejé', 26.8914100, -111.9826000, 'MX', '2017-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96726, 'Moroleón', 'Moroleon', 'Moroleon,Moroleón', 20.1257100, -101.1920800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96727, 'Morelos', 'Morelos', 'Morelos', 28.4067600, -100.8885400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96728, 'Morelos', 'Morelos', 'Morelos', 22.8621500, -102.6106100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96729, 'Morelia', 'Morelia', 'MLM,Morelia,Morelija,mo lei li ya,molellia,morelia,moreria,mwrlya  mychwakan,mwrlyh,mwrylya,mx re leiy,Морелия,Морелија,Морелія,Մորելիա,מורליה,مورلیا، میچوآکان,موريليا,موریلیا,มอเรเลีย,მორელია,モレリア,莫雷利亚,모렐리아', 19.7007800, -101.1844300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96730, 'Morales', 'Morales', 'Morales', 20.7782100, -100.8093200, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96731, 'Monterrey', 'Monterrey', 'Gorad Mantehrehj,MTY,Mons Regis,Monterej,Monterejo,Monterejus,Monterey,Monterrei,Monterrej,Monterreja,Monterrey,Monterrey City,Monterrey i Nuevo Leon,Monterrey i Nuevo León,Monterėjus,Tlahtoantepec,Tlahtoāntepēc,mamtere,meng te lei,montelei,montere''i,monterei,mwntry,mwntryy,mwntyry,mxn terrey,Μοντερρέι,Горад Мантэрэй,Монтерей,Монтереј,Монтеррей,Մոնտերեյ,מונטריי,مونتری,مونتيري,مونتےرئی,माँतेरे,ਮੋਂਤੇਰੇਈ,มอนเตร์เรย์,མཱོན་ཊི་རེ།,მონტერეი,モンテレイ,蒙特雷,몬테레이', 25.6750700, -100.3184700, 'MX', '2014-02-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96732, 'Monte Escobedo', 'Monte Escobedo', 'Monte Escobedo', 22.3036200, -103.5675100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96733, 'Monclova', 'Monclova', 'LOV,Monclova,Monklova,meng ke luo wa,mwnklwwa,Монклова,مونکلووا,蒙克洛瓦', 26.9068700, -101.4205600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96734, 'Mompaní', 'Mompani', 'Mompani,Mompaní,Monpane,Nompani,Nompaní', 20.6921400, -100.5067900, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96735, 'Momax', 'Momax', 'Momax', 21.9226000, -103.3130700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96736, 'Moctezuma', 'Moctezuma', 'Moctezuma', 29.8061500, -109.6794900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96737, 'Moctezuma', 'Moctezuma', 'Moctezuma', 22.7478700, -101.0821900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96738, 'Mocorito', 'Mocorito', 'Mocorito', 25.4820200, -107.9200800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96739, 'Mochicahui', 'Mochicahui', 'Mochicahui', 25.9509500, -108.9299100, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96740, 'Mixtlán', 'Mixtlan', 'Mixtlan,Mixtlán', 20.4390000, -104.4086700, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96741, 'Mineral de Angangueo', 'Mineral de Angangueo', 'Angangueo', 19.6205600, -100.2843600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96742, 'Minatitlán', 'Minatitlan', 'El Mamey,Minatitlan,Minatitlán', 19.3666700, -104.0666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96743, 'Mina', 'Mina', '', 26.0011000, -100.5298800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96744, 'Miguel Auza', 'Miguel Auza', 'Miguel Auza,San Miguel Mezquital,San Miguel del Mezquital', 24.2942100, -103.4509000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96745, 'Mezquital del Oro', 'Mezquital del Oro', 'Mezquital,Mezquital del Oro', 21.2166700, -103.3627800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96746, 'Mezcala', 'Mezcala', '', 20.9527800, -102.8461100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96747, 'Mezcala', 'Mezcala', 'Mexcala,Mezcala', 20.9497000, -102.8472500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96748, 'Mexticacán', 'Mexticacan', 'Mexticaoan', 21.2653800, -102.7798500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96749, 'Mexicali', 'Mexicali', 'Gorad Mekhikali,MXL,Mekhikali,Meksikalis,Mexicali,Mexicali i Baja California,Mexihcali,Mexikali,me khi kali,megsikalli,mehikari,mkhykaly,mksykaly,mo xi ka li,mqsyqly,myksykaly,Μεξικάλι,Горад Мехікалі,Мехикали,Мехікалі,מקסיקלי,مخیکالی,مكسيكالي,میکسیکالی,เมคีกาลี,მეხიკალი,メヒカリ,墨西卡利,멕시칼리', 32.6278100, -115.4544600, 'MX', '2014-10-17', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96750, 'Mesillas', 'Mesillas', 'Mesillas', 23.2465200, -106.0478300, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96751, 'Meoqui', 'Meoqui', 'Meoqui,Pedro Meoqui', 28.2722600, -105.4804600, 'MX', '2016-12-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96752, 'Menores', 'Menores', '', 20.9202800, -101.3950000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96753, 'Melchor Múzquiz', 'Melchor Muzquiz', 'Melchor Muzquiz,Melchor Múzquiz,Mozquiz,Muzguiz,Muzquiz', 27.8793300, -101.5161500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96754, 'Medina', 'Medina', '', 21.1497200, -101.6225000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96755, 'Mazatlán', 'Mazatlan', 'Ciudad Mazatlan,Ciudad Mazatlán,MZT,Macatlan,Masatlan,Masatlanas,Mazatlan,Mazatlán,ma sa te lan,masateullan,masatlan,masatoran,mzatlan  synalwa,Μαζατλάν,Мазатлан,Масатлан,Мацатлан,מסטלאן,ماساتلان,مزاتلان، سینالوآ,მასატლანი,マサトラン,馬薩特蘭,마사틀란', 23.2329000, -106.4062000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96756, 'Mazamitla', 'Mazamitla', 'Mazamitla', 19.9161000, -103.0202700, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96757, 'Matehuala', 'Matehuala', 'Matehuala,Mateuala,Матеуала', 23.6482400, -100.6433400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96758, 'Matanzas', 'Matanzas', '', 21.6333300, -101.6552800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96759, 'Matancillas (San Isidro Matancillas)', 'Matancillas (San Isidro Matancillas)', '', 21.8903600, -101.6505900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96760, 'Matamoros', 'Matamoros', 'Matamoros,Matamoros de la Laguna,Матаморос', 25.5269900, -103.2285000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96761, 'Mascota', 'Mascota', 'Mascota', 20.5261300, -104.7878100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96762, 'Hacienda de Márquez', 'Hacienda de Marquez', 'Ex Hacienda de Marquez,Ex Hacienda de Márquez,Marques,Marquez,Márquez', 20.7803700, -101.3597900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96763, 'Marín', 'Marin', 'Marin,Marín', 25.8794600, -100.0302800, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96764, 'Jesús Gómez Portugal', 'Jesus Gomez Portugal', 'Jesus Gomez Portugal,Jesús Gómez Portugal,Margaritas', 21.9960700, -102.2909500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96765, 'Margaritas', 'Margaritas', '', 20.4530600, -102.4741700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96766, 'Marfil', 'Marfil', 'Marfil', 20.9916500, -101.2843400, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96767, 'Maravatío de Ocampo', 'Maravatio de Ocampo', 'Maravatio,Maravatio de Ocampo,Maravatío,Maravatío de Ocampo', 19.8911300, -100.4444300, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96768, 'Mapimí', 'Mapimi', 'Mapimi,Mapimí', 25.8338000, -103.8461000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96769, 'Manzanillo', 'Manzanillo', 'Cozcatlan,Cōzcatlān,Mansanil''o,Manzanillo,ZLO,man sa ni yue,mansaniyo,manzanylw,mnsnyw,Мансанильо,מנסניו,مانزانیلو,曼萨尼约,만사니요', 19.1169500, -104.3421400, 'MX', '2014-02-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96770, 'Rodolfo Sánchez Taboada', 'Rodolfo Sanchez Taboada', 'El Maneadero,Maneadero,Rodolfo Sanchez Taboada,Rodolfo Sánchez Taboada', 31.7209900, -116.5718400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96771, 'Malagana (San Antonio del Monte)', 'Malagana (San Antonio del Monte)', 'Malagana,San Antonio del Monte', 21.0467000, -101.7535000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96772, 'Magdalena de Kino', 'Magdalena de Kino', 'Magdalena,Magdalena de Kino,Magdalena-de-Kino,Магдалена-де-Кино', 30.6278900, -110.9620300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96773, 'Magdalena', 'Magdalena', 'Magdalena', 20.9074100, -103.9780000, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96774, 'Madrid', 'Madrid', 'Madrid', 19.0845900, -103.8712300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96775, 'San Pedro Madera', 'San Pedro Madera', 'Ciudad Madera,Madera,San Pedro Madera', 29.1936600, -108.1468400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96776, 'Macapule', 'Macapule', 'Macapul,Macapule', 25.8860700, -109.1482000, 'MX', '2014-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96777, 'Luvianos', 'Luvianos', '', 18.9166700, -100.4000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96778, 'Luis Moya', 'Luis Moya', 'Adame,Luis Moya,San Francisco,San Francisco de los Adame', 22.4323700, -102.2486400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96779, 'Los Tepames', 'Los Tepames', 'Los Tepames,Tepames', 19.0938900, -103.6225000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96780, 'Los Pocitos', 'Los Pocitos', '', 20.5372400, -103.9372100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96781, 'Los Pilares', 'Los Pilares', 'Los Pilares', 20.3258200, -102.3732200, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96782, 'Los Nogales', 'Los Nogales', 'Los Nogales', 19.8573400, -102.1561200, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96783, 'Los Mochis', 'Los Mochis', 'LMM,Los Mochis,Los-Mochis,Mochis,los-mochisi,loseumochiseu,luo si mo qi si,lws mwchys,lws mwzys,rosumochisu,Лос Мочис,Лос-Мочис,לוס מוציס,لوس موچیس,ლოს-მოჩისი,ロスモチス,洛斯莫奇斯,로스모치스', 25.7930200, -108.9980800, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96784, 'Los Hoyos', 'Los Hoyos', 'Colonia Sur,Los Hoyos', 30.1244400, -109.7822200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96785, 'Los Algodones', 'Los Algodones', 'Los Algodones', 32.7000000, -114.7333300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96786, 'Loreto', 'Loreto', 'LTO,Loreto,loleto,luo lei tuo,roreto,Лорето,ロレト,洛雷托,로레토', 26.0121700, -111.3488800, 'MX', '2014-11-26', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96787, 'Loreto', 'Loreto', 'Loreto', 22.2724800, -101.9889800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96788, 'Lombardía', 'Lombardia', '', 19.1580600, -102.0511100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96789, 'Loma Pelada', 'Loma Pelada', 'Loma,Loma Parada', 20.5722200, -101.2941700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96790, 'Lo de Marcos', 'Lo de Marcos', '', 20.9569400, -105.3533300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96791, 'Lo Arado', 'Lo Arado', '', 19.6213900, -104.5344400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96792, 'León de los Aldama', 'Leon de los Aldama', 'BJX,Ciudad de Leon,Ciudad de León,Leon,Leon Guanajuato,Leon de los Aldama,Leon de los Aldamas,León,León de los Aldama,León de los Aldamas,reon,レオン', 21.1290800, -101.6737400, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96793, 'La Ventilla', 'La Ventilla', 'Ventilla', 21.7738900, -101.0302800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96794, 'La Venta del Astillero', 'La Venta del Astillero', '', 20.7279500, -103.5450900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96795, 'La Unión', 'La Union', '', 26.8196100, -109.6083100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96796, 'La Unión', 'La Union', 'La Union,La Unión', 17.9856100, -101.8065500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96797, 'La Trinidad', 'La Trinidad', 'La Trinidad', 25.7336700, -108.4840900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96798, 'San Nicolás de la Torre', 'San Nicolas de la Torre', 'La Torre,San Nicolas de la Torre', 20.0780600, -100.1013900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96799, 'La Tijera', 'La Tijera', '', 19.9000000, -104.4000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96800, 'Las Varas', 'Las Varas', 'Las Varas', 21.1802100, -105.1359500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96801, 'Trincheras', 'Trincheras', 'Las Trincheras,Trincheras', 30.3980600, -111.5301900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96802, 'San José Tepuzas', 'San Jose Tepuzas', 'Las Tepuzas,Tepuzas', 20.3541700, -100.3752800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96803, 'Las Quemazones', 'Las Quemazones', 'Las Quemazones', 25.6858300, -108.4524300, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96804, 'Las Pintas de Arriba', 'Las Pintas de Arriba', '', 20.5737600, -103.3234500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96805, 'Las Juntas', 'Las Juntas', 'Las Juntas', 19.4306100, -104.7064600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96806, 'Las Cuevas', 'Las Cuevas', 'Las Cuevas', 25.4981500, -103.5495000, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96807, 'Rosa Blanca', 'Rosa Blanca', 'La Rosa Blanca,Rosa Blanca', 21.1245400, -104.3581100, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96808, 'La Reforma', 'La Reforma', 'La Reforma,Peonia,Peonía', 25.0816400, -108.0567300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96809, 'Quesería', 'Queseria', 'La Queseria,La Quesería,Queseria,Quesería', 19.3870800, -103.5724300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96810, 'La Pila', 'La Pila', 'La Pila,Pila', 22.0342500, -100.8678600, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96811, 'La Piedad', 'La Piedad', 'La Piedad,La Piedad Cabadas,La Piedad Cavadas,La Piedad de Cabadas,Municipio La Piedad', 20.3423900, -102.0305000, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96812, 'La Pendencia', 'La Pendencia', 'La Pendencia,Pendencia', 22.4377800, -101.5758300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96813, 'La Paz', 'La Paz', 'LAP,La Paz,La-Pas,Paz,Ла-Пас', 24.1443700, -110.3005000, 'MX', '2015-08-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96814, 'La Palma', 'La Palma', 'La Palma,Palma', 20.5221900, -100.1739200, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96815, 'La Orilla', 'La Orilla', '', 17.9958300, -102.2269400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96816, 'Lampazos de Naranjo', 'Lampazos de Naranjo', 'Lampazos,Lampazos de Naranjo,Lampozos de Naranjo', 27.0254900, -100.5052800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96817, 'La Moncada', 'La Moncada', 'La Moncada,Moncada', 20.2829700, -100.8059000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96818, 'La Mira Tumbiscatio', 'La Mira Tumbiscatio', 'La Mira,La Mira Tumbiscatio', 18.6833300, -102.2833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96819, 'La Manzanilla de la Paz', 'La Manzanilla de la Paz', 'La Manzanilla de la Paz', 20.0049500, -103.1545600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96820, 'Lamadrid', 'Lamadrid', 'Lamadrid', 27.0494400, -101.7938900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96821, 'La Loma (La Loma de Quila)', 'La Loma (La Loma de Quila)', 'La Loma,Loma', 24.3806100, -107.2264900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96822, 'La Lira', 'La Lira', 'La Lira,Lira', 20.4755400, -100.1614500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96823, 'La Libertad', 'La Libertad', 'La Libertad,Puerto Libertad,Puerto de la Libertad', 29.9131300, -112.6917900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96824, 'La Libertad', 'La Libertad', 'La Libertad,Libertad', 21.5934700, -105.1736500, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96825, 'La Labor', 'La Labor', 'La Labor,Labor', 20.5338800, -100.7020000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96826, 'Ejido la Joya', 'Ejido la Joya', '', 21.1432500, -101.7392200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96827, 'La Jarretadera', 'La Jarretadera', '', 21.9250100, -105.0403100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96828, 'La Huerta', 'La Huerta', 'La Huerta', 19.4844000, -104.6437800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96829, 'La Huacana', 'La Huacana', 'Huacana,La Huacana', 18.9631200, -101.8072000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96830, 'La Higuera', 'La Higuera', 'Higuera,La Higuera', 19.4235400, -103.4097100, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96831, 'Lagunillas', 'Lagunillas', 'Lagunillas', 19.5627100, -101.4158200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96832, 'Lagos de Moreno', 'Lagos de Moreno', 'LOM,Lagos de Moreno', 21.3566600, -101.9376800, 'MX', '2016-06-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96833, 'La Goma', 'La Goma', 'La Goma', 25.4846000, -103.6888400, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96834, 'La Fuente', 'La Fuente', 'La Fuente', 20.5525500, -100.0359100, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96835, 'La Flor', 'La Flor', '', 25.6813800, -103.3683700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96836, 'La Estancia', 'La Estancia', 'Estancia,La Estancia', 20.4212300, -100.0661600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96837, 'La Estacada', 'La Estacada', 'Estacada,La Estacada', 20.8215100, -100.4076300, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96838, 'San José de la Era', 'San Jose de la Era', '', 22.8507300, -102.4223900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96839, 'La Cruz', 'La Cruz', 'La Cruz', 23.9212600, -106.8925000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96840, 'La Ciudad', 'La Ciudad', 'La Ciudad', 23.7305200, -105.6888200, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96841, 'La Cañada', 'La Canada', 'Canada,Cañada,El Marques,La Canada,La Cañada', 20.6080500, -100.3327500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96842, 'La Calera', 'La Calera', 'Calera de Rivera,La Calera,Las Caleras', 20.8011900, -101.3320700, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96843, 'La Brecha', 'La Brecha', 'Brecha,La Brecha', 25.3707800, -108.4192200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96844, 'La Barca', 'La Barca', 'La Barca', 20.2878400, -102.5451400, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96845, 'Banderas del Águila', 'Banderas del Aguila', 'Banderas,Banderas del Aguila,Banderas del Águila,La Bandera', 23.9259600, -105.3395000, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96846, 'Puente Grande', 'Puente Grande', 'La Aurora,Puente Grande', 20.5697700, -103.1537700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96847, 'La Angostura', 'La Angostura', '', 20.1963900, -102.4416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96848, 'La Aldea', 'La Aldea', 'Aldea,Balmaceda,La Aldea', 20.9016600, -101.4785200, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96849, 'Santa Cruz de Juventino Rosas', 'Santa Cruz de Juventino Rosas', 'Juventino Rosas,Opstina Santa Cruz de Juventino Rosas,Opština Santa Cruz de Juventino Rosas,Santa Cruz de Juventino Rosas,Santa-Krus-de-Khuventino-Rosas,Villa Santa Cruz Galeana,Санта-Крус-де-Хувентино-Росас', 20.6433700, -100.9928600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96850, 'Jungapeo de Juárez', 'Jungapeo de Juarez', 'Jungapeo,Jungapeo de Juarez,Jungapeo de Juárez', 19.4591500, -100.4948300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96851, 'Julimes', 'Julimes', '', 28.4230600, -105.4305600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96852, 'Juchitlán', 'Juchitlan', 'Juchitlan,Juchitlán', 20.0855700, -104.0986700, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96853, 'Juchipila', 'Juchipila', '', 21.4086200, -103.1166300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96854, 'Juárez', 'Juarez', 'Juarez,Juárez,Villa Juarez', 25.6472400, -100.0958200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96855, 'Pueblo Juárez (La Magdalena)', 'Pueblo Juarez (La Magdalena)', '', 19.1672200, -103.9311100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96856, 'Juan Escutia (Borbollón)', 'Juan Escutia (Borbollon)', 'Borbollon,Borbollón,Juan Escutia', 21.1674100, -104.8669800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96857, 'Juan Aldama', 'Juan Aldama', 'Juan Aldama,San Juan del Mezquita,San Juan del Mezquital', 24.2918800, -103.3927200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96858, 'Juanacatlán', 'Juanacatlan', '', 20.5088800, -103.1702500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96859, 'Jocotepec', 'Jocotepec', '', 20.2852700, -103.4289700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96860, 'J. Jesús Díaz Tzirio', 'J. Jesus Diaz Tzirio', '', 19.7666700, -102.3972200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96861, 'Jiquílpan de Juárez', 'Jiquilpan de Juarez', 'Jilquilpan,Jiquilpan,Jiquilpan de Juarez,Jiquílpan de Juárez', 19.9948200, -102.7196900, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96862, 'Jiménez', 'Jimenez', '', 28.3333300, -105.4000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96863, 'Jesús María', 'Jesus Maria', 'Jesus Maria,Jesús María', 21.9611100, -102.3433300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96864, 'Jerez de García Salinas', 'Jerez de Garcia Salinas', 'Ciudad Garcia,Ciudad Garcia Salinas,Ciudad García,Ciudad García Salinas,Jerez,Jerez de Garcia Salinas,Jerez de García Salinas,Kheres-de-Garsija-Salinas,Херес-де-Гарсия-Салинас', 22.6486200, -102.9903400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96865, 'Jerécuaro', 'Jerecuaro', 'Jerecuaro,Jerécuaro', 20.1546700, -100.5086000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96866, 'Jauregui', 'Jauregui', 'Jauregui,Jáuregui', 20.5928000, -100.7194000, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96867, 'Jaral del Progreso', 'Jaral del Progreso', 'Jaral,Jaral del Progreso,Pueblo Jaral del Progreso', 20.3723700, -101.0624900, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96868, 'Jarácuaro', 'Jaracuaro', 'Jaracuaro,Jarácuaro', 19.5605800, -101.6778500, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96869, 'Jamay', 'Jamay', 'Jamay', 20.2934900, -102.7075400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96870, 'Jaluco', 'Jaluco', 'Jaluco', 19.2304100, -104.6845100, 'MX', '2016-02-20', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96871, 'Jalpa', 'Jalpa', 'Jalpa', 21.6344800, -102.9791900, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96872, 'Jalostotitlán', 'Jalostotitlan', 'Jalostotilan,Jalostotitlan,Jalostotitlán,Khalostotitlan,Халостотитлан', 21.1674100, -102.4638600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96873, 'Xalisco', 'Xalisco', 'Jalisco,Xalisco', 21.4510000, -104.8983000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96874, 'Jalcocotán', 'Jalcocotan', 'Jalcocota,Jalcocotan,Jalcocotán', 21.4812200, -105.0985100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96875, 'Jala', 'Jala', 'Jala', 21.1048400, -104.4376400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96876, 'Ixtlán del Río', 'Ixtlan del Rio', 'Dei Rio Ixtlan,Istlan-del''-Rio,Ixtlan,Ixtlan del Rio,Ixtlán,Ixtlán del Río,Opstina Ixtlan del Rio,Opština Ixtlán del Río,Истлан-дель-Рио', 21.0390700, -104.3711600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96877, 'Ixtlán de los Hervores', 'Ixtlan de los Hervores', 'Ixtlan,Ixtlan de los Hervores,Ixtlán,Ixtlán de los Hervores', 20.1689500, -102.3948000, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96878, 'Ixtlahuacán del Río', 'Ixtlahuacan del Rio', 'Ixtlahuacan del Rio,Ixtlahuacán del Río', 20.8640500, -103.2402900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96879, 'Ixtlahuacán de los Membrillos', 'Ixtlahuacan de los Membrillos', 'Ixtlahuacan,Ixtlahuacan Membrillos,Ixtlahuacan de los Membrillos,Ixtlahuacán,Ixtlahuacán de los Membrillos', 20.3486000, -103.1933600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96880, 'Ixtlahuacán', 'Ixtlahuacan', 'Ixtlahuacan,Ixtlahuacán,Ixtlanhuacan,Ixtlanhuacán', 19.0011900, -103.7363800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96881, 'Ixtapan del Oro', 'Ixtapan del Oro', 'Ixtapan del Oro', 19.2630300, -100.2645900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96882, 'Ixtapa', 'Ixtapa', 'Ixtapa', 20.7164100, -105.2048700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96883, 'Ixtapa', 'Ixtapa', '', 17.6678200, -101.6416500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96884, 'Irapuato', 'Irapuato', 'Irapuatas,Irapuato,Iraputa,ayrabwatw,ayrapwatw,ayrpwatw  gwankhwatw,yi la pu a tuo,Ирапуато,ايرابواتو,ایراپواتو,ایرپواتو، گوانخواتو,ირაპუატო,伊拉普阿托', 20.6767500, -101.3562800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96885, 'Irámuco', 'Iramuco', 'Iramuco,Irámuco', 19.9615600, -100.9220200, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96886, 'Indaparapeo', 'Indaparapeo', 'Indaparapeo,Indiaparapeo', 19.7876700, -100.9690700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96887, 'Imuris', 'Imuris', 'Imuris', 30.7895500, -110.8459600, 'MX', '2014-08-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96888, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 28.3935500, -107.2277400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96889, 'Huiramba', 'Huiramba', 'Huiramba', 19.5460600, -101.4365100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96890, 'Huimilpan', 'Huimilpan', '', 20.3719900, -100.2773700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96891, 'Huetamo de Núñez', 'Huetamo de Nunez', 'Huetamo,Huetamo de Munez,Huetamo de Múñez,Huetamo de Nunez,Huetamo de Núñez', 18.6292600, -100.8970000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96892, 'Huepaco', 'Huepaco', '', 25.9841700, -108.8605600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96893, 'Huépac', 'Huepac', 'Huepac,Huépac', 29.9113500, -110.2132300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96894, 'Huejuquilla', 'Huejuquilla', 'Huejuquilla,Huejuquilla el Alto', 22.6254700, -103.8977700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96895, 'Huejucar', 'Huejucar', 'Huejucar,Huejúcar', 22.3588100, -103.2114000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96896, 'Huatabampo', 'Huatabampo', 'Huatabampo,Uatabampo,Уатабампо', 26.8261000, -109.6422000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96897, 'Huaniqueo de Morales', 'Huaniqueo de Morales', 'Huaniqueo,Huaniqueo de Morales', 19.8968200, -101.5045000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96898, 'Huanimaro', 'Huanimaro', 'Huanimaro,Huanímaro', 20.3678300, -101.4986900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96899, 'Huandacareo', 'Huandacareo', 'Huandacareo', 19.9913600, -101.2761000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96900, 'Huajicori', 'Huajicori', 'Huajicori,Huaricori', 22.6366700, -105.3197200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96901, 'Hostotipaquillo', 'Hostotipaquillo', '', 21.0603500, -104.0509100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96902, 'Hormiguero', 'Hormiguero', 'Hormiguero', 25.6838600, -103.3412100, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96903, 'Higueras de Abuya', 'Higueras de Abuya', 'Higueras de Abuya', 24.2605800, -107.0709000, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96904, 'Higueras', 'Higueras', 'Higueras', 25.9600700, -100.0152000, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96905, 'El Higueral', 'El Higueral', 'El Higueral,Higueral,Higueras', 24.3104400, -107.3480000, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96906, 'Higuera de Zaragoza', 'Higuera de Zaragoza', 'Higuera de Zaragoza,Higueras de Zaragoza', 25.9689200, -109.3042000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96907, 'Parral', 'Parral', 'Hidalgo del Parral,Paral,Parral,Parral'',pa la er,paral  chyywaywa,Парал,Парраль,پارال، چہواہوا,پارال، چیئوائوا,帕拉爾', 26.9302200, -105.6664000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96908, 'Heróica Zitácuaro', 'Heroica Zitacuaro', 'Heroica Zitacuaro,Heróica Zitácuaro,Zitacuaro,Zitácuaro', 19.4361200, -100.3573300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96909, 'Nogales', 'Nogales', 'Heroica Nogales,Los Nogales,NOG,Nogales,nuo jia lai si,nwgals  swnwra,nwgalys  swnwra,Ногалес,نوگالس، سونورا,نوگالیس، سونورا,諾加萊斯', 31.3086200, -110.9421700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96910, 'Heroica Caborca', 'Heroica Caborca', 'Caborca,Heroica Caborca', 30.7182500, -112.1582200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96911, 'Hermosillo', 'Hermosillo', 'Ehrmosil''o,Ermosijo,Ermosil''o,Ermosilo,HMO,Hermosiljas,Hermosillo,Pitic,ai mo xi yue,armwsyw,armwsyyw swnwra,armwsyyw  swnwra,eleumosiyo,ermosilio,erumoshijo,xer mo si yo,Ермосильо,Ермосиљо,Ермосійо,Эрмосильо,ארמוסיו,ارموسييو سونورا,ارموسیو,ارموسییو، سونورا,เอร์โมซีโย,ერმოსილიო,エルモシージョ,埃莫西约,에르모시요', 29.1026000, -110.9773200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96912, 'Hacienda Toribio', 'Hacienda Toribio', '', 23.0833300, -102.6833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96913, 'Guerrero', 'Guerrero', 'Guerrero,Presidio de Rio Grande,Presidio de Río Grande', 28.3099200, -100.3804800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96914, 'Heroica Guaymas', 'Heroica Guaymas', 'GYM,Guajmas,Guaymas,Heroica Guaymas,gua yi ma si,gwaymas,Гуаймас,گوایماس,瓜伊馬斯', 27.9192800, -110.8975500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96915, 'Guasave', 'Guasave', 'Guasava,Guasave,gua sa wei,gwasaw,Гуасаве,گواساو,瓜薩維', 25.5674500, -108.4675600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96916, 'Guanajuato', 'Guanajuato', 'Byen Guanajuato,Ciudad Guanajuato,Guanajuato,Guanajuato City,Guanakhuato,Guanaxuato,Gvanachuatas,Gvanakhuato,Pachtitlan,ghwanakhwatw,gua na hua tuo,guanafuato,gwanahuato,gwanakhwatw  gwanakhwatw,kwa na khaw to,Гванахуато,Гуанахуато,גואנחואטו,غواناخواتو,گوآناخوآتو، گوآناخوآتو,กวานาคัวโต,გუანახუატო,グアナフアト,瓜纳华托,과나후아토', 21.0185800, -101.2591000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96917, 'Guamúchil', 'Guamuchil', 'Guamuchil,Guamúchil', 25.4587000, -108.0773200, 'MX', '2016-02-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96918, 'Guadalupe y Calvo', 'Guadalupe y Calvo', 'Guadalupe y Calvo', 26.0911700, -106.9626000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96919, 'Guadalupe Victoria', 'Guadalupe Victoria', '', 31.5339600, -107.7383500, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96920, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria,Tapona', 24.4440100, -104.1215600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96921, 'Guadalupe Victoria', 'Guadalupe Victoria', '', 21.6797200, -105.3275000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96922, 'Guadalupe', 'Guadalupe', 'Ciudad Guadalupe,Guadalupe,Gvadalupe,Villa Guadalupe,Villa de Guadalupe,Гвадалупе', 25.6767800, -100.2564600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96923, 'Guadalupe', 'Guadalupe', 'Guadalupe,Gvadalupe,Гвадалупе', 22.7475300, -102.5187400, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96924, 'Guadalajara', 'Guadalajara', 'Atemaxac,GDL,Gorad Gvadalakhara,Gouadalachara,Guadalajara,Guadalajara i Jalisco,Guadalakhara,Guadalaxara,Gvadalachara,Gvadalahara,Gvadalaharo,Gvadalakhara,Gvadalakharae,gatalajara,ghwadalakhara,gu''adalahara,gua da la ha la,guadarahara,gvadalahara,gvadalakhara,gwadalakhara  khalyskw,gwadallahala,gwwdlhrh,kwa da la ha ra,Ātemaxac,Γουαδαλαχάρα,Гвадалахарæ,Гвадалахара,Горад Гвадалахара,Гуадалахара,גוודלחרה,غوادالاخارا,گوادالاخارا، خالیسکو,گواڈلہارا,ग्वादालाहारा,ਗੁਆਦਾਲਾਹਾਰਾ,ഗൗതലജാറ,กวาดาลาฮารา,გვადალახარა,グアダラハラ,瓜达拉哈拉,과달라하라', 20.6668200, -103.3918200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96925, 'Gran Morelos', 'Gran Morelos', 'Carretas,Gran Morelos,San Nicolas,San Nicolas de Carretas,San Nicolás de Carretas', 28.2492000, -106.5106200, 'MX', '2014-08-29', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96926, 'Gomez Palacio', 'Gomez Palacio', 'Gomez Palacio,Gómez Palacio', 25.5698500, -103.4958800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96927, 'Gómez Farías', 'Gomez Farias', 'Gomez Farias,Gómez Farías,San Sebastian,San Sebastián', 19.7936300, -103.4765100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96928, 'Ejido Gogorrón (Ex-Hacienda de Gogorrón)', 'Ejido Gogorron (Ex-Hacienda de Gogorron)', '', 21.8401900, -100.9113800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96929, 'General Zuazua', 'General Zuazua', 'General Zuazua,Zuazua', 25.8949100, -100.1080000, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96930, 'Vicente Guerrero', 'Vicente Guerrero', 'General Vicente Guerrero,Morelos,Mulero,Muleros,Vicente Guerrero,Villa Vicente Guerrero', 23.7342900, -103.9848700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96931, 'Santa Isabel', 'Santa Isabel', 'General Trias,General Trías,Santa Isabel', 28.3416600, -106.3722000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96932, 'Juan José Ríos', 'Juan Jose Rios', 'Colonia Juan Jose Rios,Colonia Juan José Rios,General Juan Jose Rios,General Juan José Ríos,Juan Jose Rios,Juan José Ríos', 25.7578100, -108.8242000, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96933, 'Ciudad General Escobedo', 'Ciudad General Escobedo', 'Ciudad General Escobedo,General Escobedo,Gral. Escobedo', 25.7969800, -100.3179100, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96934, 'General Cepeda', 'General Cepeda', 'General Cepeda', 25.3776700, -101.4757100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96935, 'Guaymitas', 'Guaymitas', '', 27.1102800, -109.4383300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96936, 'Garza García', 'Garza Garcia', '', 25.6538400, -100.3775800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96937, 'Trinidad García de la Cadena', 'Trinidad Garcia de la Cadena', 'Estanzuela,Garcia de la Cadena,García de la Cadena,La Estanzuela', 21.2100000, -103.4644400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96938, 'Galeana', 'Galeana', 'Galeana', 24.8245500, -100.0760100, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96939, 'Fresnillo', 'Fresnillo', 'Fresnil''o,Fresniljas,Fresnillo,Fresnillo de Gonzalez Echeverria,Fresnillo de González Echeverría,frsnylw,frysnyw,fu lei si ni yue,Фреснильо,فرسنیلو,فریسنیو,弗雷斯尼約', 23.1812600, -102.8713600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96940, 'Francisco Sarabia (Cerrito Pelón)', 'Francisco Sarabia (Cerrito Pelon)', 'Cerrito Pelon,Cerrito Pelón,Francisco Sarabia', 20.0308600, -102.7015800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96941, 'Flor Azul', 'Flor Azul', '', 25.8698700, -109.0083900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96942, 'Felipe Carrillo Puerto', 'Felipe Carrillo Puerto', 'Felipe Carrillo Puerto,La Ruana', 19.1632500, -102.7083400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96943, 'Etzatlán', 'Etzatlan', 'Etzatlan,Etzatlán', 20.7683900, -104.0773500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96944, 'Etúcuaro', 'Etucuaro', 'Etucuaro,Etúcuaro', 19.8928600, -102.1294500, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96945, 'Etchoropo', 'Etchoropo', 'Etchoropo', 26.7672700, -109.6823600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96946, 'Etchojoa', 'Etchojoa', 'Elchojoa,Etchojoa', 26.9109400, -109.6261000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96947, 'La Estanzuela', 'La Estanzuela', 'Estanzuela,La Estanzuela', 20.6689100, -103.8260900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96948, 'Las Varas (Estación Babícora)', 'Las Varas (Estacion Babicora)', 'Babicora,Bavicora,Estacion Babicora,Estación Babícora', 29.4808300, -108.0255600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96949, 'Esqueda', 'Esqueda', 'Esqueda', 30.7241200, -109.5893000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96950, 'Escuinapa', 'Escuinapa', 'Escuinapa,Escuinapa de Hidalgo', 22.8327900, -105.7777200, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96951, 'Escuadrón Doscientos Uno', 'Escuadron Doscientos Uno', 'Escuadron Doscientos Uno,Escuadrón Doscientos Uno', 25.6743300, -103.3482900, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96952, 'Escalerillas', 'Escalerillas', 'Escalerilla,Escalerillas', 22.1116700, -101.0730500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96953, 'Erongarícuaro', 'Erongaricuaro', 'Erongaricuaro,Erongarícuaro', 19.5888100, -101.7211000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96954, 'Ensenada', 'Ensenada', 'ESE,Ehnsenada,Enseada,Ensenada,ansnada  bakha kalyfrnya,ansynada,aynsynada  bakha kylyfwrnya,en sen na da,ensenada,xen se na da,Енсенада,Энсенада,אנסנדה,إنسينادا,انسنادا، باخا کالیفرنیا,اینسینادا، باخا کیلیفورنیا,เอนเซนาดา,ენსენადა,エンセナーダ,恩森那達,엔세나다', 31.8714900, -116.6007100, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96955, 'Encarnación de Díaz', 'Encarnacion de Diaz', 'Ehnkarnas''on-de-Dias,Encarnacion,Encarnacion de Diaz,Encarnación de Díaz,La Chona,Opstina Encarnacion de Diaz,Opština Encarnación de Díaz,Энкарнасьон-де-Диас', 21.5270500, -102.2401300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96956, 'Empalme Escobedo', 'Empalme Escobedo', 'Empalme Escobedo,Empalme Gonzalez,Empalme de Gonzalez,Empalme de González,Escobedo', 20.6725000, -100.7467500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96957, 'Empalme', 'Empalme', 'Empalme', 27.9616600, -110.8141100, 'MX', '2014-09-21', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96958, 'El Verde', 'El Verde', '', 20.5556700, -103.2790100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96959, 'El Tuito', 'El Tuito', 'El Tuito', 20.3204200, -105.3246900, 'MX', '2016-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96960, 'El Tobarito', 'El Tobarito', 'El Tobarito', 27.3705700, -109.8937900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96961, 'El Sauzal', 'El Sauzal', 'El Sausal,El Sauzal,El Suazal', 31.8932900, -116.6925600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96962, 'El Saúz', 'El Sauz', 'El Sauz,El Saúz,Sauz Bajo Sauz Alto,Sauz Bajo Suz Alto,Saúz Bajo Saúz Alto,Saúz Bajo Súz Alto', 20.4777400, -100.1154000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96963, 'El Salto', 'El Salto', 'El Salto,Salto', 23.7778100, -105.3619200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96964, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Ehl''-Sal''to,El Salto,Pueblo Nuevo,Pueblo de Cana,Pueblo de Caña,Эль-Сальто', 23.3792700, -105.3831300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96965, 'El Salto', 'El Salto', '', 20.3333300, -104.5000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96966, 'El Salero', 'El Salero', 'El Salero,Salero', 22.3870600, -102.3232300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96967, 'El Rosario', 'El Rosario', '', 24.2555600, -107.1827800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96968, 'El Roble', 'El Roble', 'El Roble,Roble', 23.2455600, -106.2058300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96969, 'El Refugio', 'El Refugio', '', 20.6714000, -103.7392900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96970, 'El Quince', 'El Quince', '', 20.5438700, -103.2846700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96971, 'El Pueblito', 'El Pueblito', '', 20.5397200, -100.4413900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96972, 'El Potrero de Sataya', 'El Potrero de Sataya', '', 24.6900000, -107.7091700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96973, 'El Oro de Hidalgo', 'El Oro de Hidalgo', 'El Oro,El Oro Hidalgo,El Oro de Hidalgo,Oro de Hidalgo', 19.8027200, -100.1308100, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96974, 'El Limón', 'El Limon', 'El Limon,El Limón', 19.8254600, -104.1563300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96975, 'El Habal', 'El Habal', 'El Habal,Habal', 23.3501400, -106.4183400, 'MX', '2015-01-13', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96976, 'El Grullo', 'El Grullo', 'El Grullo', 19.8060300, -104.2180500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96977, 'El Fuerte de Montes Claros', 'El Fuerte de Montes Claros', 'El Fuerte,El Fuerte de Montes Claros,Fuerte', 26.4168600, -108.6182800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96978, 'El Dorado', 'El Dorado', 'El Dorado,Eldorado', 24.3228300, -107.3629800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96979, 'Coyote', 'Coyote', 'Coyote,El Coyote,El Coyte', 25.6951000, -103.2842000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96980, 'El Colorado', 'El Colorado', 'Colorado,El Colorado', 20.5618500, -100.2452000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96981, 'El Colomo', 'El Colomo', 'El Colomo', 19.0610100, -104.2585300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96982, 'El Coacoyul', 'El Coacoyul', 'Coacoyul,El Coacoyul', 17.6381000, -101.4757100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96983, 'El Chayote', 'El Chayote', 'El Chayote', 22.2866700, -102.2390000, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96984, 'El Carrizo', 'El Carrizo', 'El Carrizo', 24.0141600, -106.8519600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96985, 'El Cambio', 'El Cambio', '', 25.6402800, -103.3250000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96986, 'Villa Insurgentes (El Calabazal)', 'Villa Insurgentes (El Calabazal)', 'Calabazal,El Calabazal', 23.7430600, -103.8425000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96987, 'El Burrión', 'El Burrion', 'El Burrion,El Burrión', 25.5387800, -108.4128600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96988, 'El Arenal', 'El Arenal', 'Arenal,El Arenal', 20.7753800, -103.6935300, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96989, 'Ejutla', 'Ejutla', 'Ejutla', 19.9063900, -104.1619400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96990, 'Ejido Yucatán', 'Ejido Yucatan', 'Ejido Yucatan,Ejido Yucatán,Yucatan,Yucatán', 32.6043500, -115.0938000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96991, 'Ejido Tabasco', 'Ejido Tabasco', 'Ejido Tobasco,Tabasco,Tabasko,Табаско', 32.5618700, -114.9265900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96992, 'Ejido Saltillo', 'Ejido Saltillo', 'Ejido Saltillo,Saltillo', 32.4243000, -115.1248000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96993, 'Puebla', 'Puebla', 'Ejido Puebla,Puebla,Puehbla,Пуэбла', 32.5665400, -115.3534000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96994, 'Ejido Plan de Ayala', 'Ejido Plan de Ayala', 'Ejido Plan de Ayala,Plan de Ayala', 32.2202300, -115.0315800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96995, 'Ejido Jiquilpan', 'Ejido Jiquilpan', 'Ejido Jiquilpan,Jiquilpan', 32.5013100, -115.0638200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96996, 'Ciudad Insurgentes', 'Ciudad Insurgentes', 'Ciudad Insurgentes,Ejido Insurgentes,Fernando de la Toba,La Toba,Villa Insurgentes', 25.2634500, -111.7744400, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96997, 'Hermosillo', 'Hermosillo', 'Ehrmosil''o,Ejido Hermosillo,Hermosillo,Эрмосильо', 32.5109700, -114.9227800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96998, 'Ejido El Largo', 'Ejido El Largo', '', 29.6833300, -108.2666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(96999, 'Ecuandureo', 'Ecuandureo', '', 20.1618800, -102.1934000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97000, 'Victoria de Durango', 'Victoria de Durango', 'Byen Durango,Ciudad de Durango,DGO,Durangas,Durango,Durango City,Victoria de Durango,Viktorija de Durango,Viktorija-de-Durango,do~urango,du lan ge,dulang-go,durango,dwrangw  dwrangw,dwrngw,Виктория-де-Дуранго,Викторија де Дуранго,Дуранго,דורנגו,دورانگو سٹی,دورانگو، دورانگو,დურანგო,ドゥランゴ,杜兰戈,두랑고', 24.0203200, -104.6575600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97001, 'Duarte', 'Duarte', 'Duarte', 21.0871200, -101.5243100, 'MX', '2016-06-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97002, 'Doctor Arroyo', 'Doctor Arroyo', '', 23.6721100, -100.1813400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97003, 'Degollado', 'Degollado', '', 20.4670200, -102.1497600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97004, 'San Miguel Cuyutlán', 'San Miguel Cuyutlan', 'Cuyutlan,Cuyutlán,San Miguel Cuyutlan,San Miguel Cuyutlán', 20.4163300, -103.3898700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97005, 'Cutzamala de Pinzón', 'Cutzamala de Pinzon', 'Cutzamala,Cutzamala de Pinzon,Cutzamala de Pinzón', 18.4678300, -100.5808900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97006, 'Cupareo', 'Cupareo', 'Cupareo', 20.2287600, -101.0180600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97007, 'Cumpas', 'Cumpas', 'Cumpas,Cúmpas', 29.9958700, -109.7808700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97008, 'Culiacancito', 'Culiacancito', 'Culiacancito', 24.8253800, -107.5344500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97009, 'Culiacán', 'Culiacan', 'CUL,Colhuahcan Rosales,Cuilacan,Culiacan,Culiacan Rosales,Culiacana,Culiacán,Culiacán Rosales,Cōlhuahcān Rosales,Kul''jakan,Kuliakan,Kulijakan,Kuljakanas,ku leiy kan,ku li ya kan,kuriakan,Кулиакан,Кулијакан,Кульякан,กูเลียกัน,კულიაკანი,クリアカン,库利亚坎', 24.7903200, -107.3878200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97010, 'Cuitzeo del Porvenir', 'Cuitzeo del Porvenir', 'Cuitzeo,Cuitzeo del Porvenir', 19.9702500, -101.1429000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97011, 'Cuitzeo (La Estancia)', 'Cuitzeo (La Estancia)', '', 20.3427800, -102.7838900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97012, 'San Bartolo Cuitareo', 'San Bartolo Cuitareo', '', 19.6513900, -100.6011100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97013, 'Cuexcomatitlán', 'Cuexcomatitlan', '', 20.4281000, -103.3618900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97014, 'Cuerámaro', 'Cueramaro', 'Cueramaro,Cuerámaro,Gueramaro', 20.6254600, -101.6724200, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97015, 'Cuencamé', 'Cuencame', 'Cucencame,Cucencamé,Cuencame,Cuencame de Ceniceros,Cuencamé,Cuencamé de Ceniceros,Kuehnkame,Villa de Cuencame,Villa de Cuencamé,Куэнкаме', 24.8711600, -103.6973100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97016, 'Palmar de Cuautla', 'Palmar de Cuautla', 'Cuantla,Cuautla', 22.2197200, -105.6475000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97017, 'Cuautla', 'Cuautla', 'Cuautla', 20.2013900, -104.4075000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97018, 'Cuauhtémoc', 'Cuauhtemoc', 'Ciudad Cuauhtemoc,Ciudad Cuauhtémoc,Cuahtemoc,Cuauhtemoc,Cuauhtémoc,San Antonio de los Arenales', 28.4088400, -106.8631900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97019, 'Cuauhtémoc', 'Cuauhtemoc', 'Cuauhtemoc,Cuauhtémoc', 19.3286100, -103.6028400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97020, 'Cuanajo', 'Cuanajo', 'Cuanajo', 19.4848500, -101.5079400, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97021, 'El Crucero de Santa María', 'El Crucero de Santa Maria', '', 20.3831700, -103.8613100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97022, 'Creel', 'Creel', 'Creel,Ehstas''on-Kreehl'',kuriru,Эстасьон-Креэль,クリル', 27.7505400, -107.6352000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97023, 'Coyula', 'Coyula', '', 20.6333300, -103.2000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97024, 'Coyuca de Catalán', 'Coyuca de Catalan', 'Coyuca,Coyuca de Catalan,Coyuca de Catalán', 18.3261400, -100.6989800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97025, 'Coyuca de Benítez', 'Coyuca de Benitez', 'Coyuca,Coyuca de Benitez,Coyuca de Benítez,Tixtlacingo', 17.0089500, -100.0871400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97026, 'Cotija de la Paz', 'Cotija de la Paz', 'Cotija,Cotija de la Paz', 19.8092200, -102.7019800, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97027, 'Villa de Costa Rica', 'Villa de Costa Rica', 'Costa Rica,Kosta-Rika,Villa de Costa Rica,Коста-Рика', 24.5916700, -107.3883600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97028, 'Cosío', 'Cosio', 'Cosio,Coso,Cosío,Ejido Cosio,Ejido Cosío', 22.3662500, -102.3000800, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97029, 'Cosalá', 'Cosala', 'Cosala,Cosalá', 24.4150100, -106.6907300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97030, 'Cortazar', 'Cortazar', 'Cortazar,Kortasar,Villa Cortazar,Кортасар', 20.4800800, -100.9606700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97031, 'Coroneo', 'Coroneo', 'Coroneo', 20.2000100, -100.3654600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97032, 'Coquimatlán', 'Coquimatlan', 'Coquimatlan,Coquimatlán', 19.2062500, -103.8095200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97033, 'Copándaro de Galeana', 'Copandaro de Galeana', 'Copandaro,Copandaro de Galeana,Copándaro,Copándaro de Galeana', 19.8925400, -101.2139400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97034, 'Copándaro (Copándaro del Cuatro)', 'Copandaro (Copandaro del Cuatro)', 'Copandaro,Copandaro del Cuatro,Copándaro,Copándaro del Cuatro', 19.9005700, -101.6594500, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97035, 'Contepec', 'Contepec', 'Contepec', 19.9543200, -100.1638500, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97036, 'La Constancia', 'La Constancia', 'Constancia,La Constancia', 24.2236300, -107.1861000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97037, 'Congregación Ortíz', 'Congregacion Ortiz', '', 28.2537500, -105.5192200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97038, 'Concordia', 'Concordia', '', 25.7798200, -103.1169600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97039, 'Concepcion del Oro', 'Concepcion del Oro', 'Concepcion del Oro,Concepción del Oro', 24.6132600, -101.4184400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97040, 'Concepción de Buenos Aires', 'Concepcion de Buenos Aires', 'Concepcion de Buenos Aires,Concepción de Buenos Aires,Pueblo Nuevo', 19.9782200, -103.2598100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97041, 'La Concha (La Concepción)', 'La Concha (La Concepcion)', 'Concepcion,Concepción,La Concepcion,La Concepción', 22.5325000, -105.4525000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97042, 'Compostela', 'Compostela', '', 21.2377700, -104.9001000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97043, 'Comonfort', 'Comonfort', 'Chamacuero de Comonfort,Comonfort,Komonfort,Villa Comonfort,Комонфорт', 20.7227800, -100.7594600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97044, 'Comala', 'Comala', 'Comala', 19.3271700, -103.7592600, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97045, 'Comachuén', 'Comachuen', 'Comachuen,Comachuén', 19.5713200, -101.9043300, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97046, 'Colotlán', 'Colotlan', 'Cololan,Colotlan,Colotlán', 22.1129900, -103.2670700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97047, 'Colorines', 'Colorines', 'Colorines', 19.1782900, -100.2181700, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97048, 'Colorines', 'Colorines', '', 19.1763900, -100.2163900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97049, 'Vicente Guerrero', 'Vicente Guerrero', 'Colonia Vicente Guerrero,Vicente Guerrero', 30.7309700, -115.9907100, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97050, 'Antonio Rosales', 'Antonio Rosales', '', 27.3511100, -109.8530600, 'MX', '2016-12-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97051, 'Colonia Plenitud', 'Colonia Plenitud', '', 23.2325000, -103.0750000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97052, 'Colonia Nicolás Bravo (Kilómetro Noventa y Dos)', 'Colonia Nicolas Bravo (Kilometro Noventa y Dos)', '', 28.0922200, -105.5277800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97053, 'Ampliación Colonia Lázaro Cárdenas', 'Ampliacion Colonia Lazaro Cardenas', 'Ampliacion Colonia Lazaro Cardenas,Ampliación Colonia Lázaro Cárdenas,Colonia Lazaro Cardenas,Colonia Lazaro Cárdenas,La Chavez,La Chávez', 28.3833300, -105.6166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97054, 'Allende', 'Allende', 'Colonia Allende,El Dieciocho', 27.1920100, -109.9073000, 'MX', '2016-12-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97055, 'Colonia Abraham González (La Quemada)', 'Colonia Abraham Gonzalez (La Quemada)', 'Colonia Abraham Gonzalez,Colonia Abraham González,La Quemada', 28.2066700, -105.4075000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97056, 'Colón', 'Colon', 'Colon,Colón', 20.7832300, -100.0514900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97057, 'Colima', 'Colima', 'CLQ,Colima,Kolima,Колима', 19.2499700, -103.7271400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97058, 'Cojumatlán de Régules', 'Cojumatlan de Regules', 'Cojumatlan,Cojumatlan de Regules,Cojumatlán,Cojumatlán de Régules', 20.1185800, -102.8518200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97059, 'Cofradía de Navolato (Cofradía de los Rocha)', 'Cofradia de Navolato (Cofradia de los Rocha)', 'Cofradia,Cofradia de los Rocha,Cofradía,Cofradía de los Rocha', 24.7680600, -107.6480600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97060, 'Cofradía', 'Cofradia', '', 19.4333300, -103.5500000, 'MX', '2006-01-17', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97061, 'Coeneo de la Libertad', 'Coeneo de la Libertad', 'Coeneo,Coeneo de la Libertad', 19.8219500, -101.5847000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97062, 'Cocula', 'Cocula', '', 20.3651700, -103.8221500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97063, 'Cocorit', 'Cocorit', 'Cocorit,Cócorit', 27.5751900, -109.9591000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97064, 'Coalcomán de Vázquez Pallares', 'Coalcoman de Vazquez Pallares', 'Coalcoman,Coalcoman de Matamoros,Coalcomán,Coalcomán de Matamoros,Matamoros', 18.7775000, -103.1600000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97065, 'Coahuayutla de Guerrero', 'Coahuayutla de Guerrero', 'Coahuayutla,Coahuayutla de Guerrero', 18.3146900, -101.7357400, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97066, 'Coahuayana Viejo', 'Coahuayana Viejo', 'Coahuayana,Coahuayana Viejo', 18.7511900, -103.6679800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97067, 'Ciudad Obregón', 'Ciudad Obregon', 'Altepetl Obregon,Altepetl Obregón,CEN,Cajeme,Cd Obregon,Cd Obregón,Cd. Obregon,Cd. Obregón,Ciudad Obregon,Ciudad Obregón,Lungsod ng Obregon,Lungsod ng Obregón,Obregon,S''judad Obregon,S''judad-Obregon,Sijudad Obregon,Siudad Obregon,Siudad Obregonas,ao fu lei gong cheng,siudad-obregoni,siudadeuobeulegon,sywdad awbrgn,sywdad awbrygwn,Сиудад Обрегон,Сијудад Обрегон,Сьюдад Обрегон,Сьюдад-Обрегон,סיודד אוברגון,سیوداد اوبرگن,سیوداد اوبریگون,სიუდად-ობრეგონი,シウダ・オブレゴン,奧夫雷貢城,시우다드오브레곤', 27.4864200, -109.9408300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97068, 'Ciudad Manuel Doblado', 'Ciudad Manuel Doblado', 'Ciudad Manuel Doblado,Manuel Doblado,San Pedro Piedra Gorda', 20.7288800, -101.9522600, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97069, 'Ciudad Lerdo', 'Ciudad Lerdo', 'Ciudad Lerdo,Lerdo', 25.5371800, -103.5245600, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97070, 'Ciudad Juárez', 'Ciudad Juarez', 'Altepetl Juarez,Altepetl Juárez,CJS,Chuaresas,Ciudad Juarez,Ciudad Juárez,El Paso del Norte,Gorad S''judad-Khuarehs,Huaresa,Juarez,Juárez,Lungsod Juarez,Lungsod Juárez,Paso del Norte,S''judad-Khuares,Sijudad Khuarez,Sioudad Chouares,Siudad Chuaresas,Siudad Khuares,Syudat Xuares,hua lei si cheng,si''udada hu''arejha,siudad-khuaresi,siudadeuhualeseu,sywdad khwars. chyywaywa,sywdad khwaryz,Σιουδάδ Χουάρες,Горад Сьюдад-Хуарэс,Сиудад Хуарес,Сијудад Хуарез,Сьюдад-Хуарес,Սյուդատ Խուարես,סיודאד חוארס,سيوداد خواريز,سیوداد خوارس٬ چیئوائوا,سیوداد خواریز,सिउदाद हुआरेझ,სიუდად-ხუარესი,シウダー・フアレス,華雷斯城,시우다드후아레스', 31.7333300, -106.4833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97071, 'Ciudad Hidalgo', 'Ciudad Hidalgo', 'Ciudad Hidalgo,Hidalgo,S''judad-Idal''go,Taximaroa,Villa Hidalgo,Сьюдад-Идальго', 19.6927000, -100.5544500, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97072, 'Ciudad Guzmán', 'Ciudad Guzman', 'Altepetl Guzman,Cd Guzman,Cd Guzmán,Cd. Guzman,Cd. Guzmán,Ciudad Guzman,Ciudad Guzmán,S''judad-Gusman,gu si man cheng,sywdad gwzman,thywdad jwthman,Сьюдад-Гусман,ثيوداد جوثمان,سیوداد گوزمان,古斯曼城', 19.7046600, -103.4617000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97073, 'Ciudad Delicias', 'Ciudad Delicias', 'Delicias,Delis''jas,Las Delicias,Делисьяс', 28.1901300, -105.4701200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97074, 'Ciudad Constitución', 'Ciudad Constitucion', 'CUA,Ciudad Constitucion,Ciudad Constitución,Constitucion,Constitución,S''judad-Konstitus''on,Villa Constitucion,Villa Constitución,shiudakonsutito~ushion,Сьюдад-Конститусьон,シウダーコンスティトゥシオン', 25.0321000, -111.6625600, 'MX', '2017-04-16', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97075, 'Ciudad Camargo', 'Ciudad Camargo', 'Camargo,Ciudad Camargo,Santa Rosalia,Santa Rosalía', 27.6784200, -105.1713600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97076, 'Ciudad Anáhuac', 'Ciudad Anahuac', 'Anahuac,Anáhuac,Ciudad Anahuac,Ciudad Anáhuac', 27.2445700, -100.1322900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97077, 'Ciudad Altamirano', 'Ciudad Altamirano', 'Altepetl Altamirano,Ciudad Altamirano,Pungarabato,S''judad-Al''tamirano,Сьюдад-Альтамирано', 18.3582000, -100.6696500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97078, 'Ciudad Acuña', 'Ciudad Acuna', 'ACN,Acuna,Acuña,Ciudad Acuna,Ciudad Acuña,Las Vacas,Lungsod ng Acuna,Lungsod ng Acuña,S''judad-Akun''ja,Siudad Akunja,Villa Acuna,Villa Acuña,a ku ni ya,akwna  kwawyla,Сиудад Акуня,Сьюдад-Акунья,אקוניה,اکونا، کواویلا,阿庫尼亞', 29.3232200, -100.9521700, 'MX', '2017-02-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97079, 'Cieneguilla', 'Cieneguilla', '', 21.2483300, -100.2738900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97080, 'Ciénega de Flores', 'Cienega de Flores', 'Cienaga de Flores,Cienega de Flores,Ciénaga de Flores,Ciénega de Flores', 25.9546700, -100.1669500, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97081, 'Churintzio', 'Churintzio', '', 20.1505600, -102.0646900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97082, 'Chucarit', 'Chucarit', 'Chucarit,Chucárit', 27.0315700, -109.5842100, 'MX', '2017-02-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97083, 'Chucándiro', 'Chucandiro', 'Chucandiro,Chucándiro', 19.9000800, -101.3338000, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97084, 'Choix', 'Choix', 'Choix,Villa Choix', 26.7090100, -108.3254500, 'MX', '2014-11-24', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97085, 'Jitonhueca', 'Jitonhueca', '', 27.0616700, -109.6050000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97086, 'Chiquilistlán', 'Chiquilistlan', '', 20.2000000, -103.8166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97087, 'Chilchota', 'Chilchota', 'Chilchota', 19.8465400, -102.1171600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97088, 'Chilapa', 'Chilapa', 'Chilapa', 22.0313800, -105.2305700, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97089, 'Chihuahua', 'Chihuahua', 'Altepetl Chihuahuah,Byen Chihuahua,CUU,Chihuahua,Chihuahua City,Chihuahua by,Chiuaua,Chiuauae,Chivava,Cihuahua,Ciuaua,Dakbayan sa Chihuahua,Tsiouaoua,chiuaua,chiwawa,chyywaywa. chyywaywa,qi wa wa shi,zhi hua hua shi,Čihuahua,Čiuaua,Τσιουάουα,Чивава,Чиуауæ,Чиуауа,Чіуауа,ציוואווה,چہواہوا,چیئوائوا٬ چیئوائوا,ჩიუაუა,チワワ,奇瓦瓦市,芝華華市,치와와', 28.6352800, -106.0888900, 'MX', '2014-10-17', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97090, 'Cherán', 'Cheran', 'Cheran,Cherán', 19.6853600, -101.9536800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97091, 'Chavinda', 'Chavinda', 'Chavinda,Chavínda,Villa Chavinda,Villa Chavínda', 20.0062500, -102.4601500, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97092, 'Charo', 'Charo', 'Chara,Charo', 19.7496600, -101.0457100, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97093, 'Charcas', 'Charcas', 'Charcas', 23.1294300, -101.1134600, 'MX', '2016-10-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97094, 'Charapán', 'Charapan', 'Charapaco,Charapan,Charapán', 19.6511200, -102.2519000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97095, 'Chapala', 'Chapala', 'Chapala', 20.2961600, -103.1912300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97096, 'Chametla', 'Chametla', '', 22.8775000, -105.9575000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97097, 'Chalchihuites', 'Chalchihuites', 'Calchihuites,Chalchihuites', 23.4749800, -103.8829300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97098, 'Cerro Gordo', 'Cerro Gordo', 'Cerro Gordo', 20.5929400, -101.1268400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97099, 'Cerro de San Pedro', 'Cerro de San Pedro', 'Cerro de San Pedro,San Pedro', 22.2178000, -100.7996100, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97100, 'Cerritos', 'Cerritos', 'Cerritos', 22.4283500, -100.2847400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97101, 'Cerano', 'Cerano', 'Cerano', 20.1087700, -101.3871000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97102, 'Celaya', 'Celaya', 'CYW,Celaya,Selaja,sai la ya,selaia,slaya,sylaya,sylayya,Селая,Селаја,Ցելայա,سلایا,سيلايا,سیلائیا,სელაია,塞拉亞', 20.5235300, -100.8157000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97103, 'Los Cedros', 'Los Cedros', '', 20.3898000, -103.2325000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97104, 'Ceballos', 'Ceballos', 'Ceballos', 26.5258000, -104.1295000, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97105, 'Castaños', 'Castanos', 'Castanos,Castaños', 26.7893200, -101.4321100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97106, 'Casimiro Castillo', 'Casimiro Castillo', 'Casimiro Castillo,Resolana', 19.6052000, -104.4343300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97107, 'Casas Grandes', 'Casas Grandes', 'Casas Grandes', 30.3826900, -107.9562800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97108, 'Carranco', 'Carranco', 'Barranco,Carranco', 21.8200200, -101.0969900, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97109, 'Carmen', 'Carmen', 'Carmen,El Carmen', 25.9365000, -100.3639600, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97110, 'Carácuaro', 'Caracuaro', 'Caracuaro,Caracuaro de Morelos,Carácuaro,Carácuaro de Morelos', 19.0196600, -101.1249400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97111, 'Capula', 'Capula', '', 19.7000000, -101.8000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97112, 'El Capomal', 'El Capomal', 'Capomal,El Zanjon,El Zanjón', 21.8393500, -105.1211600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97113, 'Capilla de Guadalupe', 'Capilla de Guadalupe', '', 20.8273900, -102.5918500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97114, 'Capácuaro', 'Capacuaro', 'Capacuaro,Capácuaro', 19.5474100, -102.0518400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97115, 'Cañitas de Felipe Pescador', 'Canitas de Felipe Pescador', 'Canitas,Canitas de Felipe Pescador,Cañitas,Cañitas de Felipe Pescador,Felipe Pescador', 23.6037100, -102.7270400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97116, 'Canatlán', 'Canatlan', '', 24.5257600, -104.7732700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97117, 'Cananea', 'Cananea', 'CNA,Cananea,Kananea,Kananeja,Kananėja,ka na nei a,Кананеа,卡納內阿', 30.9869900, -110.2906200, 'MX', '2015-06-27', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97118, 'Cañada de Caracheo', 'Canada de Caracheo', '', 20.3754900, -100.9453900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97119, 'Campo Sesenta', 'Campo Sesenta', '', 27.4500000, -110.1000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97120, 'Villa Juárez', 'Villa Juarez', 'Campo Gobierno,Villa Juarez,Villa Juárez', 24.6586900, -107.5405900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97121, 'Calvillo', 'Calvillo', 'Calvillo', 21.8458300, -102.7184900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97122, 'Víctor Rosales', 'Victor Rosales', 'Calera,Calera Victor Rosales,Calera Víctor Rosales,Victor Rosales', 22.9488900, -102.7022200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97123, 'Cajititlán', 'Cajititlan', '', 20.4317400, -103.3094000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97124, 'Bustamante', 'Bustamante', 'Bustamante,Bustamente,Estacion Bustamante,Estación Bustamante', 26.5333300, -100.5000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97125, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 19.0749900, -102.1799900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97126, 'Buena Vista Tomatlán', 'Buena Vista Tomatlan', 'Buena Vista Tomatlan,Buena Vista Tomatlán,Buenavista,Tomatlan', 19.2128100, -102.5873500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97127, 'Buenaventura', 'Buenaventura', 'Buenaventura,San Buenaventura', 29.8432000, -107.4606700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97128, 'Bucerías', 'Bucerias', 'Bucerias,Bucerías,Buserias', 20.7562600, -105.3343800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97129, 'Briseñas de Matamoros', 'Brisenas de Matamoros', 'Brisenas,Brisenas de Matamoros,Briseñas,Briseñas de Matamoros', 20.2682100, -102.5619500, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97130, 'Bimbaletes Aguascalientes (El Álamo)', 'Bimbaletes Aguascalientes (El Alamo)', '', 22.2344400, -102.0191700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97131, 'Bermejillo', 'Bermejillo', 'Bermehillo,Bermejillo', 25.8868200, -103.6206900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97132, 'Benjamin Hill', 'Benjamin Hill', 'Benjamin Hil,Benjamin Hill,Benjamín Hill', 30.1690400, -111.1140300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97133, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez', 29.7462400, -107.9396600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97134, 'Benito Juárez', 'Benito Juarez', '', 19.2333300, -100.4666700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97135, 'Bellavista', 'Bellavista', '', 20.4340800, -103.6374200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97136, 'Gonzales Ortega', 'Gonzales Ortega', 'Banon,Bañón,Gonzales Ortega', 23.1805600, -102.4758900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97137, 'Bahía de Kino', 'Bahia de Kino', 'Bahia Kino,Bahía Kino,Kino,Kino Viejo', 28.8227800, -111.9408300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97138, 'Bagojo Colectivo', 'Bagojo Colectivo', '', 25.8741700, -109.1177800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97139, 'Badiraguato', 'Badiraguato', 'Badiraguato,Badiriguato', 25.3652500, -107.5508300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97140, 'Bácum', 'Bacum', 'Bacum,Bácum', 27.5514200, -110.0833000, 'MX', '2014-04-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97141, 'Bacubirito', 'Bacubirito', 'Bacubirito,Bacurrito', 25.8094400, -107.9150000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97142, 'Bachomobampo Número Dos', 'Bachomobampo Numero Dos', 'Bachomobampo,Bachomobampo Numero Dos,Bachomobampo Número Dos,Bachomobempo,Ejido Bachomobampo Numero Dos,Ejido Bachomobampo Número Dos', 25.7388800, -109.1477600, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97143, 'Ayutla', 'Ayutla', '', 20.1290700, -104.3435500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97144, 'Autlán de Navarro', 'Autlan de Navarro', 'Aohtlan Navarro,Autlan,Autlan de Navarro,Autlán,Autlán de Navarro,Āohtlān Navarro', 19.7682200, -104.3666400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97145, 'Aután', 'Autan', 'Autan,Autlan,Autlán,Aután', 21.6897300, -105.3075000, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97146, 'Atoyac de Álvarez', 'Atoyac de Alvarez', 'Atojak-de-Al''vares,Atoyac,Atoyac de Alvarez,Атояк-де-Альварес', 17.2066700, -100.4330600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97147, 'Atoyac', 'Atoyac', 'Atoyac', 20.0097000, -103.5165200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97148, 'Atotonilquillo', 'Atotonilquillo', '', 20.3928700, -103.1235600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97149, 'Atotonilco el Alto', 'Atotonilco el Alto', 'Atotonilco,Atotonilco el Alto', 20.5507900, -102.5094200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97150, 'Aticama', 'Aticama', 'Alicama,Aticama', 21.4838700, -105.1978700, 'MX', '2014-07-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97151, 'San Juan Atezcapan', 'San Juan Atezcapan', '', 19.1672200, -100.1858300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97152, 'Atequiza', 'Atequiza', '', 20.3900600, -103.1406500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97153, 'Atenguillo', 'Atenguillo', 'Atenguillo', 20.4155300, -104.4938700, 'MX', '2016-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97154, 'Atapán', 'Atapan', 'Atapan,Atapán', 19.6505700, -102.4246300, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97155, 'Asientos', 'Asientos', 'Asientos', 22.2383600, -102.0894000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97156, 'Ascención', 'Ascencion', 'Ascencion,Ascención', 31.1000000, -107.9833300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97157, 'Arteaga', 'Arteaga', 'Arteaga,Artegia', 25.4452800, -100.8466700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97158, 'Arteaga', 'Arteaga', 'Arteaga', 18.3577900, -102.2912200, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97159, 'Villa de Arriaga', 'Villa de Arriaga', 'Arriaga,Villa de Arriaga', 21.9091700, -101.3822300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97160, 'Armeria', 'Armeria', 'Armeria', 18.9378000, -103.9641700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97161, 'Ario de Rosales', 'Ario de Rosales', 'Ario,Ario de Rosales', 19.2090000, -101.7074300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97162, 'Ario de Rayón', 'Ario de Rayon', 'Ario,Ario Santa Monica,Ario Santa Mónica,Ario de Rayon,Ario de Rayón', 20.0265100, -102.3481400, 'MX', '2016-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97163, 'Arcelia', 'Arcelia', 'Arcelia', 18.3184700, -100.2814800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97164, 'Arandas', 'Arandas', 'Arandas', 20.7051900, -102.3463500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97165, 'Santa Eulalia', 'Santa Eulalia', 'Aquiles Serdan,Aquiles Serdán,Santa Eulalia', 28.5945000, -105.8879600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97166, 'Apozol', 'Apozol', '', 21.4695200, -103.0907600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97167, 'Aporo', 'Aporo', 'Aporo', 19.6702100, -100.4106800, 'MX', '2016-11-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97168, 'Ciudad Apodaca', 'Ciudad Apodaca', 'Apodaca,Apodaka,Ciudad Apodaca,Opstina Apodaca,Opština Apodaca,Sijudad Apodaka,a bo da ka,apwdaka,Аподака,Сијудад Аподака,آپوداکا,აპოდაკა,阿波達卡', 25.7819500, -100.1883900, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97169, 'Apatzingán', 'Apatzingan', 'AZG,Apantzincan,Apatzingan,Apatzingan de la Constitucion,Apatzingán,Apatzingán de la Constitución,a pa qin gan,apatzyngan,اپاتزینگان,阿帕欽甘', 19.0886400, -102.3570400, 'MX', '2013-11-24', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97170, 'Apaseo el Grande', 'Apaseo el Grande', 'Apaseo,Apaseo el Grande,Apaseo-ehl''-Grande,Villa Apaseo,Апасео-эль-Гранде', 20.5449500, -100.6846200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97171, 'Apaseo el Alto', 'Apaseo el Alto', 'Apaseo,Apaseo el Alto,Apaseo-ehl''-Al''to,Апасео-эль-Альто', 20.4579800, -100.6208100, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97172, 'Antúnez', 'Antunez', 'Antunes,Antunez,Antúnez,Atunez,Morelos', 19.0145100, -102.2043200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97173, 'Antonio Escobedo', 'Antonio Escobedo', '', 20.8000000, -104.0166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97174, 'San Juanito de Escobedo', 'San Juanito de Escobedo', 'Antonio Escobedo,San Juanito,San Juanito de Escobedo', 20.7943600, -104.0024500, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97175, 'Angostura', 'Angostura', 'Angostura', 25.3658600, -108.1610700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97176, 'Angamacutiro de la Unión', 'Angamacutiro de la Union', 'Angamacutiro,Angamacutiro de la Union,Angamacutiro de la Unión,San Francisco', 20.1499800, -101.7111300, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97177, 'Angahuán', 'Angahuan', 'Angahuan,Angahuán', 19.5479000, -102.2256300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97178, 'Anáhuac', 'Anahuac', 'Anahuac,Anáhuac,Colonia Anahuac,Colonia Anáhuac', 28.4839600, -106.7472000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97179, 'Ameca', 'Ameca', 'Ameca,Municipio Ameca,Opstina Ameca,Opština Ameca,amyka  jalyskw,امیکا، جالیسکو', 20.5462900, -104.0450800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97180, 'Amealco', 'Amealco', 'Amealco', 20.1875800, -100.1448500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97181, 'Amatlán de Cañas', 'Amatlan de Canas', 'Amatlan de Canas,Amatlán de Cañas', 20.8069900, -104.4040800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97182, 'Amatitán', 'Amatitan', 'Amatitan,Amatitán', 20.8338800, -103.7307600, 'MX', '2016-04-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97183, 'Amatepec', 'Amatepec', 'Amatepec', 18.6822200, -100.1858300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97184, 'Amazcala', 'Amazcala', 'Amascala,Amazcala', 20.7033900, -100.2651100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97185, 'Amanalco de Becerra', 'Amanalco de Becerra', '', 19.3166700, -100.0166700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97186, 'Amacueca', 'Amacueca', 'Ainacueca,Amacueca', 20.0106900, -103.5998300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97187, 'Álvaro Obregón', 'Alvaro Obregon', 'Alvaro Obregon,San Bartolo,Álvaro Obregón', 19.8209600, -101.0400800, 'MX', '2016-03-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97188, 'Altar', 'Altar', 'Altar', 30.7153800, -111.8370300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97189, 'Altar', 'Altar', 'Altar', 30.7162600, -111.8365300, 'MX', '2016-12-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97190, 'Almoloya de las Granadas', 'Almoloya de las Granadas', 'Almoloya,Almoloya de las Granadas', 18.9730900, -100.1333500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97191, 'Allende', 'Allende', 'Allende', 28.3412400, -100.8511100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97192, 'Allende', 'Allende', 'Allende', 25.2767300, -100.0144200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97193, 'Alista', 'Alista', 'Alista', 19.6348700, -103.7894500, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97194, 'Alhuey', 'Alhuey', '', 25.3780600, -108.1302800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97195, 'Aldama', 'Aldama', 'Aldama,Jaripitio,Jaripito', 20.8164100, -101.3146700, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97196, 'Alcocer', 'Alcocer', 'Alcocer', 20.8686700, -100.7045600, 'MX', '2016-07-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97197, 'Alamos', 'Alamos', 'Alamos,XAL,Álamos', 27.0232600, -108.9344000, 'MX', '2016-12-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97198, 'Ajuchitlán del Progreso', 'Ajuchitlan del Progreso', 'Ajuchitlan', 18.1518900, -100.4835300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97199, 'Ajuchitlán', 'Ajuchitlan', 'Ajuchitlan,Ajuchitlán,Juchitan,Juchitlan,Juchitlán,Juchitán,San Jose de Gracia Ajuchitlan,San José de Gracia Ajuchitlán', 20.7071300, -100.0200800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97200, 'Ajijic', 'Ajijic', 'Ajijic,Ajijoy', 20.3032500, -103.2547600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97201, 'Ahuirán', 'Ahuiran', 'Ahuiran,Ahuirán', 19.6657400, -102.0734700, 'MX', '2014-11-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97202, 'Ahualulco de Mercado', 'Ahualulco de Mercado', 'Ahualulco', 20.7013700, -103.9746100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97203, 'Ahualulco', 'Ahualulco', 'Ahualulco', 22.4001900, -101.1661400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97204, 'Ahuacatlán', 'Ahuacatlan', 'Ahuacatlan,Ahuacatlán', 21.0540500, -104.4839800, 'MX', '2014-09-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97205, 'Ahome', 'Ahome', 'Ahoma,Ahome', 25.9198500, -109.1732000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97206, 'Aguililla', 'Aguililla', 'Aguililla,Aguililla de Iturbide', 18.7374200, -102.7893400, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97207, 'Agua Verde', 'Agua Verde', 'Agua Verde', 22.8925900, -105.9735500, 'MX', '2017-05-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97208, 'Aguascalientes', 'Aguascalientes', 'AGU,Aguascalientes,Aguascalientes City,Aguascalientes by,Aguaskal''entes,Aguaskalentes,Aguaskalientes,Aguaskaljentesas,Agvaskalijentes,Altepetl Aguascalientes,Byen Aguascalientes,Ciudad de Aguascalientes,a gua si ka lian te si,aguasukarientesu,agwaseukallienteseu,agwyaskalynts,xa k was ka leiyn tes,Агваскалијентес,Агуаскалиентес,Агуаскальентес,Аґуаскальєнтес,אגואסקליינטס,آگوئاسکالینتس,آگوسکالینٹس,อากวัสกาเลียนเตส,აგუასკალიენტესი,アグアスカリエンテス,阿瓜斯卡连特斯,아과스칼리엔테스', 21.8823400, -102.2825900, 'MX', '2014-08-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97209, 'Agua Prieta', 'Agua Prieta', 'Agua Prieta', 31.3307100, -109.5487600, 'MX', '2016-12-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97210, 'Agua Caliente Grande (De Gastélum)', 'Agua Caliente Grande (De Gastelum)', '', 26.5376200, -108.3481400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97211, 'Agiabampo Uno', 'Agiabampo Uno', 'Agiabampo', 26.3668600, -109.1457200, 'MX', '2016-12-10', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97212, 'Adolfo Ruíz Cortínes', 'Adolfo Ruiz Cortines', 'Adolfo Ruiz Cortines,Adolfo Ruiz Cortinez,Adolfo Ruiz Cortínez,Adolfo Ruíz Cortínes,Ruiz Cortines,Ruiz Cortines Numero Tres,Ruíz Cortines Número Tres', 25.7500000, -108.7500000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97213, 'Acuítzio del Canje', 'Acuitzio del Canje', 'Acuitzio,Acuitzio del Canje,Acuítzio del Canje', 19.4958500, -101.3332100, 'MX', '2016-01-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97214, 'Aconchi', 'Aconchi', 'Aconchi,Conchi', 29.8262800, -110.2249200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97215, 'Acatic', 'Acatic', '', 20.7799500, -102.9105600, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97216, 'Acaponeta', 'Acaponeta', 'Acaponeta', 22.4939600, -105.3636900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97217, 'Acapetlahuaya', 'Acapetlahuaya', 'Acapetlahuaya', 18.4194200, -100.0723700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97218, 'Acámbaro', 'Acambaro', 'Acambaro,Acámbaro,Akambaro,a kan ba luo,akambarw,Акамбаро,اکامبارو,阿坎巴罗', 20.0302400, -100.7224900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97219, 'Abasolo', 'Abasolo', 'Abasolo', 25.9459500, -100.3958400, 'MX', '2017-01-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97220, 'Abasolo', 'Abasolo', 'Abasolo,Cuitzeo de Abasolo,Cuitzeo de Hidalgo,Villa Abasolo,Абасоло', 20.4499700, -101.5307300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97221, 'Ramón Corona', 'Ramon Corona', '', 24.1861100, -103.6302800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97222, 'La Presa', 'La Presa', 'La Presa', 22.3435800, -105.3935000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97223, 'Mesa Grande', 'Mesa Grande', '', 21.8050000, -102.7216700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97224, 'La Labor', 'La Labor', '', 21.9620700, -102.6962600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97225, 'San Antonio de los Ríos', 'San Antonio de los Rios', 'San Antonio de los Rios,San Antonio de los Ríos', 22.1610400, -102.4711800, 'MX', '2014-08-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97226, 'San José de Gracia', 'San Jose de Gracia', 'San Jose de Gracia,San José de Gracia', 22.1483300, -102.4158300, 'MX', '2013-08-03', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97227, 'Valladolid', 'Valladolid', '', 22.0211100, -102.3150000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97228, 'Jesús Gómez Portugal (Margaritas)', 'Jesus Gomez Portugal (Margaritas)', '', 21.9991700, -102.2913900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97229, 'Paseos de la Providencia [Fraccionamiento]', 'Paseos de la Providencia [Fraccionamiento]', '', 22.0242500, -102.2771100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97230, 'Peñuelas (El Cienegal)', 'Penuelas (El Cienegal)', '', 21.7225000, -102.2758300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97231, 'El Refugio de Providencia (Providencia)', 'El Refugio de Providencia (Providencia)', '', 22.3466700, -102.2577800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97232, 'Puertecito de la Virgen', 'Puertecito de la Virgen', '', 21.9602800, -102.2688900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97233, 'San Jacinto', 'San Jacinto', '', 22.3486100, -102.2336100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97234, 'Jaltomate', 'Jaltomate', '', 22.0152800, -102.1458300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97235, 'Villa Juárez', 'Villa Juarez', 'Villa Juarez,Villa Juárez', 22.0944700, -102.0693000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97236, 'Noria del Borrego (Norias)', 'Noria del Borrego (Norias)', '', 22.2872200, -102.0419400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97237, 'Guadalupe de Atlas', 'Guadalupe de Atlas', '', 22.2677800, -102.0313900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97238, 'Bahía Asunción', 'Bahia Asuncion', 'Bahia Asuncion,Bahía Asunción', 27.1423100, -114.2958200, 'MX', '2014-04-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97239, 'Villa Morelos', 'Villa Morelos', '', 24.9300000, -111.6280600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97240, 'El Pescadero', 'El Pescadero', 'El Pescadero', 23.3641700, -110.1683300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97241, 'Hidalgo', 'Hidalgo', 'Cementos Hidalgo,Hidalgo,Idal''go,San Nicolas Hidalgo,San Nicolás Hidalgo,Идальго', 25.9720500, -100.4502900, 'MX', '2017-01-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97242, 'Anáhuac', 'Anahuac', 'Anahuac,Anáhuac', 27.2405600, -100.1322200, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97243, 'Victoria', 'Victoria', 'Victoria', 21.2118300, -100.2154500, 'MX', '2016-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97244, 'Doctor Mora', 'Doctor Mora', 'Charcas,Doctor Mora,Villa Doctor Mora', 21.1424600, -100.3196600, 'MX', '2016-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97245, 'Palo Colorado', 'Palo Colorado', 'Palo Colorado', 21.0083600, -100.7291700, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97246, 'San Isidro de la Estacada', 'San Isidro de la Estacada', '', 21.1474600, -100.6847300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97247, 'Dolores Hidalgo Cuna de la Independencia Nacional', 'Dolores Hidalgo Cuna de la Independencia Nacional', 'Ciudad de Dolores Hidalgo,Dolores Hidalgo', 21.1561100, -100.9325000, 'MX', '2016-02-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97248, 'El Refugio de los Sauces', 'El Refugio de los Sauces', 'El Refugio de los Sauces,El Sauce,Los Sauces', 21.0148800, -101.5308400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97249, 'San José del Torreón', 'San Jose del Torreon', '', 21.4744400, -101.4705600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97250, 'Xichú', 'Xichu', 'Xichu,Xichú', 21.2997200, -100.0552800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97251, 'El Tejocote (El Domingo)', 'El Tejocote (El Domingo)', '', 21.6761100, -100.9150000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97252, 'Chirimoya (Estación Chirimoya)', 'Chirimoya (Estacion Chirimoya)', '', 21.5927800, -101.0913900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97253, 'Maravatío del Encinal', 'Maravatio del Encinal', 'Huerta de Maravatio,Huerta de Maravatío,Maravatio,Maravatio del Encinal,Maravatío,Maravatío del Encinal', 20.2051400, -100.9633100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97254, 'Mezquite de Luna', 'Mezquite de Luna', 'Mezquite de Luna', 20.2976500, -101.8926000, 'MX', '2016-07-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97255, 'Zapote de Barajas', 'Zapote de Barajas', 'Zapote de Barajas', 20.3753600, -101.6996400, 'MX', '2016-07-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97256, 'Pastor Ortíz', 'Pastor Ortiz', 'Pastor Ortiz,Pastor Ortíz', 20.3055200, -101.5958800, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97257, 'El Sauz (El Sauz de Villaseñor)', 'El Sauz (El Sauz de Villasenor)', '', 20.4105600, -100.7966700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97258, 'La Calera', 'La Calera', '', 20.3015200, -100.8456100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97259, 'San Juan Bautista Cacalote', 'San Juan Bautista Cacalote', '', 20.3480600, -100.7883300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97260, 'El Salto de Espejo', 'El Salto de Espejo', 'El Salto de Espejo', 20.4504500, -100.5058700, 'MX', '2016-07-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97261, 'San Cayetano', 'San Cayetano', '', 20.6033300, -100.8194400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97262, 'Gasca', 'Gasca', '', 20.6044400, -100.8563900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97263, 'Franco Tavera', 'Franco Tavera', 'Franco Tavera', 20.6059500, -100.9270000, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97264, 'El Divisador', 'El Divisador', '', 20.5772200, -101.1580600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97265, 'San José de la Montaña', 'San Jose de la Montana', 'San Jose de la Montana,San José de la Montaña', 20.6003700, -101.0722800, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97266, 'Sarabia', 'Sarabia', 'C. Militar Sarabia,Sarabia', 20.5225600, -101.0616300, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97267, 'Mexicanos', 'Mexicanos', 'Mexicanos', 20.5290300, -101.0706400, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97268, 'La Tinaja', 'La Tinaja', '', 20.4902800, -101.2155600, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97269, 'La Capilla', 'La Capilla', 'La Capilla', 20.5565500, -101.3001900, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97270, 'San Vicente de Flores', 'San Vicente de Flores', 'San Vicente Flores,San Vicente de Flores', 20.6217200, -101.2529600, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97271, 'Cuchicuato', 'Cuchicuato', 'Cuchicuato', 20.6609200, -101.4620300, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97272, 'Colonia Morelos de Guadalupe de Rivera', 'Colonia Morelos de Guadalupe de Rivera', '', 20.5955600, -101.4483300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97273, 'San Ignacio de Rivera (Ojo de Agua)', 'San Ignacio de Rivera (Ojo de Agua)', 'Ojo de Agua,San Ignacio de Rivera', 20.5592600, -101.4612700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97274, 'Plan Guanajuato (La Sandía)', 'Plan Guanajuato (La Sandia)', '', 20.9216700, -101.6969400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97275, 'Medio Sitio', 'Medio Sitio', 'El Medio Sitio,Medio Sitio', 20.8694800, -101.3568900, 'MX', '2014-11-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97276, 'Bajío de Bonillas', 'Bajio de Bonillas', '', 20.9494400, -101.4952800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97277, 'Colonia Nuevo México', 'Colonia Nuevo Mexico', 'Colonia Nuevo Mexico,Colonia Nuevo México,Colonias de Nuevo Mexico,Colonias de Nuevo México,Las Colonias,Nuehvo-Meksiko,Nuevo Mexico,Nuevo México,Нуэво-Мексико', 20.9847500, -101.4850200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97278, 'San José del Rodeo', 'San Jose del Rodeo', 'El Rodeo,Rodeo,San Jose del Rodeo,San José del Rodeo', 20.9208300, -101.2163900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97279, 'Santa Catarina', 'Santa Catarina', 'Santa Catarina', 21.1418700, -100.0699400, 'MX', '2016-06-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97280, 'Potrerillos (Guanajal)', 'Potrerillos (Guanajal)', 'Guanajal,Potrerillos', 21.0815400, -101.8698600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97281, 'La Ortiga', 'La Ortiga', '', 19.9622200, -101.0005600, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97282, 'Los Fierros', 'Los Fierros', 'Fierros,Los Fierros', 20.1940700, -100.7593700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97283, 'Ansihuacuaro', 'Ansihuacuaro', 'Ancihuacaro,Anishuacaro', 20.1997200, -101.8077800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97284, 'Isaac Arriaga (Santa Ana Mancera)', 'Isaac Arriaga (Santa Ana Mancera)', '', 20.2458300, -101.4936100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97285, 'Cuamio', 'Cuamio', '', 20.0325000, -101.1488900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97286, 'San Antonio Molinos', 'San Antonio Molinos', 'San Antonio Molinos,San Antonio de Molinos', 20.0753300, -100.2150100, 'MX', '2014-11-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97287, 'Santa María de los Ángeles', 'Santa Maria de los Angeles', '', 19.7862900, -100.1993800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97288, 'Manzana de San Luis', 'Manzana de San Luis', '', 19.5623600, -100.2770300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97289, 'Irimbo', 'Irimbo', 'Irimbo', 19.7008300, -100.4784700, 'MX', '2016-11-23', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97290, 'Mesón Nuevo (Cañada de la Magdalena)', 'Meson Nuevo (Canada de la Magdalena)', '', 19.8147400, -101.1659700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97291, 'Santiago Azajo', 'Santiago Azajo', '', 19.7066700, -101.6863900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97292, 'Zopoco', 'Zopoco', 'Zocopo,Zopoco', 19.8402900, -102.0748300, 'MX', '2014-11-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97293, 'Tancítaro', 'Tancitaro', '', 19.3375000, -102.3630600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97294, 'Las Cañas', 'Las Canas', '', 18.5658300, -101.9761100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97295, 'Guacamayas', 'Guacamayas', 'Guacamayas,Las Guacamayas', 18.0193200, -102.2122500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97296, 'Ciudad Lázaro Cárdenas', 'Ciudad Lazaro Cardenas', 'Ciudad Lazaro Cardenas,Ciudad Lázaro Cárdenas,LZC,Lazaro Cardenas,Lázaro Cárdenas,Melchor Ocampo,Melchor Ocampo del Balsas', 17.9706600, -102.2212400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97297, 'Infiernillo (Morelos de Infiernillo)', 'Infiernillo (Morelos de Infiernillo)', 'Infiernillo,Infiernillo de Morelos', 18.2825000, -101.9011100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97298, 'Santa Ana Zicatecoyan', 'Santa Ana Zicatecoyan', '', 18.5716700, -100.2200000, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97299, 'San Simón de Guerrero', 'San Simon de Guerrero', '', 19.0211100, -100.0041700, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97300, 'San Pedro Tenayac', 'San Pedro Tenayac', '', 19.0466700, -100.1769400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97301, 'Zacazonapan', 'Zacazonapan', 'Zacazonapan', 19.0731700, -100.2551500, 'MX', '2016-01-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97302, 'Otzoloapan', 'Otzoloapan', 'Otzoloapan,San Martin Otzoloapan,San Martín Otzoloapan', 19.1172800, -100.2968400, 'MX', '2016-01-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97303, 'Cuadrilla de Dolores', 'Cuadrilla de Dolores', '', 19.1400000, -100.0694400, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97304, 'Casas Viejas', 'Casas Viejas', '', 19.1516700, -100.1077800, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97305, 'San Bartolo', 'San Bartolo', '', 19.2488900, -100.0558300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97306, 'Amanalco de Becerra', 'Amanalco de Becerra', 'Amanalco de Becerra', 19.2537400, -100.0198000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97307, 'Santa Rosa de Lima', 'Santa Rosa de Lima', 'Santa Rosa de Lima', 19.7858700, -100.0960600, 'MX', '2014-11-30', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97308, 'Las Rosas', 'Las Rosas', 'Las Rosas', 19.5463100, -100.1598600, 'MX', '2014-11-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97309, 'San Ildefonso', 'San Ildefonso', 'San Ildefonso', 19.3491900, -100.1379000, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97310, 'Pantla', 'Pantla', '', 17.7386100, -101.6363900, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97311, 'San José Ixtapa (Barrio Viejo)', 'San Jose Ixtapa (Barrio Viejo)', '', 17.7022200, -101.6194400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97312, 'Los Almendros', 'Los Almendros', '', 17.6116700, -101.4391700, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97313, 'San Jerónimo el Grande', 'San Jeronimo el Grande', '', 18.2116700, -100.5017900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97314, 'El Ticui', 'El Ticui', '', 17.2163900, -100.4447200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97315, 'Arenal de Álvarez (Arenal de Paco)', 'Arenal de Alvarez (Arenal de Paco)', '', 17.1261100, -100.4550000, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97316, 'Colonia Luces en el Mar', 'Colonia Luces en el Mar', 'Colonia Luces en el Mar,Luces en el Mar', 16.9216200, -100.0152600, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97317, 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', '', 21.8286100, -105.2197200, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97318, 'Las Jarretaderas', 'Las Jarretaderas', '', 20.6925000, -105.2738900, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97319, 'Las Lajitas', 'Las Lajitas', 'Las Lajitas', 20.8036000, -100.4010700, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97320, 'Montenegro', 'Montenegro', '', 20.7633300, -100.4286100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97321, 'Santa Catarina', 'Santa Catarina', 'Santa Catarina', 20.7767800, -100.4523300, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97322, 'La Luz', 'La Luz', 'La Luz', 20.8685700, -100.4383900, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97323, 'Colonia los Ángeles', 'Colonia los Angeles', '', 20.5352300, -100.4882800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97324, 'Los Cerritos', 'Los Cerritos', 'Los Cerritos', 20.5620400, -100.0633800, 'MX', '2014-09-06', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97325, 'Apapátaro', 'Apapataro', 'Apapataro,Apapátaro', 20.4680600, -100.3686100, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97326, 'Charco Blanco', 'Charco Blanco', 'Charco Blanco', 20.4340400, -100.4724400, 'MX', '2016-07-05', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97327, 'Las Taponas', 'Las Taponas', '', 20.4166700, -100.3833300, 'MX', '2013-07-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97328, 'Santiago Mexquititlán Barrio 4to.', 'Santiago Mexquititlan Barrio 4to.', '', 20.0630600, -100.0683300, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97329, 'San Juan De Los Platanos', 'San Juan De Los Platanos', '', 19.1371000, -102.4392900, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97330, 'Huapinol', 'Huapinol', '', 17.9228500, -92.9109000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97331, 'Zapopan2', 'Zapopan2', '', 20.7167000, -103.4000000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97332, 'Colonia del Valle', 'Colonia del Valle', 'Col del valle,Col. del Valle,del Valle', 19.3861100, -99.1620400, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97333, 'Colonia Lindavista', 'Colonia Lindavista', 'Col Lindavista,Col. Lindavista,Lindavista', 19.4915600, -99.1247500, 'MX', '2015-03-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97334, 'Col. Bosques de las Lomas', 'Col. Bosques de las Lomas', 'Bosques de las Lomas,Col Bosques de las Lomas,Col. Bosques,Col. Bosques de las Lomas,Colonia Bosques,Colonia Bosques de las Lomas', 19.3789300, -99.2658700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97335, 'Colonia Nativitas', 'Colonia Nativitas', 'Col Nativitas,Col. Nativitas,Nativitas', 19.3811900, -99.1368500, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97336, 'El Castillo', 'El Castillo', '', 20.5807200, -100.4929700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97337, 'Las Higuerillas', 'Las Higuerillas', 'Higuerillas', 25.2622200, -97.4361100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97338, 'El Barrancón del Tío Blas (El Barrancón)', 'El Barrancon del Tio Blas (El Barrancon)', 'El Barrancon,El Barrancón', 25.0155600, -97.7169400, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97339, 'La Isla Km 10', 'La Isla Km 10', '', 20.6067700, -97.4995000, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97340, 'Poblado Lázaro Cárdenas (La Veintiocho)', 'Poblado Lazaro Cardenas (La Veintiocho)', 'Lazaro Cardenas,Lázaro Cárdenas', 32.3733300, -115.0652800, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97341, 'Ejido Doctor Alberto Oviedo Mota (El Indiviso)', 'Ejido Doctor Alberto Oviedo Mota (El Indiviso)', 'Ejido Alberto Oviedo Mota,El Indiviso', 32.0244400, -114.9836100, 'MX', '2013-08-01', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97342, 'San Luis', 'San Luis', 'San Luis', 32.4316700, -116.9536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97343, 'Las Delicias', 'Las Delicias', 'Las Delicias', 32.4088900, -116.9436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97344, 'Ejido Javier Rojo Gómez', 'Ejido Javier Rojo Gomez', 'Ejido Javier Rojo Gomez,Ejido Javier Rojo Gómez', 32.4938900, -116.8222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97345, 'Ejido Ojo de Agua', 'Ejido Ojo de Agua', 'Ejido Ojo de Agua', 32.4755600, -116.7891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97346, 'San Pedro Garza Garcia', 'San Pedro Garza Garcia', 'Garza Garcia,Garza García,San Pedro,San Pedro Garza Garcia,San Pedro Garza García', 25.6571600, -100.4026800, 'MX', '2013-10-04', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97347, 'La Nueva Victoria', 'La Nueva Victoria', 'La Nueva Victoria', 18.6563900, -95.2580600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97348, 'Estación Santa Engracia', 'Estacion Santa Engracia', 'Estacion Santa Engracia,Estación Santa Engracia', 24.0152800, -99.2019400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97349, 'Maya Balam', 'Maya Balam', 'Maya Balam', 18.9391700, -88.3997200, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97350, 'Morocoy', 'Morocoy', 'Morocoy', 18.6032400, -88.8109700, 'MX', '2016-11-23', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97351, 'Don Samuel', 'Don Samuel', 'Don Samuel', 18.3600000, -90.8572200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97352, 'Xbacab', 'Xbacab', 'Xbacab', 18.9413900, -90.7219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97353, 'Aurelio Manrique', 'Aurelio Manrique', 'Aurelio Manrique', 22.2875000, -98.6508300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97354, 'Ponciano Arriaga', 'Ponciano Arriaga', 'Ponciano Arriaga', 22.2622200, -98.5897200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97355, 'Guayalejo', 'Guayalejo', 'Guayalejo', 22.3830600, -98.4830600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97356, 'Plan de Ayala', 'Plan de Ayala', 'Plan de Ayala', 22.5402800, -98.7672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97357, 'Estación Tamuín', 'Estacion Tamuin', 'Estacion Tamuin,Estación Tamuín', 22.0775000, -98.8111100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97358, 'San José', 'San Jose', 'San Jose,San José', 21.0691700, -98.5944400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97359, 'Machetla', 'Machetla', 'Machetla', 21.0594600, -98.4944500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97360, 'Chililico', 'Chililico', 'Chililico', 21.1344400, -98.4355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97361, 'Ricardo Flores Magón', 'Ricardo Flores Magon', 'Ricardo Flores Magon,Ricardo Flores Magón', 20.5144400, -97.4950000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97362, 'Rancho Nuevo', 'Rancho Nuevo', 'Rancho Nuevo', 20.6725000, -97.2061100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97363, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 20.3505400, -97.9363000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97364, 'San Antonio Ocopetlatlán', 'San Antonio Ocopetlatlan', 'San Antonio Ocopetlatlan,San Antonio Ocopetlatlán', 20.2470300, -97.9462100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97365, 'Ahuaxintitla', 'Ahuaxintitla', 'Ahuaxintitla', 20.2532500, -97.8956100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97366, 'El Chote', 'El Chote', 'El Chote', 20.4016700, -97.3438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97367, 'La Unión Paso Largo', 'La Union Paso Largo', 'La Union Paso Largo,La Unión Paso Largo', 20.1422400, -96.9999500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97368, 'Las Sabinas', 'Las Sabinas', 'Las Sabinas', 21.3180600, -97.8808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97369, 'El Lindero', 'El Lindero', 'El Lindero', 21.3127800, -98.2200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97370, 'La Unión', 'La Union', 'La Union,La Unión', 20.8922200, -97.6652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97371, 'La Palma', 'La Palma', 'La Palma', 28.0502800, -110.7011100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97372, 'Estación Zamora', 'Estacion Zamora', 'Estacion Zamora,Estación Zamora,Zamora', 29.2611600, -110.8865300, 'MX', '2015-02-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97373, 'Bacobampo', 'Bacobampo', 'Bacobampo', 26.9827800, -109.6519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97374, 'Soledad de Graciano Sánchez', 'Soledad de Graciano Sanchez', 'Soledad de Graciano Sanchez,Soledad de Graciano Sánchez', 22.1830600, -100.9408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97375, 'Manzanillo', 'Manzanillo', 'Cozcatlan,Mansanil''o,Manzanillo,man sa ni yue,mansaniyo,mansanyw  kwlyma,manzanylw,mnsnyw,wen cheng li you,Мансанильо,מנסניו,مانزانیلو,مانسانیو، کولیما,文成李祐,曼萨尼约,만사니요', 19.0522200, -104.3158300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97376, 'Naucalpan de Juárez', 'Naucalpan de Juarez', 'Naucalpan de Juarez,Naucalpan de Juárez', 19.3969400, -99.2766700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97377, 'Hacienda Santa Fe', 'Hacienda Santa Fe', 'Hacienda Santa Fe', 20.5180600, -103.3805600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97378, 'Fuentes del Valle', 'Fuentes del Valle', 'Fuentes del Valle', 19.6325000, -99.1386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97379, 'San Salvador Tizatlalli', 'San Salvador Tizatlalli', 'San Salvador Tizatlalli', 19.2602800, -99.5908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97380, 'Jardines de la Silla (Jardines)', 'Jardines de la Silla (Jardines)', 'Jardines de la Silla (Jardines)', 25.6294400, -100.1877800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97381, 'San Buenaventura', 'San Buenaventura', 'San Buenaventura', 19.3025000, -98.8630600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97382, 'Colonia Santa Teresa', 'Colonia Santa Teresa', 'Colonia Santa Teresa', 19.8450000, -99.2333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97383, 'San Jerónimo Cuatro Vientos', 'San Jeronimo Cuatro Vientos', 'San Jeronimo Cuatro Vientos,San Jerónimo Cuatro Vientos', 19.2930600, -98.8416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97384, 'San Martín Azcatepec', 'San Martin Azcatepec', 'San Martin Azcatepec,San Martín Azcatepec', 19.6866700, -98.9727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97385, 'Fraccionamiento Real Palmas', 'Fraccionamiento Real Palmas', 'Fraccionamiento Real Palmas', 25.9041700, -100.1597200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97386, 'Pórticos de San Antonio', 'Porticos de San Antonio', 'Porticos de San Antonio,Pórticos de San Antonio', 32.4425000, -117.0341700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97387, 'San Isidro', 'San Isidro', 'San Isidro', 19.3397200, -98.9505600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97388, 'Centro Familiar la Soledad', 'Centro Familiar la Soledad', 'Centro Familiar la Soledad', 21.1350000, -101.7497200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97389, 'San José Guadalupe Otzacatipan', 'San Jose Guadalupe Otzacatipan', 'San Jose Guadalupe Otzacatipan,San José Guadalupe Otzacatipan', 19.3447200, -99.5919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97390, 'Las Pintitas', 'Las Pintitas', 'Las Pintitas', 20.5644400, -103.3022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97391, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 19.3436100, -98.9747200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97392, 'San Antonio Tecómitl', 'San Antonio Tecomitl', 'San Antonio Tecomitl,San Antonio Tecómitl', 19.2177800, -98.9880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97393, 'Licenciado Benito Juárez (Campo Gobierno)', 'Licenciado Benito Juarez (Campo Gobierno)', 'Licenciado Benito Juarez (Campo Gobierno),Licenciado Benito Juárez (Campo Gobierno)', 24.6566700, -107.5450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97394, 'Teotihuacán de Arista', 'Teotihuacan de Arista', 'Teotihuacan de Arista,Teotihuacán de Arista', 19.6897200, -98.8608300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97395, 'Jesús del Monte', 'Jesus del Monte', 'Jesus del Monte,Jesús del Monte', 19.3750000, -99.2944400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97396, 'San Jorge Pueblo Nuevo', 'San Jorge Pueblo Nuevo', 'San Jorge Pueblo Nuevo', 19.2541700, -99.6277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97397, 'Manuel Ojinaga', 'Manuel Ojinaga', 'Manuel Ojinaga', 29.5644400, -104.4163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97398, 'Terrazas del Valle', 'Terrazas del Valle', 'Terrazas del Valle', 32.4875000, -116.8266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97399, 'La Ermita', 'La Ermita', 'La Ermita', 21.1519400, -101.7330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97400, 'Lomas del Sur', 'Lomas del Sur', 'Lomas del Sur', 20.4925000, -103.4175000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97401, 'Parque Industrial Ciudad Mitras', 'Parque Industrial Ciudad Mitras', 'Parque Industrial Ciudad Mitras', 25.7886100, -100.4477800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97402, 'Mitras Poniente', 'Mitras Poniente', 'Mitras Poniente', 25.7758300, -100.4258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97403, 'Villa del Prado 2da Sección', 'Villa del Prado 2da Seccion', 'Villa del Prado 2da Seccion,Villa del Prado 2da Sección', 32.4238900, -116.9716700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97404, 'Tres de Mayo', 'Tres de Mayo', 'Tres de Mayo', 18.8686100, -99.2083300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97405, 'Don Antonio', 'Don Antonio', 'Don Antonio', 19.8744400, -98.9347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97406, 'Heroica Ciudad de Tlaxiaco', 'Heroica Ciudad de Tlaxiaco', 'Heroica Ciudad de Tlaxiaco', 17.2694400, -97.6791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97407, 'Ciudad de Huitzuco', 'Ciudad de Huitzuco', 'Ciudad de Huitzuco', 18.3011100, -99.3311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97408, 'Casa Blanca', 'Casa Blanca', 'Casa Blanca', 19.0422200, -98.1188900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97409, 'La Providencia Siglo XXI', 'La Providencia Siglo XXI', 'La Providencia Siglo XXI', 20.0641700, -98.7172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97410, 'Ampliación San Mateo (Colonia Solidaridad)', 'Ampliacion San Mateo (Colonia Solidaridad)', 'Ampliacion San Mateo (Colonia Solidaridad),Ampliación San Mateo (Colonia Solidaridad)', 19.6163900, -99.1472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97411, 'Fraccionamiento Ciudad Olmeca', 'Fraccionamiento Ciudad Olmeca', 'Fraccionamiento Ciudad Olmeca', 18.1505600, -94.5525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97412, 'San Rafael Tlanalapan', 'San Rafael Tlanalapan', 'San Rafael Tlanalapan', 19.2916700, -98.4680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97413, 'Tecámac de Felipe Villanueva', 'Tecamac de Felipe Villanueva', 'Tecamac de Felipe Villanueva,Tecámac de Felipe Villanueva', 19.7130600, -98.9683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97414, 'Venceremos', 'Venceremos', 'Venceremos', 20.5508300, -100.3980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97415, 'Alborada Jaltenco', 'Alborada Jaltenco', 'Alborada Jaltenco', 19.6619400, -99.0688900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97416, 'Crucecita', 'Crucecita', 'Crucecita', 15.7688900, -96.1350000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97417, 'Progreso', 'Progreso', 'Progreso', 18.8800800, -99.1526000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97418, 'Santa Clara del Cobre', 'Santa Clara del Cobre', 'Santa Clara del Cobre', 19.4052800, -101.6383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97419, 'Palmira', 'Palmira', 'Palmira', 18.8827800, -97.1113900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97420, 'Villa de El Carmen Tequexquitla', 'Villa de El Carmen Tequexquitla', 'Villa de El Carmen Tequexquitla', 19.3244400, -97.6558300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97421, 'Real del Valle (El Paraíso) [Fraccionamiento]', 'Real del Valle (El Paraiso) [Fraccionamiento]', 'Real del Valle (El Paraiso) [Fraccionamiento],Real del Valle (El Paraíso) [Fraccionamiento]', 20.5455600, -103.3697200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97422, 'Villa del Campo', 'Villa del Campo', 'Villa del Campo', 32.5075000, -116.7383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97423, 'Vicente Guerrero', 'Vicente Guerrero', 'Vicente Guerrero', 16.9330600, -96.7013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97424, 'Morelos', 'Morelos', 'Morelos', 19.6488900, -101.2388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97425, 'Centro de Readaptación Social', 'Centro de Readaptacion Social', 'Centro de Readaptacion Social,Centro de Readaptación Social', 20.5544400, -103.1936100, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97426, 'Veintidós de Febrero', 'Veintidos de Febrero', 'Veintidos de Febrero,Veintidós de Febrero', 19.6113900, -99.3466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97427, 'Fraccionamiento Geovillas los Pinos', 'Fraccionamiento Geovillas los Pinos', 'Fraccionamiento Geovillas los Pinos', 19.2172200, -96.2263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97428, 'Juan Morales', 'Juan Morales', 'Juan Morales', 18.8113900, -98.9219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97429, 'Santa María Zacatepec', 'Santa Maria Zacatepec', 'Santa Maria Zacatepec,Santa María Zacatepec', 19.1233300, -98.3652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97430, 'La Tijera', 'La Tijera', 'La Tijera', 20.5816700, -103.4405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97431, 'Lomas de San Agustín', 'Lomas de San Agustin', 'Lomas de San Agustin,Lomas de San Agustín', 20.5275000, -103.4677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97432, 'Córdoba (Santa Leticia)', 'Cordoba (Santa Leticia)', 'Cordoba (Santa Leticia),Córdoba (Santa Leticia)', 18.9086100, -96.9788900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97433, 'Las Palmas', 'Las Palmas', 'Las Palmas', 22.9367200, -109.9423500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97434, 'San Francisco Tecoxpa', 'San Francisco Tecoxpa', 'San Francisco Tecoxpa', 19.1916700, -99.0063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97435, 'La Resolana', 'La Resolana', 'La Resolana', 19.6036100, -104.4347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97436, 'Villas de la Hacienda [Fraccionamiento]', 'Villas de la Hacienda [Fraccionamiento]', 'Villas de la Hacienda [Fraccionamiento]', 20.5311100, -103.3827800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97437, 'Conjunto Habitacional Villas del Pedregal', 'Conjunto Habitacional Villas del Pedregal', 'Conjunto Habitacional Villas del Pedregal', 19.6836100, -101.3036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97438, 'Pomoca', 'Pomoca', 'Pomoca', 18.0497200, -92.9305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97439, 'Simojovel de Allende', 'Simojovel de Allende', 'Simojovel de Allende', 17.1400000, -92.7150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97440, 'Puerto Escondido (Tepeolulco Puerto Escondido)', 'Puerto Escondido (Tepeolulco Puerto Escondido)', 'Puerto Escondido (Tepeolulco Puerto Escondido)', 19.5519400, -99.0980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97441, 'Unidad Habitacional José María Morelos y Pavón', 'Unidad Habitacional Jose Maria Morelos y Pavon', 'Unidad Habitacional Jose Maria Morelos y Pavon,Unidad Habitacional José María Morelos y Pavón', 18.8202800, -99.2622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97442, 'Nueva Palestina', 'Nueva Palestina', 'Nueva Palestina', 16.8172200, -91.2600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97443, 'Las Veredas', 'Las Veredas', 'Las Veredas', 23.1502800, -109.7061100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97444, 'Profesor Carlos Hank González', 'Profesor Carlos Hank Gonzalez', 'Profesor Carlos Hank Gonzalez,Profesor Carlos Hank González', 19.3722200, -98.9388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97445, 'Fraccionamiento la Trinidad', 'Fraccionamiento la Trinidad', 'Fraccionamiento la Trinidad', 19.8291700, -99.0827800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97446, 'Santa Cruz Amilpas', 'Santa Cruz Amilpas', 'Santa Cruz Amilpas', 17.0583300, -96.6833300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97447, 'Paseos de San Juan', 'Paseos de San Juan', 'Paseos de San Juan', 19.7819400, -99.0175000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97448, 'Valle Dorado Inn', 'Valle Dorado Inn', 'Valle Dorado Inn', 20.5244400, -103.3619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97449, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 18.0244400, -102.2858300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97450, 'General Ángel Flores (La Palma)', 'General Angel Flores (La Palma)', 'General Angel Flores (La Palma),General Ángel Flores (La Palma)', 24.8191700, -107.6566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97451, 'Brisas de Zicatela', 'Brisas de Zicatela', 'Brisas de Zicatela', 15.8369400, -97.0419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97452, 'San Antonio del Coyote', 'San Antonio del Coyote', 'San Antonio del Coyote', 25.6944400, -103.2855600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97453, 'Jorge Jiménez Cantú', 'Jorge Jimenez Cantu', 'Jorge Jimenez Cantu,Jorge Jiménez Cantú', 19.3097200, -98.8466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97454, 'Galaxia Bonito Jalisco', 'Galaxia Bonito Jalisco', 'Galaxia Bonito Jalisco', 20.5050000, -103.2047200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97455, 'Antúnez (Morelos)', 'Antunez (Morelos)', 'Antunez (Morelos),Antúnez (Morelos)', 19.0127800, -102.2038900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97456, 'La Alameda', 'La Alameda', 'La Alameda', 20.4952800, -103.2483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97457, 'El Niño', 'El Nino', 'El Nino,El Niño', 32.5075000, -116.7919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97458, 'Fraccionamiento Lomas de Ahuatlán', 'Fraccionamiento Lomas de Ahuatlan', 'Fraccionamiento Lomas de Ahuatlan,Fraccionamiento Lomas de Ahuatlán', 18.9544400, -99.2572200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97459, 'Lomas de Barrillas', 'Lomas de Barrillas', 'Lomas de Barrillas', 18.1480600, -94.5263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97460, 'Marte R. Gómez (Tobarito)', 'Marte R. Gomez (Tobarito)', 'Marte R. Gomez (Tobarito),Marte R. Gómez (Tobarito)', 27.3677800, -109.8858300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97461, 'Fraccionamiento Misión del Valle', 'Fraccionamiento Mision del Valle', 'Fraccionamiento Mision del Valle,Fraccionamiento Misión del Valle', 19.7655600, -101.1216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97462, 'Colonia Santa Bárbara', 'Colonia Santa Barbara', 'Colonia Santa Barbara,Colonia Santa Bárbara', 19.5019100, -96.8781700, 'MX', '2014-08-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97463, 'Bosque de Saloya', 'Bosque de Saloya', 'Bosque de Saloya', 18.0161100, -92.9580600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97464, 'San Lucas el Grande', 'San Lucas el Grande', 'San Lucas el Grande', 19.3058300, -98.4783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97465, 'San Andrés Azumiatla', 'San Andres Azumiatla', 'San Andres Azumiatla,San Andrés Azumiatla', 18.9041700, -98.2527800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97466, 'Rancho Alegre [Fraccionamiento]', 'Rancho Alegre [Fraccionamiento]', 'Rancho Alegre [Fraccionamiento]', 20.4736100, -103.2577800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97467, 'Ex-Rancho San Dimas', 'Ex-Rancho San Dimas', 'Ex-Rancho San Dimas', 19.1738900, -99.5652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97468, 'Jacarandas', 'Jacarandas', 'Jacarandas', 19.4955600, -96.8527800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97469, 'El Pino', 'El Pino', 'El Pino', 19.3513900, -98.9483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97470, 'Unión y Progreso', 'Union y Progreso', 'Union y Progreso,Unión y Progreso', 18.8727800, -97.1191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97471, 'Misión San Pablo', 'Mision San Pablo', 'Mision San Pablo,Misión San Pablo', 25.7400000, -100.1441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97472, 'Tenextepango', 'Tenextepango', 'Tenextepango', 18.7288900, -98.9577800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97473, 'Ejido San Lorenzo Cuauhtenco', 'Ejido San Lorenzo Cuauhtenco', 'Ejido San Lorenzo Cuauhtenco', 19.3013900, -99.7502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97474, 'Santa Catarina Ayometla', 'Santa Catarina Ayometla', 'Santa Catarina Ayometla', 19.1983300, -98.2136100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97475, 'El Espinal', 'El Espinal', 'El Espinal', 16.4847200, -95.0416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97476, 'Cuichapa', 'Cuichapa', 'Cuichapa', 17.9388900, -94.2800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97477, 'La Selva', 'La Selva', 'La Selva', 18.0233300, -92.9630600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97478, 'Los Olivos', 'Los Olivos', 'Los Olivos', 20.4391700, -103.2377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97479, 'Villa Luvianos', 'Villa Luvianos', 'Villa Luvianos', 18.9200000, -100.2983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97480, 'Los Ruiseñores', 'Los Ruisenores', 'Los Ruisenores,Los Ruiseñores', 20.7108300, -103.6913900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97481, 'Barrio de México', 'Barrio de Mexico', 'Barrio de Mexico,Barrio de México', 19.2825000, -99.8283300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97482, 'Tenango de las Flores', 'Tenango de las Flores', 'Tenango de las Flores', 20.2058300, -97.9880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97483, 'Independencia', 'Independencia', 'Independencia', 18.8771600, -99.1223700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97484, 'Maclovio Rojas', 'Maclovio Rojas', 'Maclovio Rojas', 32.4730600, -116.8027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97485, 'San Sebastián del Sur', 'San Sebastian del Sur', 'San Sebastian del Sur,San Sebastián del Sur', 19.7944400, -103.4730600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97486, 'Chiconcuac', 'Chiconcuac', 'Chiconcuac', 18.7827800, -99.2072200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97487, 'Chanal', 'Chanal', 'Chanal', 16.6575000, -92.2575000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97488, 'El Súchil', 'El Suchil', 'El Suchil,El Súchil', 17.2269400, -100.6391700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97489, 'El Campanario y Oradel', 'El Campanario y Oradel', 'El Campanario y Oradel', 27.4730600, -99.6200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97490, 'El Diez', 'El Diez', 'El Diez', 24.7238900, -107.4519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97491, 'Villa Alberto Andrés Alvarado Arámburo', 'Villa Alberto Andres Alvarado Aramburo', 'Villa Alberto Andres Alvarado Aramburo,Villa Alberto Andrés Alvarado Arámburo', 27.6444400, -113.3847200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97492, 'San Antonio Mihuacán', 'San Antonio Mihuacan', 'San Antonio Mihuacan,San Antonio Mihuacán', 19.1533300, -98.3047200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97493, 'Raudales Malpaso', 'Raudales Malpaso', 'Raudales Malpaso', 17.1883300, -93.6058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97494, 'San Nicolás Tolentino', 'San Nicolas Tolentino', 'San Nicolas Tolentino,San Nicolás Tolentino', 19.3588900, -99.5716700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97495, 'Santa Cruz del Monte', 'Santa Cruz del Monte', 'Santa Cruz del Monte', 19.7670200, -99.2286700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97496, 'Arenal', 'Arenal', 'Arenal', 19.3811100, -98.9427800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97497, 'San Juan Huactzinco', 'San Juan Huactzinco', 'San Juan Huactzinco', 19.2322200, -98.2525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97498, 'San Sebastián de Aparicio', 'San Sebastian de Aparicio', 'San Sebastian de Aparicio,San Sebastián de Aparicio', 19.1033300, -98.1608300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97499, 'Fraccionamiento Colinas del Sol', 'Fraccionamiento Colinas del Sol', 'Fraccionamiento Colinas del Sol', 19.3722200, -99.7402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97500, 'La Pradera', 'La Pradera', 'La Pradera', 20.6588900, -100.3422200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97501, 'Lomas de Santa Anita', 'Lomas de Santa Anita', 'Lomas de Santa Anita', 32.5427800, -116.6513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97502, 'Benito García (El Zorrillo)', 'Benito Garcia (El Zorrillo)', 'Benito Garcia (El Zorrillo),Benito García (El Zorrillo)', 31.6711100, -116.5113900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97503, 'Lomas Verdes', 'Lomas Verdes', 'Lomas Verdes', 19.5044600, -96.8889900, 'MX', '2014-08-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97504, 'Vida Mejor I', 'Vida Mejor I', 'Vida Mejor I', 14.8697200, -92.3077800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97505, 'La Constitución Toltepec', 'La Constitucion Toltepec', 'La Constitucion Toltepec,La Constitución Toltepec', 19.3486100, -99.5491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97506, 'Kilómetro 30', 'Kilometro 30', 'Kilometro 30,Kilómetro 30', 16.9977800, -99.7800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97507, 'San Bartolomé Atlatlahuca', 'San Bartolome Atlatlahuca', 'San Bartolome Atlatlahuca,San Bartolomé Atlatlahuca', 19.0686100, -99.6111100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97508, 'Fraccionamiento los Ángeles', 'Fraccionamiento los Angeles', 'Fraccionamiento los Angeles,Fraccionamiento los Ángeles', 23.1883300, -106.3300000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97509, 'Rincón de Nicolás Romero (Cedros Tercera Manzana)', 'Rincon de Nicolas Romero (Cedros Tercera Manzana)', 'Rincon de Nicolas Romero (Cedros Tercera Manzana),Rincón de Nicolás Romero (Cedros Tercera Manzana)', 19.4136100, -100.2975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97510, 'Campestre Villas del Álamo', 'Campestre Villas del Alamo', 'Campestre Villas del Alamo,Campestre Villas del Álamo', 20.1016700, -98.7072200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97511, 'Conjunto Urbano la Loma I', 'Conjunto Urbano la Loma I', 'Conjunto Urbano la Loma I', 19.3263900, -99.7319400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97512, 'Javier Rojo Gómez', 'Javier Rojo Gomez', 'Javier Rojo Gomez,Javier Rojo Gómez', 20.0697200, -98.4177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97513, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 25.9102800, -100.2805600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97514, 'Parque Urbano Napateco', 'Parque Urbano Napateco', 'Parque Urbano Napateco', 20.1427800, -98.3408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97515, 'La Aldea', 'La Aldea', 'La Aldea', 19.7430600, -101.1350000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97516, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 19.5547200, -96.9605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97517, 'El Cóporo', 'El Coporo', 'El Coporo,El Cóporo', 19.2830600, -99.8352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97518, 'Fraccionamiento Arboledas San Ramón', 'Fraccionamiento Arboledas San Ramon', 'Fraccionamiento Arboledas San Ramon,Fraccionamiento Arboledas San Ramón', 19.0941700, -96.1566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97519, 'Fraccionamiento Galaxia Tarímbaro', 'Fraccionamiento Galaxia Tarimbaro', 'Fraccionamiento Galaxia Tarimbaro,Fraccionamiento Galaxia Tarímbaro', 19.7616700, -101.1944400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97520, 'Real del Sol', 'Real del Sol', 'Real del Sol', 25.9383300, -100.1811100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97521, 'Fraccionamiento Metrópolis II', 'Fraccionamiento Metropolis II', 'Fraccionamiento Metropolis II,Fraccionamiento Metrópolis II', 19.7563900, -101.2044400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97522, 'Ciudad de Cuetzalan', 'Ciudad de Cuetzalan', 'Ciudad de Cuetzalan', 20.0186100, -97.5211100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97523, 'Colinas del Roble', 'Colinas del Roble', 'Colinas del Roble', 20.5041700, -103.3983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97524, 'Granjas Ampliación Santa Rosa', 'Granjas Ampliacion Santa Rosa', 'Granjas Ampliacion Santa Rosa,Granjas Ampliación Santa Rosa', 19.5927800, -98.9666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97525, 'Héctor Caballero', 'Hector Caballero', 'Hector Caballero,Héctor Caballero', 25.6355600, -100.1266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97526, 'Quinto Barrio (Ejido Cahuacán)', 'Quinto Barrio (Ejido Cahuacan)', 'Quinto Barrio (Ejido Cahuacan),Quinto Barrio (Ejido Cahuacán)', 19.6222200, -99.4180600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97527, 'Valle de Lincoln', 'Valle de Lincoln', 'Valle de Lincoln', 25.7933300, -100.4777800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97528, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 30.7541700, -116.0030600, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97529, 'Quinta del Cedro', 'Quinta del Cedro', 'Quinta del Cedro', 32.4375000, -117.0658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97530, 'Lomas de Altavista', 'Lomas de Altavista', 'Lomas de Altavista', 19.3613900, -98.9447200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97531, 'Unidad Minera 11 de Julio', 'Unidad Minera 11 de Julio', 'Unidad Minera 11 de Julio', 20.1047200, -98.7227800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97532, 'Galaxia la Noria', 'Galaxia la Noria', 'Galaxia la Noria', 20.4572200, -103.4188900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97533, 'Monte Kristal', 'Monte Kristal', 'Monte Kristal', 25.6261100, -100.1569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97534, 'La Lima', 'La Lima', 'La Lima', 17.9105600, -92.9338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97535, 'Loma la Paz', 'Loma la Paz', 'Loma la Paz', 25.7111100, -100.1347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97536, 'Ciudad Coahuila (Kilómetro Cincuenta y Siete)', 'Ciudad Coahuila (Kilometro Cincuenta y Siete)', 'Ciudad Coahuila (Kilometro Cincuenta y Siete),Ciudad Coahuila (Kilómetro Cincuenta y Siete)', 32.1955600, -115.0025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97537, 'Pedro Amaro', 'Pedro Amaro', 'Pedro Amaro', 18.5963900, -99.1730600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97538, 'Adolfo López Mateos (El Tamarindo)', 'Adolfo Lopez Mateos (El Tamarindo)', 'Adolfo Lopez Mateos (El Tamarindo),Adolfo López Mateos (El Tamarindo)', 24.8963900, -107.6327800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97539, 'Los Arcos', 'Los Arcos', 'Los Arcos', 18.8872200, -99.0241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97540, 'Villas de Alcalá', 'Villas de Alcala', 'Villas de Alcala,Villas de Alcalá', 25.9152800, -100.1852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97541, 'Calera Chica', 'Calera Chica', 'Calera Chica', 18.8583300, -99.1819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97542, 'El Rincón Citlaltépetl', 'El Rincon Citlaltepetl', 'El Rincon Citlaltepetl,El Rincón Citlaltépetl', 19.1555600, -97.8944400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97543, 'San Francisco de Asís', 'San Francisco de Asis', 'San Francisco de Asis,San Francisco de Asís', 20.5969400, -102.5636100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97544, 'Jicaltepec Autopan', 'Jicaltepec Autopan', 'Jicaltepec Autopan', 19.3716700, -99.6408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97545, 'Villas de Irapuato', 'Villas de Irapuato', 'Villas de Irapuato', 20.6872200, -101.4052800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97546, 'Arbolada los Sauces', 'Arbolada los Sauces', 'Arbolada los Sauces', 19.8158300, -99.0441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97547, 'Atoluca', 'Atoluca', 'Atoluca', 19.8550000, -97.3536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97548, 'Frontera Corozal', 'Frontera Corozal', 'Frontera Corozal', 16.8211100, -90.8902800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97549, 'Pocitos', 'Pocitos', 'Pocitos', 21.9216700, -102.3347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97550, 'Anacleto Canabal 2da. Sección', 'Anacleto Canabal 2da. Seccion', 'Anacleto Canabal 2da. Seccion,Anacleto Canabal 2da. Sección', 17.9755600, -93.0241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97551, 'La Pastoría', 'La Pastoria', 'La Pastoria,La Pastoría', 19.5430600, -98.9111100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97552, 'Tzimol', 'Tzimol', 'Tzimol', 16.1875000, -92.1969400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97553, 'Los Tuzos', 'Los Tuzos', 'Los Tuzos', 20.0538900, -98.7563900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97554, 'Ex-Hacienda Santa Inés', 'Ex-Hacienda Santa Ines', 'Ex-Hacienda Santa Ines,Ex-Hacienda Santa Inés', 19.7066700, -99.0725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97555, 'San Lorenzo Axocomanitla', 'San Lorenzo Axocomanitla', 'San Lorenzo Axocomanitla', 19.2238900, -98.2486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97556, 'Nueva Santa Rosa', 'Nueva Santa Rosa', 'Nueva Santa Rosa', 19.5902800, -98.9600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97557, 'Las Torres', 'Las Torres', 'Las Torres', 25.9516700, -100.3180600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97558, 'Colonia Venustiano Carranza', 'Colonia Venustiano Carranza', 'Colonia Venustiano Carranza', 28.6386100, -100.5566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97559, 'San José el Cuartel', 'San Jose el Cuartel', 'San Jose el Cuartel,San José el Cuartel', 18.9597200, -99.5772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97560, 'Colinas de Plata', 'Colinas de Plata', 'Colinas de Plata', 20.0783300, -98.7266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97561, 'Palomar', 'Palomar', 'Palomar', 20.5925000, -103.4605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97562, 'Unidad Acaquilpan', 'Unidad Acaquilpan', 'Unidad Acaquilpan', 19.3669400, -98.9391700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97563, 'Paseo del Prado', 'Paseo del Prado', 'Paseo del Prado', 20.5644400, -103.3891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97564, 'El Centenario', 'El Centenario', 'El Centenario', 24.1025000, -110.4144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97565, 'Fraccionamiento Ocuiltzapotlán Dos', 'Fraccionamiento Ocuiltzapotlan Dos', 'Fraccionamiento Ocuiltzapotlan Dos,Fraccionamiento Ocuiltzapotlán Dos', 18.1088900, -92.8677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97566, 'Los Torrentes', 'Los Torrentes', 'Los Torrentes', 19.2019400, -96.2113900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97567, 'Santa Justina Ecatepec', 'Santa Justina Ecatepec', 'Santa Justina Ecatepec', 19.3108300, -98.3550000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97568, 'Aquiles Serdán (San Fernando)', 'Aquiles Serdan (San Fernando)', 'Aquiles Serdan (San Fernando),Aquiles Serdán (San Fernando)', 17.8055600, -92.4897200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97569, 'Tungareo', 'Tungareo', 'Tungareo', 19.9083300, -100.3663900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97570, 'Villa Magna', 'Villa Magna', 'Villa Magna', 19.6836100, -101.3266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97571, 'Tianguistengo (La Romera)', 'Tianguistengo (La Romera)', 'Tianguistengo (La Romera)', 19.9141700, -99.3258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97572, 'San Felipe', 'San Felipe', 'San Felipe', 25.6927800, -103.3825000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97573, 'Hacienda los Fresnos', 'Hacienda los Fresnos', 'Hacienda los Fresnos', 20.5194400, -103.3930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97574, 'El Pedregal de Guadalupe Hidalgo', 'El Pedregal de Guadalupe Hidalgo', 'El Pedregal de Guadalupe Hidalgo', 19.2527800, -99.4650000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97575, 'Campestre las Palomas [Fraccionamiento]', 'Campestre las Palomas [Fraccionamiento]', 'Campestre las Palomas [Fraccionamiento]', 20.8177800, -103.4516700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97576, 'Villa Licenciado Jesús Terán (Calvillito)', 'Villa Licenciado Jesus Teran (Calvillito)', 'Villa Licenciado Jesus Teran (Calvillito),Villa Licenciado Jesús Terán (Calvillito)', 21.8252800, -102.1877800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97577, 'Tenango', 'Tenango', 'Tenango', 16.9047200, -92.2613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97578, 'Panuaya', 'Panuaya', 'Panuaya', 20.1950000, -99.2708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97579, 'Lo de Juárez', 'Lo de Juarez', 'Lo de Juarez,Lo de Juárez', 20.7683300, -101.3411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97580, 'Santiago Etla', 'Santiago Etla', 'Santiago Etla', 17.1525000, -96.7897200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97581, 'San Bernabé Temoxtitla', 'San Bernabe Temoxtitla', 'San Bernabe Temoxtitla,San Bernabé Temoxtitla', 18.9972200, -98.3308300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97582, 'Villas de la Loma', 'Villas de la Loma', 'Villas de la Loma', 19.6900000, -101.2994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97583, 'Molino Abajo', 'Molino Abajo', 'Molino Abajo', 19.4497200, -99.6022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97584, 'Jicaltepec Cuexcontitlán', 'Jicaltepec Cuexcontitlan', 'Jicaltepec Cuexcontitlan,Jicaltepec Cuexcontitlán', 19.3730600, -99.6275000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97585, 'General Lázaro Cárdenas (El Colorado)', 'General Lazaro Cardenas (El Colorado)', 'General Lazaro Cardenas (El Colorado),General Lázaro Cárdenas (El Colorado)', 20.5638900, -100.2438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97586, 'Tatoxcac', 'Tatoxcac', 'Tatoxcac', 19.8694400, -97.5730600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97587, 'Cereso del Hongo', 'Cereso del Hongo', 'Cereso del Hongo', 32.4841700, -116.2505600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97588, 'Villa Jiménez', 'Villa Jimenez', 'Villa Jimenez,Villa Jiménez', 19.9230600, -101.7469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97589, 'Tacopan', 'Tacopan', 'Tacopan', 19.8375000, -97.4311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97590, 'Santa María de Guadalupe', 'Santa Maria de Guadalupe', 'Santa Maria de Guadalupe,Santa María de Guadalupe', 19.8211100, -99.1277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97591, 'Santa María la Asunción', 'Santa Maria la Asuncion', 'Santa Maria la Asuncion,Santa María la Asunción', 19.2675000, -99.5525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97592, '2da. Sección de Medio Monte', '2da. Seccion de Medio Monte', '2da. Seccion de Medio Monte,2da. Sección de Medio Monte', 14.8819400, -92.1844400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97593, 'San Francisco Tepeyecac', 'San Francisco Tepeyecac', 'San Francisco Tepeyecac', 19.2486100, -98.4383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97594, 'Axotlán', 'Axotlan', 'Axotlan,Axotlán', 19.6941700, -99.2394400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97595, 'La Galarza', 'La Galarza', 'La Galarza', 18.6677800, -98.4552800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97596, 'San Buenaventura Tecaltzingo', 'San Buenaventura Tecaltzingo', 'San Buenaventura Tecaltzingo', 19.2477800, -98.4605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97597, 'Campestre Flamboyanes', 'Campestre Flamboyanes', 'Campestre Flamboyanes', 21.2100000, -89.6577800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97598, 'Villas de la Laguna', 'Villas de la Laguna', 'Villas de la Laguna', 19.8361100, -99.0900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97599, 'Alianza Real', 'Alianza Real', 'Alianza Real', 25.8513900, -100.3827800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97600, 'Colonia Revolución', 'Colonia Revolucion', 'Colonia Revolucion,Colonia Revolución', 28.2416700, -105.4436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97601, 'Loma Larga', 'Loma Larga', 'Loma Larga', 19.6275000, -99.3461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97602, 'Nejapa', 'Nejapa', 'Nejapa', 17.6138900, -99.1450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97603, 'La Trinidad Chautenco', 'La Trinidad Chautenco', 'La Trinidad Chautenco', 19.0900000, -98.2638900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97604, 'Real Hacienda (Metrópolis)', 'Real Hacienda (Metropolis)', 'Real Hacienda (Metropolis),Real Hacienda (Metrópolis)', 19.7505600, -101.1969400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97605, 'C-32 (Licenciado Francisco Trujillo Gurría)', 'C-32 (Licenciado Francisco Trujillo Gurria)', 'C-32 (Licenciado Francisco Trujillo Gurria),C-32 (Licenciado Francisco Trujillo Gurría)', 17.9683300, -93.5013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97606, 'Hércules', 'Hercules', 'Hercules,Hércules', 28.0430600, -103.7911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97607, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 20.7136100, -100.3036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97608, 'Delfino Victoria (Santa Fe)', 'Delfino Victoria (Santa Fe)', 'Delfino Victoria (Santa Fe)', 19.2075000, -96.2733300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97609, 'San Antonio', 'San Antonio', 'San Antonio', 19.6672200, -101.2680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97610, 'San Pedro Zacachimalpa', 'San Pedro Zacachimalpa', 'San Pedro Zacachimalpa', 18.9427800, -98.1561100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97611, 'Ichán', 'Ichan', 'Ichan,Ichán', 19.8580600, -102.0541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97612, 'Peña Flores (Palo Verde)', 'Pena Flores (Palo Verde)', 'Pena Flores (Palo Verde),Peña Flores (Palo Verde)', 18.8672200, -98.9683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97613, 'La Trinidad', 'La Trinidad', 'La Trinidad', 18.9663900, -99.5808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97614, 'Puerto Esmeralda', 'Puerto Esmeralda', 'Puerto Esmeralda', 18.1477800, -94.5177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97615, 'Melchor Ocampo', 'Melchor Ocampo', 'Melchor Ocampo', 18.0369400, -93.3625000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97616, 'La Providencia', 'La Providencia', 'La Providencia', 19.7583300, -99.1466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97617, 'Colonia Lomas de San Ramón (Triquis)', 'Colonia Lomas de San Ramon (Triquis)', 'Colonia Lomas de San Ramon (Triquis),Colonia Lomas de San Ramón (Triquis)', 30.7016700, -116.0027800, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97618, 'La Joya', 'La Joya', 'La Joya', 19.2763900, -99.7588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97619, 'San Bartolomé Aguas Calientes', 'San Bartolome Aguas Calientes', 'San Bartolome Aguas Calientes,San Bartolomé Aguas Calientes', 20.4955600, -100.5483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97620, 'General Felipe Ángeles (Los Ángeles)', 'General Felipe Angeles (Los Angeles)', 'General Felipe Angeles (Los Angeles),General Felipe Ángeles (Los Ángeles)', 19.8975000, -98.9261100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97621, 'Colinas del Aeropuerto', 'Colinas del Aeropuerto', 'Colinas del Aeropuerto', 25.8170500, -100.1025800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97622, 'San Bartolomé Cuahuixmatlac', 'San Bartolome Cuahuixmatlac', 'San Bartolome Cuahuixmatlac,San Bartolomé Cuahuixmatlac', 19.2933300, -98.1480600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97623, 'Vistas del Maguey [Fraccionamiento]', 'Vistas del Maguey [Fraccionamiento]', 'Vistas del Maguey [Fraccionamiento]', 20.5280600, -102.5233300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97624, 'Barrio Santa Cruz', 'Barrio Santa Cruz', 'Barrio Santa Cruz', 19.3513900, -99.6627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97625, 'Santa María Texmelucan', 'Santa Maria Texmelucan', 'Santa Maria Texmelucan,Santa María Texmelucan', 19.2941700, -98.5377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97626, 'El Saucillo (Fraccionamiento)', 'El Saucillo (Fraccionamiento)', 'El Saucillo (Fraccionamiento)', 20.0677800, -98.7319400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97627, 'Santiago Chimalpa (Chimalpa)', 'Santiago Chimalpa (Chimalpa)', 'Santiago Chimalpa (Chimalpa)', 19.5691700, -98.8916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97628, 'San Esteban (San Miguel Tateposco)', 'San Esteban (San Miguel Tateposco)', 'San Esteban (San Miguel Tateposco)', 20.7988900, -103.3744400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97629, 'Plutarco Elías Calles (La Y Griega)', 'Plutarco Elias Calles (La Y Griega)', 'Plutarco Elias Calles (La Y Griega),Plutarco Elías Calles (La Y Griega)', 30.8019400, -112.7183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97630, 'Yoshib', 'Yoshib', 'Yoshib', 16.8452800, -92.4461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97631, 'San Agustín Yatareni', 'San Agustin Yatareni', 'San Agustin Yatareni,San Agustín Yatareni', 17.0805600, -96.6680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97632, 'Hacienda San Pedro', 'Hacienda San Pedro', 'Hacienda San Pedro', 25.9147200, -100.1627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97633, 'Forjadores de Pachuca', 'Forjadores de Pachuca', 'Forjadores de Pachuca', 20.0550000, -98.7633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97634, 'Unidad Habitacional José María Morelos y Pavón', 'Unidad Habitacional Jose Maria Morelos y Pavon', 'Unidad Habitacional Jose Maria Morelos y Pavon,Unidad Habitacional José María Morelos y Pavón', 18.6213700, -99.2217800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97635, 'San Miguel Jaltocan', 'San Miguel Jaltocan', 'San Miguel Jaltocan', 19.7230600, -99.0502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97636, 'C-41 (Licenciado Carlos A. Madrazo)', 'C-41 (Licenciado Carlos A. Madrazo)', 'C-41 (Licenciado Carlos A. Madrazo)', 17.9230600, -93.4480600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97637, 'Santiago Puriatzícuaro', 'Santiago Puriatzicuaro', 'Santiago Puriatzicuaro,Santiago Puriatzícuaro', 19.8830600, -100.5886100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97638, 'Fraccionamiento Costa Dorada', 'Fraccionamiento Costa Dorada', 'Fraccionamiento Costa Dorada', 19.2083300, -96.2163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97639, 'Colonia 2 de Septiembre', 'Colonia 2 de Septiembre', 'Colonia 2 de Septiembre', 19.7005600, -99.1166700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97640, 'Toreo Bajo (El Toreo Bajo)', 'Toreo Bajo (El Toreo Bajo)', 'Toreo Bajo (El Toreo Bajo)', 19.4447200, -102.0044400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97641, 'Santa Rosa (Santa Bárbara)', 'Santa Rosa (Santa Barbara)', 'Santa Rosa (Santa Barbara),Santa Rosa (Santa Bárbara)', 19.3833300, -102.0361100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97642, 'Villa URBI del Rey', 'Villa URBI del Rey', 'Villa URBI del Rey', 19.8413200, -99.2571900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97643, 'Chalchocoyo', 'Chalchocoyo', 'Chalchocoyo', 21.3144400, -98.7919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97644, 'Barrio Cuarto (La Loma)', 'Barrio Cuarto (La Loma)', 'Barrio Cuarto (La Loma)', 19.7686100, -99.6769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97645, 'Cristeros [Fraccionamiento]', 'Cristeros [Fraccionamiento]', 'Cristeros [Fraccionamiento]', 21.3211100, -101.9733300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97646, 'Zacango', 'Zacango', 'Zacango', 18.9561100, -99.6980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97647, 'San Nicolás Zoyapetlayoca', 'San Nicolas Zoyapetlayoca', 'San Nicolas Zoyapetlayoca,San Nicolás Zoyapetlayoca', 18.9241700, -97.8652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97648, 'Colonia el Salado', 'Colonia el Salado', 'Colonia el Salado', 19.5838900, -98.9913900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97649, 'Sosa', 'Sosa', 'Sosa', 19.8011100, -97.3961100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97650, 'San Antonio Portezuelo', 'San Antonio Portezuelo', 'San Antonio Portezuelo', 18.9988900, -97.7136100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97651, 'Jardines de San Sebastián', 'Jardines de San Sebastian', 'Jardines de San Sebastian,Jardines de San Sebastián', 20.5188900, -103.4222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97652, 'Ex-Viñedos Guadalupe', 'Ex-Vinedos Guadalupe', 'Ex-Vinedos Guadalupe,Ex-Viñedos Guadalupe', 21.9594400, -102.2741700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97653, 'Chipilo de Francisco Javier Mina', 'Chipilo de Francisco Javier Mina', 'Chipilo de Francisco Javier Mina', 19.0061100, -98.3305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97654, 'Zacualpan de Amilpas', 'Zacualpan de Amilpas', 'Zacualpan de Amilpas', 18.7838900, -98.7658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97655, 'San Francisco Ayotuzco', 'San Francisco Ayotuzco', 'San Francisco Ayotuzco', 19.3658300, -99.3569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97656, 'Alfonso G. Calderón (Poblado Siete)', 'Alfonso G. Calderon (Poblado Siete)', 'Alfonso G. Calderon (Poblado Siete),Alfonso G. Calderón (Poblado Siete)', 26.0652800, -109.0197200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97657, 'San Antonio Gallardo', 'San Antonio Gallardo', 'San Antonio Gallardo', 20.6283300, -100.7677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97658, 'PRI Chacón', 'PRI Chacon', 'PRI Chacon,PRI Chacón', 20.0813900, -98.7369400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97659, 'Los Tigres (San Marcos)', 'Los Tigres (San Marcos)', 'Los Tigres (San Marcos)', 17.8905600, -95.3494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97660, 'Villa Santiago', 'Villa Santiago', 'Villa Santiago', 18.9797200, -99.1852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97661, 'San Bartolo', 'San Bartolo', 'San Bartolo', 18.0922200, -96.1075000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97662, 'Colonia Santa Cecilia (La Sauceda)', 'Colonia Santa Cecilia (La Sauceda)', 'Colonia Santa Cecilia (La Sauceda)', 21.2525000, -102.3513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97663, 'Samarkanda', 'Samarkanda', 'Samarkanda', 18.0421600, -92.9105000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97664, 'Genaro Estrada', 'Genaro Estrada', 'Genaro Estrada', 25.9361100, -108.3963900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97665, 'Colonia Lázaro Cárdenas (Los Hornos)', 'Colonia Lazaro Cardenas (Los Hornos)', 'Colonia Lazaro Cardenas (Los Hornos),Colonia Lázaro Cárdenas (Los Hornos)', 19.6316700, -99.1533300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97666, 'Atzingo (La Cumbre)', 'Atzingo (La Cumbre)', 'Atzingo (La Cumbre)', 19.9797200, -97.9686100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97667, 'Unidades Habitacionales', 'Unidades Habitacionales', 'Unidades Habitacionales', 20.0638900, -98.4205600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97668, 'Colinas de Santa Cruz Segunda Sección', 'Colinas de Santa Cruz Segunda Seccion', 'Colinas de Santa Cruz Segunda Seccion,Colinas de Santa Cruz Segunda Sección', 20.6236100, -100.4666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97669, 'Oasis', 'Oasis', 'Oasis', 19.2016700, -96.2191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97670, 'Francisco Sarabia', 'Francisco Sarabia', 'Francisco Sarabia', 16.9458300, -93.0130600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97671, 'Ocopulco', 'Ocopulco', 'Ocopulco', 19.5897200, -98.8969400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97672, 'Poblado 10', 'Poblado 10', 'Poblado 10', 17.2772200, -94.4519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97673, 'Arboledas Paso Blanco [Fraccionamiento]', 'Arboledas Paso Blanco [Fraccionamiento]', 'Arboledas Paso Blanco [Fraccionamiento]', 21.9636100, -102.3019400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97674, 'San Miguel Tianguistenco', 'San Miguel Tianguistenco', 'San Miguel Tianguistenco', 19.2938900, -98.5308300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97675, 'Barrio Tlatenco', 'Barrio Tlatenco', 'Barrio Tlatenco', 19.7391700, -99.1916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97676, 'Amatillo', 'Amatillo', 'Amatillo', 16.8202800, -99.6661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97677, 'Colonia Gustavo Baz Prada', 'Colonia Gustavo Baz Prada', 'Colonia Gustavo Baz Prada', 19.4213900, -99.0136100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97678, 'Tlamaco (San Gerónimo Tlamaco)', 'Tlamaco (San Geronimo Tlamaco)', 'Tlamaco (San Geronimo Tlamaco),Tlamaco (San Gerónimo Tlamaco)', 20.0347200, -99.2291700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97679, 'Atecucario de la Constitución (Atecuario)', 'Atecucario de la Constitucion (Atecuario)', 'Atecucario de la Constitucion (Atecuario),Atecucario de la Constitución (Atecuario)', 20.0644400, -102.2386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97680, 'Agrícola Lázaro Cárdenas', 'Agricola Lazaro Cardenas', 'Agricola Lazaro Cardenas,Agrícola Lázaro Cárdenas', 18.8136100, -97.1983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97681, 'Jagüey de Téllez (Estación Téllez)', 'Jagueey de Tellez (Estacion Tellez)', 'Jagueey de Tellez (Estacion Tellez),Jagüey de Téllez (Estación Téllez)', 19.9805600, -98.7883300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97682, 'Nachig', 'Nachig', 'Nachig', 16.7305600, -92.7252800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97683, 'Arroyo del Maíz Uno', 'Arroyo del Maiz Uno', 'Arroyo del Maiz Uno,Arroyo del Maíz Uno', 20.5366700, -97.4152800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97684, 'Colonia Nueva Era', 'Colonia Nueva Era', 'Colonia Nueva Era', 30.5066700, -115.9225000, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97685, 'Fraccionamiento Valle Dorado', 'Fraccionamiento Valle Dorado', 'Fraccionamiento Valle Dorado', 18.8688900, -97.1222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97686, 'Las Colonias de Hidalgo', 'Las Colonias de Hidalgo', 'Las Colonias de Hidalgo', 20.1961100, -97.9766700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97687, 'San Diego los Padres Cuexcontitlán Sección 5 B', 'San Diego los Padres Cuexcontitlan Seccion 5 B', 'San Diego los Padres Cuexcontitlan Seccion 5 B,San Diego los Padres Cuexcontitlán Sección 5 B', 19.3761100, -99.6122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97688, 'Belén Atzitzimititlán', 'Belen Atzitzimititlan', 'Belen Atzitzimititlan,Belén Atzitzimititlán', 19.3469400, -98.1900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97689, 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', 19.3911100, -99.5252800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97690, 'Unidad Habitacional Rinconada Acolapa', 'Unidad Habitacional Rinconada Acolapa', 'Unidad Habitacional Rinconada Acolapa', 18.8972200, -99.1313900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97691, 'El Saucito (El Horno)', 'El Saucito (El Horno)', 'El Saucito (El Horno)', 22.7311100, -102.0952800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97692, 'San Isidro Vista Hermosa', 'San Isidro Vista Hermosa', 'San Isidro Vista Hermosa', 18.5055600, -97.4002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97693, 'Simeprodeso (Colectivo Nuevo)', 'Simeprodeso (Colectivo Nuevo)', 'Simeprodeso (Colectivo Nuevo)', 25.8530600, -100.2916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97694, 'Corral de Barrancos', 'Corral de Barrancos', 'Corral de Barrancos', 21.9502800, -102.3322200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97695, 'San Pedro Benito Juárez', 'San Pedro Benito Juarez', 'San Pedro Benito Juarez,San Pedro Benito Juárez', 18.9472200, -98.5513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97696, 'Juárez Coronaco', 'Juarez Coronaco', 'Juarez Coronaco,Juárez Coronaco', 19.3605600, -98.5250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97697, 'Los Valles', 'Los Valles', 'Los Valles', 32.3925000, -116.9550000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97698, 'Pochahuizco', 'Pochahuizco', 'Pochahuizco', 17.6647200, -99.2227800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97699, 'Corral Falso', 'Corral Falso', 'Corral Falso', 18.2447200, -100.5600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97700, 'Santo Nombre', 'Santo Nombre', 'Santo Nombre', 18.6738900, -97.6761100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97701, 'Joshil', 'Joshil', 'Joshil', 17.2466700, -92.3627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97702, 'Tezoquipa', 'Tezoquipa', 'Tezoquipa', 20.0563900, -99.2047200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97703, 'Colonia los Cedros', 'Colonia los Cedros', 'Colonia los Cedros', 19.3116700, -99.5411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97704, 'Prados de San Juan', 'Prados de San Juan', 'Prados de San Juan', 19.6399800, -98.9751900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97705, 'Changata', 'Changata', 'Changata', 18.2730600, -100.5852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97706, 'San Lucas Pío', 'San Lucas Pio', 'San Lucas Pio,San Lucas Pío', 19.7936100, -100.9247200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97707, 'Los Cafetales', 'Los Cafetales', 'Los Cafetales', 14.8674500, -92.3020000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97708, 'San Francisco', 'San Francisco', 'San Francisco', 19.7772200, -97.3280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97709, 'Arena 1ra. Sección', 'Arena 1ra. Seccion', 'Arena 1ra. Seccion,Arena 1ra. Sección', 18.2013900, -93.3669400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97710, 'Colonia Vista Bella (Lomas del Peaje)', 'Colonia Vista Bella (Lomas del Peaje)', 'Colonia Vista Bella (Lomas del Peaje)', 19.4908300, -101.5938900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97711, 'Fraccionamiento las Fuentes', 'Fraccionamiento las Fuentes', 'Fraccionamiento las Fuentes', 19.4961100, -96.8863900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97712, 'Nuevo San Miguel', 'Nuevo San Miguel', 'Nuevo San Miguel', 25.9630600, -109.0540100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97713, 'Xoloateno', 'Xoloateno', 'Xoloateno', 19.8311100, -97.3694400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97714, 'El Hielo', 'El Hielo', 'El Hielo', 19.4258300, -99.3555600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97715, 'Buena Vista 1ra. Sección', 'Buena Vista 1ra. Seccion', 'Buena Vista 1ra. Seccion,Buena Vista 1ra. Sección', 18.1441700, -92.7497200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97716, 'Fraccionamiento Cosmópolis Octavo Sector', 'Fraccionamiento Cosmopolis Octavo Sector', 'Fraccionamiento Cosmopolis Octavo Sector,Fraccionamiento Cosmópolis Octavo Sector', 25.8252800, -100.2461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97717, 'La Mesa', 'La Mesa', 'La Mesa', 31.1597200, -110.9744400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97718, 'San Andrés Duraznal', 'San Andres Duraznal', 'San Andres Duraznal,San Andrés Duraznal', 17.1286100, -92.8033300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97719, 'La Colonia', 'La Colonia', 'La Colonia', 20.0547200, -98.7702800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97720, 'Cuarta Brigada', 'Cuarta Brigada', 'Cuarta Brigada', 20.6219400, -101.2800100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97721, 'La Libertad', 'La Libertad', 'La Libertad', 19.7558300, -97.6072200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97722, 'Rincones de la Hacienda', 'Rincones de la Hacienda', 'Rincones de la Hacienda', 20.1200000, -98.4016700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97723, 'Fraccionamiento Real de San Pablo', 'Fraccionamiento Real de San Pablo', 'Fraccionamiento Real de San Pablo', 19.3894400, -99.6486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97724, 'Colonia las Flores', 'Colonia las Flores', 'Colonia las Flores', 21.3616700, -97.6930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97725, 'El Saucillo', 'El Saucillo', 'El Saucillo', 20.0769400, -98.7372200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97726, 'Barrio San Joaquín el Junco', 'Barrio San Joaquin el Junco', 'Barrio San Joaquin el Junco,Barrio San Joaquín el Junco', 19.5641700, -99.7733300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97727, 'Puerto de Buenavista (Lázaro Cárdenas)', 'Puerto de Buenavista (Lazaro Cardenas)', 'Puerto de Buenavista (Lazaro Cardenas),Puerto de Buenavista (Lázaro Cárdenas)', 19.6880600, -101.1272200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97728, 'Copanatoyac', 'Copanatoyac', 'Copanatoyac', 17.4641700, -98.7125000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97729, 'Iquinuapa', 'Iquinuapa', 'Iquinuapa', 18.1958300, -93.1205600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97730, 'Javier Rojo Gómez', 'Javier Rojo Gomez', 'Javier Rojo Gomez,Javier Rojo Gómez', 18.2738900, -88.6811100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97731, 'Valle de Vaquerías', 'Valle de Vaquerias', 'Valle de Vaquerias,Valle de Vaquerías', 25.6325000, -100.1469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97732, 'Río Medio [Granja]', 'Rio Medio [Granja]', 'Rio Medio [Granja],Río Medio [Granja]', 19.2097200, -96.2088900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97733, 'Necoxtla', 'Necoxtla', 'Necoxtla', 18.7786100, -97.1536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97734, 'Juan Aldama (El Tigre)', 'Juan Aldama (El Tigre)', 'Juan Aldama (El Tigre)', 24.9397200, -107.8208300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97735, 'Lomas de Río Medio Cuatro', 'Lomas de Rio Medio Cuatro', 'Lomas de Rio Medio Cuatro,Lomas de Río Medio Cuatro', 19.1933300, -96.2105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97736, 'Jardínes del Grijalva', 'Jardines del Grijalva', 'Jardines del Grijalva,Jardínes del Grijalva', 16.7284700, -93.0346300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97737, 'Colonia la Asunción', 'Colonia la Asuncion', 'Colonia la Asuncion,Colonia la Asunción', 19.6908300, -99.0641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97738, 'Santa Mónica', 'Santa Monica', 'Santa Monica,Santa Mónica', 18.9930600, -99.4236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97739, 'Bahía de Lobos', 'Bahia de Lobos', 'Bahia de Lobos,Bahía de Lobos', 27.3516700, -110.4547200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97740, 'San Martín Coapaxtongo', 'San Martin Coapaxtongo', 'San Martin Coapaxtongo,San Martín Coapaxtongo', 18.9941700, -99.5700000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97741, 'Miguel Hidalgo', 'Miguel Hidalgo', 'Miguel Hidalgo', 28.1536100, -105.3938900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97742, 'Galaxia la Calera', 'Galaxia la Calera', 'Galaxia la Calera', 18.9990000, -98.1525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97743, 'Zapotlán', 'Zapotlan', 'Zapotlan,Zapotlán', 19.5466700, -98.9030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97744, 'La Ciénega', 'La Cienega', 'La Cienega,La Ciénega', 18.9561100, -99.5813900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97745, 'Sector H Tres', 'Sector H Tres', 'Sector H Tres', 15.7661100, -96.1469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97746, 'Tlatempan', 'Tlatempan', 'Tlatempan', 19.3316700, -98.2030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97747, 'Ixtlahuaca Barrio', 'Ixtlahuaca Barrio', 'Ixtlahuaca Barrio', 19.8388900, -98.0144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97748, 'Jesús Nazareno', 'Jesus Nazareno', 'Jesus Nazareno,Jesús Nazareno', 18.8766700, -97.6230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97749, 'Guadalupe Zaragoza', 'Guadalupe Zaragoza', 'Guadalupe Zaragoza', 19.3583300, -98.5375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97750, 'San Pedro Tepetitlán', 'San Pedro Tepetitlan', 'San Pedro Tepetitlan,San Pedro Tepetitlán', 19.6294400, -98.8897200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97751, 'Bosques de la Magdalena', 'Bosques de la Magdalena', 'Bosques de la Magdalena', 19.3577800, -98.9475000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97752, 'El Huaxtho', 'El Huaxtho', 'El Huaxtho', 20.2344400, -98.9622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97753, 'Tamazulápam del Espíritu Santo', 'Tamazulapam del Espiritu Santo', 'Tamazulapam del Espiritu Santo,Tamazulápam del Espíritu Santo', 17.0550000, -96.0652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97754, 'Poblado C-33 20 de Noviembre', 'Poblado C-33 20 de Noviembre', 'Poblado C-33 20 de Noviembre', 17.9675000, -93.5650000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97755, 'Santiago Acozac', 'Santiago Acozac', 'Santiago Acozac', 18.9569400, -97.8116700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97756, 'Colorines', 'Colorines', 'Colorines', 18.8847200, -96.9783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97757, 'Florencia', 'Florencia', 'Florencia', 21.5038900, -103.5561100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97758, 'Rancho Verde', 'Rancho Verde', 'Rancho Verde', 31.9161100, -116.5883300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97759, 'Entronque Laredo-Salinas Victoria', 'Entronque Laredo-Salinas Victoria', 'Entronque Laredo-Salinas Victoria', 25.8550000, -100.2472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97760, 'Leona Vicario', 'Leona Vicario', 'Leona Vicario', 20.9094400, -89.6011100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97761, 'San Felipe los Alzati (Colonia Nueva)', 'San Felipe los Alzati (Colonia Nueva)', 'San Felipe los Alzati (Colonia Nueva)', 19.4897200, -100.3738900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97762, 'Rinconada de los Ángeles', 'Rinconada de los Angeles', 'Rinconada de los Angeles,Rinconada de los Ángeles', 20.0261100, -98.7113900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97763, 'Manuel Ávila Camacho', 'Manuel Avila Camacho', 'Manuel Avila Camacho,Manuel Ávila Camacho', 20.1119400, -98.7069400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97764, 'Sitio Ejido', 'Sitio Ejido', 'Sitio Ejido', 19.4533400, -99.9006900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97765, 'Constitución', 'Constitucion', 'Constitucion,Constitución', 18.0727800, -92.8719400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97766, 'Conjunto Habitacional Ecológico SUTEYM', 'Conjunto Habitacional Ecologico SUTEYM', 'Conjunto Habitacional Ecologico SUTEYM,Conjunto Habitacional Ecológico SUTEYM', 19.3688900, -99.7786100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97767, 'San José el Saladillo (El Saladillo)', 'San Jose el Saladillo (El Saladillo)', 'San Jose el Saladillo (El Saladillo),San José el Saladillo (El Saladillo)', 22.6850000, -102.0377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97768, 'El Huarache (El Guarache)', 'El Huarache (El Guarache)', 'El Huarache (El Guarache)', 25.5200000, -103.4866700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97769, 'El Boxtha', 'El Boxtha', 'El Boxtha', 20.2597200, -98.9741700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97770, 'Colonia San Luis Rey', 'Colonia San Luis Rey', 'Colonia San Luis Rey', 20.9355600, -100.7361100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97771, 'El Progreso', 'El Progreso', 'El Progreso', 16.8769400, -93.2222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97772, 'Amuco de la Reforma', 'Amuco de la Reforma', 'Amuco de la Reforma', 18.2936100, -100.6397200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97773, 'Colonia Progreso', 'Colonia Progreso', 'Colonia Progreso', 16.8011100, -95.0797200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97774, 'Los Mangos', 'Los Mangos', 'Los Mangos', 18.2436100, -95.1222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97775, 'Rizos de la Joya (Rizos del Saucillo)', 'Rizos de la Joya (Rizos del Saucillo)', 'Rizos de la Joya (Rizos del Saucillo)', 21.1486100, -101.7619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97776, 'San Pedro Yancuitlalpan', 'San Pedro Yancuitlalpan', 'San Pedro Yancuitlalpan', 19.0775000, -98.4833300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97777, 'Fraccionamiento San Miguel', 'Fraccionamiento San Miguel', 'Fraccionamiento San Miguel', 20.0711100, -102.6866700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97778, 'Colonia Agrícola México (Palmitas)', 'Colonia Agricola Mexico (Palmitas)', 'Colonia Agricola Mexico (Palmitas),Colonia Agrícola México (Palmitas)', 25.1097200, -107.9447200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97779, 'Cerrillos (Campo 35)', 'Cerrillos (Campo 35)', 'Cerrillos (Campo 35)', 25.8780600, -108.9013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97780, 'El Varal (San Sebastián Número Uno)', 'El Varal (San Sebastian Numero Uno)', 'El Varal (San Sebastian Numero Uno),El Varal (San Sebastián Número Uno)', 25.6427800, -108.4250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97781, 'Portal de las Salinas', 'Portal de las Salinas', 'Portal de las Salinas', 25.9822200, -100.1433300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97782, 'Paseo Puente Viejo', 'Paseo Puente Viejo', 'Paseo Puente Viejo', 20.5691700, -103.1905600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97783, 'Santa Cruz Tetela', 'Santa Cruz Tetela', 'Santa Cruz Tetela', 19.2925000, -98.2077800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97784, 'Almoloya', 'Almoloya', 'Almoloya', 20.0227800, -98.3166700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97785, 'Fraccionamiento Misión de San Javier', 'Fraccionamiento Mision de San Javier', 'Fraccionamiento Mision de San Javier,Fraccionamiento Misión de San Javier', 25.7455600, -100.1519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97786, 'Zona Urbana Ejido Isla Mujeres', 'Zona Urbana Ejido Isla Mujeres', 'Zona Urbana Ejido Isla Mujeres', 21.2247200, -86.8536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97787, 'Fraccionamiento los Prados', 'Fraccionamiento los Prados', 'Fraccionamiento los Prados', 17.9777800, -94.6391700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97788, 'Laguna del Rey (Químicas del Rey)', 'Laguna del Rey (Quimicas del Rey)', 'Laguna del Rey (Quimicas del Rey),Laguna del Rey (Químicas del Rey)', 27.0305600, -103.3666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97789, 'Poblado Número Cinco', 'Poblado Numero Cinco', 'Poblado Numero Cinco,Poblado Número Cinco', 26.2225000, -109.0616700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97790, 'Charco Blanco', 'Charco Blanco', 'Charco Blanco', 23.8630600, -103.6575000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97791, 'Capoluca', 'Capoluca', 'Capoluca', 18.8063900, -97.0272200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97792, 'Chicahuaxtla', 'Chicahuaxtla', 'Chicahuaxtla', 20.1425000, -97.9455600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97793, 'Paraje el Mirador', 'Paraje el Mirador', 'Paraje el Mirador', 19.3994400, -99.3269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97794, 'Santa María Aranzazú (Santa María)', 'Santa Maria Aranzazu (Santa Maria)', 'Santa Maria Aranzazu (Santa Maria),Santa María Aranzazú (Santa María)', 18.9883300, -99.6505600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97795, 'Macuilxóchitl de Artigas Carranza', 'Macuilxochitl de Artigas Carranza', 'Macuilxochitl de Artigas Carranza,Macuilxóchitl de Artigas Carranza', 17.0158300, -96.5400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97796, 'Cuauhtémoc (Campo Cinco)', 'Cuauhtemoc (Campo Cinco)', 'Cuauhtemoc (Campo Cinco),Cuauhtémoc (Campo Cinco)', 27.4333300, -110.0166700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97797, 'San Francisco Independencia (Santa María Aserradero)', 'San Francisco Independencia (Santa Maria Aserradero)', 'San Francisco Independencia (Santa Maria Aserradero),San Francisco Independencia (Santa María Aserradero)', 19.0688900, -97.4302800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97798, 'Fraccionamiento Ex-Hacienda el Refugio', 'Fraccionamiento Ex-Hacienda el Refugio', 'Fraccionamiento Ex-Hacienda el Refugio', 19.9508300, -102.2563900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97799, 'San Juan Benito Juárez (San Juan Tararameo)', 'San Juan Benito Juarez (San Juan Tararameo)', 'San Juan Benito Juarez (San Juan Tararameo),San Juan Benito Juárez (San Juan Tararameo)', 19.9169400, -101.1286100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97800, 'La Aurora', 'La Aurora', 'La Aurora', 20.6266700, -100.7575000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97801, 'San Vicente la Mesilla', 'San Vicente la Mesilla', 'San Vicente la Mesilla', 16.1786100, -92.2933300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97802, 'Fraccionamiento Rinconada del Valle', 'Fraccionamiento Rinconada del Valle', 'Fraccionamiento Rinconada del Valle', 19.4111100, -99.5741700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97803, 'Unidad Habitacional Santa Teresa', 'Unidad Habitacional Santa Teresa', 'Unidad Habitacional Santa Teresa', 19.2161100, -99.5522200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97804, 'Prados San Francisco', 'Prados San Francisco', 'Prados San Francisco', 19.7215400, -99.0836600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97805, 'Hualcaltzinco', 'Hualcaltzinco', 'Hualcaltzinco', 19.4005600, -98.1600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97806, 'Uruétaro', 'Uruetaro', 'Uruetaro,Uruétaro', 19.7905600, -101.0877800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97807, 'El Ámbar (El Ámbar de Echeverría)', 'El Ambar (El Ambar de Echeverria)', 'El Ambar (El Ambar de Echeverria),El Ámbar (El Ámbar de Echeverría)', 16.0963900, -92.8333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97808, 'Santa María Huiramangaro (San Juan Tumbio)', 'Santa Maria Huiramangaro (San Juan Tumbio)', 'Santa Maria Huiramangaro (San Juan Tumbio),Santa María Huiramangaro (San Juan Tumbio)', 19.5130600, -101.7652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97809, 'Anacleto Canabal 3ra. Sección', 'Anacleto Canabal 3ra. Seccion', 'Anacleto Canabal 3ra. Seccion,Anacleto Canabal 3ra. Sección', 18.0183000, -92.9899200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97810, 'Metepec', 'Metepec', 'Metepec', 18.8788900, -98.7466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97811, 'Carmen Zacatal', 'Carmen Zacatal', 'Carmen Zacatal', 17.0808300, -92.8025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97812, 'El Cid', 'El Cid', 'El Cid', 19.8672200, -98.9269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97813, 'San José Tejamanil', 'San Jose Tejamanil', 'San Jose Tejamanil,San José Tejamanil', 19.4313900, -99.3588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97814, 'San Nicolás Zecalacoayan', 'San Nicolas Zecalacoayan', 'San Nicolas Zecalacoayan,San Nicolás Zecalacoayan', 19.1991700, -98.4883300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97815, 'Xochimilco', 'Xochimilco', 'Xochimilco', 18.8416700, -97.7258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97816, 'El Llano', 'El Llano', 'El Llano', 21.9438900, -102.3227800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97817, 'Tuncingo', 'Tuncingo', 'Tuncingo', 16.8508300, -99.7891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97818, 'Pueblo Mayo', 'Pueblo Mayo', 'Pueblo Mayo', 27.2036100, -109.5550000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97819, 'Coahuixco', 'Coahuixco', 'Coahuixco', 19.8055600, -97.4102800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97820, 'Colonia Morelos', 'Colonia Morelos', 'Colonia Morelos', 19.6377800, -99.3391700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97821, 'Zoatecpan', 'Zoatecpan', 'Zoatecpan', 19.9344400, -97.6202800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97822, 'José María Pino Suárez (Nuevo Nahuapa)', 'Jose Maria Pino Suarez (Nuevo Nahuapa)', 'Jose Maria Pino Suarez (Nuevo Nahuapa),José María Pino Suárez (Nuevo Nahuapa)', 19.9488900, -105.3277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97823, 'La Planada', 'La Planada', 'La Planada', 19.7812900, -99.1826700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97824, 'Llano de la Y', 'Llano de la Y', 'Llano de la Y', 19.4027800, -99.6163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97825, 'San Gregorio Aztotoacan', 'San Gregorio Aztotoacan', 'San Gregorio Aztotoacan', 19.2644400, -98.4919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97826, 'Loma de San José', 'Loma de San Jose', 'Loma de San Jose,Loma de San José', 19.6422200, -99.3277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97827, 'San Diego la Huerta', 'San Diego la Huerta', 'San Diego la Huerta', 19.1447200, -99.6333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97828, 'Santa María Chimalapa', 'Santa Maria Chimalapa', 'Santa Maria Chimalapa,Santa María Chimalapa', 16.9063900, -94.6833300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97829, 'San Lorenzo Queréndaro', 'San Lorenzo Querendaro', 'San Lorenzo Querendaro,San Lorenzo Queréndaro', 19.6675000, -100.4886100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97830, 'La Ermita (Nueva Jerusalén)', 'La Ermita (Nueva Jerusalen)', 'La Ermita (Nueva Jerusalen),La Ermita (Nueva Jerusalén)', 19.0744400, -101.5066700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97831, 'Gabriel Leyva Velázquez', 'Gabriel Leyva Velazquez', 'Gabriel Leyva Velazquez,Gabriel Leyva Velázquez', 25.7911100, -108.5633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97832, 'Analco de Ponciano Arriaga (Santa Cruz Analco)', 'Analco de Ponciano Arriaga (Santa Cruz Analco)', 'Analco de Ponciano Arriaga (Santa Cruz Analco)', 19.2644400, -98.5002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97833, 'San Isidro', 'San Isidro', 'San Isidro', 19.7963900, -97.3836100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97834, 'Cala Sur', 'Cala Sur', 'Cala Sur', 19.8327800, -97.4211100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97835, 'Viñas del Sol', 'Vinas del Sol', 'Vinas del Sol,Viñas del Sol', 32.6269400, -115.5466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97836, 'Kotolte', 'Kotolte', 'Kotolte', 16.8644400, -92.4611100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97837, 'Tepetzingo', 'Tepetzingo', 'Tepetzingo', 18.9380600, -99.6125000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97838, 'Apango de Zaragoza', 'Apango de Zaragoza', 'Apango de Zaragoza', 19.0683300, -97.9402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97839, 'Cartagena [Fraccionamiento]', 'Cartagena [Fraccionamiento]', 'Cartagena [Fraccionamiento]', 21.9563900, -102.2763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97840, 'Bellavista de Victoria (San José Bellavista)', 'Bellavista de Victoria (San Jose Bellavista)', 'Bellavista de Victoria (San Jose Bellavista),Bellavista de Victoria (San José Bellavista)', 18.8763900, -97.5438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97841, 'Ninguno [Centro de Readaptación Social de Atlacholoaya]', 'Ninguno [Centro de Readaptacion Social de Atlacholoaya]', 'Ninguno [Centro de Readaptacion Social de Atlacholoaya],Ninguno [Centro de Readaptación Social de Atlacholoaya]', 18.7577800, -99.2294400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97842, 'Suchilapan del Río', 'Suchilapan del Rio', 'Suchilapan del Rio,Suchilapan del Río', 17.3861100, -94.9880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97843, 'Polígonos', 'Poligonos', 'Poligonos,Polígonos', 19.4161200, -98.9909100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97844, 'San Jerónimo Almoloya', 'San Jeronimo Almoloya', 'San Jeronimo Almoloya,San Jerónimo Almoloya', 18.9411100, -98.0105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97845, 'Tlalnepantla', 'Tlalnepantla', 'Tlalnepantla', 21.1800000, -98.8461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97846, 'Rinconada la Loma [Fraccionamiento]', 'Rinconada la Loma [Fraccionamiento]', 'Rinconada la Loma [Fraccionamiento]', 20.4541700, -103.2191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97847, 'Llano Suchiapa', 'Llano Suchiapa', 'Llano Suchiapa', 16.8661100, -95.0538900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97848, 'Colonia Paraíso Escondido', 'Colonia Paraiso Escondido', 'Colonia Paraiso Escondido,Colonia Paraíso Escondido', 21.0533300, -105.2383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97849, 'Colonia Emiliano Zapata Ejido de Tenancingo', 'Colonia Emiliano Zapata Ejido de Tenancingo', 'Colonia Emiliano Zapata Ejido de Tenancingo', 18.9536100, -99.5588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97850, 'Progreso', 'Progreso', 'Progreso', 20.0197200, -99.2386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97851, 'Acxotla del Río', 'Acxotla del Rio', 'Acxotla del Rio,Acxotla del Río', 19.3241700, -98.2375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97852, 'El Rincón (Santa Cruz del Rincón)', 'El Rincon (Santa Cruz del Rincon)', 'El Rincon (Santa Cruz del Rincon),El Rincón (Santa Cruz del Rincón)', 16.9961100, -98.7352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97853, 'El Nabo', 'El Nabo', 'El Nabo', 20.6938900, -100.4802800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97854, 'Jorobas', 'Jorobas', 'Jorobas', 19.8238900, -99.2483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97855, 'Lomas de la Maestranza', 'Lomas de la Maestranza', 'Lomas de la Maestranza', 19.6875000, -101.3302800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97856, 'Paseos del Pedregal', 'Paseos del Pedregal', 'Paseos del Pedregal', 20.6641700, -100.3980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97857, 'Las Esperanzas (El Ranchito)', 'Las Esperanzas (El Ranchito)', 'Las Esperanzas (El Ranchito)', 23.8497200, -103.1311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97858, 'Centro de Readaptación Social', 'Centro de Readaptacion Social', 'Centro de Readaptacion Social,Centro de Readaptación Social', 19.6250000, -97.2202800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97859, 'Ejido de Mozoquilpan', 'Ejido de Mozoquilpan', 'Ejido de Mozoquilpan', 19.4241700, -99.5283300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97860, 'San Pedro Xochiteotla', 'San Pedro Xochiteotla', 'San Pedro Xochiteotla', 19.3066700, -98.1400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97861, 'La Noria', 'La Noria', 'La Noria', 16.2544400, -95.2205600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97862, 'Colonia San Isidro', 'Colonia San Isidro', 'Colonia San Isidro', 19.4116700, -98.1127800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97863, 'Chiloljá', 'Chilolja', 'Chilolja,Chiloljá', 16.8852800, -92.4247200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97864, 'Pantitlán', 'Pantitlan', 'Pantitlan,Pantitlán', 17.6397200, -99.1097200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97865, 'San Francisco (El Calvito)', 'San Francisco (El Calvito)', 'San Francisco (El Calvito)', 16.3216700, -92.5619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97866, 'Fraccionamiento Ciudad Yagul', 'Fraccionamiento Ciudad Yagul', 'Fraccionamiento Ciudad Yagul', 16.9775000, -96.4619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97867, 'San Miguel del Progreso', 'San Miguel del Progreso', 'San Miguel del Progreso', 19.9897200, -97.6666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97868, 'El Recuerdo de Ancón (Xoconoxtle de Arriba)', 'El Recuerdo de Ancon (Xoconoxtle de Arriba)', 'El Recuerdo de Ancon (Xoconoxtle de Arriba),El Recuerdo de Ancón (Xoconoxtle de Arriba)', 20.6380600, -101.1269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97869, 'Fraccionamiento Ex-Hacienda Catano', 'Fraccionamiento Ex-Hacienda Catano', 'Fraccionamiento Ex-Hacienda Catano', 17.2275000, -96.8155600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97870, 'Tlacotepec de José Manzo', 'Tlacotepec de Jose Manzo', 'Tlacotepec de Jose Manzo,Tlacotepec de José Manzo', 19.2719400, -98.4847200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97871, 'San José Tenería (Tenería)', 'San Jose Teneria (Teneria)', 'San Jose Teneria (Teneria),San José Tenería (Tenería)', 18.9502800, -99.5430600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97872, 'Palma Grande', 'Palma Grande', 'Palma Grande', 21.9933300, -105.3894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97873, 'Colonia las Malvinas (Colonia Antorcha)', 'Colonia las Malvinas (Colonia Antorcha)', 'Colonia las Malvinas (Colonia Antorcha)', 19.8783300, -102.2258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97874, 'Manzana Quinta (La Cañada)', 'Manzana Quinta (La Canada)', 'Manzana Quinta (La Canada),Manzana Quinta (La Cañada)', 19.5422200, -99.6025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97875, 'Carrillo Puerto', 'Carrillo Puerto', 'Carrillo Puerto', 22.4313900, -97.9641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97876, 'Cherán Atzicuirín (Cheranástico)', 'Cheran Atzicuirin (Cheranastico)', 'Cheran Atzicuirin (Cheranastico),Cherán Atzicuirín (Cheranástico)', 19.7000000, -102.0155600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97877, 'Ejido la Soledad', 'Ejido la Soledad', 'Ejido la Soledad', 19.6450000, -100.1063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97878, 'Tehuilotepec', 'Tehuilotepec', 'Tehuilotepec', 18.5516700, -99.5811100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97879, 'Villa de Guadalupe', 'Villa de Guadalupe', 'Villa de Guadalupe', 25.5144400, -103.4891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97880, 'Hacienda la Cruz [Fraccionamiento]', 'Hacienda la Cruz [Fraccionamiento]', 'Hacienda la Cruz [Fraccionamiento]', 20.6333300, -100.2627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97881, 'San Salvador (Naranjillo)', 'San Salvador (Naranjillo)', 'San Salvador (Naranjillo)', 19.8313900, -97.3150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97882, 'Colonia Campesina', 'Colonia Campesina', 'Colonia Campesina', 28.1402800, -105.5266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97883, 'San Miguel Tianguizolco', 'San Miguel Tianguizolco', 'San Miguel Tianguizolco', 19.1586100, -98.4408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97884, 'San Cosme Atlamaxac', 'San Cosme Atlamaxac', 'San Cosme Atlamaxac', 19.2383300, -98.2258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97885, 'Mismaloya (Fraccionamiento Pedregal de Santa Martha)', 'Mismaloya (Fraccionamiento Pedregal de Santa Martha)', 'Mismaloya (Fraccionamiento Pedregal de Santa Martha)', 20.6069400, -103.1713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97886, 'La Roca', 'La Roca', 'La Roca', 20.5127800, -103.4263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97887, 'El Cuervero (Cuerveros)', 'El Cuervero (Cuerveros)', 'El Cuervero (Cuerveros)', 21.8605600, -102.6838900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97888, 'San Bartolo del Llano (San Isidro)', 'San Bartolo del Llano (San Isidro)', 'San Bartolo del Llano (San Isidro)', 19.3052800, -99.8275000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97889, 'San Isidro Gallinero (El Gallinero)', 'San Isidro Gallinero (El Gallinero)', 'San Isidro Gallinero (El Gallinero)', 16.8813900, -99.7141700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97890, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 16.7561100, -98.1816700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97891, 'Amacuitlapilco', 'Amacuitlapilco', 'Amacuitlapilco', 18.6961100, -98.8116700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97892, 'Loma Bonita', 'Loma Bonita', 'Loma Bonita', 18.9314400, -99.1756400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97893, 'Colonia Río Lerma (Tic Ti)', 'Colonia Rio Lerma (Tic Ti)', 'Colonia Rio Lerma (Tic Ti),Colonia Río Lerma (Tic Ti)', 19.8055600, -99.8972200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97894, 'San Mateo Capultitlán', 'San Mateo Capultitlan', 'San Mateo Capultitlan,San Mateo Capultitlán', 19.1950000, -98.4152800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97895, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 18.4013900, -92.9594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97896, 'San Juan Ahuehueyo', 'San Juan Ahuehueyo', 'San Juan Ahuehueyo', 18.7150000, -98.9327800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97897, 'San José Carpinteros', 'San Jose Carpinteros', 'San Jose Carpinteros,San José Carpinteros', 18.9947200, -97.9116700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97898, 'Colonia Ricardo Flores Magón', 'Colonia Ricardo Flores Magon', 'Colonia Ricardo Flores Magon,Colonia Ricardo Flores Magón', 19.2683300, -99.7583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97899, 'Santa Martha', 'Santa Martha', 'Santa Martha', 19.4314500, -98.9174400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97900, 'Hermenegildo J. Aldana', 'Hermenegildo J. Aldana', 'Hermenegildo J. Aldana', 18.0061100, -94.6122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97901, 'Colonia Guadalupe Victoria (La Capilla)', 'Colonia Guadalupe Victoria (La Capilla)', 'Colonia Guadalupe Victoria (La Capilla)', 19.4022200, -99.4541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97902, 'Corral del Risco (Punta de Mita)', 'Corral del Risco (Punta de Mita)', 'Corral del Risco (Punta de Mita)', 20.7736100, -105.5166700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97903, 'El Curtidor', 'El Curtidor', 'El Curtidor', 19.2916700, -99.8350000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97904, 'San Andrés', 'San Andres', 'San Andres,San Andrés', 19.7900000, -97.3388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97905, 'Poblado C-21 Licenciado Benito Juárez García', 'Poblado C-21 Licenciado Benito Juarez Garcia', 'Poblado C-21 Licenciado Benito Juarez Garcia,Poblado C-21 Licenciado Benito Juárez García', 18.0677800, -93.5613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97906, 'Cima del Sol (Fraccionamiento Cima del Sol)', 'Cima del Sol (Fraccionamiento Cima del Sol)', 'Cima del Sol (Fraccionamiento Cima del Sol)', 20.4688900, -103.4172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97907, 'Pueblos Unidos', 'Pueblos Unidos', 'Pueblos Unidos', 24.2925000, -107.1513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97908, 'Luis Rodríguez (El Vergel)', 'Luis Rodriguez (El Vergel)', 'Luis Rodriguez (El Vergel),Luis Rodríguez (El Vergel)', 30.4072200, -115.8872200, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97909, 'Betania', 'Betania', 'Betania', 16.6063900, -92.5219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97910, 'San Miguel Espejo', 'San Miguel Espejo', 'San Miguel Espejo', 19.0950000, -98.0666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97911, 'Alfonso G. Calderón Velarde', 'Alfonso G. Calderon Velarde', 'Alfonso G. Calderon Velarde,Alfonso G. Calderón Velarde', 25.7855600, -108.6022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97912, 'Colonia San Ramón', 'Colonia San Ramon', 'Colonia San Ramon,Colonia San Ramón', 18.9683300, -99.5722200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97913, 'Paso de Arena', 'Paso de Arena', 'Paso de Arena', 18.3033300, -100.8463900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97914, 'Tulipanes', 'Tulipanes', 'Tulipanes', 20.0602800, -98.7672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97915, 'San Francisco Temetzontla', 'San Francisco Temetzontla', 'San Francisco Temetzontla', 19.3502800, -98.2886100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97916, 'Los Laureles', 'Los Laureles', 'Los Laureles', 19.4877800, -89.9944400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97917, 'Panales Jamaica (Cañones)', 'Panales Jamaica (Canones)', 'Panales Jamaica (Canones),Panales Jamaica (Cañones)', 20.2955600, -100.8230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97918, 'Loma Bonita', 'Loma Bonita', 'Loma Bonita', 19.1872200, -100.2150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97919, 'Cereso 14 (El Amate)', 'Cereso 14 (El Amate)', 'Cereso 14 (El Amate)', 16.5947200, -93.8027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97920, 'Acatepec', 'Acatepec', 'Acatepec', 17.3247200, -98.9094400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97921, 'Bonifacio Moreno (El Aguaje)', 'Bonifacio Moreno (El Aguaje)', 'Bonifacio Moreno (El Aguaje)', 18.9916700, -102.7108300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97922, 'Las Cañadas', 'Las Canadas', 'Las Canadas,Las Cañadas', 20.2975000, -101.9780600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97923, 'Santa Catarina Villanueva', 'Santa Catarina Villanueva', 'Santa Catarina Villanueva', 18.9991700, -97.6147200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97924, 'Doctor Rodulfo Figueroa (Tierra Blanca)', 'Doctor Rodulfo Figueroa (Tierra Blanca)', 'Doctor Rodulfo Figueroa (Tierra Blanca)', 15.8508300, -92.0622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97925, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 20.8816700, -87.5250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97926, 'Unión Ejidal Tierra y Libertad', 'Union Ejidal Tierra y Libertad', 'Union Ejidal Tierra y Libertad,Unión Ejidal Tierra y Libertad', 19.6575000, -98.3375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97927, 'El Tigre', 'El Tigre', 'El Tigre', 18.1019400, -92.9419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97928, 'Veinte de Noviembre', 'Veinte de Noviembre', 'Veinte de Noviembre', 16.6200000, -92.0819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97929, 'Barrio de Centro del Cerrillo', 'Barrio de Centro del Cerrillo', 'Barrio de Centro del Cerrillo', 19.5369400, -99.9541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97930, 'Centro de Readaptación Social Nuevo', 'Centro de Readaptacion Social Nuevo', 'Centro de Readaptacion Social Nuevo,Centro de Readaptación Social Nuevo', 31.1844400, -110.9677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97931, 'Santa Rosa de Lima', 'Santa Rosa de Lima', 'Santa Rosa de Lima', 16.0711100, -97.6233300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97932, 'San Antonio del Monte', 'San Antonio del Monte', 'San Antonio del Monte', 16.7602800, -92.6530600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97933, 'Loma Larga (Barrio de Loma Larga)', 'Loma Larga (Barrio de Loma Larga)', 'Loma Larga (Barrio de Loma Larga)', 19.8672200, -99.1161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97934, 'Xhixhata', 'Xhixhata', 'Xhixhata', 19.9705600, -99.5461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97935, 'Nuevo Paso Nazareno (Chichicazapa)', 'Nuevo Paso Nazareno (Chichicazapa)', 'Nuevo Paso Nazareno (Chichicazapa)', 18.2966700, -96.3472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97936, 'Llano Largo', 'Llano Largo', 'Llano Largo', 20.3011100, -99.7655600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97937, 'El Encanto del Cerril', 'El Encanto del Cerril', 'El Encanto del Cerril', 18.9319400, -98.4255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97938, 'La Mesa de Chosto', 'La Mesa de Chosto', 'La Mesa de Chosto', 19.8525000, -99.8902800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97939, 'Magisterio Digno', 'Magisterio Digno', 'Magisterio Digno', 20.0569400, -98.7688900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97940, 'Pañhé', 'Panhe', 'Panhe,Pañhé', 20.5216700, -99.6966700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97941, 'El Carmen (El Limón)', 'El Carmen (El Limon)', 'El Carmen (El Limon),El Carmen (El Limón)', 17.8905600, -93.1652800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97942, 'El Romereño (INFONAVIT)', 'El Romereno (INFONAVIT)', 'El Romereno (INFONAVIT),El Romereño (INFONAVIT)', 20.3808300, -102.9494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97943, 'Lindavista', 'Lindavista', 'Lindavista', 20.0261100, -98.7977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97944, 'Tz''Aquiviljok', 'Tz''Aquiviljok', 'Tz''Aquiviljok', 16.8552800, -92.4597200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97945, 'Tonalá', 'Tonala', 'Tonala,Tonalá', 16.8616700, -99.0544400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97946, 'Tecpantzacoalco', 'Tecpantzacoalco', 'Tecpantzacoalco', 18.4769400, -97.0394400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97947, 'Barrio de Jesús Fracción Primera', 'Barrio de Jesus Fraccion Primera', 'Barrio de Jesus Fraccion Primera,Barrio de Jesús Fracción Primera', 19.3677800, -99.6869400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97948, 'Colonia Morelos (El Nueve)', 'Colonia Morelos (El Nueve)', 'Colonia Morelos (El Nueve)', 20.2250000, -99.1411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97949, 'Arboledas', 'Arboledas', 'Arboledas', 19.2072200, -96.2144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97950, 'Texcaltitán Xoteapan (Texcaltitán)', 'Texcaltitan Xoteapan (Texcaltitan)', 'Texcaltitan Xoteapan (Texcaltitan),Texcaltitán Xoteapan (Texcaltitán)', 18.4466700, -95.2533300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97951, 'Fredepo', 'Fredepo', 'Fredepo', 18.8805600, -96.9769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97952, 'Diamante de Echeverría', 'Diamante de Echeverria', 'Diamante de Echeverria,Diamante de Echeverría', 16.1133300, -92.8800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97953, 'San Francisco', 'San Francisco', 'San Francisco', 27.6450000, -113.4191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97954, 'Octaviano López', 'Octaviano Lopez', 'Octaviano Lopez,Octaviano López', 27.0025000, -105.0330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97955, 'Progreso', 'Progreso', 'Progreso', 22.2283300, -100.1280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97956, 'Texalpan de Arriba', 'Texalpan de Arriba', 'Texalpan de Arriba', 18.4294400, -95.2441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97957, 'Gunyo Poniente (San José Gunyo)', 'Gunyo Poniente (San Jose Gunyo)', 'Gunyo Poniente (San Jose Gunyo),Gunyo Poniente (San José Gunyo)', 20.1114900, -99.8386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97958, 'Chulum Juárez', 'Chulum Juarez', 'Chulum Juarez,Chulum Juárez', 17.3319400, -92.5338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97959, 'El Salto', 'El Salto', 'El Salto', 23.1955600, -103.0675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97960, 'Barrio de Guadalupe', 'Barrio de Guadalupe', 'Barrio de Guadalupe', 19.2305400, -98.9309000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97961, 'Ladrillera (Entronque Pesquería)', 'Ladrillera (Entronque Pesqueria)', 'Ladrillera (Entronque Pesqueria),Ladrillera (Entronque Pesquería)', 25.8030600, -100.1011100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97962, 'San Francisco (Mata Clara)', 'San Francisco (Mata Clara)', 'San Francisco (Mata Clara)', 18.8144400, -96.7461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97963, 'Cipreses', 'Cipreses', 'Cipreses', 20.0588900, -98.7675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97964, 'Colonia el Renacimiento', 'Colonia el Renacimiento', 'Colonia el Renacimiento', 19.2188900, -96.2163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97965, 'Macario J. Gómez [Colonia]', 'Macario J. Gomez [Colonia]', 'Macario J. Gomez [Colonia],Macario J. Gómez [Colonia]', 21.9805600, -102.2513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97966, 'Unidad Habitacional Antonio Osorio de León (Bojay)', 'Unidad Habitacional Antonio Osorio de Leon (Bojay)', 'Unidad Habitacional Antonio Osorio de Leon (Bojay),Unidad Habitacional Antonio Osorio de León (Bojay)', 20.0438900, -99.2447200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97967, 'Taniperla', 'Taniperla', 'Taniperla', 16.8222200, -91.5233300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97968, 'San José Monte Chiquito', 'San Jose Monte Chiquito', 'San Jose Monte Chiquito,San José Monte Chiquito', 18.4961100, -97.4380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97969, 'Xonalpu', 'Xonalpu', 'Xonalpu', 20.1283300, -97.6105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97970, 'Morelos Piedra 3ra. Sección', 'Morelos Piedra 3ra. Seccion', 'Morelos Piedra 3ra. Seccion,Morelos Piedra 3ra. Sección', 18.1438900, -93.2200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97971, 'San Francisco Tlaltica', 'San Francisco Tlaltica', 'San Francisco Tlaltica', 19.6583300, -98.7750000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97972, 'San Francisco Zacapexpan', 'San Francisco Zacapexpan', 'San Francisco Zacapexpan', 19.8802800, -97.5961100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97973, 'Cliserio Alanís (San Gaspar)', 'Cliserio Alanis (San Gaspar)', 'Cliserio Alanis (San Gaspar),Cliserio Alanís (San Gaspar)', 18.8611100, -99.1600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97974, 'Tinajitas', 'Tinajitas', 'Tinajitas', 19.6180600, -96.4425000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97975, 'Nuevo Vicente Guerrero (El Chichonal)', 'Nuevo Vicente Guerrero (El Chichonal)', 'Nuevo Vicente Guerrero (El Chichonal)', 16.4852800, -92.8713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97976, 'San Isidro (El Reservado)', 'San Isidro (El Reservado)', 'San Isidro (El Reservado)', 19.3069400, -99.7788900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97977, 'Mariano Balleza', 'Mariano Balleza', 'Mariano Balleza', 26.9538900, -106.3461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97978, 'Brisas del Carrizal', 'Brisas del Carrizal', 'Brisas del Carrizal', 18.0155600, -92.9708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97979, 'Rafael Yáñez Sosa (El Mezquite)', 'Rafael Yanez Sosa (El Mezquite)', 'Rafael Yanez Sosa (El Mezquite),Rafael Yáñez Sosa (El Mezquite)', 23.3283300, -102.6102800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97980, 'Bocaneo (San Pedro)', 'Bocaneo (San Pedro)', 'Bocaneo (San Pedro)', 19.8386100, -100.8172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97981, 'CEFERESO Número 3', 'CEFERESO Numero 3', 'CEFERESO Numero 3,CEFERESO Número 3', 25.8472200, -97.6333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97982, 'Tzeltal', 'Tzeltal', 'Tzeltal', 16.9394400, -92.4777800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97983, 'Alfredo V. Bonfil (Chacampalco)', 'Alfredo V. Bonfil (Chacampalco)', 'Alfredo V. Bonfil (Chacampalco)', 18.6552800, -99.1541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97984, 'San Buenaventura Atempan', 'San Buenaventura Atempan', 'San Buenaventura Atempan', 19.3266700, -98.2219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97985, 'Tocob Leglemal', 'Tocob Leglemal', 'Tocob Leglemal', 17.2338900, -92.3783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97986, 'Altus Bosques', 'Altus Bosques', 'Altus Bosques', 20.5680600, -103.3725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97987, 'Barrio de Nuevo León', 'Barrio de Nuevo Leon', 'Barrio de Nuevo Leon,Barrio de Nuevo León', 19.0886100, -98.2900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97988, 'Colonia 18 de Marzo', 'Colonia 18 de Marzo', 'Colonia 18 de Marzo', 20.5555600, -101.0355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97989, 'Heriberto Valdez Romero (El Guayabo)', 'Heriberto Valdez Romero (El Guayabo)', 'Heriberto Valdez Romero (El Guayabo)', 25.9405600, -109.1372200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97990, 'San José Chapayal', 'San Jose Chapayal', 'San Jose Chapayal,San José Chapayal', 17.3005600, -92.8902800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97991, 'Seis de Octubre (Santo Niño)', 'Seis de Octubre (Santo Nino)', 'Seis de Octubre (Santo Nino),Seis de Octubre (Santo Niño)', 25.7638900, -103.2388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97992, 'La Escalera', 'La Escalera', 'La Escalera', 17.8436100, -92.5255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97993, 'Papatlazolco', 'Papatlazolco', 'Papatlazolco', 20.1775000, -97.9916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97994, 'Colonia Felipe Ángeles', 'Colonia Felipe Angeles', 'Colonia Felipe Angeles,Colonia Felipe Ángeles', 20.0541700, -98.4186100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97995, 'San Francisco (Baños de Agua Caliente)', 'San Francisco (Banos de Agua Caliente)', 'San Francisco (Banos de Agua Caliente),San Francisco (Baños de Agua Caliente)', 21.0738900, -101.4727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97996, 'Ciudad Morelos', 'Ciudad Morelos', 'Ciudad Morelos', 32.3438900, -117.0105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97997, 'El Copalar', 'El Copalar', 'El Copalar', 16.8769400, -93.2138900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97998, 'San Diego', 'San Diego', 'San Diego', 19.8566700, -97.3611100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(97999, 'San Pedro Xalcaltzinco', 'San Pedro Xalcaltzinco', 'San Pedro Xalcaltzinco', 19.2277800, -98.2280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98000, 'Campo Real', 'Campo Real', 'Campo Real', 20.7872200, -103.4430600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98001, 'Taxco', 'Taxco', 'Taxco', 18.1391700, -93.0052800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98002, 'Belisario Domínguez', 'Belisario Dominguez', 'Belisario Dominguez,Belisario Domínguez', 15.2994400, -92.3805600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98003, 'Sierra de Guadalupe', 'Sierra de Guadalupe', 'Sierra de Guadalupe', 19.5925000, -99.1594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98004, 'Ninguno [CERESO]', 'Ninguno [CERESO]', 'Ninguno [CERESO]', 28.6097200, -105.9402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98005, 'Acatempa', 'Acatempa', 'Acatempa', 17.6433300, -99.3663900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98006, 'Chimalapa', 'Chimalapa', 'Chimalapa', 20.1880600, -98.1600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98007, 'Xoxonacatla', 'Xoxonacatla', 'Xoxonacatla', 20.0075000, -97.9405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98008, 'Otilpan', 'Otilpan', 'Otilpan', 19.5572200, -96.9766700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98009, 'Progreso de Juárez', 'Progreso de Juarez', 'Progreso de Juarez,Progreso de Juárez', 18.9616700, -97.7555600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98010, 'San Rafael Tepatlaxco', 'San Rafael Tepatlaxco', 'San Rafael Tepatlaxco', 19.2983300, -98.1197200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98011, 'Vallecitos de Zaragoza', 'Vallecitos de Zaragoza', 'Vallecitos de Zaragoza', 17.9202800, -101.3236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98012, 'Monte Grande', 'Monte Grande', 'Monte Grande', 20.9980600, -101.8633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98013, 'San José del Cerrito de Camargo', 'San Jose del Cerrito de Camargo', 'San Jose del Cerrito de Camargo,San José del Cerrito de Camargo', 20.4191700, -101.0422200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98014, 'Barrio de España', 'Barrio de Espana', 'Barrio de Espana,Barrio de España', 19.8613900, -99.0816700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98015, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', 20.3441700, -102.0055600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98016, 'Techachaltitla', 'Techachaltitla', 'Techachaltitla', 19.3650000, -98.9405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98017, 'Francisco I. Madero', 'Francisco I. Madero', 'Francisco I. Madero', 16.8742700, -93.2167800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98018, 'Ricardo Flores Magón', 'Ricardo Flores Magon', 'Ricardo Flores Magon,Ricardo Flores Magón', 25.7405600, -108.9958300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98019, 'San Francisco Tlacuilohcan', 'San Francisco Tlacuilohcan', 'San Francisco Tlacuilohcan', 19.4016700, -98.1927800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98020, 'Valle Huejúcar (Fraccionamiento Popular) [Fraccionamiento]', 'Valle Huejucar (Fraccionamiento Popular) [Fraccionamiento]', 'Valle Huejucar (Fraccionamiento Popular) [Fraccionamiento],Valle Huejúcar (Fraccionamiento Popular) [Fraccionamiento]', 21.8311100, -102.7502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98021, 'San Antonio Tecolco', 'San Antonio Tecolco', 'San Antonio Tecolco', 18.8522200, -97.7780600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98022, 'Fraccionamiento Hacienda del Bosque', 'Fraccionamiento Hacienda del Bosque', 'Fraccionamiento Hacienda del Bosque', 19.7266700, -98.9686100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98023, 'Oso Viejo', 'Oso Viejo', 'Oso Viejo', 24.3994400, -107.1713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98024, 'El Cortijo', 'El Cortijo', 'El Cortijo', 16.9897200, -99.1488900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98025, 'Colonia Montemariana (Colonia Mariana)', 'Colonia Montemariana (Colonia Mariana)', 'Colonia Montemariana (Colonia Mariana)', 23.3263900, -103.1122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98026, 'Santa Ana', 'Santa Ana', 'Santa Ana', 21.0591700, -101.6758300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98027, 'Colonia Latinoamericana', 'Colonia Latinoamericana', 'Colonia Latinoamericana', 21.0302800, -101.7058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98028, 'Zahuatlán de Morelos (San José)', 'Zahuatlan de Morelos (San Jose)', 'Zahuatlan de Morelos (San Jose),Zahuatlán de Morelos (San José)', 18.9833300, -97.8675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98029, 'El Pozole', 'El Pozole', 'El Pozole', 22.9147200, -105.9133300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98030, 'Tatauzoquico', 'Tatauzoquico', 'Tatauzoquico', 19.8283300, -97.5269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98031, 'Guadalupe Minerva', 'Guadalupe Minerva', 'Guadalupe Minerva', 20.1258300, -98.7138900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98032, 'San José', 'San Jose', 'San Jose,San José', 19.8030600, -97.3338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98033, 'San Lorenzo Tlaxipehuala', 'San Lorenzo Tlaxipehuala', 'San Lorenzo Tlaxipehuala', 20.1302800, -97.9736100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98034, 'Paseo de las Cañadas', 'Paseo de las Canadas', 'Paseo de las Canadas,Paseo de las Cañadas', 20.6213900, -103.1977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98035, 'Constancio Farfán (La Pascuala)', 'Constancio Farfan (La Pascuala)', 'Constancio Farfan (La Pascuala),Constancio Farfán (La Pascuala)', 18.7419400, -98.9538900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98036, 'Villas Fundadores [Fraccionamiento]', 'Villas Fundadores [Fraccionamiento]', 'Villas Fundadores [Fraccionamiento]', 20.3777800, -99.9094400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98037, 'Bella Vista del Río', 'Bella Vista del Rio', 'Bella Vista del Rio,Bella Vista del Río', 20.6900000, -99.5713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98038, 'Abelardo L. Rodríguez', 'Abelardo L. Rodriguez', 'Abelardo L. Rodriguez,Abelardo L. Rodríguez', 18.7375000, -98.9852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98039, 'El Rincón de San Felipe (Tercera Manzana San Felipe)', 'El Rincon de San Felipe (Tercera Manzana San Felipe)', 'El Rincon de San Felipe (Tercera Manzana San Felipe),El Rincón de San Felipe (Tercera Manzana San Felipe)', 19.5063900, -100.3727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98040, 'Fraccionamiento Monte Olivo', 'Fraccionamiento Monte Olivo', 'Fraccionamiento Monte Olivo', 19.9847200, -102.2511100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98041, 'Tlamanca de Hernández', 'Tlamanca de Hernandez', 'Tlamanca de Hernandez,Tlamanca de Hernández', 19.9559700, -97.8148900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98042, 'Purísima del Progreso', 'Purisima del Progreso', 'Purisima del Progreso,Purísima del Progreso', 20.7933300, -101.3302800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98043, 'Calvario Buenavista', 'Calvario Buenavista', 'Calvario Buenavista', 19.7041700, -99.9569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98044, 'El Jacal', 'El Jacal', 'El Jacal', 19.4050000, -100.0894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98045, 'San Pedro de los Sauces', 'San Pedro de los Sauces', 'San Pedro de los Sauces', 19.7863900, -101.1377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98046, 'La Azozuca', 'La Azozuca', 'La Azozuca', 16.8213900, -99.0419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98047, 'Colonia Agrícola Álvaro Obregón', 'Colonia Agricola Alvaro Obregon', 'Colonia Agricola Alvaro Obregon,Colonia Agrícola Álvaro Obregón', 19.2280600, -99.5558300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98048, 'Cuatzoquitengo', 'Cuatzoquitengo', 'Cuatzoquitengo', 17.2882200, -98.6152300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98049, 'Palmillas', 'Palmillas', 'Palmillas', 19.6936100, -99.9502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98050, 'Lagartera 1ra. Sección', 'Lagartera 1ra. Seccion', 'Lagartera 1ra. Seccion,Lagartera 1ra. Sección', 18.0627700, -92.8856300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98051, 'Hacienda Vieja del Castillo (Castillo Viejo)', 'Hacienda Vieja del Castillo (Castillo Viejo)', 'Hacienda Vieja del Castillo (Castillo Viejo)', 20.5400000, -103.2441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98052, 'Ceiba 1ra. Sección (Jahuactal)', 'Ceiba 1ra. Seccion (Jahuactal)', 'Ceiba 1ra. Seccion (Jahuactal),Ceiba 1ra. Sección (Jahuactal)', 18.0622200, -93.1130600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98053, 'San Vicente Zoyatlán', 'San Vicente Zoyatlan', 'San Vicente Zoyatlan,San Vicente Zoyatlán', 17.3225000, -98.3641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98054, 'Tenochtitlán', 'Tenochtitlan', 'Tenochtitlan,Tenochtitlán', 19.8091700, -96.9161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98055, 'Huehuetán', 'Huehuetan', 'Huehuetan,Huehuetán', 16.6358300, -98.5588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98056, 'Chichicaxtle', 'Chichicaxtle', 'Chichicaxtle', 19.3430600, -96.4686100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98057, 'Manuel Villalongín', 'Manuel Villalongin', 'Manuel Villalongin,Manuel Villalongín', 20.2375000, -101.5266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98058, 'La Versolilla', 'La Versolilla', 'La Versolilla', 20.8730600, -100.3788900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98059, 'Colonia Tulteca Teopan', 'Colonia Tulteca Teopan', 'Colonia Tulteca Teopan', 19.5613900, -98.8441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98060, 'Fraccionamiento Paseo de las Torres', 'Fraccionamiento Paseo de las Torres', 'Fraccionamiento Paseo de las Torres', 21.1683300, -101.7580600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98061, 'El Cahulote de Santa Ana', 'El Cahulote de Santa Ana', 'El Cahulote de Santa Ana', 19.0761100, -101.5825000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98062, 'Colonia Agrícola de Ocotepec (Colonia San José)', 'Colonia Agricola de Ocotepec (Colonia San Jose)', 'Colonia Agricola de Ocotepec (Colonia San Jose),Colonia Agrícola de Ocotepec (Colonia San José)', 18.9297200, -98.5444400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98063, 'Apeo', 'Apeo', 'Apeo', 19.8872200, -100.3419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98064, 'Leacaman', 'Leacaman', 'Leacaman', 20.0986100, -97.6430600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98065, 'Yashanal', 'Yashanal', 'Yashanal', 16.8288900, -92.4519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98066, 'Santa Elena', 'Santa Elena', 'Santa Elena', 19.8586100, -100.4083300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98067, 'Cinco de Mayo', 'Cinco de Mayo', 'Cinco de Mayo', 20.1316700, -97.6300000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98068, 'Buenavista de Juárez', 'Buenavista de Juarez', 'Buenavista de Juarez,Buenavista de Juárez', 18.9450000, -97.8277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98069, 'Colonia Emiliano Zapata (San Juan Zitácuaro)', 'Colonia Emiliano Zapata (San Juan Zitacuaro)', 'Colonia Emiliano Zapata (San Juan Zitacuaro),Colonia Emiliano Zapata (San Juan Zitácuaro)', 19.4477800, -100.3058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98070, 'Caparroso', 'Caparroso', 'Caparroso', 18.3450000, -92.8036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98071, 'Colonia Diana Laura Riojas de Colosio', 'Colonia Diana Laura Riojas de Colosio', 'Colonia Diana Laura Riojas de Colosio', 26.9772200, -101.4808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98072, 'Tlaxinga (Clatzinga)', 'Tlaxinga (Clatzinga)', 'Tlaxinga (Clatzinga)', 17.5210600, -99.1933100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98073, 'Fraccionamiento San Miguel', 'Fraccionamiento San Miguel', 'Fraccionamiento San Miguel', 17.2127800, -96.7869400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98074, 'Paso Nacional', 'Paso Nacional', 'Paso Nacional', 18.7663900, -95.7486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98075, 'San Pedro Nichtalucum', 'San Pedro Nichtalucum', 'San Pedro Nichtalucum', 17.0344400, -92.7269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98076, 'Hermenegildo Galeana 2da. Sección', 'Hermenegildo Galeana 2da. Seccion', 'Hermenegildo Galeana 2da. Seccion,Hermenegildo Galeana 2da. Sección', 18.1705400, -93.1350800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98077, 'La Gloria', 'La Gloria', 'La Gloria', 15.9638900, -91.9650000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98078, 'Hacienda Tecate', 'Hacienda Tecate', 'Hacienda Tecate', 32.5650000, -116.5250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98079, 'San Javier', 'San Javier', 'San Javier', 20.7525000, -99.7177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98080, 'San Antonio la Portilla', 'San Antonio la Portilla', 'San Antonio la Portilla', 18.7961100, -97.7627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98081, 'San Bartolomé Hueyapan', 'San Bartolome Hueyapan', 'San Bartolome Hueyapan,San Bartolomé Hueyapan', 19.0252800, -97.9305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98082, 'Marcelino Rodríguez (San Ignacio)', 'Marcelino Rodriguez (San Ignacio)', 'Marcelino Rodriguez (San Ignacio),Marcelino Rodríguez (San Ignacio)', 18.5788900, -98.7436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98083, 'Francisco I. Madero', 'Francisco I. Madero', 'Francisco I. Madero', 18.3266700, -95.3625000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98084, 'San Sebastián [Fraccionamiento]', 'San Sebastian [Fraccionamiento]', 'San Sebastian [Fraccionamiento],San Sebastián [Fraccionamiento]', 21.8213900, -102.2711100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98085, 'Fraccionamiento Universo', 'Fraccionamiento Universo', 'Fraccionamiento Universo', 18.9616700, -99.1863900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98086, 'El Esclavo', 'El Esclavo', 'El Esclavo', 19.6766700, -99.3713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98087, 'Ahuacatlán', 'Ahuacatlan', 'Ahuacatlan,Ahuacatlán', 20.1372200, -98.0075000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98088, 'Santa Cruz Acapa', 'Santa Cruz Acapa', 'Santa Cruz Acapa', 18.4055600, -97.3261100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98089, 'San Miguel Monteverde', 'San Miguel Monteverde', 'San Miguel Monteverde', 17.5311100, -97.7925000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98090, 'Ampliación la Hincada', 'Ampliacion la Hincada', 'Ampliacion la Hincada,Ampliación la Hincada', 22.2152800, -99.2361100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98091, 'Pueblo Nuevo Tlalmimilolpan', 'Pueblo Nuevo Tlalmimilolpan', 'Pueblo Nuevo Tlalmimilolpan', 19.3922200, -99.5016700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98092, 'El Mirador', 'El Mirador', 'El Mirador', 20.0300000, -98.8105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98093, 'San Atenógenes (La Villita)', 'San Atenogenes (La Villita)', 'San Atenogenes (La Villita),San Atenógenes (La Villita)', 23.9905600, -104.0172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98094, 'Cerro las Iguanas', 'Cerro las Iguanas', 'Cerro las Iguanas', 18.4108300, -95.1997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98095, 'Texcaltepec', 'Texcaltepec', 'Texcaltepec', 20.0302800, -98.3241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98096, 'San Roque de Montes', 'San Roque de Montes', 'San Roque de Montes', 21.0100000, -101.8108300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98097, 'Jardines del Edén', 'Jardines del Eden', 'Jardines del Eden,Jardines del Edén', 20.5325000, -103.3627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98098, 'Caserío de Cortés', 'Caserio de Cortes', 'Caserio de Cortes,Caserío de Cortés', 19.1986100, -98.9544400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98099, 'Alpuyecancingo de las Montañas', 'Alpuyecancingo de las Montanas', 'Alpuyecancingo de las Montanas,Alpuyecancingo de las Montañas', 17.6708300, -98.8519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98100, 'Santa Cruz Papalutla', 'Santa Cruz Papalutla', 'Santa Cruz Papalutla', 16.9586100, -96.5850000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98101, 'San Cayetano', 'San Cayetano', 'San Cayetano', 16.9611900, -92.7601600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98102, 'Buena Vista', 'Buena Vista', 'Buena Vista', 25.8522200, -100.3600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98103, 'Emiliano Zapata (El Ranchito)', 'Emiliano Zapata (El Ranchito)', 'Emiliano Zapata (El Ranchito)', 19.2439400, -104.7186300, 'MX', '2016-02-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98104, 'Tezhuatepec', 'Tezhuatepec', 'Tezhuatepec', 19.8116700, -97.4625000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98105, 'Santiago Jaltepec', 'Santiago Jaltepec', 'Santiago Jaltepec', 20.1097200, -98.7111100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98106, 'Olintepec', 'Olintepec', 'Olintepec', 18.7405600, -98.9872200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98107, 'La Joya', 'La Joya', 'La Joya', 23.8375000, -103.9986100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98108, 'El Arco', 'El Arco', 'El Arco', 19.2252800, -100.1316700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98109, 'San Francisco de la Palma', 'San Francisco de la Palma', 'San Francisco de la Palma', 20.6602800, -100.5152800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98110, 'Colonia Lázaro Cárdenas', 'Colonia Lazaro Cardenas', 'Colonia Lazaro Cardenas,Colonia Lázaro Cárdenas', 19.5130600, -98.9200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98111, 'Fraccionamiento Real del Valle', 'Fraccionamiento Real del Valle', 'Fraccionamiento Real del Valle', 16.9327800, -96.7677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98112, 'San José del Puente', 'San Jose del Puente', 'San Jose del Puente,San José del Puente', 19.7205600, -99.1966700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98113, 'Bosques de San Pedro', 'Bosques de San Pedro', 'Bosques de San Pedro', 25.6013900, -100.1797200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98114, 'Pejelagartero 1ra. Sección (Plataforma)', 'Pejelagartero 1ra. Seccion (Plataforma)', 'Pejelagartero 1ra. Seccion (Plataforma),Pejelagartero 1ra. Sección (Plataforma)', 18.0550000, -93.8247200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98115, 'Ahuacatlán de Guadalupe', 'Ahuacatlan de Guadalupe', 'Ahuacatlan de Guadalupe,Ahuacatlán de Guadalupe', 21.2147200, -99.5405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98116, 'Monte Calvario', 'Monte Calvario', 'Monte Calvario', 19.1044400, -99.5952800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98117, 'San Pedro Atmatla', 'San Pedro Atmatla', 'San Pedro Atmatla', 19.9108300, -97.9675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98118, 'La Mohonera', 'La Mohonera', 'La Mohonera', 17.6383900, -99.2022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98119, 'Mecoacán 2da. Sección (San Lorenzo)', 'Mecoacan 2da. Seccion (San Lorenzo)', 'Mecoacan 2da. Seccion (San Lorenzo),Mecoacán 2da. Sección (San Lorenzo)', 18.2779000, -93.0909500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98120, 'Guásimas (De Belem)', 'Guasimas (De Belem)', 'Guasimas (De Belem),Guásimas (De Belem)', 27.8858300, -110.5816700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98121, 'Colonia Adolfo López Mateos', 'Colonia Adolfo Lopez Mateos', 'Colonia Adolfo Lopez Mateos,Colonia Adolfo López Mateos', 19.4005600, -99.4594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98122, 'Colonia el Refugio', 'Colonia el Refugio', 'Colonia el Refugio', 19.2269400, -99.6941700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98123, 'Nuevo Milenio Valdivia', 'Nuevo Milenio Valdivia', 'Nuevo Milenio Valdivia', 15.5030600, -92.9486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98124, 'Estación Corral', 'Estacion Corral', 'Estacion Corral,Estación Corral', 27.6288900, -109.9661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98125, 'San Pedro Ozumacín', 'San Pedro Ozumacin', 'San Pedro Ozumacin,San Pedro Ozumacín', 17.6786100, -96.2255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98126, 'Coamilpa de Juárez', 'Coamilpa de Juarez', 'Coamilpa de Juarez,Coamilpa de Juárez', 19.1977800, -99.4436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98127, 'Los Ángeles', 'Los Angeles', 'Los Angeles,Los Ángeles', 20.5536100, -100.9416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98128, 'Los Dolores (Las Quince Letras)', 'Los Dolores (Las Quince Letras)', 'Los Dolores (Las Quince Letras)', 21.3177800, -100.5658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98129, 'Colonia Militar', 'Colonia Militar', 'Colonia Militar', 20.1113900, -98.7030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98130, 'Coachiti', 'Coachiti', 'Coachiti', 20.5594400, -100.5894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98131, 'Vamos Tamaulipas', 'Vamos Tamaulipas', 'Vamos Tamaulipas', 25.9866700, -98.2216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98132, 'Loma Alta Taxhimay', 'Loma Alta Taxhimay', 'Loma Alta Taxhimay', 19.8422200, -99.4080600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98133, 'Cuaxuxpa', 'Cuaxuxpa', 'Cuaxuxpa', 18.4621100, -97.0355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98134, 'Atenxoxola', 'Atenxoxola', 'Atenxoxola', 17.4881900, -99.1428500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98135, 'San Pedro Arriba 3ra. Sección', 'San Pedro Arriba 3ra. Seccion', 'San Pedro Arriba 3ra. Seccion,San Pedro Arriba 3ra. Sección', 19.5008300, -99.5572200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98136, 'Colonia 28 de Mayo (Santa Rosa)', 'Colonia 28 de Mayo (Santa Rosa)', 'Colonia 28 de Mayo (Santa Rosa)', 20.1661100, -98.3900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98137, 'Fraccionamiento y Club de Golf los Encinos', 'Fraccionamiento y Club de Golf los Encinos', 'Fraccionamiento y Club de Golf los Encinos', 19.2891700, -99.4800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98138, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 16.4050000, -92.5525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98139, 'El Limón', 'El Limon', 'El Limon,El Limón', 16.9955600, -99.3775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98140, 'Mezapa la Fábrica', 'Mezapa la Fabrica', 'Mezapa la Fabrica,Mezapa la Fábrica', 19.1755600, -99.4452800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98141, 'San Jerónimo Yahuiche', 'San Jeronimo Yahuiche', 'San Jeronimo Yahuiche,San Jerónimo Yahuiche', 17.1086100, -96.7697200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98142, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 32.4227800, -116.9411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98143, 'Colonia Antorcha Campesina (Santa Rosa)', 'Colonia Antorcha Campesina (Santa Rosa)', 'Colonia Antorcha Campesina (Santa Rosa)', 19.6800000, -100.5261100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98144, 'Manzana Sexta Parte Centro', 'Manzana Sexta Parte Centro', 'Manzana Sexta Parte Centro', 19.5275000, -99.6052800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98145, 'El Pozo', 'El Pozo', 'El Pozo', 16.9203400, -92.4116600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98146, 'San Isidro Alta Huerta', 'San Isidro Alta Huerta', 'San Isidro Alta Huerta', 19.7247200, -100.6388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98147, 'Colonia San Francisco de Asís', 'Colonia San Francisco de Asis', 'Colonia San Francisco de Asis,Colonia San Francisco de Asís', 19.5786100, -99.7544400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98148, 'Fraccionamiento la Florida', 'Fraccionamiento la Florida', 'Fraccionamiento la Florida', 20.5866700, -97.4283300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98149, 'Cruztón', 'Cruzton', 'Cruzton,Cruztón', 16.7616700, -92.5791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98150, 'La Cruz', 'La Cruz', 'La Cruz', 20.4569400, -100.7958300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98151, 'Artemio Treviño', 'Artemio Trevino', 'Artemio Trevino,Artemio Treviño', 25.8352800, -100.1427800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98152, 'La Pimienta', 'La Pimienta', 'La Pimienta', 17.1411100, -92.7622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98153, 'Geovillas Laureles del Campanario', 'Geovillas Laureles del Campanario', 'Geovillas Laureles del Campanario', 21.3305600, -101.9236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98154, 'Guadalupe Totoltepec', 'Guadalupe Totoltepec', 'Guadalupe Totoltepec', 19.3483300, -99.5641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98155, 'Plan de Agua Prieta', 'Plan de Agua Prieta', 'Plan de Agua Prieta', 16.1311100, -92.7913900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98156, 'José María Morelos (La Yegüería)', 'Jose Maria Morelos (La Yegueeria)', 'Jose Maria Morelos (La Yegueeria),José María Morelos (La Yegüería)', 19.8638900, -100.8791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98157, 'Ejido Cajón Ojo de Agua Número Dos', 'Ejido Cajon Ojo de Agua Numero Dos', 'Ejido Cajon Ojo de Agua Numero Dos,Ejido Cajón Ojo de Agua Número Dos', 22.9000000, -105.9713900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98158, 'Huapacal 2da. Sección (Punta Brava)', 'Huapacal 2da. Seccion (Punta Brava)', 'Huapacal 2da. Seccion (Punta Brava),Huapacal 2da. Sección (Punta Brava)', 18.1972200, -93.1719400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98159, 'Los Parques', 'Los Parques', 'Los Parques', 25.7869400, -100.4763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98160, 'Sitalá', 'Sitala', 'Sitala,Sitalá', 17.0241700, -92.3069400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98161, 'Atlamajac', 'Atlamajac', 'Atlamajac', 17.5552800, -98.5472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98162, 'San Antonio Texas', 'San Antonio Texas', 'San Antonio Texas', 20.9855600, -101.4900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98163, 'Capitán Felipe Castellanos Díaz (San Pedro)', 'Capitan Felipe Castellanos Diaz (San Pedro)', 'Capitan Felipe Castellanos Diaz (San Pedro),Capitán Felipe Castellanos Díaz (San Pedro)', 17.7730600, -91.1475000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98164, 'Cuautotolapan (San José)', 'Cuautotolapan (San Jose)', 'Cuautotolapan (San Jose),Cuautotolapan (San José)', 18.4329900, -97.1209100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98165, 'La Fundición (Quinta Manzana)', 'La Fundicion (Quinta Manzana)', 'La Fundicion (Quinta Manzana),La Fundición (Quinta Manzana)', 19.4552800, -100.3036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98166, 'Parque de Poblamiento Solidaridad', 'Parque de Poblamiento Solidaridad', 'Parque de Poblamiento Solidaridad', 21.1519400, -98.3861100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98167, 'Tanamacoyan', 'Tanamacoyan', 'Tanamacoyan', 19.8905600, -97.4297200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98168, 'El Encanto', 'El Encanto', 'El Encanto', 14.7308300, -92.4102800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98169, 'San José del Jagüey', 'San Jose del Jagueey', 'San Jose del Jagueey,San José del Jagüey', 20.7372200, -99.9244400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98170, 'Colonia Adolfo Ruiz Cortines (Colonia Obrera)', 'Colonia Adolfo Ruiz Cortines (Colonia Obrera)', 'Colonia Adolfo Ruiz Cortines (Colonia Obrera)', 18.2569400, -96.1613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98171, 'Colonia Guadalupe Victoria', 'Colonia Guadalupe Victoria', 'Colonia Guadalupe Victoria', 19.4991700, -98.9191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98172, 'Barrio Bordo Nuevo', 'Barrio Bordo Nuevo', 'Barrio Bordo Nuevo', 19.3791700, -99.6733300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98173, 'Shoctic', 'Shoctic', 'Shoctic', 17.2236100, -92.4880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98174, 'San Pedro Tulixtlahuaca', 'San Pedro Tulixtlahuaca', 'San Pedro Tulixtlahuaca', 16.5397200, -98.0347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98175, 'Santana 2da. Sección B (La Palma)', 'Santana 2da. Seccion B (La Palma)', 'Santana 2da. Seccion B (La Palma),Santana 2da. Sección B (La Palma)', 18.1750500, -93.4318000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98176, 'El Refugio', 'El Refugio', 'El Refugio', 22.3702800, -101.7608300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98177, 'Zacapalco', 'Zacapalco', 'Zacapalco', 18.6391700, -98.9594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98178, 'Zapotitlán Tablas', 'Zapotitlan Tablas', 'Zapotitlan Tablas,Zapotitlán Tablas', 17.4241700, -98.7805600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98179, 'Sebastián Lerdo de Tejada', 'Sebastian Lerdo de Tejada', 'Sebastian Lerdo de Tejada,Sebastián Lerdo de Tejada', 23.9544400, -104.6363900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98180, 'La Cuchilla (Extramuros de Tesistán)', 'La Cuchilla (Extramuros de Tesistan)', 'La Cuchilla (Extramuros de Tesistan),La Cuchilla (Extramuros de Tesistán)', 20.7800000, -103.4622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98181, 'Colonia Agrícola Analco', 'Colonia Agricola Analco', 'Colonia Agricola Analco,Colonia Agrícola Analco', 19.3497200, -99.4750000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98182, 'Rancho Chico', 'Rancho Chico', 'Rancho Chico', 18.7466700, -97.6650000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98183, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 20.1533300, -97.7483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98184, 'Paso Blanco', 'Paso Blanco', 'Paso Blanco', 21.9736100, -102.3169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98185, 'Crescencio Morales (San Mateo)', 'Crescencio Morales (San Mateo)', 'Crescencio Morales (San Mateo)', 19.4911100, -100.2430600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98186, 'Campo la Arrocera', 'Campo la Arrocera', 'Campo la Arrocera', 25.8450000, -108.9183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98187, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 23.9911100, -106.9563900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98188, 'San Andrés Ocotepec', 'San Andres Ocotepec', 'San Andres Ocotepec,San Andrés Ocotepec', 18.9036100, -100.0466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98189, 'San José la Hacienda', 'San Jose la Hacienda', 'San Jose la Hacienda,San José la Hacienda', 16.9794400, -99.0666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98190, 'Los Reyes Tlanechicolpan', 'Los Reyes Tlanechicolpan', 'Los Reyes Tlanechicolpan', 19.0325000, -98.3525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98191, 'Rancho Bellavista [Fraccionamiento]', 'Rancho Bellavista [Fraccionamiento]', 'Rancho Bellavista [Fraccionamiento]', 20.6066700, -100.4497200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98192, 'El Cerrito', 'El Cerrito', 'El Cerrito', 19.3552800, -99.3483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98193, 'Apatauyan', 'Apatauyan', 'Apatauyan', 19.7991100, -97.4444000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98194, 'Solalpan 1ra. Sección', 'Solalpan 1ra. Seccion', 'Solalpan 1ra. Seccion,Solalpan 1ra. Sección', 19.4927800, -99.5744400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98195, 'San José Neria', 'San Jose Neria', 'San Jose Neria,San José Neria', 18.9933300, -96.9991700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98196, 'Paintla', 'Paintla', 'Paintla', 18.5033300, -99.6552800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98197, 'Colonia Ignacio Allende', 'Colonia Ignacio Allende', 'Colonia Ignacio Allende', 19.3566700, -97.7838900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98198, 'Santa Catarina Roatina', 'Santa Catarina Roatina', 'Santa Catarina Roatina', 16.2791700, -96.5177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98199, 'San Bernabé de las Canteras', 'San Bernabe de las Canteras', 'San Bernabe de las Canteras,San Bernabé de las Canteras', 19.7663900, -101.1633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98200, 'Villa de las Flores', 'Villa de las Flores', 'Villa de las Flores', 20.5763900, -97.4336100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98201, 'Villas del Campo', 'Villas del Campo', 'Villas del Campo', 19.1802800, -99.6122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98202, 'El Llano Santa María', 'El Llano Santa Maria', 'El Llano Santa Maria,El Llano Santa María', 19.7838900, -99.0863900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98203, 'Centro de Readaptación Social', 'Centro de Readaptacion Social', 'Centro de Readaptacion Social,Centro de Readaptación Social', 18.1366700, -94.5186100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98204, 'Tepetates', 'Tepetates', 'Tepetates', 21.9566700, -102.3216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98205, 'El Jazmín', 'El Jazmin', 'El Jazmin,El Jazmín', 20.3444400, -100.0466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98206, 'La Cabecera Concepción', 'La Cabecera Concepcion', 'La Cabecera Concepcion,La Cabecera Concepción', 19.7036100, -99.9411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98207, 'Loma de San Miguel', 'Loma de San Miguel', 'Loma de San Miguel', 19.3419400, -99.7916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98208, 'Zona Urbana Ejidal', 'Zona Urbana Ejidal', 'Zona Urbana Ejidal', 18.5325000, -96.5891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98209, 'Sebastián Lerdo de Tejada', 'Sebastian Lerdo de Tejada', 'Sebastian Lerdo de Tejada,Sebastián Lerdo de Tejada', 19.3897200, -99.7252800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98210, 'El Porvenir (El Porvenir de Arriba)', 'El Porvenir (El Porvenir de Arriba)', 'El Porvenir (El Porvenir de Arriba)', 25.7744400, -103.3252800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98211, 'San José Atoyatenco', 'San Jose Atoyatenco', 'San Jose Atoyatenco,San José Atoyatenco', 19.2508300, -98.3552800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98212, 'Chula Vista', 'Chula Vista', 'Chula Vista', 27.0408300, -103.3661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98213, 'Galaxias Toluca', 'Galaxias Toluca', 'Galaxias Toluca', 19.3980600, -99.6500000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98214, 'Monclova Primer Sector', 'Monclova Primer Sector', 'Monclova Primer Sector', 25.8147200, -100.4030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98215, 'San Antonio Coyahuacán', 'San Antonio Coyahuacan', 'San Antonio Coyahuacan,San Antonio Coyahuacán', 17.8619400, -98.6800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98216, 'Tikinmul', 'Tikinmul', 'Tikinmul', 19.7661100, -90.2230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98217, 'Jiménez del Teul', 'Jimenez del Teul', 'Jimenez del Teul,Jiménez del Teul', 23.2550000, -103.7977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98218, 'Aguas Calientes', 'Aguas Calientes', 'Aguas Calientes', 16.8425000, -99.6405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98219, 'Salvador Urbina', 'Salvador Urbina', 'Salvador Urbina', 16.6355600, -93.0027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98220, 'Pénjamo', 'Penjamo', 'Penjamo,Pénjamo', 18.4344400, -93.0930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98221, 'San Martín Ahuatepec', 'San Martin Ahuatepec', 'San Martin Ahuatepec,San Martín Ahuatepec', 19.6813900, -98.7280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98222, 'Héroes de Chapultepec (Rodeo de San Antonio)', 'Heroes de Chapultepec (Rodeo de San Antonio)', 'Heroes de Chapultepec (Rodeo de San Antonio),Héroes de Chapultepec (Rodeo de San Antonio)', 20.3111100, -101.5025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98223, 'Barrio San Miguel Dorami', 'Barrio San Miguel Dorami', 'Barrio San Miguel Dorami', 19.4462200, -99.3429600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98224, 'Santa Ana', 'Santa Ana', 'Santa Ana', 18.9875000, -99.4133300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98225, 'Santa Martha Hidalgo', 'Santa Martha Hidalgo', 'Santa Martha Hidalgo', 18.9850000, -98.3244400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98226, 'Cuonetzingo', 'Cuonetzingo', 'Cuonetzingo', 17.5272200, -99.2658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98227, 'Ladrilleras del Refugio', 'Ladrilleras del Refugio', 'Ladrilleras del Refugio', 21.0847200, -101.5536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98228, 'La Candelaria', 'La Candelaria', 'La Candelaria', 17.2183300, -95.9330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98229, 'Habanero 1ra. Sección (Venustiano Carranza)', 'Habanero 1ra. Seccion (Venustiano Carranza)', 'Habanero 1ra. Seccion (Venustiano Carranza),Habanero 1ra. Sección (Venustiano Carranza)', 17.9677800, -93.3280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98230, 'Nueva Tenochtitlán (Rizo de Oro)', 'Nueva Tenochtitlan (Rizo de Oro)', 'Nueva Tenochtitlan (Rizo de Oro),Nueva Tenochtitlán (Rizo de Oro)', 16.4763900, -94.0805600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98231, 'Buena Vista (Apasco)', 'Buena Vista (Apasco)', 'Buena Vista (Apasco)', 17.6555600, -92.4438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98232, 'Cañada del Tabaco', 'Canada del Tabaco', 'Canada del Tabaco,Cañada del Tabaco', 21.7097200, -105.3541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98233, 'San Martín Tlamapa', 'San Martin Tlamapa', 'San Martin Tlamapa,San Martín Tlamapa', 18.9775000, -98.3969400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98234, 'Fraccionamiento Santa Cruz', 'Fraccionamiento Santa Cruz', 'Fraccionamiento Santa Cruz', 17.9719400, -94.8950000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98235, 'San Antonio las Palmas', 'San Antonio las Palmas', 'San Antonio las Palmas', 17.6716700, -96.0908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98236, 'Gobernadores', 'Gobernadores', 'Gobernadores', 18.2469400, -93.1852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98237, 'San José de Cervera', 'San Jose de Cervera', 'San Jose de Cervera,San José de Cervera', 20.9677800, -101.3025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98238, 'Cristóbal Colón', 'Cristobal Colon', 'Cristobal Colon,Cristóbal Colón', 17.1919400, -91.6291700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98239, 'Vista Hermosa', 'Vista Hermosa', 'Vista Hermosa', 17.7963900, -97.7569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98240, 'Los Cues', 'Los Cues', 'Los Cues', 20.5019400, -100.2641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98241, 'Estación Obispo', 'Estacion Obispo', 'Estacion Obispo,Estación Obispo', 24.2930600, -107.1594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98242, 'Hueyitlalpan', 'Hueyitlalpan', 'Hueyitlalpan', 17.6752800, -99.2955600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98243, 'Colonia Azteca', 'Colonia Azteca', 'Colonia Azteca', 19.0780600, -99.6541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98244, 'Colonia Aeropuerto', 'Colonia Aeropuerto', 'Colonia Aeropuerto', 17.6202800, -101.4588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98245, 'El Venado', 'El Venado', 'El Venado', 20.0647200, -98.7586100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98246, 'San Lorenzo Joya de Rodríguez', 'San Lorenzo Joya de Rodriguez', 'San Lorenzo Joya de Rodriguez,San Lorenzo Joya de Rodríguez', 19.0544400, -97.8533300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98247, 'Joaquín Miguel Gutiérrez (Margaritas)', 'Joaquin Miguel Gutierrez (Margaritas)', 'Joaquin Miguel Gutierrez (Margaritas),Joaquín Miguel Gutiérrez (Margaritas)', 15.5502800, -93.0930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98248, 'Guadalupe Coté', 'Guadalupe Cote', 'Guadalupe Cote,Guadalupe Coté', 19.6107500, -99.9849900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98249, 'Valle Verde', 'Valle Verde', 'Valle Verde', 19.4725000, -100.3552800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98250, 'Nueva División del Bayo (Guatemala)', 'Nueva Division del Bayo (Guatemala)', 'Nueva Division del Bayo (Guatemala),Nueva División del Bayo (Guatemala)', 17.8400000, -92.4888900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98251, 'Gómez Poniente', 'Gomez Poniente', 'Gomez Poniente,Gómez Poniente', 19.7725000, -97.4869400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98252, 'La Trinidad Tianguismanalco', 'La Trinidad Tianguismanalco', 'La Trinidad Tianguismanalco', 18.8941700, -98.0325000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98253, 'Temalacaco', 'Temalacaco', 'Temalacaco', 21.4138900, -98.8469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98254, 'Chiquinshulum', 'Chiquinshulum', 'Chiquinshulum', 17.0719400, -92.5980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98255, 'La Y', 'La Y', 'La Y', 19.3980600, -99.5897200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98256, 'Narciso Mendoza', 'Narciso Mendoza', 'Narciso Mendoza', 18.8741700, -98.9697200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98257, 'Cucharas', 'Cucharas', 'Cucharas', 21.6161100, -97.6613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98258, 'Santa Lucía Potrerillo', 'Santa Lucia Potrerillo', 'Santa Lucia Potrerillo,Santa Lucía Potrerillo', 18.9691700, -97.0241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98259, 'San Isidro', 'San Isidro', 'San Isidro', 25.9772200, -109.2511100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98260, 'Chicumtantic', 'Chicumtantic', 'Chicumtantic', 16.8655600, -92.6052800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98261, 'Matzam', 'Matzam', 'Matzam', 16.7891700, -92.4769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98262, 'Primero de Mayo', 'Primero de Mayo', 'Primero de Mayo', 19.0816700, -98.0977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98263, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 19.9891700, -101.6458300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98264, 'Paseos de las Haciendas [Fraccionamiento]', 'Paseos de las Haciendas [Fraccionamiento]', 'Paseos de las Haciendas [Fraccionamiento]', 21.9922200, -102.3436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98265, 'Las Margaritas', 'Las Margaritas', 'Las Margaritas,Rancho Santa Margarita', 27.6183300, -113.4536100, 'MX', '2015-01-18', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98266, 'El Tzay', 'El Tzay', 'El Tzay', 16.8636100, -92.3122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98267, 'Melitón Albáñez Domínguez', 'Meliton Albanez Dominguez', 'Meliton Albanez Dominguez,Melitón Albáñez Domínguez', 23.6613900, -110.4208300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98268, 'El Muey', 'El Muey', 'El Muey', 20.5027800, -103.2208300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98269, 'La Candelaria Teotlalpan', 'La Candelaria Teotlalpan', 'La Candelaria Teotlalpan', 19.3330600, -98.2255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98270, 'San Isidro Monjas', 'San Isidro Monjas', 'San Isidro Monjas', 17.0016700, -96.7486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98271, 'Hacienda Sotavento', 'Hacienda Sotavento', 'Hacienda Sotavento', 19.1336100, -96.1813900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98272, 'El CERESO', 'El CERESO', 'El CERESO', 21.0222200, -101.6891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98273, 'Texmola', 'Texmola', 'Texmola', 18.9397200, -97.2438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98274, 'Las Flechas', 'Las Flechas', 'Las Flechas', 16.7002800, -93.0263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98275, 'Llano de la Lima', 'Llano de la Lima', 'Llano de la Lima', 14.8659600, -92.2971400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98276, 'Colonia Veintitrés de Mayo', 'Colonia Veintitres de Mayo', 'Colonia Veintitres de Mayo,Colonia Veintitrés de Mayo', 21.0100000, -102.1977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98277, 'La Lima', 'La Lima', 'La Lima', 21.9272200, -99.1027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98278, 'Casa Nueva', 'Casa Nueva', 'Casa Nueva', 19.8333300, -99.2094400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98279, 'Ocotlán de Venustiano Carranza', 'Ocotlan de Venustiano Carranza', 'Ocotlan de Venustiano Carranza,Ocotlán de Venustiano Carranza', 18.7911100, -97.6691700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98280, 'Mezquitic de la Magdalena', 'Mezquitic de la Magdalena', 'Mezquitic de la Magdalena', 21.2211100, -102.3044400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98281, 'Praxedis de Guerrero', 'Praxedis de Guerrero', 'Praxedis de Guerrero', 16.7200000, -96.6400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98282, 'Arroyo Choápam', 'Arroyo Choapam', 'Arroyo Choapam,Arroyo Choápam', 17.9702800, -96.1572200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98283, 'Martínez Domínguez', 'Martinez Dominguez', 'Martinez Dominguez,Martínez Domínguez', 22.7480600, -102.4811100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98284, 'San Francisco Atotonilco', 'San Francisco Atotonilco', 'San Francisco Atotonilco', 20.1947200, -98.1516700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98285, 'Santa Clara', 'Santa Clara', 'Santa Clara', 19.6988900, -98.5777800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98286, 'Laguna de Tabernillas (El Resbaloso)', 'Laguna de Tabernillas (El Resbaloso)', 'Laguna de Tabernillas (El Resbaloso)', 19.4613900, -99.8783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98287, 'San Martín', 'San Martin', 'San Martin,San Martín', 19.7825000, -97.3402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98288, 'Istaro', 'Istaro', 'Istaro', 19.3280600, -101.7536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98289, 'Xocoyolzintla', 'Xocoyolzintla', 'Xocoyolzintla', 17.7127800, -98.9819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98290, 'Camelia Roja', 'Camelia Roja', 'Camelia Roja', 18.0283300, -96.2080600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98291, 'El Palmar', 'El Palmar', 'El Palmar', 19.1397200, -97.0530600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98292, 'Los Cristales (Talican)', 'Los Cristales (Talican)', 'Los Cristales (Talican)', 19.8723700, -97.5942400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98293, 'Emilio Carranza (Santa Cruz)', 'Emilio Carranza (Santa Cruz)', 'Emilio Carranza (Santa Cruz)', 19.7127800, -97.6527800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98294, 'Benito Juárez II (San Martín)', 'Benito Juarez II (San Martin)', 'Benito Juarez II (San Martin),Benito Juárez II (San Martín)', 18.1405600, -96.4613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98295, 'Colonia el Pedregal', 'Colonia el Pedregal', 'Colonia el Pedregal', 18.3496100, -99.8564200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98296, 'Primera de Analco', 'Primera de Analco', 'Primera de Analco', 18.9025000, -99.7755600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98297, 'San Lucas', 'San Lucas', 'San Lucas', 18.9780600, -99.6605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98298, 'Ixticpan', 'Ixticpan', 'Ixticpan', 19.8141900, -97.3445400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98299, 'Arenal Santa Ana', 'Arenal Santa Ana', 'Arenal Santa Ana', 17.7897200, -95.7702800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98300, 'Jolotichán', 'Jolotichan', 'Jolotichan,Jolotichán', 16.7522200, -98.7305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98301, 'Colonia Doctor Gustavo Baz', 'Colonia Doctor Gustavo Baz', 'Colonia Doctor Gustavo Baz', 19.4105600, -99.9216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98302, 'Zaragoza', 'Zaragoza', 'Zaragoza', 19.3186100, -98.2638900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98303, 'Barrio de la Barranca', 'Barrio de la Barranca', 'Barrio de la Barranca', 19.4358300, -99.5583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98304, 'Tierras Coloradas', 'Tierras Coloradas', 'Tierras Coloradas', 20.7288900, -102.8608300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98305, 'Fracción Milpillas', 'Fraccion Milpillas', 'Fraccion Milpillas,Fracción Milpillas', 22.2277800, -100.9641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98306, 'Colonia Pedro María Anaya', 'Colonia Pedro Maria Anaya', 'Colonia Pedro Maria Anaya,Colonia Pedro María Anaya', 20.5261100, -100.8777800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98307, 'Soyatlán de Afuera', 'Soyatlan de Afuera', 'Soyatlan de Afuera,Soyatlán de Afuera', 19.6908300, -103.2827800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98308, 'La Rosa', 'La Rosa', 'La Rosa', 19.4851900, -99.3298400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98309, 'Arroyo de Enmedio', 'Arroyo de Enmedio', 'Arroyo de Enmedio', 18.4975000, -96.5472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98310, 'Ninguno [CERESO]', 'Ninguno [CERESO]', 'Ninguno [CERESO]', 20.6736100, -100.3602800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98311, 'Querendas', 'Querendas', 'Querendas', 18.3425000, -100.6344400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98312, 'Santa Cruz Xaltetela', 'Santa Cruz Xaltetela', 'Santa Cruz Xaltetela', 19.8741700, -97.5808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98313, 'El Chinaco (El Pujido)', 'El Chinaco (El Pujido)', 'El Chinaco (El Pujido)', 20.5222200, -100.9197200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98314, 'Ex-Hacienda de Guadalupe', 'Ex-Hacienda de Guadalupe', 'Ex-Hacienda de Guadalupe', 19.8088900, -98.9725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98315, 'Unidad Habitacional 10 de Abril', 'Unidad Habitacional 10 de Abril', 'Unidad Habitacional 10 de Abril', 18.7544400, -98.9161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98316, 'Colonia los Aguiluchos', 'Colonia los Aguiluchos', 'Colonia los Aguiluchos', 19.7261100, -99.0902800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98317, 'Miguel Valdez Quintero (El Corazón)', 'Miguel Valdez Quintero (El Corazon)', 'Miguel Valdez Quintero (El Corazon),Miguel Valdez Quintero (El Corazón)', 24.4941700, -107.3177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98318, 'Toxtla', 'Toxtla', 'Toxtla', 20.0663200, -97.9474800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98319, 'San José Ozumba', 'San Jose Ozumba', 'San Jose Ozumba,San José Ozumba', 19.2330600, -97.7283300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98320, 'San Miguel Papaxtla', 'San Miguel Papaxtla', 'San Miguel Papaxtla', 19.0627800, -98.3900000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98321, 'Monte Alegre', 'Monte Alegre', 'Monte Alegre', 19.9825000, -99.3413900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98322, 'Salvador Rosas Magallón', 'Salvador Rosas Magallon', 'Salvador Rosas Magallon,Salvador Rosas Magallón', 31.9013900, -116.5477800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98323, 'Barrio de San Juan', 'Barrio de San Juan', 'Barrio de San Juan', 19.4142000, -99.5371700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98324, 'La Loma de los Negritos', 'La Loma de los Negritos', 'La Loma de los Negritos', 21.8705600, -102.3500000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98325, 'Villa Hermosa (Las Pozas)', 'Villa Hermosa (Las Pozas)', 'Villa Hermosa (Las Pozas)', 17.6336100, -101.4663900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98326, 'Cerro de San Francisco', 'Cerro de San Francisco', 'Cerro de San Francisco', 19.3703800, -99.3516200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98327, 'Fraccionamiento la Virgen', 'Fraccionamiento la Virgen', 'Fraccionamiento la Virgen', 19.3230600, -98.2738900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98328, 'Tlaltempanapa', 'Tlaltempanapa', 'Tlaltempanapa', 17.7361100, -99.1772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98329, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 19.5597200, -97.6600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98330, 'Eureka y Belén', 'Eureka y Belen', 'Eureka y Belen,Eureka y Belén', 17.5596800, -92.9289900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98331, 'Paseo de San Javier', 'Paseo de San Javier', 'Paseo de San Javier', 25.7397200, -100.1344400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98332, 'La Península', 'La Peninsula', 'La Peninsula,La Península', 17.9434700, -93.3614800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98333, 'El Porvenir I', 'El Porvenir I', 'El Porvenir I', 19.3169400, -99.7288900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98334, 'Ejido Pátzcuaro', 'Ejido Patzcuaro', 'Ejido Patzcuaro,Ejido Pátzcuaro', 32.3513900, -115.0658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98335, 'Fraccionamiento las Liebres', 'Fraccionamiento las Liebres', 'Fraccionamiento las Liebres', 20.6475000, -101.3955600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98336, 'Chixtontic', 'Chixtontic', 'Chixtontic', 16.8908000, -92.4579300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98337, 'La Cañada', 'La Canada', 'La Canada,La Cañada', 19.4863900, -99.5988900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98338, 'Santiago Tepeticpac', 'Santiago Tepeticpac', 'Santiago Tepeticpac', 19.3347600, -98.2269200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98339, 'Gaviotas Sur (El Cedral)', 'Gaviotas Sur (El Cedral)', 'Gaviotas Sur (El Cedral)', 17.9537300, -92.8907100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98340, 'Lázaro Cárdenas (El Empalme)', 'Lazaro Cardenas (El Empalme)', 'Lazaro Cardenas (El Empalme),Lázaro Cárdenas (El Empalme)', 18.9322200, -99.0252800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98341, 'Barrio de Canales', 'Barrio de Canales', 'Barrio de Canales', 19.3733300, -99.3755600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98342, 'Cozotlán Norte', 'Cozotlan Norte', 'Cozotlan Norte,Cozotlán Norte', 19.7083300, -98.8600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98343, 'Encrucijada 3ra. Sección (Las Calzadas)', 'Encrucijada 3ra. Seccion (Las Calzadas)', 'Encrucijada 3ra. Seccion (Las Calzadas),Encrucijada 3ra. Sección (Las Calzadas)', 18.2549100, -93.5561900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98344, 'Chichicastle 1ra. Sección', 'Chichicastle 1ra. Seccion', 'Chichicastle 1ra. Seccion,Chichicastle 1ra. Sección', 18.3041700, -92.4313900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98345, 'Corriente 1ra. Sección', 'Corriente 1ra. Seccion', 'Corriente 1ra. Seccion,Corriente 1ra. Sección', 18.1576700, -92.9937200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98346, 'Tzintzimeo', 'Tzintzimeo', 'Tzintzimeo', 19.8702800, -100.9777800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98347, 'Francisco Sarabia', 'Francisco Sarabia', 'Francisco Sarabia', 16.2475000, -91.9627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98348, 'Francisco Rueda', 'Francisco Rueda', 'Francisco Rueda', 17.8291700, -93.9338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98349, 'Agua Zarca', 'Agua Zarca', 'Agua Zarca', 15.6341700, -92.1447200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98350, 'Tapias de Santa Cruz (Pedro Ruiz González)', 'Tapias de Santa Cruz (Pedro Ruiz Gonzalez)', 'Tapias de Santa Cruz (Pedro Ruiz Gonzalez),Tapias de Santa Cruz (Pedro Ruiz González)', 23.1888900, -103.1311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98351, 'Rincón de Cedeños (Rincón de Dolores)', 'Rincon de Cedenos (Rincon de Dolores)', 'Rincon de Cedenos (Rincon de Dolores),Rincón de Cedeños (Rincón de Dolores)', 19.6780600, -100.5763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98352, 'Piletas', 'Piletas', 'Piletas', 19.5880600, -96.9786100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98353, 'El Sauz de Abajo', 'El Sauz de Abajo', 'El Sauz de Abajo', 20.0750000, -102.2683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98354, 'Villa de los Niños', 'Villa de los Ninos', 'Villa de los Ninos,Villa de los Niños', 20.4066700, -103.5416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98355, 'Santo Tomás', 'Santo Tomas', 'Santo Tomas,Santo Tomás', 18.0419400, -96.5138900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98356, 'San Antonio', 'San Antonio', 'San Antonio', 19.7561100, -97.3569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98357, 'Norte 1ra. Sección (San Julián)', 'Norte 1ra. Seccion (San Julian)', 'Norte 1ra. Seccion (San Julian),Norte 1ra. Sección (San Julián)', 18.3013900, -93.2094400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98358, 'Santa Teresita de Don Diego', 'Santa Teresita de Don Diego', 'Santa Teresita de Don Diego', 20.8800000, -100.7786100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98359, 'Mexcala', 'Mexcala', 'Mexcala', 18.6955600, -97.1647200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98360, 'Tlacoapa', 'Tlacoapa', 'Tlacoapa', 17.2636100, -98.7486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98361, 'Vicente Guerrero', 'Vicente Guerrero', 'Vicente Guerrero', 20.1232200, -97.6541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98362, 'Colonia 24 de Febrero', 'Colonia 24 de Febrero', 'Colonia 24 de Febrero', 25.6472200, -108.6491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98363, 'Apas', 'Apas', 'Apas', 16.7106600, -92.7933500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98364, 'Zoquitlán', 'Zoquitlan', 'Zoquitlan,Zoquitlán', 17.3419400, -98.9491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98365, 'Ejido del Tejocote', 'Ejido del Tejocote', 'Ejido del Tejocote', 19.4847400, -99.2784700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98366, 'Lipuntahuaca', 'Lipuntahuaca', 'Lipuntahuaca', 20.0911900, -97.6302600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98367, 'San Martín Obispo (San Martín San Pedro)', 'San Martin Obispo (San Martin San Pedro)', 'San Martin Obispo (San Martin San Pedro),San Martín Obispo (San Martín San Pedro)', 19.3194400, -100.0747200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98368, 'Taza de Agua Ojo Zarco', 'Taza de Agua Ojo Zarco', 'Taza de Agua Ojo Zarco', 18.7833300, -97.2022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98369, 'Los Nicolases', 'Los Nicolases', 'Los Nicolases', 20.8580600, -101.3175000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98370, 'La Estancia', 'La Estancia', 'La Estancia', 20.2988900, -98.6894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98371, 'Muquén', 'Muquen', 'Muquen,Muquén', 16.8064100, -92.6100600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98372, 'Tepechicotlán', 'Tepechicotlan', 'Tepechicotlan,Tepechicotlán', 17.4831700, -99.4154900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98373, 'El Tepetatal', 'El Tepetatal', 'El Tepetatal', 19.3458100, -99.7708600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98374, 'Valle de los Girasoles [Fraccionamiento]', 'Valle de los Girasoles [Fraccionamiento]', 'Valle de los Girasoles [Fraccionamiento]', 20.4266700, -103.1988900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98375, 'Colonia Isidro Fabela', 'Colonia Isidro Fabela', 'Colonia Isidro Fabela', 19.3005600, -99.5227800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98376, 'El Palmar (San Gabriel)', 'El Palmar (San Gabriel)', 'El Palmar (San Gabriel)', 16.8455600, -93.0163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98377, 'Primer Cantón', 'Primer Canton', 'Primer Canton,Primer Cantón', 15.1205600, -92.4400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98378, 'Puxtla', 'Puxtla', 'Puxtla', 18.8100000, -98.9825000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98379, 'San Juan Pancoac', 'San Juan Pancoac', 'San Juan Pancoac', 19.1491700, -98.4419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98380, 'Purísima de Cubos (La Purísima)', 'Purisima de Cubos (La Purisima)', 'Purisima de Cubos (La Purisima),Purísima de Cubos (La Purísima)', 20.6002800, -100.1183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98381, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez', 15.0550000, -92.1911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98382, 'El Sibal', 'El Sibal', 'El Sibal', 16.9800000, -91.4911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98383, 'La Concepción', 'La Concepcion', 'La Concepcion,La Concepción', 19.6961100, -99.3002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98384, 'Santa María Urapicho', 'Santa Maria Urapicho', 'Santa Maria Urapicho,Santa María Urapicho', 19.6813900, -102.1119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98385, 'Colonia Chalchihuecan', 'Colonia Chalchihuecan', 'Colonia Chalchihuecan', 19.2141700, -96.2144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98386, 'Ángel Albino Corzo (Guadalupe)', 'Angel Albino Corzo (Guadalupe)', 'Angel Albino Corzo (Guadalupe),Ángel Albino Corzo (Guadalupe)', 17.1263900, -93.2750000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98387, 'Entronque de Matehuala (El Huizache)', 'Entronque de Matehuala (El Huizache)', 'Entronque de Matehuala (El Huizache)', 22.9250000, -100.4588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98388, 'Estación Mogoñé', 'Estacion Mogone', 'Estacion Mogone,Estación Mogoñé', 16.9947200, -95.0366700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98389, 'El Molino', 'El Molino', 'El Molino', 19.8133300, -97.5802800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98390, 'San José Cuaro', 'San Jose Cuaro', 'San Jose Cuaro,San José Cuaro', 19.9883300, -101.2519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98391, 'Chacoma', 'Chacoma', 'Chacoma', 16.8761100, -92.4913900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98392, 'El Potrerillo (Potrerillo del Rincón)', 'El Potrerillo (Potrerillo del Rincon)', 'El Potrerillo (Potrerillo del Rincon),El Potrerillo (Potrerillo del Rincón)', 16.9580600, -98.7308300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98393, 'Gildardo Magaña (Los Ángeles)', 'Gildardo Magana (Los Angeles)', 'Gildardo Magana (Los Angeles),Gildardo Magaña (Los Ángeles)', 19.5488900, -102.4586100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98394, 'Santiago', 'Santiago', 'Santiago', 19.8119400, -97.3236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98395, 'Fermín Rabadán Cervantes', 'Fermin Rabadan Cervantes', 'Fermin Rabadan Cervantes,Fermín Rabadán Cervantes', 18.3152800, -99.5672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98396, 'Colonia Palma', 'Colonia Palma', 'Colonia Palma', 19.5644400, -99.4241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98397, 'Goros Número Dos', 'Goros Numero Dos', 'Goros Numero Dos,Goros Número Dos', 25.8769400, -109.0441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98398, 'Orizaba', 'Orizaba', 'Orizaba', 23.9575000, -104.0738900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98399, 'Barrio los Tules', 'Barrio los Tules', 'Barrio los Tules', 19.4291700, -100.0747200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98400, 'Majomut', 'Majomut', 'Majomut', 16.8491700, -92.6594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98401, 'Usipa', 'Usipa', 'Usipa', 17.5002800, -92.4380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98402, 'Gabriel Leyva Solano (Zapotillo Dos)', 'Gabriel Leyva Solano (Zapotillo Dos)', 'Gabriel Leyva Solano (Zapotillo Dos)', 25.8830600, -109.0091700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98403, 'Tetecolala', 'Tetecolala', 'Tetecolala', 18.9225000, -99.1627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98404, 'Vista Hermosa (Cuasinada)', 'Vista Hermosa (Cuasinada)', 'Vista Hermosa (Cuasinada)', 20.3686100, -100.0125000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98405, 'Ciudad Satélite', 'Ciudad Satelite', 'Ciudad Satelite,Ciudad Satélite', 22.1108300, -100.7958300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98406, 'San Isidro', 'San Isidro', 'San Isidro', 20.7911100, -103.3511100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98407, 'Monte Largo 1ra. Sección', 'Monte Largo 1ra. Seccion', 'Monte Largo 1ra. Seccion,Monte Largo 1ra. Sección', 17.8356700, -92.6066400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98408, 'San Francisco Tláloc', 'San Francisco Tlaloc', 'San Francisco Tlaloc,San Francisco Tláloc', 19.3697200, -98.4772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98409, 'Colonia Aviación Autopan', 'Colonia Aviacion Autopan', 'Colonia Aviacion Autopan,Colonia Aviación Autopan', 19.3791700, -99.6927800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98410, 'Paisanos', 'Paisanos', 'Paisanos', 22.2036100, -101.0358300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98411, 'San José Villarreal', 'San Jose Villarreal', 'San Jose Villarreal,San José Villarreal', 19.5327800, -97.8975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98412, 'Poblado Chulavista (El Chorizo)', 'Poblado Chulavista (El Chorizo)', 'Poblado Chulavista (El Chorizo)', 30.7472200, -116.0030600, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98413, 'Las Trojas', 'Las Trojas', 'Las Trojas', 20.7111100, -100.7808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98414, 'Paraje la Pera', 'Paraje la Pera', 'Paraje la Pera', 19.3805600, -99.3450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98415, 'Conjunto Habitacional el Trébol', 'Conjunto Habitacional el Trebol', 'Conjunto Habitacional el Trebol,Conjunto Habitacional el Trébol', 19.7669400, -101.1547200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98416, '31 de Octubre', '31 de Octubre', '31 de Octubre', 27.2958300, -110.0375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98417, 'Estación de Apulco', 'Estacion de Apulco', 'Estacion de Apulco,Estación de Apulco', 20.2861100, -98.3475000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98418, 'San Jerónimo Coaltepec', 'San Jeronimo Coaltepec', 'San Jeronimo Coaltepec,San Jerónimo Coaltepec', 20.0038900, -97.8663900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98419, 'La Laguna', 'La Laguna', 'La Laguna', 18.7994400, -97.7366700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98420, 'Rio de la Soledad', 'Rio de la Soledad', 'Rio de la Soledad', 20.1150000, -98.7119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98421, 'Tacubaya', 'Tacubaya', 'Tacubaya', 25.6836100, -103.0686100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98422, 'Benito Juárez (La Playita)', 'Benito Juarez (La Playita)', 'Benito Juarez (La Playita),Benito Juárez (La Playita)', 17.9323100, -93.3647200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98423, 'Lázaro Cárdenas (Santana)', 'Lazaro Cardenas (Santana)', 'Lazaro Cardenas (Santana),Lázaro Cárdenas (Santana)', 20.2250000, -97.5930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98424, 'Nuevo Pumpuapa (Cereso)', 'Nuevo Pumpuapa (Cereso)', 'Nuevo Pumpuapa (Cereso)', 14.9256200, -92.3653300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98425, 'Ex-Hacienda del Copal', 'Ex-Hacienda del Copal', 'Ex-Hacienda del Copal', 20.7408300, -101.3352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98426, 'Déxtho de Victoria', 'Dextho de Victoria', 'Dextho de Victoria,Déxtho de Victoria', 20.3252800, -99.0238900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98427, 'Javier Rojo Gómez', 'Javier Rojo Gomez', 'Javier Rojo Gomez,Javier Rojo Gómez', 25.4947200, -108.3775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98428, 'Juan del Grijalva', 'Juan del Grijalva', 'Juan del Grijalva', 16.7280600, -92.9775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98429, 'Colonia Obrera', 'Colonia Obrera', 'Colonia Obrera', 15.0980600, -92.4980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98430, 'San Pablo Huacano', 'San Pablo Huacano', 'San Pablo Huacano', 17.1958300, -93.2075000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98431, 'Jilotzingo', 'Jilotzingo', 'Jilotzingo', 20.0325000, -97.9025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98432, 'Cantioc', 'Cantioc', 'Cantioc', 17.2622200, -92.4069400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98433, 'Nuevo Michoacán (Estación Riíto)', 'Nuevo Michoacan (Estacion Riito)', 'Nuevo Michoacan (Estacion Riito),Nuevo Michoacán (Estación Riíto)', 32.1661100, -114.9616700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98434, 'Abrevadero', 'Abrevadero', 'Abrevadero', 18.2822200, -95.2144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98435, 'Tronconal', 'Tronconal', 'Tronconal', 18.8050000, -98.4836100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98436, 'La Magdalena de los Reyes (La Magdalena)', 'La Magdalena de los Reyes (La Magdalena)', 'La Magdalena de los Reyes (La Magdalena)', 19.1897200, -99.4100000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98437, 'Temastián (La Cantera)', 'Temastian (La Cantera)', 'Temastian (La Cantera),Temastián (La Cantera)', 21.9772200, -103.5250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98438, 'Polvillos (San Bartolo Quinta Sección)', 'Polvillos (San Bartolo Quinta Seccion)', 'Polvillos (San Bartolo Quinta Seccion),Polvillos (San Bartolo Quinta Sección)', 19.2361100, -100.0800000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98439, 'Cuaxoxpan', 'Cuaxoxpan', 'Cuaxoxpan', 19.8080600, -97.3458300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98440, 'Fraccionamiento Praderas de la Venta', 'Fraccionamiento Praderas de la Venta', 'Fraccionamiento Praderas de la Venta', 20.5361100, -101.0000000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98441, 'Sibaniljá Pocolum', 'Sibanilja Pocolum', 'Sibanilja Pocolum,Sibaniljá Pocolum', 16.8763900, -92.4611100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98442, 'Los Condes', 'Los Condes', 'Los Condes', 23.8388900, -103.0786100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98443, 'La Playa', 'La Playa', 'La Playa', 23.0641700, -109.6683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98444, 'San Pablo de los Gallos', 'San Pablo de los Gallos', 'San Pablo de los Gallos', 19.6772200, -99.2461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98445, 'El Polvorín', 'El Polvorin', 'El Polvorin,El Polvorín', 16.5783300, -98.8013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98446, 'Buena Vista (Puxcatán)', 'Buena Vista (Puxcatan)', 'Buena Vista (Puxcatan),Buena Vista (Puxcatán)', 17.7307300, -92.6199600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98447, 'San Antonio Xoquitla', 'San Antonio Xoquitla', 'San Antonio Xoquitla', 19.3405600, -97.1650000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98448, 'El Águila (La Mesa)', 'El Aguila (La Mesa)', 'El Aguila (La Mesa),El Águila (La Mesa)', 19.1669400, -99.4063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98449, 'Adolfo Moreno', 'Adolfo Moreno', 'Adolfo Moreno', 19.7247200, -97.2380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98450, 'Mérida', 'Merida', 'Merida,Mérida', 16.5675000, -93.8172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98451, 'Nuevo Guerrero', 'Nuevo Guerrero', 'Nuevo Guerrero', 18.2258300, -100.5258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98452, 'Colonia las Arboledas', 'Colonia las Arboledas', 'Colonia las Arboledas', 18.7852800, -98.9397200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98453, 'Morelos', 'Morelos', 'Morelos', 19.7547200, -97.5775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98454, 'Cuauhtamingo', 'Cuauhtamingo', 'Cuauhtamingo', 19.7647200, -97.3141700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98455, 'Santa Anita', 'Santa Anita', 'Santa Anita', 17.4258300, -98.7188900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98456, 'Orba (Infiernito)', 'Orba (Infiernito)', 'Orba (Infiernito)', 25.6894400, -108.3627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98457, 'Paso de la Mina 2da. Sección (Barrial)', 'Paso de la Mina 2da. Seccion (Barrial)', 'Paso de la Mina 2da. Seccion (Barrial),Paso de la Mina 2da. Sección (Barrial)', 17.9527800, -93.6908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98458, 'Ignacio Manuel Altamirano', 'Ignacio Manuel Altamirano', 'Ignacio Manuel Altamirano', 19.3672200, -98.5830600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98459, 'Rancho Nuevo de Morelos (De Guadalupe)', 'Rancho Nuevo de Morelos (De Guadalupe)', 'Rancho Nuevo de Morelos (De Guadalupe)', 22.3405600, -101.7852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98460, 'San Isidro Monterrosas', 'San Isidro Monterrosas', 'San Isidro Monterrosas', 18.8566700, -97.5752800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98461, 'Villa Rotaria', 'Villa Rotaria', 'Villa Rotaria', 17.1944400, -100.6691700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98462, 'Buenavista', 'Buenavista', 'Buenavista', 16.2427800, -91.9877800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98463, 'La Amistad', 'La Amistad', 'La Amistad', 20.0083300, -99.3202800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98464, 'Atotonilco', 'Atotonilco', 'Atotonilco', 19.9411100, -100.2230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98465, 'Veintiuno de Agosto', 'Veintiuno de Agosto', 'Veintiuno de Agosto', 19.7250000, -97.2722200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98466, 'Oriente 6ta. Sección (Los Mulatos)', 'Oriente 6ta. Seccion (Los Mulatos)', 'Oriente 6ta. Seccion (Los Mulatos),Oriente 6ta. Sección (Los Mulatos)', 18.1672200, -93.2358300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98467, 'Ignacio Allende', 'Ignacio Allende', 'Ignacio Allende', 16.5255600, -92.9922200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98468, 'Las Masas (La Luz Masas)', 'Las Masas (La Luz Masas)', 'Las Masas (La Luz Masas)', 20.5991700, -101.5427800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98469, 'La Joya', 'La Joya', 'La Joya', 18.9725000, -99.6527800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98470, 'Rancho Nuevo', 'Rancho Nuevo', 'Rancho Nuevo', 18.5813900, -97.2247200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98471, 'Belisario Domínguez', 'Belisario Dominguez', 'Belisario Dominguez,Belisario Domínguez', 17.4061100, -91.9836100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98472, 'Lomas de Tepemecatl', 'Lomas de Tepemecatl', 'Lomas de Tepemecatl', 19.2386100, -99.2394400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98473, 'El Mirador', 'El Mirador', 'El Mirador', 18.7713900, -99.3413900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98474, 'Residencial las Olas', 'Residencial las Olas', 'Residencial las Olas', 18.1186100, -94.5661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98475, 'Zoquiapa', 'Zoquiapa', 'Zoquiapa', 17.5447200, -99.2769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98476, 'Colonia Reforma Tlalmimilolpan', 'Colonia Reforma Tlalmimilolpan', 'Colonia Reforma Tlalmimilolpan', 19.3880600, -99.4888900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98477, 'San Andrés Enguaro', 'San Andres Enguaro', 'San Andres Enguaro,San Andrés Enguaro', 20.1947200, -101.2363900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98478, 'Cebadilla 1ra. Sección', 'Cebadilla 1ra. Seccion', 'Cebadilla 1ra. Seccion,Cebadilla 1ra. Sección', 14.8638100, -92.2796900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98479, 'Zaragoza (Puerto de Medina)', 'Zaragoza (Puerto de Medina)', 'Zaragoza (Puerto de Medina)', 19.8738900, -100.1177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98480, 'San Andrés de la Cal', 'San Andres de la Cal', 'San Andres de la Cal,San Andrés de la Cal', 18.9569400, -99.1144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98481, 'Ixcatla', 'Ixcatla', 'Ixcatla', 17.4225000, -98.9994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98482, 'Cuauhtémoc', 'Cuauhtemoc', 'Cuauhtemoc,Cuauhtémoc', 19.2230600, -97.3383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98483, 'Las Tazas', 'Las Tazas', 'Las Tazas', 16.7572200, -91.6150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98484, 'Ejido los Huastecos', 'Ejido los Huastecos', 'Ejido los Huastecos', 21.9591700, -98.6502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98485, 'Estanzuela', 'Estanzuela', 'Estanzuela', 22.2688900, -101.0080600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98486, 'San José de Abajo', 'San Jose de Abajo', 'San Jose de Abajo,San José de Abajo', 18.7758300, -96.7772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98487, 'Álamos Tepetitlán', 'Alamos Tepetitlan', 'Alamos Tepetitlan,Álamos Tepetitlán', 19.1961900, -97.4385800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98488, 'San Bernardo', 'San Bernardo', 'San Bernardo', 20.4738900, -101.0975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98489, 'Loma de los Hoyos', 'Loma de los Hoyos', 'Loma de los Hoyos', 19.0355600, -102.4427800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98490, 'Atzalán', 'Atzalan', 'Atzalan,Atzalán', 19.8247200, -97.4441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98491, 'Tepeteno de Iturbide', 'Tepeteno de Iturbide', 'Tepeteno de Iturbide', 19.7958300, -97.4972200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98492, 'Ciudad Chemuyil', 'Ciudad Chemuyil', 'Ciudad Chemuyil', 20.3486100, -87.3530600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98493, 'Tandzumadz', 'Tandzumadz', 'Tandzumadz', 21.5652800, -98.9802800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98494, 'Cajelitos', 'Cajelitos', 'Cajelitos', 17.2677800, -99.4930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98495, 'Huitzmaloc', 'Huitzmaloc', 'Huitzmaloc', 18.4563900, -96.9405600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98496, 'Pezmatlán', 'Pezmatlan', 'Pezmatlan,Pezmatlán', 19.8466400, -97.4852900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98497, 'Santa Anita', 'Santa Anita', 'Santa Anita', 20.4702800, -100.8150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98498, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Lazaro Cardenas,Lázaro Cárdenas', 20.9455600, -103.0222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98499, 'El Copetillo', 'El Copetillo', 'El Copetillo', 22.1433300, -102.0013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98500, 'Apalani', 'Apalani', 'Apalani', 16.8536100, -99.5894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98501, 'Barrio el Vivero', 'Barrio el Vivero', 'Barrio el Vivero', 19.4530600, -100.0352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98502, 'El Embarcadero', 'El Embarcadero', 'El Embarcadero', 16.9641700, -100.0016700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98503, 'Tlacoaxtla', 'Tlacoaxtla', 'Tlacoaxtla', 17.5548500, -99.2008100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98504, 'Tierra Blanca', 'Tierra Blanca', 'Tierra Blanca', 19.5066700, -99.5838900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98505, 'La Higuerita (Colonia San Rafael)', 'La Higuerita (Colonia San Rafael)', 'La Higuerita (Colonia San Rafael)', 19.6186100, -102.4844400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98506, 'Buen Retiro (El Retiro)', 'Buen Retiro (El Retiro)', 'Buen Retiro (El Retiro)', 25.4619400, -108.4783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98507, 'Colonia Gómez Morín', 'Colonia Gomez Morin', 'Colonia Gomez Morin,Colonia Gómez Morín', 31.8816700, -116.5438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98508, 'Colinas del Sol', 'Colinas del Sol', 'Colinas del Sol', 32.4030600, -117.0305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98509, 'Xochicalco (Cirenio Longares)', 'Xochicalco (Cirenio Longares)', 'Xochicalco (Cirenio Longares)', 18.7872200, -99.2994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98510, 'Tierra Blanca', 'Tierra Blanca', 'Tierra Blanca', 23.8272200, -103.0766700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98511, 'Zangarro (Zangarro Nuevo)', 'Zangarro (Zangarro Nuevo)', 'Zangarro (Zangarro Nuevo)', 20.8580600, -101.2727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98512, 'Artículo Primero Constitucional', 'Articulo Primero Constitucional', 'Articulo Primero Constitucional,Artículo Primero Constitucional', 18.9741200, -98.1584800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98513, 'Álvaro Obregón', 'Alvaro Obregon', 'Alvaro Obregon,Álvaro Obregón', 25.5141700, -103.5050000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98514, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 18.9480600, -99.5841700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98515, 'Villa Hermosa', 'Villa Hermosa', 'Villa Hermosa', 16.9386100, -99.3300000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98516, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 17.5355600, -95.8936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98517, 'Cala Norte', 'Cala Norte', 'Cala Norte', 19.8477800, -97.4230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98518, 'Xochitepec', 'Xochitepec', 'Xochitepec', 17.1825000, -99.2263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98519, 'Colonia la Libertad', 'Colonia la Libertad', 'Colonia la Libertad', 19.1852800, -99.5027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98520, 'Lomas de San Pablo', 'Lomas de San Pablo', 'Lomas de San Pablo', 19.2025000, -98.9177800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98521, 'San Pedro Cacahuatepec', 'San Pedro Cacahuatepec', 'San Pedro Cacahuatepec', 16.8150000, -99.6683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98522, 'Acachapan y Colmena 3ra. Sección', 'Acachapan y Colmena 3ra. Seccion', 'Acachapan y Colmena 3ra. Seccion,Acachapan y Colmena 3ra. Sección', 18.0485800, -92.7775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98523, 'Ejido Palma (Ejido San Francisco)', 'Ejido Palma (Ejido San Francisco)', 'Ejido Palma (Ejido San Francisco)', 19.5688900, -99.4088900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98524, 'Sinahua', 'Sinahua', 'Sinahua', 18.2811100, -100.6002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98525, 'Colonia Ecológica Asociación de Lucha Social (Lucha Social)', 'Colonia Ecologica Asociacion de Lucha Social (Lucha Social)', 'Colonia Ecologica Asociacion de Lucha Social (Lucha Social),Colonia Ecológica Asociación de Lucha Social (Lucha Social)', 19.6883300, -100.6091700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98526, 'Coxolico', 'Coxolico', 'Coxolico', 18.4510400, -97.0299100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98527, 'Saclamantón', 'Saclamanton', 'Saclamanton,Saclamantón', 16.7883300, -92.6350000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98528, 'San Antonio el Paso', 'San Antonio el Paso', 'San Antonio el Paso', 20.1472200, -98.6161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98529, 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', 'Colonia Emiliano Zapata', 19.1241700, -99.5808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98530, 'Lázaro Cárdenas (La Purísima)', 'Lazaro Cardenas (La Purisima)', 'Lazaro Cardenas (La Purisima),Lázaro Cárdenas (La Purísima)', 19.8697200, -101.0230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98531, 'San Lucas Huarirapeo (La Mesa de San Lucas)', 'San Lucas Huarirapeo (La Mesa de San Lucas)', 'San Lucas Huarirapeo (La Mesa de San Lucas)', 19.6786100, -100.6238900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98532, 'Miguel Hidalgo 2da. Sección B (La Natividad)', 'Miguel Hidalgo 2da. Seccion B (La Natividad)', 'Miguel Hidalgo 2da. Seccion B (La Natividad),Miguel Hidalgo 2da. Sección B (La Natividad)', 18.0786100, -93.3505600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98533, 'Colonia Juárez', 'Colonia Juarez', 'Colonia Juarez,Colonia Juárez', 19.9958300, -99.1494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98534, 'San Juan Colón', 'San Juan Colon', 'San Juan Colon,San Juan Colón', 18.5772200, -98.5583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98535, 'Alfredo V. Bonfil (Siete Ejidos)', 'Alfredo V. Bonfil (Siete Ejidos)', 'Alfredo V. Bonfil (Siete Ejidos)', 25.6430600, -108.2333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98536, 'San Juan Hueyapan', 'San Juan Hueyapan', 'San Juan Hueyapan', 20.0300000, -98.2819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98537, 'Paseos del Marqués', 'Paseos del Marques', 'Paseos del Marques,Paseos del Marqués', 20.6038900, -100.2402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98538, 'Ixtlilco el Chico', 'Ixtlilco el Chico', 'Ixtlilco el Chico', 18.5583300, -98.8469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98539, 'Ocoxaltepec', 'Ocoxaltepec', 'Ocoxaltepec', 18.9350000, -98.7525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98540, 'Felipe Neri (Cuatepec)', 'Felipe Neri (Cuatepec)', 'Felipe Neri (Cuatepec)', 19.0394400, -98.9436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98541, 'Cumbres III', 'Cumbres III', 'Cumbres III', 21.9222200, -102.2375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98542, 'Fraccionamiento Villas de la Llave', 'Fraccionamiento Villas de la Llave', 'Fraccionamiento Villas de la Llave', 18.9158300, -96.9911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98543, 'San Andrés Playa Encantada (El Podrido)', 'San Andres Playa Encantada (El Podrido)', 'San Andres Playa Encantada (El Podrido),San Andrés Playa Encantada (El Podrido)', 16.6922200, -99.6338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98544, 'Barrio de Ensido', 'Barrio de Ensido', 'Barrio de Ensido', 19.4938900, -99.3744400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98545, 'Pilotos', 'Pilotos', 'Pilotos', 22.0372200, -101.9591700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98546, 'Santa Ana', 'Santa Ana', 'Santa Ana', 19.5822200, -100.4688900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98547, 'Fraccionamiento Villa Jardín', 'Fraccionamiento Villa Jardin', 'Fraccionamiento Villa Jardin,Fraccionamiento Villa Jardín', 20.9916700, -101.8519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98548, 'Lomas de San Martín', 'Lomas de San Martin', 'Lomas de San Martin,Lomas de San Martín', 25.7472200, -100.1197200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98549, 'Tlixco', 'Tlixco', 'Tlixco', 18.2738900, -96.9997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98550, 'Santa Clara del Tule', 'Santa Clara del Tule', 'Santa Clara del Tule', 19.8238900, -100.8269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98551, 'San José Viborillas', 'San Jose Viborillas', 'San Jose Viborillas,San José Viborillas', 20.5677800, -100.6336100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98552, 'Ejido Jesús María', 'Ejido Jesus Maria', 'Ejido Jesus Maria,Ejido Jesús María', 21.1419400, -100.9116700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98553, 'Colonia Sesenta y Dos', 'Colonia Sesenta y Dos', 'Colonia Sesenta y Dos', 20.0052800, -99.3458300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98554, 'El Coloso', 'El Coloso', 'El Coloso', 19.0977800, -99.5977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98555, 'San Francisco Jaconá', 'San Francisco Jacona', 'San Francisco Jacona,San Francisco Jaconá', 17.2627800, -93.0325000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98556, 'Barrio de San Miguel', 'Barrio de San Miguel', 'Barrio de San Miguel', 19.6433300, -97.1238900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98557, 'Barrio Chiquichuca', 'Barrio Chiquichuca', 'Barrio Chiquichuca', 19.3213900, -100.2127800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98558, 'Putlunichuchut (Vista Hermosa)', 'Putlunichuchut (Vista Hermosa)', 'Putlunichuchut (Vista Hermosa)', 20.1559300, -97.6155700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98559, 'Doctor Samuel León Brindis', 'Doctor Samuel Leon Brindis', 'Doctor Samuel Leon Brindis,Doctor Samuel León Brindis', 17.4352800, -91.9319400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98560, 'Ahuihuiyuco', 'Ahuihuiyuco', 'Ahuihuiyuco', 17.6295800, -99.2273800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98561, 'Santa Rita', 'Santa Rita', 'Santa Rita', 22.9119400, -102.4183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98562, 'Catishtic', 'Catishtic', 'Catishtic', 16.7802800, -92.7377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98563, 'San Andrés Cohamiata', 'San Andres Cohamiata', 'San Andres Cohamiata,San Andrés Cohamiata', 22.1894400, -104.2408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98564, 'Barrio San Diego', 'Barrio San Diego', 'Barrio San Diego', 17.2791700, -97.6741700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98565, 'Fraccionamiento del Magisterio Tulancinguense', 'Fraccionamiento del Magisterio Tulancinguense', 'Fraccionamiento del Magisterio Tulancinguense', 20.0763900, -98.3997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98566, 'Colonia Obrera', 'Colonia Obrera', 'Colonia Obrera', 18.9316700, -99.0388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98567, 'Banus Vallarta (Verde Vallarta)', 'Banus Vallarta (Verde Vallarta)', 'Banus Vallarta (Verde Vallarta)', 20.7161100, -105.2230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98568, 'San Juan Tomasquillo Herradura', 'San Juan Tomasquillo Herradura', 'San Juan Tomasquillo Herradura', 19.1722200, -99.4038900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98569, 'Residencial Tajín', 'Residencial Tajin', 'Residencial Tajin,Residencial Tajín', 20.5980600, -97.4169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98570, 'Colonia San Francisco (San Francisco)', 'Colonia San Francisco (San Francisco)', 'Colonia San Francisco (San Francisco)', 22.3036100, -101.8205600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98571, 'Fraccionamiento la Noria', 'Fraccionamiento la Noria', 'Fraccionamiento la Noria', 25.5572200, -103.3436100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98572, 'Ahuacachahue (Ndog''yo Itún Tichi)', 'Ahuacachahue (Ndog''yo Itun Tichi)', 'Ahuacachahue (Ndog''yo Itun Tichi),Ahuacachahue (Ndog''yo Itún Tichi)', 16.8286100, -98.9855600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98573, 'Progreso', 'Progreso', 'Progreso', 19.4883300, -97.6772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98574, 'Banderas', 'Banderas', 'Banderas', 20.9908300, -97.3936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98575, 'Ixtahuiata (La Legua)', 'Ixtahuiata (La Legua)', 'Ixtahuiata (La Legua)', 19.8438900, -97.3355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98576, 'Romerillo', 'Romerillo', 'Romerillo', 16.7652800, -92.5675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98577, 'San Isidro las Banderas', 'San Isidro las Banderas', 'San Isidro las Banderas', 17.2302800, -93.0602800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98578, 'Tepetitán Reyeshogpan de Hidalgo', 'Tepetitan Reyeshogpan de Hidalgo', 'Tepetitan Reyeshogpan de Hidalgo,Tepetitán Reyeshogpan de Hidalgo', 20.0836100, -97.4936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98579, 'La Ibérica (La Gotera)', 'La Iberica (La Gotera)', 'La Iberica (La Gotera),La Ibérica (La Gotera)', 19.1647200, -101.9161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98580, 'Cerritos', 'Cerritos', 'Cerritos', 20.3530600, -99.0122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98581, 'Colonia San Juan', 'Colonia San Juan', 'Colonia San Juan', 20.1902800, -99.2827800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98582, 'El Progreso', 'El Progreso', 'El Progreso', 20.0191700, -97.3647200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98583, 'Álvaro Obregón (Santa Cruz)', 'Alvaro Obregon (Santa Cruz)', 'Alvaro Obregon (Santa Cruz),Álvaro Obregón (Santa Cruz)', 18.3942200, -92.7998200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98584, 'Las Lomas', 'Las Lomas', 'Las Lomas', 16.9819400, -100.0950000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98585, 'Los Bahuises', 'Los Bahuises', 'Los Bahuises', 27.1166700, -109.4672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98586, 'Jolochero 2da. Sección', 'Jolochero 2da. Seccion', 'Jolochero 2da. Seccion,Jolochero 2da. Sección', 18.1200000, -92.7983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98587, 'La Soledad', 'La Soledad', 'La Soledad', 16.9200000, -98.1669400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98588, 'La Calera (Nacimientos)', 'La Calera (Nacimientos)', 'La Calera (Nacimientos)', 20.2752800, -101.5755600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98589, 'El Triunfo de las Tres Maravillas', 'El Triunfo de las Tres Maravillas', 'El Triunfo de las Tres Maravillas', 15.6469400, -92.1563900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98590, 'Potrerillo', 'Potrerillo', 'Potrerillo', 18.2547200, -93.1347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98591, 'San Pedro Huitzapula Norte (Huitzapula Norte)', 'San Pedro Huitzapula Norte (Huitzapula Norte)', 'San Pedro Huitzapula Norte (Huitzapula Norte)', 17.4264200, -98.8058800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98592, 'Tzoeptic', 'Tzoeptic', 'Tzoeptic', 16.8827800, -92.5680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98593, 'La Unión Ejido Mexcaltepec', 'La Union Ejido Mexcaltepec', 'La Union Ejido Mexcaltepec,La Unión Ejido Mexcaltepec', 19.6080600, -97.7105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98594, 'Francisco Sarabia', 'Francisco Sarabia', 'Francisco Sarabia', 18.9641700, -98.3138900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98595, 'Mitzitón', 'Mitziton', 'Mitziton,Mitzitón', 16.6463900, -92.5433300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98596, 'Alcozacán', 'Alcozacan', 'Alcozacan,Alcozacán', 17.5044400, -99.0950000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98597, 'Granadillas (La Colonia)', 'Granadillas (La Colonia)', 'Granadillas (La Colonia)', 21.3797200, -101.9013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98598, 'Tlahuapa', 'Tlahuapa', 'Tlahuapa', 17.3750000, -98.3375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98599, 'Plaza Nueva', 'Plaza Nueva', 'Plaza Nueva', 18.9294400, -99.4344400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98600, 'La Manga 2da. Sección (El Jobal)', 'La Manga 2da. Seccion (El Jobal)', 'La Manga 2da. Seccion (El Jobal),La Manga 2da. Sección (El Jobal)', 18.0191700, -92.8694400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98601, 'Los Mancera', 'Los Mancera', 'Los Mancera', 20.4702800, -100.8038900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98602, 'Palo Seco (El Gato)', 'Palo Seco (El Gato)', 'Palo Seco (El Gato)', 22.3541700, -100.1919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98603, 'Colonia Renacimiento', 'Colonia Renacimiento', 'Colonia Renacimiento', 16.7627800, -98.1822200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98604, 'Santa Cruz de la Loma (Tepetates)', 'Santa Cruz de la Loma (Tepetates)', 'Santa Cruz de la Loma (Tepetates)', 20.4880600, -103.5497200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98605, 'Fraccionamiento Laureles Eréndira', 'Fraccionamiento Laureles Erendira', 'Fraccionamiento Laureles Erendira,Fraccionamiento Laureles Eréndira', 19.7722200, -101.1305600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98606, 'Las Nieves', 'Las Nieves', 'Las Nieves', 18.1836100, -98.0461100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98607, 'Colonia Bellavista', 'Colonia Bellavista', 'Colonia Bellavista', 19.2982000, -99.8087900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98608, 'Nicolás Bravo 5ta. Sección (Punta Brava)', 'Nicolas Bravo 5ta. Seccion (Punta Brava)', 'Nicolas Bravo 5ta. Seccion (Punta Brava),Nicolás Bravo 5ta. Sección (Punta Brava)', 18.2782700, -93.1287200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98609, 'Almoloya', 'Almoloya', 'Almoloya', 20.1513900, -98.4486100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98610, 'La Loma', 'La Loma', 'La Loma', 20.6000000, -100.2388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98611, 'Yibeljoj', 'Yibeljoj', 'Yibeljoj', 16.9575000, -92.5036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98612, 'San Pedro Matamoros', 'San Pedro Matamoros', 'San Pedro Matamoros', 19.3697200, -98.5547200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98613, 'Santa Anita', 'Santa Anita', 'Santa Anita', 32.1008300, -116.8691700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98614, 'Colonia Morelos', 'Colonia Morelos', 'Colonia Morelos', 19.8905600, -98.8166700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98615, 'La Mesa (La Mesa de Cedano)', 'La Mesa (La Mesa de Cedano)', 'La Mesa (La Mesa de Cedano)', 19.4486100, -100.3272200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98616, 'Ranchería de Pocitos', 'Rancheria de Pocitos', 'Rancheria de Pocitos,Ranchería de Pocitos', 19.3938900, -97.7594400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98617, 'San Roque', 'San Roque', 'San Roque', 19.4802800, -99.9605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98618, 'Patria Nueva (San José el Contento)', 'Patria Nueva (San Jose el Contento)', 'Patria Nueva (San Jose el Contento),Patria Nueva (San José el Contento)', 16.9277800, -92.1136100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98619, 'San Cristóbal Hidalgo', 'San Cristobal Hidalgo', 'San Cristobal Hidalgo,San Cristóbal Hidalgo', 19.0219400, -97.8102800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98620, 'San Andrés (San Andrés Chichayotla)', 'San Andres (San Andres Chichayotla)', 'San Andres (San Andres Chichayotla),San Andrés (San Andrés Chichayotla)', 20.9266700, -98.5633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98621, 'San Antonio Chiverías', 'San Antonio Chiverias', 'San Antonio Chiverias,San Antonio Chiverías', 18.6522200, -99.2213900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98622, 'Colonia 3 de Mayo (La Cruz)', 'Colonia 3 de Mayo (La Cruz)', 'Colonia 3 de Mayo (La Cruz)', 19.9808300, -99.1636100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98623, 'La Glorieta', 'La Glorieta', 'La Glorieta', 19.4115400, -99.3856200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98624, 'Ejido San José Xilatzén', 'Ejido San Jose Xilatzen', 'Ejido San Jose Xilatzen,Ejido San José Xilatzén', 21.6747200, -98.9275000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98625, 'Villa Hidalgo (El Cubo)', 'Villa Hidalgo (El Cubo)', 'Villa Hidalgo (El Cubo)', 18.1616700, -100.3150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98626, 'La Magdalena Tenexpan', 'La Magdalena Tenexpan', 'La Magdalena Tenexpan', 19.4633300, -99.5886100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98627, 'Vega del Sol', 'Vega del Sol', 'Vega del Sol', 17.8097200, -96.2169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98628, 'Tlanipatla', 'Tlanipatla', 'Tlanipatla', 17.8080600, -99.4513900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98629, 'San Martín Itunyoso', 'San Martin Itunyoso', 'San Martin Itunyoso,San Martín Itunyoso', 17.2280600, -97.8808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98630, 'Cuchulumtic', 'Cuchulumtic', 'Cuchulumtic', 16.7772200, -92.7041700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98631, 'Barrio la Tenería', 'Barrio la Teneria', 'Barrio la Teneria,Barrio la Tenería', 19.6936100, -99.7919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98632, 'San Rafael', 'San Rafael', 'San Rafael', 17.2266700, -98.4241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98633, 'Paso Bonito', 'Paso Bonito', 'Paso Bonito', 22.3252800, -101.2616700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98634, 'Playa Chica', 'Playa Chica', 'Playa Chica', 18.0613900, -96.5183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98635, 'Iztacapa', 'Iztacapa', 'Iztacapa', 21.3700000, -98.9416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98636, 'Acatla', 'Acatla', 'Acatla', 18.7494400, -97.2183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98637, 'Loma de Guadalupe (La Biznaga)', 'Loma de Guadalupe (La Biznaga)', 'Loma de Guadalupe (La Biznaga)', 19.6521900, -99.3687300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98638, 'Metepec Primero', 'Metepec Primero', 'Metepec Primero', 20.1416700, -98.4322200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98639, 'Tanhuixco', 'Tanhuixco', 'Tanhuixco', 19.8205600, -97.4672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98640, 'Guadalupe Hidalgo', 'Guadalupe Hidalgo', 'Guadalupe Hidalgo', 19.2261100, -98.1875000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98641, 'El Palacio', 'El Palacio', 'El Palacio', 19.3513900, -99.3566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98642, 'Empaque Tarriba', 'Empaque Tarriba', 'Empaque Tarriba', 23.9002800, -106.9311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98643, 'Zapuyo', 'Zapuyo', 'Zapuyo', 21.3547200, -98.9213900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98644, 'Cerro Armadillo Grande', 'Cerro Armadillo Grande', 'Cerro Armadillo Grande', 17.8661100, -96.3086100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98645, 'Estación Dobladero', 'Estacion Dobladero', 'Estacion Dobladero,Estación Dobladero', 18.1150000, -95.7661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98646, 'Puerto de Providencia', 'Puerto de Providencia', 'Puerto de Providencia', 22.3652800, -101.0655600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98647, 'Estación Capomas', 'Estacion Capomas', 'Estacion Capomas,Estación Capomas', 25.6011100, -108.2236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98648, 'Los Pinos', 'Los Pinos', 'Los Pinos', 18.4438900, -95.2433300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98649, 'Huixcolotla', 'Huixcolotla', 'Huixcolotla', 18.6655600, -96.4975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98650, 'Colonia Lázaro Cárdenas', 'Colonia Lazaro Cardenas', 'Colonia Lazaro Cardenas,Colonia Lázaro Cárdenas', 19.4461100, -98.9047200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98651, 'San Miguel Tenango', 'San Miguel Tenango', 'San Miguel Tenango', 19.9087700, -97.9347400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98652, 'El Calvario', 'El Calvario', 'El Calvario', 17.2175000, -92.5569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98653, 'José Refugio Salcido', 'Jose Refugio Salcido', 'Jose Refugio Salcido,José Refugio Salcido', 23.9644400, -104.5180600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98654, 'José María Morelos (San José)', 'Jose Maria Morelos (San Jose)', 'Jose Maria Morelos (San Jose),José María Morelos (San José)', 19.6825000, -98.5763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98655, 'Los Encinos', 'Los Encinos', 'Los Encinos', 19.1791700, -98.3983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98656, 'Privada del Álamo', 'Privada del Alamo', 'Privada del Alamo,Privada del Álamo', 20.0983300, -98.7002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98657, 'Cuapinolito (Azulillo)', 'Cuapinolito (Azulillo)', 'Cuapinolito (Azulillo)', 15.8219400, -96.3183300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98658, 'Los Dulces Nombres', 'Los Dulces Nombres', 'Los Dulces Nombres', 20.6480600, -100.9647200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98659, 'Colonia Obrera', 'Colonia Obrera', 'Colonia Obrera', 19.2294400, -97.7975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98660, 'Sección 23', 'Seccion 23', 'Seccion 23,Sección 23', 19.7877800, -97.3791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98661, 'Mixtlalcingo', 'Mixtlalcingo', 'Mixtlalcingo', 18.8033300, -98.9002800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98662, 'Zoyatitla', 'Zoyatitla', 'Zoyatitla', 19.8234300, -97.8183100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98663, 'Tonalapan', 'Tonalapan', 'Tonalapan', 18.4683300, -95.2200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98664, 'Gabriel Hernández (Mancinas)', 'Gabriel Hernandez (Mancinas)', 'Gabriel Hernandez (Mancinas),Gabriel Hernández (Mancinas)', 23.8116700, -104.0244400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98665, 'Higuera de los Vega', 'Higuera de los Vega', 'Higuera de los Vega', 25.6550000, -107.9577800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98666, 'San Isidro Xoteapan (San Isidro Texcaltitán)', 'San Isidro Xoteapan (San Isidro Texcaltitan)', 'San Isidro Xoteapan (San Isidro Texcaltitan),San Isidro Xoteapan (San Isidro Texcaltitán)', 18.4677800, -95.2380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98667, 'La Luz de Juárez', 'La Luz de Juarez', 'La Luz de Juarez,La Luz de Juárez', 17.5350000, -98.3483300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98668, 'Colonia Aquiles Córdoba Morán', 'Colonia Aquiles Cordoba Moran', 'Colonia Aquiles Cordoba Moran,Colonia Aquiles Córdoba Morán', 19.7066700, -100.5352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98669, 'Banderas (Guatacalca 2da. Sección)', 'Banderas (Guatacalca 2da. Seccion)', 'Banderas (Guatacalca 2da. Seccion),Banderas (Guatacalca 2da. Sección)', 18.1516700, -92.8988100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98670, 'Ejido Hidalgo', 'Ejido Hidalgo', 'Ejido Hidalgo', 22.3008300, -102.0386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98671, 'Maya Tecún I', 'Maya Tecun I', 'Maya Tecun I,Maya Tecún I', 19.1536100, -90.5055600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98672, 'Tepozcuautla', 'Tepozcuautla', 'Tepozcuautla', 17.6222200, -99.2277800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98673, 'La Providencia', 'La Providencia', 'La Providencia', 30.9688900, -116.1586100, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98674, 'Barrio la Joya', 'Barrio la Joya', 'Barrio la Joya', 19.4200000, -100.0997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98675, 'Loma de San Francisco', 'Loma de San Francisco', 'Loma de San Francisco', 19.2833300, -99.8091700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98676, 'Arimatea', 'Arimatea', 'Arimatea', 17.3413900, -91.8763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98677, 'Las Huertas Tercera Sección', 'Las Huertas Tercera Seccion', 'Las Huertas Tercera Seccion,Las Huertas Tercera Sección', 20.6527800, -101.3930600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98678, 'Francisco Primo de Verdad (Ciénega de Mata)', 'Francisco Primo de Verdad (Cienega de Mata)', 'Francisco Primo de Verdad (Cienega de Mata),Francisco Primo de Verdad (Ciénega de Mata)', 21.7447200, -101.8261100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98679, 'Pablo L. Sidar', 'Pablo L. Sidar', 'Pablo L. Sidar', 17.9002800, -93.0291700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98680, 'San José el Nuevo', 'San Jose el Nuevo', 'San Jose el Nuevo,San José el Nuevo', 20.4438900, -100.7719400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98681, 'Paso de Núñez (Buenavista)', 'Paso de Nunez (Buenavista)', 'Paso de Nunez (Buenavista),Paso de Núñez (Buenavista)', 18.8947200, -100.9466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98682, 'San Pedro Cuitlapan', 'San Pedro Cuitlapan', 'San Pedro Cuitlapan', 16.9730600, -98.2516700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98683, 'La Herradura', 'La Herradura', 'La Herradura', 21.4425000, -98.9491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98684, 'Santo Domingo de las Palmas', 'Santo Domingo de las Palmas', 'Santo Domingo de las Palmas', 16.1366700, -91.3219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98685, 'El Mogote', 'El Mogote', 'El Mogote', 20.1658300, -99.9144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98686, 'Colonia Wenceslao Labra', 'Colonia Wenceslao Labra', 'Colonia Wenceslao Labra', 19.8277300, -99.1243500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98687, 'Cementeras del Pital', 'Cementeras del Pital', 'Cementeras del Pital', 20.1769400, -96.8958300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98688, 'Puebla', 'Puebla', 'Puebla', 16.9158300, -92.5038900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98689, 'Tzopilja', 'Tzopilja', 'Tzopilja', 16.7397200, -92.3091700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98690, 'Tonalixco', 'Tonalixco', 'Tonalixco', 20.2316700, -98.2552800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98691, 'Cerro Grande', 'Cerro Grande', 'Cerro Grande', 20.2386100, -97.6819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98692, 'Oriente 1ra. Sección (Santo Domingo)', 'Oriente 1ra. Seccion (Santo Domingo)', 'Oriente 1ra. Seccion (Santo Domingo),Oriente 1ra. Sección (Santo Domingo)', 18.2641700, -93.2030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98693, 'Quintana Roo', 'Quintana Roo', 'Quintana Roo', 16.6066700, -93.5619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98694, 'El Porvenir', 'El Porvenir', 'El Porvenir', 18.9208300, -96.9258300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98695, 'Barrio del Cajón', 'Barrio del Cajon', 'Barrio del Cajon,Barrio del Cajón', 19.3913900, -99.6580600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98696, 'Hidalgo Amajac', 'Hidalgo Amajac', 'Hidalgo Amajac', 20.9050000, -97.6294400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98697, 'Tierra Blanca', 'Tierra Blanca', 'Tierra Blanca', 18.9722200, -99.5919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98698, 'Tomaquilapa', 'Tomaquilapa', 'Tomaquilapa', 19.7563500, -97.3216100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98699, 'Licenciado Gustavo Díaz Ordaz (18 de Marzo)', 'Licenciado Gustavo Diaz Ordaz (18 de Marzo)', 'Licenciado Gustavo Diaz Ordaz (18 de Marzo),Licenciado Gustavo Díaz Ordaz (18 de Marzo)', 18.6322200, -91.0027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98700, 'Zizicazapa', 'Zizicazapa', 'Zizicazapa', 17.5155600, -99.1525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98701, 'Sergio Villaseñor', 'Sergio Villasenor', 'Sergio Villasenor,Sergio Villaseñor', 20.6450000, -100.4208300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98702, 'San Miguel del Arenal', 'San Miguel del Arenal', 'San Miguel del Arenal', 20.9908300, -101.4855600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98703, 'Cuatro Caminos', 'Cuatro Caminos', 'Cuatro Caminos', 18.4913000, -97.1290100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98704, 'La Soledad', 'La Soledad', 'La Soledad', 20.1694400, -100.1911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98705, 'Chiconamel', 'Chiconamel', 'Chiconamel', 21.3680600, -98.7191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98706, 'San José de Abajo [Unidad Habitacional]', 'San Jose de Abajo [Unidad Habitacional]', 'San Jose de Abajo [Unidad Habitacional],San José de Abajo [Unidad Habitacional]', 18.9197200, -96.9636100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98707, 'Patlicha', 'Patlicha', 'Patlicha', 17.4394400, -98.7216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98708, 'San Antonio Xahuento', 'San Antonio Xahuento', 'San Antonio Xahuento', 19.6916700, -99.1072200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98709, 'Colonia Ángel Bocanegra (Adolfo López Mateos)', 'Colonia Angel Bocanegra (Adolfo Lopez Mateos)', 'Colonia Angel Bocanegra (Adolfo Lopez Mateos),Colonia Ángel Bocanegra (Adolfo López Mateos)', 18.9263900, -99.0297200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98710, 'Colonia Hidalgo (El Tecolote)', 'Colonia Hidalgo (El Tecolote)', 'Colonia Hidalgo (El Tecolote)', 22.3297200, -102.0358300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98711, 'Carmen Serdán', 'Carmen Serdan', 'Carmen Serdan,Carmen Serdán', 19.0363900, -97.8119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98712, 'Colonia Guadalupe', 'Colonia Guadalupe', 'Colonia Guadalupe', 19.9391700, -98.7655600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98713, 'Emiliano Zapata', 'Emiliano Zapata', 'Emiliano Zapata', 15.6691700, -92.2386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98714, 'San Bernardo Peña Blanca', 'San Bernardo Pena Blanca', 'San Bernardo Pena Blanca,San Bernardo Peña Blanca', 20.4616700, -101.4825000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98715, 'Izotepec', 'Izotepec', 'Izotepec', 17.5850000, -99.9544400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98716, 'Rancho de las Lomas', 'Rancho de las Lomas', 'Rancho de las Lomas', 17.7397200, -99.2458300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98717, 'San Juan del Río', 'San Juan del Rio', 'San Juan del Rio,San Juan del Río', 16.8825000, -96.1613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98718, 'Arroyo Chical (Nuevo Arroyo Chicali)', 'Arroyo Chical (Nuevo Arroyo Chicali)', 'Arroyo Chical (Nuevo Arroyo Chicali)', 18.2161100, -96.3366700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98719, 'Buenavista', 'Buenavista', 'Buenavista', 17.2255600, -92.5266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98720, 'Tres Cerros', 'Tres Cerros', 'Tres Cerros', 16.9155600, -92.4727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98721, 'Atlamajalcingo del Río', 'Atlamajalcingo del Rio', 'Atlamajalcingo del Rio,Atlamajalcingo del Río', 17.5266700, -98.6555600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98722, 'Xalatlaco', 'Xalatlaco', 'Xalatlaco', 19.0497200, -97.0411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98723, 'CERESO Nuevo', 'CERESO Nuevo', 'CERESO Nuevo', 25.8913900, -109.0422200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98724, 'Pascala del Oro', 'Pascala del Oro', 'Pascala del Oro', 17.0547200, -98.8097200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98725, 'Ladrilleras de Ocoro', 'Ladrilleras de Ocoro', 'Ladrilleras de Ocoro', 25.5980600, -108.4494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98726, 'Puerta del Llano', 'Puerta del Llano', 'Puerta del Llano', 20.7852800, -103.4613900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98727, 'El Obraje', 'El Obraje', 'El Obraje', 19.7226900, -99.9625900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98728, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 17.2900000, -92.9380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98729, 'El Refugio', 'El Refugio', 'El Refugio', 17.0383300, -99.2005600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98730, 'Majastic', 'Majastic', 'Majastic', 17.2894400, -92.6283300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98731, 'Las Letras', 'Las Letras', 'Las Letras', 20.2308300, -101.4336100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98732, 'El Pozo', 'El Pozo', 'El Pozo', 20.6375000, -100.3330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98733, 'Oriente 2da. Sección (Palma Huaca)', 'Oriente 2da. Seccion (Palma Huaca)', 'Oriente 2da. Seccion (Palma Huaca),Oriente 2da. Sección (Palma Huaca)', 18.3291700, -93.1852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98734, 'Molinos', 'Molinos', 'Molinos', 22.1627800, -102.0947200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98735, 'Maclovio Herrera (Colonia Aviación)', 'Maclovio Herrera (Colonia Aviacion)', 'Maclovio Herrera (Colonia Aviacion),Maclovio Herrera (Colonia Aviación)', 32.5419400, -116.6361100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98736, 'Cumbre de Barranca Honda', 'Cumbre de Barranca Honda', 'Cumbre de Barranca Honda', 16.7316700, -98.3366700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98737, 'Colonia Arboledas (San Andrés)', 'Colonia Arboledas (San Andres)', 'Colonia Arboledas (San Andres),Colonia Arboledas (San Andrés)', 19.2025000, -99.5808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98738, 'Fracción San Roque (El Prieto)', 'Fraccion San Roque (El Prieto)', 'Fraccion San Roque (El Prieto),Fracción San Roque (El Prieto)', 19.6872200, -99.1722200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98739, 'San Cristóbal los Nava', 'San Cristobal los Nava', 'San Cristobal los Nava,San Cristóbal los Nava', 18.9952800, -97.8319400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98740, 'Lucio Blanco (Los Gavilanes)', 'Lucio Blanco (Los Gavilanes)', 'Lucio Blanco (Los Gavilanes)', 21.1152800, -101.5511100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98741, 'Los Palacios', 'Los Palacios', 'Los Palacios', 14.8571800, -92.2582100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98742, 'Oxeloco', 'Oxeloco', 'Oxeloco', 20.9188900, -98.3255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98743, 'El Césped', 'El Cesped', 'El Cesped,El Césped', 19.8825000, -100.1397200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98744, 'San Antonio Matlahuacales', 'San Antonio Matlahuacales', 'San Antonio Matlahuacales', 19.7552800, -98.0819400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98745, 'Piedra Blanca', 'Piedra Blanca', 'Piedra Blanca', 16.9886100, -95.0127800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98746, 'La Purísima', 'La Purisima', 'La Purisima,La Purísima', 20.5144400, -100.6725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98747, 'Praderas de San Francisco', 'Praderas de San Francisco', 'Praderas de San Francisco', 25.8183300, -100.4025000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98748, 'Alejo González (Bilbao)', 'Alejo Gonzalez (Bilbao)', 'Alejo Gonzalez (Bilbao),Alejo González (Bilbao)', 25.8219400, -103.1947200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98749, 'Colonia Patria Nueva', 'Colonia Patria Nueva', 'Colonia Patria Nueva', 20.5283300, -100.8794400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98750, 'Colonia Guadalupana', 'Colonia Guadalupana', 'Colonia Guadalupana', 20.5666700, -103.2188900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98751, 'Xalticpac', 'Xalticpac', 'Xalticpac', 19.8430100, -97.5955600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98752, 'Santa Ana Nichi Ejido', 'Santa Ana Nichi Ejido', 'Santa Ana Nichi Ejido', 19.5844100, -99.9890500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98753, 'Tequila 1ra. Sección (La Aurora)', 'Tequila 1ra. Seccion (La Aurora)', 'Tequila 1ra. Seccion (La Aurora),Tequila 1ra. Sección (La Aurora)', 17.8800000, -92.7230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98754, 'Primero de Mayo (Chupaderos)', 'Primero de Mayo (Chupaderos)', 'Primero de Mayo (Chupaderos)', 21.4661100, -101.8272200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98755, 'Prados del Rosario', 'Prados del Rosario', 'Prados del Rosario', 21.0219400, -100.3925000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98756, 'San Antonio Bulujib', 'San Antonio Bulujib', 'San Antonio Bulujib', 16.9966700, -92.2966700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98757, 'San Ignacio', 'San Ignacio', 'San Ignacio', 21.2819400, -100.5372200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98758, 'Colonia los Remedios', 'Colonia los Remedios', 'Colonia los Remedios', 19.7344400, -98.7911100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98759, 'San Antonio de Corrales', 'San Antonio de Corrales', 'San Antonio de Corrales', 20.7455600, -100.9636100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98760, 'El Salvador (Ranchito San José del Carmen)', 'El Salvador (Ranchito San Jose del Carmen)', 'El Salvador (Ranchito San Jose del Carmen),El Salvador (Ranchito San José del Carmen)', 20.2875000, -100.8772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98761, 'Potrero de los Sánchez (Estación Techa)', 'Potrero de los Sanchez (Estacion Techa)', 'Potrero de los Sanchez (Estacion Techa),Potrero de los Sánchez (Estación Techa)', 25.1100000, -107.9011100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98762, 'Oriente 2da. Sección (San Cayetano)', 'Oriente 2da. Seccion (San Cayetano)', 'Oriente 2da. Seccion (San Cayetano),Oriente 2da. Sección (San Cayetano)', 18.1866700, -93.2294400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98763, 'Rincón Verde', 'Rincon Verde', 'Rincon Verde,Rincón Verde', 19.4963900, -99.2908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98764, 'La Palmita y Anexos (La Presita)', 'La Palmita y Anexos (La Presita)', 'La Palmita y Anexos (La Presita)', 24.9091700, -107.4519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98765, 'San Carlos Autopan', 'San Carlos Autopan', 'San Carlos Autopan', 19.3858300, -99.6872200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98766, 'Patria Nueva', 'Patria Nueva', 'Patria Nueva', 20.6322200, -100.4769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98767, 'Zequentic', 'Zequentic', 'Zequentic', 16.7169400, -92.8266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98768, 'Eureka de Media Luna (Eureka)', 'Eureka de Media Luna (Eureka)', 'Eureka de Media Luna (Eureka)', 25.7988900, -103.3736100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98769, 'San Vicente (Calpulalpan Tercera Manzana)', 'San Vicente (Calpulalpan Tercera Manzana)', 'San Vicente (Calpulalpan Tercera Manzana)', 20.0372200, -99.6416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98770, 'Las Yerbitas [Aserradero]', 'Las Yerbitas [Aserradero]', 'Las Yerbitas [Aserradero]', 26.0802500, -106.7796900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98771, 'San José de Bernalejo (El Guayabo)', 'San Jose de Bernalejo (El Guayabo)', 'San Jose de Bernalejo (El Guayabo),San José de Bernalejo (El Guayabo)', 20.6400000, -101.4013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98772, 'Buenavista (Matasanos)', 'Buenavista (Matasanos)', 'Buenavista (Matasanos)', 17.1077800, -93.0669400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98773, 'Río Jordán', 'Rio Jordan', 'Rio Jordan,Río Jordán', 17.2461100, -91.9330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98774, 'Escalerilla Lagunas', 'Escalerilla Lagunas', 'Escalerilla Lagunas', 17.3780600, -98.8466700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98775, 'El Mirador', 'El Mirador', 'El Mirador', 19.5569400, -97.7719400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98776, 'Cuesta de Laja', 'Cuesta de Laja', 'Cuesta de Laja', 18.2933300, -95.2211100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98777, 'La Sábana', 'La Sabana', 'La Sabana,La Sábana', 18.4446100, -92.8841100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98778, 'La Trinidad Chimalpa', 'La Trinidad Chimalpa', 'La Trinidad Chimalpa', 19.3294400, -98.2452800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98779, 'La Colonia', 'La Colonia', 'La Colonia', 19.1444400, -98.7866700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98780, 'Playa de la Libertad', 'Playa de la Libertad', 'Playa de la Libertad', 19.0830600, -96.0977800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98781, 'Macutzio', 'Macutzio', 'Macutzio', 19.4991700, -100.3550000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98782, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 17.5830600, -95.7772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98783, 'Fraccionamiento Riberas de San Jerónimo', 'Fraccionamiento Riberas de San Jeronimo', 'Fraccionamiento Riberas de San Jeronimo,Fraccionamiento Riberas de San Jerónimo', 17.1125000, -96.7772200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98784, 'El Silencio', 'El Silencio', 'El Silencio', 27.4680100, -113.2998700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98785, 'Santa Cruz Texmalaquilla', 'Santa Cruz Texmalaquilla', 'Santa Cruz Texmalaquilla', 18.9430600, -97.2875000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98786, 'Lomas de Santa Cruz', 'Lomas de Santa Cruz', 'Lomas de Santa Cruz', 18.9244400, -97.7300000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98787, 'El Mollejon', 'El Mollejon', 'El Mollejon', 20.5422200, -97.4111100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98788, 'Tacuba Nueva', 'Tacuba Nueva', 'Tacuba Nueva', 17.0902800, -92.3702800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98789, 'Cálido', 'Calido', 'Calido,Cálido', 17.0988900, -92.7875000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98790, 'Paso de Pirules', 'Paso de Pirules', 'Paso de Pirules', 20.9502800, -101.2997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98791, 'Las Lomas', 'Las Lomas', 'Las Lomas', 17.9555600, -94.5611100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98792, 'Alfonso Garzón [Granjas Familiares]', 'Alfonso Garzon [Granjas Familiares]', 'Alfonso Garzon [Granjas Familiares],Alfonso Garzón [Granjas Familiares]', 32.5466700, -116.6172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98793, 'San José de Durán (Los Troncoso)', 'San Jose de Duran (Los Troncoso)', 'San Jose de Duran (Los Troncoso),San José de Durán (Los Troncoso)', 21.0630600, -101.6741700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98794, 'Ococh', 'Ococh', 'Ococh', 16.8380600, -92.4752800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98795, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Lazaro Cardenas,Lázaro Cárdenas', 19.1430600, -97.4005600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98796, 'Boquilla de Babisas (La Boquilla de Conchos)', 'Boquilla de Babisas (La Boquilla de Conchos)', 'Boquilla de Babisas (La Boquilla de Conchos)', 27.5486100, -105.4036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98797, 'Colonia Constitución', 'Colonia Constitucion', 'Colonia Constitucion,Colonia Constitución', 17.5366700, -98.5994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98798, 'Chichicapa', 'Chichicapa', 'Chichicapa', 18.4005600, -97.0469400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98799, 'Tulimanca', 'Tulimanca', 'Tulimanca', 18.4694400, -97.1400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98800, 'Nueva Libertad (El Colorado)', 'Nueva Libertad (El Colorado)', 'Nueva Libertad (El Colorado)', 15.8986100, -92.0591700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98801, 'El Colegio', 'El Colegio', 'El Colegio', 19.7733300, -101.1775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98802, 'Colonia Jordán', 'Colonia Jordan', 'Colonia Jordan,Colonia Jordán', 16.3889300, -95.2020300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98803, 'José María Morelos', 'Jose Maria Morelos', 'Jose Maria Morelos,José María Morelos', 23.3227800, -103.0144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98804, 'Pechucalco 2da. Sección (Las Cruces)', 'Pechucalco 2da. Seccion (Las Cruces)', 'Pechucalco 2da. Seccion (Las Cruces),Pechucalco 2da. Sección (Las Cruces)', 18.1269400, -93.1905600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98805, 'Xolostitla de Morelos (Xolostitla)', 'Xolostitla de Morelos (Xolostitla)', 'Xolostitla de Morelos (Xolostitla)', 20.0663900, -98.6386100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98806, 'La Independencia (Las Pilas)', 'La Independencia (Las Pilas)', 'La Independencia (Las Pilas)', 16.6775000, -93.2494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98807, 'Colonia Guadalupe', 'Colonia Guadalupe', 'Colonia Guadalupe', 19.7130600, -99.2497200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98808, 'Lázaro Cárdenas (Chilil)', 'Lazaro Cardenas (Chilil)', 'Lazaro Cardenas (Chilil),Lázaro Cárdenas (Chilil)', 16.6761100, -92.4891700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98809, 'Cuesta Amarilla', 'Cuesta Amarilla', 'Cuesta Amarilla', 18.3466700, -95.2338900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98810, 'Ignacio Allende (Concepción)', 'Ignacio Allende (Concepcion)', 'Ignacio Allende (Concepcion),Ignacio Allende (Concepción)', 20.0105500, -97.6344800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98811, 'Ejido General Leandro Valle', 'Ejido General Leandro Valle', 'Ejido General Leandro Valle', 30.6216700, -115.9658300, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98812, 'El Llano del Compromiso', 'El Llano del Compromiso', 'El Llano del Compromiso', 19.2547200, -99.4791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98813, 'Arroyo Zapotillo', 'Arroyo Zapotillo', 'Arroyo Zapotillo', 18.0763900, -96.5441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98814, 'Tenexio', 'Tenexio', 'Tenexio', 21.3766700, -98.8794400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98815, 'La Esperanza [Granjas Familiares]', 'La Esperanza [Granjas Familiares]', 'La Esperanza [Granjas Familiares]', 32.4627800, -117.1050000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98816, 'Bautista Chico', 'Bautista Chico', 'Bautista Chico', 16.7997200, -92.7119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98817, 'Profresor Roberto Barrios', 'Profresor Roberto Barrios', 'Profresor Roberto Barrios', 17.3258300, -91.9263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98818, 'San José de Rancho Nuevo (Los Arrieros)', 'San Jose de Rancho Nuevo (Los Arrieros)', 'San Jose de Rancho Nuevo (Los Arrieros),San José de Rancho Nuevo (Los Arrieros)', 21.5963900, -101.0038900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98819, 'El Pedregal', 'El Pedregal', 'El Pedregal', 19.5108300, -101.4491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98820, 'Buenavista Tetela', 'Buenavista Tetela', 'Buenavista Tetela', 18.9196700, -98.1763200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98821, 'Barrio Nuevo de los Muertos', 'Barrio Nuevo de los Muertos', 'Barrio Nuevo de los Muertos', 16.8927800, -99.5438900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98822, 'Progreso (Campo 47)', 'Progreso (Campo 47)', 'Progreso (Campo 47)', 27.3402800, -110.0936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98823, 'Colonia el Mirador', 'Colonia el Mirador', 'Colonia el Mirador', 19.6716700, -99.3572200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98824, 'Soyata', 'Soyata', 'Soyata', 18.3688900, -95.2822200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98825, 'La Palmita (La Palmita de San Gabriel)', 'La Palmita (La Palmita de San Gabriel)', 'La Palmita (La Palmita de San Gabriel)', 20.4980600, -100.8780600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98826, 'Colonia Francisco Javier Mina', 'Colonia Francisco Javier Mina', 'Colonia Francisco Javier Mina', 20.9794400, -101.4163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98827, 'Cupuán del Río', 'Cupuan del Rio', 'Cupuan del Rio,Cupuán del Río', 18.7780600, -102.1877800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98828, 'Tierra Blanca', 'Tierra Blanca', 'Tierra Blanca', 20.8750000, -97.4600000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98829, 'Colonia Miguel Hidalgo', 'Colonia Miguel Hidalgo', 'Colonia Miguel Hidalgo', 19.7858300, -101.1013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98830, 'Ignacio Bastida (Santa Catarina Tlayca)', 'Ignacio Bastida (Santa Catarina Tlayca)', 'Ignacio Bastida (Santa Catarina Tlayca)', 18.9402800, -99.0144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98831, 'Santiago Ixtaltepec', 'Santiago Ixtaltepec', 'Santiago Ixtaltepec', 16.6883300, -94.9058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98832, 'San Francisco Javier', 'San Francisco Javier', 'San Francisco Javier', 17.0286100, -96.7775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98833, 'Rincón del Porvenir', 'Rincon del Porvenir', 'Rincon del Porvenir,Rincón del Porvenir', 22.3230600, -101.1763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98834, 'El Escribano', 'El Escribano', 'El Escribano', 18.4102800, -93.2216700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98835, 'Matacapan', 'Matacapan', 'Matacapan', 18.4347200, -95.1658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98836, 'Ixcuinatoyac', 'Ixcuinatoyac', 'Ixcuinatoyac', 17.3694400, -98.3425000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98837, 'Los Achotes', 'Los Achotes', 'Los Achotes', 17.6005600, -101.4175000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98838, 'Pochálcatl', 'Pochalcatl', 'Pochalcatl,Pochálcatl', 20.0029500, -97.8540800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98839, 'Zolonquiapa', 'Zolonquiapa', 'Zolonquiapa', 18.5761100, -98.5272200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98840, 'Hermenegildo Galeana', 'Hermenegildo Galeana', 'Hermenegildo Galeana', 15.5527800, -93.0069400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98841, 'Octeyuco Dos Mil', 'Octeyuco Dos Mil', 'Octeyuco Dos Mil', 19.9633300, -99.5880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98842, 'Santa Ana de Guerrero (El Cascabel)', 'Santa Ana de Guerrero (El Cascabel)', 'Santa Ana de Guerrero (El Cascabel)', 19.2763900, -100.4413900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98843, 'Arena 6ta. Sección (La Bolsa)', 'Arena 6ta. Seccion (La Bolsa)', 'Arena 6ta. Seccion (La Bolsa),Arena 6ta. Sección (La Bolsa)', 18.1621800, -93.3953900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98844, 'Nuevo Cereso Regional de Altamira', 'Nuevo Cereso Regional de Altamira', 'Nuevo Cereso Regional de Altamira', 22.4605600, -98.0083300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98845, 'El Ámbar', 'El Ambar', 'El Ambar,El Ámbar', 17.0250000, -92.8341700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98846, 'Fraccionamiento Paraíso Real', 'Fraccionamiento Paraiso Real', 'Fraccionamiento Paraiso Real,Fraccionamiento Paraíso Real', 21.1125000, -101.5808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98847, 'El Canario', 'El Canario', 'El Canario', 20.1569400, -101.3355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98848, 'San Miguel Amazcala', 'San Miguel Amazcala', 'San Miguel Amazcala', 20.7505600, -100.2355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98849, 'Morelia (Victórico Rodolfo Grajales)', 'Morelia (Victorico Rodolfo Grajales)', 'Morelia (Victorico Rodolfo Grajales),Morelia (Victórico Rodolfo Grajales)', 16.7230600, -91.9677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98850, 'Reforma y Planada', 'Reforma y Planada', 'Reforma y Planada', 17.3869400, -92.8658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98851, 'El Carmen', 'El Carmen', 'El Carmen', 19.2416700, -97.2011100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98852, 'Boquiapa', 'Boquiapa', 'Boquiapa', 18.1611100, -93.1375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98853, 'Santa Isabel', 'Santa Isabel', 'Santa Isabel', 20.1922200, -97.5291700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98854, 'Colonia de Guadalupe', 'Colonia de Guadalupe', 'Colonia de Guadalupe', 19.8008300, -100.9155600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98855, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 22.1633300, -101.0700000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98856, 'Jagüey Blanco', 'Jagueey Blanco', 'Jagueey Blanco,Jagüey Blanco', 20.2763900, -99.1522200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98857, 'Fraccionamiento Colinas Universidad', 'Fraccionamiento Colinas Universidad', 'Fraccionamiento Colinas Universidad', 20.0183300, -102.7369400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98858, 'Estrella de Belén', 'Estrella de Belen', 'Estrella de Belen,Estrella de Belén', 17.3872200, -91.9586100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98859, 'Jerusalén', 'Jerusalen', 'Jerusalen,Jerusalén', 17.3680600, -92.0608300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98860, 'Lázaro Cárdenas', 'Lazaro Cardenas', 'Lazaro Cardenas,Lázaro Cárdenas', 17.1978800, -92.3810700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98861, 'Gambino', 'Gambino', 'Gambino', 25.6516700, -108.3863900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98862, 'Los Caños', 'Los Canos', 'Los Canos,Los Caños', 21.7816700, -102.4675000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98863, 'Ventoquipa', 'Ventoquipa', 'Ventoquipa', 20.0336100, -98.3377800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98864, 'Colonia Independencia', 'Colonia Independencia', 'Colonia Independencia', 19.6155600, -100.3238900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98865, 'Fraccionamiento los Álamos', 'Fraccionamiento los Alamos', 'Fraccionamiento los Alamos,Fraccionamiento los Álamos', 18.9238900, -96.9752800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98866, 'La Isla (Kilómetro 10)', 'La Isla (Kilometro 10)', 'La Isla (Kilometro 10),La Isla (Kilómetro 10)', 20.6080600, -97.5013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98867, 'Chipahuatlán', 'Chipahuatlan', 'Chipahuatlan,Chipahuatlán', 20.0611100, -97.6886100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98868, 'Río Seco 2da. Sección (Santiaguito)', 'Rio Seco 2da. Seccion (Santiaguito)', 'Rio Seco 2da. Seccion (Santiaguito),Río Seco 2da. Sección (Santiaguito)', 18.1375000, -93.2758300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98869, 'San Cristóbal Chacón', 'San Cristobal Chacon', 'San Cristobal Chacon,San Cristóbal Chacón', 20.0802800, -98.7327800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98870, 'El Ojuelo', 'El Ojuelo', 'El Ojuelo', 21.4016700, -101.8375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98871, 'Las Mercedes [Agropecuaria]', 'Las Mercedes [Agropecuaria]', 'Las Mercedes [Agropecuaria]', 29.3638900, -110.9516700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98872, 'Loma Bonita', 'Loma Bonita', 'Loma Bonita', 19.2633300, -99.4472200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98873, 'Ex-Hacienda de Guadalupe', 'Ex-Hacienda de Guadalupe', 'Ex-Hacienda de Guadalupe', 19.7841700, -101.2147200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98874, 'Colinas del Sol', 'Colinas del Sol', 'Colinas del Sol', 32.4658300, -117.0369400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98875, 'El Barrido', 'El Barrido', 'El Barrido', 20.4502800, -99.1908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98876, 'Barrio de San Miguel', 'Barrio de San Miguel', 'Barrio de San Miguel', 18.9313900, -97.1250000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98877, 'Nigromante', 'Nigromante', 'Nigromante', 20.9619400, -100.7802800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98878, 'Colonia el Pirame', 'Colonia el Pirame', 'Colonia el Pirame', 19.2408300, -99.4719400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98879, 'La Soledad', 'La Soledad', 'La Soledad', 19.5211100, -100.4833300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98880, 'San Juan Tezongo', 'San Juan Tezongo', 'San Juan Tezongo', 19.8447200, -97.3638900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98881, 'Chimhucum', 'Chimhucum', 'Chimhucum', 16.8900000, -92.5313900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98882, 'Sierra de Agua', 'Sierra de Agua', 'Sierra de Agua', 18.7502800, -97.2416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98883, 'El Triunfo 1ra. Sección (Cardona)', 'El Triunfo 1ra. Seccion (Cardona)', 'El Triunfo 1ra. Seccion (Cardona),El Triunfo 1ra. Sección (Cardona)', 17.6077800, -93.2330600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98884, 'Estación de San Francisco', 'Estacion de San Francisco', 'Estacion de San Francisco,Estación de San Francisco', 21.0372200, -101.8247200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98885, 'Chimalpa Viejo', 'Chimalpa Viejo', 'Chimalpa Viejo', 19.4495600, -99.3443500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98886, 'Pechucalco', 'Pechucalco', 'Pechucalco', 18.0936100, -93.1661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98887, 'San José del Caliche (El Caliche)', 'San Jose del Caliche (El Caliche)', 'San Jose del Caliche (El Caliche),San José del Caliche (El Caliche)', 21.1252800, -101.9300000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98888, 'Colonia Rincón Villa del Valle', 'Colonia Rincon Villa del Valle', 'Colonia Rincon Villa del Valle,Colonia Rincón Villa del Valle', 19.2096600, -100.1191700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98889, 'Arroyo Palenque', 'Arroyo Palenque', 'Arroyo Palenque', 17.3916700, -92.1044400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98890, 'Aurora Ermita', 'Aurora Ermita', 'Aurora Ermita', 17.2358300, -92.8738900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98891, 'Coyahualco', 'Coyahualco', 'Coyahualco', 17.7413900, -98.5666700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98892, 'Cantinela', 'Cantinela', 'Cantinela', 20.4577800, -99.2102800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98893, 'Los Naranjos Esquipulas', 'Los Naranjos Esquipulas', 'Los Naranjos Esquipulas', 15.9816700, -96.4588900, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98894, 'Las Golondrinas [Fraccionamiento]', 'Las Golondrinas [Fraccionamiento]', 'Las Golondrinas [Fraccionamiento]', 22.1052800, -103.2541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98895, 'Colonia la Central', 'Colonia la Central', 'Colonia la Central', 18.0866600, -96.5161900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98896, 'Congregación Reforma', 'Congregacion Reforma', 'Congregacion Reforma,Congregación Reforma', 14.7818600, -92.3133600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98897, 'Los Naranjos', 'Los Naranjos', 'Los Naranjos', 18.3311100, -95.2416700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98898, 'Turuachi', 'Turuachi', 'Turuachi', 26.1313900, -106.7041700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98899, 'Paseos de la Pradera', 'Paseos de la Pradera', 'Paseos de la Pradera', 19.8911100, -99.2380600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98900, 'Xiloxochico de Rafael Ávila Camacho', 'Xiloxochico de Rafael Avila Camacho', 'Xiloxochico de Rafael Avila Camacho,Xiloxochico de Rafael Ávila Camacho', 20.0458300, -97.4908300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98901, 'Cerrito de Jaral', 'Cerrito de Jaral', 'Cerrito de Jaral', 22.2236100, -101.0625000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98902, 'San Simón', 'San Simon', 'San Simon,San Simón', 18.2377800, -93.0341700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98903, 'El Cuitzillo Grande', 'El Cuitzillo Grande', 'El Cuitzillo Grande', 19.7797200, -101.1169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98904, 'Nuevo Xcán', 'Nuevo Xcan', 'Nuevo Xcan,Nuevo Xcán', 20.8691700, -87.6030600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98905, 'La Albarrada (San Francisco la Albarrada)', 'La Albarrada (San Francisco la Albarrada)', 'La Albarrada (San Francisco la Albarrada)', 19.0675000, -100.0752800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98906, 'Los Garcías', 'Los Garcias', 'Los Garcias,Los Garcías', 18.8033300, -97.3941700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98907, 'Las Pilas', 'Las Pilas', 'Las Pilas', 22.8400000, -102.6127800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98908, 'Montaña Monarca (Punta Altozano)', 'Montana Monarca (Punta Altozano)', 'Montana Monarca (Punta Altozano),Montaña Monarca (Punta Altozano)', 19.6605600, -101.1655600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98909, 'La Concepción (La Concha)', 'La Concepcion (La Concha)', 'La Concepcion (La Concha),La Concepción (La Concha)', 18.7677800, -99.6925000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98910, 'General Juan José Baz (San José del Corral)', 'General Juan Jose Baz (San Jose del Corral)', 'General Juan Jose Baz (San Jose del Corral),General Juan José Baz (San José del Corral)', 18.8216700, -96.8180600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98911, 'Álvaro Obregón', 'Alvaro Obregon', 'Alvaro Obregon,Álvaro Obregón', 16.8436100, -93.1927800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98912, 'Chulum Cárdenas', 'Chulum Cardenas', 'Chulum Cardenas,Chulum Cárdenas', 17.3841700, -92.5738900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98913, 'Santa Ana', 'Santa Ana', 'Santa Ana', 20.3730600, -101.1125000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98914, 'San Isidro', 'San Isidro', 'San Isidro', 19.7680600, -100.2036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98915, 'Caxitepec', 'Caxitepec', 'Caxitepec', 17.2944900, -98.9674100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98916, 'Betania', 'Betania', 'Betania', 18.2800300, -93.3208100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98917, 'Octavio Paz', 'Octavio Paz', 'Octavio Paz', 14.8577800, -92.2638900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98918, 'Estación la Piedad', 'Estacion la Piedad', 'Estacion la Piedad,Estación la Piedad', 20.3675000, -101.9980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98919, 'Santa Cruz Otlatla', 'Santa Cruz Otlatla', 'Santa Cruz Otlatla', 19.3722200, -98.6225000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98920, 'Agua Señora', 'Agua Senora', 'Agua Senora,Agua Señora', 22.2375000, -101.0422200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98921, 'Ejido la Piña (Maromilla)', 'Ejido la Pina (Maromilla)', 'Ejido la Pina (Maromilla),Ejido la Piña (Maromilla)', 19.0286100, -96.7836100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98922, 'Ahuexotitlán', 'Ahuexotitlan', 'Ahuexotitlan,Ahuexotitlán', 17.5284900, -99.2439800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98923, 'Cerro Quemado', 'Cerro Quemado', 'Cerro Quemado', 18.1541700, -96.5750000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98924, 'El Bajío', 'El Bajio', 'El Bajio,El Bajío', 17.9817300, -92.7822900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98925, 'Tentic', 'Tentic', 'Tentic', 16.8633300, -92.6822200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98926, 'Doxteje Centro', 'Doxteje Centro', 'Doxteje Centro', 19.9752800, -99.9547200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98927, 'Sección del Cerrito', 'Seccion del Cerrito', 'Seccion del Cerrito,Sección del Cerrito', 19.5588900, -99.6783300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98928, 'General Lauro G. Caloca (El Rascón)', 'General Lauro G. Caloca (El Rascon)', 'General Lauro G. Caloca (El Rascon),General Lauro G. Caloca (El Rascón)', 22.3780600, -102.0575000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98929, 'Tierras Coloradas (San Pedro)', 'Tierras Coloradas (San Pedro)', 'Tierras Coloradas (San Pedro)', 19.7188900, -100.6463900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98930, 'Emiliano Zapata (Casahuates)', 'Emiliano Zapata (Casahuates)', 'Emiliano Zapata (Casahuates)', 18.9305600, -98.9588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98931, 'Lacapan Camallagne', 'Lacapan Camallagne', 'Lacapan Camallagne', 20.1286200, -97.6534300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98932, 'Jiquilpan (Estación Bonanza)', 'Jiquilpan (Estacion Bonanza)', 'Jiquilpan (Estacion Bonanza),Jiquilpan (Estación Bonanza)', 15.3419400, -92.7475000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98933, 'Nuevo Naranjo', 'Nuevo Naranjo', 'Nuevo Naranjo', 17.1544400, -93.4333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98934, 'Rancho Viejo', 'Rancho Viejo', 'Rancho Viejo', 16.8650000, -99.2894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98935, 'San Pedro Denxhi Centro', 'San Pedro Denxhi Centro', 'San Pedro Denxhi Centro', 20.2502600, -99.9673100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98936, 'Valle de Juárez', 'Valle de Juarez', 'Valle de Juarez,Valle de Juárez', 25.6377800, -100.1583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98937, 'Nexticapan', 'Nexticapan', 'Nexticapan', 19.8272200, -97.5541700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98938, 'Colonia Padre Hidalgo', 'Colonia Padre Hidalgo', 'Colonia Padre Hidalgo', 21.1705600, -100.9355600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98939, 'San Antonio de los Tepetates', 'San Antonio de los Tepetates', 'San Antonio de los Tepetates', 21.0447200, -101.6761100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98940, 'San Felipe Tílpam', 'San Felipe Tilpam', 'San Felipe Tilpam,San Felipe Tílpam', 18.1888900, -96.5863900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98941, 'San Félix Rijo', 'San Felix Rijo', 'San Felix Rijo,San Félix Rijo', 18.6202800, -98.5502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98942, 'Barranca de Otates (Barranca de Otatán)', 'Barranca de Otates (Barranca de Otatan)', 'Barranca de Otates (Barranca de Otatan),Barranca de Otates (Barranca de Otatán)', 20.2680600, -103.6647200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98943, 'La Planada (El Arenal)', 'La Planada (El Arenal)', 'La Planada (El Arenal)', 19.3333300, -99.6769400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98944, 'San Felipe Sultepec', 'San Felipe Sultepec', 'San Felipe Sultepec', 19.5908300, -98.6152800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98945, 'Los Benitos', 'Los Benitos', 'Los Benitos', 20.6850000, -99.9561100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98946, 'Las Trancas', 'Las Trancas', 'Las Trancas', 19.5044400, -96.8644400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98947, 'Ojite Rancho Nuevo', 'Ojite Rancho Nuevo', 'Ojite Rancho Nuevo', 20.9694400, -97.5280600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98948, 'Santa Fe y la Mar', 'Santa Fe y la Mar', 'Santa Fe y la Mar', 17.7661100, -96.3161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98949, 'De Parral', 'De Parral', 'De Parral', 20.4561100, -101.0077800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98950, 'Fraccionamiento Villas de Guanajuato', 'Fraccionamiento Villas de Guanajuato', 'Fraccionamiento Villas de Guanajuato', 20.9602800, -101.2980600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98951, 'Barrio el Boncho', 'Barrio el Boncho', 'Barrio el Boncho', 19.4261100, -100.1063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98952, 'Miguel Utrilla (Los Chorros)', 'Miguel Utrilla (Los Chorros)', 'Miguel Utrilla (Los Chorros)', 16.9427800, -92.4797200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98953, 'Ojo de Agua de Morán', 'Ojo de Agua de Moran', 'Ojo de Agua de Moran,Ojo de Agua de Morán', 20.5947200, -102.5297200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98954, 'El Bellote (Miguel de la Madrid)', 'El Bellote (Miguel de la Madrid)', 'El Bellote (Miguel de la Madrid)', 18.4252800, -93.1508300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98955, 'Jomanichim', 'Jomanichim', 'Jomanichim', 16.9005600, -92.4722200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98956, 'Tazaquil', 'Tazaquil', 'Tazaquil', 21.4911100, -98.9400000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98957, 'Los Pozos', 'Los Pozos', 'Los Pozos', 23.0094400, -106.1525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98958, 'San José Yashitinín', 'San Jose Yashitinin', 'San Jose Yashitinin,San José Yashitinín', 16.6547200, -92.4450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98959, 'Zapote de Palomas', 'Zapote de Palomas', 'Zapote de Palomas', 20.5844400, -101.1150000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98960, 'Llano de Agua', 'Llano de Agua', 'Llano de Agua', 18.1061100, -96.8108300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98961, 'Luis Espinoza', 'Luis Espinoza', 'Luis Espinoza', 17.0316700, -93.0269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98962, 'Arvenza Uno', 'Arvenza Uno', 'Arvenza Uno', 16.7797200, -92.7202800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98963, 'Colonia 3 de Mayo', 'Colonia 3 de Mayo', 'Colonia 3 de Mayo', 18.8272600, -99.6930400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98964, 'San Miguel Aguacomulican', 'San Miguel Aguacomulican', 'San Miguel Aguacomulican', 18.8222200, -98.5505600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98965, 'Cuauhtamazaco', 'Cuauhtamazaco', 'Cuauhtamazaco', 20.0250000, -97.4872200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98966, 'Tzinil', 'Tzinil', 'Tzinil', 16.2577800, -92.3222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98967, 'Fraccionamiento Privadas del Sol', 'Fraccionamiento Privadas del Sol', 'Fraccionamiento Privadas del Sol', 19.7522200, -101.1913900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98968, 'Gregorio Méndez', 'Gregorio Mendez', 'Gregorio Mendez,Gregorio Méndez', 18.1963900, -93.1022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98969, 'Ocotequila', 'Ocotequila', 'Ocotequila', 17.4494400, -98.6775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98970, 'Santa María Xigui', 'Santa Maria Xigui', 'Santa Maria Xigui,Santa María Xigui', 20.4611100, -99.3450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98971, 'El Salitre', 'El Salitre', 'El Salitre', 18.6758300, -98.9580600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98972, 'Santa María Zapotitlán', 'Santa Maria Zapotitlan', 'Santa Maria Zapotitlan,Santa María Zapotitlán', 16.1280600, -95.8519400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98973, 'General Alatriste (San Joaquín)', 'General Alatriste (San Joaquin)', 'General Alatriste (San Joaquin),General Alatriste (San Joaquín)', 18.8402800, -96.7936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98974, 'Constitución', 'Constitucion', 'Constitucion,Constitución', 17.0755600, -92.5241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98975, 'Jolsibaquil', 'Jolsibaquil', 'Jolsibaquil', 17.2597200, -92.4816700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98976, 'Residencial Arboledas', 'Residencial Arboledas', 'Residencial Arboledas', 20.0644400, -99.3016700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98977, 'Paseos del Valle [Fraccionamiento]', 'Paseos del Valle [Fraccionamiento]', 'Paseos del Valle [Fraccionamiento]', 20.5222200, -103.3333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98978, 'Concepción Caro', 'Concepcion Caro', 'Concepcion Caro,Concepción Caro', 19.7713900, -99.9091700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98979, 'San Antonio el Llanito', 'San Antonio el Llanito', 'San Antonio el Llanito', 19.2775000, -99.4950000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98980, 'La Higuerilla (Los Lirios)', 'La Higuerilla (Los Lirios)', 'La Higuerilla (Los Lirios)', 19.9225000, -100.2763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98981, 'Chiquinival', 'Chiquinival', 'Chiquinival', 16.9911100, -91.9602800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98982, 'Santiago Centro', 'Santiago Centro', 'Santiago Centro', 21.2052800, -98.8636100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98983, 'Guadalupe Calderón', 'Guadalupe Calderon', 'Guadalupe Calderon,Guadalupe Calderón', 18.9661100, -97.8583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98984, 'J. Jesús González Ortega (San Mateo)', 'J. Jesus Gonzalez Ortega (San Mateo)', 'J. Jesus Gonzalez Ortega (San Mateo),J. Jesús González Ortega (San Mateo)', 22.8872200, -103.4852800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98985, 'Zacate Colorado Segundo (Fraternidad)', 'Zacate Colorado Segundo (Fraternidad)', 'Zacate Colorado Segundo (Fraternidad)', 18.6833300, -95.9711100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98986, 'Vallejo (Porvenir Vallejo)', 'Vallejo (Porvenir Vallejo)', 'Vallejo (Porvenir Vallejo)', 25.8827800, -109.0736100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98987, 'Los Sauces', 'Los Sauces', 'Los Sauces', 18.0333500, -92.9169300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98988, 'Los Liros', 'Los Liros', 'Los Liros', 16.7397200, -98.2172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98989, 'Nexpan', 'Nexpan', 'Nexpan', 19.8838900, -97.4233300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98990, 'Ahuehueyo Primero Centro', 'Ahuehueyo Primero Centro', 'Ahuehueyo Primero Centro', 21.3450000, -98.8372200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98991, 'Barrancas y Amate 3ra. Sección', 'Barrancas y Amate 3ra. Seccion', 'Barrancas y Amate 3ra. Seccion,Barrancas y Amate 3ra. Sección', 17.9710000, -92.7617300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98992, 'Francisco Villa', 'Francisco Villa', 'Francisco Villa', 19.8750000, -100.9358300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98993, 'El Progreso', 'El Progreso', 'El Progreso', 20.1141700, -97.0144400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98994, 'El Cabi', 'El Cabi', 'El Cabi', 19.1898600, -98.8537100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98995, 'Agua Blanca', 'Agua Blanca', 'Agua Blanca', 19.2205600, -99.4705600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98996, 'Nicolás Blanco (San Pancho)', 'Nicolas Blanco (San Pancho)', 'Nicolas Blanco (San Pancho),Nicolás Blanco (San Pancho)', 19.3525000, -96.3383300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98997, 'Techichili', 'Techichili', 'Techichili', 19.1713900, -99.4222200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98998, 'Peña del Panal', 'Pena del Panal', 'Pena del Panal,Peña del Panal', 19.7733300, -101.1894400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(98999, 'El Pueblito (Garbanzal)', 'El Pueblito (Garbanzal)', 'El Pueblito (Garbanzal)', 19.5938900, -96.9241700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99000, 'La Corregidora', 'La Corregidora', 'La Corregidora', 21.4441700, -104.8122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99001, 'Bochojbo Alto', 'Bochojbo Alto', 'Bochojbo Alto', 16.7358300, -92.7169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99002, 'San José Manzanitos', 'San Jose Manzanitos', 'San Jose Manzanitos,San José Manzanitos', 19.2611100, -97.2147200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99003, 'Misija', 'Misija', 'Misija', 17.2661100, -92.3816700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99004, 'Colonia Fraccionamiento el Puente', 'Colonia Fraccionamiento el Puente', 'Colonia Fraccionamiento el Puente', 20.5236100, -100.8966700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99005, 'Lomas de Romero', 'Lomas de Romero', 'Lomas de Romero', 18.9144400, -97.7172200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99006, 'Lomas de Tlatelolco', 'Lomas de Tlatelolco', 'Lomas de Tlatelolco', 32.4830600, -116.8016700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99007, 'Ciudad Guzmán [CERESO]', 'Ciudad Guzman [CERESO]', 'Ciudad Guzman [CERESO],Ciudad Guzmán [CERESO]', 19.6519400, -103.5000000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99008, 'Kilómetro 40', 'Kilometro 40', 'Kilometro 40,Kilómetro 40', 17.0494400, -99.7705600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99009, 'Barrio de Guadalupe del Mezquitillo', 'Barrio de Guadalupe del Mezquitillo', 'Barrio de Guadalupe del Mezquitillo', 20.9441700, -101.8008300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99010, 'La Loma Cuexcontitlán', 'La Loma Cuexcontitlan', 'La Loma Cuexcontitlan,La Loma Cuexcontitlán', 19.3800000, -99.6488900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99011, 'El Plan', 'El Plan', 'El Plan', 19.3745200, -99.8004900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99012, 'El Metlapil', 'El Metlapil', 'El Metlapil', 16.8416700, -99.7488900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99013, 'El Cortijo', 'El Cortijo', 'El Cortijo', 20.4691700, -103.4219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99014, 'San Benito Encinal', 'San Benito Encinal', 'San Benito Encinal', 17.9872200, -95.9105600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99015, 'Guadalupe Victoria', 'Guadalupe Victoria', 'Guadalupe Victoria', 19.1044400, -97.6055600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99016, 'Santiago Tlacochcalco', 'Santiago Tlacochcalco', 'Santiago Tlacochcalco', 19.2686100, -98.2230600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99017, 'Metlac Hernández (Metlac Primero)', 'Metlac Hernandez (Metlac Primero)', 'Metlac Hernandez (Metlac Primero),Metlac Hernández (Metlac Primero)', 18.9775000, -97.1430600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99018, 'El Paraíso', 'El Paraiso', 'El Paraiso,El Paraíso', 17.2463900, -92.5569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99019, 'Ejido San Cristóbal', 'Ejido San Cristobal', 'Ejido San Cristobal,Ejido San Cristóbal', 19.5425000, -98.8941700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99020, 'El Roble', 'El Roble', 'El Roble', 20.0580600, -98.7583300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99021, 'Quetzalapa', 'Quetzalapa', 'Quetzalapa', 18.9405600, -99.5969400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99022, 'Concentración 5 de Febrero', 'Concentracion 5 de Febrero', 'Concentracion 5 de Febrero,Concentración 5 de Febrero', 25.8563900, -108.6294400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99023, 'Cerro del Murciélago', 'Cerro del Murcielago', 'Cerro del Murcielago,Cerro del Murciélago', 19.2819400, -99.7547200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99024, 'Tierra Negra', 'Tierra Negra', 'Tierra Negra', 20.2433300, -97.9566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99025, 'Melchor Ocampo', 'Melchor Ocampo', 'Melchor Ocampo', 19.8397200, -97.3066700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99026, 'Las Brisas', 'Las Brisas', 'Las Brisas', 30.9605600, -116.1644400, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99027, 'La Rinconada', 'La Rinconada', 'La Rinconada', 15.5933300, -92.2680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99028, 'San Marcos', 'San Marcos', 'San Marcos', 17.3469000, -99.0040900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99029, 'Tlatilpa', 'Tlatilpa', 'Tlatilpa', 18.7338900, -97.1441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99030, 'Nueva Frontera', 'Nueva Frontera', 'Nueva Frontera', 16.8880600, -99.8158300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99031, 'Colonia Doctor Gustavo Baz', 'Colonia Doctor Gustavo Baz', 'Colonia Doctor Gustavo Baz', 19.0130600, -99.3966700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99032, 'San Martín Mazateopan', 'San Martin Mazateopan', 'San Martin Mazateopan,San Martín Mazateopan', 18.4527800, -96.8161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99033, 'San Cristóbal Xochimilpa', 'San Cristobal Xochimilpa', 'San Cristobal Xochimilpa,San Cristóbal Xochimilpa', 20.0663900, -97.9075000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99034, 'San Isidro Palotal', 'San Isidro Palotal', 'San Isidro Palotal', 18.9441700, -96.9658300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99035, 'Sargento López 2da. Sección (El Chuzo)', 'Sargento Lopez 2da. Seccion (El Chuzo)', 'Sargento Lopez 2da. Seccion (El Chuzo),Sargento López 2da. Sección (El Chuzo)', 18.1995300, -93.2923500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99036, 'La Estancia Sector Uno (La Estancia)', 'La Estancia Sector Uno (La Estancia)', 'La Estancia Sector Uno (La Estancia)', 19.8705600, -99.7916700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99037, 'El Colorado', 'El Colorado', 'El Colorado', 20.2152800, -99.0022200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99038, 'Unidad Grajales INFONAVIT', 'Unidad Grajales INFONAVIT', 'Unidad Grajales INFONAVIT', 19.2412600, -97.8106800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99039, 'El Tintal', 'El Tintal', 'El Tintal', 20.8919400, -87.4661100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99040, 'Los Pinos', 'Los Pinos', 'Los Pinos', 16.9208300, -92.1086100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99041, 'Loma de Yerbabuena', 'Loma de Yerbabuena', 'Loma de Yerbabuena', 21.0605600, -101.4494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99042, 'Tutepec', 'Tutepec', 'Tutepec', 16.9216700, -99.1563900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99043, 'José María Pino Suárez', 'Jose Maria Pino Suarez', 'Jose Maria Pino Suarez,José María Pino Suárez', 20.2472200, -99.4211100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99044, 'El Capulín (La Nueva Pochota)', 'El Capulin (La Nueva Pochota)', 'El Capulin (La Nueva Pochota),El Capulín (La Nueva Pochota)', 18.2297200, -96.2780600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99045, 'San José Buena Vista', 'San Jose Buena Vista', 'San Jose Buena Vista,San José Buena Vista', 18.4052800, -97.2683300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99046, 'Banco Nacional', 'Banco Nacional', 'Banco Nacional', 25.8713900, -103.3566700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99047, 'Rinconadas del Venado I', 'Rinconadas del Venado I', 'Rinconadas del Venado I', 20.0636100, -98.7633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99048, 'Rincón de Aguirre', 'Rincon de Aguirre', 'Rincon de Aguirre,Rincón de Aguirre', 18.8994700, -100.1365900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99049, 'Miravalle', 'Miravalle', 'Miravalle', 21.9725000, -102.3113900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99050, 'Acuaco', 'Acuaco', 'Acuaco', 19.7625000, -97.5644400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99051, 'La Presita Segundo Cuartel', 'La Presita Segundo Cuartel', 'La Presita Segundo Cuartel', 20.1627800, -99.8727800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99052, 'Progreso', 'Progreso', 'Progreso', 17.0452800, -97.5702800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99053, 'Monte Blanco', 'Monte Blanco', 'Monte Blanco', 20.3547200, -101.5275000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99054, 'Adjuntas del Río', 'Adjuntas del Rio', 'Adjuntas del Rio,Adjuntas del Río', 21.1166700, -100.8680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99055, 'Colonia los Cerritos', 'Colonia los Cerritos', 'Colonia los Cerritos', 18.9538900, -99.1925000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99056, 'San Juan Zapotitlán', 'San Juan Zapotitlan', 'San Juan Zapotitlan,San Juan Zapotitlán', 17.8052800, -96.6063900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99057, 'Santa Rosa Segundo', 'Santa Rosa Segundo', 'Santa Rosa Segundo', 19.9777800, -88.2625000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99058, 'Rincón de los Reyes', 'Rincon de los Reyes', 'Rincon de los Reyes,Rincón de los Reyes', 19.1944400, -97.1605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99059, 'La Soledad', 'La Soledad', 'La Soledad', 18.8100000, -97.7641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99060, 'Praderas del Potrero', 'Praderas del Potrero', 'Praderas del Potrero', 19.8847200, -99.2302800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99061, 'Corral de Piedra', 'Corral de Piedra', 'Corral de Piedra', 18.2452800, -96.3055600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99062, 'Zoyotla', 'Zoyotla', 'Zoyotla', 19.9277800, -97.6938900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99063, 'Santa Isabel [Fraccionamiento]', 'Santa Isabel [Fraccionamiento]', 'Santa Isabel [Fraccionamiento]', 22.0811100, -102.2677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99064, 'La Trinidad', 'La Trinidad', 'La Trinidad', 20.5633300, -100.7836100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99065, 'San Miguelito', 'San Miguelito', 'San Miguelito', 17.6358300, -101.4375000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99066, 'Rancho Alegre', 'Rancho Alegre', 'Rancho Alegre', 20.2072200, -97.6388900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99067, 'Ejido Netzahualcóyotl', 'Ejido Netzahualcoyotl', 'Ejido Netzahualcoyotl,Ejido Netzahualcóyotl', 32.6244400, -115.0622200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99239, 'Padang Mat Sirat', 'Padang Mat Sirat', 'Kampung Padang Masirat,Kampung Padang Mat Sirat,Kampung-Padang-Masirat,Padang Masirat,Padang Mat Sirat,Кампунг-Паданг-Масират', 6.3542300, 99.7340400, 'MY', '2016-03-27', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99240, 'Ayer Hangat', 'Ayer Hangat', 'Air Hangat,Ayer Hangat,Ehjr-Khangat,Kampong Ayer Hangat,Эйр-Хангат', 6.4206200, 99.8219900, 'MY', '2016-08-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99241, 'Kuah', 'Kuah', 'Kuah,Kuakh,Kuan,Kwah,LGK,Langkawi,Куах', 6.3264900, 99.8432000, 'MY', '2015-12-20', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99242, 'Jerantut', 'Jerantut', 'Jerantut', 3.9360000, 102.3626000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99243, 'Raub', 'Raub', 'Raub', 3.7899000, 101.8570000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99244, 'Batu Pahat', 'Batu Pahat', 'BP,Bandar Penggaram,Batu Pahat', 1.8548000, 102.9325000, 'MY', '2015-02-23', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99245, 'Parit Raja', 'Parit Raja', 'Parit Raja', 1.8681000, 103.1124000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99246, 'Pekan Nenas', 'Pekan Nenas', 'Pekan Nanas,Pekan Nenas', 1.5100000, 103.5141000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99247, 'Pontian Kechil', 'Pontian Kechil', 'Pontian,Pontian Kechil,Pontian Kecil', 1.4866000, 103.3896000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99248, 'Kampung Pasir Gudang Baru', 'Kampung Pasir Gudang Baru', 'Kampung Pasir Gudang,Kampung Pasir Gudang Baru', 1.4726000, 103.8780000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99249, 'Kota Tinggi', 'Kota Tinggi', 'Kota Tinggi,Kota Tuiggi', 1.7381000, 103.8999000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99250, 'Taman Senai', 'Taman Senai', 'Senai,Taman Senai,Сенаи', 1.6006000, 103.6419000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99251, 'Kulai', 'Kulai', 'Kulai,Kuli', 1.6561000, 103.6032000, 'MY', '2012-01-28', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99252, 'Skudai', 'Skudai', 'Kampong Skudai,Kangkar Skudai,Scudai,Sekudai,Skudai', 1.5374100, 103.6577900, 'MY', '2014-04-26', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99253, 'Johor Bahru', 'Johor Bahru', 'Baru,Bharu,Dzhokhor Bakhru,Dzhokhor-Baru,Dzohor Baru,Dzokhor Bakhru,Džohor Baru,JHB,Jahore Bahru,Johor,Johor Baharu,Johor Bahru,Johore,Johore Bahru,Johore Baru,Johore Bharu,Sin-san-su,Sîn-sân-sṳ,joholeubalu,johora baru,johorubaru,jokur paru,jwhr bhrw,jwhwr bhrw,xin shan,ya hor bah ru,Џохор Бахру,Джохор Бахру,Джохор-Бару,גוהור באהרו,جوهر بهرو,جوهور بهرو,جوھر بھرو,जोहोर बारू,ஜொகூர் பாரு,ยะโฮร์บาห์รู,ဂျဟိုးဘာရူးမြို့,ジョホールバル,新山,조호르바루', 1.4655000, 103.7578000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99254, 'Kluang', 'Kluang', 'Keluang,Kluang', 2.0304600, 103.3168900, 'MY', '2015-03-28', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99255, 'Yong Peng', 'Yong Peng', 'Yong Peng', 2.0136000, 103.0659000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99256, 'Mersing', 'Mersing', 'MEP,Mersing', 2.4312000, 103.8405000, 'MY', '2014-06-24', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99257, 'Segamat', 'Segamat', 'Segamat', 2.5148000, 102.8158000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99258, 'Tangkak', 'Tangkak', 'Tangkah,Tangkak', 2.2673000, 102.5453000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99259, 'Muar', 'Muar', 'Bandar Maharani,Muar,Muar town,ma po,Муар,麻坡', 2.0442000, 102.5689000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99260, 'Bakri', 'Bakri', 'Bakeri,Bakri,Bukit Bakri,Бакри', 2.0441000, 102.6527000, 'MY', '2013-10-05', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99261, 'Labis', 'Labis', 'Labis', 2.3850000, 103.0210000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99262, 'Chaah', 'Chaah', 'Caah,Chaah,Kangkar Chaah', 2.2490000, 103.0480000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99263, 'Kuala Selangor', 'Kuala Selangor', 'Kuala Selangor,Kuala-Selangor,Selangor,Куала-Селангор', 3.3500000, 101.2500000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99264, 'Batang Berjuntai', 'Batang Berjuntai', 'Batang Berjuntai,Bestari Jaya,Betang Berjuntai', 3.3833300, 101.4166700, 'MY', '2013-10-30', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99265, 'Batu Arang', 'Batu Arang', 'Arang,Batu Arang', 3.3166700, 101.4666700, 'MY', '2013-10-30', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99266, 'Shah Alam', 'Shah Alam', 'Sa-a-nam,Shah Alam,Shakh Alam,Shakh-Alam,Sâ-â-nàm,sa alam,saha alama,sha a nan,sha ya nan,shaہ ʿalm  mlayyshya,syaallam,Шах Алам,Шах-Алам,شاه عالم,شاہ عالم، ملائیشیا,शाह आलम,ஷா ஆலாம்,シャー・アラム,沙亞南,莎阿南,샤알람', 3.0850700, 101.5328100, 'MY', '2010-08-09', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99267, 'Klang', 'Klang', 'Kelang,Klang,Klangas,Klanq,keullang,killan,klang,klanj,kuran,Келанг,Кланг,كلانج,کلانگ,கிள்ளான்,クラン,클랑', 3.0333300, 101.4500000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99268, 'Cukai', 'Cukai', 'Chukai,Chukei,Cukai,Mokuan,Telor Mokuan', 4.2500000, 103.4166700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99269, 'Kuala Lipis', 'Kuala Lipis', 'Kuala Lipis', 4.1842000, 102.0468000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99270, 'Papar', 'Papar', 'Papar', 5.7333300, 115.9333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99271, 'Kota Kinabalu', 'Kota Kinabalu', 'BKI,Jesselton,Kinabalu,Kota Kinabalu,Kota-Kinabalu,kotakinaballu,kotakinabalu,kotakinabaru,kwta kynabalw,ya bi,Кота-Кинабалу,کوتا کینابالو,コタキナバル,亞庇,코타키나바루,코타키나발루', 5.9749000, 116.0724000, 'MY', '2017-07-24', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99272, 'Donggongon', 'Donggongon', '', 5.9070200, 116.1014600, 'MY', '2010-06-16', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99273, 'Putatan', 'Putatan', 'Kampong Putatan,Putatan Station', 5.9258000, 116.0609400, 'MY', '2010-06-16', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99274, 'Kinarut', 'Kinarut', 'Kinarut,Kinarut Station', 5.8231000, 116.0466000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99275, 'Ranau', 'Ranau', 'RNU,Ranau,lanau,ranau,ラナウ,라나우', 5.9538000, 116.6641000, 'MY', '2016-02-28', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99276, 'Semporna', 'Semporna', 'SMM,Semporna,Semporna Settlement,Sempurna,Simporan,Simporna,Семпорна', 4.4817800, 118.6111900, 'MY', '2012-12-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99277, 'Victoria', 'Victoria', 'Labuan,Victoria,Victoria Town,Viktorija,Виктория', 5.2766700, 115.2416700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99278, 'Beaufort', 'Beaufort', 'Beaufort', 5.3473000, 115.7455000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99279, 'Lahad Datu', 'Lahad Datu', 'LDU,Lahad Datu,Lahad Datu Town,lakat tattu,na du,rahadato~u,லகாட் டத்து,ラハダトゥ,拿笃', 5.0268000, 118.3270000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99280, 'Sandakan', 'Sandakan', 'Elopura,SDK,Samdakan,San-ta-kin,Sandakan,Sandakan Town,Sân-tá-kîn,cantakkan,san da kan,sandakan,shan da gen,sndakan,Сандакан,سانداكان,سانداکان,سنداکان,சண்டாக்கான்,ശാന്തകൻ,ซันดากัน,サンダカン,山打根,산다칸', 5.8402000, 118.1179000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99281, 'Keningau', 'Keningau', 'KGU,Kaningow,Kengingan,Keningau', 5.3378000, 116.1602000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99282, 'Tawau', 'Tawau', 'TWU,Tavau,Tawao,Tawau,dou hu,tavav,tawau,tawaw,Тавау,تاواو,தாவாவ்,タワウ,斗湖,타와우', 4.2448200, 117.8911500, 'MY', '2014-09-01', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99283, 'Paka', 'Paka', 'Kampong Paka,Packa,Pak,Paka,Пак', 4.6374000, 103.4368000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99284, 'Kertih', 'Kertih', 'KTE,Kerteh,Kertih,Kuala Kerteh', 4.5141000, 103.4483000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99285, 'Kulim', 'Kulim', 'Kulim', 5.3649900, 100.5617700, 'MY', '2012-01-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99286, 'Bagan Serai', 'Bagan Serai', 'Bagan Serai', 5.0108000, 100.5410100, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99287, 'Bedong', 'Bedong', 'Bedong,Bedung', 5.7274300, 100.5087600, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99288, 'Simpang Empat', 'Simpang Empat', 'Semanggol,Simpang Ampat,Simpang Empat', 4.9500000, 100.6333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99289, 'Taiping', 'Taiping', 'Bandar Taiping,TPG,Taipeng,Taiping,Taipingo,Tajpin,tai ping,taipin,taiping,taippin,Тайпин,தைப்பிங்,タイピン,太平,타이핑', 4.8500000, 100.7333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99290, 'Kuala Kangsar', 'Kuala Kangsar', 'Kangsar,Kuala Kangsa,Kuala Kangsar,jiang sha xian,kaw la kang sar,kolakancar,kuallakangsaleu,kwala kngsr,کوالا کنگسر,கோலாகங்சார்,กัวลากังซาร์,江沙縣,쿠알라캉사르', 4.7666700, 100.9333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99291, 'Ipoh', 'Ipoh', 'IPH,Ipo,Ipoh,Ipoha,Ipohas,Ipokh,Yi-po-su,Yî-pó-sṳ,aybwh,aypw,aypwh,ipo,ippo,xi poh,yi bao,Іпох,Ипо,Ипох,איפוה,ايبوه,ایپو,ایپوه,ஈப்போ,อีโปห์,အီပိုးမြို့,イポー,怡保,이포', 4.5841000, 101.0829000, 'MY', '2015-06-03', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99292, 'Gua Musang', 'Gua Musang', 'Gua Musang', 4.8823000, 101.9644000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99293, 'Kuala Terengganu', 'Kuala Terengganu', 'Bandar Kuala Terengganu,Kuala Terenganu,Kuala Terengganu,Kuala Trengganu,Kuala-Trenganu,Kuala-Trengganu,Kvala Terenganu,TGG,Trengganu,Tringano,Tringganu,gua la deng jia lou,kaw la trang kanu,kuallateuleng-ganu,kuaratorenganu,kwala trnghanw,kwala tyrnganw,Куала Теренгану,Куала Теренггану,Куала-Тренгану,Куала-Тренггану,كوالا ترنغانو,کوالا تیرنگانو,กัวลาตรังกานู,クアラトレンガヌ,瓜拉登嘉楼,쿠알라트렝가누', 5.3302000, 103.1408000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99294, 'Marang', 'Marang', 'Kuala Marang,Kualla Merang,Marang,Маранг', 5.2056000, 103.2059000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99295, 'Tampin', 'Tampin', 'Tampin', 2.4701000, 102.2302000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99296, 'Alor Gajah', 'Alor Gajah', 'Alor Gajah,Alor Gajeh,Alur Gajah,alor kaja,alwr gaja,ya luo ya ye,الور گاجا,அலோர் காஜா,亚罗牙也', 2.3804000, 102.2089000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99297, 'Kampung Ayer Keroh', 'Kampung Ayer Keroh', 'Air Keruh,Ayer Keroh,Kampung Ayer Keroh', 2.2654000, 102.2801000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99298, 'Sungai Udang', 'Sungai Udang', 'Sungai Udang', 2.2690000, 102.1427000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99299, 'Malacca', 'Malacca', 'Bandaraya Melaka,MKZ,Malaca,Malacca,Malacca Town,Malaka,Malakka,Melaka,ma liu jia,marakka,Малакка,マラッカ,马六甲', 2.1960000, 102.2405000, 'MY', '2015-06-23', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99300, 'Pelabuhan Klang', 'Pelabuhan Klang', 'Pelabohan Klang,Pelabuhan Kelang,Pelabuhan Kelang Selatan,Pelabuhan Klang,Port Kalang,Port Kelang,Port Klang,Port Sweetenham,Port Swettenham', 2.9995900, 101.3928700, 'MY', '2017-05-24', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99301, 'Banting', 'Banting', 'Banting', 2.8136000, 101.5018500, 'MY', '2014-04-06', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99302, 'Jenjarum', 'Jenjarum', 'Jenjarom,Jenjarum', 2.8724000, 101.4948400, 'MY', '2014-04-06', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99303, 'Semenyih', 'Semenyih', 'Semenyeh,Semenyih,Semeyih', 2.9516000, 101.8430000, 'MY', '2014-04-06', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99304, 'Seremban', 'Seremban', 'Fu-yung-su,Fû-yûng-sṳ,Gorad Serehmban,Seremban,cirampan,fu rong shi,sarembana,seuleumban,srem ban,srmban,surenban,Горад Серэмбан,Серембан,سرمبان,सरेंबान,சிரம்பான்,സിരമ്പാൻ,สเรมบัน,スレンバン,芙蓉市,스름반', 2.7297000, 101.9381000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99305, 'Port Dickson', 'Port Dickson', 'Arang Arang Anchorage,Arang-Arang,Port Dickson', 2.5371800, 101.8057100, 'MY', '2014-08-06', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99306, 'Sepang', 'Sepang', 'Sepang,Сепанг', 2.6931000, 101.7498000, 'MY', '2015-12-13', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99307, 'Bahau', 'Bahau', 'Bahau', 2.8079000, 102.4049000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99308, 'Kuala Pilah', 'Kuala Pilah', 'Kuala Lipis,Kuala Pilah', 2.7389000, 102.2487000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99309, 'Buloh Kasap', 'Buloh Kasap', 'Buloh Kasap,Buluh Kasap', 2.5536000, 102.7640000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99310, 'Kampung Tekek', 'Kampung Tekek', 'Kampung Tekek,Tekek,Текек', 2.8147000, 104.1592000, 'MY', '2013-05-30', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99311, 'Pekan', 'Pekan', 'Pekan,bei gen,pekkan,pkan,Пекан,پکان,பெக்கான்,ปกัน,北根', 3.4836000, 103.3996000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99312, 'Mentekab', 'Mentekab', 'Mentakab,Mentekab', 3.4854000, 102.3484000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99313, 'Temerluh', 'Temerluh', 'Temerloh,Temerluh', 3.4506000, 102.4176000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99314, 'Batu Feringgi', 'Batu Feringgi', 'Batu Feringgi,Batu Ferringhi', 5.4709000, 100.2452900, 'MY', '2016-10-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99315, 'Butterworth', 'Butterworth', 'BWH,Batervortas,Butterworth,bat te xrweirth,batawasu,batrwwrt,bei hai,beoteowoseu,kolappurai,باتروورت,கோலப்புறை,บัตเตอร์เวิร์ท,バターワース,北海,버터워스', 5.3991000, 100.3638200, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99316, 'Perai', 'Perai', 'Perai,Prai', 5.3833300, 100.3833300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99317, 'Bukit Mertajam', 'Bukit Mertajam', 'Bukit Mertajam', 5.3630100, 100.4667000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99318, 'Nibong Tebal', 'Nibong Tebal', 'Nibong Tebal,Nibong Tepal,Nibung Tebal', 5.1658600, 100.4779300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99319, 'Parit Buntar', 'Parit Buntar', 'Parit Buntar', 5.1267100, 100.4931600, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99320, 'Tasek Glugor', 'Tasek Glugor', 'Tasek Gelugor,Tasek Gelugur,Tasek Glugor', 5.4803200, 100.4984900, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99321, 'George Town', 'George Town', 'Dzhordzhtaun,Dzordz Taun,Dzordztauna,Dzordztaunas,Džordžtauna,Džordžtaunas,George Town,Georgetown,Gorgtauno,Khiau-chhu-su,Khiâu-chhṳ-sṳ,PEN,Penang,Pinang,Pinang George Town,cxrc thawn,jarj tavun,jarja ta''una,jojitaun,jrj tawn pnang,qiao zhi shi,Ĝorĝtaŭno,Џорџ Таун,Джорджтаун,גורג טאון,جارج ٹاؤن، پینانگ,جرج تاون پنانگ,जर्ज टाउन,ஜார்ஜ் டவுன்,ജോർജ്ജ് ടൗൺ,จอร์จทาวน์,ပီနန်မြို့,ჯორჯტაუნი,ジョージタウン,乔治市,喬治市,조지타운', 5.4112300, 100.3354300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99322, 'Kampung Bukit Tinggi, Bentong', 'Kampung Bukit Tinggi, Bentong', '', 3.3494400, 101.8263100, 'MY', '2015-04-02', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99323, 'Serendah', 'Serendah', 'Serendah', 3.3646000, 101.6041000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99324, 'Rawang', 'Rawang', 'Rawang', 3.3213000, 101.5767000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99325, 'Petaling Jaya', 'Petaling Jaya', 'Petaling Dzhaja,Petaling Jaya,Petaling-Dzhaja,ba da ling zai ye,bytalyngh jaya,petalin jeya,peutallingjaya,ptalyng jaya,pytalnyg jaya,Петалинг Джая,Петалинг-Джая,بيتالينغ جايا,پتالینگ جایا,پیتالنیگ جایا,பெடாலிங் ஜெயா,プタリン・ジャヤ,八打灵再也,프탈링자야', 3.1072600, 101.6067100, 'MY', '2012-02-19', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99326, 'Kuala Lumpur', 'Kuala Lumpur', 'Gizlungzpoh,Gorad Kuala-Lumpur,KUL,Kouala Loumpou,Kouala Loumpour,Kuala Lumpor,Kuala Lumpur,Kuala-Lumpur,Kuala-Lumpuro,Kualae-Lumpur,Kualalumpura,Kualalumpūra,Kvala Lumpuras,Kvala Lumpūras,Kúala Lúmpúr,ji long po,kaulalampur,kawlalampexr,kolalampur,ku''a lalampura,ku''ala lupura,ku''alalampura,ku''alalumpura,kuallalumpuleu,kuararunpuru,kuyalalamapura,kvalalampura,kwala lambwr,kwala lmpwr,kwalalampwr,kwalalmbwr,kwalalmpwr,kwalalwmpwr,kۇyalalۇmpۇr,Κουάλα Λουμπούρ,Горад Куала-Лумпур,Куалæ-Лумпур,Куала Лумпур,Куала-Лумпур,Կուալա Լումպուր,קואלה לומפור,كوالا لامبور,كوالالمبور,كۇئالالۇمپۇر,کوالا لمپور,کوالالامپور,کوالالمپور,کوالالومپور,कुआ लालम्पुर,कुआलालम्पुर,क्वालालंपूर,কুয়ালালামপুর,ਕੁਆਲਾ ਲੁੰਪੁਰ,କୁଆଲାଲୁମ୍ପୁର,கோலாலம்பூர்,ಕೌಲಾಲಂಪುರ್,കോലാലമ്പൂർ,กัวลาลัมเปอร์,ཁལ་ལུང་ཕུ།,ကွာလာလမ်ပူမြို့,კუალა-ლუმპური,ኩዋላ ሉምፑር,クアラルンプール,吉隆坡,쿠알라룸푸르', 3.1412000, 101.6865300, 'MY', '2015-06-03', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99327, 'Sabak Bernam', 'Sabak Bernam', 'Sabah,Sabak,Sabak Bernam,Sobak Bernam', 3.7698000, 100.9879000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99328, 'Sungai Besar', 'Sungai Besar', 'Kampong Sungei Besar,Sungai Besar', 3.6746000, 100.9867000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99329, 'Kuantan', 'Kuantan', 'KUA,Koan-tan-su,Kuala Kuantan,Kuala Kuatan,Kuantan,Kôan-tan-sṳ,guan dan,kuantan,kuvantan,kvantana,kwantan,kwn tan,Куантан,كوانتان,کوانتان,क्वांतान,குவாந்தான்,กวนตัน,クアンタン,关丹,쿠안탄', 3.8077000, 103.3260000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99330, 'Tanah Rata', 'Tanah Rata', 'Tana Rata,Tanah Rata,Тана Рата', 4.4636100, 101.3763000, 'MY', '2014-08-27', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99331, 'Batu Gajah', 'Batu Gajah', 'Batu Gaah,Batu Gajah', 4.4691600, 101.0410700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99332, 'Kampar', 'Kampar', 'Kampar', 4.3000000, 101.1500000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99333, 'Tapah Road', 'Tapah Road', 'Tapah Road', 4.1666700, 101.2000000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99334, 'Bidur', 'Bidur', 'Bidor,Bidur', 4.1166700, 101.2833300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99335, 'Lumut', 'Lumut', 'Lumut', 4.2323000, 100.6298000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99336, 'Teluk Intan', 'Teluk Intan', 'Telok Anson,Teluk Anson,Teluk Intan,an shun,an shun shi,teluk intan,terokkuintan,teullug-intan,தெலுக் இந்தான்,テロックインタン,安顺,安顺市,틀룩인탄', 4.0221900, 101.0208300, 'MY', '2017-05-24', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99337, 'Gurun', 'Gurun', 'Gurun,Kampung Gurun', 5.8171700, 100.4738100, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99338, 'Sungai Petani', 'Sungai Petani', 'Sungai Patani,Sungai Petani,Sungei Patani', 5.6470000, 100.4877200, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99339, 'Kepala Batas', 'Kepala Batas', 'Kapala Batas,Kepala Batas', 5.5170700, 100.4265000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99340, 'Ketereh', 'Ketereh', 'Ketereh', 5.9570100, 102.2481700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99341, 'Pulai Chondong', 'Pulai Chondong', 'Pulai Chondong,Pulai Chongdong,Pulai Condong', 5.8713300, 102.2317700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99342, 'Tanah Merah', 'Tanah Merah', 'Tanah Merah,Tanah Merak', 5.8000000, 102.1500000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99343, 'Kuching', 'Kuching', 'KCH,Kuching,Kucingas,Kučingas,gu jin,ku ching,kuchin,kuching,kucinga,kwchyng,kwtshyngh,qwzyng,Кучинг,קוצינג,كوتشينغ,کوچینگ,कुचिंग,กูชิง,クチン,古晉,쿠칭', 1.5500000, 110.3333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99344, 'Simanggang', 'Simanggang', 'Bandar Sri Aman,SGG,Simanggang,Simmangang,Simmanggang,Sri Aman', 1.2472200, 111.4527800, 'MY', '2013-03-09', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99345, 'Sarikei', 'Sarikei', 'Sarikei,Seriki,Siriki,salikei,사리케이', 2.1166700, 111.5166700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99346, 'Sibu', 'Sibu', 'Fort Brooke,SBW,Siboe,Sibu,shi wu,shibu,sibu,sybw,Сибу,سيبو,سیبو,シブ,詩巫,시부', 2.3000000, 111.8166700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99347, 'Kangar', 'Kangar', 'Kangar,Perlis,Poelit,Polit,jia yang,kang-aleu,kangr,kanjar,kankar,kngr,Кангар,كانجار,کانگر,کنگر,கங்கார்,加央,캉아르', 6.4414000, 100.1986200, 'MY', '2012-01-28', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99348, 'Kuala Perlis', 'Kuala Perlis', 'Kampong Kuala Perlis,Kampong Perlis,Kuala Perlis', 6.4000000, 100.1333300, 'MY', '2012-01-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99349, 'Jitra', 'Jitra', 'Jitra', 6.2681200, 100.4216700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99350, 'Kuala Kedah', 'Kuala Kedah', '', 6.1000000, 100.3000000, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99351, 'Alor Setar', 'Alor Setar', 'AOR,Alor Setar,Alor Setaras,Alor Star,Alor-Setar,Alor-Star,Alostar,Alur Setar,Saiburu,Thai,alloleuseutaleu,alor star,alwr star,alwr sytar,arosuta,xlxrstar,ya luo shi da,Алор Стар,Алор-Сетар,Алор-Стар,ألور ستار,الور ستار,الور سیتار,அலோர் ஸ்டார்,อลอร์สตาร์,アロースター,亚罗士打,亞羅士打,알로르스타르', 6.1210400, 100.3601400, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99352, 'Tumpat', 'Tumpat', 'Tumpat', 6.1977500, 102.1709800, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99353, 'Pasir Mas', 'Pasir Mas', 'Pasir Mas', 6.0493400, 102.1398700, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99354, 'Kota Bharu', 'Kota Bharu', 'Bharu,KBR,Khota Baharu,Khota Bahru,Ko-ta-hap-lu-su,Kota Baharu,Kota Bahru,Kota Baru,Kota Bharu,Kota-Baru,Kô-tá-ha̍p-lû-sṳ,ge da ba lu,kotabalu,kotabaru,kwta bharw,Кота Бару,Кота-Бару,كوتا بهارو,โกตาบารู,コタバル,哥打巴鲁,코타바루', 6.1332800, 102.2386000, 'MY', '2013-06-28', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99355, 'Kuala Besut', 'Kuala Besut', 'Kampung Kuala Besut,Kuala Besut,Kuala-Besut,Куала-Бесут', 5.8330300, 102.5551400, 'MY', '2016-03-25', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99356, 'Jertih', 'Jertih', 'Jerteh,Jertih', 5.7336000, 102.4897000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99357, 'Kudat', 'Kudat', 'KUD,Kudat', 6.8873200, 116.8236400, 'MY', '2015-08-15', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99358, 'Kota Belud', 'Kota Belud', 'Khota Balud,Kota Belud', 6.3510000, 116.4305000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99359, 'Kapit', 'Kapit', 'KPI,Kapit,Kapit Fort,Капит', 2.0166700, 112.9333300, 'MY', '2016-04-15', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99360, 'Bintulu', 'Bintulu', 'BTU,Bintulu,bintullu,byntwlw,min dou lu,Бинтулу,بينتولو,بینتولو,民都魯,民都鲁,빈툴루', 3.1666700, 113.0333300, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99361, 'Limbang', 'Limbang', 'LMN,Limbang', 4.7500000, 115.0000000, 'MY', '2012-05-05', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99362, 'Miri', 'Miri', 'Bandar Miri,MYY,Miri,mei li,mili,miri,myry,Мири,ميري,میری,മിറി,მირი,ミリ,美里,미리', 4.3992800, 113.9916300, 'MY', '2017-05-24', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99363, 'Ulu Tiram', 'Ulu Tiram', 'Ulu Tiram,Ulu Tiram Village', 1.6000000, 103.8166700, 'MY', '2010-08-09', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99364, 'Telaga Batu', 'Telaga Batu', 'Telaga Batu,Телага Бату', 5.4666700, 100.2333300, 'MY', '2016-03-10', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99365, 'Tanjung Tokong', 'Tanjung Tokong', 'Tanjong Tokong,Tanjung Tokong', 5.4606100, 100.3074200, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99366, 'Tanjung Sepat', 'Tanjung Sepat', 'Kampong Tanjong Sepat,Tanjong Sepat,Tanjung Sepat', 2.6579000, 101.5629000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99367, 'Sungai Pelek New Village', 'Sungai Pelek New Village', '', 2.6500000, 101.7000000, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99368, 'Pulau Sebang', 'Pulau Sebang', 'Pulau Sebang', 2.4550000, 102.2329000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99369, 'Permatang Kuching', 'Permatang Kuching', 'Permatang Kuching', 5.4633900, 100.3814400, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99370, 'Peringat', 'Peringat', '', 6.0333300, 102.2833300, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99371, 'Ladang Seri Kundang', 'Ladang Seri Kundang', 'Ladang Seri Kundang,Pengkalan Kundang', 3.2856000, 101.5190000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99372, 'Pantai Remis', 'Pantai Remis', 'Kampong Pantai Remis,Pantai Remis,Pantei Remis', 4.4557000, 100.6288000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99373, 'Kuang', 'Kuang', 'Kuang,Куанг', 3.2594000, 101.5541000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99374, 'Kuala Sungai Baru', 'Kuala Sungai Baru', 'Kuala Sungai Baharu,Kuala Sungai Baru', 2.3594000, 102.0353000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99375, 'Klebang Besar', 'Klebang Besar', 'Kelebang Besar,Klebang Besar', 2.2186000, 102.1995000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99376, 'Kelapa Sawit', 'Kelapa Sawit', 'Kelapa Sawit', 1.6698000, 103.5327000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99377, 'Kampung Tanjung Karang', 'Kampung Tanjung Karang', 'Kampung Tanjung Karang,Tanjong Karang', 3.4242000, 101.1849000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99378, 'Kampung Sungai Ara', 'Kampung Sungai Ara', 'Kampong Sungai Ara,Kampung Sungai Ara,Sungei Ara', 5.3269900, 100.2734800, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99379, 'Kampung Simpang Renggam', 'Kampung Simpang Renggam', 'Kampong Simpang Rengam,Kampung Simpang Renggam', 1.8278000, 103.3000000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99380, 'Kampong Pangkal Kalong', 'Kampong Pangkal Kalong', '', 5.9166700, 102.2166700, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99381, 'Kampong Masjid Tanah', 'Kampong Masjid Tanah', '', 2.3500000, 102.1166700, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99382, 'Kampong Kadok', 'Kampong Kadok', '', 6.0000000, 102.2500000, 'MY', '2006-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99383, 'Kampong Dungun', 'Kampong Dungun', 'Kampong Dungan,Kampong Dungun', 3.2166700, 101.3166700, 'MY', '2013-10-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99384, 'Kampung Bukit Baharu', 'Kampung Bukit Baharu', 'Kampong Bukit Baru,Kampung Bukit Baharu', 2.2152000, 102.2851000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99385, 'Kampung Batu Feringgi', 'Kampung Batu Feringgi', 'Batu-Ferringi,Kampong Batu Feringgi,Kampung Batu Feringgi,Бату-Ферринги', 5.4694800, 100.2444900, 'MY', '2016-03-25', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99386, 'Kampung Baru Subang', 'Kampung Baru Subang', '', 3.1500000, 101.5333300, 'MY', '2012-02-19', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99387, 'Kampung Baharu Nilai', 'Kampung Baharu Nilai', 'Kampong Baharu Nilai,Kampong Bahru Nilai,Kampong Nilai,Kampung Baharu Nilai,Kampung Bharu Nilai,Nilai', 2.8033000, 101.7972000, 'MY', '2014-04-06', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99388, 'Kampong Baharu Balakong', 'Kampong Baharu Balakong', 'Balakong,Kampong Baharu Balakong', 3.0333300, 101.7500000, 'MY', '2013-03-02', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99389, 'Kampung Ayer Molek', 'Kampung Ayer Molek', 'Kampong Ayer Molek,Kampung Ayer Molek', 2.2139000, 102.3278000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99390, 'Juru', 'Juru', 'Juru', 5.3120100, 100.4422900, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99391, 'Bukit Rambai', 'Bukit Rambai', 'Bukit Rambai', 2.2594000, 102.1838000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99392, 'Bentong Town', 'Bentong Town', '', 3.5222900, 101.9086600, 'MY', '2015-04-01', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99393, 'Bemban', 'Bemban', 'Bemban', 2.2684000, 102.3746000, 'MY', '2012-01-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99394, 'Batu Berendam', 'Batu Berendam', 'Batu Berendam,Berendam', 2.2487000, 102.2460000, 'MY', '2013-10-05', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99395, 'Bagan Pulau Ketam', 'Bagan Pulau Ketam', '', 3.0166700, 101.2666700, 'MY', '2016-10-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99396, 'Putrajaya', 'Putrajaya', '', 2.9352700, 101.6911200, 'MY', '2008-10-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99397, 'Kampung Kilim', 'Kampung Kilim', 'Kampung Kilim,Kilim', 6.4055000, 99.8502000, 'MY', '2016-08-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99398, 'Kampung Kok', 'Kampung Kok', 'Kampung Kok,Kampung-Kok,Pantai Kok,Pantaj-Kok,Кампунг-Кок,Пантай-Кок', 6.3675900, 99.6825200, 'MY', '2016-01-08', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99399, 'Kuala Teriang', 'Kuala Teriang', 'Kuala Periang,Kuala Teriang,Kuala-Teriang,Куала-Терианг', 6.3637700, 99.7153200, 'MY', '2016-08-29', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99400, 'Kampung Kuala Besut', 'Kampung Kuala Besut', 'Kampung Kuala Besut,Kuala-Besut,Куала-Бесут', 5.8329700, 102.5506100, 'MY', '2016-10-25', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99401, 'Kampung Lemal', 'Kampung Lemal', 'Kampung Lemal', 6.0302100, 102.1412600, 'MY', '2012-01-20', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99402, 'Bandar Labuan', 'Bandar Labuan', '', 5.2888300, 115.2692400, 'MY', '2010-06-17', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99403, 'Data Kakus', 'Data Kakus', '', 2.6546500, 113.6224900, 'MY', '2015-03-04', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99404, 'Subang Jaya', 'Subang Jaya', 'Subang Dzhaja,Subang Jaya,shu bang,shu bang zai ye,subangjaya,swbang jaya,swbangh jaya,Субанг Джая,سوبانغ جايا,سوبانگ جایا,スバン・ジャヤ,梳邦,梳邦再也,수방자야', 3.0438400, 101.5806200, 'MY', '2013-03-11', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99405, 'Taman Rajawali', 'Taman Rajawali', '', 5.8947700, 118.0457600, 'MY', '2014-03-05', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99406, 'Lidung Jelo', 'Lidung Jelo', '', 2.6484800, 114.7865300, 'MY', '2015-03-04', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99407, 'Long Ampan Aing or Abanang', 'Long Ampan Aing or Abanang', '', 2.6567100, 114.7367500, 'MY', '2015-02-16', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99408, 'Putra Heights', 'Putra Heights', '', 2.9936100, 101.5725500, 'MY', '2015-09-11', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99409, 'Pantai Cenang', 'Pantai Cenang', 'Pantai Cenang,Pantaj Chenang,Pantaj-Senang,Pantaj-Tengakh,Пантай Ченанг,Пантай-Сенанг,Пантай-Тенгах', 6.2936900, 99.7278600, 'MY', '2016-03-27', 135);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99068, 'Manzana Segunda', 'Manzana Segunda', 'Manzana Segunda', 19.5672200, -99.5938900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99069, 'La Palma (Las Palmas)', 'La Palma (Las Palmas)', 'La Palma (Las Palmas)', 19.7711100, -101.1408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99070, 'La Toma', 'La Toma', 'La Toma', 19.4527800, -97.1936100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99071, 'Ixtlahuaca', 'Ixtlahuaca', 'Ixtlahuaca', 19.8230900, -97.3349600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99072, 'Veracruz', 'Veracruz', 'Veracruz', 16.4041700, -91.9994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99073, 'El Olvera', 'El Olvera', 'El Olvera', 20.2700000, -99.0255600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99074, 'Paraje Trejo (El Chaparral)', 'Paraje Trejo (El Chaparral)', 'Paraje Trejo (El Chaparral)', 19.4055600, -99.3122200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99075, 'Ejido el Castillo', 'Ejido el Castillo', 'Ejido el Castillo', 19.4358300, -99.3058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99076, 'Tocoy', 'Tocoy', 'Tocoy', 21.6386100, -98.8708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99077, 'La Nueva Era', 'La Nueva Era', 'La Nueva Era', 17.6986100, -95.8083300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99078, 'Ocuiltzapoyo', 'Ocuiltzapoyo', 'Ocuiltzapoyo', 21.3244400, -98.7286100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99079, 'La Sala (La Caliente)', 'La Sala (La Caliente)', 'La Sala (La Caliente)', 20.2072200, -98.8725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99080, 'Joconoxtle (La Tuna)', 'Joconoxtle (La Tuna)', 'Joconoxtle (La Tuna)', 20.4522200, -102.6763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99081, 'Álvaro Obregón 2da. Sección (El Lechugal)', 'Alvaro Obregon 2da. Seccion (El Lechugal)', 'Alvaro Obregon 2da. Seccion (El Lechugal),Álvaro Obregón 2da. Sección (El Lechugal)', 18.3916700, -92.7880600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99082, 'La Herradura', 'La Herradura', 'La Herradura', 19.0400000, -99.5847200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99083, 'Guadalupe Morelos', 'Guadalupe Morelos', 'Guadalupe Morelos', 19.0255600, -97.8041700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99084, 'Santa Bárbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 20.4755600, -101.3494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99085, 'Tlatzala', 'Tlatzala', 'Tlatzala', 18.7286100, -97.1411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99086, 'Miguel Hidalgo', 'Miguel Hidalgo', 'Miguel Hidalgo', 17.9063900, -93.1175000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99087, 'La Mezquitera', 'La Mezquitera', 'La Mezquitera', 20.5583300, -103.1125000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99088, 'Unidad Habitacional Mariano Matamoros', 'Unidad Habitacional Mariano Matamoros', 'Unidad Habitacional Mariano Matamoros', 18.7475000, -98.8522200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99089, 'Manuel Edgardo Ávalos (San Isidro)', 'Manuel Edgardo Avalos (San Isidro)', 'Manuel Edgardo Avalos (San Isidro),Manuel Edgardo Ávalos (San Isidro)', 19.0677800, -97.3919400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99090, 'Tinajas 1ra. Sección', 'Tinajas 1ra. Seccion', 'Tinajas 1ra. Seccion,Tinajas 1ra. Sección', 14.7175000, -92.3286100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99091, 'El Ramal (Porvenir)', 'El Ramal (Porvenir)', 'El Ramal (Porvenir)', 15.8658300, -92.9455600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99092, 'Los Olivos', 'Los Olivos', 'Los Olivos', 19.2077800, -102.8619400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99093, 'Molino de San José', 'Molino de San Jose', 'Molino de San Jose,Molino de San José', 21.5708300, -101.2638900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99094, 'San José Independencia', 'San Jose Independencia', 'San Jose Independencia,San José Independencia', 18.7558300, -96.9450000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99095, 'Fraccionamiento del Valle', 'Fraccionamiento del Valle', 'Fraccionamiento del Valle', 31.9113900, -116.2605600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99096, 'Tierra Larga (Campo Nuevo)', 'Tierra Larga (Campo Nuevo)', 'Tierra Larga (Campo Nuevo)', 18.8644400, -98.9480600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99097, 'Ignacio Zaragoza 1ra. Sección', 'Ignacio Zaragoza 1ra. Seccion', 'Ignacio Zaragoza 1ra. Seccion,Ignacio Zaragoza 1ra. Sección', 18.3315700, -93.3350800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99098, '10 de Abril', '10 de Abril', '10 de Abril', 16.8291700, -99.7408300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99099, 'El Espinalillo', 'El Espinalillo', 'El Espinalillo', 16.9847200, -100.1269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99100, 'La Trinidad', 'La Trinidad', 'La Trinidad', 19.6805600, -99.1722200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99101, 'Santa Rosa (El Huizache)', 'Santa Rosa (El Huizache)', 'Santa Rosa (El Huizache)', 21.9350000, -102.0219400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99102, 'Hoya de Cintora (La Hoya de Arriba)', 'Hoya de Cintora (La Hoya de Arriba)', 'Hoya de Cintora (La Hoya de Arriba)', 20.3644400, -101.2083300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99103, 'El Recodo', 'El Recodo', 'El Recodo', 27.0772200, -109.5275000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99104, 'General Luis Felipe Domínguez Suárez', 'General Luis Felipe Dominguez Suarez', 'General Luis Felipe Dominguez Suarez,General Luis Felipe Domínguez Suárez', 17.6563900, -91.5366700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99105, 'Pugchén Mumuntic', 'Pugchen Mumuntic', 'Pugchen Mumuntic,Pugchén Mumuntic', 16.8638900, -92.8236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99106, 'Cantón Villaflor', 'Canton Villaflor', 'Canton Villaflor,Cantón Villaflor', 15.1142400, -92.3526100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99107, 'San Julio', 'San Julio', 'San Julio', 25.9363900, -103.4208300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99108, 'Coahuixtla', 'Coahuixtla', 'Coahuixtla', 18.5741700, -99.3700000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99109, 'El Camalote', 'El Camalote', 'El Camalote', 15.8725000, -96.6236100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99110, 'Yopi', 'Yopi', 'Yopi', 19.8266700, -97.3802800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99111, 'Tlacuilola', 'Tlacuilola', 'Tlacuilola', 21.2375000, -98.8680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99112, 'Rinconadas del Bosque', 'Rinconadas del Bosque', 'Rinconadas del Bosque', 20.0852800, -101.1983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99113, 'Atenguillo', 'Atenguillo', 'Atenguillo', 19.5636100, -98.8763900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99114, 'Santa Ana Chapitiro', 'Santa Ana Chapitiro', 'Santa Ana Chapitiro', 19.5261100, -101.6525000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99115, 'Loma Chapultepec', 'Loma Chapultepec', 'Loma Chapultepec', 18.1197200, -96.8391700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99116, 'Campo de Águila', 'Campo de Aguila', 'Campo de Aguila,Campo de Águila', 18.0675000, -94.9861100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99117, 'Buenos Aires (San Isidro)', 'Buenos Aires (San Isidro)', 'Buenos Aires (San Isidro)', 20.8402800, -97.6013900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99118, 'Jarillas', 'Jarillas', 'Jarillas', 22.2961100, -102.0633300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99119, 'Centro de Readaptación Social', 'Centro de Readaptacion Social', 'Centro de Readaptacion Social,Centro de Readaptación Social', 18.8380600, -96.9394400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99120, 'Manzana la Cofradía', 'Manzana la Cofradia', 'Manzana la Cofradia,Manzana la Cofradía', 19.5494400, -100.3558300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99121, 'Santiago Chilixtlahuaca', 'Santiago Chilixtlahuaca', 'Santiago Chilixtlahuaca', 17.9061100, -97.8952800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99122, 'Texocoyohuac', 'Texocoyohuac', 'Texocoyohuac', 19.7777800, -97.5902800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99123, 'Llano de las Flores (Barrio del Hueso)', 'Llano de las Flores (Barrio del Hueso)', 'Llano de las Flores (Barrio del Hueso)', 19.4358300, -99.3225000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99124, 'Colonia el Mirador (Llano del Ejido)', 'Colonia el Mirador (Llano del Ejido)', 'Colonia el Mirador (Llano del Ejido)', 19.6758300, -100.5536100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99125, 'San José Boxay', 'San Jose Boxay', 'San Jose Boxay,San José Boxay', 20.2623600, -99.1008500, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99126, 'Mariscal Subikuski', 'Mariscal Subikuski', 'Mariscal Subikuski', 17.3325000, -92.3808300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99127, 'Lodo Grande', 'Lodo Grande', 'Lodo Grande', 17.6097200, -99.2119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99128, 'Pintillo', 'Pintillo', 'Pintillo', 20.7966700, -100.4169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99129, 'Jesús Tepactepec', 'Jesus Tepactepec', 'Jesus Tepactepec,Jesús Tepactepec', 19.2291700, -98.3141700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99130, 'Fraccionamiento la Mezquitera', 'Fraccionamiento la Mezquitera', 'Fraccionamiento la Mezquitera', 21.0097200, -101.8347200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99131, 'Zacamulpa', 'Zacamulpa', 'Zacamulpa', 20.0058300, -99.2569400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99132, 'Cuartel la Mesa (El Asoleadero)', 'Cuartel la Mesa (El Asoleadero)', 'Cuartel la Mesa (El Asoleadero)', 19.5697200, -100.2869400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99133, 'Oxinam', 'Oxinam', 'Oxinam', 16.8630600, -92.5491700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99134, 'La Cañada', 'La Canada', 'La Canada,La Cañada', 17.0700000, -96.7780600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99135, 'El Recodo de San José Axalco', 'El Recodo de San Jose Axalco', 'El Recodo de San Jose Axalco,El Recodo de San José Axalco', 19.2027800, -98.9027800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99136, 'Puentecillas (Tercera Manzana de Zirahuato)', 'Puentecillas (Tercera Manzana de Zirahuato)', 'Puentecillas (Tercera Manzana de Zirahuato)', 19.5050000, -100.4050000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99137, 'Calpanería Atezquilla', 'Calpaneria Atezquilla', 'Calpaneria Atezquilla,Calpanería Atezquilla', 19.6555600, -97.9952800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99138, 'Arroyo San Isidro', 'Arroyo San Isidro', 'Arroyo San Isidro', 18.4866700, -95.4133300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99139, 'La Esperanza (El Zapotal)', 'La Esperanza (El Zapotal)', 'La Esperanza (El Zapotal)', 15.4491700, -93.1641700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99140, 'Pueblo Madero (El Playón)', 'Pueblo Madero (El Playon)', 'Pueblo Madero (El Playon),Pueblo Madero (El Playón)', 17.1261100, -99.6725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99141, 'Barrio de San Ramón', 'Barrio de San Ramon', 'Barrio de San Ramon,Barrio de San Ramón', 19.3736100, -99.3311100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99142, 'Santa Fe de la Purísima', 'Santa Fe de la Purisima', 'Santa Fe de la Purisima,Santa Fe de la Purísima', 20.4955600, -100.8927800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99143, 'El Tigre (Segunda Manzana de Crescencio Morales)', 'El Tigre (Segunda Manzana de Crescencio Morales)', 'El Tigre (Segunda Manzana de Crescencio Morales)', 19.4736100, -100.2441700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99144, 'Tetelcingo', 'Tetelcingo', 'Tetelcingo', 18.2391700, -98.0266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99145, '18 de Marzo', '18 de Marzo', '18 de Marzo', 18.9688900, -98.1602800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99146, 'Ejido la Guayana (Rancho Seco)', 'Ejido la Guayana (Rancho Seco)', 'Ejido la Guayana (Rancho Seco)', 21.9802800, -102.2730600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99147, 'Pueblo Benito García', 'Pueblo Benito Garcia', 'Pueblo Benito Garcia,Pueblo Benito García', 30.5158300, -115.9327800, 'MX', '2016-04-08', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99148, 'Santa Rosa Caxtlahuaca', 'Santa Rosa Caxtlahuaca', 'Santa Rosa Caxtlahuaca', 17.3030600, -98.0169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99149, 'Buenavista', 'Buenavista', 'Buenavista', 19.2576700, -97.0753100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99150, 'Apantla', 'Apantla', 'Apantla', 17.0397200, -99.1694400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99151, 'Barrio de Puentecillas', 'Barrio de Puentecillas', 'Barrio de Puentecillas', 19.5355800, -99.9846300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99152, 'Colonia San Luis', 'Colonia San Luis', 'Colonia San Luis', 16.3800000, -95.2411100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99153, 'Loma Bonita', 'Loma Bonita', 'Loma Bonita', 18.5133300, -96.8677800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99154, 'Corralejo de Arriba', 'Corralejo de Arriba', 'Corralejo de Arriba', 20.8966700, -100.6544400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99155, 'Tonalapa', 'Tonalapa', 'Tonalapa', 17.4905600, -99.2419400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99156, 'La Mintzita (Piedra Dura)', 'La Mintzita (Piedra Dura)', 'La Mintzita (Piedra Dura)', 19.6519400, -101.2775000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99157, 'Nenehuaca', 'Nenehuaca', 'Nenehuaca', 19.1438900, -97.0422200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99158, 'Aguas Buenas', 'Aguas Buenas', 'Aguas Buenas', 20.9702800, -101.3725000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99159, 'Colonia Nueva Revolución', 'Colonia Nueva Revolucion', 'Colonia Nueva Revolucion,Colonia Nueva Revolución', 16.8983300, -99.8058300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99160, 'El Dorado', 'El Dorado', 'El Dorado', 17.8832300, -93.3678800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99161, 'El Moreno (San Miguel Moreno)', 'El Moreno (San Miguel Moreno)', 'El Moreno (San Miguel Moreno)', 20.3013900, -99.1736100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99162, 'Derramadero Segundo (Infiernillo)', 'Derramadero Segundo (Infiernillo)', 'Derramadero Segundo (Infiernillo)', 21.0975000, -100.5141700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99163, 'Las Primaveras [Invernadero]', 'Las Primaveras [Invernadero]', 'Las Primaveras [Invernadero]', 19.6947200, -103.8333300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99164, 'Miguel Negrete', 'Miguel Negrete', 'Miguel Negrete', 18.9522200, -97.8291700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99165, 'Camémbaro', 'Camembaro', 'Camembaro,Camémbaro', 19.4272200, -100.3988900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99166, 'San Clemente de Lima', 'San Clemente de Lima', 'San Clemente de Lima', 20.7372200, -105.2708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99167, 'El Siviral (Jigica)', 'El Siviral (Jigica)', 'El Siviral (Jigica)', 27.1022200, -109.5008300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99168, 'José Colomo', 'Jose Colomo', 'Jose Colomo,José Colomo', 17.9469100, -92.4665900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99169, 'Colonia Rafael Corrales Ayala', 'Colonia Rafael Corrales Ayala', 'Colonia Rafael Corrales Ayala', 20.9019400, -101.5161100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99170, 'Doxteje Barrio Primero', 'Doxteje Barrio Primero', 'Doxteje Barrio Primero', 19.9597200, -99.9586100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99171, 'Las Pintas', 'Las Pintas', 'Las Pintas', 19.8966700, -98.8869400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99172, 'Villa Tejúpam de la Unión', 'Villa Tejupam de la Union', 'Villa Tejupam de la Union,Villa Tejúpam de la Unión', 17.6625000, -97.4708300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99173, 'Paso Blanco', 'Paso Blanco', 'Paso Blanco', 22.2061100, -101.0705600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99174, 'Jalmolonga (La Hacienda)', 'Jalmolonga (La Hacienda)', 'Jalmolonga (La Hacienda)', 18.9183500, -99.4940700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99175, 'Cuto de la Esperanza', 'Cuto de la Esperanza', 'Cuto de la Esperanza', 19.7308300, -101.3402800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99176, 'El Capulo (La Quebradora)', 'El Capulo (La Quebradora)', 'El Capulo (La Quebradora)', 18.9494400, -98.2688900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99177, 'San Andrés Yahuitlalpan', 'San Andres Yahuitlalpan', 'San Andres Yahuitlalpan,San Andrés Yahuitlalpan', 19.6733300, -97.7269400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99178, 'Colonia Alborada', 'Colonia Alborada', 'Colonia Alborada', 16.8815100, -99.8177900, 'MX', '2014-08-25', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99179, 'La Concordia', 'La Concordia', 'La Concordia', 16.9058300, -98.9758300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99180, 'Ejido Miraflores', 'Ejido Miraflores', 'Ejido Miraflores', 19.5700000, -99.3975000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99181, 'Fraccionamiento Carlos Salinas de Gortari', 'Fraccionamiento Carlos Salinas de Gortari', 'Fraccionamiento Carlos Salinas de Gortari', 20.1102800, -98.4302800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99182, 'San José Mezapa Sección I', 'San Jose Mezapa Seccion I', 'San Jose Mezapa Seccion I,San José Mezapa Sección I', 19.1630600, -99.4550000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99183, 'Colonia la Calzada (La Olla)', 'Colonia la Calzada (La Olla)', 'Colonia la Calzada (La Olla)', 20.5027800, -100.9588900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99184, 'La Junta', 'La Junta', 'La Junta', 17.8277800, -97.7455600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99185, 'Unión Agropecuarios Lázaro Cárdenas del Norte', 'Union Agropecuarios Lazaro Cardenas del Norte', 'Union Agropecuarios Lazaro Cardenas del Norte,Unión Agropecuarios Lázaro Cárdenas del Norte', 25.8322200, -100.3841700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99186, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 19.1408300, -99.4263900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99187, 'Candelaria Portezuelo', 'Candelaria Portezuelo', 'Candelaria Portezuelo', 19.0419400, -97.7008300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99188, 'Unión Juárez', 'Union Juarez', 'Union Juarez,Unión Juárez', 17.2808300, -92.3997200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99189, 'Colonia Palo Prieto (Chipitongo)', 'Colonia Palo Prieto (Chipitongo)', 'Colonia Palo Prieto (Chipitongo)', 18.7041700, -99.1127800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99190, 'Peña Colorada', 'Pena Colorada', 'Pena Colorada,Peña Colorada', 17.4777800, -97.7941700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99191, 'Tetlatzinga', 'Tetlatzinga', 'Tetlatzinga', 18.6947200, -97.1844400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99192, 'Rinconadas de San Francisco', 'Rinconadas de San Francisco', 'Rinconadas de San Francisco', 20.0661100, -98.7680600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99193, 'Nuevo Carmen Tonapac', 'Nuevo Carmen Tonapac', 'Nuevo Carmen Tonapac', 16.6966700, -92.9555600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99194, 'Las Plazuelas', 'Las Plazuelas', 'Las Plazuelas', 16.8741700, -99.7855600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99195, 'El Progreso Hidalgo', 'El Progreso Hidalgo', 'El Progreso Hidalgo', 18.8463900, -99.6141700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99196, 'Las Torres de Guadalupe', 'Las Torres de Guadalupe', 'Las Torres de Guadalupe', 25.8061100, -100.6225000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99197, 'San Miguel Tlamahuco', 'San Miguel Tlamahuco', 'San Miguel Tlamahuco', 19.3241700, -98.2397200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99198, 'El Huidero', 'El Huidero', 'El Huidero', 18.3875000, -95.1791700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99199, 'San José Barbabosa', 'San Jose Barbabosa', 'San Jose Barbabosa,San José Barbabosa', 19.2758300, -99.7200000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99200, 'Rancho Grande', 'Rancho Grande', 'Rancho Grande', 18.3538900, -96.3494400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99201, 'Caobanal 1ra. Sección (Mezcalapa)', 'Caobanal 1ra. Seccion (Mezcalapa)', 'Caobanal 1ra. Seccion (Mezcalapa),Caobanal 1ra. Sección (Mezcalapa)', 17.6485800, -93.3946400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99202, 'Rancho de Guadalupe', 'Rancho de Guadalupe', 'Rancho de Guadalupe', 21.2163900, -101.0100000, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99203, 'Estación Corralejo', 'Estacion Corralejo', 'Estacion Corralejo,Estación Corralejo', 20.4700000, -101.6163900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99204, 'Melchor Ocampo', 'Melchor Ocampo', 'Melchor Ocampo', 17.3589500, -98.4475400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99205, 'Tlacpac', 'Tlacpac', 'Tlacpac', 20.1488900, -98.2169400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99206, 'Colonia el Florido', 'Colonia el Florido', 'Colonia el Florido', 18.7383300, -99.3672200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99207, 'Tlamaya Grande', 'Tlamaya Grande', 'Tlamaya Grande', 20.1468900, -97.8031300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99208, 'Loma del Refugio', 'Loma del Refugio', 'Loma del Refugio', 27.1219400, -109.4591700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99209, 'Unidos Avanzamos', 'Unidos Avanzamos', 'Unidos Avanzamos', 22.4338900, -97.9716700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99210, 'El Progreso', 'El Progreso', 'El Progreso', 16.3027800, -91.9266700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99211, 'Moyotepec (Moyotepec de Juárez)', 'Moyotepec (Moyotepec de Juarez)', 'Moyotepec (Moyotepec de Juarez),Moyotepec (Moyotepec de Juárez)', 17.3316700, -98.6855600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99212, 'Tlaminca', 'Tlaminca', 'Tlaminca', 19.1357100, -99.4399900, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99213, 'Cenobio Aguilar (La Trinidad)', 'Cenobio Aguilar (La Trinidad)', 'Cenobio Aguilar (La Trinidad)', 17.4047200, -92.3194400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99214, 'Cruz Verde', 'Cruz Verde', 'Cruz Verde', 19.1375000, -97.1086100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99215, 'Joltealal', 'Joltealal', 'Joltealal', 17.0768300, -92.6216300, 'MX', '2016-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99216, 'Rancho Nuevo del Llanito', 'Rancho Nuevo del Llanito', 'Rancho Nuevo del Llanito', 20.8236100, -101.3686100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99217, 'Oriental de Zapata', 'Oriental de Zapata', 'Oriental de Zapata', 19.9852800, -99.0316700, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99218, 'Colonia San Francisco', 'Colonia San Francisco', 'Colonia San Francisco', 18.8961100, -98.9036100, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99219, 'Ignacio Zaragoza', 'Ignacio Zaragoza', 'Ignacio Zaragoza', 19.2788900, -97.1994400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99220, 'Nuevo Refugio de Afuera (Nuevo Refugio)', 'Nuevo Refugio de Afuera (Nuevo Refugio)', 'Nuevo Refugio de Afuera (Nuevo Refugio)', 20.5488900, -102.7072200, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99221, 'Iratzio', 'Iratzio', 'Iratzio', 19.6458300, -101.4119400, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99222, 'San Pedro Tlapacoyan', 'San Pedro Tlapacoyan', 'San Pedro Tlapacoyan', 20.0580600, -97.0983300, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99223, 'Nueva Ameyalco', 'Nueva Ameyalco', 'Nueva Ameyalco', 19.2916700, -99.5055600, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99224, 'Puerto de Chiquihuite', 'Puerto de Chiquihuite', 'Puerto de Chiquihuite', 20.7008300, -99.8352800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99225, 'El Bajío (La Laguna)', 'El Bajio (La Laguna)', 'El Bajio (La Laguna),El Bajío (La Laguna)', 21.3794400, -101.9502800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99226, 'El Colorado', 'El Colorado', 'El Colorado', 20.0963900, -99.7627800, 'MX', '2014-04-11', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99227, 'Honey', 'Honey', 'Honey', 20.2388500, -98.2125300, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99228, 'Nuevo Necaxa', 'Nuevo Necaxa', 'Nuevo Necaxa', 20.2104900, -98.0065700, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99229, 'Espinal', 'Espinal', 'Espinal', 20.2581700, -97.4002800, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99230, 'Juamave', 'Juamave', '', 23.4057800, -99.3804400, 'MX', '2014-07-02', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99231, 'Chimaltitán', 'Chimaltitan', 'Chimaltitan,Chimaltitán', 21.7797700, -103.7807100, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99232, 'Benito Juárez', 'Benito Juarez', 'Benito Juarez,Benito Juárez,Laureles', 19.3135100, -100.4335800, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99233, 'Tecoanapa', 'Tecoanapa', 'Tecoanapa', 16.9877100, -99.2600200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99234, 'Santa Lucía Ocotlán', 'Santa Lucia Ocotlan', 'Santa Lucia Ocotlan,Santa Lucía Ocotlán', 16.7383400, -96.6796200, 'MX', '2015-06-22', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99235, 'El Guayabito', 'El Guayabito', 'El Guayabito', 19.9495600, -102.4441400, 'MX', '2014-11-07', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99236, 'Tlacolulan', 'Tlacolulan', 'Tlacolulan', 19.6668700, -97.0019400, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99237, 'Zumpahuacán', 'Zumpahuacan', 'Zumpahuacan,Zumpahuacán', 18.8372300, -99.5808000, 'MX', '2016-03-31', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99238, 'Nezahualcóyotl', 'Nezahualcoyotl', 'Ciudad Netzahualcoyotl,Ciudad Nezahualcoyotl,Nezahualcoyotl,Nezahualcóyotl', 19.3876300, -98.9926400, 'MX', '2017-04-09', 144);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99410, 'Xai-Xai', 'Xai-Xai', 'Chai Chai,Joa Belo,Joao Belo,João Belo,Sai Sajus,Sai-Sai,Shai-Shai,VJB,Vila de Joao Belo,Vila de João Belo,Vila-Joao-Belo,Vila-João-Belo,Xai Xai,Xai-Xai,sai sai,shai-shai,shaishai,shay-shay,syaisyai,Šai Šajus,Σάι-Σάι,Шаи-Шаи,Шаї-Шаї,شای-شای,შაი-შაი,シャイシャイ,賽賽,샤이샤이', -25.0519400, 33.6441700, 'MZ', '2014-09-02', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99411, 'Dondo', 'Dondo', 'Dondo,Vila do Dondo,Дондо', -19.6094400, 34.7430600, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99412, 'Macia', 'Macia', 'Macia,Vila de Macia', -25.0269400, 33.0988900, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99413, 'Tete', 'Tete', 'TET,Tete,Tetė,Vila-de-Santiago-Maior,tai te,tete,teteu,Τέτε,Тете,تیتے، موزمبیق,ტეტე,テテ,太特,테트', -16.1563900, 33.5866700, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99414, 'Ressano Garcia', 'Ressano Garcia', 'Resano Garcia,Ressano Garcia', -25.4427800, 31.9952800, 'MZ', '2013-05-05', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99415, 'Quelimane', 'Quelimane', 'Gorad Kelimaneh,Kelimane,Kelimanė,Quelimane,UEL,ke li ma nei,kellimaneu,kerimane,kylymany,Κελιμάνε,Горад Келіманэ,Келимане,Келімане,کیلیمانی,კელიმანე,ケリマネ,克利馬內,켈리마느', -17.8786100, 36.8883300, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99416, 'Pemba', 'Pemba', 'POL,Pemba,Pempa,Porto Amelia,pemba,penba,peng ba,pymba  mwzmbyq,Πέμπα,Пемба,پیمبا، موزمبیق,პემბა,ペンバ,彭巴,펨바', -12.9739500, 40.5177500, 'MZ', '2010-05-28', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99417, 'Nampula', 'Nampula', 'APL,Nampoula,Nampula,nampulla,nampwla,nan pu la,nanpura,Ναμπούλα,Нампула,نامپولا,ნამპულა,ナンプラ,楠普拉,남풀라', -15.1164600, 39.2666000, 'MZ', '2010-05-28', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99418, 'Nacala', 'Nacala', 'Cidade de Nacala,Fernao Veloso,Fernão Veloso,Gorod-de-Nakala,MNC,Maaia,Maiaia,Nacala,Nacala-Porto,Город-де-Накала', -14.5625700, 40.6853800, 'MZ', '2013-12-01', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99419, 'Montepuez', 'Montepuez', 'MTU,Montepuez,Montepveze,Vila de Montepuez,Монтепвезе', -13.1255600, 38.9997200, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99420, 'Mocímboa', 'Mocimboa', '', -11.3166700, 40.3500000, 'MZ', '2013-08-10', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99421, 'Ilha de Moçambique', 'Ilha de Mocambique', 'Ilha de Mocambique,Ilha de Moçambique,Mocambique,Mozambique,Moçambique', -15.0341700, 40.7358300, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99422, 'Maxixe', 'Maxixe', 'Maxixe', -23.8597200, 35.3472200, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99423, 'Matola', 'Matola', 'Cidade da Matola,Matola,Vila Salazar,Матола', -25.9622200, 32.4588900, 'MZ', '2013-07-04', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99424, 'Maputo', 'Maputo', 'Can Pfumo,Gorad Maputu,Kapfumo,Lourenco Marques,Lourenço Marques,MPM,Mabuto,Mabutu,Mapouto,Maputo,Maputu,Mapútó,ma pu to,ma pu tuo,mabwtw,maputo,maputto,maputu,mapwtw,mpwtw,Μαπούτο,Горад Мапуту,Мапуто,Мапуту,Մապուտու,מפוטו,مابوتو,ماپوتو,ماپوتۆ,ماپوٹو,मापुतो,ਮਾਪੂਤੋ,மபூட்டோ,มาปูโต,མ་པུ་ཊོ།,მაპუტუ,ማፑቶ,マプト,马普托,마푸토,마푸투', -25.9655300, 32.5832200, 'MZ', '2017-06-22', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99425, 'Manjacaze', 'Manjacaze', 'Cheverine,Manjacaze,Vila de Manjacaze', -24.7116700, 33.8827800, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99426, 'Manhiça', 'Manhica', 'Manhica,Manhiça,Vila da Manhica,Vila da Manhiça', -25.4022200, 32.8072200, 'MZ', '2014-04-01', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99427, 'Lichinga', 'Lichinga', 'Lichinga,Lishinga,Lisinga,Lišinga,VXC,Vila Cabral,li xin jia,lishinga,lising-ga,lychynga,rishinga,Лишинга,Лішинга,لیچینگا,ლიშინგა,リシンガ,利欣加,리싱가', -13.3127800, 35.2405600, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99428, 'Inhambane', 'Inhambane', 'INH,In''jambane,Inhambane,Injambane,Injambanė,aynhambanh,iniambane,inyambaneu,inyanbane shi,yi ni yang ba nei,Іньямбане,Иньямбане,انہامبان,اینهامبانه,ინიამბანე,イニャンバネ市,伊尼揚巴內,이냠바느', -23.8650000, 35.3833300, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99429, 'Cuamba', 'Cuamba', 'Cuamba,Cuanda,FXO,Guamba,Kwamba,Mucuamba,Mukwamba,Nova Freixo,ku an ba,kua mu ba,库安巴,誇姆巴', -14.8030600, 36.5372200, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99430, 'Chokwé', 'Chokwe', 'Chokue,Chokué,Chokwe,Chokwé,Choque,Chókwè,TGS,Trigo Morais,Trigo de Morais,Vila Trigo de Morais', -24.5333300, 32.9833300, 'MZ', '2017-04-25', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99431, 'Chimoio', 'Chimoio', 'Chimoio,Chimoyo,Shimojo,Simojas,VPY,Vila Pery,shimoio,shymwyw,simoiu,xi mo you,Šimojas,Шимойо,شیمویو,შიმოიო,希莫尤,시모이우', -19.1163900, 33.4833300, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99432, 'Chibuto', 'Chibuto', 'Chibuto,Vila do Chibuto', -24.6866700, 33.5305600, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99433, 'Beira', 'Beira', 'BEW,Beira,Bejra,bei la,beila,beira,byra  mwzambyk,byyra  mwzmbyq,Μπέιρα,Беира,Бейра,بیئرا، موزمبیق,بیرا، موزامبیک,ბეირა,ベイラ,贝拉,베이라', -19.8436100, 34.8388900, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99434, 'António Enes', 'Antonio Enes', 'Angoche,Antonio Enes,Antonio Engs,Antonio Ennes,António Enes,Vila de Antonio Enes,Vila de António Enes', -16.2325000, 39.9086100, 'MZ', '2012-01-19', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99435, 'Mutuáli', 'Mutuali', '', -14.8705600, 37.0044400, 'MZ', '2006-01-17', 152);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99436, 'Katima Mulilo', 'Katima Mulilo', 'Katima Molilo,Katima Mulilas,Katima Mulilo,Katima-Mulilo,MPA,ka di ma mu li luo,katimamullillo,katyma mwlylw,Катима Мулило,Катима-Мулило,Катіма-Муліло,קאטימה מולילו,کاتیما مولیلو,カティマ・ムリロ,卡蒂马穆利洛,카티마물릴로', -17.5000000, 24.2666700, 'NA', '2017-06-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99437, 'Bagani', 'Bagani', 'BQI,Bagani', -18.1106500, 21.6164500, 'NA', '2013-05-08', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99438, 'Windhoek', 'Windhoek', 'Gorad Vindkhuk,Gouintchouk,Vindguk,Vindhuk,Vindhuka,Vindhukas,Vindhuko,Vindkhuk,Vinduque,Vindxuk,Vintchouk,WDH,Windhoek,Windhuk,Windoek,Windoèk,Wynhoeke,binteuhukeu,u~intofukku,vatahuka,vindahoka,vintok,wen de he ke,wen he ke,win dhuk,wwynthwq,wyndhwk,wyndhwq,wyndھwk,wynٹہwk,Βίντχουκ,Γουίντχουκ,Виндхук,Віндгук,Горад Віндхук,Վինդհուկ,ווינטהוק,וינדהוק,ونڈہوک,ويندهوك,ویندهوک,ویندھوک,وینٹہوک,विंडहोक,ਵੰਟਹੁਕ,விந்தோக்,วินด์ฮุก,ཝིན་ཌི་ཧོཡིཀ།,ვინდჰუკი,ዊንድሁክ,ウィントフック,温得和克,溫得和克,溫荷克,빈트후크', -22.5594100, 17.0832300, 'NA', '2017-06-20', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99439, 'Warmbad', 'Warmbad', 'Warmbad', -28.4500000, 18.7333300, 'NA', '2012-02-01', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99440, 'Usakos', 'Usakos', 'Usakos', -22.0000000, 15.6000000, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99441, 'Tsumeb', 'Tsumeb', 'Cumeb,Cumebo,TSB,Tsoumeb,Tsumeb,chu mei bu,chumebeu,tsumebu,Τσουμέμπ,Цумеб,צואמב,ツメブ,楚梅布,추메브', -19.2333300, 17.7166700, 'NA', '2013-11-01', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99442, 'Tses', 'Tses', 'Tses', -25.8833300, 18.0000000, 'NA', '2013-05-05', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99443, 'Swakopmund', 'Swakopmund', 'SWP,Svakopmund,Svakopmundas,Swakopmund,seubakopeumunteu,si wa ke pu meng de,sokapamunda,suwakopumunto,swakwpmwnd,swwqwpmwnd,Свакопмунд,סווקופמונד,سواکوپموند,সোকপমুন্ড,スワコプムント,斯瓦科普蒙德,스바코프문트', -22.6833300, 14.5333300, 'NA', '2013-10-04', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99444, 'Rundu', 'Rundu', 'NDU,Rundu,Runtu,long du,lundu,rwndw,Рунду,روندو,龍杜,룬두', -17.9333300, 19.7666700, 'NA', '2014-03-06', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99445, 'Rehoboth', 'Rehoboth', 'Rehoboth,Rekhobot,Рехобот', -23.3170000, 17.0900000, 'NA', '2016-09-19', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99446, 'Outjo', 'Outjo', 'Outjo', -20.1166700, 16.1500000, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99447, 'Otjiwarongo', 'Otjiwarongo', 'OTJ,Ochivarongo,Ocivarongas,Ot''ivarongo,Otiwarongo,Očivarongas,ao qi wa long ge,awtjywarwngw,Отьиваронго,Очиваронго,اوتجیوارونگو,奧奇瓦龍戈', -20.4636900, 16.6477200, 'NA', '2016-12-20', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99448, 'Otjimbingwe', 'Otjimbingwe', 'Otjimbingue,Otjimbingwe', -22.3500000, 16.1333300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99449, 'Otavi', 'Otavi', 'Otavi,Otawi', -19.6500000, 17.3333300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99450, 'Oshikango', 'Oshikango', 'Oshikango', -17.4000000, 15.8833300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99451, 'Oshakati', 'Oshakati', 'Okatana,Osakatis,Oshakati,Ošakatis,ao sha ka di,awshakaty,Ошакати,Ошакаті,اوشاکاتی,奧沙卡蒂', -17.7833300, 15.6833300, 'NA', '2012-01-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99452, 'Oranjemund', 'Oranjemund', 'OMD,Orange Mouth,Orangemund,Oranjemond,Oranjemund', -28.5500000, 16.4333300, 'NA', '2014-08-18', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99453, 'Opuwo', 'Opuwo', 'OPW,Ohopoho,Ohopuho,Opuwa', -18.0606800, 13.8399800, 'NA', '2017-06-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99454, 'Ongwediva', 'Ongwediva', 'Onguedira,Onguediva,Ongwediva', -17.7833300, 15.7666700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99455, 'Ongandjera', 'Ongandjera', 'Okandjera,Ongandjera,Rehoboth', -17.8833300, 15.0666700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99456, 'Ondangwa', 'Ondangwa', 'OND,Ondangua,Ondangva,Ondangwa,Ondonga,weng dan gua,Ондангва,翁丹瓜', -17.9166700, 15.9500000, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99457, 'Omuthiya', 'Omuthiya', 'Omuthiya Gwiipundi', -18.3646300, 16.5814600, 'NA', '2017-05-11', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99458, 'Omaruru', 'Omaruru', 'Omaruru', -21.4333300, 15.9333300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99459, 'Okakarara', 'Okakarara', 'Okakarara', -20.5833300, 17.4333300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99460, 'Okahandja', 'Okahandja', 'Okahandja,Okahanja,Okakhandzha,ao ka han gu,okahanja,Окаханджа,オカハンジャ,奧卡漢賈', -21.9833300, 16.9166700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99461, 'Nkurenkuru', 'Nkurenkuru', 'Kuring Kuru,Nkurenkuru', -17.6166700, 18.6000000, 'NA', '2014-03-06', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99462, 'Mariental', 'Mariental', 'Mariental,Mariental'',Marientalis,ma lin ta er,maliental,marientaru,Мариентал,Мариенталь,Марієнталь,マリエンタール,马林塔尔,마리엔탈', -24.6333300, 17.9666700, 'NA', '2013-06-28', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99463, 'Maltahöhe', 'Maltahohe', 'Maltahohe,Maltahöhe', -24.8333300, 16.9833300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99464, 'Lüderitz', 'Luderitz', 'LUD,Lideric,Ljuderic,Luderitz,Luederitz,Lüderitz,lu de li ci,lwidelicheu,lydryz,ryuderittsu,Лидериц,Людериц,לידריץ,リューデリッツ,吕德里茨,뤼데리츠', -26.6480600, 15.1594400, 'NA', '2017-03-16', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99465, 'Khorixas', 'Khorixas', 'Khorixas,Wallwitch,Wellwitsch,Welwitsch,Welwitschia', -20.3666700, 14.9666700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99466, 'Keetmanshoop', 'Keetmanshoop', 'KMP,Keetmanshoop,Ketmanshopas,Ketmanskhop,Kitmanskhup,ji te man si hu pu,keiteumanseuhopeu,ketomansufupu,kytmanshwp,qytmnshwp,Кетмансхоп,Китмансхуп,Кітмансхуп,קיטמנסהופ,کیتمانشوپ,ケートマンスフープ,基特曼斯胡普,케이트만스호프', -26.5833300, 18.1333300, 'NA', '2012-01-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99467, 'Karibib', 'Karibib', 'Karibib', -21.9333300, 15.8333300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99468, 'Karasburg', 'Karasburg', 'KAS,Kalkfontein,Kalkfontein South,Karasburg', -28.0166700, 18.7500000, 'NA', '2013-10-26', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99469, 'Hoachanas', 'Hoachanas', 'Hoachanas', -23.9166700, 18.0500000, 'NA', '2013-05-05', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99470, 'Hentiesbaai', 'Hentiesbaai', 'Henties Bay,Hentiesbaai', -22.1166700, 14.2833300, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99471, 'Grootfontein', 'Grootfontein', 'GFY,Grootfontein,Groutfontein,Grutfontejn,Khrutfontejn,geuluteupontein,gurutofontein,he lu te fang dan,Грутфонтейн,Хрутфонтейн,グルートフォンテイン,赫魯特方丹,그루트폰테인', -19.5666700, 18.1166700, 'NA', '2014-08-19', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99472, 'Gobabis', 'Gobabis', 'GOG,Gobabis,ge ba bi si,gwabys,Гобабис,Гобабіс,گوابیس,戈巴比斯', -22.4500000, 18.9666700, 'NA', '2012-01-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99473, 'Eenhana', 'Eenhana', 'Eenana,Eenhana,Enana', -17.4666700, 16.3333300, 'NA', '2012-01-14', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99474, 'Bethanie', 'Bethanie', 'Bethanie,Bethanien,Bethany', -26.4833300, 17.1500000, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99475, 'Aranos', 'Aranos', 'Aranos', -24.1333300, 19.1166700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99476, 'Arandis', 'Arandis', 'ADI,Arandis', -22.4166700, 14.9666700, 'NA', '2012-01-17', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99477, 'Walvis Bay', 'Walvis Bay', 'Gorad Uolvis-Behj,Uolfish Bej,Uolfish-Bej,Valvis Bej,Volfis-Bej,Volvis Bejus,Volvis Bėjus,WVB,Walfisch-Bucht-Niederland,Walfischbucht,Walvis Bay,Walvisbaai,jing wan gang,u~orubisubei,wlfs by,wolbiseubei,Валвис Беј,Волфіш-Бей,Горад Уолвіс-Бэй,Уолфиш Бей,Уолфиш-Бей,ואלוויס ביי,ولفس بي,ウォルビスベイ,鲸湾港,월비스베이', -22.9575000, 14.5052800, 'NA', '2017-05-05', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99478, 'Outapi', 'Outapi', 'Ombalantu,Outapi,Uutapi', -17.5000000, 14.9833300, 'NA', '2013-10-09', 154);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99479, 'Yaté-Barrage', 'Yate-Barrage', '', -22.1500000, 166.8833300, 'NC', '2006-01-17', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99480, 'Wé', 'We', 'Oue,Oué,We,Wé', -20.9168700, 167.2646100, 'NC', '2017-01-12', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99481, 'Wala', 'Wala', 'BMY,Uala,Waala,Wala', -19.7116100, 163.6470200, 'NC', '2015-03-29', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99482, 'Voh', 'Voh', 'Voh', -20.9666700, 164.7000000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99483, 'Vao', 'Vao', 'Upuaite,Vao', -22.6664500, 167.4962700, 'NC', '2017-01-12', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99484, 'Touho', 'Touho', 'TOU,Touho,Tuho,Tuo', -20.7909400, 165.2498700, 'NC', '2015-04-23', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99485, 'Thio', 'Thio', 'Thio', -21.6166700, 166.2166700, 'NC', '2014-04-01', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99486, 'Tadine', 'Tadine', 'Tadine,Tadinou,Tadinu,Todine', -21.5500000, 167.8833300, 'NC', '2017-01-12', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99487, 'Poya', 'Poya', 'Poya', -21.3500000, 165.1500000, 'NC', '2012-02-02', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99488, 'Poum', 'Poum', 'Bouemanda,Bouémanda,Buemanda,PUV,Peum,Poum,Poume,Pum', -20.2333300, 164.0166700, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99489, 'Pouembout', 'Pouembout', 'Pouembout,Puembut', -21.1333300, 164.9000000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99490, 'Pouébo', 'Pouebo', 'Pouebo,Pouébo,Puebo,Puébo', -20.4000000, 164.5666700, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99491, 'Ponérihouen', 'Ponerihouen', 'Ponerihouen,Poneriuen,Ponérihouen,Punereuin', -21.0833300, 165.4000000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99492, 'Poindimié', 'Poindimie', 'Poindimie,Poindimié', -20.9333300, 165.3333300, 'NC', '2012-02-02', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99493, 'Païta', 'Paita', 'Paita,Païta', -22.1310500, 166.3571700, 'NC', '2017-01-10', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99494, 'Ouégoa', 'Ouegoa', 'Ouegoa,Ouégoa', -20.3500000, 164.4333300, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99495, 'Nouméa', 'Noumea', 'NOU,Nomea,Noumea,Nouméa,Numea,Numeja,Numeo,Numėja,Port de France,nu me xa,nu mei a,nume''a,numea,numiya,nwmya,Νουμεά,Нумеа,נומאה,نومئا,نوميا,नूमेआ,நூமியா,นูเมอา,ნუმეა,ヌメア,努美阿,누메아', -22.2740700, 166.4488400, 'NC', '2017-07-27', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99496, 'Mont-Dore', 'Mont-Dore', '', -22.2625700, 166.5662100, 'NC', '2017-01-10', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99497, 'La Foa', 'La Foa', '', -21.7107900, 165.8276400, 'NC', '2013-05-03', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99498, 'Koumac', 'Koumac', 'KOC,Koumac,Kumac,Kumak', -20.5666700, 164.2833300, 'NC', '2014-04-01', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99499, 'Koné', 'Kone', 'KNQ', -21.0595100, 164.8658200, 'NC', '2017-05-26', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99500, 'Kaala-Gomén', 'Kaala-Gomen', 'Gomen,Kaala-Gomen,Kaala-Gomén', -20.6666700, 164.4000000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99501, 'Houaïlou', 'Houailou', 'Houailou,Houaïlou,Huailu,Huaïlu', -21.2833300, 165.6166700, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99502, 'Hienghène', 'Hienghene', 'Hienghene,Hiengherie,Hienghène,Yengen', -20.6833300, 164.9333300, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99503, 'Fayaoué', 'Fayaoue', 'Faiaoue,Faiaoué,Faiaue,Faiaué,Fayaoue,Fayaoué', -20.6528400, 166.5364100, 'NC', '2017-01-12', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99504, 'Dumbéa', 'Dumbea', 'Dumbea,Dumbéa', -22.1500000, 166.4500000, 'NC', '2012-02-02', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99505, 'Canala', 'Canala', 'Canala,Kanala,Napoleonville,Napoléonville', -21.5333300, 165.9500000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99506, 'Bourail', 'Bourail', 'Bourail,Boureil,Burail', -21.5669000, 165.4973600, 'NC', '2014-10-07', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99507, 'Bouloupari', 'Bouloupari', 'Bouloupari,Boulouparis,Bulupari', -21.8666700, 166.0500000, 'NC', '2012-01-18', 158);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99508, 'Birnin Gaouré', 'Birnin Gaoure', 'Birni Ngaoure,Birni Ngaouré,Birni Ngaure,Birnin Gaoure,Birnin Gaouré', 13.0817300, 2.9109900, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99509, 'Birni N Konni', 'Birni N Konni', 'Birni N Konni,Birni n''Kenni,Birni n’Kenni,Birni-Koni,Birnin Koni,Birnin Konni,Birnin-Konni,Konni,Бирнин-Конни', 13.7959900, 5.2502600, 'NE', '2013-05-12', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99510, 'Zinder', 'Zinder', 'Gorad Zindehr,Sinder,ZND,Zinder,Zinderis,jandeleu,jin de er,sinde xr,zanderu,zndr,zyndr,Горад Зіндэр,Зиндер,Зіндер,زندر,زيندر,ซินเดอร์,ザンデール,津德尔,잔데르', 13.8071600, 8.9881000, 'NE', '2011-10-27', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99511, 'Tillabéri', 'Tillaberi', 'Tillaberi,Tillabery,Tillabéri,Tillabéry,di la bei li,tillabeli,tiraberi,Тиллабери,ティラベリ,蒂拉貝里,틸라베리', 14.2071100, 1.4541800, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99512, 'Tibiri', 'Tibiri', '', 13.5627100, 7.0484800, 'NE', '2006-01-17', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99513, 'Tessaoua', 'Tessaoua', 'Tessaoua', 13.7573700, 7.9874000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99514, 'Téra', 'Tera', 'Tera,Téra,Тера', 14.0077600, 0.7530600, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99515, 'Tchintabaraden', 'Tchintabaraden', 'Tchin Tabaraden,Tchin Tabaradèn,Tchin-Tabaradene,Tchin-terbaradin,Tchintabaraden,Tchintabaradene', 15.8969000, 5.7985000, 'NE', '2014-05-29', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99516, 'Tanout', 'Tanout', 'Tanout', 14.9708900, 8.8878600, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99517, 'Tahoua', 'Tahoua', 'THZ,Tahoua,Tahua,Takhua,ta wa,taua,Тахуа,تاہؤا,タウア,塔瓦,타우아', 14.8888000, 5.2692000, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99518, 'Say', 'Say', 'Say', 13.1007000, 2.3689000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99519, 'Ouallam', 'Ouallam', 'Oualam,Ouallam', 14.3164100, 2.0859700, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99520, 'Niamey', 'Niamey', 'Gorad Nijamej,NIM,Niame,Niamei,Niamej,Niameja,Niamejus,Niameo,Niamey,Niamè,Niamėjus,Nijamej,Níamey,ni ya mei,ni''ami,niame,niamei,nixame,niyame,niyami,nyamy,nyʼmyy,Νιαμέι,Νιαμέυ,Горад Ніямей,Ниамей,Нијамеј,Ніамей,Նիամեյ,ניאמיי,نيامي,نیامی,نیامەی,ܢܝܐܡܝ,नियामे,নিয়ামে,ਨਿਆਮੀ,நியாமி,นีอาเม,ནི་ཡ་མེ།,ნიამეი,ኒያሜ,ニアメ,尼亞美,니아메', 13.5136600, 2.1098000, 'NE', '2011-10-27', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99521, 'Nguigmi', 'Nguigmi', 'Ngigmi,Nguigmi', 14.2495300, 13.1092100, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99522, 'Mirriah', 'Mirriah', 'Miria,Mirria,Mirriah,Mirya,Myrria,Мирриа', 13.7072700, 9.1501300, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99523, 'Mayahi', 'Mayahi', 'Majakhi,Mayahi,Mayaki,Майахи', 13.9553200, 7.6712200, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99524, 'Matamey', 'Matamey', 'Matamey,Matameye,Matamèye', 13.4230900, 8.4748500, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99525, 'Maradi', 'Maradi', 'MFQ,Maradi,Maradis,maladi,maradi,marady  nayjr,Маради,مارادی، نائجر,マラディ,마라디', 13.5000000, 7.1017400, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99526, 'Maïné Soroa', 'Maine Soroa', 'Maine Soroa,Maine-Soroa,Maïné Soroa,Maïné-Soroa', 13.2113900, 12.0241000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99527, 'Magaria', 'Magaria', 'Magaria', 12.9982600, 8.9099100, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99528, 'Madarounfa', 'Madarounfa', 'Madaroumfa,Madarounfa,Madarunfa', 13.3086700, 7.1560200, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99529, 'Madaoua', 'Madaoua', 'Madaoua,Madawa', 14.0730000, 5.9600000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99530, 'Loga', 'Loga', 'Loga', 13.6132000, 3.2358000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99531, 'Kollo', 'Kollo', 'Kollo,Kolo', 13.3043000, 2.3390000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99532, 'Keïta', 'Keita', 'Keita,Keïta', 14.7551000, 5.7749000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99533, 'Kantché', 'Kantche', 'Kantche,Kantché', 13.5392600, 8.4629300, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99534, 'Illéla', 'Illela', 'Ilella,Illela,Illeta,Illéla,Illéta', 14.4605000, 5.2437000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99535, 'Guidan Roumdji', 'Guidan Roumdji', 'Gidan Roumji,Guidam Roumji,Guidan Roumdji,Guidan Roumji', 13.6576000, 6.6956700, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99536, 'Gouré', 'Goure', 'Goure,Gouré', 13.9835000, 10.2703500, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99537, 'Gaya', 'Gaya', 'Gaya', 11.8843500, 3.4491900, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99538, 'Filingué', 'Filingue', 'Filingue,Filingué', 14.3521000, 3.3168000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99539, 'Dosso', 'Dosso', 'Dosso,Доссо', 13.0490000, 3.1937000, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99540, 'Dogondoutchi', 'Dogondoutchi', 'Dogondoutchi,Dogonduchi', 13.6393300, 4.0287500, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99541, 'Diffa', 'Diffa', 'Difa,Diffa,difa,dipa,dyfa,Дифа,Диффа,ديفا,ディファ,디파', 13.3153600, 12.6113500, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99542, 'Dakoro', 'Dakoro', 'Dakoro', 14.5105600, 6.7650000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99543, 'Bouza', 'Bouza', 'Bouza', 14.4229300, 6.0427800, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99544, 'Bilma', 'Bilma', 'Bil''ma,Bilina,Bilma,Fort Dromard,bi er ma,bilma,biruma,bylma,Μπίλμα,Билма,Бильма,بیلما,ビルマ,比爾馬,빌마', 18.6853200, 12.9164300, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99545, 'Ayorou', 'Ayorou', 'Agorou,Ayorou', 14.7307500, 0.9173900, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99546, 'Arlit', 'Arlit', 'Arhli,Arli,Arlit,Arlitas,RLT,a er li te,aleulliteu,aritto,arlyt,Арли,Арлит,أرليت,ارلیت,アーリット,阿爾利特,아를리트', 18.7369400, 7.3852800, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99547, 'Alaghsas', 'Alaghsas', 'Alaghsas,Alarsas', 17.0187000, 8.0168000, 'NE', '2012-01-18', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99548, 'Aguié', 'Aguie', 'Aguie,Aguié,Agye,Agyé', 13.5060100, 7.7786300, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99549, 'Agadez', 'Agadez', 'AJY,Agades,Agadesas,Agadez,Agadèz,Ankantez,a jia de zi,agadeja,agadejeu,agadesi,agadesu,agadyz,aghadys,Αγκαντέζ,Агадез,Агадес,אגדז,أغاديس,اگادیز,अगादेज,აგადესი,アガデス,阿加德茲,아가데즈', 16.9733300, 7.9911100, 'NE', '2017-02-04', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99550, 'Abalak', 'Abalak', 'Abalak,Ebaka,Ibeka', 15.4509000, 6.2793000, 'NE', '2013-10-06', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99551, 'Tchirozérine', 'Tchirozerine', 'Tchighozerine,Tchirozerine,Tchirozérine', 17.2209600, 7.7614000, 'NE', '2013-10-11', 161);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99553, 'Zuru', 'Zuru', '', 11.4352200, 5.2349400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99554, 'Zurmi', 'Zurmi', 'Zurmi', 12.7767500, 6.7840400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99555, 'Zungeru', 'Zungeru', 'Zungeru', 9.8072600, 6.1523800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99556, 'Zonkwa', 'Zonkwa', 'Zankuwa,Zenkuwa,Zonkwa', 9.7845300, 8.2905600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99557, 'Zing', 'Zing', 'Zing,Zinna', 8.9906400, 11.7476300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99558, 'Zaria', 'Zaria', 'ZAR,Zaria,Zarija,Zariya,Zarja,jalia,zari''a,zaria,zarya,zha li ya,Зариа,Заря,زاريا,ਜ਼ਾਰੀਆ,ザリア,扎里亚,자리아', 11.1112800, 7.7227000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99559, 'Zango', 'Zango', '', 13.0531300, 8.4857400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99560, 'Zalanga', 'Zalanga', 'Zalanga', 10.6143200, 10.1764700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99561, 'Zakirai', 'Zakirai', '', 12.1003300, 8.8852400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99562, 'Zaki Biam', 'Zaki Biam', 'Zaki Biam,Zaki Biyem', 7.5067100, 9.6104000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99563, 'Zadawa', 'Zadawa', 'Zadawa', 11.4496000, 10.3672000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99564, 'Yuli', 'Yuli', 'Anguri,Yuli', 9.6970700, 10.2735000, 'NG', '2016-10-08', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99565, 'Yola', 'Yola', 'Jola,YOL,Yola,yolla,yora,yue la,ywla  nayjyrya,ywla  nyjryh,Йола,یولا، نائجیریا,یولا، نیجریه,ヨラ,約拉,욜라', 9.2083900, 12.4814600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99566, 'Yenagoa', 'Yenagoa', 'Yenagoa,Yenegoa', 4.9267500, 6.2676400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99567, 'Yelwa', 'Yelwa', 'Yelwa', 10.8350500, 4.7424400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99568, 'Yelwa', 'Yelwa', '', 8.8333300, 9.6333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99569, 'Yashikera', 'Yashikera', '', 9.7666700, 3.4000000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99570, 'Yandev', 'Yandev', '', 7.3630800, 9.0423500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99571, 'Yanda Bayo', 'Yanda Bayo', 'Yanda Bayo,Yando Bayo', 11.5071000, 10.7459000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99572, 'Yamrat', 'Yamrat', '', 10.1116100, 9.8260400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99573, 'Yajiwa', 'Yajiwa', 'Yajiwa,Yajua,Yajuao', 11.3862300, 12.7199200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99574, 'Yabo', 'Yabo', '', 12.7221700, 5.0132900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99575, 'Wuyo', 'Wuyo', '', 10.3852200, 11.6967800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99576, 'Wushishi', 'Wushishi', '', 9.7303500, 6.0730500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99577, 'Wurno', 'Wurno', 'Wurno', 13.2904800, 5.4237300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99578, 'Wukari', 'Wukari', 'Ukari,Wukari', 7.8713900, 9.7778600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99579, 'Wudil', 'Wudil', '', 11.8093700, 8.8442200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99580, 'Wawa', 'Wawa', '', 9.9022200, 4.4191700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99581, 'Wase', 'Wase', 'Wase', 9.0942400, 9.9560500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99582, 'Wasagu', 'Wasagu', 'Wasaga,Wasagu', 11.3764000, 5.7953600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99583, 'Warri', 'Warri', 'Bappi,Bаppи,QRW,Varri,Warri,wa li,wali,wari,wary,Варри,واري,واری,ワリ,瓦里,와리', 5.5173700, 5.7500600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99584, 'Wannune', 'Wannune', '', 7.5638400, 8.8853400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99585, 'Wamba', 'Wamba', '', 8.9415300, 8.6031500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99586, 'Wamako', 'Wamako', 'Wamakka,Wamakko,Wamako', 13.0305400, 5.1043300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99587, 'Wagini', 'Wagini', 'Wagin,Wagini', 12.6878100, 7.1957900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99588, 'Vom', 'Vom', '', 9.7291000, 8.7913800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99589, 'Vandeikya', 'Vandeikya', 'Vande Ikya,Vandeikya', 6.7848100, 9.0679900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99590, 'Uyo', 'Uyo', 'QUO,Uyo', 5.0512700, 7.9335000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99591, 'Utu Etim Ekpo', 'Utu Etim Ekpo', 'Utu Etim,Utu Etim Ekpo', 5.0048500, 7.6102800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99592, 'Ozoro', 'Ozoro', 'Ozoro,Usoro', 5.5469200, 6.2264900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99593, 'Uselu', 'Uselu', '', 6.3842900, 5.6098400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99594, 'Uruobo-Okija', 'Uruobo-Okija', 'Okija,Uruobo-Okija', 5.9001600, 6.8431200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99595, 'Urualla', 'Urualla', '', 5.8539700, 7.0990600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99596, 'Uromi', 'Uromi', '', 6.7000000, 6.3333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99597, 'Uquo', 'Uquo', '', 4.6583200, 8.0586800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99598, 'Ukpor', 'Ukpor', 'Ukpor,Upor', 5.9421100, 6.9293100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99599, 'Ungogo', 'Ungogo', 'Ungogo', 12.0917100, 8.4953100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99600, 'Umuneke-Ngor', 'Umuneke-Ngor', 'Nmu Neke,Umu-Neke,Umuneke,Umuneke-Ngor', 5.3355800, 7.1518700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99601, 'Umunede', 'Umunede', 'Umunede', 6.2654900, 6.3096200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99602, 'Umulona', 'Umulona', 'Umulokpa,Umulona,Umuluokpa', 6.5078900, 7.0974300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99603, 'Umuelemai', 'Umuelemai', 'Umu Elemai,Umuelemai,Umulemai', 5.6878600, 7.2433400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99604, 'Umuahia', 'Umuahia', 'Umuahia,Umuahia-Ibeku,Umuakhija,umuahia,wu mu a xi ya,Умуахия,Умуахія,اومواہیا,乌穆阿希亚,우무아히아', 5.5249100, 7.4946100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99605, 'Ukpo', 'Ukpo', 'Ukpo,Ukpo-Akpu', 6.2140700, 6.9665700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99606, 'Ukata', 'Ukata', '', 10.8312200, 5.8249400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99607, 'Ughelli', 'Ughelli', 'Ughelli', 5.4895600, 6.0040700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99608, 'Ugep', 'Ugep', 'Ugep', 5.8086500, 8.0809800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99609, 'Ugba', 'Ugba', '', 7.5070000, 9.3480400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99610, 'Uga', 'Uga', 'Uga', 5.9357600, 7.0793000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99611, 'Udi', 'Udi', 'Udi', 6.3159200, 7.4208600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99612, 'Ubiaja', 'Ubiaja', 'Ubiaja', 6.6558100, 6.3849400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99613, 'Uba', 'Uba', '', 10.4550900, 13.2223300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99614, 'Tureta', 'Tureta', 'Tureta', 12.5936700, 5.5439100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99615, 'Tudun Wada', 'Tudun Wada', 'Tudan Wada,Tudun Wada,Wada', 11.2484800, 8.4010900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99616, 'Tsanyawa', 'Tsanyawa', 'Tsanyawa', 12.2955900, 7.9865400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99617, 'Toungo', 'Toungo', 'Toungo', 8.1173300, 12.0461100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99618, 'Toto', 'Toto', '', 8.3876000, 7.0775100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99619, 'Toro', 'Toro', '', 10.0588900, 9.0691000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99620, 'Tokombere', 'Tokombere', '', 11.2213500, 13.4878300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99621, 'Tofa', 'Tofa', '', 12.0578900, 8.2730900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99622, 'Tegina', 'Tegina', '', 10.0706000, 6.1906000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99623, 'Tede', 'Tede', '', 8.5562500, 3.4463800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99624, 'Taura', 'Taura', '', 12.2271200, 9.2830600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99625, 'Tambuwal', 'Tambuwal', 'Tambawal,Tambawel,Tambuwal', 12.4059200, 4.6460500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99626, 'Talata Mafara', 'Talata Mafara', 'Talata Mafara', 12.5684100, 6.0622500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99627, 'Talasse', 'Talasse', 'Tailase,Talasse,Tallasa,Tallase', 9.9684300, 11.6794500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99628, 'Takum', 'Takum', '', 7.2666700, 9.9833300, 'NG', '2013-05-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99629, 'Bunza', 'Bunza', 'Bunza,Takalafian Bunza', 12.0882100, 4.0152000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99630, 'Takai', 'Takai', '', 11.5756900, 9.1088000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99631, 'Tafawa Balewa', 'Tafawa Balewa', 'Tafawa Balewa', 9.7601700, 9.5517200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99632, 'Suya', 'Suya', 'Saya,Souya,Suya', 9.4666700, 3.1833300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99633, 'Surulere', 'Surulere', 'QSL,Sufu-Lere,Suru-Lere,Surulere', 6.5015300, 3.3580800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99634, 'Sumaila', 'Sumaila', 'Sumaila', 11.5301100, 8.9559300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99635, 'Sule Tankarkar', 'Sule Tankarkar', 'Sule Tankarka,Sule Tankarkar,Sule-Tankar-Kar', 12.6668600, 9.2282800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99636, 'Suleja', 'Suleja', 'Abudzha,Abuja,Sulaija,Suleija,Suleja,Абуджа', 9.1805900, 7.1793900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99637, 'Song', 'Song', '', 9.8267500, 12.6238000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99638, 'Sokoto', 'Sokoto', 'SKO,Socoto,Sokotas,Sokoto,Sokoto stad,Sókótó,sokoto,suo ke tuo,Сокото,სოკოტო,ソコト,索科托,소코토', 13.0626900, 5.2432200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99639, 'Soba', 'Soba', '', 10.9813300, 8.0574900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99640, 'Siluko', 'Siluko', '', 6.5385800, 5.1609000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99641, 'Silame', 'Silame', 'Silame', 13.0392100, 4.8459300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99642, 'Somolu', 'Somolu', 'Shomolu,Somolu', 6.5389100, 3.3742000, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99643, 'Shinkafi', 'Shinkafi', 'Shinkafe,Shinkafi', 13.0729600, 6.5057400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99644, 'Shendam', 'Shendam', 'Shendam', 8.8786600, 9.5346400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99645, 'Shelleng', 'Shelleng', 'Shellem,Shellen,Shelleng', 9.8964700, 12.0057200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99646, 'Share', 'Share', '', 8.8208600, 4.9734200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99647, 'Shanono', 'Shanono', 'Shanomo,Shanono', 12.0515400, 7.9920000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99648, 'Shani', 'Shani', '', 10.2182400, 12.0605900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99649, 'Shanga', 'Shanga', 'Shanga', 11.2137400, 4.5794100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99650, 'Saki', 'Saki', 'Saki,Shaki,Саки', 8.6676200, 3.3939300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99651, 'Shagari', 'Shagari', 'Shagari', 12.6272700, 4.9929500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99652, 'Shagamu', 'Shagamu', 'Sagamu,Shagamu', 6.8485000, 3.6463300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99653, 'Shaffa', 'Shaffa', '', 10.5067300, 12.3331500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99654, 'Serti', 'Serti', '', 7.5057400, 11.3631000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99655, 'Sauri', 'Sauri', 'Samri,Sauri', 11.7265500, 6.7837400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99656, 'Sarkin Pawa', 'Sarkin Pawa', '', 10.0209400, 7.1124400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99657, 'Sapele', 'Sapele', 'Sapele', 5.8940500, 5.6766600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99658, 'Sankwala', 'Sankwala', '', 6.5475300, 9.2225800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99659, 'Sankera', 'Sankera', 'Sankara,Sankera', 7.5353000, 9.6522300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99660, 'Sandamu', 'Sandamu', 'Sandamu', 12.9616300, 8.3601700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99661, 'Samamiya', 'Samamiya', 'Samamiya,Samammiya,Saman', 11.3487300, 9.6398900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99662, 'Sakaba', 'Sakaba', '', 11.0651300, 5.5961000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99663, 'Sagbama', 'Sagbama', 'Aduezi,Ndiama,Ndiemazi,Obuare,Sagbama', 5.1591500, 6.1966600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99664, 'Safana', 'Safana', 'Safana', 12.4107500, 7.4145600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99665, 'Sade', 'Sade', '', 11.3595000, 10.6732000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99666, 'Sabuwa', 'Sabuwa', 'Sabua,Sabuwa', 11.1737200, 7.1211300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99667, 'Sabongida-Ora', 'Sabongida-Ora', 'Sabon Gida,Sabongida-Ora,Sabongidda,Sabongidda Ora', 6.9023100, 5.9311700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99668, 'Sabon Birni', 'Sabon Birni', 'Sabon Birni,Sobon Birni', 13.5638700, 6.3235500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99669, 'Runka', 'Runka', '', 12.4478800, 7.3091800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99670, 'Ruma', 'Ruma', '', 12.8626000, 7.2346900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99671, 'Roni', 'Roni', '', 12.6586200, 8.2650500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99672, 'Rogo', 'Rogo', '', 11.5523700, 7.8225300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99673, 'Riyom', 'Riyom', 'Riom,Riyom', 9.6368100, 8.7569400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99674, 'Riti', 'Riti', '', 7.9084400, 9.6168800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99675, 'Ririwai', 'Ririwai', 'Ririwai,Riruwai', 10.7402500, 8.7412800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99676, 'Ringim', 'Ringim', '', 12.1514300, 9.1621600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99677, 'Rimin Gado', 'Rimin Gado', 'Rafin Gado,Rimin Gado', 11.9672000, 8.2476000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99678, 'Rimi', 'Rimi', '', 12.8503000, 7.7097400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99679, 'Rijau', 'Rijau', 'Rijau', 11.1038900, 5.2555600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99680, 'Ribah', 'Ribah', '', 11.3963700, 5.4863100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99681, 'Rano', 'Rano', 'Rano', 11.5568400, 8.5806500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99682, 'Rann', 'Rann', 'Ran,Rann', 12.2693800, 14.4655200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99683, 'Saminaka', 'Saminaka', 'Rahama,Saminaka,Samunakar', 10.4122700, 8.6874800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99684, 'Rabah', 'Rabah', 'Rabah', 13.1225700, 5.5076200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99685, 'Potiskum', 'Potiskum', 'Potiskum,Putuskum', 11.7139100, 11.0810800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99686, 'Port Harcourt', 'Port Harcourt', 'Gorad Port-Kharkort,PHC,Port Harcourt,Port Harkortas,Port Kharkurt,Port-Kharkort,Ugwu Ocha,Ugwu Ọcha,bwrt harkwrt,ha ke te gang,poteuhakeoteu,potohakoto,pwrt hrqwrt,Горад Порт-Харкорт,Порт Харкурт,Порт-Харкорт,פורט הרקורט,بورت هاركورت,ポートハーコート,哈科特港,포트하커트', 4.7774200, 7.0134000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99687, 'Pindiga', 'Pindiga', 'Pindiga', 9.9843300, 10.9522900, 'NG', '2016-10-08', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99688, 'Patigi', 'Patigi', 'Pategi,Patigi', 8.7285100, 5.7556100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99689, 'Patani', 'Patani', '', 5.2288500, 6.1913900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99690, 'Panyam', 'Panyam', '', 9.4075600, 9.2148100, 'NG', '2016-02-06', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99691, 'Pantisawa', 'Pantisawa', 'Panti Sawa,Pantisawa,Pantishawa', 8.9450400, 11.5117600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99692, 'Pankshin', 'Pankshin', '', 9.3254100, 9.4352000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99693, 'Paiko', 'Paiko', '', 9.4368500, 6.6335700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99694, 'Ozubulu', 'Ozubulu', 'Ozubulu', 5.9575300, 6.8530500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99695, 'Oyo', 'Oyo', 'Oio,Oió,Ojo,Oyo,Ойо', 7.8525700, 3.9312500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99696, 'Oye-Ekiti', 'Oye-Ekiti', 'Oye,Oye-Ekiti', 7.7997600, 5.3324200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99697, 'Oyan', 'Oyan', '', 8.0500000, 4.7666700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99698, 'Owu-Isin', 'Owu-Isin', 'Owu,Owu-Isin', 8.2809000, 5.0194000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99699, 'Owode', 'Owode', '', 6.9485100, 3.5056100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99700, 'Owo', 'Owo', 'Ovo,Owo,Ово', 7.1962000, 5.5868100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99701, 'Owerri', 'Owerri', 'Overi,Overri,Owerre,Owerri,Owẹrrẹ,QOW,ao wei li,awwyry,awyry,oweli,Овери,Оверри,أويري,اوویری,奧韋里,오웨리', 5.4836300, 7.0332500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99702, 'Owena', 'Owena', 'Owena,Owenna', 7.1941400, 5.0226400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99703, 'Owa-Oyibu', 'Owa-Oyibu', 'Owa Oyiebu,Owa-Oyibu', 6.1826700, 6.1990200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99704, 'Otuocha', 'Otuocha', 'Otuocha,Otuocha Aguleri', 6.3390800, 6.8463600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99705, 'Otun-Ekiti', 'Otun-Ekiti', 'Awtun,Otun,Otun-Ekiti', 7.9885800, 5.1229100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99706, 'Otukpa', 'Otukpa', '', 7.1016800, 7.6594500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99707, 'Otu-Jeremi', 'Otu-Jeremi', 'Jeremi Town,Otu-Chievwen,Otu-Ghievwen,Otu-Jeremi,Otu-Ughievwen,Otughievwen,Otujeremi', 5.4381800, 5.8782900, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99708, 'Otor-Udu', 'Otor-Udu', 'Otor-Udu,Otudu,Udu', 5.4534100, 5.8693000, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99709, 'Otu', 'Otu', '', 8.2065000, 3.4073500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99710, 'Ota', 'Ota', 'Ota,Otta', 6.6886700, 3.2320200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99711, 'Otan Ayegbaju', 'Otan Ayegbaju', 'Ota,Otan,Otan Aiyegbaju,Otan Ayegbaju,Oton', 7.9478300, 4.7883600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99712, 'Osu', 'Osu', 'Oshu,Osu', 7.5858500, 4.6226000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99713, 'Osogbo', 'Osogbo', 'Eshogbo,Oshogbo,Osogbo', 7.7710400, 4.5569800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99714, 'Oshodi', 'Oshodi', '', 6.5550400, 3.3436300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99715, 'Afor-Oru', 'Afor-Oru', 'Afor-Oru,Afororu,Oru', 5.5411000, 7.2684500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99716, 'Oron', 'Oron', 'Oron,Oron Town', 4.8217100, 8.2350400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99717, 'Orodo', 'Orodo', 'Orodo', 5.6166700, 7.0333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99718, 'Orlu', 'Orlu', 'Awlu,Orlu', 5.7956500, 7.0351300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99719, 'Orita Eruwa', 'Orita Eruwa', '', 7.5500000, 3.4333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99720, 'Orerokpe', 'Orerokpe', 'Orerokpe,Orerukpe', 5.6374700, 5.8901300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99721, 'Ore', 'Ore', '', 6.7471600, 4.8761000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99722, 'Oporoma', 'Oporoma', '', 4.8060400, 6.0801600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99723, 'Opobo', 'Opobo', 'Opobo,Opobo Town', 4.5138800, 7.5379400, 'NG', '2015-07-03', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99724, 'Ikot Abasi', 'Ikot Abasi', 'Egwanga,Ikot Abasi,Opobo', 4.5685100, 7.5526200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99725, 'Opi', 'Opi', '', 6.7822300, 7.4331900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99726, 'Onyedega', 'Onyedega', 'Onyadega,Onyedega', 6.8820900, 6.6758500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99727, 'Onitsha', 'Onitsha', 'Onicha,Onitsha,Onịchạ,QNI,ao ni cha,onicha,Онитша,Онича,Оніча,オニチャ,奧尼查,오니차', 6.1497800, 6.7856900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99728, 'Ondo', 'Ondo', 'Ondo,Ондо', 7.0931600, 4.8352800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99729, 'Omuo-Ekiti', 'Omuo-Ekiti', 'Omuo,Omuo-Kota', 7.7583300, 5.7222700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99730, 'Omu-Aran', 'Omu-Aran', 'Omu,Omu-Aran', 8.1385700, 5.1026000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99731, 'Omoku', 'Omoku', 'Oil City 3,Omoko,Omoku', 5.3438800, 6.6568400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99732, 'Olupona', 'Olupona', 'Olupona,Olupono', 7.6000000, 4.1833300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99733, 'Oleh', 'Oleh', 'Ole,Oleh', 5.4618600, 6.2062400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99734, 'Okpoga', 'Okpoga', 'Okpoga,Okwoga', 7.0391100, 7.8122500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99735, 'Okwe', 'Okwe', '', 5.7774300, 7.2179400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99736, 'Okuta', 'Okuta', '', 9.2166700, 3.1833300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99737, 'Okrika', 'Okrika', 'Okrika', 4.7421500, 7.0836800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99738, 'Okpoma', 'Okpoma', '', 6.5967900, 8.6372800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99739, 'Okpo', 'Okpo', '', 7.2162600, 7.5602200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99740, 'Okoroete', 'Okoroete', 'Okoro-Ete,Okoroete', 4.5407700, 7.7485800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99741, 'Okopedi', 'Okopedi', '', 4.8491800, 8.1256400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99742, 'Oko Ita', 'Oko Ita', 'Oko Ita,Okolta', 5.1920000, 7.8953100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99743, 'Okigwe', 'Okigwe', 'Okigwe,Okigwi', 5.8291700, 7.3505600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99744, 'Oke-Oyi', 'Oke-Oyi', '', 8.5826300, 4.7162200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99745, 'Okene', 'Okene', 'Okene,Okeni', 7.5512200, 6.2358900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99746, 'Oke Mesi', 'Oke Mesi', 'Oke Mesi,Oke Messi', 7.8166700, 4.9166700, 'NG', '2013-05-17', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99747, 'Oke Ila', 'Oke Ila', 'Oke Ila', 7.9500000, 4.9833300, 'NG', '2013-05-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99748, 'Okeho', 'Okeho', 'Oke-Iho,Okeho', 8.0338600, 3.3475900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99749, 'Okehi', 'Okehi', 'Okehi,Okehin', 5.1389500, 7.1391500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99750, 'Oke-Agbe', 'Oke-Agbe', 'Oke-Agbe,Okeagbe', 7.6431400, 5.7594300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99751, 'Okada', 'Okada', '', 6.7346900, 5.3908300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99752, 'Oka', 'Oka', 'Oka,Oka-Akoko', 7.4601200, 5.8017400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99753, 'Oju', 'Oju', 'Oju', 6.8452600, 8.4191400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99754, 'Ojoto', 'Ojoto', 'Ojoto', 6.0584200, 6.8612400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99755, 'Oji River', 'Oji River', '', 6.2556300, 7.2702500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99756, 'Ohafia-Ifigh', 'Ohafia-Ifigh', '', 5.6145500, 7.8119100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99757, 'Ogwashi-Uku', 'Ogwashi-Uku', 'Ogvashi-Uku,Ogwashi-Uku,Ugwashi-Uku,Огваши-Уку', 6.1781100, 6.5246100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99758, 'Oguta', 'Oguta', 'Oguta', 5.7104400, 6.8093600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99759, 'Ogurugu', 'Ogurugu', 'Ogrugru,Ogurugu', 6.7863600, 6.9501700, 'NG', '2015-09-06', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99760, 'Oguma', 'Oguma', 'Ogum,Oguma', 7.8963500, 7.0622900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99761, 'Ogu', 'Ogu', '', 4.7224700, 7.1985900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99762, 'Ogoja', 'Ogoja', 'Ogoja', 6.6584000, 8.7992300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99763, 'Ogidi', 'Ogidi', 'Ogid,Ogidi', 6.1520900, 6.8634300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99764, 'Ogbomoso', 'Ogbomoso', 'Ogbomocho,Ogbomosho,Ogbomoso', 8.1337300, 4.2401400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99765, 'Ogbere', 'Ogbere', 'Alakuko,Alaluko,Ogbere', 6.7394800, 4.1610200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99552, 'Kingston', 'Kingston', 'Kingston,Kingston pa Norfolkoya,Kingston på Norfolkøya,Kingstona,Kingstonas,Kingstono,Kingstun,Kinqston,Pasjolak Kingstan,jin si dui,khing s tan,kincutan,kingseuteon,kingstana,kingusuton,kynghstwn,kyngstwn,Кингстон,Кингстън,Кінгстон,Пасёлак Кінгстан,كينغستون,کنگسٹن,کینگستون,किंग्स्टन,கிங்சுடன்,คิงส์ตัน,კინგსტონი,キングストン,金斯敦,킹스턴', -29.0545900, 167.9662800, 'NF', '2014-08-18', 164);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100590, 'Zwolle', 'Zwolle', 'Gemeen Zwolle,Gorad Zvolle,Svolla,Swol,Zvole,Zvolle,Zvolė,Zwolle,ci wo lei,jeubolleo,jhvola,s wol lex,zfwlh,zi wo lei,zuvu~ore,zvole,zwwlh,Горад Зволле,Зволе,Зволле,Զվոլե,زفوله,زولے,زووله,झ्वोला,ซโวลเลอ,ზვოლე,ズヴォレ,兹沃勒,즈볼러', 52.5125000, 6.0944400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100591, 'Zwijndrecht', 'Zwijndrecht', 'Zuindracum,Zvayndrext,Zvejndrekht,Zvejndrekhte,Zwijndrecht,ci wei en de lei he te,zfayndrykht,Звейндрехт,Звейндрехте,Զվայնդրեխտ,زفايندريخت,兹韦恩德雷赫特', 51.8175000, 4.6333300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100592, 'Zwaanshoek', 'Zwaanshoek', '', 52.3125000, 4.6166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100593, 'De Westereen', 'De Westereen', 'De Westereen,De Westerein,Zwaagwesteinde', 53.2573100, 6.0363000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100594, 'Zwaagdijk-Oost', 'Zwaagdijk-Oost', 'Zwaagdijk', 52.7075000, 5.1402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100595, 'Zutphen', 'Zutphen', 'Zjutfen,Zutfen,Zutphen,Зютфен', 52.1383300, 6.2013900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100596, 'Zundert', 'Zundert', 'Groot Zundert,Zjundert,Зюндерт', 51.4716700, 4.6555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100597, 'Zuilichem', 'Zuilichem', 'Zuelichem', 51.8091700, 5.1361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100598, 'Zuidwijk', 'Zuidwijk', 'Zuidwijk', 51.8753200, 4.4851400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100599, 'Zuid-Scharwoude', 'Zuid-Scharwoude', '', 52.6866700, 4.8083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100600, 'Zuidlaren', 'Zuidlaren', 'Sudlaren,Súdlaren,Zaountlaren,Zuidlaren,ze yi de la lun,Ζαουντλάρεν,泽伊德拉伦', 53.0941700, 6.6819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100601, 'Zuidhorn', 'Zuidhorn', '', 53.2466700, 6.4027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100602, 'Zuiderburen', 'Zuiderburen', 'Zuidburen', 53.1734000, 5.8427100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100603, 'Zuidbroek', 'Zuidbroek', 'Zuidbreek,Zuidbrock,Zuidbruek', 53.1633300, 6.8611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100604, 'Zuid-Beijerland', 'Zuid-Beijerland', 'Zuidbeierland', 51.7508300, 4.3680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100605, 'Zoutkamp', 'Zoutkamp', 'Saltkamp,Sâltkamp', 53.3391700, 6.3041700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100606, 'Zoutelande', 'Zoutelande', '', 51.5016700, 3.4847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100607, 'Zonnemaat', 'Zonnemaat', '', 51.9311500, 6.0623500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100608, 'Zonderwijk', 'Zonderwijk', '', 51.4114100, 5.3936100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100609, 'Zoeterwoude-Dorp', 'Zoeterwoude-Dorp', '', 52.1200000, 4.4958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100610, 'Zoetermeer', 'Zoetermeer', 'Zeutermaer,Zoetermeer,zwtrmyyr,זוטרמייר', 52.0575000, 4.4930600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100611, 'Zoelen', 'Zoelen', '', 51.9125000, 5.4027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100612, 'Zijtaart', 'Zijtaart', 'Seitaart,Sijtaard,Sijtaart', 51.5925000, 5.5416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100613, 'Zevenhuizen', 'Zevenhuizen', '', 52.2181600, 5.9784100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100614, 'Zevenhoven', 'Zevenhoven', '', 52.1816700, 4.7791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100615, 'Zevenbergschen Hoek', 'Zevenbergschen Hoek', 'Zevenbergschehoek', 51.6725000, 4.6791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100616, 'Zevenaar', 'Zevenaar', 'Zevenar,Зевенар', 51.9300000, 6.0708300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100617, 'Zetten', 'Zetten', '', 51.9283300, 5.7138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100618, 'Zesgehuchten', 'Zesgehuchten', '', 51.4166700, 5.5500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100619, 'Zelhem', 'Zelhem', '', 52.0066700, 6.3486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100620, 'Zeist', 'Zeist', 'Seist,Zajst,Zeist,Zejst,Zeyst,jeiseuteu,zai si te,zaisuto,zayst,Зајст,Зейст,Զեյստ,زايست,زایست,ザイスト,宰斯特,제이스트', 52.0900000, 5.2333300, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100621, 'Zeilberg', 'Zeilberg', 'Zeilberg,Zijlberg', 51.4546900, 5.8187800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100622, 'Zegge', 'Zegge', '', 51.5566700, 4.5180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100623, 'Zeewolde', 'Zeewolde', '', 52.3300000, 5.5416700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100624, 'Zeelst', 'Zeelst', '', 51.4242100, 5.4156600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100625, 'Zeeland', 'Zeeland', 'Op-Zeeland,Seelandt,Selant,Zeeland,Zelant,Zelland,Zélland', 51.6975000, 5.6763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100626, 'Zeddam', 'Zeddam', '', 51.9033300, 6.2597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100627, 'Zandvoort', 'Zandvoort', 'Landvoort,Zandvoort,Зандвоорт', 52.3712500, 4.5330600, 'NL', '2016-02-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100628, 'Zandberg', 'Zandberg', '', 51.5733300, 4.7847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100629, 'Zaltbommel', 'Zaltbommel', 'zarutobomeru,zha er te bo mo er,ザルトボメル,扎爾特博默爾', 51.8100000, 5.2444400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100630, 'Zaanstad', 'Zaanstad', 'Zaanstad', 52.4531300, 4.8135600, 'NL', '2010-01-30', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100631, 'Zaandijk', 'Zaandijk', 'zan dai ke,zand jk,زاند جک,赞代克', 52.4749400, 4.8068600, 'NL', '2015-08-23', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100632, 'Zaandam', 'Zaandam', 'Zaandam,Zandam,Zandamas,jandam,zan dan,zan dm,zandamu,Заандам,Зандам,Զանդամ,زان دم,ザーンダム,赞丹,잔담', 52.4385400, 4.8264300, 'NL', '2010-06-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100633, 'Zaamslag', 'Zaamslag', 'Zaomslag,zams lyg,زامس لیگ', 51.3125000, 3.9125000, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100634, 'Yerseke', 'Yerseke', 'Erseke,IJerseka,Iersake,Ierseke,Iese,Yrseke,Ерсеке,یرسکے', 51.4925000, 4.0500000, 'NL', '2010-07-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100635, 'Wouw', 'Wouw', '', 51.5216700, 4.3902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100636, 'Woudsend', 'Woudsend', 'Waldsein,Wâldsein', 52.9435700, 5.6284300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100637, 'Woudrichem', 'Woudrichem', 'Vaudrixem,Woudrichem,fawdrykhym,wo de li he mu,Վաուդրիխեմ,فاودريخيم,沃德里赫姆', 51.8150000, 5.0013900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100638, 'Woudenberg', 'Woudenberg', '', 52.0808300, 5.4166700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100639, 'Woubrugge', 'Woubrugge', '', 52.1700000, 4.6361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100640, 'Workum', 'Workum', 'Warkum,Workum,wo er ke mu,沃爾克姆', 52.9796900, 5.4471000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100641, 'Wooldrik', 'Wooldrik', '', 52.2166700, 6.9166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100642, 'Woolde', 'Woolde', '', 52.2721000, 6.7589100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100643, 'Wommels', 'Wommels', '', 53.1088300, 5.5874900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100644, 'Wolvega', 'Wolvega', 'Vol''vega,Wolvega,Wolvegea,wo er fu ha,Вольвега,沃尔弗哈', 52.8754500, 5.9969100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100645, 'Wolphaartsdijk', 'Wolphaartsdijk', 'Oostkerk,Oostkerke,Wolphaartsdijk', 51.5316700, 3.8194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100646, 'Wolfsbos', 'Wolfsbos', '', 52.7173400, 6.4988100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100647, 'Wolfheze', 'Wolfheze', 'Wolfheeze', 52.0033300, 5.7902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100648, 'Wolder', 'Wolder', 'Wilree', 50.8375200, 5.6593800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100649, 'Woerden', 'Woerden', 'Verden,Vurden,Woerden,wu er deng,Верден,Вурден,Վուրդեն,武爾登', 52.0850000, 4.8833300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100650, 'Woenselse Heide', 'Woenselse Heide', '', 51.4833300, 5.4666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100651, 'Woensdrecht', 'Woensdrecht', 'Vonsdrekht,Woensdrecht,Вонсдрехт', 51.4289700, 4.3035500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100652, 'Witmarsum', 'Witmarsum', 'Witmarsum,Wytmarsum', 53.1045200, 5.4690200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100653, 'Wissenkerke', 'Wissenkerke', 'Wissekerke', 51.5850000, 3.7472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100654, 'Wisch', 'Wisch', '', 51.9264800, 6.4170500, 'NL', '2011-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100655, 'Wirdum', 'Wirdum', '', 53.1489300, 5.8038700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100656, 'Winterswijk', 'Winterswijk', 'Vintersvejk,Винтерсвейк', 51.9725000, 6.7194400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100657, 'Winsum', 'Winsum', '', 53.3300000, 6.5208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100658, 'Winschoten', 'Winschoten', 'Vinskhoten,Winschoten,Wynskoat,wen si huo teng,Винсхотен,溫斯霍滕', 53.1441700, 7.0347200, 'NL', '2010-09-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100659, 'Winkel', 'Winkel', '', 52.7541700, 4.9027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100660, 'Wilnis', 'Wilnis', '', 52.1966700, 4.8972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100661, 'Wilhelminadorp', 'Wilhelminadorp', '', 51.4974200, 5.3922300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100662, 'Wildervank', 'Wildervank', '', 53.0808300, 6.8625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100663, 'Wijnjewoude', 'Wijnjewoude', 'Duurswoude,Wijnjeterp,Wijnjeterp-Duurswoude,Wijnjewoude,Wynjeterp,Wynjewald,Wynjewâld', 53.0581400, 6.2047000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100664, 'Wijnandsrade', 'Wijnandsrade', '', 50.9058300, 5.8833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100665, 'Wijlre', 'Wijlre', 'Wielder', 50.8333300, 5.8958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100666, 'Wijk bij Duurstede', 'Wijk bij Duurstede', 'Vayk bey Dursteyde,Wyk by Duerstede,fayk bay dywrstydh,Վայկ բեյ Դուրստեյդե,فايك باي ديورستيده', 51.9741700, 5.3416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100667, 'Wijk aan Zee', 'Wijk aan Zee', '', 52.4936000, 4.5940900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100668, 'Wijhe', 'Wijhe', 'Wije', 52.3866700, 6.1347200, 'NL', '2008-12-21', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100669, 'Wijdenes', 'Wijdenes', '', 52.6350000, 5.1569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100670, 'Wijchen', 'Wijchen', 'Vijchen,Wijchen,Вийчен', 51.8091700, 5.7250000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100671, 'Wijbosch', 'Wijbosch', '''t Wijbosch,Weibosch', 51.6166700, 5.4680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100672, 'Wieringerwerf', 'Wieringerwerf', 'Wieringerdorf', 52.8508300, 5.0263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100673, 'Wieringerwaard', 'Wieringerwaard', '', 52.8358300, 4.8652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100674, 'Wierden', 'Wierden', 'Vierden,Wierden,Виерден', 52.3591700, 6.5930600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100675, 'Westwoud', 'Westwoud', '', 52.6850000, 5.1347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100676, 'West-Terschelling', 'West-Terschelling', 'West-Skylge,Westerschelling', 53.3591100, 5.2148200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100677, 'West-Souburg', 'West-Souburg', 'Souberg,Westsoeburg', 51.4641700, 3.5916700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100678, 'Westmaas', 'Westmaas', '', 51.7866700, 4.4750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100679, 'Westlaren', 'Westlaren', 'Duvelsoord,Westlaren', 53.0848000, 6.6646900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100680, 'Westkapelle', 'Westkapelle', 'Wasschappel', 51.5291700, 3.4402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100681, 'Westerzicht', 'Westerzicht', '', 51.4625200, 3.5868700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100682, 'Westervoort', 'Westervoort', '', 51.9558300, 5.9722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100683, 'Westerlee', 'Westerlee', '', 53.1458300, 6.9875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100684, 'Westerhoven', 'Westerhoven', '', 51.3325000, 5.3958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100685, 'Westerhaar-Vriezenveensewijk', 'Westerhaar-Vriezenveensewijk', 'Westerhaar', 52.4558300, 6.6236100, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100686, 'Westerbork', 'Westerbork', 'Vesterbork,Вестерборк', 52.8500000, 6.6083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100687, 'Westeneng', 'Westeneng', 'Westenenk', 52.1275000, 5.7152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100688, 'Westeinde', 'Westeinde', '', 53.2085300, 5.7681200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100689, 'Westdorpe', 'Westdorpe', '', 51.2325000, 3.8263900, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100690, 'Wessem', 'Wessem', 'Wessem,Wèssem', 51.1595400, 5.8814600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100691, 'Wernhout', 'Wernhout', '', 51.4550000, 4.6416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100692, 'Werkhoven', 'Werkhoven', '', 52.0250000, 5.2444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100693, 'Werkendam', 'Werkendam', 'Verkendam,Werkendam,Веркендам', 51.8100000, 4.8944400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100694, 'Wemeldinge', 'Wemeldinge', '', 51.5183300, 3.9972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100695, 'Wellerlooi', 'Wellerlooi', '', 51.5341700, 6.1361100, 'NL', '2009-01-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100696, 'Welberg', 'Welberg', '', 51.5766700, 4.3305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100697, 'Wekerom', 'Wekerom', '', 52.1125000, 5.7138900, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100698, 'Weiteveen', 'Weiteveen', '', 52.6725000, 6.9875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100699, 'Weijpoort', 'Weijpoort', '', 52.0816700, 4.8027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100700, 'Weesp', 'Weesp', 'Vesp,Veysp,Weesp,fysb,wei si pu,Весп,Վեյսպ,فيسب,韋斯普', 52.3075000, 5.0416700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100701, 'Weert', 'Weert', 'Vert,Weerd,Weert,Wieert,Wieërt,Верт', 51.2516700, 5.7069400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100702, 'Weerestein', 'Weerestein', '', 52.3038100, 4.5886100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100703, 'Waubach', 'Waubach', 'Waubach-Lauradorp', 50.9183300, 6.0500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100704, 'Waterakkers', 'Waterakkers', '', 52.5044000, 4.6560800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100705, 'Wassenaar', 'Wassenaar', '', 52.1458300, 4.4027800, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100706, 'Waspik', 'Waspik', '', 51.6866700, 4.9444400, 'NL', '2009-01-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100707, 'Warnsveld', 'Warnsveld', '', 52.1375000, 6.2305600, 'NL', '2009-09-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100708, 'Warmond', 'Warmond', 'Varmond,Вармонд', 52.1966700, 4.5027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100709, 'Wergea', 'Wergea', 'Warga,Wergea', 53.1514500, 5.8440400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100710, 'Warffum', 'Warffum', 'Warfum', 53.3925000, 6.5583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100711, 'Wapenveld', 'Wapenveld', 'Wapenvelde', 52.4291700, 6.0736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100712, 'Wanssum', 'Wanssum', 'Wansum', 51.5358300, 6.0763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100713, 'Wanroij', 'Wanroij', 'Wanrooi,Wanrooy,Wanroy', 51.6575000, 5.8180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100714, 'Wageningen', 'Wageningen', 'Vada,Vageningen,Vageningenas,Vaxeningen,Wageningen,vu~aheningen,wa han ning en,wa he ning en,wakhnyngn,Вагенинген,Վախենինգեն,واخنینگن,ヴァーヘニンゲン,瓦罕寧恩,瓦赫寧恩', 51.9700000, 5.6666700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100715, 'Wagenborgen', 'Wagenborgen', '', 53.2558300, 6.9333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100716, 'Wagenberg', 'Wagenberg', '', 51.6650000, 4.7486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100717, 'Waddinxveen', 'Waddinxveen', '', 52.0450000, 4.6513900, 'NL', '2015-09-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100718, 'Waarland', 'Waarland', '', 52.7266700, 4.8319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100719, 'Waarder', 'Waarder', '', 52.0608300, 4.8208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100720, 'Waardenburg', 'Waardenburg', '', 51.8325000, 5.2569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100721, 'Waarde', 'Waarde', '', 51.4175000, 4.0680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100722, 'Waalwijk', 'Waalwijk', 'Waalwijk', 51.6825000, 5.0708300, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100723, 'Waalre', 'Waalre', 'Waalre', 51.3866700, 5.4444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100724, 'Vuren', 'Vuren', '', 51.8250000, 5.0458300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100725, 'Vught', 'Vught', 'Vjugt,Vuxt,fwkht,Вюгт,Վուխտ,فوخت', 51.6533300, 5.2875000, 'NL', '2016-04-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100726, 'Vroomshoop', 'Vroomshoop', '', 52.4608300, 6.5652800, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100727, 'Vriezenveen', 'Vriezenveen', 'Uriezenveen', 52.4083300, 6.6222200, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100728, 'Vries', 'Vries', '', 53.0741700, 6.5777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100729, 'Vrieheide', 'Vrieheide', '', 50.9219200, 5.9670100, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100730, 'Vreewijk', 'Vreewijk', '', 51.8842800, 4.5196700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100731, 'Vreeswijk', 'Vreeswijk', 'Nieuwegein-Zuid', 52.0108800, 5.0928500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100732, 'Vredenburg', 'Vredenburg', '', 51.9535500, 5.9028400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100733, 'Vorstenbosch', 'Vorstenbosch', '', 51.6525000, 5.5500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100734, 'Vorden', 'Vorden', '', 52.1050000, 6.3097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100735, 'Voorthuizen', 'Voorthuizen', '', 52.1866700, 5.6055600, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100736, 'Voorst', 'Voorst', 'Voorst,Vorst,fwrst,Воорст,Ворст,Վորստ,فورست', 52.1700000, 6.1416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100737, 'Voorschoten', 'Voorschoten', '', 52.1275000, 4.4486100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100738, 'Voorhout', 'Voorhout', 'Vorkhaut,phuraha''uta,Ворхаут,फूरहाउट', 52.2216700, 4.4847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100739, 'Voorburg', 'Voorburg', 'Voorburg,fwrbwrkh,Воорбург,فوربورخ', 52.0741700, 4.3597200, 'NL', '2009-08-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100740, 'Vollenhove', 'Vollenhove', 'Veno,fu lun huo fu,福倫霍弗', 52.6808300, 5.9541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100741, 'Volkel', 'Volkel', '', 51.6425000, 5.6541700, 'NL', '2009-01-05', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100742, 'Volendam', 'Volendam', 'Volendam,Volendamas,fu lun dan,pollendam,wwlndm,Волендам,וולנדם,福伦丹,폴렌담', 52.4950000, 5.0708300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100743, 'Voldijn', 'Voldijn', '', 51.4005200, 5.4719600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100744, 'Vogelwijk', 'Vogelwijk', '', 52.0763100, 4.2479000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100745, 'Vogelenzang', 'Vogelenzang', '', 52.3191700, 4.5777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100746, 'Voerendaal', 'Voerendaal', '', 50.8832700, 5.9297800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100747, 'Vlokhoven', 'Vlokhoven', '', 51.4666700, 5.4833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100748, 'Vlodrop', 'Vlodrop', '', 51.1333300, 6.0763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100749, 'Vlissingen', 'Vlissingen', 'Flesinga,Flessinga,Flessingue,Flissingen,Flushing,Vlisingen,Vlissienge,Vlissinge,Vlissingen,flsnkn,fu li xin en,peullising-eon,Влиссинген,Флиссинген,Վլիսինգեն,فلسنكن,弗利辛恩,플리싱언', 51.4425000, 3.5736100, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100750, 'Vlietwijk', 'Vlietwijk', '', 52.1243600, 4.4573600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100462, 'Yalagüina', 'Yalaguina', 'Yalaguina,Yalagüina', 13.4837500, -86.4929700, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100463, 'Wiwilí', 'Wiwili', 'Gueigueili,Guiguili,Guiguilí,Guiquili,Güigüilí,Wiwili,Wiwilí', 13.6267900, -85.8254000, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100464, 'Waspam', 'Waspam', 'Huaspan,WSP,Waspam,Waspan,Waspán', 14.7418900, -83.9717000, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100465, 'Waslala', 'Waslala', 'Waslala', 13.2333300, -85.3833300, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100466, 'Villa Sandino', 'Villa Sandino', 'Viila Somoza,Villa Sandino,Villa Somoza', 12.0483000, -84.9936200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100467, 'Valle San Francisco', 'Valle San Francisco', '', 12.5166700, -86.2833300, 'NI', '2006-01-17', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100468, 'LLano de La Cruz', 'LLano de La Cruz', '', 13.1244900, -86.0083300, 'NI', '2017-01-23', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100469, 'Totogalpa', 'Totogalpa', 'Totogalpa', 13.5626900, -86.4923900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100470, 'Tola', 'Tola', 'Tola', 11.4392700, -85.9389100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100471, 'Tisma', 'Tisma', 'Tisma', 12.0819400, -86.0173900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100472, 'Tipitapa', 'Tipitapa', 'Tipitapa,Типитапа', 12.1973200, -86.0970600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100473, 'Ticuantepe', 'Ticuantepe', 'Ticuantepe', 12.0226300, -86.2049300, 'NI', '2016-01-03', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100474, 'Teustepe', 'Teustepe', 'Teustepe,Tuestepe', 12.4200200, -85.7996600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100475, 'Terrabona', 'Terrabona', 'Terabona,Terrabona', 12.7302800, -85.9647400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100476, 'Telpaneca', 'Telpaneca', 'Telpaneca', 13.5316600, -86.2871000, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100477, 'Telica', 'Telica', 'Telica', 12.5220000, -86.8593800, 'NI', '2013-04-04', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100478, 'Somoto', 'Somoto', 'Gorad Samota,Somotas,Somoto,somoto,suo mo tuo,swmwtw  madrys,Горад Самота,Сомото,سوموتو، مادریس,სომოტო,ソモト,索莫托,소모토', 13.4808200, -86.5820800, 'NI', '2013-06-28', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100479, 'Somotillo', 'Somotillo', 'Poyas,Somotillo', 13.0432800, -86.9064500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100480, 'Siuna', 'Siuna', 'SIU,Siuna,Suina', 13.7332100, -84.7772500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100481, 'Santo Tomás', 'Santo Tomas', 'Santa Tomas,Santo Tomas,Santo Tomás', 12.0693800, -85.0905900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100482, 'Santo Domingo', 'Santo Domingo', 'Santa Domingo,Santo Domingo', 12.2635600, -85.0807800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100483, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 11.7432100, -86.2141300, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100484, 'Santa Rosa del Peñón', 'Santa Rosa del Penon', 'Santa Rosa,Santa Rosa del Penon,Santa Rosa del Peñón', 12.8011600, -86.3699400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100485, 'Santa Lucía', 'Santa Lucia', 'Santa Lucia,Santa Lucía', 12.5326700, -85.7109900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100486, 'San Sebastián de Yalí', 'San Sebastian de Yali', 'San Sebastian de Yali,San Sebastián de Yalí,Yali,Yalí', 13.3051000, -86.1864100, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100487, 'San Ramón', 'San Ramon', 'San Ramon,San Ramón', 12.9234400, -85.8389800, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100488, 'San Rafael del Sur', 'San Rafael del Sur', 'San Rafael,San Rafael del Sur', 11.8485400, -86.4383900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100489, 'San Rafael del Norte', 'San Rafael del Norte', 'San Rafael del Norte', 13.2124800, -86.1105900, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100490, 'San Miguelito', 'San Miguelito', 'San Miguelito,San Miguellito', 11.4025500, -84.8999100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100491, 'San Marcos', 'San Marcos', 'San Marcos', 11.9094900, -86.2035100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100492, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 12.3778100, -85.6674100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100493, 'San Juan de Río Coco', 'San Juan de Rio Coco', 'San Juan,San Juan de Rio Coco,San Juan de Río Coco,San Juan de Telpaneca,San Juan del Rio Coco,San Juan del Río Coco', 13.5448300, -86.1650600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100494, 'San Juan de Oriente', 'San Juan de Oriente', 'San Juan,San Juan de Oriente', 11.9062400, -86.0734300, 'NI', '2015-12-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100495, 'San Juan del Sur', 'San Juan del Sur', 'San Juan del Sur', 11.2529200, -85.8704900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100496, 'San Juan de Limay', 'San Juan de Limay', 'Limay,San Juan de Limay', 13.1760300, -86.6123400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100497, 'San José de los Remates', 'San Jose de los Remates', 'San Jose,San Jose de los Remates,San José,San José de los Remates', 12.5972500, -85.7617000, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100498, 'San José de Cusmapa', 'San Jose de Cusmapa', 'Cusmapa,San Jose de Cusmapa,San José de Cusmapa', 13.2884100, -86.6553900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100499, 'San José de Bocay', 'San Jose de Bocay', 'San Jose de Bocay,San José de Bocay', 13.5420400, -85.5394200, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100500, 'San Jorge', 'San Jorge', 'San Jorge', 11.4558400, -85.8030800, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100501, 'San Fernando', 'San Fernando', 'San Fernando', 13.6772000, -86.3153000, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100502, 'San Dionisio', 'San Dionisio', 'San Dionisio', 12.7602300, -85.8501800, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100503, 'San Carlos', 'San Carlos', 'NCR,San Carlos,San Karlosas,San-Karlos,san karlws  ryw san khwan,sankaleulloseu,sheng ka luo si,Сан-Карлос,سان کارلوس، ریو سان خوان,სან-კარლოსი,聖卡洛斯,산카를로스', 11.1236000, -84.7779500, 'NI', '2013-06-28', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100504, 'Rivas', 'Rivas', 'ECI,Nicaragua,Rivas,Villa of Nicaragua,Ривас', 11.4371600, -85.8263200, 'NI', '2015-12-06', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100505, 'Río Blanco', 'Rio Blanco', 'Rio Blanco,Río Blanco', 12.9343500, -85.2235400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100506, 'Rama', 'Rama', 'Ciudad Rama,Rama,Ramy,Рамы', 12.1596500, -84.2195200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100507, 'Quilalí', 'Quilali', 'Quilali,Quilalí', 13.5669500, -86.0260000, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100508, 'Quezalguaque', 'Quezalguaque', 'Quesalguaque,Quezalguaque', 12.5068300, -86.9029200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100509, 'Puerto Morazán', 'Puerto Morazan', 'Morazan,Morazán,Puerto Morazan,Puerto Morazán', 12.8504200, -87.1716700, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100510, 'Puerto Cabezas', 'Puerto Cabezas', 'Bilwi,Bragman''s Bluff,Bragman’s Bluff,PUZ,Puehrto-Kabesas,Puerto Cabezas,Пуэрто-Кабесас', 14.0350700, -83.3888200, 'NI', '2014-10-17', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100511, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 13.3798400, -86.4807500, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100512, 'Potosí', 'Potosi', 'Potosi,Potosí', 11.4941600, -85.8568000, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100513, 'Posoltega', 'Posoltega', 'Posoletega,Posoltega', 12.5448100, -86.9799200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100514, 'Paso Real de Cuá', 'Paso Real de Cua', 'Paso Real de Cua,Paso Real de Cuá,Paso Real del Cua,Paso Real del Cuá', 13.3684400, -85.6733500, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100515, 'Palacagüina', 'Palacaguina', 'Palacaguina,Palacagüina', 13.4556600, -86.4062200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100516, 'Ocotal', 'Ocotal', 'Ocotal,Okotal'',Окоталь', 13.6320800, -86.4751600, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100517, 'Nuevo Amanecer', 'Nuevo Amanecer', 'Nuevo Amanecer,Tortuguero', 12.8224700, -84.1962900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100518, 'Nueva Guinea', 'Nueva Guinea', 'Colonia Nueva Guinea,NVG,Nueva Guinea', 11.6875800, -84.4561600, 'NI', '2015-05-31', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100519, 'Niquinohomo', 'Niquinohomo', 'Niqui,Niquinohomo,Niquinomo', 11.9051800, -86.0944600, 'NI', '2015-12-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100520, 'Nindirí', 'Nindiri', 'Nindiri,Nindirí', 12.0038600, -86.1212800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100521, 'Nandasmo', 'Nandasmo', 'Nandasma,Nandasmo', 11.9241100, -86.1207200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100522, 'Nandaime', 'Nandaime', 'Nandaime', 11.7569600, -86.0528600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100523, 'Nagarote', 'Nagarote', 'Nagarote,Nagorote', 12.2659300, -86.5647400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100524, 'Muy Muy', 'Muy Muy', 'Muy Muy', 12.7622400, -85.6291500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100525, 'Murra', 'Murra', 'Murra,San Juan,San Juan de Murra', 13.7585000, -86.0184300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100526, 'Muelle de los Bueyes', 'Muelle de los Bueyes', 'Muelle de los Bueyes', 12.0699900, -84.5350300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100527, 'Mozonte', 'Mozonte', 'Mosonte,Mozonte', 13.6603400, -86.4384100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100528, 'Moyogalpa', 'Moyogalpa', 'Moyogalpa', 11.5400600, -85.6979500, 'NI', '2016-02-12', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100529, 'Morrito', 'Morrito', 'El Morrito,Morrito,Puerto Morrito', 11.6211800, -85.0805200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100530, 'Matiguás', 'Matiguas', 'Matiguas,Matiguás', 12.8373400, -85.4621800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100531, 'Matagalpa', 'Matagalpa', 'Matagal''pa,Matagalpa,Матагальпа', 12.9255900, -85.9174700, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100532, 'Masaya', 'Masaya', 'Masaja,Masaya,ma sa ya,masaia,masaya,Масая,มาซายา,მასაია,マサヤ,馬薩亞', 11.9744400, -86.0941700, 'NI', '2010-11-24', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100533, 'Masatepe', 'Masatepe', 'Masatepe', 11.9184000, -86.1446700, 'NI', '2015-12-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100534, 'Masachapa', 'Masachapa', 'Masachapa,Puerto Masachapa,Puerto Somoza,Масачапа', 11.7868700, -86.5141600, 'NI', '2010-07-13', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100535, 'Managua', 'Managua', 'Gorad Managua,MGA,Managoua,Managua,Managuae,Managva,Managvo,Managûa,Manahuac,Manankoua,Manaqua,Manawa,Manágua,Mānāhuac,ma na gua,managhwa,managu''a,managua,managva,managwa,manakaw,manakuva,Μανάγκουα,Μανάγουα,Горад Манагуа,Манагва,Манагуæ,Манагуа,Մանագուա,מנגואה,ماناغوا,ماناگوآ,ماناگوا,ماناگۇئا,मानाग्वा,ਮਾਨਾਗੁਆ,மனாகுவா,มานากัว,མ་ན་གུ་འ།,მანაგუა,ማናጓ,マナグア,馬拿瓜,馬納瓜,마나과', 12.1328200, -86.2504000, 'NI', '2010-05-30', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100536, 'León', 'Leon', 'Gorad Leon,Leon,Leonas,León,lai ang,le-on,leoni,lywn  nkaragwa,reon,Λεόν,Горад Леон,Леон,לאון,لیون، نکاراگوا,ლეონი,レオン,莱昂,레온', 12.4378700, -86.8780400, 'NI', '2010-11-24', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100537, 'Las Sabanas', 'Las Sabanas', 'Las Sabanas,Pueblo La Sabana,Sabanas,Savanas', 13.3430200, -86.6218400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100538, 'Larreynaga', 'Larreynaga', 'Larreynaga', 12.6769200, -86.5719300, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100539, 'La Paz de Oriente', 'La Paz de Oriente', 'La Paz,La Paz de Oriente,Paz', 11.8233100, -86.1275600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100540, 'La Paz Centro', 'La Paz Centro', 'La Paz,La Paz Central,La Paz Centro,Paz Central', 12.3400000, -86.6752800, 'NI', '2016-10-06', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100541, 'La Libertad', 'La Libertad', 'La Libertad,Libertad', 12.2163500, -85.1659500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100542, 'Laguna de Perlas', 'Laguna de Perlas', 'English Bank,Laguna de Perlas,Las Perlas,Las Perlas Town,Los Perlos,Perla,Perlas', 12.3429400, -83.6712300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100543, 'La Cruz de Río Grande', 'La Cruz de Rio Grande', 'La Cruz,La Cruz de Rio Grande,La Cruz de Río Grande', 13.1129000, -84.1858800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100544, 'La Concordia', 'La Concordia', 'Concordia,La Concordia', 13.1952800, -86.1667400, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100545, 'La Concepción', 'La Concepcion', 'Concepcion,Concepción,La Cancepcion,La Cancepción,La Concepcion,La Concepción', 11.9371100, -86.1897600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100546, 'Juigalpa', 'Juigalpa', 'Juigalpa', 12.1062900, -85.3645200, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100547, 'Jiquilillo', 'Jiquilillo', 'Jiquilillo,Khikilijo,Tiguilillo,Хикилийо', 12.7459300, -87.4516000, 'NI', '2010-08-16', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100548, 'Jinotepe', 'Jinotepe', 'Jinotepe', 11.8496200, -86.1990300, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100549, 'Jinotega', 'Jinotega', 'Jinotega,Khinotega,Хинотега', 13.0883900, -85.9994000, 'NI', '2017-01-23', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100550, 'Jalapa', 'Jalapa', 'Jalapa,Khalapa,Халапа', 13.9222100, -86.1234600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100551, 'Granada', 'Granada', 'Gorad Granada,Granada,Granadae,Granado,Grenada,ge la na da,geulanada,granada,grynada  nkaragwa,guranada,Γρανάδα,Горад Гранада,Гранадæ,Гранада,Гренада,گرینادا، نکاراگوا,გრანადა,グラナダ,格拉纳达,그라나다', 11.9298800, -85.9560200, 'NI', '2013-06-28', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100552, 'Estelí', 'Esteli', 'Ehsteli,Esteli,Estelí,ai si te li,aystaly,eseutelli,esuteri,Εστελί,Эстели,ایستالی,ესტელი,エステリ,埃斯特利,에스텔리', 13.0918500, -86.3538400, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100553, 'El Viejo', 'El Viejo', 'Ehl''-V''ekho,El Viejo,Viejo,Эль-Вьехо', 12.6633000, -87.1672200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100554, 'El Sauce', 'El Sauce', 'El Sauce,Sauce', 12.8868700, -86.5390300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100555, 'El Rosario', 'El Rosario', 'El Rosario', 11.7775600, -86.3737400, 'NI', '2012-08-05', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100556, 'El Realejo', 'El Realejo', 'El Realejo,Realejo', 12.5430700, -87.1646600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100557, 'La Jicaral', 'La Jicaral', 'El Jicaral,Jicaral,Jicaro,La India Jicaral,La Jicaral', 12.7267600, -86.3805700, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100558, 'El Crucero', 'El Crucero', 'Crucero,El Cirucero,El Crucero', 11.9900800, -86.3095400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100559, 'El Ayote', 'El Ayote', 'El Ayote', 12.1904600, -85.2873700, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100560, 'El Almendro', 'El Almendro', 'Almendro,El Almendo,El Almendro', 11.6785900, -84.7026900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100561, 'Dolores', 'Dolores', 'Dolores', 11.8562100, -86.2157500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100562, 'Diriomo', 'Diriomo', 'Diriomo', 11.8761200, -86.0518400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100563, 'Diriamba', 'Diriamba', 'Diriamba,Diriambo', 11.8584200, -86.2387800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100564, 'Diriá', 'Diria', 'Diria,Diriá', 11.8842000, -86.0550800, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100565, 'Cuapa', 'Cuapa', 'Coapa,Cuapa', 12.2675600, -85.3819600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100566, 'Corn Island', 'Corn Island', 'Corn Island,RNI,South End', 12.1694300, -83.0417500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100567, 'Corinto', 'Corinto', 'Corinto', 12.4819900, -87.1733600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100568, 'Condega', 'Condega', 'Condega', 13.3650200, -86.3984600, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100569, 'Comalapa', 'Comalapa', 'Comalapa', 12.2834500, -85.5108100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100570, 'Ciudad Darío', 'Ciudad Dario', 'Ciudad Dario,Ciudad Darío,Dario,Metapa', 12.7314300, -86.1240200, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100571, 'Ciudad Antigua', 'Ciudad Antigua', 'Ciudad Antigua', 13.6406000, -86.3081500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100572, 'Chinandega', 'Chinandega', 'Chinandega,Chinandege,Чинандеге', 12.6293700, -87.1310500, 'NI', '2012-01-14', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100573, 'Chichigalpa', 'Chichigalpa', 'Chichigalpa', 12.5775800, -87.0270500, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100574, 'Catarina', 'Catarina', 'Catarina', 11.9119700, -86.0738300, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100575, 'Carlos Fonseca Amador', 'Carlos Fonseca Amador', 'Carlos Fonseca Amador,El Carmen,Villa Carlos Fonseca Amador,Villa El Carmen', 11.9800900, -86.5057100, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100576, 'Cárdenas', 'Cardenas', 'Cardenas,Concepcion,Concepción,Cárdenas,La Concepcion,La Concepción', 11.1963900, -85.5089000, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100577, 'Camoapa', 'Camoapa', 'Camaopa,Camoapa', 12.3838600, -85.5115700, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100578, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 11.4691600, -85.8166100, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100579, 'Bonanza', 'Bonanza', 'BZA,Bonanza,Bonanza Bodega', 14.0288500, -84.5910300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100580, 'Bocana de Paiwas', 'Bocana de Paiwas', 'Bocana de Paiwas,Paigua,Paiguas,Paiguás,Paiwas,San Jose de Paiwas,San José de Paiwas', 12.7857100, -85.1226900, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100581, 'Boaco', 'Boaco', 'Boaco', 12.4722400, -85.6586000, 'NI', '2013-06-28', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100582, 'Bluefields', 'Bluefields', 'BEF,Blewfield,Bluefields,Blufildse,Блуфилдсе', 12.0136600, -83.7635300, 'NI', '2013-05-05', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100583, 'Belén', 'Belen', 'Belen,Belén', 11.5029900, -85.8893500, 'NI', '2012-02-02', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100584, 'Altagracia', 'Altagracia', 'Altagracia', 11.5661500, -85.5784000, 'NI', '2016-02-12', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100585, 'Acoyapa', 'Acoyapa', 'Acoyapa,San Sebastian de Acoyapa', 11.9702800, -85.1711300, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100586, 'Achuapa', 'Achuapa', 'Achuapa,San Jose de Achuapa,San José de Achuapa', 13.0537000, -86.5900400, 'NI', '2012-01-18', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100587, 'Ciudad Sandino', 'Ciudad Sandino', 'Ciudad Sandino', 12.1588900, -86.3441700, 'NI', '2012-01-20', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100588, 'Santa Maía de Pantasma', 'Santa Maia de Pantasma', '', 13.3480900, -85.9445100, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100589, 'Wiwilí de Jinotega', 'Wiwili de Jinotega', '', 13.6149400, -85.8167600, 'NI', '2016-11-27', 160);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99766, 'Ogbede', 'Ogbede', '', 6.6729500, 7.3744100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99767, 'Ogaminana', 'Ogaminana', 'Ogaminan,Ogaminana', 7.5938300, 6.2179800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99768, 'Offa', 'Offa', 'Offa,Оффа', 8.1491100, 4.7207400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99769, 'Odukpani', 'Odukpani', '', 5.1337500, 8.3381400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99770, 'Odot', 'Odot', '', 4.8309500, 8.0383900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99771, 'Odoro Ikpe', 'Odoro Ikpe', 'Odoro Ikpe,Ududu Ikpe', 5.3583500, 7.7518400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99772, 'Odogbolu', 'Odogbolu', 'Odogbolo,Odogbolu', 6.8403500, 3.7628500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99773, 'Odo-Ere', 'Odo-Ere', 'Eri,Odo Ore,Odo-Ere', 8.2505700, 5.5497900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99774, 'Odeda', 'Odeda', 'Awdeda,Odeda,Odedah', 7.2325100, 3.5281900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99775, 'Ode', 'Ode', 'Awde,Oda,Ode,Ода', 7.7899000, 5.7117000, 'NG', '2012-01-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99776, 'Ode-Ekiti', 'Ode-Ekiti', 'Ode,Ode-Ekiti', 7.6481300, 5.5494800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99777, 'Ochobo', 'Ochobo', 'Ochobo,Ochobu', 7.1804500, 7.9824000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99778, 'Obudu', 'Obudu', '', 6.6681900, 9.1645300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99779, 'Obubra', 'Obubra', '', 6.0767200, 8.3324100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99780, 'Obonoma', 'Obonoma', 'Abonnema,Obonema,Obonoma', 4.7113100, 6.7908400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99781, 'Obolo-Eke (1)', 'Obolo-Eke (1)', 'Obolo Eke,Obolo-Eke (1)', 6.8833300, 7.6333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99782, 'Obollo-Afor', 'Obollo-Afor', 'Obollo-Afor,Obolo', 6.9162400, 7.5184900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99783, 'Obiaruku', 'Obiaruku', 'Obiariku,Obiaruku,Obiaruku Quarters', 5.8467200, 6.1529000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99784, 'Obi', 'Obi', 'Obi', 8.3692200, 8.7738300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99785, 'Nzam', 'Nzam', 'Nzam', 6.4529600, 6.7288200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99786, 'Nung Udoe', 'Nung Udoe', '', 4.9165700, 7.9631400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99787, 'Numan', 'Numan', 'Numan', 9.4637400, 12.0306200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99788, 'Nto Edino', 'Nto Edino', '', 5.2570400, 7.5756900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99789, 'Nteje', 'Nteje', 'Nteje', 6.2681000, 6.9206200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99790, 'Nsukka', 'Nsukka', 'Nsukka,QNK,Нсукка', 6.8578300, 7.3957700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99791, 'Isiokpo', 'Isiokpo', 'Isiokpo,Nsokpo', 5.0024300, 6.8726200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99792, 'Nnewi', 'Nnewi', 'Newi,Nnewi,Nnjuvi,Ннюви', 6.0196200, 6.9172900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99793, 'Nkwerre', 'Nkwerre', 'Nkwerre', 5.7591700, 7.1038400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99794, 'Nkpor', 'Nkpor', 'Mkpor,Nkpor', 6.1503800, 6.8304200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99795, 'Mkpat Enin', 'Mkpat Enin', 'Mkpat Enin,Nkpat Enin', 4.7347800, 7.7489700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99796, 'Ningi', 'Ningi', '', 11.0783700, 9.5688600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99797, 'Nguzu Edda', 'Nguzu Edda', 'Ngusu,Nguzu,Nguzu Edda', 5.7554300, 7.8172100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99798, 'Nguru', 'Nguru', 'N''gourou,Nguru,N’gourou', 12.8769500, 10.4553600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99799, 'Ngurore', 'Ngurore', 'Ngurore', 9.2887100, 12.2402600, 'NG', '2016-07-04', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99800, 'Ngo', 'Ngo', '', 4.4838800, 7.4144600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99801, 'Ngala', 'Ngala', '', 12.3405300, 14.1867000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99802, 'Wara', 'Wara', 'New Warra,Wara,Warra', 10.2288400, 4.6236300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99803, 'New Shagunnu', 'New Shagunnu', 'New Shagunnu,Shagunnu', 10.3395700, 4.4688000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99804, 'New Bussa', 'New Bussa', 'New Bussa', 9.8864400, 4.5085400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99805, 'Neni', 'Neni', '', 6.0951100, 7.0242600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99806, 'Nembe', 'Nembe', 'Nembe,Nimbi', 4.5367300, 6.4033200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99807, 'Ndeaboh', 'Ndeaboh', 'Ndeaboh,Ndeaboh Station', 6.0340500, 7.5684300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99808, 'Nasarawa Egon', 'Nasarawa Egon', 'Nasarawa Egon,Nassarawa Eggon,Nassarawa Egon,Nassarawan Eggon', 8.7122600, 8.5406000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99809, 'Nasarawa', 'Nasarawa', 'Nasarawa,Nassarava,Nassarawa,Нассарава', 8.5389500, 7.7082100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99810, 'Nafada', 'Nafada', 'Nafada', 11.0959600, 11.3326100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99811, 'Mutum Biyu', 'Mutum Biyu', 'Mutum Biyu,Mutum Mbiyu,Mutumbiyu', 8.6413800, 10.7735500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99812, 'Mushin', 'Mushin', 'Mushin,Mushin Halt', 6.5279900, 3.3541100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99813, 'Musawa', 'Musawa', 'Musawa', 12.1294900, 7.6702300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99814, 'Mubi', 'Mubi', 'Mubi,Муби', 10.2685800, 13.2670100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99815, 'Moriki', 'Moriki', '', 12.8740500, 6.4875400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99816, 'Mopa', 'Mopa', 'Mopa,Mope', 8.1038700, 5.8928000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99817, 'Moniya', 'Moniya', 'Mawniya,Moniya', 7.5284300, 3.9115600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99818, 'Monguno', 'Monguno', 'Mongono,Mongonu,Monguno', 12.6705900, 13.6122400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99819, 'Mangu', 'Mangu', 'Mangu,Mongu,Mongu Hausawa', 9.5206000, 9.0976900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99820, 'Mokwa', 'Mokwa', '', 9.2948200, 5.0541200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99821, 'Modakeke', 'Modakeke', '', 7.3833300, 4.2666700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99822, 'Bolorunduro', 'Bolorunduro', 'Bolorunduro,Mobaolorunduro,Mobolonduro,Mobolorunduro', 7.1658600, 4.9637000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99823, 'Misau', 'Misau', '', 11.3137000, 10.4666400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99824, 'Miringa', 'Miringa', 'Maringa,Meringa,Miringa', 10.7311500, 12.1462600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99825, 'Minna', 'Minna', 'MXJ,Minna,ming na,minna,myna  nayjyrya,Минна,Мінна,مینا، نائجیریا,明納,민나', 9.6152400, 6.5477600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99826, 'Minjibir', 'Minjibir', '', 12.1776500, 8.6578200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99827, 'Miga', 'Miga', 'Miga', 12.2388000, 9.7136200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99828, 'Michika', 'Michika', 'Michika', 10.6204200, 13.3892800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99829, 'Imeko', 'Imeko', 'Imeko,Mekkaw,Meko', 7.4488800, 2.8428900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99830, 'Mgbidi', 'Mgbidi', 'Mbidi,Mgbidi', 5.7323600, 6.8886900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99831, 'Mberubu', 'Mberubu', '', 6.1731000, 7.6301700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99832, 'Mbalano', 'Mbalano', 'Mbalano,Nbalano', 5.7343200, 7.5023800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99833, 'Mayo-Belwa', 'Mayo-Belwa', 'Maya Belwa,Mayo Balwa,Mayo-Belwa', 9.0542100, 12.0579400, 'NG', '2016-07-04', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99834, 'Machina', 'Machina', 'Machina,Matsena', 13.1363900, 10.0492400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99835, 'Matazu', 'Matazu', 'Matasu,Mataza,Matazu', 12.2354900, 7.6742600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99836, 'Mashi', 'Mashi', 'Mashi', 12.9804400, 7.9470300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99837, 'Maru', 'Maru', '', 12.3336000, 6.4037200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99838, 'Marte', 'Marte', 'Marte,Marte-Kuna', 12.3653200, 13.8293000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99839, 'Maradun', 'Maradun', '', 12.5670400, 6.2440700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99840, 'Mani', 'Mani', '', 12.8542600, 7.8752600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99841, 'Mando', 'Mando', '', 10.7166700, 6.5666700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99842, 'Malumfashi', 'Malumfashi', 'Malumfashi', 11.7893500, 7.6206100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99843, 'Mallam Sidi', 'Mallam Sidi', 'Malam Sidi,Mallam Sidi,Mallamsidi', 10.4683000, 11.2929400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99844, 'Mallammaduri', 'Mallammaduri', 'Malam-Maduri,Malamaduri,Mallammaduri,Malummaduri', 12.5642700, 9.9572700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99845, 'Makurdi', 'Makurdi', 'MDI,Makurdi,Makurdu,ma ku er di,makuleudi,makwrdy,Макурди,Макурді,ماکوردی,马库尔迪,마쿠르디', 7.7337500, 8.5213900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99846, 'Makoko', 'Makoko', 'Makoko', 6.4961100, 3.3877800, 'NG', '2013-05-05', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99847, 'Makera', 'Makera', 'Makare,Makera', 10.4714000, 7.4102600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99848, 'Makarfi', 'Makarfi', '', 11.3773400, 7.8809800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99849, 'Maiyama', 'Maiyama', 'Maiyama,Maiyema', 12.0822500, 4.3690700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99850, 'Maikunkele', 'Maikunkele', 'Maikonkele,Maikonkole,Maikunkele', 9.6843000, 6.4788900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99851, 'Maiha', 'Maiha', 'Maiha', 9.9967200, 13.2166500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99852, 'Maigatari', 'Maigatari', '', 12.8078300, 9.4451600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99853, 'Maigana', 'Maigana', 'Maigama,Maigana', 11.0270700, 7.9384400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99854, 'Maiduguri', 'Maiduguri', 'MIU,Maidiguri,Maidugari,Maiduguri,Maiduguris,Majduguri,mai du gu li,maido~uguri,maiduguli,maydwghwry,mydwgwry,Маидугури,Майдугури,Майдугурі,מידוגורי,مايدوغوري,マイドゥグリ,邁杜古里,마이두구리', 11.8469200, 13.1571200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99855, 'Mai’Adua', 'Mai''Adua', 'Mai''Adua,Maiadua,Maiaduwa,Mai’Adua', 13.1798600, 8.2304000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99856, 'Mahuta', 'Mahuta', '', 11.5533800, 4.9813800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99857, 'Magumeri', 'Magumeri', '', 12.1145100, 12.8262000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99858, 'Mafa', 'Mafa', 'Mafa,Moufi', 11.9241700, 13.6006600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99859, 'Madobi', 'Madobi', 'Madobi,Maidobi', 11.7772500, 8.2880100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99860, 'Madara', 'Madara', '', 11.7798000, 10.4479000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99861, 'Madala', 'Madala', 'Madala,Madalla', 9.1044400, 7.2133300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99862, 'Madagali', 'Madagali', '', 10.8894200, 13.6283200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99863, 'Lokoja', 'Lokoja', 'Lairdstown,Lokoja,Zokoja', 7.7968800, 6.7404800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99864, 'Lere', 'Lere', 'Lera,Lere,Leri,Лера', 10.3858400, 8.5728600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99865, 'Lere', 'Lere', 'Lere', 9.7105200, 9.3402900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99866, 'Lemu', 'Lemu', '', 9.3963700, 6.0279100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99867, 'Lau', 'Lau', 'Lau', 9.2082700, 11.2754100, 'NG', '2016-11-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99868, 'Lapai', 'Lapai', 'Badeggi,Badeji,Lapai', 9.0443900, 6.5708900, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99869, 'Langtang', 'Langtang', 'Langtang', 9.1416400, 9.7910100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99870, 'Lamurde', 'Lamurde', 'Lamurde', 9.6081600, 11.7931500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99871, 'Lame', 'Lame', 'Lame,Lemme,Lemmi', 10.4415400, 9.2395500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99872, 'Lalupon', 'Lalupon', '', 7.4666700, 4.0666700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99873, 'Lagos', 'Lagos', 'Eko,Gorad Lagas,LOS,Lacupolis,Lagos,Lagos shaary,Lagosa,Lagosas,Lagoso,Laguosos,Laqos,Logos,la ge si,lageas,laghws,lagos,lagosa,lagoseu,lagosi,laguseu,lagws,lajws,lakos,legosa,lek xs,ragosu,Èkó,Λάγος,Горад Лагас,Лагос,Лагос шаары,Лаґос,Լագոս,לאגאס,לאגוס,لاجوس,لاغوس,لاگوس,لاگۆس,लागोस,লেগোস,ਲਾਗੋਸ,લાગોસ,லாகோஸ்,లాగోస్,ಲಾಗೊಸ್,ലാഗോസ്,เลกอส,လေးဂို့စ်မြို့,ლაგოსი,ሌጎስ,ラゴス,拉哥斯,라고스,라구스', 6.4540700, 3.3946700, 'NG', '2017-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99874, 'Lafiagi', 'Lafiagi', '', 8.8529900, 5.4164100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99875, 'Lafia', 'Lafia', 'Lafia,Lafia Beriberi', 8.4939000, 8.5153200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99876, 'Kwolla', 'Kwolla', 'Kwalla,Kwolla', 8.9036100, 9.2908600, 'NG', '2016-02-06', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99877, 'Kwoi', 'Kwoi', 'Fadan Kwai,Kwoi', 9.4574500, 8.0068400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99878, 'Kwaya Kusar', 'Kwaya Kusar', 'Kawaya Tera,Kwaia,Kwaya,Kwaya Kusar,Kwaya Tera,Kwaya Terra', 10.5029600, 11.8433100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99879, 'Kwatarkwashi', 'Kwatarkwashi', 'Kotorkoshi,Kotorkushi,Kwatarkwashi', 12.1408200, 6.8219600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99880, 'Kware', 'Kware', 'Kware', 13.2196900, 5.2659600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99881, 'Kwali', 'Kwali', '', 8.8834600, 7.0185800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99882, 'Kwale', 'Kwale', 'Kwale,Kwale Station,Obetim', 5.7077300, 6.4340200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99883, 'Kutigi', 'Kutigi', '', 9.2010300, 5.5949800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99884, 'Kuta', 'Kuta', '', 9.8686400, 6.7104200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99885, 'Kusheriki', 'Kusheriki', 'Kusheriki,Kusherki', 10.5328300, 6.4422200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99886, 'Kusada', 'Kusada', 'Kusada', 12.4656000, 7.9784800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99887, 'Kurfi', 'Kurfi', 'Kurfi', 12.6663000, 7.4847800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99888, 'Kura', 'Kura', '', 11.7723200, 8.4263100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99889, 'Kunchi', 'Kunchi', '', 12.5026000, 8.2709200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99890, 'Kumo', 'Kumo', '', 10.0480700, 11.2105500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99891, 'Kumbotso', 'Kumbotso', 'Kum Botso,Kumbotso', 11.8900200, 8.5030000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99892, 'Kumagunnam', 'Kumagunnam', 'Kumaganum,Kumagunam,Kumagunnam', 13.1549800, 10.6346800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99893, 'Kukawa', 'Kukawa', 'Koukaoua,Koukawa,Kukawa', 12.9247500, 13.5661700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99894, 'Kuje', 'Kuje', 'Kuje', 8.8795200, 7.2275600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99895, 'Kujama', 'Kujama', '', 10.4576700, 7.6380800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99896, 'Kpor', 'Kpor', '', 4.6526500, 7.2839700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99897, 'Koton-Karfe', 'Koton-Karfe', 'Koton Karifi,Koton-Karfe', 8.0912000, 6.7978200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99898, 'Kosubosu', 'Kosubosu', '', 9.5510700, 3.2284100, 'NG', '2015-03-08', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99899, 'Kontagora', 'Kontagora', 'Kontagora', 10.4031900, 5.4708000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99900, 'Konkwesso', 'Konkwesso', 'Konkweso,Konkwesso', 10.8468600, 4.0983500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99901, 'Konduga', 'Konduga', 'Kanduga,Konduga', 11.6533100, 13.4178700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99902, 'Koko', 'Koko', 'Koko,Koko Town', 6.0008400, 5.4552300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99903, 'Kiyawa', 'Kiyawa', 'Kiyawa', 11.7844200, 9.6069000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99904, 'Kisi', 'Kisi', 'Kishi,Kisi', 9.0829700, 3.8519600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99905, 'Kiru', 'Kiru', '', 11.7021000, 8.1348100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99906, 'Karkarna', 'Karkarna', 'Karkarna,Kirkirna', 12.7665300, 8.5098100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99907, 'Kiri Kasamma', 'Kiri Kasamma', 'Kiri Kasama,Kiri Kasamma,Kirikasama,Kirikasamma', 12.6927300, 10.2545600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99908, 'Kirfi', 'Kirfi', 'Kirfi,Kirfin Kasa,Kirifi', 10.4055600, 10.4045100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99909, 'Auyo', 'Auyo', 'Auyo,Kiggin', 12.3333800, 9.9389100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99910, 'Kibiya', 'Kibiya', 'Kibiya', 11.5280000, 8.6610800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99911, 'Kende', 'Kende', '', 11.5196600, 4.2603000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99912, 'Kafin Hausa', 'Kafin Hausa', 'Kaffin-Hausa,Kafin Hausa,Keffin Hausa', 12.2393300, 9.9110500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99913, 'Keffi', 'Keffi', '', 8.8465100, 7.8735400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99914, 'Kebbe', 'Kebbe', 'Kebba,Kebbe,Kebbi', 12.1286100, 4.7343300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99915, 'Keana', 'Keana', '', 8.1472400, 8.7960100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99916, 'Kazaure', 'Kazaure', 'Kazaure', 12.6484600, 8.4117800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99917, 'Kauru', 'Kauru', 'Kauru', 10.5760100, 8.1509600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99918, 'Kaura Namoda', 'Kaura Namoda', 'Kaura Namoda', 12.5937100, 6.5864800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99919, 'Kaugama', 'Kaugama', 'Kaugama', 12.4743100, 9.7367100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99920, 'Katsina-Ala', 'Katsina-Ala', 'Katsena Ala,Katsina-Ala', 7.1693800, 9.2846500, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99921, 'Katsina', 'Katsina', 'DKA,Kacina,Katsina,Kàtsínà,ka qi na,kachina,Катсина,卡齐纳,카치나', 12.9908200, 7.6017700, 'NG', '2017-04-14', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99922, 'Katcha', 'Katcha', '', 8.7607600, 6.3120000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99923, 'Warji', 'Warji', 'Katanga Warji,Katangan Warji,Warji', 11.1775600, 9.7524100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99924, 'Katagum', 'Katagum', 'Katagum', 12.2850700, 10.3502700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99925, 'Karim Lamido', 'Karim Lamido', 'Karim Lamido,Karmi Lamido,Kogin Lamido', 9.3143000, 11.1873100, 'NG', '2016-11-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99926, 'Kari', 'Kari', '', 11.2471000, 10.5610000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99927, 'Karaye', 'Karaye', 'Karaye', 11.7836000, 8.0150400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99928, 'Kano', 'Kano', 'Byen Kano,Cano,Gorad Kano,KAN,Kanas,Kano,Kánò,ka nuo,kano,kanw,kanw  nyjryh,qnw,Горад Кано,Кано,קנו,كانو,کانو,کانو، نیجریه,कानो,ਕਾਨੋ,கனோ,カノ,卡諾,카노', 12.0001200, 8.5167200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99929, 'Kankia', 'Kankia', 'Kankia,Kankiya', 12.5463700, 7.8225400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99930, 'Kankara', 'Kankara', '', 11.9311400, 7.4111500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99931, 'Kamba', 'Kamba', 'Kamba,Kambo,Камба', 11.8517200, 3.6547800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99932, 'Kaltungo', 'Kaltungo', 'Kalfungo,Kaltungo', 9.8199800, 11.3087100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99933, 'Kalgo', 'Kalgo', '', 12.3266600, 4.2004000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99934, 'Kajuru', 'Kajuru', '', 10.3228100, 7.6846200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99935, 'Kaita', 'Kaita', '', 13.0834600, 7.7409200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99936, 'Kangiwa', 'Kangiwa', 'Kaingiwa,Kangiwa', 12.5533900, 3.8181400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99937, 'Kaiama', 'Kaiama', 'Kaiama,Kaima', 9.6053000, 3.9410100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99938, 'Kaiama', 'Kaiama', '', 5.1197000, 6.3010100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99939, 'Kagoro', 'Kagoro', 'Kagoro', 9.6077600, 8.3904300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99940, 'Kagarko', 'Kagarko', '', 9.4911000, 7.6977100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99941, 'Kagara', 'Kagara', '', 10.1866200, 6.2548500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99942, 'Kafur', 'Kafur', '', 11.6458900, 7.6906800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99943, 'Kafin Madaki', 'Kafin Madaki', 'Kafin Madaki,Keffin Madaki,L. Makaki,Madaki', 10.6885600, 9.7605100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99944, 'Kafarati', 'Kafarati', 'Kafarati,Kafareti', 10.3830400, 11.0956700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99945, 'Kafanchan', 'Kafanchan', 'Kafachan,Kafanchan,Kafanchan Junction,Kajanchan', 9.5812600, 8.2926000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99946, 'Lissam', 'Lissam', 'Kaduna Lissam,Lissam', 7.1961000, 10.0462000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99947, 'Kaduna', 'Kaduna', 'Gorad Kaduna,KAD,Kadun,Kaduna,Kaduno,Kàdúná,ka du na,kado~una,kaduna,kadwna,qdwnh,Горад Кадуна,Кадуна,קדונה,كادونا,کادونا,ਕਾਦੂਨਾ,カドゥナ,卡杜納,카두나', 10.5264100, 7.4387900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99948, 'Kachia', 'Kachia', '', 9.8734200, 7.9540700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99949, 'Kabo', 'Kabo', '', 11.8560600, 8.1702000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99950, 'Kabba', 'Kabba', 'Kabba', 7.8271900, 6.0750200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99951, 'Jos', 'Jos', 'Dzhos,Dzos,Dżos,JOS,Jos,joseu,josu,jws,jws  nayjyrya,qiao si,Џос,Джос,Йос,جوس,جوس، نائجیریا,ジョス,乔斯,조스', 9.9284900, 8.8921200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99952, 'Jobele', 'Jobele', '', 7.7630000, 3.9193500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99953, 'Jimeta', 'Jimeta', 'Jimeta', 9.2794900, 12.4581900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99954, 'Jikamshi', 'Jikamshi', '', 12.1732800, 7.7742400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99955, 'Jibia', 'Jibia', 'Djibia,Jibia,Jibiya', 13.0937800, 7.2262400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99956, 'Jega', 'Jega', '', 12.2221900, 4.3796300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99957, 'Jebba', 'Jebba', 'Djebba,Jebba', 9.1333300, 4.8333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99958, 'Angware', 'Angware', 'Angware,Jarawa', 9.9910500, 9.1081100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99959, 'Jama’are', 'Jama''are', 'Jama''are,Jamaare,Jamaari,Jama’are,Jemma''are,Jemma’are', 11.6698000, 9.9280000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99960, 'Jalingo', 'Jalingo', 'Jalingo', 8.8936700, 11.3596000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99961, 'Jakusko', 'Jakusko', 'Jakusko,Jasuko', 12.3709300, 10.7737300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99962, 'Jajimaji', 'Jajimaji', 'Jaji Maji,Jajimaji,Jajimari', 12.8985000, 10.8068800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99963, 'Lajere', 'Lajere', 'Jajere,Lajere', 11.9802200, 11.4400200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99964, 'Jahun', 'Jahun', 'Jahun', 12.0762900, 9.6275700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99965, 'Jada', 'Jada', '', 8.7568200, 12.1553700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99966, 'Iye-Ekiti', 'Iye-Ekiti', 'Aye,Iye,Iye-Ekiti', 7.9545700, 5.2331400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99967, 'Iyara', 'Iyara', 'Ilukpa,Iyara,Lupa', 7.8432500, 5.9706100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99968, 'Iwo', 'Iwo', 'Ivo,Iwo,Иво', 7.6352700, 4.1815600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99969, 'Iwere-Ile', 'Iwere-Ile', 'Iwere,Iwere-Ile', 7.9991900, 3.0882700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99970, 'Itu', 'Itu', '', 5.4639500, 7.3307800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99971, 'Itu', 'Itu', '', 5.2013100, 7.9837300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99972, 'Itori', 'Itori', '', 6.9312300, 3.2214700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99973, 'Obarike-Ito', 'Obarike-Ito', 'Ito,Obarike-Ito,Oborike-Ito', 7.0245000, 8.3235800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99974, 'Itigidi', 'Itigidi', '', 5.8914700, 8.0218700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99975, 'Itas', 'Itas', 'Itas,Itass', 11.8575000, 9.9639400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99976, 'Ita-Ogbolu', 'Ita-Ogbolu', 'Ita-Ogbolu,Itaogbolu', 7.3683800, 5.2468400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99977, 'Isu', 'Isu', '', 6.1500200, 7.8013100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99978, 'Issele-Uku', 'Issele-Uku', 'Issele-Uku', 6.3158400, 6.4759900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99979, 'Isiokolo', 'Isiokolo', 'Isiokolo,Isiokolo-Agbon,Islokolo', 5.5958600, 6.0002800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99980, 'Isieke', 'Isieke', 'Isieke', 6.3818600, 8.0373600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99981, 'Isua', 'Isua', 'Ishua,Isua,Isua Akoko', 7.4536100, 5.9104700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99982, 'Iseyin', 'Iseyin', 'Iseyin', 7.9702200, 3.5962600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99983, 'Ise-Ekiti', 'Ise-Ekiti', 'Ise,Ise-Ekiti', 7.4647800, 5.4233300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99984, 'Isara', 'Isara', 'Isara,Isara-Remo,Ishara', 6.9934500, 3.6814800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99985, 'Isanlu-Itedoijowa', 'Isanlu-Itedoijowa', '', 8.2744500, 5.8352800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99986, 'Isanlu', 'Isanlu', 'Isanlu,Isanlu-Itedo', 8.2882300, 5.8183700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99987, 'Isa', 'Isa', '', 13.2006600, 6.4048700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99988, 'Iresa-Adu', 'Iresa-Adu', 'Iresa,Iresa-Adu,Iresa-Du,Iresadu,Iressa', 8.0874700, 4.3926400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99989, 'Ode-Irele', 'Ode-Irele', 'Irele,Ode-Irele', 6.4941800, 4.8703600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99990, 'Iragbiji', 'Iragbiji', 'Iragbiji', 7.9040000, 4.6870500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99991, 'Ipoti', 'Ipoti', '', 7.8737700, 5.0769100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99992, 'Ipokia', 'Ipokia', 'Ipokia', 6.5249900, 2.8424600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99993, 'Ipetumodu', 'Ipetumodu', 'Ipetumodu,Ipetymodu', 7.5215200, 4.4447700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99994, 'Iperu', 'Iperu', '', 6.9100200, 3.6655700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99995, 'Iperindo', 'Iperindo', '', 7.5011900, 4.8247700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99996, 'Inisa', 'Inisa', '', 7.8500000, 4.3333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99997, 'Ingawa', 'Ingawa', 'Ingawa', 12.6413800, 8.0516200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99998, 'Ilorin', 'Ilorin', 'Gorad Iloryn,ILR,Illorin,Ilorin,Ilorinas,alwrn,illolin,irorin,yi luo lin,Горад Ілорын,Илорин,אילורין,الورن,イロリン,伊洛林,일로린', 8.4966400, 4.5421400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(99999, 'Iloffa', 'Iloffa', 'Ilofa,Iloffa', 8.0934300, 5.1423300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100000, 'Ilobu', 'Ilobu', 'Ilobu', 7.8403600, 4.4855700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100001, 'Illushi', 'Illushi', 'Illushi', 6.6703300, 6.6290700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100002, 'Illela', 'Illela', '', 13.7306400, 5.2977700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100003, 'Ilesa', 'Ilesa', 'Ilesa,Ilesha', 7.6278900, 4.7416100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100004, 'Ile-Oluji', 'Ile-Oluji', '', 7.2130900, 4.8690200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100005, 'Ilemona', 'Ilemona', 'Ilemana,Ilemona', 8.1099200, 4.6605900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100006, 'Ile-Ogbo', 'Ile-Ogbo', 'Ile-Igbo,Ile-Ogbo', 7.6212900, 4.2453100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100007, 'Ilawe-Ekiti', 'Ilawe-Ekiti', 'Ilae,Ilawe,Ilawe-Ekiti', 7.5988100, 5.1047000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100008, 'Ilaro', 'Ilaro', 'Ilaro', 6.8890100, 3.0141600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100009, 'Ilare', 'Ilare', 'Ilara,Ilare', 7.3506700, 5.1133300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100010, 'Ila Orangun', 'Ila Orangun', 'Ila,Ila Orangun', 8.0171400, 4.9042100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100011, 'Ikoyi-Ile', 'Ikoyi-Ile', 'Ikoyi,Ikoyi-Ile', 8.2444000, 4.1718100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100012, 'Ikoyi', 'Ikoyi', 'Ikoyi,Okepa', 6.4525400, 3.4358400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100013, 'Ikotun', 'Ikotun', 'Iko Tun,Ikotan,Ikotun', 6.5443300, 3.2637900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100014, 'Ikot Nakanda', 'Ikot Nakanda', '', 4.8842600, 8.4837900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100015, 'Ikot Ibritam', 'Ikot Ibritam', 'Ikot Ibritam,Ikot Ibritan', 4.8117100, 7.6140100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100016, 'Ikot Ekpene', 'Ikot Ekpene', 'Ikot Ekpene', 5.1819400, 7.7148100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100017, 'Afaha Ikot Ebak', 'Afaha Ikot Ebak', 'Afaha Ikot Ebak,Afaha-Iko-Ebat,Ikot Ebak,Ikot Ebak Efagha', 5.1250400, 7.6571600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100018, 'Ikorodu', 'Ikorodu', 'Ikorodu', 6.6152600, 3.5069000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100019, 'Ikom', 'Ikom', '', 5.9666900, 8.7063200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100020, 'Ikole-Ekiti', 'Ikole-Ekiti', 'Ikole,Ikole-Ekiti', 7.7914800, 5.5086500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100021, 'Ikirun', 'Ikirun', 'Ikirun', 7.9128300, 4.6674100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100022, 'Ikire', 'Ikire', 'Ikire', 7.3724100, 4.1873900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100023, 'Ikere-Ekiti', 'Ikere-Ekiti', 'Ikare,Ikere,Ikere-Ekiti,Ikerre', 7.4974800, 5.2304100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100024, 'Ikenne', 'Ikenne', 'Ikene,Ikenne', 6.8657900, 3.7151800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100025, 'Ikem', 'Ikem', '', 6.7799300, 7.7148400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100026, 'Ikeja', 'Ikeja', 'Ikeja', 6.5965100, 3.3420500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100027, 'Ikare', 'Ikare', 'Ikare,Ikare-Akoko', 7.5259100, 5.7534200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100028, 'Ikara', 'Ikara', 'Ikara', 11.1751100, 8.2246600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100029, 'Ikang', 'Ikang', '', 4.7897800, 8.5316000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100030, 'Iju', 'Iju', '', 7.3945200, 5.2591900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100031, 'Ijero-Ekiti', 'Ijero-Ekiti', 'Ijero,Ijero-Ekiti', 7.8151400, 5.0671600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100032, 'Ijebu-Ode', 'Ijebu-Ode', 'Ijebu Ode,Ijebu-Ode', 6.8194400, 3.9173100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100033, 'Ijebu-Jesa', 'Ijebu-Jesa', 'Ijebu-Ijesa,Ijebu-Ijesha,Ijebu-Jesa,Ijebu-Jesha', 7.6826700, 4.8143600, 'NG', '2017-03-24', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100034, 'Ijebu-Igbo', 'Ijebu-Igbo', 'Ijebu-Igbo', 6.9719800, 3.9993800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100035, 'Ijebu-Ife', 'Ijebu-Ife', '', 6.7783700, 4.0338600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100036, 'Iho', 'Iho', 'Iho,Ihuo', 5.5822500, 7.0989600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100037, 'Ihiala', 'Ihiala', 'Ihiala', 5.8547500, 6.8594400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100038, 'Iguobazuwa', 'Iguobazuwa', 'Iguobazowa,Iguobazuwa', 6.5653600, 5.3544300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100039, 'Igumale', 'Igumale', 'Igumale', 6.7979200, 7.9679400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100040, 'Igede-Ekiti', 'Igede-Ekiti', 'Igbede,Igede,Igede-Ekiti', 7.6685000, 5.1262700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100041, 'Igbo-Ukwu', 'Igbo-Ukwu', 'Igbo,Igbo-Ukwu', 6.0179800, 7.0202700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100042, 'Igbor', 'Igbor', '', 7.4512300, 8.6080500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100043, 'Igbo-Ora', 'Igbo-Ora', 'Igbo-Awra,Igbo-Ora', 7.4338300, 3.2878800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100044, 'Igbokoda', 'Igbokoda', '', 6.3526600, 4.8040600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100045, 'Igboho', 'Igboho', 'Igboho', 8.8378400, 3.7562800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100046, 'Igbeti', 'Igbeti', 'Igbeti,Igbetti', 8.7492100, 4.1311300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100047, 'Igbekebo', 'Igbekebo', 'Gbekebo,Igbekebo', 6.3552100, 4.8622100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100048, 'Igbara-Oke', 'Igbara-Oke', 'Igbara-Oke,Igbaraoke', 7.4117200, 5.0580500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100049, 'Igbara-Odo', 'Igbara-Odo', 'Igbara-Odo,Igbarra-Odo', 7.5025100, 5.0625800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100050, 'Igarra', 'Igarra', 'Igara,Igarra', 7.2936600, 6.1043200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100051, 'Igabi', 'Igabi', 'Igabi', 10.8060300, 7.7144300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100052, 'Ifon', 'Ifon', '', 7.8599200, 4.4762100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100053, 'Ifon', 'Ifon', '', 6.9297300, 5.7736800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100054, 'Ifo', 'Ifo', 'Ifaw,Ifo', 6.8149100, 3.1951800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100055, 'Ifetedo', 'Ifetedo', '', 7.1841900, 4.7004600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100056, 'Ile-Ife', 'Ile-Ife', 'Ife,Ile-Ife', 7.4824000, 4.5603200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100057, 'Ifaki', 'Ifaki', '', 7.7894200, 5.2485200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100058, 'Idu', 'Idu', '', 5.0300500, 8.0171600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100059, 'Idogbo', 'Idogbo', '', 6.2681200, 5.7129600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100060, 'Idi Iroko', 'Idi Iroko', 'Idi Iroko,Idiroko', 6.6333300, 2.7333300, 'NG', '2013-05-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100061, 'Idi-Ayunre', 'Idi-Ayunre', '', 7.2329200, 3.8615200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100062, 'Ido-Ekiti', 'Ido-Ekiti', 'Iddo,Iddo-Ekiti,Ido,Ido-Ekiti', 7.8459800, 5.1831400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100063, 'Ido', 'Ido', 'Iddo,Ido', 7.4710300, 3.7574000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100064, 'Idanre', 'Idanre', '', 7.1127000, 5.1159000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100065, 'Idah', 'Idah', 'Idah', 7.1134500, 6.7386600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100066, 'Icheu', 'Icheu', '', 7.7067000, 6.7718000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100067, 'Ibokun', 'Ibokun', 'Ibokun', 7.7849200, 4.7265300, 'NG', '2016-03-10', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100068, 'Iboko', 'Iboko', '', 6.4065500, 8.2332900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100069, 'Ibi', 'Ibi', '', 8.1812200, 9.7443100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100070, 'Ibeto', 'Ibeto', '', 10.4853600, 5.1450100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100071, 'Ibagwa-Aka', 'Ibagwa-Aka', 'Abagwa Aka,Ibagwa-Aka,Ibegwa-Aka', 6.9185400, 7.3989500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100072, 'Ibadan', 'Ibadan', 'Gorad Ibadan,IBA,Ibadan,Ibadan shaary,Ibadana,Ibadanas,Ibadano,Ibadán,abadan,aybadan,ibadan,ibadana,yi ba dan,Ìbàdàn,İbadan,Ібадан,Горад Ібадан,Ибадан,Ибадан шаары,איבדאן,إبادان,إيبادان,ابادان,ਇਬਾਦਾਨ,イバダン,伊巴丹,이바단', 7.3775600, 3.9059100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100073, 'Hunkuyi', 'Hunkuyi', '', 11.2668000, 7.6491600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100074, 'Hong', 'Hong', '', 10.2330500, 12.9280500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100075, 'Holma', 'Holma', '', 9.8986300, 13.0545000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100076, 'Hinna', 'Hinna', '', 10.3042600, 11.4990500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100077, 'Hadejia', 'Hadejia', 'Hadejia', 12.4534700, 10.0411500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100078, 'Gwoza', 'Gwoza', 'Gwoza', 11.0831300, 13.6959500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100079, 'Ugwolawo', 'Ugwolawo', 'Gwalawo,Gwolawo,Ogwoawo,Ugbwolawo,Ugwalawo,Ugwolawo', 7.2367200, 6.9230200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100080, 'Gwiwa', 'Gwiwa', '', 12.7816900, 8.3372200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100081, 'Gwio Kura', 'Gwio Kura', 'Gwio Kura', 12.6747900, 11.0669000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100082, 'Gwasero', 'Gwasero', '', 9.4833300, 3.5000000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100083, 'Gwarzo', 'Gwarzo', 'Gwarzo', 11.9159700, 7.9337000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100084, 'Gwaram', 'Gwaram', 'Gwaram,Old Gwaram', 11.2772700, 9.8838500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100085, 'Gwaram', 'Gwaram', 'Gwaram', 10.2329500, 10.2857200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100086, 'Gwantu', 'Gwantu', '', 9.2289900, 8.4580700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100087, 'Gwandu', 'Gwandu', '', 12.5020400, 4.6429500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100088, 'Gwagwalada', 'Gwagwalada', 'Gwagwalada,Gwagwaldda', 8.9434200, 7.0816500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100089, 'Gwadabawa', 'Gwadabawa', 'Gwadabawa', 13.3581900, 5.2381200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100090, 'Guyuk', 'Guyuk', 'Guyok,Guyuk', 9.9066300, 11.9275300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100091, 'Gusau', 'Gusau', 'Gusau,QUS,Гусау', 12.1702400, 6.6641200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100092, 'Guri', 'Guri', 'Guri,Gurri', 12.7281000, 10.4198900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100093, 'Gummi', 'Gummi', 'Gummi,Gunmi,Kunmi,Кунми', 12.1448400, 5.1177600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100094, 'Gumel', 'Gumel', 'Gumel', 12.6269000, 9.3880700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100095, 'Gulma', 'Gulma', '', 12.6423100, 4.3554500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100096, 'Gulak', 'Gulak', '', 10.8053000, 13.4582400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100097, 'Gujba', 'Gujba', 'Gujba', 11.4995900, 11.9339600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100098, 'Gudumbali', 'Gudumbali', 'Gidimbari,Gudumbali', 12.9428400, 13.1783100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100099, 'Gubio', 'Gubio', 'Gubio,Gubiya', 12.4974900, 12.7808900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100100, 'Goronyo', 'Goronyo', 'Goronyo', 13.4422600, 5.6723400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100101, 'Gorgoram', 'Gorgoram', 'Gorgoram,Gorgorum', 12.6395800, 10.7042200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100102, 'Gora', 'Gora', '', 11.9129400, 7.6653100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100103, 'Goniri', 'Goniri', '', 11.4845100, 12.3126400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100104, 'Gombi', 'Gombi', 'Gombe,Gombi,Gombi Fulani,Little Gombi', 10.1675600, 12.7368400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100105, 'Gombe', 'Gombe', 'GMO,Gombe', 10.2896900, 11.1672900, 'NG', '2017-04-14', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100106, 'Giwa', 'Giwa', '', 11.3156800, 7.4495700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100107, 'Girei', 'Girei', 'Girei', 9.3652600, 12.5462100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100108, 'Gidan Madi', 'Gidan Madi', 'Gidan Madi', 13.2957500, 4.9746700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100109, 'Giade', 'Giade', '', 11.3908300, 10.1998700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100110, 'Gezawa', 'Gezawa', '', 12.1015700, 8.7502900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100111, 'Gembu', 'Gembu', 'Gembu', 6.7255600, 11.2565200, 'NG', '2014-12-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100112, 'Gella', 'Gella', 'Gella,Ouro Guela,Ouro Guéla,Uro-Gela', 10.1573800, 13.3000400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100113, 'Geidam', 'Geidam', 'Gaidam,Geidam', 12.8943900, 11.9264900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100114, 'Buruku', 'Buruku', 'Bukuru,Buruku,Gburuku', 7.4596100, 9.2045500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100115, 'Gbongan', 'Gbongan', 'Gbongan', 7.4773400, 4.3535100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100116, 'Gboko', 'Gboko', 'Gboko', 7.3227500, 9.0010800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100117, 'Gbajimba', 'Gbajimba', 'Bajimba,Gbajimba', 7.8204000, 8.8595500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100118, 'Gaya', 'Gaya', '', 11.8606400, 9.0027000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100119, 'Gassol', 'Gassol', '', 8.5353500, 10.4461500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100120, 'Gashua', 'Gashua', 'Gashua', 12.8739800, 11.0405700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100121, 'Garun Malam', 'Garun Malam', 'Garum Malam,Garum Mallam,Garun Malam', 11.6856600, 8.3698600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100122, 'Garko', 'Garko', '', 11.6497400, 8.8032800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100123, 'Garko', 'Garko', '', 10.1750600, 11.1645800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100124, 'Garki', 'Garki', '', 12.4345600, 9.1902800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100125, 'Garaku', 'Garaku', '', 8.8471700, 8.1302100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100126, 'Ganye', 'Ganye', 'Ganye', 8.4349700, 12.0510700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100127, 'Gantsa', 'Gantsa', '', 11.6631200, 9.7263900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100128, 'Gandi', 'Gandi', '', 12.9635800, 5.7433700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100129, 'Gamboru', 'Gamboru', 'Gambaru,Gambaru Ngala,Gamboru,Gamboru Ngala', 12.3729900, 14.2069000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100130, 'Gamawa', 'Gamawa', 'Gamawa', 12.1337900, 10.5378500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100131, 'Gakem', 'Gakem', '', 6.7696300, 8.9912000, 'NG', '2014-08-05', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100132, 'Gajiram', 'Gajiram', '', 12.4914900, 13.2119100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100133, 'Gagarawa', 'Gagarawa', 'Gagarawa,Gargaraw,Gargarawa', 12.4084800, 9.5288100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100134, 'Gada', 'Gada', '', 13.7543000, 5.6572300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100135, 'Gabarin', 'Gabarin', '', 11.1093000, 10.4441000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100136, 'Funtua', 'Funtua', 'Funtua,Puntua', 11.5235100, 7.3117400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100137, 'Fugar', 'Fugar', '', 7.0907600, 6.4982800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100138, 'Fufu', 'Fufu', '', 8.4483800, 4.7207700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100139, 'Fufore', 'Fufore', 'Fufore', 9.2217500, 12.6497500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100140, 'Fika', 'Fika', 'Fika,Fike', 11.2867400, 11.3077200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100141, 'Fiditi', 'Fiditi', '', 7.7136100, 3.9172200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100142, 'Faskari', 'Faskari', 'Faskari', 11.7210800, 7.0299100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100143, 'Ezza-Ohu', 'Ezza-Ohu', '', 6.4409400, 8.0843200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100144, 'Ezzamgbo', 'Ezzamgbo', 'Ezamgbo,Ezzamgbo', 6.3989500, 7.9615500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100145, 'Etinan', 'Etinan', 'Etinan', 4.8426200, 7.8525200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100146, 'Ete', 'Ete', '', 7.0895600, 7.4534100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100147, 'Esuk Oron', 'Esuk Oron', '', 4.8029300, 8.2534100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100148, 'Eruwa', 'Eruwa', '', 7.5336500, 3.4179600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100149, 'Epe', 'Epe', 'Ehpe,Epe,Epeh,Эпе', 6.5841200, 3.9833600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100150, 'Enwang', 'Enwang', 'Engwang,Enwang', 4.6564300, 8.2520600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100151, 'Umunze', 'Umunze', 'Enugu Umunze,Umunze,Ururow-Umunze', 5.9669400, 7.2366400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100152, 'Enugu-Ukwu', 'Enugu-Ukwu', 'Enugu,Enugu-Ukwu,Enugwu-Ukwu', 6.1714600, 7.0052500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100153, 'Enugu-Ezike', 'Enugu-Ezike', '', 6.9827000, 7.4553400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100154, 'Enugu', 'Enugu', 'ENU,Ehnugu,Enuga,Enugu,Enugwu,Enúgwu,ai nu gu,anwghw,anwgw,enugu,Енугу,Энугу,إنوغو,انوگو,Ẹnúgu,エヌグ,埃努古,에누구', 6.4413200, 7.4988300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100155, 'Enagi', 'Enagi', '', 9.1273400, 5.5438700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100156, 'Emure-Ekiti', 'Emure-Ekiti', 'Emure,Emure-Ekiti', 7.4363600, 5.4592500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100157, 'Emuoha', 'Emuoha', 'Emohua,Emuoha', 4.8840000, 6.8601000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100158, 'Elele', 'Elele', 'Elele', 5.1009000, 6.8141100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100159, 'Ekpoma', 'Ekpoma', 'Ekpoma', 6.7430000, 6.1402900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100160, 'Eket', 'Eket', 'Eket', 4.6423100, 7.9243800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100161, 'Ekeremor', 'Ekeremor', 'Ekeremo,Ekeremor', 5.0580500, 5.7804800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100162, 'Ejirin', 'Ejirin', 'Ejinrin,Ejirin,Euni', 6.6142300, 3.9001900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100163, 'Ejigbo', 'Ejigbo', 'Ejigbo', 7.9029200, 4.3141900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100164, 'Ehor', 'Ehor', 'Ehor,Iho', 6.6155000, 5.9823800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100165, 'Eha Amufu', 'Eha Amufu', '', 6.6591500, 7.7596100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100166, 'Egbeda', 'Egbeda', '', 7.3772000, 4.0497500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100167, 'Egbe', 'Egbe', 'Egbe', 8.2166700, 5.5166700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100168, 'Effurun', 'Effurun', 'Efferun,Effurum,Effurun', 5.5562900, 5.7845900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100169, 'Efon-Alaaye', 'Efon-Alaaye', 'Effon-Alaiye,Efon,Efon Alaaye,Efon Alaaye-Ekiti,Efon Alaye,Efon-Alaaye,Efon-Alaiye', 7.6564900, 4.9223500, 'NG', '2016-10-08', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100170, 'Effium', 'Effium', 'Effium', 6.6310500, 8.0581400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100171, 'Effraya', 'Effraya', 'Efferaya,Effraya', 5.8592600, 8.7230100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100172, 'Ede', 'Ede', 'Edde,Ede', 7.7363500, 4.4353600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100173, 'Ebute-Metta', 'Ebute-Metta', 'Ebute Meta,Ebute Metta,Ebute-Metta', 6.4879900, 3.3816600, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100174, 'Ebute Ikorodu', 'Ebute Ikorodu', 'Awja-Ikoradu,Ebute Ikorodu,Ebute-Egga', 6.6008600, 3.4881800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100175, 'Eberi', 'Eberi', '', 5.0911700, 7.2337000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100176, 'Ebem Ohafia', 'Ebem Ohafia', 'Ebem,Ebem Ohafia,Isiama,Isiama Ohafia,Ohafia', 5.6310800, 7.8302400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100177, 'Dutsin-Ma', 'Dutsin-Ma', 'Dutsin Wai,Dutsin-Ma,Dutsinma', 12.4539200, 7.4972300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100178, 'Dutsi', 'Dutsi', 'Dusti,Dutsi', 12.8286200, 8.1398000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100179, 'Dutsen Wai', 'Dutsen Wai', 'Dutsan Wai,Dutsen Wai', 10.8500900, 8.1990000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100180, 'Dutse', 'Dutse', 'Dutse,Dutsi', 11.7561800, 9.3389600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100181, 'Malam Madori', 'Malam Madori', 'Dunari,Malam Madori,Malam-Maduri,Mallammaduri', 12.5647300, 9.8808400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100182, 'Duku', 'Duku', 'Dukku,Duku', 11.2361000, 4.9072700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100183, 'Dukku', 'Dukku', 'Dukku,Duku', 10.8237900, 10.7722100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100184, 'Donga', 'Donga', '', 7.7217500, 10.0452600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100185, 'Doma', 'Doma', '', 8.3930700, 8.3554400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100186, 'Disina', 'Disina', 'Disina', 11.4813500, 9.9190300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100187, 'Dindima', 'Dindima', 'Dindawa,Dindima', 10.2262900, 10.1513200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100188, 'Dikwa', 'Dikwa', 'Dikoa,Dikwa', 12.0360900, 13.9181500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100189, 'Dikenafai', 'Dikenafai', 'Dikenafai,Dikenafia,Dikenefai', 5.7701500, 7.1547300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100190, 'Dengi', 'Dengi', 'Dengi', 9.3687200, 9.9622300, 'NG', '2016-05-07', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100191, 'Demsa', 'Demsa', 'Demsa', 9.4556600, 12.1524900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100192, 'Dekina', 'Dekina', '', 7.6896700, 7.0438000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100193, 'Degema', 'Degema', '', 4.7480700, 6.7661800, 'NG', '2015-07-03', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100194, 'Deba', 'Deba', 'Deba,Deba Habe', 10.2118700, 11.3871000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100195, 'Dawakin Tofa', 'Dawakin Tofa', 'Dawaki,Dawakin Tofa,Dawakin Tofo', 12.1045200, 8.3299900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100196, 'Dawakin Kudu', 'Dawakin Kudu', 'Dawaki,Dawaki Kudu,Dawakin Kudu', 11.8372700, 8.5969900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100197, 'Daura', 'Daura', 'Daura,Даура', 13.0329900, 8.3235100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100198, 'Daura', 'Daura', '', 11.5541000, 11.4060000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100199, 'Darazo', 'Darazo', 'Darazo', 10.9992000, 10.4106200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100200, 'Dapchi', 'Dapchi', 'Dapchi', 12.4953600, 11.4997700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100201, 'Dan Sadau', 'Dan Sadau', '', 11.2962100, 6.4952000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100202, 'Dan Musa', 'Dan Musa', 'Dan Musa,Danimusa,Runka', 12.2615700, 7.3340900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100203, 'Dankama', 'Dankama', '', 13.2978200, 7.7949200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100204, 'Dankalwa', 'Dankalwa', 'Dankalwa,Dankalwar', 11.7444900, 12.1854500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100205, 'Danja', 'Danja', '', 11.3771000, 7.5609700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100206, 'Dan Gora', 'Dan Gora', '', 11.5348500, 8.1522400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100207, 'Dange', 'Dange', 'Dange,Denge', 12.8531300, 5.3457200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100208, 'Dandume', 'Dandume', 'Dan Dume,Dandume', 11.4588000, 7.1260200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100209, 'Damboa', 'Damboa', 'Damboa,Dumboa', 11.1553400, 12.7563800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100210, 'Dambatta', 'Dambatta', 'Dambarta,Dambatta,Danbata,Danbatta', 12.4350000, 8.5153100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100211, 'Dambam', 'Dambam', 'Dambam,Damban', 11.6789300, 10.7079200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100212, 'Damaturu', 'Damaturu', 'Damaturu', 11.7469700, 11.9608300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100213, 'Damasak', 'Damasak', 'Damasak,Damask', 13.1051800, 12.5085400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100214, 'Damagum', 'Damagum', 'Damagum,Damagun', 11.6782400, 11.3351700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100215, 'Dakingari', 'Dakingari', '', 11.6480900, 4.0617700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100216, 'Dadiya', 'Dadiya', '', 9.6166700, 11.4333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100217, 'Dabai', 'Dabai', '', 11.4765100, 5.2062500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100218, 'Chibok', 'Chibok', 'Chibok,Chibuk', 10.8694900, 12.8465700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100219, 'Charanchi', 'Charanchi', 'Charanchi,Cheranchi', 12.6715500, 7.7292900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100220, 'Tsafe', 'Tsafe', 'Chafe,Tsafe', 11.9577500, 6.9208300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100221, 'Calabar', 'Calabar', 'CBQ,Calabar,Kalabar,Kalabaras,Kalabaro,ka la ba er,kalabar,kallabaleu,Калабар,کالابار,卡拉巴尔,칼라바르', 4.9589300, 8.3269500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100222, 'Bwari', 'Bwari', 'Bwari', 9.2799500, 7.3804500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100223, 'Burutu', 'Burutu', 'Burutu', 5.3532800, 5.5082600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100224, 'Burumburum', 'Burumburum', '', 11.3910600, 8.7234100, 'NG', '2006-01-17', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100225, 'Bunza', 'Bunza', '', 12.0844400, 4.0211100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100226, 'Bununu', 'Bununu', 'Bununu,Bununu Kasa,Bununu Kassa', 9.8822400, 9.6805800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100227, 'Dass', 'Dass', 'Bununu,Bununu Dass,Dass', 10.0006500, 9.5159600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100228, 'Bunkure', 'Bunkure', 'Bunkure', 11.6992400, 8.5412700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100229, 'Bungudu', 'Bungudu', 'Bongudu,Bungudu', 12.2684800, 6.5528800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100230, 'Bukuru', 'Bukuru', 'Bukuru', 9.7939900, 8.8639700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100231, 'Bukkuyum', 'Bukkuyum', 'Bukkuyum,Bukuyum,Bukwium', 12.1372000, 5.4682100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100232, 'Buguma', 'Buguma', 'Bugama,Buguma', 4.7361400, 6.8623600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100233, 'Buga', 'Buga', '', 8.4905600, 7.3413900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100234, 'Briyel', 'Briyel', 'Biriyel,Briyel,Bryel', 10.3476400, 11.6099000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100235, 'Twon-Brass', 'Twon-Brass', 'Brass,Brass Town,Bross,Twon-Brass', 4.3123100, 6.2409100, 'NG', '2015-05-06', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100236, 'Bornu Yassu', 'Bornu Yassu', '', 12.2750300, 12.5685600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100237, 'Bori', 'Bori', 'Bori', 4.6762900, 7.3651900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100238, 'Ugbokpo', 'Ugbokpo', 'Bopa,Bopo,Ugbokpo', 7.6532100, 7.8841000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100239, 'Bonny', 'Bonny', 'Bonny,Bonny Town', 4.4516000, 7.1707400, 'NG', '2015-07-03', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100240, 'Bomadi', 'Bomadi', 'Bomadi,Bomodi', 5.1607300, 5.9237500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100241, 'Bokkos', 'Bokkos', '', 9.2992100, 8.9946700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100242, 'Bokani', 'Bokani', '', 9.4333300, 5.2000000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100243, 'Boju', 'Boju', '', 7.3557200, 7.8930300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100244, 'Boje', 'Boje', 'Boje,Boji', 6.2842800, 8.9206200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100245, 'Boi', 'Boi', 'Boi', 9.5610900, 9.5015400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100246, 'Bogoro', 'Bogoro', 'Bogoro,Mogaro', 9.6690400, 9.6052800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100247, 'Bodinga', 'Bodinga', 'Bodinga', 12.8441300, 5.1500100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100248, 'Bode Saadu', 'Bode Saadu', 'Bode Saadu,Bode-Sadu', 8.9390000, 4.7822700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100249, 'Bode Osi', 'Bode Osi', 'Bode Osi,Bode-Olla,Bode-Olle,Ibede-Osi,Ibode-Osi', 7.7510300, 4.2298000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100250, 'Biu', 'Biu', 'Biu', 10.6128500, 12.1945800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100251, 'Mallam Fatori', 'Mallam Fatori', 'Bisagana,Bisugana,Malam Fatori,Mallam Fatori,Malum Fatori,Malumfatori', 13.6746000, 13.3395200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100252, 'Birniwa', 'Birniwa', 'Birinawa,Biriniwa,Birniwa', 12.7907000, 10.2361400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100253, 'Birnin Kudu', 'Birnin Kudu', 'Birnin Kudu', 11.4520700, 9.4785600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100254, 'Birnin Kebbi', 'Birnin Kebbi', 'Birnin Kebbi', 12.4538900, 4.1975000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100255, 'Sofo-Birnin-Gwari', 'Sofo-Birnin-Gwari', 'Birni-Gwari,Birnin-Gwari,Sofo-Birnin-Gwari', 11.0153700, 6.7803600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100256, 'Birnin Gwari', 'Birnin Gwari', 'Birnin Gwari', 10.6637400, 6.5400300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100257, 'Bin Yauri', 'Bin Yauri', '', 10.7823000, 4.8113500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100258, 'Binji', 'Binji', 'Binji', 13.2229400, 4.9088800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100259, 'Bindawa', 'Bindawa', 'Bindawa', 12.6698700, 7.8086500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100260, 'Billiri', 'Billiri', 'Biliri Laushi,Billiri', 9.8902400, 11.2179400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100261, 'Billiri', 'Billiri', 'Biliri,Billiri', 9.8654500, 11.2262400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100262, 'Bida', 'Bida', 'Bida,Бида', 9.0804400, 6.0099000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100263, 'Bichi', 'Bichi', 'Bichi', 12.2338500, 8.2406300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100264, 'Besse', 'Besse', '', 11.2667600, 4.4311400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100265, 'Benisheikh', 'Benisheikh', 'Beni Sheik,Benisheik,Benisheikh', 11.8091900, 12.4915100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100266, 'Benin City', 'Benin City', 'BNI,Benim,Benin,Benin City,Benin Siti,Benin by,Benin-Siti,Benin-Stadt,Benin-stad,Beninas,Beninborg,Beninurbo,Benínborg,Bénin,Ciudad de Benin,Ciudad de Benín,Ilu Benin,Kota Benin,Thanh pho Benin,Thành phố Benin,bei ning cheng,beni n si ti,benina sahira,benina siti,beninshiti,beninsiti,bnyn,Ìlú Benin,Бенин,Бенин-Сити,Бенін-Сіті,بنين,بنین,بینن شہر,बेनिन सिटी,ਬੇਨਿਨ ਸ਼ਹਿਰ,เบนินซิตี,ベニンシティ,贝宁城,베닌시티', 6.3381500, 5.6257500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100267, 'Bende', 'Bende', 'Bende', 5.5587400, 7.6335900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100268, 'Bena', 'Bena', '', 11.2844400, 5.9347200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100269, 'Beli', 'Beli', 'Bali', 7.8586800, 10.9718700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100270, 'Bebeji', 'Bebeji', 'Bebeji', 11.6676800, 8.2620000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100271, 'Baure', 'Baure', '', 12.8377200, 8.7451300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100272, 'Bauchi', 'Bauchi', 'BCU,Bauchi,Baucis,Bauczi,Baučis,Yakoba,Yakubu,bao qi,Баучи,包奇', 10.3103200, 9.8438800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100273, 'Batsari', 'Batsari', 'Batsari', 12.7555100, 7.2480900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100274, 'Batagarawa', 'Batagarawa', 'Batagarawa', 12.9061100, 7.6058600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100275, 'Bassa', 'Bassa', '', 9.9424900, 8.7404200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100276, 'Baro', 'Baro', 'Barbo,Baro,Баро', 8.6000000, 6.4166700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100277, 'Barkin Ladi', 'Barkin Ladi', 'B-Ladi,Bar-n-Ladi,Barakin,Barakin Ladi,Barikin Ladi,Barkin Ladi', 9.5381200, 8.8927000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100278, 'Bara', 'Bara', '', 10.9360500, 11.6824200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100279, 'Bara', 'Bara', 'Bara', 10.3744400, 10.7288400, 'NG', '2012-01-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100280, 'Bama', 'Bama', 'Bama', 11.5213400, 13.6895200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100281, 'Balle', 'Balle', 'Bale,Balle', 13.4702900, 4.6811900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100282, 'Bakura', 'Bakura', '', 12.7114100, 5.8736700, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100283, 'Bakori', 'Bakori', 'Bakori', 11.5555900, 7.4241900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100284, 'Bajoga', 'Bajoga', 'Bajoga', 10.8515200, 11.4316900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100285, 'Baissa', 'Baissa', 'Ba''Issa,Baissa,Ba’Issa,Bdissa', 7.2308700, 10.6244400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100286, 'Bagwai', 'Bagwai', 'Bagwai', 12.1577000, 8.1358000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100287, 'Bagudo', 'Bagudo', 'Bagudo,Tuga', 11.4035100, 4.2257100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100288, 'Bugana', 'Bugana', 'Bagana,Bugana', 7.9991700, 7.5836100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100289, 'Obagaji', 'Obagaji', 'Bagagi,Bagaji,Obagaji,Obagiji', 7.8916900, 7.9093800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100290, 'Badeggi', 'Badeggi', 'Badegg,Badeggi', 9.0563000, 6.1430000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100291, 'Badagry', 'Badagry', 'Badagri,Badagry', 6.4150200, 2.8813200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100292, 'Babura', 'Babura', '', 12.7725600, 9.0152500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100293, 'Babban Gida', 'Babban Gida', 'Baban Gida,Babangida,Babban Gida', 12.1548200, 11.7709000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100294, 'Babana', 'Babana', '', 10.4294900, 3.8149500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100295, 'Azare', 'Azare', 'Azare', 11.6747800, 10.1906900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100296, 'Awo-Idemili', 'Awo-Idemili', 'Awo Idemiri,Awo Ndemini,Awo-Idemili,Awodemili', 5.8264800, 6.9337400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100297, 'Awo', 'Awo', '', 7.7676400, 4.3951500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100298, 'Awka', 'Awka', 'Akwa,Avka,Awka,Oka,ao ka,auka,awka,Óká,Авка,اوکا,奧卡,아우카', 6.2126900, 7.0719900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100299, 'Awgu', 'Awgu', '', 6.0727800, 7.4773900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100300, 'Awe', 'Awe', '', 8.1044500, 9.1401100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100301, 'Auna', 'Auna', '', 10.1880500, 4.7231800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100302, 'Augie', 'Augie', 'Augi,Augie', 12.8902700, 4.5996500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100303, 'Auchi', 'Auchi', 'Auchi', 7.0675600, 6.2636000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100304, 'Atani', 'Atani', 'Atani', 6.0127700, 6.7476800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100305, 'Askira', 'Askira', '', 10.6508600, 12.9088300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100306, 'Azare', 'Azare', 'Asari,Azare', 10.5258300, 12.2911500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100307, 'Asaba', 'Asaba', 'ABB,Asaba,Асаба', 6.1982400, 6.7318700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100308, 'Arochukwu', 'Arochukwu', 'Arochuku,Arochukwu', 5.3894100, 7.9123500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100309, 'Argungu', 'Argungu', 'Argungu', 12.7448200, 4.5251400, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100310, 'Araromi-Opin', 'Araromi-Opin', 'Araromi-Opin,Araromi-Osi', 8.0652700, 5.2539800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100311, 'Aramoko-Ekiti', 'Aramoko-Ekiti', 'Ara,Aramoko,Aramoko-Ekiti,Araomoko Ekiti', 7.7048300, 5.0405400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100312, 'Apomu', 'Apomu', '', 7.3515600, 4.1833500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100313, 'Apapa', 'Apapa', 'Apapa,QAP', 6.4488000, 3.3590100, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100314, 'Ankpa', 'Ankpa', 'Ank,Ankpa', 7.4024900, 7.6319600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100315, 'Anka', 'Anka', '', 12.1134700, 5.9268100, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100316, 'Anchau', 'Anchau', '', 10.9624500, 8.3923300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100317, 'Anaku', 'Anaku', 'Anaku', 6.4687500, 6.9289300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100318, 'Amper', 'Amper', 'Amper', 9.3550900, 9.7012100, 'NG', '2016-05-07', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100319, 'Amaigbo', 'Amaigbo', 'Amaigbo,Amibo,Amigbo', 5.7301600, 7.1151000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100320, 'Amassoma', 'Amassoma', 'Amasama,Amassama,Amassoma', 4.9703200, 6.1091500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100321, 'Umundugba', 'Umundugba', 'Amanduba,Amandugba,Umundugba', 5.6759700, 7.0718400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100322, 'Amaigbo', 'Amaigbo', 'Amaigbo', 5.7891700, 7.8382900, 'NG', '2012-05-05', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100323, 'Amagunze', 'Amagunze', '', 6.3306300, 7.6524700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100324, 'Alkaleri', 'Alkaleri', 'Alkalere,Alkaleri', 10.2668800, 10.3323800, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100325, 'Aliero', 'Aliero', 'Aleiro,Aliero', 12.2883500, 4.4713900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100326, 'Aliade', 'Aliade', 'Aliade,Eleyeddi', 7.2962700, 8.4827800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100327, 'Albasu', 'Albasu', 'Albasu', 11.6740300, 9.1405900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100328, 'Alapa', 'Alapa', '', 8.6166700, 4.3833300, 'NG', '2013-05-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100329, 'Akwukwu-Igbo', 'Akwukwu-Igbo', 'Akwukwu,Akwukwu-Igbo', 6.3575300, 6.5906600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100330, 'Akwete', 'Akwete', 'Akvete,Akwete,Аквете', 4.8868800, 7.3568600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100331, 'Akwanga', 'Akwanga', 'Akwanga', 8.9107700, 8.4065500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100332, 'Akure', 'Akure', 'AKR,Akuce,Akure,Akurė,a ku lei,akule,Àkúrẹ́,Акуре,اکورے,阿庫雷,아쿠레', 7.2525600, 5.1931200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100333, 'Aku', 'Aku', 'Aku', 6.7090200, 7.3182600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100334, 'Akodo', 'Akodo', 'Akawdo,Akodo', 6.4378700, 3.9309000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100335, 'Akko', 'Akko', 'Akko,Ako', 10.2889900, 10.9732000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100336, 'Ake-Eze', 'Ake-Eze', 'Aka Eze,Ake-Eze,Akeze', 5.9167700, 7.6761500, 'NG', '2012-01-18', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100337, 'Akanran', 'Akanran', '', 7.2812400, 4.0255300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100338, 'Akamkpa', 'Akamkpa', 'Akamkpa,Akankpa', 5.3124600, 8.3551500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100339, 'Akankpa', 'Akankpa', '', 5.1264000, 8.1898000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100340, 'Ajingi', 'Ajingi', 'Ajingi', 11.9682600, 9.0367900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100341, 'Ajaawa', 'Ajaawa', 'Ajaawa,Ajawa,Ajowa', 7.9311800, 4.1265400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100342, 'Ajasse Ipo', 'Ajasse Ipo', 'Ajasse,Ajasse Ipo', 8.2333300, 4.8166700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100343, 'Ajaokuta', 'Ajaokuta', 'Ajaokuta,QJK', 7.5622900, 6.6549700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100344, 'Ajalli', 'Ajalli', 'Ajalli,Ujali,Ujalli,Ujari', 6.0442700, 7.2086400, 'NG', '2016-05-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100345, 'Ajaka', 'Ajaka', '', 7.1741600, 6.8253500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100346, 'Ayetoro', 'Ayetoro', 'Aiyetoro,Ayetoro', 7.2428100, 3.0263900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100347, 'Ayete', 'Ayete', 'Aiyete,Ayete', 7.5428600, 3.2226300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100348, 'Ahoada', 'Ahoada', 'Ahoada,Ahoadao', 5.0828000, 6.6498100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100349, 'Agwara', 'Agwara', 'Agwara,Agwarra', 10.7061100, 4.5812500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100350, 'Agulu', 'Agulu', 'Agulu', 6.1004500, 7.0610000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100351, 'Aguata', 'Aguata', 'Aguata', 6.0163400, 7.0878200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100352, 'Akpet Central', 'Akpet Central', 'Agoi Efut,Akpet Central', 5.6210500, 8.1016300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100353, 'Ago Are', 'Ago Are', 'Agaw-Are,Ago Are', 8.5000000, 3.4166700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100354, 'Ago-Amodu', 'Ago-Amodu', 'Ago Amadu,Ago-Amodu,Shepeteri', 8.6231400, 3.6141900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100355, 'Agenebode', 'Agenebode', 'Agenebode', 7.1051200, 6.6938100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100356, 'Agege', 'Agege', 'Agege', 6.6156300, 3.3333700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100357, 'Agbor', 'Agbor', 'Afbor,Agbor,Agbor-BoIIboji,Агбор', 6.2537500, 6.1942000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100358, 'Tse-Agberagba', 'Tse-Agberagba', 'Agbelagba,Ise Agberagba,Tse-Agberagba', 7.0766800, 8.6655100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100359, 'Agbani', 'Agbani', 'Agbani', 6.3066900, 7.5486200, 'NG', '2016-03-10', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100360, 'Agbabu', 'Agbabu', '', 6.5886200, 4.8343000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100361, 'Agaie', 'Agaie', 'Agaie', 9.0085000, 6.3182100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100362, 'Afuze', 'Afuze', 'Afuje,Afuji,Afuze', 6.9694500, 6.0425400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100363, 'Afon', 'Afon', '', 8.3131300, 4.5273800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100364, 'Afikpo', 'Afikpo', 'Afikpo,Ehugbo', 5.8925800, 7.9353400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100365, 'Afam', 'Afam', 'Afam,Afam Uka,Afam Uko,Afam-Uku', 4.7900400, 7.3118700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100366, 'Afaha Offiong', 'Afaha Offiong', 'Afaha Obio Offiong,Afaha Obio Ofiong,Afaha Offiong', 4.8622600, 7.9062600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100367, 'Adoru', 'Adoru', '', 6.9769400, 7.1626200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100368, 'Ado Odo', 'Ado Odo', 'Addo,Ado,Ado Odo', 6.6000000, 2.9333300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100369, 'Adogo', 'Adogo', '', 7.5100400, 6.4798000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100370, 'Ado-Ekiti', 'Ado-Ekiti', 'Ado,Ado-Ekiti', 7.6232900, 5.2208700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100371, 'Adikpo', 'Adikpo', '', 6.8900200, 9.2335100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100372, 'Adani', 'Adani', '', 6.7397100, 7.0111700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100373, 'Achalla', 'Achalla', 'Achalla', 6.3346500, 6.9886300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100374, 'Abuochiche', 'Abuochiche', 'Abuochiche,Abuochichi', 6.6913200, 8.9433700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100375, 'Abuja', 'Abuja', 'ABV,Abodza,Abodža,Abouja,Abuca,Abudz,Abudza,Abudzha,Abudża,Abudž,Abudža,Abugia,Abugo,Abuja,Abuya,Abuzha,Abuĝo,Abùjá,Ampouza,Gorad Abudzha,a bu gu,a bu jia,abuja,abwja,apuja,xabu ca,yەbwwja,ʼbwgh,Αμπούζα,Абуджа,Абужа,Абуџа,Абуҷа,Горад Абуджа,Աբուջա,אבוגה,אבודזשא,آبوجا,أبوجا,ئەبووجا,ابوجا,अबुजा,আবুজা,ਅਬੁਜਾ,ଅବୁଜା,அபுஜா,അബുജ,อาบูจา,ཨ་པུ་ཅ།,အဘူဂျာမြို့,აბუჯა,አቡጃ,アブジャ,阿布賈,阿布贾,아부자', 9.0578500, 7.4950800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100376, 'Abudu', 'Abudu', 'Abudu', 6.2948900, 6.0299500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100377, 'Abua', 'Abua', '', 4.8576300, 6.6451900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100378, 'Abraka', 'Abraka', 'Abraka,Kwale', 5.7902300, 6.1047300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100379, 'Abonnema', 'Abonnema', 'Abonema,Abonnema,Nyemoni', 4.7317100, 6.7722300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100380, 'Aboh', 'Aboh', 'Abo,Aboh', 5.5478100, 6.5258800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100381, 'Abocho', 'Abocho', '', 7.5677000, 6.9863000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100382, 'Abigi', 'Abigi', '', 6.4867600, 4.3953100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100383, 'Abeokuta', 'Abeokuta', 'Abeokuta,Abẹ́òkúta,QAT,a bei ao ku ta,abe-okuta,abeokuta,abwkata,abywkwta,Абеокута,אבאוקוטה,أبيوكوتا,ابوکاتا,ابیوکوتا,アベオクタ,阿贝奥库塔,아베오쿠타', 7.1557100, 3.3450900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100384, 'Abejukolo', 'Abejukolo', 'Abajikolo,Abajukolo,Abejukolo', 7.8680800, 7.5090700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100385, 'Abakaliki', 'Abakaliki', 'Abakaliki,a ba ka li ji,阿巴卡利基', 6.3248500, 8.1136800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100386, 'Abak', 'Abak', 'Abak', 4.9823600, 7.7892200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100387, 'Abaji', 'Abaji', 'Abaji', 8.4737200, 6.9445300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100388, 'Abagana', 'Abagana', 'Abagana', 6.1903100, 6.9935700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100389, 'Aba', 'Aba', 'Aba,Aba i Nigeria,Abá,QAX,a ba,aba,aba  abya,Аба,Աբա,אבה,آبا,آبا، ابیا,აბა,アバ,阿巴,아바', 5.1065800, 7.3666700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100390, 'Ajegunle', 'Ajegunle', 'Ajegunle', 6.4519700, 3.3311500, 'NG', '2016-02-07', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100391, 'Ojota', 'Ojota', '', 6.5780600, 3.3868600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100392, 'Ifako', 'Ifako', '', 6.6442300, 3.3248800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100393, 'Degema Hulk', 'Degema Hulk', 'Degema,Degema Hulk', 4.7614500, 6.7495700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100394, 'Yana', 'Yana', '', 11.4072400, 10.0134500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100395, 'Buni Yadi', 'Buni Yadi', 'Buni Yadi,Buniyadi', 11.2744100, 12.0085200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100396, 'Obangede', 'Obangede', '', 7.6206600, 6.1992800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100397, 'Naka', 'Naka', '', 7.5833100, 8.2044000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100398, 'Ezillo', 'Ezillo', 'Ezillo,Ezilo,Eziulo', 6.4293000, 7.8178700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100399, 'Koguna', 'Koguna', '', 12.3813700, 8.4573300, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100400, 'Nasko', 'Nasko', '', 10.4953900, 4.8990400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100401, 'Oghara', 'Oghara', 'Oghara,Oghara Town,Ogharefe', 5.9355400, 5.6661000, 'NG', '2016-11-23', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100402, 'Abat', 'Abat', '', 4.6171200, 7.8663900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100403, 'Urua Inyang', 'Urua Inyang', '', 5.0230900, 7.5389500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100404, 'Ibiaku Ntok Okpo', 'Ibiaku Ntok Okpo', '', 5.3085700, 7.7110600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100405, 'Irrua', 'Irrua', 'Irrua', 6.7363400, 6.2198400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100406, 'Uromi', 'Uromi', 'Uromi', 6.7097100, 6.3298100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100407, 'Igueben', 'Igueben', 'Igueben,Iguegben', 6.6018300, 6.2427600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100408, 'Umumma', 'Umumma', 'Omuma,Umumma', 5.7569000, 6.9461300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100409, 'Akinima', 'Akinima', '', 5.0853600, 6.4663300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100410, 'Umuguma', 'Umuguma', 'Umuguma,Umuoguma', 5.4678300, 6.9659400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100411, 'Sabon Garin Nangere', 'Sabon Garin Nangere', 'Sabon Gari,Sabon Gari Nanger,Sabon Gari-Nangere,Sabon Garin Nangere', 11.8494500, 11.0733000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100412, 'Aguobu-Owa', 'Aguobu-Owa', '', 6.3722900, 7.2717800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100413, 'Ugbodo', 'Ugbodo', '', 6.5115500, 8.1298400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100414, 'Onueke', 'Onueke', '', 6.1553700, 8.0373500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100415, 'Lessel', 'Lessel', 'Lesel,Lessel', 7.1272900, 9.0198100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100416, 'Festac Town', 'Festac Town', 'Festac,Festac Town', 6.4697000, 3.2829900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100417, 'Atan', 'Atan', '', 6.8945600, 4.0071500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100418, 'Okuku', 'Okuku', '', 8.0180700, 4.6725300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100419, 'Iyana-Ofa', 'Iyana-Ofa', 'Iyana-Ofa,Iyana-Offa', 7.5004300, 4.0810400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100420, 'Mashegu', 'Mashegu', 'Mashegu,Moshegu', 9.9721300, 5.7788600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100421, 'Bangi', 'Bangi', '', 10.8336800, 5.8268800, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100422, 'Gawu Babangida', 'Gawu Babangida', 'Babangida,Gawu,Gawu Babangida', 9.2782700, 6.9933500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100423, 'Sabon Wuse', 'Sabon Wuse', 'New Wuse,Sabon Wuse,Wuse', 9.3342400, 7.2611400, 'NG', '2015-04-10', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100424, 'Birnin Magaji', 'Birnin Magaji', 'Birni Magaji,Birnin Magaji', 12.5592000, 6.8945900, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100425, 'Warawa', 'Warawa', '', 11.8662100, 8.7014600, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100426, 'Kaura', 'Kaura', '', 9.6681200, 8.4582500, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100427, 'Karu', 'Karu', '', 9.0094300, 7.6614700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100428, 'Akpafa', 'Akpafa', '', 7.4719200, 6.1497900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100429, 'Nkwo Nike', 'Nkwo Nike', '', 6.5092100, 7.5100600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100430, 'Isiaka', 'Isiaka', '', 5.8626500, 7.5462200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100431, 'Obiozara', 'Obiozara', '', 6.0464400, 7.7727300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100432, 'Onuebonyi Echara', 'Onuebonyi Echara', 'Echara Onu-Ebonyi,Echara-Anuaboyi,Echara-Onuaboyi,Onu Ebonyi Echara,Onuebonyi Echara', 6.0954000, 8.1515700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100433, 'Nwaorieubi', 'Nwaorieubi', 'Nwaorie-Ubi,Nwaorieubi,Nworieubi', 5.5818200, 7.0165100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100434, 'Aboh', 'Aboh', '', 5.4756900, 7.2716100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100435, 'Egbema', 'Egbema', '', 5.5443500, 6.7609000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100436, 'Isinweke', 'Isinweke', '', 5.6204800, 7.3498500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100437, 'Nnenasa', 'Nnenasa', '', 5.7326200, 7.0136400, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100438, 'Oke-Ikpe', 'Oke-Ikpe', 'Oke-Ikpe,Okeikpe', 4.9130100, 7.3193600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100439, 'Osisioma', 'Osisioma', '', 5.1597900, 7.3223500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100440, 'Omoba', 'Omoba', '', 5.2426800, 7.4062300, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100441, 'Okpuala-Ngwa', 'Okpuala-Ngwa', '', 5.3571000, 7.3876500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100442, 'Nkwoagu Isuochi', 'Nkwoagu Isuochi', 'Isuochi,Nkwoagu,Nkwoagu Isuochi,Nwoagu-Isuochi', 5.9912500, 7.3944500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100443, 'Isiala Oboro', 'Isiala Oboro', 'Isiala,Isiala Oboro', 5.4063200, 7.5681600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100444, 'Ogbia', 'Ogbia', 'Ogbia,Ogbia Town', 4.6883600, 6.3152500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100445, 'Oghara', 'Oghara', 'Oghara,Oghara Town', 5.9358700, 5.6791600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100446, 'Upenekang', 'Upenekang', 'Ukpenekang,Ukpenekong,Upenekang', 4.5706400, 7.9795500, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100447, 'Ikot Edibon', 'Ikot Edibon', 'Ikot Edibon,Ikot Edibong', 4.7702200, 7.9310000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100448, 'Ikot Akpa Nkuk', 'Ikot Akpa Nkuk', '', 4.8723100, 7.5645900, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100449, 'Eyofin', 'Eyofin', 'Eyo-Ofin,Eyofin', 4.7516000, 8.2305600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100450, 'Urue Offong', 'Urue Offong', 'Udua Offong,Urue Offong', 4.7527500, 8.1677000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100451, 'Mabudi', 'Mabudi', 'Mabudi,Mabudu', 8.7303700, 9.7851200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100452, 'Tunkus', 'Tunkus', 'Tunkus', 9.0216700, 9.6138400, 'NG', '2016-05-10', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100453, 'Baap', 'Baap', 'Ba''ap,Baap,Ba’ap', 8.9432100, 9.2412600, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100454, 'Kwal', 'Kwal', 'Kwal', 9.3712800, 9.6192000, 'NG', '2016-05-10', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100455, 'Boh', 'Boh', '', 9.7818700, 11.2788200, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100456, 'Kanamma', 'Kanamma', 'Kanama,Kanamga,Kanamma', 13.0996900, 12.1079000, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100457, 'Khaddamari', 'Khaddamari', '', 11.9258900, 13.2306200, 'NG', '2016-06-22', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100458, 'Sunkani', 'Sunkani', '', 8.7029800, 11.2575700, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100459, 'Saakpenwa', 'Saakpenwa', 'Saakpenwa,Sakpenwa', 4.7167700, 7.2630000, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100460, 'Nchia', 'Nchia', '', 4.7930900, 7.1206100, 'NG', '2016-01-30', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100461, 'Rumuodomaya', 'Rumuodomaya', 'Rumuodamaya,Rumuodo-Manya,Rumuodomanya,Rumuodomaya', 4.8933300, 7.0022800, 'NG', '2016-10-28', 162);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100751, 'Vlierden', 'Vlierden', '', 51.4450000, 5.7583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100752, 'Vliedberg', 'Vliedberg', '', 51.6896100, 5.1903100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100753, 'Vleuten', 'Vleuten', '', 52.1058300, 5.0152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100754, 'Vledder', 'Vledder', '', 52.8558300, 6.2083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100755, 'Vlagtwedde', 'Vlagtwedde', 'Vlachtwedde,Vlagtwedde', 53.0275000, 7.1083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100756, 'Vlaardingen', 'Vlaardingen', 'Vlaardinge,Vlaardingen', 51.9125000, 4.3416700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100757, 'Vinkeveen', 'Vinkeveen', '', 52.2150700, 4.9337200, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100758, 'Vijlen', 'Vijlen', '', 50.7883300, 5.9652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100759, 'Vijfhuizen', 'Vijfhuizen', '', 52.3508300, 4.6777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100760, 'Vierpolders', 'Vierpolders', '', 51.8791700, 4.1791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100761, 'Vianen', 'Vianen', '', 51.9925000, 5.0916700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100762, 'Venray', 'Venray', 'Venraai,Venraij', 51.5250000, 5.9750000, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100763, 'Venlo', 'Venlo', 'Fenlo,Venlas,Venlo,Venlonum,Venloo,fen luo,fenro,fnlw,wynlw,Φένλο,Венло,فنلو,وینلو,フェンロー,芬洛', 51.3700000, 6.1680600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100764, 'Venhorst', 'Venhorst', '', 51.6083300, 5.7375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100765, 'Ven', 'Ven', '', 51.6400000, 5.5500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100766, 'Veltum', 'Veltum', '', 51.5195400, 5.9603200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100767, 'Velsen-Zuid', 'Velsen-Zuid', 'Velsen,Velzen', 52.4600000, 4.6500000, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100768, 'Velp', 'Velp', 'Felp,wlp  khldrland,ولپ، خلدرلاند', 51.9950000, 5.9736100, 'NL', '2009-09-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100769, 'Veldhuizen', 'Veldhuizen', '', 52.0753700, 5.0123400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100770, 'Veldhoven', 'Veldhoven', '', 51.4183300, 5.4027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100771, 'Veghel', 'Veghel', 'Vechel,Vegel,Veghel,Vexel,Вегел,Վեխել', 51.6166700, 5.5486100, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100772, 'Feanwâlden', 'Feanwalden', 'Feanwalden,Feanwâlden,Veenwouden,fynfaldn,فينفالدن', 53.2355800, 5.9883200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100773, 'Veenoord', 'Veenoord', '', 52.7108700, 6.8486900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100774, 'Veenendaal', 'Veenendaal', 'QVX,Veenendaal,Venendaal', 52.0286300, 5.5589100, 'NL', '2017-07-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100775, 'Veendam', 'Veendam', '', 53.1066700, 6.8791700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100776, 'Veen', 'Veen', '', 51.7775000, 5.1083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100777, 'Varsseveld', 'Varsseveld', 'Faassefeld,Varseveld,Varsseveld,wrswld,Варссевелд,ورسولد', 51.9433300, 6.4583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100778, 'Valthermond', 'Valthermond', 'Eerste Valthermond,Eerste-Valtermond', 52.8816700, 6.9625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100779, 'Valthe', 'Valthe', 'Valte', 52.8458300, 6.8944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100780, 'Valkenswaard', 'Valkenswaard', 'Valkenswaard,Valkeswaerd', 51.3508300, 5.4597200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100781, 'Valkenburg', 'Valkenburg', '', 52.1800000, 4.4319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100782, 'Valkenburg', 'Valkenburg', 'Bad Valkenburg', 50.8652300, 5.8320500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100783, 'Valendries', 'Valendries', '', 51.8065800, 5.7344500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100784, 'Valburg', 'Valburg', '', 51.9116700, 5.7902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100785, 'Vaassen', 'Vaassen', 'Vasen', 52.2858300, 5.9666700, 'NL', '2009-09-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100786, 'Vaartbroek', 'Vaartbroek', '', 51.4795400, 5.4980600, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100787, 'Vaals', 'Vaals', 'Vaals,Vols', 50.7708300, 6.0180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100788, 'Utrecht', 'Utrecht', 'Gemeente Utrecht,Gorad Utrehkht,Magaalada Utrecht,Outrechte,Owtrext,Traiectum ad Rhenum,UTC,Utert,Utrech,Utrecht,Utrechtas,Utreht,Utrehta,Utrei,Utrekht,Utrekht khot,Utreque,Utrext,awtrkht,utrekhta,witeuleheuteu,wu de lei zhi,yu the rkt,yutorehito,ywtrkht,ywtrykht,Ουτρέχτη,Горад Утрэхт,Утрехт,Утрехт хот,Ուտրեխտ,אוטרכט,أوترخت,اوترخت,یوترخت,یوتریخت,ܐܘܛܪܝܟܛ,उट्रेख्त,ยูเทรกต์,ယူးထရက်မြို့,უტრეხტი,ユトレヒト,乌得勒支,烏德勒支,위트레흐트', 52.0908300, 5.1222200, 'NL', '2017-03-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100789, 'Usquert', 'Usquert', 'Uskwerd,Uskwert', 53.4025000, 6.6111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100790, 'Urmond', 'Urmond', 'Uermend,Werment', 50.9908300, 5.7722200, 'NL', '2009-01-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100791, 'Urk', 'Urk', 'Urk', 52.6625000, 5.6013900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100792, 'Ureterp', 'Ureterp', 'Oerterp,Ureterp', 53.0924400, 6.1671800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100793, 'Ulvenhout', 'Ulvenhout', 'Ulvenhout', 51.5490700, 4.7993100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100794, 'Ulrum', 'Ulrum', '', 53.3591700, 6.3333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100795, 'Ulestraten', 'Ulestraten', '', 50.9058300, 5.7819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100796, 'Uithuizermeeden', 'Uithuizermeeden', 'Uithuizermeden,Uithuizermeedum', 53.4141700, 6.7236100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100797, 'Uithuizen', 'Uithuizen', '', 53.4075000, 6.6708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100798, 'Uithoorn', 'Uithoorn', 'Authorn,Ehjtkhorn,Uithoorn,Uthoarn,ao te huo lun,awthwrn,Эйтхорн,Աուտհորն,آوتهورن,奥特霍伦', 52.2375000, 4.8263900, 'NL', '2014-08-21', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100799, 'Uitgeest', 'Uitgeest', 'Autxeyst,Ehjtgest,Uitgeest,Utgeast,awtkhyst,Эйтгест,Աուտխեյստ,آوتخيست', 52.5291700, 4.7097200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100800, 'Ugchelen', 'Ugchelen', 'Uchelen,Ugchelen', 52.1846400, 5.9317700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100801, 'Uffelte', 'Uffelte', '', 52.7900000, 6.2805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100802, 'Udenhout', 'Udenhout', '', 51.6091700, 5.1430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100803, 'Uden', 'Uden', 'UDE,Uden,Уден', 51.6608300, 5.6194400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100804, 'Uddel', 'Uddel', '', 52.2591700, 5.7805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100805, 'Ubachsberg', 'Ubachsberg', 'De Berg,Ubagsberg,abachsbrg,ywbachsbrg,اباچسبرگ,یوباچسبرگ', 50.8533300, 5.9486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100806, 'Tzummarum', 'Tzummarum', 'Tjummarum,Tsjummearum,Tzummarum', 53.2373300, 5.5461200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100807, '''t Zand', '''t Zand', 'Zand', 52.8366700, 4.7555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100808, 'Tynaarlo', 'Tynaarlo', 'Tinaarlo,Tinaarloo,Tynaarlo', 53.0775000, 6.6166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100809, 'Twisk', 'Twisk', 'Twist', 52.7408300, 5.0527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100810, 'Twijzelerheide', 'Twijzelerheide', 'Twijzelerheide,Twizelerheide', 53.2401500, 6.0459100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100811, 'Twijzel', 'Twijzel', 'Twijzel,Twizel', 53.2315200, 6.0895200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100812, 'Twello', 'Twello', '', 52.2366700, 6.1027800, 'NL', '2009-03-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100813, 'Twekkelerveld', 'Twekkelerveld', 'Twekelerveld,Twekkelerveld', 52.2306400, 6.8600400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100814, 'Tweede Exloërmond', 'Tweede Exloermond', '2e Exloermond,2e Exloërmond,Tweede Ekslooermond,Tweede Ekslooërmond', 52.9091700, 6.9333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100815, 'Tuk', 'Tuk', '', 52.7966700, 6.0944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100816, 'Tuindorp', 'Tuindorp', '', 51.9303200, 4.3784000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100817, 'Tuikwerd', 'Tuikwerd', '', 53.3166700, 6.9000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100818, 'Tubbergen', 'Tubbergen', 'Tubbergen,Тубберген', 52.4075000, 6.7847200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100819, 'Tricht', 'Tricht', '', 51.8908300, 5.2680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100820, 'Tongelre', 'Tongelre', 'Tongelre', 51.4488900, 5.5197800, 'NL', '2012-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100821, 'Tolkamer', 'Tolkamer', 'Tokalmar,Tolkmar', 51.8550000, 6.1027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100822, 'Tivoli', 'Tivoli', '', 51.4206900, 5.5081800, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100823, 'Tinga', 'Tinga', '', 53.0206400, 5.6457500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100824, 'Tilburg', 'Tilburg', 'Gorad Cilburg,Tilburch,Tilburg,Tilburga,Tilburgas,Tilburgo,Tilia,di er bao,thi lburk,tilbwileuheu,tiruburufu,tylbwrkh,Горад Цілбург,Тилбург,Тілбург,تیلبورخ,ٹلبرگ,ทิลบืร์ก,ტილბურგი,ティルブルフ,蒂尔堡,틸뷔르흐', 51.5555100, 5.0913000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100825, 'Tijnje', 'Tijnje', 'De Tynje,Tijnje,Tynje', 53.0305800, 5.9919300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100826, 'Tytsjerk', 'Tytsjerk', 'Tietjerk,Tytsjerk', 53.2134300, 5.9096100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100827, 'Tienray', 'Tienray', 'Tienraai,Tienray', 51.4950000, 6.0930600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100828, 'Tiel', 'Tiel', 'Tiel,Til,Тил', 51.8866700, 5.4291700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100829, 'Thorn', 'Thorn', 'Thorn,Toear,Torn,tuo er en,托爾恩', 51.1616700, 5.8416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100830, 'Tholen', 'Tholen', 'Tholen,Tole,Tolen,Толен', 51.5316700, 4.2208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100831, '''t Hofke', '''t Hofke', '', 51.4494300, 5.5192600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100832, 'Theereheide', 'Theereheide', '', 51.6384300, 5.3372900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100833, 'Teteringen', 'Teteringen', '', 51.6091700, 4.8208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100834, 'Terwolde', 'Terwolde', 'Terwolde,Terwolte', 52.2833300, 6.1000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100835, 'Terwinselen', 'Terwinselen', 'Tervinselen,Terwinseien', 50.8665900, 6.0247100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100836, 'Terschuur', 'Terschuur', '', 52.1650000, 5.5166700, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100837, 'Terneuzen', 'Terneuzen', 'Neuzen,Terneuze,Terneuzen,Ternezen,Тернезен', 51.3358300, 3.8277800, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100838, 'Ternaard', 'Ternaard', 'Ternaard', 53.3820300, 5.9652300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100839, 'Terheijden', 'Terheijden', 'Terheden,Terheide,Terheiden', 51.6433300, 4.7541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100840, 'Terbregge', 'Terbregge', '', 51.9532800, 4.5153700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100841, 'Terborg', 'Terborg', 'Terborch', 51.9200000, 6.3541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100842, 'Ter Apel', 'Ter Apel', '', 52.8766700, 7.0597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100843, 'Ten Boer', 'Ten Boer', 'Ten Boer', 53.2758300, 6.6944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100844, 'Tegelen', 'Tegelen', 'Tegele', 51.3441700, 6.1361100, 'NL', '2009-10-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100845, 'Surhuisterveen', 'Surhuisterveen', 'Surhuisterveen,Surhusterfean,Surhústerfean', 53.1847700, 6.1703100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100846, 'Strijp', 'Strijp', '', 52.0308300, 4.3013900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100847, 'Strijen', 'Strijen', '', 51.7452100, 4.5508300, 'NL', '2008-01-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100848, 'Stramproy', 'Stramproy', 'Stamprooi,Stamproy,Stramproij', 51.1941700, 5.7194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100849, 'Stompetoren', 'Stompetoren', '', 52.6133300, 4.8208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100850, 'Stolwijk', 'Stolwijk', '', 51.9725000, 4.7736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100851, 'Stiens', 'Stiens', '', 53.2623400, 5.7576900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100852, 'Stepekolk', 'Stepekolk', '', 51.4550000, 5.6125100, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100853, 'Stein', 'Stein', '', 52.0033300, 4.7819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100854, 'Stein', 'Stein', 'Steyn,si tai yin,stayn,Ստեյն,ستاين,斯泰因', 50.9691700, 5.7666700, 'NL', '2009-01-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100855, 'Stegeslag', 'Stegeslag', '', 51.9415100, 6.0619400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100856, 'Steenwijkerwold', 'Steenwijkerwold', 'Kerkbuurt', 52.8041700, 6.0638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100857, 'Steenwijk', 'Steenwijk', 'Stienwyk,si teng wei ke,斯滕韋克', 52.7875000, 6.1208300, 'NL', '2008-12-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100858, 'Steensel', 'Steensel', '', 51.3766700, 5.3527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100859, 'Steenderen', 'Steenderen', '', 52.0641700, 6.1875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100860, 'Steenbergen', 'Steenbergen', 'Steenbergen', 51.5841700, 4.3194400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100861, 'Stavenisse', 'Stavenisse', '', 51.5875000, 4.0125000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100862, 'Statenkwartier', 'Statenkwartier', '', 52.0931100, 4.2757700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100863, 'Staphorst', 'Staphorst', 'Staphorst', 52.6450000, 6.2111100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100864, 'Standdaarbuiten', 'Standdaarbuiten', '', 51.6133300, 4.5138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100865, 'Stampersgat', 'Stampersgat', '', 51.6133300, 4.4444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100866, 'Stadskanaal', 'Stadskanaal', 'Afraai,Stadskanaal', 52.9894700, 6.9504000, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100867, 'Stadsfenne', 'Stadsfenne', '', 53.0398700, 5.6784400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100868, 'Stadbroek', 'Stadbroek', '', 51.0018700, 5.8765600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100869, 'Sprundel', 'Sprundel', '', 51.5375000, 4.5972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100870, 'Spoorwijk', 'Spoorwijk', 'Spoorwijk', 52.0534700, 4.3133900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100871, 'Spijkenisse', 'Spijkenisse', 'Spijkenisse', 51.8450000, 4.3291700, 'NL', '2015-05-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100872, 'Spijk', 'Spijk', '', 53.3900000, 6.8375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100873, 'Spierdijk', 'Spierdijk', '', 52.6508300, 4.9430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100874, 'Spekholzerheide', 'Spekholzerheide', '', 50.8555900, 6.0247100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100875, 'Spaubeek', 'Spaubeek', 'Sjpawbik,Spanbeek,Spaubeek', 50.9400000, 5.8430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100876, 'Spangen', 'Spangen', 'Spangen', 51.9168800, 4.4353900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100877, 'Spakenburg', 'Spakenburg', 'Bunschoten-Spakenburg,Spakenburch,Spakenburg', 52.2500000, 5.3666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100878, 'Son', 'Son', 'Son en Breugel', 51.5113600, 5.4928200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100879, 'Someren-Eind', 'Someren-Eind', '''t Eind,Eindje,Het Eind', 51.3575000, 5.7333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100880, 'Someren', 'Someren', 'Someren,Zomere', 51.3850000, 5.7111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100881, 'Soestdijk', 'Soestdijk', '', 52.1908300, 5.2847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100882, 'Soest', 'Soest', 'Sust,Zoest,swst,Зоест,Суст,Սուստ,سوست', 52.1733300, 5.2916700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100883, 'Soerendonk', 'Soerendonk', '', 51.3008300, 5.5750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100884, 'Sneek', 'Sneek', 'Sneek,Snek,Sneêk,Snits,asnyk,seuneikeu,si nei ke,suneku,Снек,اسنیک,スネーク,斯內克,스네이크', 53.0329700, 5.6589000, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100885, 'Sluiskil', 'Sluiskil', 'Sluuskille', 51.2783300, 3.8361100, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100886, 'Sluis', 'Sluis', 'Sljojs,Sluis,Слёйс', 51.3083300, 3.3861100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100887, 'Slootdorp', 'Slootdorp', '', 52.8425000, 4.9722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100888, 'Slochteren', 'Slochteren', 'Slochteren', 53.2207800, 6.8054700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100889, 'Slikkerveer', 'Slikkerveer', 'Slikkerveer', 51.8853100, 4.6049400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100890, 'Sliedrecht', 'Sliedrecht', 'Shedrecht,Slidrekht,Слидрехт', 51.8208300, 4.7763900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100891, 'Sleen', 'Sleen', '', 52.7716700, 6.8027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100892, 'Sittard', 'Sittard', 'Sitardas,Sittard,Zittert,sitaleuteu,sytard,xi ta de,Ситтард,سیتارد,錫塔德,시타르트', 50.9983300, 5.8694400, 'NL', '2009-01-05', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100893, 'Sint Willebrord', 'Sint Willebrord', 'Heike,Willebrord', 51.5483300, 4.5888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100894, 'Sint Philipsland', 'Sint Philipsland', 'Sint Filipsland', 51.6166700, 4.1652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100895, 'Sint Pancras', 'Sint Pancras', 'Pankras,Sint Pankras', 52.6600000, 4.7833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100896, 'Sint-Oedenrode', 'Sint-Oedenrode', 'Sint-Oedenrode', 51.5675000, 5.4597200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100897, 'Sint Odiliënberg', 'Sint Odilienberg', 'Berg,Sint-Odilienberg,Sint-Odiliënberg,Синт-Одилиенберг', 51.1433300, 6.0000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100898, 'Sint Nicolaasga', 'Sint Nicolaasga', 'Sint Nicolaasga,Sint Nikelsgea,Sint Nikolaasga,Sint Nyk', 52.9229300, 5.7424200, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100899, 'Sint-Michielsgestel', 'Sint-Michielsgestel', 'Saint-Michel-Gestel,Sint-Mixilsxestel,synt mykhylyskhystl,Սինտ-Միխիլսխեստել,سينت ميخيليسخيستل', 51.6416700, 5.3527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100900, 'Sint Laurens', 'Sint Laurens', 'Laurens', 51.5275000, 3.6027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100901, 'Sint Joost', 'Sint Joost', '', 51.1175000, 5.8986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100902, 'Sintjohannesga', 'Sintjohannesga', 'Sint Jansgea,Sint Johannisga,Sint Jânsgea,Sintjohannesga', 52.9315700, 5.8558800, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100903, 'Sint Jansklooster', 'Sint Jansklooster', '', 52.6775000, 6.0055600, 'NL', '2008-12-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100904, 'Sint Jacobiparochie', 'Sint Jacobiparochie', '', 53.2729100, 5.6035400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100905, 'Sint Anthonis', 'Sint Anthonis', 'Antonis,Sint Anthonis,Sint Antonis,Sintunnis', 51.6266700, 5.8819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100906, 'Sint Annaparochie', 'Sint Annaparochie', 'Annaparochie,Sint Annaparochie,Sint Anne,St. Annaparochie', 53.2762000, 5.6572700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100907, 'Simpelveld', 'Simpelveld', 'Simpelveld,Zumpelveld', 50.8341700, 5.9819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100908, 'Silvolde', 'Silvolde', '', 51.9091700, 6.3875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100909, 'Siddeburen', 'Siddeburen', '', 53.2500000, 6.8680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100910, 'Sibbe', 'Sibbe', '', 50.8441700, 5.8263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100911, '''s-Hertogenbosch', '''s-Hertogenbosch', '''s Bosch,''s-Hertogenbosch,Bois-le-Duc,Bolduque,Boscoducale,De Bosk,Den Bosch,Hertogenbosch,Herzogenbusch,Khertogenbos,Oeteldonk,Silva Ducis,Хертогенбос,’s-Hertogenbosch', 51.6991700, 5.3041700, 'NL', '2015-02-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100912, '''s-Heerenberg', '''s-Heerenberg', '''s-Heerenberg,s-Heerenberg,s-Kherenberg,с-Херенберг,’s-Heerenberg', 51.8767000, 6.2587700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100913, '''s-Gravenzande', '''s-Gravenzande', '', 52.0016700, 4.1652800, 'NL', '2011-08-11', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100914, '''s Gravenmoer', '''s Gravenmoer', '''s Gravemoer', 51.6559400, 4.9407600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100915, 'The Hague', 'The Hague', '''s-Gravenhage,A Haia,An Haig,An Háig,Chage,D''n Haog,De Haach,Den Haag,Gaaga,HAG,Haag,Hag,Haga,Hago,Hague,Hága,Hāga,Khag,Khaga,L''Aia,La Haia,La Haya,La Haye,Lahey,The Hague,haaga,hagu,hai ya,heigeu,lahay,lahh,Χάγη,Гаага,Хаг,Хага,האג,لاهاي,لاهه,ჰააგა,ハーグ,海牙,헤이그', 52.0766700, 4.2986100, 'NL', '2014-06-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100916, 'Sexbierum', 'Sexbierum', 'Seisbierrum,Sexbierum,Sixbierum', 53.2182300, 5.4840200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100917, 'Sevenum', 'Sevenum', 'Sevenum,Zaerem', 51.4125000, 6.0375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100918, 'Serooskerke', 'Serooskerke', '', 51.5483300, 3.5944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100919, 'Selwerd', 'Selwerd', '', 53.2352000, 6.5545000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100920, 'Sellingen', 'Sellingen', '', 52.9458300, 7.1513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100921, 'Schutsboom', 'Schutsboom', '', 51.4615200, 5.6226000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100922, 'Schoonrewoerd', 'Schoonrewoerd', 'Schoonerwoerd', 51.9208300, 5.1166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100923, 'Schoonoord', 'Schoonoord', '', 52.8458300, 6.7555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100924, 'Schoonhoven', 'Schoonhoven', 'Schoonhoven,Sconhouen', 51.9475000, 4.8486100, 'NL', '2016-06-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100925, 'Schoonebeek', 'Schoonebeek', 'Oud Schoonebeek', 52.6625000, 6.8847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100926, 'Schoondijke', 'Schoondijke', '', 51.3541700, 3.5555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100927, 'Schipluiden', 'Schipluiden', 'Skhipljojden,Схиплёйден', 51.9758300, 4.3138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100928, 'Schinveld', 'Schinveld', 'Sjilvend', 50.9691700, 5.9791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100929, 'Schinnen', 'Schinnen', '', 50.9433300, 5.8888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100930, 'Schimmert', 'Schimmert', 'Sjoemmert,Sjömmert', 50.9066700, 5.8236100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100931, 'Schildwolde', 'Schildwolde', '', 53.2332700, 6.8156600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100932, 'Schilberg', 'Schilberg', '', 51.0991700, 5.8861100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100933, 'Schijndel', 'Schijndel', 'Schijndel', 51.6225000, 5.4319400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100934, 'Schiermonnikoog', 'Schiermonnikoog', 'Oosterburen,Schiermonnikoog,Skiermuntseach,Skiermûntseach', 53.4802500, 6.1520900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100935, 'Schiedam', 'Schiedam', 'Schidamas,Schiedam,Skhidam,Skiedam,Sxidam,askhydam,si xi dan,ski dam,Схидам,Շխիդամ,اسخیدام,สกีดาม,斯希丹', 51.9191700, 4.3888900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100936, 'Schiebroek', 'Schiebroek', 'Schiebroek', 51.9583800, 4.4712400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100937, 'Scheveningen', 'Scheveningen', 'Scheveningen,Sheveningen,Sjeveninge,Skeveningen,Skheveningen,askhyfnyngn,seuhebening-eon,si he fu ning en,skwwnyngn,suhefeningen,Схевенинген,Шевенинген,סכוונינגן,اسخیفنینگن,スヘフェニンゲン,斯赫弗宁恩,스헤베닝언', 52.1046100, 4.2755700, 'NL', '2010-01-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100938, 'Scherpenzeel', 'Scherpenzeel', 'Skerpenseel,Sxerpenzeyl,skhyrbnzyl,Շխերպենզեյլ,سخيربنزيل', 52.0800000, 5.4888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100939, 'Scherpenisse', 'Scherpenisse', '', 51.5466700, 4.1055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100940, 'Schermerhorn', 'Schermerhorn', '', 52.6008300, 4.8916700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100941, 'Schelluinen', 'Schelluinen', '', 51.8433300, 4.9263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100942, 'Scheemda', 'Scheemda', 'Scheemda,Skhemda,Схемда', 53.1733300, 6.9722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100943, 'Scharnegoutum', 'Scharnegoutum', '', 53.0605100, 5.6782200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100944, 'Scharn', 'Scharn', '', 50.8500000, 5.7333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100945, 'Scharendijke', 'Scharendijke', 'Skharendejke,Схарендейке', 51.7358300, 3.8430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100946, 'Schalkhaar', 'Schalkhaar', 'Schalkhaap', 52.2683300, 6.1944400, 'NL', '2008-09-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100947, 'Schaijk', 'Schaijk', 'Scadewic,Schaaik,Schadewijk,Schaik,Schayk', 51.7458300, 5.6319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100948, 'Schagerbrug', 'Schagerbrug', '', 52.8025000, 4.7583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100949, 'Schagen', 'Schagen', 'Schagen,Skagen,Skhagen,Sxagen,si ha heng,Схаген,Շխագեն,斯哈亨', 52.7875000, 4.7986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100950, 'Sas van Gent', 'Sas van Gent', 'Sas,Sas de Gand,Sas fan Gent,sa si fan heng te,薩斯凡亨特', 51.2275000, 3.7986100, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100951, 'Sassenheim', 'Sassenheim', 'Sassenkhejm,Сассенхейм', 52.2250000, 4.5222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100952, 'Sappemeer', 'Sappemeer', '', 53.1641700, 6.7902800, 'NL', '2009-01-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100953, 'Ruurlo', 'Ruurlo', '', 52.0883300, 6.4500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100954, 'Ruinerwold', 'Ruinerwold', '', 52.7233300, 6.2486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100955, 'Ruinen', 'Ruinen', '', 52.7625000, 6.3541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100956, 'Rugge', 'Rugge', '', 51.8992100, 4.1523100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100957, 'Rucphen', 'Rucphen', 'Rukfen', 51.5316700, 4.5583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100958, 'Rozendaal', 'Rozendaal', 'Roosendaal,Rosendaal', 52.0058300, 5.9625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100959, 'Rozenburg', 'Rozenburg', '', 51.9041700, 4.2486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100960, 'Rottevalle', 'Rottevalle', 'Rottefalle,Rottevalle', 53.1452300, 6.1041100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100961, 'Rotterdam', 'Rotterdam', 'Gorad Ratehrdam,RTM,Roterdam,Roterdama,Roterdamas,Roterdami,Roterdamo,Roterdan,Roterdao,Roterdão,Roterntam,Roterodamum,Rotterdam,Rottérdam,Róterdam,Róterdan,loteleudam,lu te dan,rattartem,rotaradema,rotterudamu,rtrdam,rwtrdam,rwtrdm,rxt the xr dam,Ρότερνταμ,Горад Ратэрдам,Ротердам,Роттердам,ראטערדאם,רוטרדם,راٹرڈیم,رتردام,روتردام,ܪܘܛܪܕܐܡ,रॉटरडॅम,ராட்டர்டேம்,รอตเทอร์ดาม,ရော်တာဒမ်မြို့,როტერდამი,ロッテルダム,鹿特丹,로테르담', 51.9225000, 4.4791700, 'NL', '2013-06-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100962, 'Rothem', 'Rothem', '', 50.8766700, 5.7388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100963, 'Rossum', 'Rossum', '', 52.3516700, 6.9222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100964, 'Rossum', 'Rossum', '', 51.8008300, 5.3333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100965, 'Roosteren', 'Roosteren', '', 51.0833300, 5.8180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100966, 'Roosendaal', 'Roosendaal', 'Roosendaal,Rosendael,Rozendael,Rozendal,Rozendal'',ZYO,losendal,luo sen da er,ro sen dal,rozendaru,rwsyndal,Розендал,Розендаль,روزن‌دال,روسيندال,โรเซนดาล,ローゼンダール,罗森达尔,로센달', 51.5308300, 4.4652800, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100967, 'Rolde', 'Rolde', '', 52.9841700, 6.6486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100968, 'Roermond', 'Roermond', 'Remunj,Reurmond,Roermond,Ruremonde,Rurmond,Rurmonda,Rurmondas,lu er meng de,rurumonto,rwrmwnd,Рурмонд,Рурмонда,رورموند,ルールモント,鲁尔蒙德', 51.1941700, 5.9875000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100969, 'Roelofarendsveen', 'Roelofarendsveen', '', 52.2033300, 4.6333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100970, 'Roden', 'Roden', 'Roan', 53.1375000, 6.4208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100971, 'Rockanje', 'Rockanje', 'Rockanje,Rokanje,Rokkanje', 51.8716700, 4.0708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100972, 'Rijswijk', 'Rijswijk', '', 52.0363400, 4.3250100, 'NL', '2008-01-21', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100973, 'Rijswijk', 'Rijswijk', '', 51.7975000, 5.0250000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100974, 'Rijsoord', 'Rijsoord', '', 51.8508300, 4.5958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100975, 'Rijsbergen', 'Rijsbergen', '', 51.5175000, 4.6972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100976, 'Rijpwetering', 'Rijpwetering', '', 52.1925000, 4.5833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100977, 'Rijnsburg', 'Rijnsburg', 'Reinsburgum,Rynsburch', 52.1900000, 4.4416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100978, 'Rijnsaterwoude', 'Rijnsaterwoude', 'Rijnxaterwoude', 52.1958300, 4.6708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100979, 'Rijen', 'Rijen', 'Reijen', 51.5908300, 4.9194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100980, 'Riethoven', 'Riethoven', '', 51.3541700, 5.3875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100981, 'Ridderkerk', 'Ridderkerk', 'Bidderkerk,Ridderkerk,Риддеркерк', 51.8725000, 4.6027800, 'NL', '2014-02-18', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100982, 'Rhoon', 'Rhoon', 'Ron,Roon,Рон', 51.8575000, 4.4222200, 'NL', '2007-11-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100983, 'Rhenen', 'Rhenen', 'QPT,Renen,Reynen,Rhenen,lei nen,rynn,Ренен,Ռեյնեն,رينن,رینن,雷嫩', 51.9591700, 5.5680600, 'NL', '2017-07-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100984, 'Rheden', 'Rheden', '', 52.0050000, 6.0291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100985, 'Reuver', 'Reuver', '', 51.2841700, 6.0777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100986, 'Reusel', 'Reusel', 'Reuzel', 51.3625000, 5.1652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100987, 'Renswoude', 'Renswoude', '', 52.0733300, 5.5402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100988, 'Renkum', 'Renkum', 'Renkum', 51.9766700, 5.7333300, 'NL', '2013-04-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100989, 'Renesse', 'Renesse', 'Renesse,Ренессе', 51.7325000, 3.7750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100990, 'Reeuwijk', 'Reeuwijk', 'lei wei ke,雷韦克', 52.0466700, 4.7250000, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100991, 'Reek', 'Reek', '', 51.7458300, 5.6819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100992, 'Ravenstein', 'Ravenstein', 'Ravestein,la fen si tai yin,拉芬斯泰因', 51.7966700, 5.6500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100993, 'Raamsdonksveer', 'Raamsdonksveer', 'Raamsdonkveer', 51.6966700, 4.8736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100994, 'Raamsdonk', 'Raamsdonk', '', 51.6875000, 4.9083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100995, 'Raam', 'Raam', '', 51.6596700, 5.6363700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100996, 'Raalte', 'Raalte', 'Raalt,Raalte,Раалт', 52.3858300, 6.2750000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100997, 'Quirijnstok', 'Quirijnstok', '', 51.5843000, 5.0981000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100998, 'Putten', 'Putten', 'Putten,Путтен', 52.2591700, 5.6069400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(100999, 'Putte', 'Putte', 'Putten', 51.3600000, 4.3958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101000, 'Puth', 'Puth', '', 50.9541700, 5.8736100, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101001, 'Purmerend', 'Purmerend', 'Pjurmerend,Purmerein,Purmerend,bwrmyrand,pi er mo lun de,purumerento,pwileumeleonteu,pwrmrnd,Пурмеренд,Пюрмеренд,Պուրմերենդ,بورميراند,پورمرند,ปืร์เมอแร็นด์,プルメレント,皮爾默倫德,퓌르메런트', 52.5050000, 4.9597200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101002, 'Puiflijk', 'Puiflijk', '', 51.8783300, 5.5902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101003, 'Prinsenbeek', 'Prinsenbeek', '', 51.5983300, 4.7125000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101004, 'Princenhage', 'Princenhage', 'Prinsenhage', 51.5763200, 4.7390600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101005, 'Pottenberg', 'Pottenberg', '', 50.8513500, 5.6566800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101006, 'Posterholt', 'Posterholt', '', 51.1233300, 6.0347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101007, 'Poortvliet', 'Poortvliet', '', 51.5441700, 4.1430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101008, 'Poeldijk', 'Poeldijk', '', 52.0241700, 4.2194400, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101009, 'Pijnacker', 'Pijnacker', 'Pijnacker,Pynakker', 52.0195400, 4.4294600, 'NL', '2015-02-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101010, 'Piershil', 'Piershil', '', 51.7933300, 4.3138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101011, 'Pierik', 'Pierik', '', 52.5014100, 6.1117000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101012, 'Petten', 'Petten', '', 52.7666700, 4.6611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101013, 'Pernis', 'Pernis', '', 51.8883300, 4.3888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101014, 'Pendrecht', 'Pendrecht', 'Pendrecht', 51.8715200, 4.4690100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101015, 'Peize', 'Peize', '', 53.1466700, 6.4972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101016, 'Peij', 'Peij', 'Pei,Pey', 51.0941700, 5.8958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101017, 'Pathmos', 'Pathmos', 'Pathmos,Patmos', 52.2139700, 6.8755500, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101018, 'Paterswolde', 'Paterswolde', 'QYT', 53.1450000, 6.5652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101019, 'Passart', 'Passart', '', 50.9238900, 5.9467400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101020, 'Papenveer', 'Papenveer', '', 52.1850000, 4.7250000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101021, 'Papendrecht', 'Papendrecht', 'Papendrekht,Papendrext,pa peng de lei he te,Папендрехт,Պապենդրեխտ,帕彭德雷赫特', 51.8316700, 4.6875000, 'NL', '2008-12-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101022, 'Panningen', 'Panningen', '', 51.3266700, 5.9791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101023, 'Pannerden', 'Pannerden', 'Rannereen', 51.8908300, 6.0388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101024, 'Palenstein', 'Palenstein', 'Palenstein', 52.0557900, 4.5086900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101025, 'Overveen', 'Overveen', '', 52.3916700, 4.6138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101026, 'Overschie', 'Overschie', 'Overschie', 51.9386300, 4.4276600, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101027, 'Overloon', 'Overloon', 'Loon,Overloon', 51.5716700, 5.9472200, 'NL', '2014-08-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101028, 'Overhoven', 'Overhoven', '', 51.0086900, 5.8662800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101029, 'Overberg', 'Overberg', '', 52.0400000, 5.4944400, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101030, 'Overasselt', 'Overasselt', '', 51.7600000, 5.7888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101031, 'Oud-Vossemeer', 'Oud-Vossemeer', 'Oud Vosmeer', 51.5708300, 4.1986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101032, 'Oud-Loosdrecht', 'Oud-Loosdrecht', 'Aud-Losdrekht,Ауд-Лосдрехт', 52.2066700, 5.0805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101033, 'Oudkarspel', 'Oudkarspel', '', 52.7158300, 4.8055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101034, 'Oud Gastel', 'Oud Gastel', '', 51.5866700, 4.4597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101035, 'Oude Wetering', 'Oude Wetering', '', 52.2141700, 4.6444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101036, 'Oudewater', 'Oudewater', '', 52.0250000, 4.8680600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101037, 'Oudeschoot', 'Oudeschoot', 'Aldskoat', 52.9334300, 5.9557900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101038, 'Oudeschild', 'Oudeschild', '', 53.0391700, 4.8472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101039, 'Ouderkerk aan den IJssel', 'Ouderkerk aan den IJssel', 'Ouderkerk,Ouderkerk a/d IJssel,Ouderkerk a/d Yssel,Ouderkerk aan de IJssel,Ouderkerk aan de Yssel,Ouderkerk aan den IJssel,Ouderkerk aan den Yssel,Ouderkerk-aan-den-IJsel', 51.9341700, 4.6361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101040, 'Ouderkerk aan de Amstel', 'Ouderkerk aan de Amstel', 'Auderkerk kaj Amstel,Ouder Amstel,Ouderkerk,Ouderkerk Aan Den Amstel,Ouderkerk a/d Amstel,Ouderkerk aan de Amstel,Ouderkerk-sur-lAmstel,Аудеркерк кај Амстел', 52.2950400, 4.9074600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101041, 'Oude Pekela', 'Oude Pekela', '', 53.1041700, 7.0097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101042, 'Oudemirdum', 'Oudemirdum', 'Aldemardum', 52.8501900, 5.5354400, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101043, 'Oudehaske', 'Oudehaske', 'Aldehaske,Oldehaske,Oudehaske', 52.9570900, 5.8709500, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101044, 'Oudega', 'Oudega', 'Aldegea,Oudega', 53.1250400, 5.9988800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101045, 'Ouddorp', 'Ouddorp', 'Alddoarp,Auddorp,Ouwdurp,Ауддорп', 51.8116700, 3.9347200, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101046, 'Oud-Caberg', 'Oud-Caberg', 'Caberg,Oud-Caberg', 50.8653900, 5.6644400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101047, 'Oud-Beijerland', 'Oud-Beijerland', 'Oud Beierland', 51.8241700, 4.4125000, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101048, 'Ottersum', 'Ottersum', '', 51.7033300, 5.9833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101049, 'Otterlo', 'Otterlo', 'Otterloo,otteruro,オッテルロー', 52.1000000, 5.7722200, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101050, 'Othene', 'Othene', '', 51.3308300, 3.8597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101051, 'Ossendrecht', 'Ossendrecht', '', 51.3941700, 4.3263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101052, 'Oss', 'Oss', 'Os,Oss,Oss i Nederland,ao si,osu,Осс,オス,奥斯', 51.7650000, 5.5180600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101053, 'Ospel', 'Ospel', '', 51.2975000, 5.7847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101054, 'Orthen', 'Orthen', '', 51.7061300, 5.3046800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101055, 'Orden', 'Orden', '', 52.2011300, 5.9341700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101056, 'Oranjewoud', 'Oranjewoud', 'It Oranjewald,It Oranjewâld', 52.9457900, 5.9503800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101057, 'Opperdoes', 'Opperdoes', '', 52.7591500, 5.0753400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101058, 'Oppenhuizen', 'Oppenhuizen', '', 53.0119400, 5.6949500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101059, 'Opmeer', 'Opmeer', 'Opmar,Opmeer', 52.7066700, 4.9444400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101060, 'Opijnen', 'Opijnen', 'Opitnen', 51.8291700, 5.2986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101061, 'Ophoven', 'Ophoven', '', 50.9903600, 5.8586800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101062, 'Opheusden', 'Opheusden', '', 51.9316700, 5.6319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101063, 'Ophemert', 'Ophemert', '', 51.8450000, 5.3875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101064, 'Opeinde', 'Opeinde', 'De Pein,Opeinde', 53.1341000, 6.0565600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101065, 'Ooyerhoek', 'Ooyerhoek', '', 52.1283800, 6.2230700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101066, 'Ootmarsum', 'Ootmarsum', '', 52.4083300, 6.9013900, 'NL', '2016-02-16', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101067, 'Oostvoorne', 'Oostvoorne', '', 51.9125000, 4.0986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101068, 'Oost-Vlieland', 'Oost-Vlieland', 'East Flylan,East Flylân', 53.2970300, 5.0743100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101069, 'Oostrum', 'Oostrum', '', 51.5291700, 6.0166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101070, 'Oostkapelle', 'Oostkapelle', '', 51.5666700, 3.5513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101071, 'Oosthuizen', 'Oosthuizen', '', 52.5725000, 4.9958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101072, 'Oosterzij', 'Oosterzij', '', 52.5850000, 4.7055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101073, 'Oosterwolde', 'Oosterwolde', 'Easterwalde,Easterwâlde,Oosterwolde,Oosterwoolde', 52.9916400, 6.2909600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101074, 'Oosterpark', 'Oosterpark', 'Oosterpark,Oosterparkwijk', 53.2237000, 6.5853000, 'NL', '2012-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101075, 'Eastermar', 'Eastermar', 'Eastermar,Oostermeer', 53.1746600, 6.0599900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101076, 'Oostermeenthe', 'Oostermeenthe', '', 52.7931900, 6.1313800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101077, 'Oosterland', 'Oosterland', '', 51.6500000, 4.0361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101078, 'Oosterhout', 'Oosterhout', '', 51.8800000, 5.8263900, 'NL', '2009-09-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101079, 'Oosterhout', 'Oosterhout', 'Oosterhout,Osterkhout,ao si te hao te,Остерхоут,奧斯特豪特', 51.6450000, 4.8597200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101080, 'Oosterhoogebrug', 'Oosterhoogebrug', '', 53.2289200, 6.6014100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101081, 'Oosterholt', 'Oosterholt', '', 52.5591700, 5.9555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101082, 'Oosterhesselen', 'Oosterhesselen', '', 52.7541700, 6.7222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101083, 'Oosterblokker', 'Oosterblokker', '', 52.6691700, 5.1180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101084, 'Oosterbeek', 'Oosterbeek', 'Osterbek,Остербек', 51.9858300, 5.8458300, 'NL', '2009-09-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101085, 'Oostendorp', 'Oostendorp', 'Oostdorp', 52.4472200, 5.8544300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101086, 'Oostelbeers', 'Oostelbeers', '', 51.4717100, 5.2689700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101087, 'Oosteinde', 'Oosteinde', '', 52.2791700, 4.7958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101088, 'Oosteind', 'Oosteind', '', 51.6441800, 4.8978400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101089, 'Oostdorp', 'Oostdorp', '', 52.1499400, 4.3931900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101090, 'Oostburg', 'Oostburg', 'Oostburg,Ostburg,Wostburg,Wòstburg,Ôostburg,Остбург', 51.3258300, 3.4875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101091, 'Ooy', 'Ooy', 'Ooi,Ooy', 51.9191700, 6.0583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101092, 'Ooij', 'Ooij', 'Ooi,Ooy', 51.8546500, 5.9391500, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101093, 'Oog in Al', 'Oog in Al', 'Oog in Al', 52.0863600, 5.0847000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101094, 'Onstwedde', 'Onstwedde', '', 53.0350000, 7.0402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101095, 'Onderdijk', 'Onderdijk', '', 52.7433300, 5.1375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101096, 'Ommoord', 'Ommoord', 'Ommoord', 51.9595100, 4.5453300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101097, 'Ommelanderwijk', 'Ommelanderwijk', '', 53.0891700, 6.9055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101098, 'Olst', 'Olst', '', 52.3375000, 6.1097200, 'NL', '2008-12-21', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101099, 'Oldenzaal', 'Oldenzaal', 'Oldenzaal,Oldenzal,Олдензал', 52.3133300, 6.9291700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101100, 'Oldemarkt', 'Oldemarkt', '', 52.8208300, 5.9750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101101, 'Oldehove', 'Oldehove', 'Oldenhove', 53.3033300, 6.3958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101102, 'Oldebroek', 'Oldebroek', 'Oldebruk,Olderbroek,Олдебрук', 52.4450000, 5.9013900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101103, 'Aldeboarn', 'Aldeboarn', 'Aldeboarn,Oldeboorn', 53.0500000, 5.9000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101104, 'Oldeberkoop', 'Oldeberkoop', 'Aldeberkeap,Berkeap,Berkoop,Oldeberkoop', 52.9378800, 6.1308900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101105, 'Oisterwijk', 'Oisterwijk', 'Oisterwijk,Ojstervejk,Oosterwijk,Ойстервейк', 51.5791700, 5.1888900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101106, 'Oirschot', 'Oirschot', 'Oirschot,Oorschot', 51.5050000, 5.3138900, 'NL', '2009-10-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101107, 'Oirsbeek', 'Oirsbeek', 'Oeesjbik,Oeësjbik,Oorsbeek', 50.9508300, 5.9083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101108, 'Oirlo', 'Oirlo', 'Oorlo,Oorloo', 51.5116700, 6.0375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101109, 'Offenbeek', 'Offenbeek', 'Offenbeck,Offenbeek', 51.2822500, 6.0950000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101110, 'Oerle', 'Oerle', 'Oers', 51.4225500, 5.3716300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101111, 'Oentsjerk', 'Oentsjerk', 'Oenkerk,Oentsjerk', 53.2500000, 5.9000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101112, 'Oegstgeest', 'Oegstgeest', 'Oegstgeest,Oestgeest', 52.1800000, 4.4694400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101113, 'Odoorn', 'Odoorn', '', 52.8491700, 6.8513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101114, 'Odiliapeel', 'Odiliapeel', '', 51.6433300, 5.7055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101115, 'Odijk', 'Odijk', '', 52.0525000, 5.2361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101116, 'Ochten', 'Ochten', '', 51.9100000, 5.5694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101117, 'Obergum', 'Obergum', 'Obergum', 53.3333300, 6.5166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101118, 'Obdam', 'Obdam', 'Obdam', 52.6758300, 4.9069400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101119, 'Obbicht', 'Obbicht', '', 51.0283300, 5.7805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101120, 'Nuth', 'Nuth', 'Nut,Nuth', 50.9175000, 5.8861100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101121, 'Nunspeet', 'Nunspeet', '', 52.3791700, 5.7861100, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101122, 'Numansdorp', 'Numansdorp', 'Buitensluis,Niemansdorp,Numansdurp', 51.7316700, 4.4375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101123, 'Nuenen', 'Nuenen', 'Njunen,Nuenen,Нюнен', 51.4700000, 5.5527800, 'NL', '2014-06-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101124, 'Norg', 'Norg', '', 53.0666700, 6.4583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101125, 'Noordwolde', 'Noordwolde', 'Noardwalde,Noardwâlde,Noordwolde', 52.8896400, 6.1415300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101126, 'Noordwijkerhout', 'Noordwijkerhout', '', 52.2616700, 4.4930600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101127, 'Noordwijk-Binnen', 'Noordwijk-Binnen', 'Noordwijk', 52.2340000, 4.4447400, 'NL', '2012-06-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101128, 'Noord-Scharwoude', 'Noord-Scharwoude', '', 52.6983300, 4.8111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101129, 'Noordhorn', 'Noordhorn', '', 53.2616700, 6.3958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101130, 'Noord-Hofland', 'Noord-Hofland', '', 52.1405900, 4.4586400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101131, 'Noordhoek', 'Noordhoek', '', 51.6425000, 4.5319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101132, 'Noordgeest', 'Noordgeest', '', 51.5091700, 4.2791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101133, 'Noordeloos', 'Noordeloos', '', 51.9033300, 4.9416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101134, 'Noordeinde', 'Noordeinde', '', 52.0166700, 4.4833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101135, 'Noordbroek', 'Noordbroek', '', 53.1950000, 6.8736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101136, 'Noardburgum', 'Noardburgum', 'Noardburgum,Noordbergum', 53.2213500, 6.0052300, 'NL', '2008-10-23', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101137, 'Noordbarge', 'Noordbarge', 'Noordbarge', 52.7723700, 6.8871300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101138, 'Nistelrode', 'Nistelrode', '', 51.7041700, 5.5625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101139, 'Nispen', 'Nispen', '', 51.4833100, 4.4613100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101140, 'Nijrees', 'Nijrees', '', 52.3350000, 6.6638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101141, 'Nijnsel', 'Nijnsel', 'Neinsel,Nijrsel', 51.5508300, 5.4833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101142, 'Nijmegen', 'Nijmegen', 'Gemeen Nimwaege,Gorad Najmegen,Naimechen,Najmegen,Neimegena,Neimegenas,Nejmegen,Neymeyxen,Nijmegen,Nijmeyen,Nimega,Nimegen,Nimegue,Nimwege,Nimwegen,Nimègue,Nymegen,Nymwegen,Nîmegue,Nĳmegen,QNQ,Ulpia Noviomagus Batavorum,nai mei heng,naimehen,naymykhn,ne me ken,neimegeni,neimeheon,njmygan,nymykhn,nyymkn,Ναϊμέχεν,Горад Наймеген,Најмеген,Неймеген,Նեյմեյխեն,ניימכן,نايميخن,نجمیگان,نیمیخن,เนเมเกน,ნეიმეგენი,ኔመሕን,ナイメーヘン,奈梅亨,네이메헌', 51.8425000, 5.8527800, 'NL', '2015-11-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101143, 'Nijkerkerveen', 'Nijkerkerveen', '', 52.1950000, 5.4666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101144, 'Nijkerk', 'Nijkerk', 'Neykerk,nai kai er ke,naykyrk,neikeoleukeu,neikeruku,Նեյկերկ,نايكيرك,ネイケルク,奈凱爾克,네이커르크', 52.2200000, 5.4861100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101145, 'Nijenheim', 'Nijenheim', '', 52.0868900, 5.2185200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101146, 'Nieuw-Vossemeer', 'Nieuw-Vossemeer', 'Nieuw-Vosmeer', 51.5900000, 4.2180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101147, 'Nieuwveen', 'Nieuwveen', '', 52.1966700, 4.7569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101148, 'Nieuw-Roden', 'Nieuw-Roden', '', 53.1316700, 6.3972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101149, 'Nieuwpoort', 'Nieuwpoort', '', 51.9358300, 4.8680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101150, 'Nieuwoord', 'Nieuwoord', '', 52.4666700, 6.5500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101151, 'Nieuwolda', 'Nieuwolda', '', 53.2441700, 6.9750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101152, 'Nieuw-Lotbroek', 'Nieuw-Lotbroek', '', 50.9128300, 5.9279800, 'NL', '2009-10-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101153, 'Nieuw-Loosdrecht', 'Nieuw-Loosdrecht', 'N''iv-Losdrekht,Ньив-Лосдрехт', 52.1991700, 5.1388900, 'NL', '2010-09-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101154, 'Nieuw-Lekkerland', 'Nieuw-Lekkerland', 'N''iv-Lekkerland,Niu-Lekerland,niulekeleullanteu,xin lai ke lan,Ньив-Леккерланд,Նիու-Լեկերլանդ,ニーウ・レッケルラント,新莱克兰,니우레케를란트', 51.8891500, 4.6865300, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101155, 'Nieuw- en Sint Joosland', 'Nieuw- en Sint Joosland', 'Nieuw-en Sint Joosland', 51.4833300, 3.6569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101156, 'Nieuwkuijk', 'Nieuwkuijk', 'Nieuwkuik', 51.6900000, 5.1819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101157, 'Nieuwkoop', 'Nieuwkoop', '', 52.1508300, 4.7763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101158, 'Nieuwerkerk', 'Nieuwerkerk', '', 51.6508300, 4.0013900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101159, 'Nieuwe Pekela', 'Nieuwe Pekela', '', 53.0791700, 6.9652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101160, 'Nieuwe-Niedorp', 'Nieuwe-Niedorp', '', 52.7400000, 4.8986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101161, 'Nieuwenhoorn', 'Nieuwenhoorn', '', 51.8541700, 4.1430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101162, 'Nieuwehorne', 'Nieuwehorne', 'Nieuwehorne,Nijehorne,Nijhoarne', 52.9511300, 6.0634200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101163, 'Nieuwegein', 'Nieuwegein', 'Nieuwegein,Nieuwegen', 52.0291700, 5.0805600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101164, 'Nieuwdorp', 'Nieuwdorp', '', 50.9621600, 5.7729700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101165, 'Nieuw-Dordrecht', 'Nieuw-Dordrecht', '', 52.7483300, 6.9680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101166, 'Nieuw-Buinen', 'Nieuw-Buinen', '', 52.9625000, 6.9500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101167, 'Nieuw-Beijerland', 'Nieuw-Beijerland', 'Nieuw-Beierland', 51.8125000, 4.3430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101168, 'Niekerk', 'Niekerk', '', 53.2250000, 6.3527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101169, 'Nes', 'Nes', 'Nes', 53.4450200, 5.7740000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101170, 'Nes', 'Nes', 'Nes', 53.0520700, 5.8522300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101171, 'Neerkant', 'Neerkant', '', 51.3683300, 5.8666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101172, 'Neerbeek', 'Neerbeek', '', 50.9500000, 5.8152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101173, 'Andel', 'Andel', 'Andel', 51.7833300, 5.0583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101174, 'Neede', 'Neede', 'Nede', 52.1341700, 6.6138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101175, 'Nederwoud', 'Nederwoud', '', 52.1008300, 5.5708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101176, 'Nederweert', 'Nederweert', 'Nedervert,Nederweert,Neyderveyrt,Ni-jwieert,Ni-jwieërt,Недерверт,Նեյդերվեյրտ', 51.2858300, 5.7486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101177, 'Nederhemert-Noord', 'Nederhemert-Noord', 'Nederhemert Noordzijde,Nederhemert-Noord', 51.7632200, 5.1730500, 'NL', '2012-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101178, 'Nederhemert', 'Nederhemert', '', 51.7651800, 5.1681700, 'NL', '2009-01-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101179, 'Neder-Hardinxveld', 'Neder-Hardinxveld', 'Neder Hardingsveld,Neder-Hardinxveld', 51.8287900, 4.8548900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101180, 'Naastenbest', 'Naastenbest', '', 51.5048400, 5.3857900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101181, 'Naarden', 'Naarden', 'Naarden', 52.2958300, 5.1625000, 'NL', '2016-07-31', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101182, 'Naaldwijk', 'Naaldwijk', 'Naldvejk,Налдвейк', 51.9941700, 4.2097200, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101183, 'Munstergeleen', 'Munstergeleen', 'Munstergelaen', 50.9750000, 5.8638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101184, 'Muiderberg', 'Muiderberg', '', 52.3258300, 5.1208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101185, 'Mook', 'Mook', '', 51.7525000, 5.8819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101186, 'Montfort', 'Montfort', 'Mofert,meng fu te,ᎼᏋᏗ,蒙福特', 51.1258300, 5.9486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101187, 'Montfoort', 'Montfoort', '', 52.0458300, 4.9527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101188, 'Monster', 'Monster', 'Monster,Монстер', 52.0258300, 4.1750000, 'NL', '2008-12-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101189, 'Monnickendam', 'Monnickendam', 'Monnikendam,Monnikkendam,meng ni ken dan,Монниккендам,蒙尼肯丹', 52.4583300, 5.0375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101190, 'Molenhoek', 'Molenhoek', '', 51.7111300, 5.3680900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101191, 'Moesel', 'Moesel', 'Moezel', 51.2382800, 5.7177800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101192, 'Moerdijk', 'Moerdijk', 'Moerdijk', 51.7016700, 4.6263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101193, 'Minnertsga', 'Minnertsga', 'Minnertsga,Minnertsgea', 53.2510400, 5.5951300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101194, 'Milsbeek', 'Milsbeek', 'Milsbeek bij Gennep', 51.7250000, 5.9486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101195, 'Milheeze', 'Milheeze', '', 51.5016700, 5.7791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101196, 'Mijnsheerenland', 'Mijnsheerenland', '', 51.7966700, 4.4875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101197, 'Mijdrecht', 'Mijdrecht', 'Mijdrecht,Mudrecht,Müdrecht', 52.2066700, 4.8625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101198, 'Mierlo', 'Mierlo', 'Mierloo', 51.4400000, 5.6194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101199, 'Midwoud', 'Midwoud', '', 52.7166700, 5.0750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101200, 'Midwolda', 'Midwolda', '', 53.1950000, 7.0138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101201, 'Middenmeer', 'Middenmeer', '', 52.8066700, 4.9986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101202, 'Middenbeemster', 'Middenbeemster', '', 52.5491700, 4.9125000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101203, 'Middelstum', 'Middelstum', '', 53.3466700, 6.6416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101204, 'Middelsluis', 'Middelsluis', '', 51.7425000, 4.4416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101205, 'Middelrode', 'Middelrode', '', 51.6641700, 5.4194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101206, 'Middelharnis', 'Middelharnis', 'Menheerse,Middelharnis,Middelkharnis,Midelharnis,mi de er ha ni si,Мидделхарнис,Միդելհարնիս,米德尔哈尼斯', 51.7575000, 4.1652800, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101207, 'Middelburg', 'Middelburg', 'Gorad Midehlburg,Medioburgum,Middelbourg,Middelburch,Middelburg,Midelb''org,Midelburg,Midelburgas,Midelburgo,Mintelmpourch,mi de er bao,midelbwileuheu,mideruburufu,Μίντελμπουρχ,Горад Мідэлбург,Мидделбург,Миделбург,Миделбьорг,Мідделбург,میدل‌بورخ,ミデルブルフ,米德尔堡,미델뷔르흐', 51.5000000, 3.6138900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101208, 'Middelbeers', 'Middelbeers', '', 51.4666700, 5.2500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101209, 'Meteren', 'Meteren', '', 51.8650000, 5.2833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101210, 'Merum', 'Merum', '', 51.1733300, 5.9597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101211, 'Merselo', 'Merselo', 'Meerselo', 51.5300000, 5.9277800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101212, 'Merkelbeek', 'Merkelbeek', '', 50.9538900, 5.9406900, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101213, 'Merenwijk', 'Merenwijk', '', 52.1765500, 4.5088500, 'NL', '2016-12-27', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101214, 'Meppel', 'Meppel', 'Meppel,Меппел', 52.6958300, 6.1944400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101215, 'Menaam', 'Menaam', 'Menaam,Menaldum', 53.2179700, 5.6612400, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101216, 'Melle', 'Melle', '', 51.6624400, 5.6336700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101217, 'Meliskerke', 'Meliskerke', '', 51.5141700, 3.5097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101218, 'Melick', 'Melick', 'Melik', 51.1591700, 6.0166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101219, 'Melderslo', 'Melderslo', '', 51.4616700, 6.0861100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101220, 'Mekkelholt', 'Mekkelholt', '', 52.2364500, 6.8905800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101221, 'Meijel', 'Meijel', 'Mael,Meiel', 51.3441700, 5.8847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101222, 'Megen', 'Megen', '', 51.8216700, 5.5625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101223, 'Meezenbroek', 'Meezenbroek', '', 50.8968000, 5.9905100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101224, 'Meerveldhoven', 'Meerveldhoven', 'Meerveldhoven,Mereveldhoven', 51.4170500, 5.4161800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101225, 'Meerssen', 'Meerssen', 'Meersen,Meersje,Meerssen', 50.8875000, 5.7500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101226, 'Meerlo', 'Meerlo', 'Meerloo', 51.5133300, 6.0847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101227, 'Meeden', 'Meeden', '', 53.1400000, 6.9263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101228, 'Medemblik', 'Medemblik', 'Medemblik', 52.7716700, 5.1055600, 'NL', '2013-10-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101229, 'Mechelen', 'Mechelen', 'Mechele', 50.7958300, 5.9263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101230, 'Maurik', 'Maurik', '', 51.9608300, 5.4222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101231, 'Marum', 'Marum', 'Marum', 53.1441700, 6.2625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101232, 'Marsum', 'Marsum', 'Marssum,Marsum', 53.2105000, 5.7263700, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101233, 'Marrum', 'Marrum', '', 53.3227700, 5.8019800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101234, 'Markelo', 'Markelo', 'Markeloo', 52.2350000, 6.4986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101235, 'Mariarade', 'Mariarade', '', 50.9290600, 5.9273800, 'NL', '2009-10-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101236, 'Mariahout', 'Mariahout', '', 51.5408300, 5.5722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101237, 'Margraten', 'Margraten', 'Mergraote', 50.8208300, 5.8208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101238, 'Mantgum', 'Mantgum', '', 53.1286500, 5.7192400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101239, 'Malta', 'Malta', '', 51.6500000, 3.9333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101240, 'Malburgen West', 'Malburgen West', '', 51.9681100, 5.8974300, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101241, 'Malberg', 'Malberg', '', 50.8624400, 5.6541900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101242, 'Makkum', 'Makkum', '', 53.0951300, 5.6794600, 'NL', '2010-08-31', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101243, 'Makkum', 'Makkum', '', 53.0545800, 5.4023100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101244, 'Magele', 'Magele', '', 52.4691700, 6.5208300, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101245, 'Made', 'Made', 'Die Meede,میڈ، نیدرلینڈز', 51.6766700, 4.7930600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101246, 'Maastricht', 'Maastricht', 'Gorad Maastrykht,MST,Maastricht,Maastrikht,Maestricht,Mastrichtas,Mastrihta,Mastrikht,Mastrique,Mastrixt,Mestreech,Māstrihta,Traiectum Mosae,ma si te li he te,mas thrichth,maseuteuliheuteu,mastrikhta,mastrikt,mastrkht,mastrsht,mastrykht,masutorihito,Μάαστριχτ,Горад Маастрыхт,Маастрихт,Мастрихт,Մաստրիխտ,מאסטריכט,ماسترخت,ماسترشت,ماستریخت,मास्ट्रिख्ट,மாஸ்ட்ரிக்ட்,มาสทริชท์,მაასტრიხტი,マーストリヒト,马斯特里赫特,마스트리흐트', 50.8483300, 5.6888900, 'NL', '2016-08-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101247, 'Maassluis', 'Maassluis', 'Maassluis', 51.9233300, 4.2500000, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101248, 'Maasland', 'Maasland', '', 51.9341700, 4.2722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101249, 'Maaskantje', 'Maaskantje', '', 51.6583300, 5.3708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101250, 'Maasdijk', 'Maasdijk', '', 51.9591700, 4.2138900, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101251, 'Maasbree', 'Maasbree', 'Bree,masbryy,ماسبریی', 51.3575000, 6.0486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101252, 'Maasbracht', 'Maasbracht', 'Brach,Maasbracht', 51.1392900, 5.8862700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101253, 'Maartensdijk', 'Maartensdijk', 'Maartensdyk', 52.1550000, 5.1750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101254, 'Maarssen', 'Maarssen', 'Maarsen,marsyn,مارسین', 52.1391700, 5.0416700, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101255, 'Maarn', 'Maarn', 'marn,مارن', 52.0641700, 5.3708300, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101256, 'Maarheeze', 'Maarheeze', 'Haarheeze,Maarheze,Mares,Mâres,مارہییزی', 51.3116700, 5.6166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101257, 'Luyksgestel', 'Luyksgestel', 'Luijksgestel,Luiksgestel', 51.2891700, 5.3236100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101258, 'Lutjebroek', 'Lutjebroek', '', 52.6975000, 5.2041700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101259, 'Lunteren', 'Lunteren', '', 52.0850000, 5.6222200, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101260, 'Loven', 'Loven', '', 51.5648000, 5.0974800, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101261, 'Lottum', 'Lottum', '', 51.4616700, 6.1611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101262, 'Losser', 'Losser', 'Losser,Лоссер', 52.2608300, 7.0041700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101263, 'Loppersum', 'Loppersum', 'Loppersum', 53.3316700, 6.7472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101264, 'Lopik', 'Lopik', '', 51.9725000, 4.9486100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101265, 'Loosbroek', 'Loosbroek', '', 51.6783300, 5.5069400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101266, 'Loon op Zand', 'Loon op Zand', 'Loon op Zand,Venloen op Zand', 51.6275000, 5.0750000, 'NL', '2014-01-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101267, 'Lombardijen', 'Lombardijen', 'Lombardijen', 51.8738000, 4.5219200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101268, 'Loenen', 'Loenen', '', 52.1175000, 6.0194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101269, 'Lochem', 'Lochem', '', 52.1591700, 6.4111100, 'NL', '2008-12-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101270, 'Lobith', 'Lobith', 'Lebith,Lobit', 51.8625000, 6.1180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101271, 'Lith', 'Lith', 'Lit,Lith', 51.8058300, 5.4388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101272, 'Lisserbroek', 'Lisserbroek', '', 52.2566700, 4.5722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101273, 'Lisse', 'Lisse', 'Lisse,Лиссе', 52.2600000, 4.5569400, 'NL', '2015-12-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101274, 'Linschoten', 'Linschoten', '', 52.0625000, 4.9152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101275, 'Linne', 'Linne', '', 51.1550000, 5.9388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101276, 'Lindenholt', 'Lindenholt', '', 51.8327000, 5.7934000, 'NL', '2009-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101277, 'Lindenheuvel', 'Lindenheuvel', '', 50.9850900, 5.8166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101278, 'Limmel', 'Limmel', '', 50.8671800, 5.7071900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101279, 'Limbricht', 'Limbricht', 'Limbricht,Limbrikht,Лимбрихт', 51.0116700, 5.8375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101280, 'Lievendaal', 'Lievendaal', '', 51.4421900, 5.4340500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101281, 'Liesveld', 'Liesveld', '', 51.9325000, 4.8319400, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101282, 'Liessel', 'Liessel', 'Liesel,Liezel', 51.4133300, 5.8208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101283, 'Lieshout', 'Lieshout', 'lyshawt,لیسهاوت', 51.5203600, 5.5947900, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101284, 'Lierop', 'Lierop', '', 51.4191700, 5.6791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101285, 'Lienden', 'Lienden', '', 51.9483300, 5.5180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101286, 'Liempde', 'Liempde', '', 51.5691700, 5.3722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101287, 'Lichtenvoorde', 'Lichtenvoorde', '', 51.9866700, 6.5666700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101288, 'Lichtenberg', 'Lichtenberg', '', 50.9022000, 6.0252300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101289, 'Leuth', 'Leuth', 'Leut', 51.8391700, 5.9916700, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101290, 'Leusden', 'Leusden', 'Hamersveld,Leusden,Leusden-Centrum,Леусден', 52.1325000, 5.4319400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101291, 'Leunen', 'Leunen', '', 51.5100000, 5.9791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101292, 'Leuken', 'Leuken', '', 51.2528800, 5.7346000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101293, 'Lepelstraat', 'Lepelstraat', '', 51.5483300, 4.2763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101294, 'Lent', 'Lent', 'Tent', 51.8616700, 5.8666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101295, 'Lemmer', 'Lemmer', 'De Lemmer,Lemmer', 52.8461800, 5.7091200, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101296, 'Lelystad', 'Lelystad', 'LEY,Lelistad,Lelystad,lai li si ta de,Лелистад,لیلی‌استاد,莱利斯塔德', 52.5083300, 5.4750000, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101297, 'Leimuiden', 'Leimuiden', 'Leymuiden', 52.2241700, 4.6694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101298, 'Leiderdorp', 'Leiderdorp', 'Lejderdorp,Lejderdorpe,Leyderdorp,lai de duo pu,laydrdwrb,Лейдердорп,Лейдердорпе,Լեյդերդորպ,لايدردورب,莱德多普', 52.1583300, 4.5291700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101299, 'Leiden', 'Leiden', 'Gorad Lejdehn,Lajden,Leida,Leiden,Leidenas,Leidene,Leie,Leien,Leinten,Lejda,Lejden,Lejdeni,Leyde,Leyden,Lugdunum,Lugdunum Batavorum,Lèida,la''idena,lai dun,laitan,laydn,laydyn,leideni,leideon,li dein,lydn,lyydn,raiden,Λέιντεν,Горад Лейдэн,Лайден,Лајден,Лейден,Լեյդեն,ליידן,لائڈن,لايدن,لايدين,لیدن,লাইডেন,லைடன்,ไลเดิน,ლეიდენი,ライデン,莱顿,레이던', 52.1583300, 4.4930600, 'NL', '2017-01-31', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101300, 'Leeuwen', 'Leeuwen', '', 51.2103200, 5.9986200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101301, 'Leeuwarden', 'Leeuwarden', 'Gorad Leuvardehn,L''ovet,LWR,Leeuwarden,Leewarden,Leuvarden,Leuvardena,Leuvardenas,Leyvarden,Lieuwarden,Liewarde,Liwwadden,Ljouwert,leiualeudeon,lew ar dein,liyuvardena,lu fa deng,lywwardn,rewaruden,Горад Леўвардэн,Леуварден,Льовет,ليوواردن,لیوواردن,लीयुवार्डेन,เลวาร์เดิน,レーワルデン,吕伐登,레이우아르던', 53.2013900, 5.8085900, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101302, 'Leesten', 'Leesten', '', 52.1279000, 6.2321700, 'NL', '2009-09-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101303, 'Leest', 'Leest', '', 51.6098300, 5.5431200, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101304, 'Leersum', 'Leersum', 'lai er se mu,萊爾瑟姆', 52.0116700, 5.4277800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101305, 'Leerdam', 'Leerdam', 'Leerdam,Lerdam,Leyrdam,lai er dan,lyrdam,Лердам,Լեյրդամ,ليردام,莱尔丹', 51.8933300, 5.0916700, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101306, 'Leens', 'Leens', 'Lens,Liens,Lèns', 53.3600000, 6.3791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101307, 'Leende', 'Leende', '', 51.3508300, 5.5541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101308, 'Leek', 'Leek', 'De Leek,De Like,Leek,Lek,Leyk,lei ke,lyk,Лек,Լեյկ,ليك,雷克', 53.1625000, 6.3763900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101309, 'Lauradorp', 'Lauradorp', '', 50.9122900, 6.0459100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101310, 'Laren', 'Laren', 'Laren,la lun,laryn,raren,Ларен,Լարեն,لارين,لارین,ラーレン,拉倫', 52.2566700, 5.2277800, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101311, 'Laren', 'Laren', '', 52.1941700, 6.3652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101312, 'Langweer', 'Langweer', 'Langwar,Langweer', 52.9583600, 5.7217300, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101313, 'Langenoord', 'Langenoord', 'Langeroord', 52.1876800, 5.3803400, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101314, 'Langenboom', 'Langenboom', 'Lange Boom,Langenboem', 51.7041700, 5.7305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101315, 'Langeheit', 'Langeheit', '', 52.4920000, 4.7584900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101316, 'Landsmeer', 'Landsmeer', 'Landsmeer,Landsmer,Landsmeyr,Lansmar,Lânsmar,landsmyr,Ландсмер,Լանդսմեյր,لاندسمير,لانڈسمیر', 52.4308300, 4.9152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101317, 'Lammerenburg', 'Lammerenburg', '', 51.4666700, 3.5583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101318, 'Lage Mierde', 'Lage Mierde', '', 51.4058300, 5.1472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101319, 'Kwintsheul', 'Kwintsheul', '', 52.0133300, 4.2555600, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101320, 'Kunrade', 'Kunrade', '', 50.8776900, 5.9310700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101321, 'Kudelstaart', 'Kudelstaart', '', 52.2341700, 4.7513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101322, 'Kruisland', 'Kruisland', '', 51.5691700, 4.4097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101323, 'Kruisberg', 'Kruisberg', '', 50.9423400, 5.9651900, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101324, 'Krooswijk', 'Krooswijk', '', 51.6466500, 4.5920300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101325, 'Krimpen aan den IJssel', 'Krimpen aan den IJssel', 'Krimpen,Krimpen a/d IJssel,Krimpen a/d Yssel,Krimpen aan de Yssel,Krimpen aan den IJssel,Krimpen aan den Yssel', 51.9166700, 4.6027800, 'NL', '2015-05-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101326, 'Krakeel', 'Krakeel', '', 52.7233900, 6.5114600, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101327, 'Koudum', 'Koudum', 'Koudum', 52.9155100, 5.4483400, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101328, 'Koudekerke', 'Koudekerke', '', 51.4816700, 3.5541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101329, 'Korvel', 'Korvel', '', 51.5495400, 5.0707900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101330, 'Kortenhoef', 'Kortenhoef', 'Kortenkhov,Кортенхов', 52.2391700, 5.1069400, 'NL', '2009-10-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101331, 'Korrewegwijk', 'Korrewegwijk', '', 53.2323500, 6.5680400, 'NL', '2011-04-19', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101332, 'Kootwijkerbroek', 'Kootwijkerbroek', '', 52.1508300, 5.6694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101333, 'Kootstertille', 'Kootstertille', 'Koatstertille,Kootstertille', 53.2126100, 6.0920900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101334, 'Koningslust', 'Koningslust', '', 51.3575000, 5.9930600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101335, 'Koningsbosch', 'Koningsbosch', '', 51.0516700, 5.9583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101336, 'Kollumerzwaag', 'Kollumerzwaag', 'Kollumerlan,Kollumerland,Kollumerlân,Kollumersweach,Kollumerzwaag', 53.2622400, 6.0754400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101337, 'Kollum', 'Kollum', 'Kollum', 53.2769500, 6.1529300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101338, 'Koewacht', 'Koewacht', '', 51.2283300, 3.9736100, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101339, 'Koekange', 'Koekange', '', 52.6991700, 6.3166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101340, 'Klundert', 'Klundert', '', 51.6650000, 4.5347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101341, 'Kloetinge', 'Kloetinge', '', 51.4983300, 3.9152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101342, 'Klimmen', 'Klimmen', 'Klumme', 50.8758300, 5.8805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101343, 'Klein-Zundert', 'Klein-Zundert', '', 51.4808300, 4.6541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101344, 'Klein Driene', 'Klein Driene', '', 52.2693500, 6.8161300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101345, 'Klazienaveen', 'Klazienaveen', '', 52.7241700, 6.9902800, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101346, 'Klarenbeek', 'Klarenbeek', '', 51.5096400, 3.6113200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101347, 'Klaaswaal', 'Klaaswaal', '', 51.7700000, 4.4458300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101348, 'Kijkduin', 'Kijkduin', 'Kijkduin', 52.0676500, 4.2218800, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101349, 'Kesteren', 'Kesteren', '', 51.9350000, 5.5694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101350, 'Kessel', 'Kessel', 'kai se er,凱瑟爾', 51.2916700, 6.0541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101351, 'Kerschoten', 'Kerschoten', '', 52.2333300, 5.9666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101352, 'Kerkrade', 'Kerkrade', 'Kerkraad,Kerkrade,Kirchrath,Kirchroa,kerukurade,Керкраде,ケルクラーデ', 50.8658300, 6.0625000, 'NL', '2013-08-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101353, 'Kerkelanden', 'Kerkelanden', '', 52.2175500, 5.1357500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101354, 'Kerkehout', 'Kerkehout', '', 52.1101800, 4.3795700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101355, 'Kerkdriel', 'Kerkdriel', '', 51.7716700, 5.3347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101356, 'Marken', 'Marken', 'Marken,Monnickenwerf,Monnikenwerf,Маркен', 52.4583300, 5.1027800, 'NL', '2010-01-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101357, 'Kerensheide', 'Kerensheide', 'De Kaereshei', 50.9721000, 5.7766600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101358, 'Kerckebosch', 'Kerckebosch', '', 52.0784400, 5.2658400, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101359, 'Keijenborg', 'Keijenborg', 'Keienborg,Keienburg,Keyenborg', 52.0291700, 6.2944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101360, 'Keent', 'Keent', '', 51.2421800, 5.7007900, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101361, 'Kedichem', 'Kedichem', '', 51.8600000, 5.0500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101362, 'Katwijk aan Zee', 'Katwijk aan Zee', 'Katijk aan Zee,Katwijk Aan Zee,Katwyk Aan Zee', 52.2033300, 4.3986100, 'NL', '2016-12-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101363, 'Katwijk aan den Rijn', 'Katwijk aan den Rijn', 'Katwijk,Katwijk a/d Rijn,Katwijk aan de Rijn,Katwijk aan den Rijn', 52.1941700, 4.4222200, 'NL', '2016-12-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101364, 'Katendrecht', 'Katendrecht', 'Katendrecht', 51.9007400, 4.4825400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101365, 'Kamperland', 'Kamperland', 'Camperland,Kamperland,Камперланд', 51.5716700, 3.7041700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101366, 'Kampen', 'Kampen', 'Gemeen Kampen,Gorad Kampen,Kampen,kambn,kampeon,kan peng,kanpen,qmpn,Горад Кампен,Кампен,Կամպեն,קמפן,كامبن,カンペン,坎彭,캄펀', 52.5550000, 5.9111100, 'NL', '2013-09-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101367, 'Kalsdonk', 'Kalsdonk', '', 51.5397300, 4.4711100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101368, 'Kakert', 'Kakert', '', 50.9041400, 6.0046300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101369, 'Kadoelen', 'Kadoelen', 'Cadoelen', 52.4175000, 4.9056100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101370, 'Kaalheide', 'Kaalheide', 'Kaalhei', 50.8650500, 6.0364300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101371, 'Joure', 'Joure', 'De Jouwer,Joure,ywrh,يوره', 52.9657000, 5.8030100, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101372, 'Jagershoef', 'Jagershoef', '', 51.4733000, 5.4672000, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101373, 'Jirnsum', 'Jirnsum', 'Irnsum,Jirnsum', 53.0775300, 5.7925400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101374, 'Ingen', 'Ingen', '', 51.9591700, 5.4847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101375, 'Ilpendam', 'Ilpendam', '', 52.4633300, 4.9500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101376, 'IJzendijke', 'IJzendijke', 'Iezendieke,Ysendyck', 51.3216700, 3.6166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101377, 'Ysselsteyn', 'Ysselsteyn', 'IJsselstein,Ysselsteyn', 51.4900000, 5.8972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101378, 'IJsselstein', 'IJsselstein', 'IJselstein,Issel''stejn,Иссельстейн', 52.0200000, 5.0430600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101379, 'IJlst', 'IJlst', 'Drylts,IJlst,ai er si te,艾爾斯特', 53.0100900, 5.6231200, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101380, 'Husken', 'Husken', '', 50.8956700, 5.9564800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101381, 'Hummelo', 'Hummelo', 'Hummelo en Keppel', 52.0041700, 6.2333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101382, 'Hulst', 'Hulst', '''Ulst,Khjulst,xu er si te,Хюлст,許爾斯特', 51.2800000, 4.0527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101383, 'Hulsberg', 'Hulsberg', '', 50.8891700, 5.8555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101384, 'Huizen', 'Huizen', 'Huizen', 52.2991700, 5.2416700, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101385, 'Huizum', 'Huizum', 'Huizum', 53.1917000, 5.8111900, 'NL', '2009-08-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101386, 'Huijbergen', 'Huijbergen', 'Huibergen,Huybergen', 51.4325000, 4.3763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101387, 'Houthem', 'Houthem', 'Houtem,Houthem-St. Gerlach', 50.8725000, 5.7930600, 'NL', '2009-09-30', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101388, 'Houten', 'Houten', 'Hauten,hao teng,hauten,hauteon,hawtn,hwtn,Հաուտեն,هاوتن,هوتن,ハウテン,豪滕,하우턴', 52.0283300, 5.1680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101389, 'Horssen', 'Horssen', 'Horsen', 51.8558300, 5.6097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101390, 'Hopel', 'Hopel', '', 50.8924500, 6.0504600, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101391, 'Hoorn', 'Hoorn', 'Gorn,Hoarn,Hoorn,Hoorn NH,Horn,Khorn,he en,holeun,horn,horun,hwrn,Горн,Хорн,Հորն,هورن,โฮร์น,ホールン,荷恩,호른', 52.6425000, 5.0597200, 'NL', '2013-06-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101392, 'Hoogwoud', 'Hoogwoud', '', 52.7158300, 4.9388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101393, 'Hoogmade', 'Hoogmade', 'Hoogmaden,Khogmade,Хогмаде', 52.1691700, 4.5819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101394, 'Hoogland', 'Hoogland', '', 52.1825000, 5.3736100, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101395, 'Hooge Zwaluwe', 'Hooge Zwaluwe', '', 51.6875000, 4.7444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101396, 'Hoogezand', 'Hoogezand', 'Hegesan,Hegesân,Khogezand,Хогезанд', 53.1616700, 6.7611100, 'NL', '2009-01-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101397, 'Hoogeveen', 'Hoogeveen', 'Hoogeveen,Khoogeveen,Хоогевеен', 52.7225000, 6.4763900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101398, 'Hoogerheide', 'Hoogerheide', '', 51.4241700, 4.3250000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101399, 'Hooge Mierde', 'Hooge Mierde', '', 51.3875000, 5.1291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101400, 'Hoogeloon', 'Hoogeloon', '', 51.3975000, 5.2680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101401, 'Hoogblokland', 'Hoogblokland', '', 51.8750000, 4.9763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101402, 'Hoofddorp', 'Hoofddorp', 'Haarlemmermeer,Hoofddorp,QHZ', 52.3025000, 4.6888900, 'NL', '2010-03-18', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101403, 'Honselersdijk', 'Honselersdijk', 'Hondshorledijk,Honselerdijk', 52.0066500, 4.2244100, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101404, 'Holz', 'Holz', '', 50.8641500, 6.0742400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101405, 'Holwerd', 'Holwerd', 'Holwerd,Holwert', 53.3681500, 5.9007300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101406, 'Holtum', 'Holtum', '', 51.0475000, 5.8222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101407, 'Hollum', 'Hollum', 'Hollum', 53.4394000, 5.6380500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101408, 'Hollandsche Rading', 'Hollandsche Rading', '', 52.1750000, 5.1777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101409, 'Hoge Mors', 'Hoge Mors', '', 52.1561600, 4.4602500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101410, 'Hoge Vucht', 'Hoge Vucht', '', 51.6079400, 4.7915000, 'NL', '2013-11-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101411, 'Hofgeest', 'Hofgeest', '', 52.4433300, 4.6583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101412, 'Hoeven', 'Hoeven', 'De Hoeven', 51.6720600, 5.6344400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101413, 'Hoeven', 'Hoeven', '', 51.5791700, 4.5833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101414, 'Hoensbroek', 'Hoensbroek', 'Gebrook,Hoensbrock,Khunsbruk,Хунсбрук', 50.9238700, 5.9252800, 'NL', '2009-10-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101415, 'Hoek van Holland', 'Hoek van Holland', 'Hoek van Holland,Hook of Holland,Khoek van Kholland,Khuk-van-Kholland,Oek van Olland,he lan jiao gang,Хоек ван Холланд,Хук-ван-Холланд,荷蘭角港', 51.9775000, 4.1333300, 'NL', '2008-12-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101416, 'Hippolytushoef', 'Hippolytushoef', 'Hypolitushoef', 52.9075000, 4.9625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101417, 'Hilversumse Meent', 'Hilversumse Meent', '', 52.2711500, 5.1372900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101418, 'Hilversum', 'Hilversum', 'Hilfertsom,Hilversum,Hilvertsheim,Khilversjum,Khilversum,QYI,hylfrswm,xi er fu se mu,Хилверсум,Хилверсюм,Հիլվերսում,هيلفرسوم,هیلفرسوم,希爾弗瑟姆', 52.2233300, 5.1763900, 'NL', '2008-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101419, 'Hilvarenbeek', 'Hilvarenbeek', '', 51.4858300, 5.1375000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101420, 'Hillegom', 'Hillegom', 'Hillegom', 52.2908300, 4.5833300, 'NL', '2017-05-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101421, 'Heythuysen', 'Heythuysen', 'Heijthuizen,Heithuizen,Heitse,Heythuizen,Heythuysen', 51.2500000, 5.8986100, 'NL', '2009-01-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101422, 'Heusdenhout', 'Heusdenhout', '', 51.5881100, 4.8193000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101423, 'Heusden', 'Heusden', 'Heusden,Housden,he si deng,hwsdn,Հեուսդեն,هوسدن,赫斯登', 51.7341700, 5.1388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101424, 'Heusden', 'Heusden', '', 51.3841700, 5.7638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101425, 'Heumen', 'Heumen', 'Heume,Heumen', 51.7650000, 5.8444400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101426, 'Heugem', 'Heugem', '', 50.8279100, 5.7077400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101427, 'Het Oostrik', 'Het Oostrik', '', 52.2500000, 6.2166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101428, 'Het Loo', 'Het Loo', '''t Loo,Het Loo,Loo,’t Loo', 52.2339000, 5.9527500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101429, 'Heteren', 'Heteren', '', 51.9566700, 5.7555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101430, 'Herwijnen', 'Herwijnen', '', 51.8266700, 5.1291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101431, 'Herten', 'Herten', '', 51.1808300, 5.9625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101432, 'Herpen', 'Herpen', '', 51.7716700, 5.6416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101433, 'Herkenbosch', 'Herkenbosch', '', 51.1533300, 6.0638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101434, 'Hensbroek', 'Hensbroek', '', 52.6583300, 4.8847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101435, 'Hengstdal', 'Hengstdal', 'Hengsdal,Hengstdaal', 51.8333300, 5.8833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101436, 'Hengevelde', 'Hengevelde', 'Hengeveld', 52.1991700, 6.6361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101437, 'Hengelo', 'Hengelo', 'Hemgelo,Hengelo,Hengeloo', 52.2658300, 6.7930600, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101438, 'Hengelo', 'Hengelo', 'Hengeloo', 52.0508300, 6.3097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101439, 'Hendrik-Ido-Ambacht', 'Hendrik-Ido-Ambacht', 'Hendrik-Ido-Ambaxt,Khendrik-Ido-Ambakht,heng de li ke-yi duo-a mu ba he te,hndryk- aydw- ambakht,Хендрик-Идо-Амбахт,Հենդրիկ-Իդո-Ամբախտ,هندريك- إيدو- أمباخت,亨德里克－伊多－阿姆巴赫特', 51.8441700, 4.6388900, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101440, 'Hem', 'Hem', '', 52.6608300, 5.1833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101441, 'Helvoirt', 'Helvoirt', 'Helvoort', 51.6316700, 5.2305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101442, 'Helpman', 'Helpman', '', 53.1979400, 6.5797800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101443, 'Helmond', 'Helmond', 'Gelmond,Hellemed,Helmond,Helmondas,Hèllemed,Khelmond,hai er meng de,he lmxnd,helmonteu,herumonto,hlmwnd,hylmwnd,Гелмонд,Хелмонд,Հելմոնդ,هلموند,هيلموند,เฮลมอนด์,ヘルモント,海爾蒙德,헬몬트', 51.4816700, 5.6611100, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101444, 'Hellevoetsluis', 'Hellevoetsluis', 'Helefutslaus,Hellevoet,Khelevutslojs,Khellevutsljojs,he lei fu ci lao si,hylyfwtslaws,Хелевутслојс,Хеллевутслёйс,Հելեֆուտսլաուս,هيليفوتسلاوس,赫勒富茨劳斯', 51.8333300, 4.1333300, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101445, 'Helden', 'Helden', '', 51.3191700, 6.0000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101446, 'Heksenberg', 'Heksenberg', 'Hessenberg', 50.9206800, 5.9737300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101447, 'Heino', 'Heino', 'Heino', 52.4366100, 6.2328200, 'NL', '2012-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101448, 'Heiloo', 'Heiloo', 'Heilo,Heiloo', 52.6025200, 4.6881500, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101449, 'Heiligerlee', 'Heiligerlee', '', 53.1566700, 7.0097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101450, 'Heijplaat', 'Heijplaat', 'De Heij,De Heiplaat,Hei,Heiplaat,Hey,Hyplaat,Tuindorp Heyplaat', 51.8933300, 4.4208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101451, 'Heijen', 'Heijen', 'Heien,MC Heijen', 51.6750000, 5.9805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101452, 'Heide', 'Heide', '', 51.0683300, 5.8722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101453, 'Hegelsom', 'Hegelsom', '', 51.4391700, 6.0388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101454, 'Heeze', 'Heeze', 'Heeze', 51.3828000, 5.5714500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101455, 'Heeswijk-Dinther', 'Heeswijk-Dinther', '', 51.6508300, 5.4750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101456, 'Heesterakker', 'Heesterakker', '', 51.4861000, 5.4968100, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101457, 'Heesch', 'Heesch', 'Khes,Хес', 51.7336200, 5.5267200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101458, 'Hees', 'Hees', '', 51.8413600, 5.8284600, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101459, 'Heerlen', 'Heerlen', 'Coriovalo,Heele,Heerlen,Heële,Kheerlen,Хеерлен', 50.8836500, 5.9815400, 'NL', '2008-12-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101460, 'Heerle', 'Heerle', '', 51.5191700, 4.3597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101461, 'Heerjansdam', 'Heerjansdam', '', 51.8358300, 4.5638900, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101462, 'Heerhugowaard', 'Heerhugowaard', 'Heerhugowaard,Heyrhuxovard,Kherkhjugovard,hai er xu huo wa de,Херхюговард,Հեյրհուխովարդ,海爾許霍瓦德', 52.6714400, 4.8486200, 'NL', '2009-12-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101463, 'Heerewaarden', 'Heerewaarden', 'Heriwarda', 51.8176900, 5.3930000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101464, 'Heerenveen', 'Heerenveen', 'Heerenveen,Hereveen,It Hearrenfean,Kherenven,QYZ,Херенвен', 52.9592900, 5.9185400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101465, 'Heerde', 'Heerde', '', 52.3872300, 6.0401600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101466, 'Heer', 'Heer', 'Hier,Meer', 50.8383600, 5.7298900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101467, 'Heemstede', 'Heemstede', 'Gemstede,Heemstede,Hemstede,Hemstedė,Heymsteyde,Hiemstee,Khemstede,hai mu si tai de,heimseutedeo,hemusutede,hymstydh,Гемстеде,Хемстеде,Հեյմստեյդե,هيمستيده,ヘームステーデ,海姆斯泰德,헤임스테더', 52.3499200, 4.6230100, 'NL', '2010-01-30', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101468, 'Heemskerk', 'Heemskerk', 'Heemskerk,Kheemskerk,Хеемскерк', 52.5110800, 4.6716500, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101469, 'Heelsum', 'Heelsum', '', 51.9841700, 5.7583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101470, 'Heel', 'Heel', '', 51.1791700, 5.8944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101471, 'Heeg', 'Heeg', '', 52.9686000, 5.6107500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101472, 'Heechterp', 'Heechterp', '', 53.2096300, 5.8225000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101473, 'Hedel', 'Hedel', '', 51.7480200, 5.2613400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101474, 'Havelte', 'Havelte', '', 52.7694100, 6.2401500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101475, 'Haulerwijk', 'Haulerwijk', 'Haulerwiek,Haulerwijk,Haulerwyk', 53.0646800, 6.3345300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101476, 'Hattemerbroek', 'Hattemerbroek', '', 52.4741700, 6.0222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101477, 'Hattem', 'Hattem', 'Hattem', 52.4750000, 6.0638900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101478, 'Hatert', 'Hatert', 'Hatert', 51.8063500, 5.8305700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101479, 'Hasselt', 'Hasselt', 'Asselt,Gorad Khasel''t,Khasselt,ha se er te,Горад Хасельт,Хасселт,哈瑟爾特', 52.5926700, 6.0952700, 'NL', '2009-01-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101480, 'Harskamp', 'Harskamp', 'Hartenkamp,Hartskamp', 52.1300000, 5.7527800, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101481, 'Harlingen', 'Harlingen', 'Garlingen,Harlingen,Harns,Kharlingen,ha ling gen,haleulling-eon,harlynjn,haruringen,Гарлінген,Харлинген,هارلينجن,ハルリンゲン,哈靈根,하를링언', 53.1747700, 5.4224400, 'NL', '2008-01-23', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101482, 'Harkstede', 'Harkstede', '', 53.2133300, 6.6986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101483, 'Harkema', 'Harkema', 'De Harkema,Harkema,Harkema-Opeinde', 53.1833300, 6.1333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101484, 'Harenkarspel', 'Harenkarspel', 'Harenkarspel,Kharenkarspel,Харенкарспел,Հարենկարսպել', 52.7341600, 4.7768200, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101485, 'Haren', 'Haren', 'Haren,Kharen,ha lun,haryn,Харен,Հարեն,هارين,哈伦', 53.1720900, 6.6093100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101486, 'Harderwijk', 'Harderwijk', '', 52.3416700, 5.6208300, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101487, 'Hardenberg', 'Hardenberg', 'Hardenberg,Khardenberge,Stad-Hardenberg,ha deng bei he,Харденберге,هاردن‌برخ,哈登貝赫', 52.5758300, 6.6194400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101488, 'Hurdegaryp', 'Hurdegaryp', 'Hardegarijp,Hurdegaryp', 53.2133300, 5.9413700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101489, 'Haps', 'Haps', 'Hops', 51.6891700, 5.8611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101490, 'Hapert', 'Hapert', '', 51.3683300, 5.2569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101491, 'Handel', 'Handel', '', 51.5800000, 5.7097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101492, 'Halsteren', 'Halsteren', '', 51.5283400, 4.2678500, 'NL', '2008-01-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101493, 'Hallum', 'Hallum', '', 53.3065700, 5.7837900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101494, 'Halfweg', 'Halfweg', 'Halfweg,Khalveg,Халвег', 52.5241700, 4.9277800, 'NL', '2013-08-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101495, 'Halfweg', 'Halfweg', '', 52.3825000, 4.7541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101496, 'Haelen', 'Haelen', 'Haelen,Hale,Halen', 51.2358300, 5.9569400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101497, 'Haastrecht', 'Haastrecht', 'ہاسٹریچٹ', 52.0007400, 4.7763900, 'NL', '2015-05-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101498, 'Haarsteeg', 'Haarsteeg', '', 51.7116700, 5.1986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101499, 'Haarlem', 'Haarlem', 'Chaarlem,Garlem,Gorad Kharlem,Haarlem,Haarlemo,Haarlim,Harlem,Harlema,Harlemas,Harlemum,Hārlema,Khaarlem,Kharlem,ha lei mu,haarlemi,haleulleom,harlm,haruremu,Χάαρλεμ,Гарлем,Горад Харлем,Хаарлем,Харлем,Հարլեմ,הארלם,هارلم,ہارلم,ܗܐܪܠܡ,ჰაარლემი,ハールレム,哈勒姆,하를럼', 52.3808400, 4.6368300, 'NL', '2008-01-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101500, 'Haarle', 'Haarle', '', 52.3591700, 6.3805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101501, 'Haaren', 'Haaren', 'Haaren,Haren,haren,harn,هارن,ہارین،شمالی برابنٹ,ハーレン', 51.6025000, 5.2222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101502, 'Haanrade', 'Haanrade', '', 50.8798100, 6.0741100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101503, 'Haamstede', 'Haamstede', 'Khamstede,Хамстеде', 51.6968200, 3.7429900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101504, 'Haalderen', 'Haalderen', '', 51.8875000, 5.9291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101505, 'Haaksbergen', 'Haaksbergen', 'Haaksbergen,Khaaksbergen,Хааксберген', 52.1566700, 6.7388900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101506, 'Haaften', 'Haaften', '', 51.8158300, 5.2111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101507, 'Guttecoven', 'Guttecoven', 'Guttekoven', 51.0150000, 5.8180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101508, 'Gulpen', 'Gulpen', 'Gulpe', 50.8158300, 5.8888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101509, 'Grou', 'Grou', 'Grou,Grouw', 53.0945600, 5.8374500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101510, 'Groot IJsselmonde', 'Groot IJsselmonde', 'Groot IJsselmonde,Westijselmonde,Westijsselmonde', 51.8826400, 4.5493700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101511, 'Grootegast', 'Grootegast', 'Grootegast', 53.2125000, 6.2736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101512, 'Groot-Ammers', 'Groot-Ammers', '', 51.9233300, 4.8236100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101513, 'Gronsveld', 'Gronsveld', '', 50.8108300, 5.7305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101514, 'Groningen', 'Groningen', 'Chronin''nken,GRQ,Gorad Groningen,Greunienge,Grins,Groninga,Groninge,Groningen,Groningena,Groningenas,Groningue,Grunneng,Gròninga,Qroningen,Vilojati Groningen,furoningen,furoningen shi,ge luo ning gen,groningeni,heuloning-eon,hrwnyngn,khrwnyngn,Χρόνινγκεν,Вилояти Гронинген,Горад Гронінген,Гронинген,Гронінген,חרונינגן,خرونینگن,گروننگن شہر,გრონინგენი,フローニンゲン,フローニンゲン市,格罗宁根,흐로닝언', 53.2191700, 6.5666700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101515, 'Groessen', 'Groessen', 'Groesen', 51.9316700, 6.0263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101516, 'Groesbeek', 'Groesbeek', 'Groesbeek', 51.7766700, 5.9361100, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101517, 'Groenewoud', 'Groenewoud', '', 51.5386000, 5.0902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101518, 'Groenekan', 'Groenekan', '', 52.1233300, 5.1527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101519, 'Grijpskerke', 'Grijpskerke', '', 51.5341700, 3.5611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101520, 'Grijpskerk', 'Grijpskerk', 'Gryptsjerk', 53.2625000, 6.3083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101521, 'Griffioen', 'Griffioen', '', 51.5054800, 3.5959800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101522, 'Grevenbicht', 'Grevenbicht', '', 51.0383300, 5.7750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101523, 'Grave', 'Grave', 'De Graaf,Grave,Xrave,he la fu,khrafh,Граве,Խրավե,خرافه,赫拉弗', 51.7590200, 5.7388200, 'NL', '2014-01-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101524, 'Grashoek', 'Grashoek', '', 51.3608300, 5.9430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101525, 'Grafhorst', 'Grafhorst', '', 52.5825000, 5.9333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101526, 'Gracht', 'Gracht', '', 50.8517500, 6.0279300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101527, 'Gouwsluis', 'Gouwsluis', 'Goudschesluis,Gouse Sluis,Gouwsche Sluis,Gouwsluis', 52.1194300, 4.6689900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101528, 'Goutum', 'Goutum', '', 53.1773400, 5.8037000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101529, 'Goudswaard', 'Goudswaard', 'Korendijk', 51.7941700, 4.2763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101530, 'Gouderak', 'Gouderak', '', 51.9841700, 4.6777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101531, 'Gouda', 'Gouda', 'Chaounta,Gauda,Gaudanum,Gorad Gauda,Gouda,Guda,Quda,ga''uda,gauda,goda,hao da,hauda,kea da,khawda,Χάουντα,Гауда,Горад Гауда,Գաուդա,خاودا,गउडा,గౌడ,เกาดา,გაუდა,ゴーダ,豪达,하우다', 52.0166700, 4.7083300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101532, 'Gorssel', 'Gorssel', 'Gorsel', 52.2016700, 6.2013900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101533, 'Gorredijk', 'Gorredijk', 'De Gordyk,Gordyk,Gorredijk', 53.0065900, 6.0640200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101534, 'Gorinchem', 'Gorinchem', 'Chorin''chem,Garkum,Gorcum,Goricum,Gorinkhem,Gorkum,Xorinxem,holinheom,horukumu,huo lin he mu,khwrykwm,Χόρινχεμ,Горинхем,Ґорінхем,Խորինխեմ,خوريكوم,ホルクム,霍林赫姆,호린험', 51.8365200, 4.9724300, 'NL', '2016-09-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101535, 'Goor', 'Goor', 'Goor,Гоор', 52.2333300, 6.5861100, 'NL', '2009-03-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101536, 'Goirle', 'Goirle', 'Goirl,Goirle,Goorle,Gorle,Xorle,khwrla,Гоирл,Горле,Խորլե,خورلا', 51.5208300, 5.0666700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101537, 'Goes', 'Goes', 'Chous,Goes,Gus,Gusas,hu si,khws,Χους,Гус,خوس,胡斯', 51.5041700, 3.8888900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101538, 'Goedereede', 'Goedereede', 'Goederee,Goeree,Goereê,Guderede,Xudereyde,hu de lei de,Гудереде,Խուդերեյդե,胡德雷德', 51.8175000, 3.9805600, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101539, 'Glimmen', 'Glimmen', '', 53.1391700, 6.6291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101540, 'Ginneken', 'Ginneken', '', 51.5659300, 4.7931000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101541, 'Gilze', 'Gilze', '', 51.5441700, 4.9402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101542, 'Giethoorn', 'Giethoorn', 'Giteren,Githorn,Gitkhorn,hythwrn,jythwrn,yang jiao cun,Гитхорн,Գիթհորն,חיטהורן,جيثورن,羊角村', 52.7400000, 6.0791700, 'NL', '2008-12-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101543, 'Gieten', 'Gieten', '', 53.0050000, 6.7638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101544, 'Giessendam', 'Giessendam', 'Giesdam,Giesendam', 51.8241700, 4.8152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101545, 'Giessenburg', 'Giessenburg', 'Giesen Nieuwkerk,Giessen Nieuwkerk', 51.8508300, 4.8902800, 'NL', '2009-03-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101546, 'Giessen', 'Giessen', 'Giesen', 51.7900000, 5.0305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101547, 'Giesbeek', 'Giesbeek', '', 51.9933300, 6.0666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101548, 'Gytsjerk', 'Gytsjerk', 'Giekerk,Gytsjerk', 53.2429300, 5.8950200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101549, 'Gerwen', 'Gerwen', '', 51.4900000, 5.5625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101550, 'Genoenhuis', 'Genoenhuis', '', 51.4091700, 5.5388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101551, 'Gennep', 'Gennep', 'Asnapium,Gennep,Gennep an der Maas', 51.6983300, 5.9736100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101552, 'Gendt', 'Gendt', 'Gent', 51.8775000, 5.9708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101553, 'Gendringen', 'Gendringen', 'Gendringen,Гендринген', 51.8733300, 6.3763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101554, 'Genderen', 'Genderen', '', 51.7358300, 5.0875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101555, 'Gemonde', 'Gemonde', '', 51.6183300, 5.3569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101556, 'Geleen', 'Geleen', 'Gelaen,Gelen,Gelenas,he lun,khe len,Гелен,เคเลน,赫倫', 50.9741700, 5.8291700, 'NL', '2016-07-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101557, 'Geldrop', 'Geldrop', 'Gel''drop,Гельдроп', 51.4216700, 5.5597200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101558, 'Geldermalsen-West', 'Geldermalsen-West', '', 51.8796800, 5.2801500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101559, 'Geldermalsen', 'Geldermalsen', 'Gel''dermalsen,Geldermalsen,Xeldermalsen,khyldrmalsn,Гелдермалсен,Гельдермалсен,Խելդերմալսեն,خيلدرمالسن', 51.8808300, 5.2888900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101560, 'Geitenkamp', 'Geitenkamp', '', 52.0037900, 5.9386200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101561, 'Geffen', 'Geffen', '', 51.7400000, 5.4638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101562, 'Geertruidenberg', 'Geertruidenberg', 'Geertruidenberg,Getrudenberg,Mont-Sainte-Gertrude,Xeyrtraudenberx,hai te lei yi deng bei he,khyrtrawdnbyrkh,Гетруденберг,Խեյրտրաուդենբերխ,خيرتراودنبيرخ,海特勒伊登貝赫', 51.7016700, 4.8569400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101563, 'Geenhoven', 'Geenhoven', '', 51.3593500, 5.4602100, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101564, 'Gasselternijveen', 'Gasselternijveen', 'Gasselternijeveen', 52.9883300, 6.8527800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101565, 'Gasselte', 'Gasselte', '', 52.9716700, 6.7944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101566, 'Garyp', 'Garyp', 'Garijp,Garyp', 53.1666700, 5.9666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101567, 'Garderen', 'Garderen', '', 52.2308300, 5.7138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101568, 'Gameren', 'Gameren', '', 51.8008300, 5.2041700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101569, 'Gageldonk', 'Gageldonk', '', 51.6016700, 4.7388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101570, 'Frankhuis', 'Frankhuis', '', 52.5250000, 6.0680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101571, 'Franeker', 'Franeker', 'Franeker,Frjentsjer,franykyr,fu la ne ke,Франекер,فرانيكير,弗拉訥克', 53.1854600, 5.5412300, 'NL', '2008-01-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101572, 'Flevowijk', 'Flevowijk', '', 52.5458300, 5.9133800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101573, 'Fijnaart', 'Fijnaart', '', 51.6375000, 4.4694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101574, 'Ferwert', 'Ferwert', 'Ferwerd', 53.3378400, 5.8253300, 'NL', '2009-08-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101575, 'Feijenoord', 'Feijenoord', 'Fijenoord', 51.9116900, 4.5064500, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101576, 'Farmsum', 'Farmsum', '', 53.3216700, 6.9263900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101577, 'Exloo', 'Exloo', 'Eksloo,Exlo', 52.8825000, 6.8638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101578, 'Etten', 'Etten', '', 51.9166700, 6.3361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101579, 'Essesteijn', 'Essesteijn', '', 52.0853400, 4.3726300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101580, 'Esch', 'Esch', '', 51.6108300, 5.2902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101581, 'Erp', 'Erp', '', 51.6000000, 5.6069400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101582, 'Ermelo', 'Ermelo', 'Ehrmelo,Ermelo,Эрмело', 52.2983300, 5.6222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101583, 'Epse', 'Epse', '', 52.2250000, 6.2000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101584, 'Epe', 'Epe', 'Ehpe,Эпе', 52.3475000, 5.9833300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101585, 'Enschot', 'Enschot', '', 51.5784600, 5.1388500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101586, 'Enschede', 'Enschede', 'ENS,Eanske,Ehnskhede,Enschede,Enschedė,Ensjedee,Enskede,Enskhede,Ensxeyde,Gorad Ehnskhedeh,Ynskedee,anskhdh,anskhydh,en si he de,enseuhedeo,enskhede,ensuhede,xen s kede,Горад Энсхедэ,Енсхеде,Энсхеде,Էնշխեյդե,אנסחדה,إنسخيده,انسخده,انشیدے,ܐܢܫܟܕܐ,เอนสเกเด,ენსხედე,エンスヘーデ,恩斯赫德,엔스헤더', 52.2183300, 6.8958300, 'NL', '2009-02-16', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101587, 'Ens', 'Ens', '', 52.6366700, 5.8277800, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101588, 'Enkhuizen', 'Enkhuizen', 'Enkhuizen,Enkhuze,Inkhuzen', 52.7033300, 5.2916700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101589, 'Emst', 'Emst', '', 52.3158300, 5.9736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101590, 'Emmerschans', 'Emmerschans', '', 52.8008300, 6.9388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101591, 'Emmermeer', 'Emmermeer', 'Emmermeer', 52.8007100, 6.8931500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101592, 'Emmerhout', 'Emmerhout', '', 52.7875500, 6.9388100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101593, 'Emmer-Erfscheidenveen', 'Emmer-Erfscheidenveen', 'Erfscheidenveen', 52.8066700, 6.9888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101594, 'Emmer-Compascuum', 'Emmer-Compascuum', '', 52.8116700, 7.0472200, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101595, 'Emmen', 'Emmen', 'Ehmmen,Emen,Emenas,Emme,Emmen,Emmeni vald,ai men,amn,aymyn,emen,emena,emeon,Емен,Еммен,Эммен,Էմմեն,אמן,إيمين,امن,एमेन,エメン,埃門,에먼', 52.7791700, 6.9069400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101596, 'Emmeloord', 'Emmeloord', 'Ehmmelord,Emmeloard,Emmelord,ai mo luo er de,Еммелорд,Эммелорд,埃默洛爾德', 52.7108300, 5.7486100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101597, 'Elst', 'Elst', '', 51.9191700, 5.8416700, 'NL', '2009-09-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101598, 'Elspeet', 'Elspeet', '', 52.2916700, 5.7888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101599, 'Elsloo', 'Elsloo', 'Aelse,Elslo', 50.9491700, 5.7708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101600, 'Elshout', 'Elshout', '', 51.7008300, 5.1416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101601, 'Ellecom', 'Ellecom', 'Ellekom', 52.0325000, 6.0875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101602, 'Elden', 'Elden', '', 51.9583300, 5.8819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101603, 'Elburg', 'Elburg', 'Ehlburg,Элбург', 52.4475000, 5.8430600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101604, 'Ekenrooi', 'Ekenrooi', 'Eekenrade,Ekenrooi', 51.3965600, 5.4862400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101605, 'Einighausen', 'Einighausen', 'Eimighausen', 51.0016700, 5.8277800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101606, 'Eindhoven', 'Eindhoven', 'Aintchofen,Ajndkhoven,Ajntoven,Ajntovën,EIN,Ehjndkhoven,Ehjndkhoven khot,Eindhove,Eindhoven,Eindhovena,Eindhovenas,Eindovia,Ejndgoven,Eyndhoven,Gorad Ehjndkhoven,a''indahovana,ai yin huo wen,aintohofen,ayndhwfn,ayndhwwn,eindhoveni,einteuhobeon,xind ho wen,yan hao fen,Αϊντχόφεν,Айндховен,Ајндховен,Горад Эйндховен,Ейндговен,Эйндховен,Эйндховен хот,Էյնդհովեն,איינדהובן,آئنڈھون,آيندهوفن,آیندهوون,اینتہوون,आइंडहोवन,ไอนด์โฮเวน,ეინდჰოვენი,アイントホーフェン,埃因霍温,燕豪芬,에인트호번', 51.4408300, 5.4777800, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101607, 'Eijsden', 'Eijsden', 'Eesjde,Eisden,Eysden,Èèsjde', 50.7800000, 5.7177000, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101608, 'Eibergen', 'Eibergen', '', 52.1000000, 6.6486100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101609, 'Egmond-Binnen', 'Egmond-Binnen', '', 52.5958300, 4.6555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101610, 'Egmond aan Zee', 'Egmond aan Zee', 'Ehgmond-an-Zee,Эгмонд-ан-Зее', 52.6204000, 4.6270500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101611, 'Egchel', 'Egchel', 'Echel', 51.3141700, 5.9722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101612, 'Eexta', 'Eexta', 'Eeksta', 53.1638600, 6.9834400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101613, 'Eext', 'Eext', 'Eekst', 53.0175000, 6.7347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101614, 'Eersel', 'Eersel', 'Eersel,Eyrsel,ayrsl,Էյրսել,إيرسل', 51.3575000, 5.3180600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101615, 'Eerschot', 'Eerschot', '', 51.5683300, 5.4736100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101616, 'Eerde', 'Eerde', '', 51.6041700, 5.4986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101617, 'Eerbeek', 'Eerbeek', 'Erbeke', 52.1050000, 6.0583300, 'NL', '2009-01-12', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101618, 'Eenrum', 'Eenrum', 'Enram,Ènram', 53.3625000, 6.4583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101619, 'Eelde', 'Eelde', 'Eelde,Paterswolde', 53.1358300, 6.5625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101620, 'Eefde', 'Eefde', '', 52.1666700, 6.2250000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101621, 'Ederveen', 'Ederveen', '', 52.0633300, 5.5777800, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101622, 'Ede', 'Ede', 'Ede,Ehde,ede,Эде,エーデ', 52.0333300, 5.6583300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101623, 'Edam', 'Edam', 'Edam,Ehdam,Gorad Ehdam,ai dan,edam,edamu,Горад Эдам,Едам,Эдам,エダム,埃丹,에담', 52.5121500, 5.0480500, 'NL', '2010-09-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101624, 'Eckart', 'Eckart', '', 51.4732000, 5.4944900, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101625, 'Echtenerbrug', 'Echtenerbrug', 'Echterbrug', 52.8714100, 5.8214700, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101626, 'Dwingeloo', 'Dwingeloo', 'Dvingelo,Dwingelo,dfynjylw,Двингело,دفينجيلو', 52.8341700, 6.3694400, 'NL', '2009-10-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101627, 'Duizel', 'Duizel', '', 51.3683300, 5.2972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101628, 'Duivendrecht', 'Duivendrecht', '', 52.3294100, 4.9396400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101629, 'Duiven', 'Duiven', 'Duiven', 51.9466700, 6.0138900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101630, 'Duinzigt', 'Duinzigt', '', 52.1048500, 4.3249400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101631, 'Duindorp', 'Duindorp', '', 52.0907800, 4.2603800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101632, 'Druten', 'Druten', 'Druten', 51.8883300, 5.6055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101633, 'Drumpt', 'Drumpt', 'Drumpt,Drumt', 51.8970000, 5.4104300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101634, 'Dronten', 'Dronten', 'Dronten,doronten,Дронтен,ドロンテン', 52.5250000, 5.7180600, 'NL', '2017-07-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101635, 'Dronryp', 'Dronryp', 'Dronrijp,Dronryp', 53.2000000, 5.6500000, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101636, 'Drogeham', 'Drogeham', 'Droegeham,Drogeham,Droogeham', 53.2021300, 6.1118300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101637, 'Driemond', 'Driemond', '', 52.3058300, 5.0166700, 'NL', '2009-01-15', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101638, 'Driemanspolder', 'Driemanspolder', 'Driemanspolder', 52.0517600, 4.4850400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101639, 'Driel', 'Driel', '', 51.9591700, 5.8138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101640, 'Driehuizen', 'Driehuizen', '', 52.2087900, 5.9444200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101641, 'Driebruggen', 'Driebruggen', '', 52.0441700, 4.8000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101642, 'Driebergen-Rijsenburg', 'Driebergen-Rijsenburg', '', 52.0533300, 5.2805600, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101643, 'Drachtstercompagnie', 'Drachtstercompagnie', 'De Compagnie,Drachster Compaghnie,Drachtster Kompenije,Drachtstercompagnie', 53.1346200, 6.1415300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101644, 'Drachten', 'Drachten', 'Drachten,Drakhten,QYC,de la he teng,drakhtn,Драхтен,دراختن,德拉赫滕', 53.1125400, 6.0989000, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101645, 'Dorst', 'Dorst', '', 51.5900000, 4.8569400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101646, 'Dordrecht', 'Dordrecht', 'Doardt,Dordracum,Dordrech,Dordrecht,Dordreque,Dordt,Dort,Ntorntrecht,dorutorehito,Ντόρντρεχτ,ドルトレヒト', 51.8100000, 4.6736100, 'NL', '2016-08-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101647, 'Doorwerth', 'Doorwerth', '', 51.9791700, 5.7972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101648, 'Doornsteeg', 'Doornsteeg', '', 52.2300000, 5.4541700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101649, 'Doornspijk', 'Doornspijk', 'Doornspyk', 52.4183300, 5.8180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101650, 'Doornenburg', 'Doornenburg', '', 51.8900000, 6.0000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101651, 'Doorn', 'Doorn', 'Doorn,Dorn,Доорн,Дорн', 52.0334300, 5.3457100, 'NL', '2008-01-15', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101652, 'Doonheide', 'Doonheide', '', 51.5666700, 5.6944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101653, 'Donkerbroek', 'Donkerbroek', 'Donkerbroek', 53.0173400, 6.2392700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101654, 'Donk', 'Donk', '', 51.5384300, 5.6291400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101655, 'Dongen', 'Dongen', 'Dongen,dwnjn,Донген,Դոնգեն,دونجن', 51.6266700, 4.9388900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101656, 'Dommelen', 'Dommelen', '', 51.3462400, 5.4339400, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101657, 'Domburg', 'Domburg', 'Dombourg,Domburgo', 51.5633300, 3.4958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101658, 'Dokkum', 'Dokkum', 'Dok''om,Dokkjum,Dokkum,duo ke mu,dwkwm,Доккюм,Докьом,دوكوم,多克姆', 53.3222400, 5.9969700, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101659, 'Doetinchem', 'Doetinchem', 'Doetinchem,Dutinkhem,Дутинхем', 51.9650000, 6.2888900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101660, 'Doesburg', 'Doesburg', '', 52.0666700, 5.6166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101661, 'Doesburg', 'Doesburg', '', 52.0125000, 6.1388900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101662, 'Doenrade', 'Doenrade', 'Groot Doenrade', 50.9675000, 5.9069400, 'NL', '2012-06-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101663, 'Dirksland', 'Dirksland', 'Dirksland,di er ke si lan,Дирксланд,Դիրկսլանդ,迪尔克斯兰', 51.7491700, 4.1000000, 'NL', '2013-06-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101664, 'Dirkshorn', 'Dirkshorn', 'Dirckshorn', 52.7500000, 4.7750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101665, 'Dinteloord', 'Dinteloord', '', 51.6350000, 4.3694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101666, 'Diever', 'Diever', '', 52.8541700, 6.3180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101667, 'Diessen', 'Diessen', 'Diesen', 51.4758300, 5.1750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101668, 'Dieren', 'Dieren', 'di lun,迪倫', 52.0525000, 6.1000000, 'NL', '2009-09-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101669, 'Diepenheim', 'Diepenheim', '', 52.2000000, 6.5555600, 'NL', '2009-03-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101670, 'Diemen', 'Diemen', 'Diemen,Diemerbrug,Dijmen,Dimen,dymyn,Диймен,Димен,Դիմեն,ديمين', 52.3396400, 4.9625600, 'NL', '2010-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101671, 'De Wijk', 'De Wijk', 'De Wyk,Wijk', 52.6733300, 6.2902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101672, 'De Wijert', 'De Wijert', '', 53.1945000, 6.5711700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101673, 'Deventer', 'Deventer', 'Daventria,Deventer,Deventeris,Deyventer,Dimter,Gemeen Deventer,Gemeen Dèventer,QYV,dai fen te er,de wen texr,debenteoleu,defenteru,dfntr,Девентер,Դեյվենտեր,دفنتر,เดเวนเตอร์,デーフェンテル,代芬特尔,데벤터르', 52.2550000, 6.1638900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101674, 'Deuteren', 'Deuteren', 'Groot-Deuteren', 51.6866700, 5.2666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101675, 'De Uithof', 'De Uithof', 'De Uithof,Uithof', 52.0852600, 5.1745600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101676, 'De Rompert', 'De Rompert', '', 51.7166700, 5.3166700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101677, 'De Rijp', 'De Rijp', 'Rijp', 52.5566700, 4.8458300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101678, 'De Reit', 'De Reit', '', 51.5603800, 5.0493200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101679, 'De Peulen', 'De Peulen', '', 51.8236200, 4.8216500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101680, 'De Noord', 'De Noord', '', 52.7075000, 4.8513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101681, 'Den Oever', 'Den Oever', 'De Oever,Den-Uver,Oever,Ден-Увер', 52.9335300, 5.0307900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101682, 'Den Helder', 'Den Helder', 'DHR,De Helder,Den Helder,Den-Khelder,Der Helder,Helder,Le Helder,Nten Chelnter,deng hai er de,dn hldr,Ντεν Χέλντερ,Ден-Хелдер,Դեն Հելդեր,دن هلدر,デン・ヘルダー,登海尔德', 52.9598800, 4.7593300, 'NL', '2014-07-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101683, 'Den Ham', 'Den Ham', 'Ham', 52.4658300, 6.4958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101684, 'Den Dungen', 'Den Dungen', 'Dungen', 51.6650000, 5.3722200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101685, 'Den Burg', 'Den Burg', 'Burg,De Burg', 53.0541700, 4.7972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101686, 'De Mheen', 'De Mheen', 'De Melm', 52.2195400, 5.9914100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101687, 'De Maer', 'De Maer', '', 52.5190100, 4.6817100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101688, 'De Loo', 'De Loo', 'De Loo,Loo', 52.6716700, 6.7396700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101689, 'De Lier', 'De Lier', 'Lier', 51.9750000, 4.2486100, 'NL', '2009-01-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101690, 'Delfzijl', 'Delfzijl', 'Delfzejl,Delfzijl,Delfzyl,Делфзейл', 53.3300000, 6.9180600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101691, 'Delft', 'Delft', 'Delft,Ntelpht,dai er fu te,derufuto shi,dlpt,Ντελφτ,Делфт,דלפט,デルフト市,代尔夫特', 52.0066700, 4.3555600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101692, 'Delfshaven', 'Delfshaven', '', 51.9048800, 4.4531500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101693, 'Delden', 'Delden', '', 52.2600000, 6.7111100, 'NL', '2009-03-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101694, 'De Kruiskamp', 'De Kruiskamp', '', 51.6997800, 5.2603200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101695, 'De Koog', 'De Koog', 'Koog', 53.0975000, 4.7611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101696, 'De Kieviet', 'De Kieviet', 'De Kieviet,De Kievit,Kievit', 52.1233300, 4.3583900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101697, 'Deil', 'Deil', '', 51.8841700, 5.2430600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101698, 'De Hoven', 'De Hoven', '', 52.2490100, 6.1436700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101699, 'De Heeg', 'De Heeg', '', 50.8245400, 5.7230900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101700, 'De Hagen', 'De Hagen', '', 51.9938100, 5.1026300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101701, 'De Greiden', 'De Greiden', '', 52.9496000, 5.9136600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101702, 'De Goorn', 'De Goorn', 'Goorn', 52.6258300, 4.9472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101703, 'De Glip', 'De Glip', 'Glip', 52.3308300, 4.6111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101704, 'Deest', 'Deest', '', 51.8900000, 5.6666700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101705, 'De Drait', 'De Drait', '', 53.0974300, 6.0679100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101706, 'De Doornakkers', 'De Doornakkers', 'Doornakkers', 51.4384400, 5.5088700, 'NL', '2009-01-11', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101707, 'De Domp', 'De Domp', '', 53.0311300, 5.6771600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101708, 'De Blaak', 'De Blaak', '', 51.5462600, 5.0446500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101709, 'De Bilt', 'De Bilt', 'De Bilt,Nte Bilt,dy bylt,Ντε Μπιλτ,Դե Բիլտ,دي بيلت', 52.1100000, 5.1805600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101710, 'Dauwendaele', 'Dauwendaele', 'Dauwendaele', 51.4929900, 3.6262400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101711, 'Damwâld', 'Damwald', 'Damwald,Damwoude,Damwâld,Moarrewald,Moarrewâld,Murmerwoude', 53.2904600, 5.9978500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101712, 'Dalfsen', 'Dalfsen', 'Dal''fsen,Dalfsen,Дальфсен', 52.5116700, 6.2569400, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101713, 'Dalen', 'Dalen', '', 52.6991700, 6.7555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101714, 'Culemborg', 'Culemborg', 'Culemborg,Culembourg,Kuilenburg,Kulemborg,Kulemborx,kwlmbwrkh,qu lun bo he,Кулемборг,Կուլեմբորխ,كولمبورخ,屈伦博赫', 51.9550000, 5.2277800, 'NL', '2017-01-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101715, 'Cuijk', 'Cuijk', 'Ceuclum,Cuijk,Cuyk,Kauk,Kuic,Kuk,Kuuk,Kuyc,Kuyk,kawk,Կաուկ,كاوك', 51.7308300, 5.8791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101716, 'Cranendonck', 'Cranendonck', 'Cranendonck,Kranedonk', 51.3041700, 5.5888900, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101717, 'Cothen', 'Cothen', 'Koten', 51.9966700, 5.3083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101718, 'Commandeurs', 'Commandeurs', '', 52.5090200, 4.6584300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101719, 'Colijnsplaat', 'Colijnsplaat', 'Colijnsplaat', 51.5991700, 3.8486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101720, 'Coevorden', 'Coevorden', 'Coevorden,Koevorden,Kuvorden,ku fu er deng,Куворден,Կուվորդեն,庫福爾登', 52.6610300, 6.7404600, 'NL', '2009-12-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101721, 'Coevering', 'Coevering', '', 51.4174200, 5.5746300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101722, 'Coendersborg', 'Coendersborg', '', 53.1941000, 6.5894400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101723, 'Chaam', 'Chaam', '', 51.5058300, 4.8611100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101724, 'Castricum', 'Castricum', 'Castricum,Kastrikjum,Kastrikum,ka si te li ke mu,kastrkwm,kasutorikumu,Кастрикюм,Կաստրիկում,كاستركوم,カストリクム,卡斯特里克姆', 52.5483300, 4.6694400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101725, 'Carnisse', 'Carnisse', 'Carnisse,Carnisselande,Garnisse,Karnisse', 51.8893200, 4.4775800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101726, 'Capelle-West', 'Capelle-West', '', 51.9166700, 4.5666700, 'NL', '2012-09-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101727, 'Capelle aan den IJssel', 'Capelle aan den IJssel', 'Capelle,Capelle a/d IJssel,Capelle a/d Yssel,Capelle aan de IJssel,Capelle aan de Yssel,Capelle aan den IJssel,Capelle aan den Ijssel,Capelle aan den Yssel,Kapele an den Eysel,Kapelle,Kapelle-an-den-Ehjssel,ai se er he pan ka pei lei,ka pe lex xan dex xi seil,kabyla an dn aysl,kapelleoanden-eiseol,Капелле-ан-ден-Эйссел,Կապելե ան դեն Էյսել,كابيلا آن دن آيسل,کاپله ان‌دن ایسل,กาเปเลออานเดอไอเซิล,艾瑟尔河畔卡佩勒,카펠러안덴에이설', 51.9291700, 4.5777800, 'NL', '2012-11-27', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101728, 'Callantsoog', 'Callantsoog', 'Kallensoog', 52.8400000, 4.6958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101729, 'Bussum', 'Bussum', 'Bjussjum,Bussum,Busum,bu sen,bwswm,Бюссюм,Բուսում,بوسوم,布森', 52.2733300, 5.1611100, 'NL', '2016-07-31', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101730, 'Bunschoten', 'Bunschoten', 'Bunschoten-Spakenburg,Bunskoat,Bunsxoten,bwnskhwtn,Բունշխոտեն,بونسخوتن', 52.2430400, 5.3788400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101731, 'Bunnik', 'Bunnik', '', 52.0666700, 5.1986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101732, 'Bunde', 'Bunde', '', 50.8966700, 5.7319400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101733, 'Buitenpost', 'Buitenpost', 'Buitenpost,Butenpost,Bûtenpost', 53.2516600, 6.1448300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101734, 'Budschop', 'Budschop', '', 51.2851100, 5.7589800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101735, 'Budel-Schoot', 'Budel-Schoot', 'Groot Schoot,Groote Schoot', 51.2475000, 5.5652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101736, 'Budel-Dorplein', 'Budel-Dorplein', 'Dorplein,Dorpplein', 51.2366700, 5.5875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101737, 'Budel', 'Budel', 'Budel,Buul', 51.2716700, 5.5750000, 'NL', '2017-04-05', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101738, 'Buchten', 'Buchten', '', 51.0433300, 5.8097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101739, 'Brunssum', 'Brunssum', 'Brjunssume,Broensem,Brunssum,Brunsum,Брюнссуме', 50.9466700, 5.9708300, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101740, 'Brunnepe', 'Brunnepe', '', 52.5618500, 5.9034300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101741, 'Brummen', 'Brummen', 'Brummen,Бруммен', 52.0900000, 6.1555600, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101742, 'Brukske', 'Brukske', '', 51.5210100, 5.9927000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101743, 'Bruinisse', 'Bruinisse', '', 51.6616700, 4.0944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101744, 'Bruchem', 'Bruchem', '', 51.7866700, 5.2361100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101745, 'Brouwershaven', 'Brouwershaven', '', 51.7266700, 3.9125000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101746, 'Broeksterwâld', 'Broeksterwald', 'Broek,Broeksterwald,Broeksterwoude,Broeksterwâld,De Broek', 53.2746600, 5.9964800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101747, 'Broeksittard', 'Broeksittard', '', 51.0029000, 5.8951100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101748, 'Broek op Langedijk', 'Broek op Langedijk', 'Broek op Langendijk', 52.6741700, 4.8055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101749, 'Broek in Waterland', 'Broek in Waterland', 'Broek', 52.4341700, 4.9958300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101750, 'Broekhoven', 'Broekhoven', '', 51.5480100, 5.0917500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101751, 'Broekhem', 'Broekhem', 'Brokem', 50.8711900, 5.8206900, 'NL', '2009-09-30', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101752, 'Brinkhorst', 'Brinkhorst', '', 52.2130200, 5.9516700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101753, 'Brielle', 'Brielle', 'Brile,Brille,Den Briel,Gorad Bryle,brylh,bu li lei,Брилле,Брілле,Горад Брыле,Բրիլե,بريله,布里勒', 51.9016700, 4.1625000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101754, 'Breukelen', 'Breukelen', 'beuloekeolleon,ბროიკელენი,브뢰컬런', 52.1741700, 5.0013900, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101755, 'Breugel', 'Breugel', '', 51.5175000, 5.5111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101756, 'Breskens', 'Breskens', 'Bresjes,Breskens,Брескенс', 51.3958300, 3.5555600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101757, 'Breezand', 'Breezand', '', 52.8900000, 4.8041700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101758, 'Bredeweg', 'Bredeweg', 'Breedeweg', 51.7601900, 5.9418900, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101759, 'Bredevoort', 'Bredevoort', 'Bradford,Bredevort,Breevoort,Brādford,bu lei de fu te,Бредеворт,布雷德福特', 51.9416700, 6.6208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101760, 'Breda', 'Breda', 'Breda,Breda khot,Brenta,Brigita,Bréda,GLZ,Gorad Brehda,be rda,beuleda,brda,brdh,breda,bryda,bu lei da,bureda,Μπρέντα,Бреда,Бреда хот,Горад Брэда,Բրեդա,ברדה,بردا,بريدا,بریڈا,เบรดา,ბრედა,ブレダ,布雷达,브레다', 51.5865600, 4.7759600, 'NL', '2011-09-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101761, 'Brand', 'Brand', '', 51.4583900, 5.6242700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101762, 'Brakkenstein', 'Brakkenstein', 'Brakkenstein,Brakkestein', 51.8132400, 5.8653900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101763, 'Brakel', 'Brakel', '', 51.8175000, 5.0902800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101764, 'Brachterbeek', 'Brachterbeek', 'Brachterbaek', 51.1469400, 5.9044600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101765, 'Brabander', 'Brabander', 'De Brabander', 51.5358300, 5.9680600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101766, 'Boxtel', 'Boxtel', 'Bokstel,Boxtel,bwkstl,Бокстел,Բոքստել,بوكستل', 51.5908300, 5.3291700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101767, 'Boxmeer', 'Boxmeer', 'Boc''s Mere,Boksmaer,Boksmeer,Boxmeer,Meer,Mere', 51.6466700, 5.9472200, 'NL', '2014-08-15', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101768, 'Boven-Hardinxveld', 'Boven-Hardinxveld', 'Boven Hardingsveld,Hardingsveld,Hardinxveld', 51.8233300, 4.8819400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101769, 'Bosschenhoofd', 'Bosschenhoofd', '', 51.5608300, 4.5402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101770, 'Boskoop', 'Boskoop', 'Boskop,bo si ke pu,Боскоп,Բոսկոպ,博斯科普', 52.0750000, 4.6555600, 'NL', '2015-05-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101771, 'Boskamp', 'Boskamp', '', 52.3308300, 6.1277800, 'NL', '2008-12-21', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101772, 'Bosch en Duin', 'Bosch en Duin', '', 52.1166700, 5.2416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101773, 'Borssele', 'Borssele', 'Borsele,Borssel'',Borsselen,Bossele,Борссель', 51.4233300, 3.7347200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101774, 'Borne', 'Borne', 'Boorn,Borne,bwrnh,Борне,Բորնե,بورنه', 52.3013600, 6.7482000, 'NL', '2013-06-04', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101775, 'Born', 'Born', 'Bor', 51.0316700, 5.8097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101776, 'Borgharen', 'Borgharen', 'Bowgraven', 50.8775000, 5.6875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101777, 'Borger', 'Borger', 'Borger,bwrkhr,Боргер,بورخر', 52.9233300, 6.7930600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101778, 'Borgele', 'Borgele', '', 52.2763000, 6.1492600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101779, 'Borculo', 'Borculo', 'Berkelland,Borkulo', 52.1158300, 6.5222200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101780, 'Boornbergum', 'Boornbergum', 'Boarnburgum,Boornbergum', 53.0828400, 6.0457800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101781, 'Bolsward', 'Bolsward', 'Boalsert,Bolsvard,Bolsward,Gemeen Bolsward,bo er si wa de,bolseubaleuteu,borusuvu~aruto,Болсвард,ボルスヴァルト,博尔斯瓦德,볼스바르트', 53.0655500, 5.5317600, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101782, 'Bolnes', 'Bolnes', '', 51.8950000, 4.5791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101783, 'Boekel', 'Boekel', '', 51.6033300, 5.6750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101784, 'Bodegraven', 'Bodegraven', '', 52.0825000, 4.7500000, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101785, 'Bocholtz', 'Bocholtz', 'Boches,Bocholz,Bóches', 50.8183300, 6.0055600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101786, 'Blokzijl', 'Blokzijl', '', 52.7266700, 5.9611100, 'NL', '2008-12-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101787, 'Bloemhof', 'Bloemhof', 'Bloemhof', 51.8972300, 4.4994300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101788, 'Bloemendaal', 'Bloemendaal', 'Bloemendaal,Bloemendaalseweg', 52.0287800, 4.6944000, 'NL', '2012-01-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101789, 'Bloemendaal', 'Bloemendaal', 'Bloemendaal', 52.4025000, 4.6222200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101790, 'Blitterswijck', 'Blitterswijck', 'Blitterswijk', 51.5308300, 6.1083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101791, 'Blijham', 'Blijham', '', 53.1091700, 7.0763900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101792, 'Bleiswijk', 'Bleiswijk', '', 52.0108300, 4.5319400, 'NL', '2016-02-16', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101793, 'Bleijerheide', 'Bleijerheide', '', 50.8553800, 6.0678900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101794, 'Blaricum', 'Blaricum', 'Blaricum,Blarikjum,Blarikum,blarykwm,bu la li ke mu,Бларикюм,Բլարիկում,بلاريكوم,布拉里克姆', 52.2725000, 5.2416700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101795, 'Bladel', 'Bladel', 'Bladel,bladl,Բլադել,بلادل', 51.3683300, 5.2208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101796, 'Blaarthem', 'Blaarthem', 'Blaartem,Blaarthem', 51.4250100, 5.4578400, 'NL', '2017-04-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101797, 'Bitswijk', 'Bitswijk', '', 51.6687000, 5.6092100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101798, 'Burdaard', 'Burdaard', 'Birdaard,Burdaard', 53.2942100, 5.8789700, 'NL', '2008-10-23', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101799, 'Binnenhof', 'Binnenhof', '', 52.1641800, 4.5364400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101800, 'Bilgaard', 'Bilgaard', 'Bilgaard,Bilgaerd', 53.2155100, 5.7957400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101801, 'Bijvanck', 'Bijvanck', 'Bijvanck,De Bijvang', 52.2858500, 5.2653400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101802, 'Biesland', 'Biesland', 'Biesland', 50.8411000, 5.6757300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101803, 'Biesdonk', 'Biesdonk', '', 51.6061300, 4.7851500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101804, 'Biddinghuizen', 'Biddinghuizen', 'Biddinghuizen', 52.4550000, 5.6930600, 'NL', '2009-03-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101805, 'Beverwijk', 'Beverwijk', 'Berverwyk,Bevervejk,Beverwijk,Beverwyk,Beyverveyk,byfyrfayk,Бевервейк,Բեյվերվեյկ,بيفيرفايك', 52.4833300, 4.6569400, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101806, 'Beusichem', 'Beusichem', '', 51.9500000, 5.2916700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101807, 'Beuningen', 'Beuningen', '', 51.8608300, 5.7666700, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101808, 'Best', 'Best', 'Best', 51.5075000, 5.3902800, 'NL', '2013-03-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101809, 'Besoijen', 'Besoijen', 'Besooien,Besoyen,Bezooien', 51.6833300, 5.0500000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101810, 'Berltsum', 'Berltsum', 'Berlikum,Berltsum', 53.2437000, 5.6510100, 'NL', '2012-04-14', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101811, 'Berlicum', 'Berlicum', 'Berlikum', 51.6775000, 5.4000000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101812, 'Berkum', 'Berkum', '', 52.5239500, 6.1365500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101813, 'Berkhout', 'Berkhout', '', 52.6408300, 5.0013900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101814, 'Berkenwoude', 'Berkenwoude', '', 51.9450000, 4.7069400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101815, 'Beringe', 'Beringe', 'Beringen', 51.3366700, 5.9486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101816, 'Burgum', 'Burgum', 'Bergum,Burgum', 53.1924300, 5.9900900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101817, 'Bergstoep', 'Bergstoep', '', 51.9225000, 4.7847200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101818, 'Bergschenhoek', 'Bergschenhoek', 'Bergsenkhuk,Бергсенхук', 51.9900000, 4.4986100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101819, 'Berghem', 'Berghem', 'Berchem', 51.7699100, 5.5682700, 'NL', '2007-11-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101820, 'Bergharen', 'Bergharen', '', 51.8508300, 5.6694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101821, 'Bergeijk', 'Bergeyk', 'Bergeijk,Bergeik', 51.3191700, 5.3583300, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101822, 'Bergen op Zoom', 'Bergen op Zoom', 'Bergen op Zoom,Bergen-op-Zom,WOE,Берген-оп-Зом', 51.4950000, 4.2916700, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101823, 'Berg en Dal', 'Berg en Dal', '', 51.8216700, 5.9166700, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101824, 'Berg en Bos', 'Berg en Bos', '', 52.2200900, 5.9334000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101825, 'Berg', 'Berg', 'Berg aan de Maas', 51.0041700, 5.7708300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101826, 'Berg', 'Berg', '', 50.8616700, 5.7833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101827, 'Benthuizen', 'Benthuizen', '', 52.0775000, 4.5444400, 'NL', '2015-05-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101828, 'Bennekom', 'Bennekom', 'Bennekom,Беннеком', 51.9983300, 5.6763900, 'NL', '2009-01-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101829, 'Bennebroek', 'Bennebroek', 'Bennebroek', 52.3208300, 4.5986100, 'NL', '2008-01-25', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101830, 'Bemmel', 'Bemmel', 'Bemel,Бемел', 51.8916700, 5.8986100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101831, 'Beltrum', 'Beltrum', '', 52.0666700, 6.5638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101832, 'Bellingwolde', 'Bellingwolde', '', 53.1158300, 7.1652800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101833, 'Belfort', 'Belfort', '', 50.8469800, 5.6599100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101834, 'Belcrum', 'Belcrum', '', 51.5991100, 4.7699400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101835, 'Beilen', 'Beilen', '', 52.8633300, 6.5138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101836, 'Beetsterzwaag', 'Beetsterzwaag', 'Beetstersweach,Beetsterzwaag', 53.0591400, 6.0771100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101837, 'Beesel', 'Beesel', 'Besel', 51.2683300, 6.0388900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101838, 'Beesd', 'Beesd', 'Beest', 51.8875000, 5.1916700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101839, 'Beersdal', 'Beersdal', '', 50.9059700, 5.9644000, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101840, 'Beers', 'Beers', 'Beers,Bèèrs', 51.7258300, 5.8277800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101841, 'Beekbergen', 'Beekbergen', '', 52.1600000, 5.9638900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101842, 'Beek', 'Beek', '', 51.9066700, 6.1875000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101843, 'Beek', 'Beek', '', 51.5289000, 5.6338200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101844, 'Beek', 'Beek', 'Baek,Beek', 50.9408300, 5.7972200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101845, 'Beegden', 'Beegden', '', 51.1891700, 5.9194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101846, 'Bedum', 'Bedum', 'Bedum', 53.3008300, 6.6027800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101847, 'Bavel', 'Bavel', '', 51.5658300, 4.8305600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101848, 'Barneveld', 'Barneveld', 'Barneveld,Барневелд', 52.1400000, 5.5847200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101849, 'Barger-Oosterveld', 'Barger-Oosterveld', '', 52.7700000, 6.9583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101850, 'Bargeres', 'Bargeres', 'Barger,Bargeres', 52.7615200, 6.8814500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101851, 'Barendrecht', 'Barendrecht', 'Barendrekht,Barendrext,ba lun de lei he te,baryndrykht,Барендрехт,Բարենդրեխտ,بارن‌درخت,باريندريخت,巴伦德雷赫特', 51.8566700, 4.5347200, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101852, 'Banholt', 'Banholt', '', 50.7900000, 5.8083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101853, 'Bangert', 'Bangert', 'Bangerd,Bangert,De Bangert', 52.7358200, 5.1801000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101854, 'Ballast', 'Ballast', '', 52.6721800, 6.7329900, 'NL', '2017-04-07', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101855, 'Balk', 'Balk', '', 52.8975600, 5.5796400, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101856, 'Bakkeveen', 'Bakkeveen', 'Bakkefean,Bakkeveen', 53.0807200, 6.2567100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101857, 'Bakhuizen', 'Bakhuizen', '', 52.8697500, 5.4592600, 'NL', '2017-04-13', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101858, 'Bakenberg', 'Bakenberg', '', 52.0051100, 5.8771000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101859, 'Bakel', 'Bakel', '', 51.5033300, 5.7402800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101860, 'Baflo', 'Baflo', '', 53.3625000, 6.5138900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101861, 'Babberich', 'Babberich', '', 51.9075000, 6.1111100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101862, 'Baarn', 'Baarn', 'Baan,Baarn,Barn,baleun,barn,barun,Баан,Барн,Բարն,بارن,バールン,바른', 52.2116700, 5.2875000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101863, 'Baarlo', 'Baarlo', 'Baarloo,Baolder', 51.3308300, 6.0944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101864, 'Baarle-Nassau', 'Baarle-Nassau', 'Baarle-Nassau,バールレ・ナッサウ', 51.4475000, 4.9291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101865, 'Baardwijk', 'Baardwijk', '', 51.6924600, 5.0962800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101866, 'Baambrugge', 'Baambrugge', '', 52.2458300, 4.9888900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101867, 'Baalder', 'Baalder', '', 52.5857900, 6.6529900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101868, 'Axel', 'Axel', 'Aksel', 51.2666700, 3.9083300, 'NL', '2008-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101869, 'Avenhorn', 'Avenhorn', '', 52.6175000, 4.9513900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101870, 'Austerlitz', 'Austerlitz', '', 52.0800000, 5.3152800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101871, 'Augustinusga', 'Augustinusga', 'Augustinusga,Stynsgea', 53.2178500, 6.1617000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101872, 'Asten', 'Asten', 'Aste,Asten', 51.4041700, 5.7486100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101873, 'Assen', 'Assen', 'Asen,Asenas,Asningseli,Asningsėli,Asse,Assen,Gorad Asen,a sen,aseon,asn,assen,xas sein,Άσσεν,Асен,Ассен,Горад Асен,Ասսեն,آسن,أسن,อาสเซิน,アッセン,阿森,아선', 52.9966700, 6.5625000, 'NL', '2011-11-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101874, 'Arnhem', 'Arnhem', 'Arecanum,Arnem,Arnema,Arnheim,Arnhem,Arnhemas,Arnhemia,Arnhim,Arném,Gemeen Arnem,Gorad Arnem,ZYM,a na mu,aleunheom,anemu,arnahema,arnemi,arnhm,arnm,Άρνεμ,Арнем,Горад Арнем,Արնհեմ,ארנהם,آرنم,آرنهم,آرنہم,आर्नहेम,არნემი,アーネム,阿纳姆,아른험', 51.9800000, 5.9111100, 'NL', '2011-06-15', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101875, 'Arnemuiden', 'Arnemuiden', 'Erremu,a ne mo yi deng,阿訥默伊登', 51.5016700, 3.6750000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101876, 'Arkel', 'Arkel', '', 51.8641700, 4.9944400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101877, 'Arcen', 'Arcen', 'Arse,Arsen,Árse', 51.4766700, 6.1805600, 'NL', '2010-09-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101878, 'Appingedam', 'Appingedam', '', 53.3216700, 6.8583300, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101879, 'Appelscha', 'Appelscha', 'Appelscha,Appelsche,Appelsga,Appelskea,Nieuw Appelsga', 52.9552600, 6.3505300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101880, 'Apeldoorn', 'Apeldoorn', 'Apeldoarn,Apeldoorn,Apeldoorne,Apeldorn,Apeldornas,Gorad Apeldorn,QYP,a po er duo lun,abldwrn,apeldoleun,aperudorun,apldwrn,epeladorna,xa phel dorn,Апелдорн,Горад Апелдорн,Ապելդորն,آبلدورن,آپلدورن,ایپلڈوم,एपेलडॉर्न,อาเพลโดร์น,აპელდორნი,アペルドールン,阿珀尔多伦,아펠도른', 52.2100000, 5.9694400, 'NL', '2014-03-31', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101881, 'Annen', 'Annen', '', 53.0575000, 6.7194400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101882, 'Anklaar', 'Anklaar', '', 52.2311100, 5.9849700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101883, 'Ankeveense Rade', 'Ankeveense Rade', '', 52.2589100, 5.1016000, 'NL', '2017-04-08', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101884, 'Angerlo', 'Angerlo', '', 51.9958300, 6.1347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101885, 'Angeren', 'Angeren', '', 51.9158300, 5.9583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101886, 'Angelslo', 'Angelslo', 'Angelslo,Angelsloo', 52.7809000, 6.9264500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101887, 'Andelst', 'Andelst', '', 51.9083300, 5.7291700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101888, 'Amsterdam', 'Amsterdam', 'AMS,Amesterdam,Amesterdao,Amesterdão,Amistardam,Amstardam,Amstedam,Amstelodamum,Amsterdam,Amsterdama,Amsterdamas,Amsterdami,Amsterdamo,Amsterdams,Amsterdan,Amsterntam,Amstèdam,Amszterdam,Damsko,Gorad Amstehrdam,I-Amsterdami,Mokum,a mu si te dan,aimstardaima,amasataradama,amastaradama,amastararyama,amseuteleudam,amstardama,amstartam,amstrdam,amusuterudamu,anstardyam,emstaradyama,xamstexrdam,yەmstەrdam,Àmsterdam,Ámsterdam,Ámsterdan,Άμστερνταμ,Амстердам,Горад Амстэрдам,Ամստերդամ,אמסטערדאם,אמסטרדם,آمستردام,أمستردام,ئامستېردام,ئەمستەردام,امستردام,امسټرډام,ایمسٹرڈیم,ܐܡܣܛܪܕܐܡ,अ‍ॅम्स्टरडॅम,आम्स्टर्डम,एम्स्तरद्याम,ऐम्स्टर्डैम,আমস্টারডাম,ਅਮਸਤਰਦਮ,ଆମଷ୍ଟରଡ଼୍ୟାମ,ஆம்ஸ்டர்டம்,ಆಂಸ್ಟರ್ಡ್ಯಾಮ್,ആംസ്റ്റർഡാം,ඈම්ස්ටර්ඩෑම්,อัมสเตอร์ดัม,ཨེམ་སི་ཊར་ཌམ།,အမ်စတာဒမ်မြို့,ამსტერდამი,አምስተርዳም,アムステルダム,阿姆斯特丹,암스테르담', 52.3740300, 4.8896900, 'NL', '2016-09-10', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101889, 'Amstenrade', 'Amstenrade', '', 50.9391700, 5.9236100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101890, 'Amstelveen', 'Amstelveen', 'Amstelveen,Amstelven,Amstelveyn,Amstelvin,Nieuwer Amstel,a mu si te er fen,amseutelbein,amusuterufen,Амстелвен,Амстелвин,Ամստելվեյն,אמסטלפיין,آمستل‌فین,アムステルフェーン,阿姆斯特尔芬,암스텔베인', 52.3008300, 4.8638900, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101891, 'Ammerzoden', 'Ammerzoden', '', 51.7491700, 5.2208300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101892, 'Ammerstol', 'Ammerstol', '', 51.9275000, 4.8083300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101893, 'Amersfoort', 'Amersfoort', 'Amersfoort,Amersfort,Amersforto,QYM,Амерсфорт', 52.1550000, 5.3875000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101894, 'Amerongen', 'Amerongen', 'Ameron''chen,amrangn,Αμερόνχεν,امرانگن', 52.0025000, 5.4597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101895, 'America', 'America', 'Amerika', 51.4366700, 5.9791700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101896, 'Amby', 'Amby', 'Ambij,Amie,amby,امبی', 50.8621500, 5.7322900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101897, 'Alverna', 'Alverna', '', 51.8041700, 5.7597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101898, 'Alphen aan den Rijn', 'Alphen aan den Rijn', 'Alfen,Alphen,Alphen a/d Rijn,Alphen aan de Rijn,Alphen aan den Rijn,Alphen aan der Rijn', 52.1291700, 4.6554600, 'NL', '2012-04-28', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101899, 'Alphen', 'Alphen', 'Alfen,alfn  shmal brabant,الفن، شمال برابانت', 51.4816700, 4.9583300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101900, 'Almkerk', 'Almkerk', 'almkrk,المکرک', 51.7708300, 4.9597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101901, 'Almere Stad', 'Almere Stad', 'Almere', 52.3702500, 5.2141300, 'NL', '2016-02-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101902, 'Almelo', 'Almelo', 'Almelo,Almeloo,QYL,Алмело', 52.3566700, 6.6625000, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101903, 'Alkmaar', 'Alkmaar', 'Alkmaar,Alkmaer,Alkmar,Alkmaras,a er ke ma er,alkeumaleu,alkmar,arukumaru,Άλκμααρ,Алкмаар,Алкмар,Ալկմար,אלקמאר,آلکمار,ألكمار,ئەڵکمار,アルクマール,阿尔克马尔,알크마르', 52.6316700, 4.7486100, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101904, 'Alblasserdam', 'Alblasserdam', 'Alblaserdam,Alblasserdam,Alhlasserdam,a er bu la se dan,alblasrdam,Алблассердам,Ալբլասերդամ,ألبلاسردام,البلاسردام,阿尔布拉瑟丹', 51.8658300, 4.6611100, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101905, 'Akkrum', 'Akkrum', 'Akkrum,Ankrum,akram,اکرام', 53.0502400, 5.8308700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101906, 'Akert', 'Akert', '', 51.4140700, 5.5596000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101907, 'Afferden', 'Afferden', '', 51.8800000, 5.6347200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101908, 'Aduard', 'Aduard', 'Adeward,Adewardervoorwerk,Kloster Aduard', 53.2566700, 6.4597200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101909, 'Adegeest', 'Adegeest', '', 52.1362100, 4.4524900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101910, 'Abdissenbosch', 'Abdissenbosch', '', 50.9166700, 6.0333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101911, 'Abcoven', 'Abcoven', '', 51.5275000, 5.0833300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101912, 'Abcoude', 'Abcoude', 'Abcoude,Abkoude,a bu kao de,abkad,abkawdh,أبكاوده,ابکاد,阿布考德', 52.2725000, 4.9694400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101913, 'Abbekerk', 'Abbekerk', '', 52.7316700, 5.0180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101914, 'Aardenburg', 'Aardenburg', 'Aarntenmpournk,Erreburg,ardnbrg,Άαρντενμπουργκ,آردنبرگ,آرڈنبرگ', 51.2733300, 3.4472200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101915, 'Aalten', 'Aalten', 'Aalten', 51.9250000, 6.5805600, 'NL', '2007-06-03', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101916, 'Aalst', 'Aalst', '', 51.3966700, 5.4777800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101917, 'Aalst', 'Aalst', '', 51.7825000, 5.1277800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101918, 'Aalsmeer', 'Aalsmeer', 'Aalsmeer,Alsmer,QFA,a er si mei er,Алсмер,阿尔斯梅尔', 52.2591700, 4.7597200, 'NL', '2010-01-29', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101919, 'Aalden', 'Aalden', '', 52.7900000, 6.7180600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101920, 'Aalburg', 'Aalburg', 'Aalburg,Albjurg,Alburx,Wijk en Aalburg,albrg,albwrkh,Албюрг,Ալբուրխ,آلبرگ,آلبورخ', 51.7548200, 5.1315600, 'NL', '2008-01-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101921, 'Aagtekerke', 'Aagtekerke', '', 51.5466700, 3.5097200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101922, 'Klundert', 'Klundert', '', 51.6629700, 4.5346100, 'NL', '2008-01-26', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101923, 'Camminghaburen', 'Camminghaburen', '', 53.2097300, 5.8431800, 'NL', '2008-01-20', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101924, 'Amsterdam-Zuidoost', 'Amsterdam-Zuidoost', '', 52.3075000, 4.9722200, 'NL', '2009-01-15', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101925, 'Zuid-Berghuizen', 'Zuid-Berghuizen', '', 52.3008300, 6.9333300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101926, 'Chevremont', 'Chevremont', '', 50.8755400, 6.0598100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101927, 'Welgelegen', 'Welgelegen', '', 52.2139700, 5.9764300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101928, 'Matenveld', 'Matenveld', '', 52.1876700, 5.9987900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101929, 'Matenhoeve', 'Matenhoeve', '', 52.1905600, 6.0133800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101930, 'Matendonk', 'Matendonk', '', 52.1976600, 6.0111500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101931, 'Matenhorst', 'Matenhorst', '', 52.2048200, 5.9930400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101932, 'Matendreef', 'Matendreef', '', 52.1999300, 5.9859200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101933, 'Matengaarde', 'Matengaarde', '', 52.1979300, 5.9957000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101934, 'Rivierenkwartier', 'Rivierenkwartier', '', 52.1891400, 5.9766500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101935, 'Staatsliedenkwartier', 'Staatsliedenkwartier', '', 52.1995100, 5.9769100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101936, 'Brummelhof', 'Brummelhof', '', 52.2050300, 5.9678900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101937, 'Vogelkwartier', 'Vogelkwartier', '', 52.1977700, 5.9672100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101938, 'Componistenkwartier', 'Componistenkwartier', '', 52.1897700, 5.9660900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101939, 'Woudhuis', 'Woudhuis', '', 52.2132300, 6.0112400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101940, 'Sluisoord', 'Sluisoord', '', 52.2229100, 5.9814500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101941, 'Sprenkelaar', 'Sprenkelaar', '', 52.2251200, 5.9992200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101942, 'De Haven', 'De Haven', '', 52.2104500, 5.9740700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101943, 'Binnenstad', 'Binnenstad', '', 52.2130400, 5.9595700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101944, 'Sprengenweg-Noord', 'Sprengenweg-Noord', '', 52.2183900, 5.9506800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101945, 'Sprengenbos', 'Sprengenbos', '', 52.2190200, 5.9416300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101946, 'Spainkbos', 'Spainkbos', '', 52.2222800, 5.9473800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101947, 'De Heeze', 'De Heeze', '', 52.2006100, 5.9536500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101948, 'Westenenk', 'Westenenk', '', 52.1962400, 5.9565600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101949, 'Winkewijert', 'Winkewijert', '', 52.1908200, 5.9579400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101950, 'De Bouwhof', 'De Bouwhof', '', 52.1854600, 5.9470400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101951, 'Speelheide', 'Speelheide', '', 51.5060700, 5.4051900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101952, 'Salderes', 'Salderes', '', 51.5150500, 5.3899100, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101953, 'Jubbega', 'Jubbega', 'Jobbegea', 53.0039600, 6.1218300, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101954, 'Meerhoven', 'Meerhoven', '', 51.4426700, 5.4110200, 'NL', '2010-05-02', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101955, 'Grasrijk', 'Grasrijk', '', 51.4391600, 5.4154400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101956, 'Hoek', 'Hoek', 'Hoek', 53.2045500, 5.8019200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101957, 'De Knipe', 'De Knipe', 'De Knijpe,De Knipe', 52.9682900, 5.9711600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101958, 'Lunetten', 'Lunetten', '', 52.0617800, 5.1347400, 'NL', '2008-12-27', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101959, 'Aarle-Rixtel', 'Aarle-Rixtel', 'arl-rykstl,آرل-ریکستل,آرلے ریکسٹل', 51.5097600, 5.6383900, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101960, 'Kelpen-Oler', 'Kelpen-Oler', '', 51.2181700, 5.8260200, 'NL', '2009-01-09', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101961, 'Muschberg en Geestenberg', 'Muschberg en Geestenberg', '', 51.4438400, 5.5232900, 'NL', '2009-01-11', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101962, 'Villapark', 'Villapark', '', 51.4414400, 5.4938500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101963, 'Lakerlopen', 'Lakerlopen', '', 51.4379100, 5.5010600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101964, 'Berkel en Rodenrijs', 'Berkel en Rodenrijs', '', 51.9931300, 4.4786500, 'NL', '2016-02-17', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101965, 'Reitdiep', 'Reitdiep', '', 53.2425200, 6.5195700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101966, 'Ypenburg', 'Ypenburg', '', 52.0409800, 4.3698100, 'NL', '2009-09-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101967, 'Aldlân-Oost', 'Aldlan-Oost', '', 53.1886000, 5.8282500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101968, 'Oranjewijk', 'Oranjewijk', '', 52.0492200, 4.6537400, 'NL', '2009-09-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101969, 'Vondelwijk', 'Vondelwijk', '', 52.0549700, 4.6531400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101970, 'Groenswaard', 'Groenswaard', '', 52.0515400, 4.6454100, 'NL', '2009-09-06', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101971, 'Randenbroek', 'Randenbroek', '', 52.1486300, 5.4012000, 'NL', '2009-09-22', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101972, 'Corlaer', 'Corlaer', '', 52.2163900, 5.4653500, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101973, 'Kapelle', 'Kapelle', '', 51.4862700, 3.9580400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101974, 'Hoogkamp', 'Hoogkamp', '', 51.9963000, 5.8802600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101975, 'Gulden Bodem', 'Gulden Bodem', '', 51.9942800, 5.8908000, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101976, 'Sterrenberg', 'Sterrenberg', '', 51.9935000, 5.8838700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101977, 'Burgemeesterswijk', 'Burgemeesterswijk', '', 51.9894300, 5.8959700, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101978, 'Kop van Zuid', 'Kop van Zuid', '', 51.9055300, 4.4870600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101979, '''s-Gravenland', '''s-Gravenland', '', 51.9233600, 4.5531500, 'NL', '2012-09-01', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101980, 'Spechtenkamp', 'Spechtenkamp', '', 52.1392600, 5.0175800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101981, 'Besterd', 'Besterd', '', 51.5638000, 5.0865800, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101982, 'Wisselaar', 'Wisselaar', '', 51.6128600, 4.7844400, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101983, 'Waterdonken', 'Waterdonken', '', 51.6095900, 4.8045200, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101984, 'Hunnerberg', 'Hunnerberg', '', 51.8420900, 5.8787600, 'NL', '2017-03-24', 157);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101985, 'Vardø', 'Vardo', 'VAW,Vard''o,Varde,Vardo,Vardø,Vardő,Varggat,Vuorea,Vuoreija,Várggát,Варде,Вардьо', 70.3704800, 31.1106600, 'NO', '2015-09-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101986, 'Vuonnabahta', 'Vuonnabahta', 'Varangerboti,Varangerbotn,Vuodnabatta,Vuonnabahta,Варангерботи', 70.1727800, 28.5559800, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101987, 'Vadsø', 'Vadso', 'Cahcesuolu,VDS,Vadse,Vadso,Vadso kommun,Vadsø,Vadsø kommun,Vesisaari,Čáhcesuolu,Вадсе', 70.0734800, 29.7494300, 'NO', '2014-01-06', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101988, 'Storslett', 'Storslett', 'Hansinkenttae,Hansinkenttä,Storslet,Storslett', 69.7678300, 21.0246600, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101989, 'Skjervøy', 'Skjervoy', 'Skjarvoy,Skjarvöy,Skjervo,Skjervoy,Skjervö,Skjervøy,Skjoervo,Skjoervø', 70.0311400, 20.9714100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101990, 'Olderdalen', 'Olderdalen', 'Dalvesvaggi,Dálvesvággi,Olderdal,Olderdalen,Talosvankka', 69.6040700, 20.5327200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101991, 'Øksfjord', 'Oksfjord', 'Aksovuotna,Aksuvuodna,Akšuvuodna,Oksfjord,Ákšovuotna,Øksfjord', 70.2393600, 22.3507000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101992, 'Mehamn', 'Mehamn', 'MEH,Mehamn,Mehavn,Mekhamn,Мехамн', 71.0413700, 27.8513300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101993, 'Lyngseidet', 'Lyngseidet', 'Lyngseidet,Lyngsejdet', 69.5762900, 20.2188700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101994, 'Lakselv', 'Lakselv', 'Gorad Laksehl''v,LKL,Lakeselv,Laksehl''v,Lakselv,Leavdnja,Lemmijoki,la ke sai er fu,laksylw,Горад Лаксэльв,Лакселв,Лаксэльв,لاکسیلو,拉克塞爾夫', 70.0513300, 24.9718200, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101995, 'Kvalsund', 'Kvalsund', 'Falesnuorri,Fálesnuorri,Kommun Kvalsund,Kvalsund,Kvalsundi vald,Kvalsunds kommun,Kvalsunn,Rahkkeravju,Rakkeravjo,Ráhkkerávju,kabhalasunda,ke wa er song,Квалсунн,কভালসুন্ড,克瓦爾松', 70.5027100, 23.9797400, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101996, 'Kjøllefjord', 'Kjollefjord', '', 70.9457400, 27.3465000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101997, 'Kirkenes', 'Kirkenes', 'Circenes,Girkonjarga,Girkonjárga,KKN,Khirkenes,Kirkenes,Kirkenesas,Kirkkoniemi,kirukenesu,kyrkns,sileukeneseu,xi er ke nei si,Κίρκενες,Ћирћенес,Киркенес,Кіркенес,Хиркенес,کیرکنس,キルケネス,希尔克内斯,시르케네스', 69.7270600, 30.0457800, 'NO', '2014-07-21', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101998, 'Kautokeino', 'Kautokeino', 'Guov''dagaei''dno,Guov''dagæi''dno,Guovdagaeidno,Guovdagaeino,Guovdageaidnu,Guovdageaidnu Kautokeino,Guovdageaidnu vald,Guovdageainnu suohkan,Guovdageajdnu,Guovdagæidno,Guovdagæino,Kautokeini,Kautokeino,Kautokeino kommun,Kautokeino kommuna,Kjoutukejnu,Kommun Kautokeino,Koutokeino,QKX,gu''obhadage''idanu kautake''ino,kai yu tu kai nu,kautokeino,Гуовдагеайдну,Кёутукейну,গুওভডাগেইডনু কৌটকেইনো,カウトケイノ,凱于圖凱努', 69.0124700, 23.0411600, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(101999, 'Kárášjohka', 'Karasjohka', 'Karasjohka,Karasjok,Kárášjohka,QKK,Карасйок', 69.4718700, 25.5112200, 'NO', '2014-05-28', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102000, 'Honningsvåg', 'Honningsvag', 'HVG,Honingsvogas,Honnesvahki,Honnesváhki,Honningsvaag,Honningsvag,Honningsvåg,Hönningsvaag,Khoningsvog,Khonningsvog,Sondre Honningsvaag,Sondre Honningsvag,Söndre Honningsvaag,Söndre Honningsvåg,hnyngswag,hong ning si wo ge,honingusuvu~ogu,Хонингсвог,Хоннингсвог,هنینگسواگ,ホニングスヴォーグ,洪寧斯沃格', 70.9820900, 25.9703700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102001, 'Ávanuorri', 'Avanuorri', 'Avanuorri,Havosund,Havoysund,Havøsund,Havøysund,Khavesunn,Ávanuorri,Хавесунн', 70.9963400, 24.6621700, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102002, 'Hammerfest', 'Hammerfest', 'HFT,Hammarfeasta,Hammerfest,Hammerfest koezseg,Hammerfest község,Hammerfesti vald,Hámmárfeasta,Khamerfest,Khammerfest,Kommun Hammerfest,ham''meraphista,hamrfst,hanmerufesuto,heng mo fei si,hmrpst,Хамерфест,Хаммерфест,המרפסט,هامرفست,হাম্মেরফিস্ট,ハンメルフェスト,亨墨菲斯', 70.6633600, 23.6820900, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102003, 'Burfjord', 'Burfjord', 'Burfjord', 69.9380400, 22.0520500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102004, 'Bjørnevatn', 'Bjornevatn', 'Bjornevand,Bjornevatn,Bjornvandet,Björnevand,Björnvandet,Bjørnevatn,Kruuvakylae,Kruuvakylä', 69.6674500, 29.9872200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102005, 'Berlevåg', 'Berlevag', 'BVG,Bearalvahki,Bearalváhki,Berlevaag,Berlevag,Berlevog,Berlevåg,Берлевог', 70.8577800, 29.0863600, 'NO', '2015-12-20', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102006, 'Båtsfjord', 'Batsfjord', 'BJF,Bahcavuotna,Batsfjord,Batsfjordi vald,Batsfjords kommun,Botsf''ord,Báhcavuotna,Båtsfjord,Båtsfjordi vald,Båtsfjords kommun,Kommun Batsfjord,Kommun Båtsfjord,batasphajorda,bo ci fei you er,botsufiyoru,Ботсфьорд,বটস্ফজোর্ড,ボツフィヨール,博茨菲尤爾', 70.6342800, 29.7175000, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102007, 'Alta', 'Alta', 'ALF,Alattio,Alta,Alta vald,Kommun Alta,a er ta,alta,aruta,Áltá,Алта,ألتا,التا,アルタ,阿尔塔,알타', 69.9688700, 23.2716500, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102008, 'Rypefjord', 'Rypefjord', 'Rypefjord', 70.6412600, 23.6721300, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102009, 'Strai', 'Strai', 'Strai,Ytre Strai', 58.1893000, 7.9282600, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102010, 'Skålevik', 'Skalevik', 'Skaalevig,Ytre Skalevik,Ytre Skålevik', 58.0795500, 8.0160200, 'NO', '2013-07-08', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102011, 'Ytre Arna', 'Ytre Arna', 'Ytre Arna', 60.4617500, 5.4326500, 'NO', '2013-03-17', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102012, 'Voss', 'Voss', 'Kommun Voss,Reino de Voss,Vos,Voss,Voss kommun,Vossavangen,Vossevangen,Vossi vald,bhosa,boseu,vu~osu,wo si,Вос,Восс,ভোস,ヴォス,沃斯,보스', 60.6286900, 6.4147400, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102013, 'Volda', 'Volda', 'Hallkjellsvik,Hallkjelsvik,Kommun Volda,Volda,Volda kommun,Volden,bholada,wo er da,Волда,ভোলডা,沃爾達', 62.1460000, 6.0710800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102014, 'Vinstra', 'Vinstra', 'Vinstra,XKZ', 61.5949600, 9.7513400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102015, 'Vikøyri', 'Vikoyri', 'Vikora,Vikoyri,Vikøra,Vikøyri', 61.0870700, 6.5791400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102016, 'Vikeså', 'Vikesa', 'Vigesa,Vigesaa,Vigeså,Vikesa,Vikeså', 58.6375900, 6.0913300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102017, 'Vikersund', 'Vikersund', 'Vikersund,Vikesund,vu~ikerusun,Викерсунд,ヴィケルスン', 59.9683800, 9.9910700, 'NO', '2016-05-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102018, 'Vik', 'Vik', 'Vik,Vik i Helgeland', 65.3125400, 12.1673400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102019, 'Vigrestad', 'Vigrestad', 'Vigrestad', 58.5710300, 5.6818200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102020, 'Vigeland', 'Vigeland', '', 58.0843700, 7.3049700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102021, 'Vevelstad', 'Vevelstad', '', 65.6978000, 12.4370600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102022, 'Vestbygd', 'Vestbygd', 'Vestbygd,Vestbygda,Vestbygden', 58.0999100, 6.5869600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102023, 'Vestby', 'Vestby', 'Kommun Vestby,Vestbju,Vestby,Vestby kommun,bestaba''i,wei si te bi,Вестбю,বেস্টবাই,韋斯特比', 59.6051100, 10.7523300, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102024, 'Verdal', 'Verdal', 'Vaerdalsoren,Verdalsora,Verdalsoren,Verdalsoyra,Verdalsören,Verdalsöyra,Verdalsøra,Værdalsören,XXG', 63.7933200, 11.4817000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102025, 'Vennesla', 'Vennesla', 'Vennesla,Vennesla kommun,XXE', 58.2685600, 7.9731400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102026, 'Vatne', 'Vatne', 'Vatne', 62.5582600, 6.6170800, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102027, 'Varhaug', 'Varhaug', 'Varhaug', 58.6181000, 5.6570200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102028, 'Vanse', 'Vanse', 'Lista,Vanse', 58.0981200, 6.6918400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102029, 'Vangsvika', 'Vangsvika', 'Vangsvik,Vangsvika', 69.1705700, 17.7341600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102030, 'Valle', 'Valle', '', 59.2125900, 7.5355900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102031, 'Valldal', 'Valldal', 'Valdal,Valldal', 62.2978200, 7.2637400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102032, 'Våler', 'Valer', 'Vaaler,Valbyen,Valer,Valer i Solor,Vålbyen,Våler,Våler i Solør', 60.6712200, 11.8347700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102033, 'Vågåmo', 'Vagamo', 'Vagamo,Vågåmo', 61.8750500, 9.0967100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102034, 'Utsira', 'Utsira', 'Utsira,Utsira kommun,Utsire', 59.3057000, 4.8862000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102035, 'Ulvik', 'Ulvik', 'Ulvik,Ulvik i Hardanger', 60.5679100, 6.9164500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102036, 'Ulsteinvik', 'Ulsteinvik', 'Ul''stejnvik,Ulstajnvik,Ulsteinvik,Ulsteinvikas,Ulstejnvik,yu er si tai yin wei ke,Улстайнвик,Улстејнвик,Ульстейнвик,于爾斯泰因維克', 62.3431700, 5.8486900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102037, 'Ulefoss', 'Ulefoss', 'Ulefoss', 59.2824500, 9.2654800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102038, 'Uggdal', 'Uggdal', '', 60.0040200, 5.5287600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102039, 'Tysvær', 'Tysvaer', 'Kommun Tysvaer,Kommun Tysvær,Tjusver,Tysvaer,Tysvaers kommun,Tysvær,Tysværs kommun,di si wei er,ta''isabayera,Тюсвер,টাইসবায়ের,蒂斯韋爾', 59.3320400, 5.4898100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102040, 'Tysse', 'Tysse', '', 60.3740400, 5.7595200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102041, 'Tynset', 'Tynset', 'Kommun Tynset,Tjunset,Tonset,Tynset,Tynsets kommun,Tönset,ZMX,ta''inaseta,ting se,Тюнсет,টাইনসেট,廷瑟', 62.2759400, 10.7824100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102042, 'Tveit', 'Tveit', 'Tveid,Tveit i Kristiansand', 58.2336600, 8.1219900, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102043, 'Tvedestrand', 'Tvedestrand', 'Kommun Tvedestrand,Tvedestran,Tvedestrand,Tvedestrandi vald,Tvedestrands kommun,Tvedestrann,tabhedestranda,te wei de si te lan,Тведестран,Тведестранн,টভেডেস্ট্রান্ড,特韋德斯特蘭', 58.6220300, 8.9314700, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102044, 'Innbygda', 'Innbygda', 'Trysil', 61.3148400, 12.2637400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102045, 'Trondheim', 'Trondheim', 'Gorad Tronkhejm,Kommun Trondheim,Nidaros,Nidrosia,THrandheimur,TRD,Troandin,Trondheim,Trondheimas,Trondhjem,Trondkhajm,Trondkhejm,Trongejm,Tronheima,Tronkhejm,Trontchaim,Truondheims,Truondhėims,te long he mu,teulonheim,thrx nd hem,toronhaimu,toronheimu,tronad''ehima,troneim,trwndhaym,trwndhyym,Þrándheimur,Τροντχαιμ,Τρόντχαιμ,Τρόντχαϊμ,Горад Тронхейм,Тронгейм,Трондхайм,Трондхејм,Тронхейм,טרונדהיים,تروندهايم,تروندهایم,ٹرونڈہائم,ট্রোনডেহিম,ทรอนด์เฮม,ტრონჰეიმი,トロンハイム,トロンヘイム,特隆赫姆,트론헤임', 63.4304900, 10.3950600, 'NO', '2014-05-11', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102046, 'Tromsø', 'Tromso', 'Gorad Tromsjo,Kommun Tromso,Kommun Tromsø,Romsa,TOS,Troms''o,Tromse,Tromsieg,Tromsjo,Tromso,Tromsoe,Tromsoe kommun,Tromsonda,Tromssa,Tromsö,Tromsö kommun,Tromsø,Tromsīeg,Trumse,Trumsė,te luo mu se,teulomsoe,thrm sex,toromuso,tromasa,tromso,trwmsa,trwmsh,trwmsw,Горад Тромсё,Тромсе,Тромсьо,Тромсё,טרומסה,ترومسا,ترومسو,ٹرومسو,ट्रोम्सो,ট্রোমসা,ทรมเซอ,ტრომსე,トロムソ,特罗姆瑟,트롬쇠', 69.6489000, 18.9550800, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102047, 'Trofors', 'Trofors', 'Trofors', 65.5333500, 13.4063100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102048, 'Treungen', 'Treungen', '', 59.0206400, 8.5202000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102049, 'Tretten', 'Tretten', 'Tretten', 61.3142300, 10.3006600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102050, 'Tranby', 'Tranby', 'Tranby', 59.8085000, 10.2611400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102051, 'Tonstad', 'Tonstad', 'Sirdal,Siredalen,Tonstad,Tonstead', 58.6626300, 6.7169400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102052, 'Tønsberg', 'Tonsberg', 'Gorad Cjonsberg,Kommun Tonsberg,Kommun Tønsberg,T''onsberg,Tensberg,Tionsbergas,Tjonsberg,Toensberg,Tonsberg,Tönsberg,Tønsberg,tanasabarga,teng si bei ge,toenseubeleugeu,tonsuberugu,twnsbyrgh,Горад Цёнсберг,Тенсберг,Тьонсберг,Тёнсберг,تونسبيرغ,ٹانسبرگ,টানসবার্গ,トンスベルグ,滕斯贝格,퇸스베르그', 59.2675400, 10.4076200, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102053, 'Tomter', 'Tomter', 'Tomter', 59.6591000, 10.9948700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102054, 'Tomra', 'Tomra', 'Tomra,Tomra i Romsdal,Tomren', 62.5811800, 6.9310600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102055, 'Tolga', 'Tolga', 'Tolga,Tolgen', 62.4089800, 10.9988300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102056, 'Tofte', 'Tofte', 'Tofte,Tofte i Hurum', 59.5427500, 10.5613800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102057, 'Tjøme', 'Tjome', 'Tjome,Tjome kommun,Tjøme,Tjøme kommun', 59.1109000, 10.3933000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102058, 'Tjeldstø', 'Tjeldsto', '', 60.5962300, 4.8444900, 'NO', '2014-05-29', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102059, 'Tingvatn', 'Tingvatn', 'Tingpatn,Tingvatn,Tingvatne', 58.3757000, 7.2197000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102060, 'Terråk', 'Terrak', 'Terraak,Terrak,Terråk', 65.0870000, 12.3714800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102061, 'Tau', 'Tau', 'Tau', 59.0648100, 5.9225000, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102062, 'Tangvall', 'Tangvall', 'Tangvall,Tufteland', 58.0978100, 7.8152900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102063, 'Tananger', 'Tananger', 'Tananger', 58.9361800, 5.5741000, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102064, 'Syfteland', 'Syfteland', '', 60.2380300, 5.4528500, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102065, 'Svolvær', 'Svolvaer', 'SVJ,Svol''ver,Svolvaer,Svolver,Svolvær,si wo er wei er,Сволвер,Свольвер,斯沃尔韦尔', 68.2341700, 14.5683400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102066, 'Svelvik', 'Svelvik', 'Svelvik,Svelvik kommun,Свелвик', 59.6137000, 10.4087200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102067, 'Svelgen', 'Svelgen', '', 61.7697600, 5.2954400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102068, 'Sveio', 'Sveio', 'Sveio,Sveio kommun', 59.5419000, 5.3517800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102069, 'Sunndalsøra', 'Sunndalsora', 'Sundalsoren,Sundalsören,Sunndalsora,Sunndalsoyra,Sunndalsöyra,Sunndalsøra,sun da er se la,孫達爾瑟拉', 62.6751900, 8.5632700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102070, 'Stryn', 'Stryn', 'Kommun Stryn,Nedstryn,Strjun,Stryn,Stryni vald,Stryns kommun,si te lin,strayana,Стрюн,স্ট্রয়ন,斯特林', 61.9025900, 6.7179000, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102071, 'Straumen', 'Straumen', '', 67.3476900, 15.6049300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102072, 'Straumen', 'Straumen', 'Straumen,Strommen,Strömmen', 63.8716300, 11.2961700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102073, 'Straume', 'Straume', 'Straume,Stromme,Strömme', 68.6888000, 14.4720500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102074, 'Stranda', 'Stranda', 'Stranda,Stranden', 62.3086400, 6.9371700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102075, 'Storsteinnes', 'Storsteinnes', '', 69.2408100, 19.2343700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102076, 'Storebø', 'Storebo', 'Storabo,Storabø,Storebo,Storebö', 60.0948500, 5.2270500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102077, 'Stokmarknes', 'Stokmarknes', 'SKN,Stokkmarknes,Stokmarknes', 68.5646200, 14.9107500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102078, 'Stokke', 'Stokke', 'Stokke,Stokke kommun', 59.2225500, 10.3005500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102079, 'Stjørdalshalsen', 'Stjordalshalsen', '', 63.4681000, 10.9261800, 'NO', '2014-08-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102080, 'Steinshamn', 'Steinshamn', 'Steinshamn', 62.7838900, 6.4706500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102081, 'Steinkjer', 'Steinkjer', 'Steinkjer,Stenkjaer', 64.0148700, 11.4953700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102082, 'Stavern', 'Stavern', 'Fredriksvaern,Fredriksvern,Fredriksværn,Stavern', 59.0000000, 10.0333300, 'NO', '2012-01-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102083, 'Stavanger', 'Stavanger', 'SVG,Stafangur,Stavanger,Stavangera,Stavenger,sutavu~angeru,Ставангер,スタヴァンゲル', 58.9700500, 5.7333200, 'NO', '2011-06-16', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102084, 'Stange', 'Stange', 'Stange,Stange Stasjonsby', 60.7180300, 11.1941700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102085, 'Spydeberg', 'Spydeberg', '', 59.6170900, 11.0855900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102086, 'Spetalen', 'Spetalen', '', 60.1833300, 11.9000000, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102087, 'Sørumsand', 'Sorumsand', '', 59.9862100, 11.2415400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102088, 'Sortland', 'Sortland', 'Kommun Sortland,Sortlan,Sortland,Sortlands kommun,Sortlann,Suorta,sortalenda,sorutoran,su te lan,Сортлан,Сортланд,Сортланн,সোর্টলেন্ড,ソルトラン,苏特兰', 68.6956900, 15.4049800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102089, 'Sørland', 'Sorland', '', 67.6656400, 12.6978400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102090, 'Solfjellsjøen', 'Solfjellsjoen', 'Solfjellsjoen,Solfjellsjøen', 66.1166700, 12.4833300, 'NO', '2014-04-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102091, 'Sola', 'Sola', 'Haaland,Haland,Håland,Kommun Sola,Sola,Sola koezseg,Sola kommun,Sola község,Sola vald,Sole,sola,su la,Сола,সোলা,蘇拉', 58.8885400, 5.6528500, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102092, 'Søgne', 'Sogne', 'Sogne,Sogne kommun,Søgne,Søgne kommun', 58.0932800, 7.7829400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102093, 'Sogndalsfjøra', 'Sogndalsfjora', 'Sogndalsfjaera,Sogndalsfjora,Sogndalsfjæra,Sogndalsfjøra', 61.2257500, 7.1017800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102094, 'Snåase', 'Snaase', 'Snaase,Snaasen,Snasa,Snåase,Snåsa', 64.2457000, 12.3777900, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102095, 'Slemmestad', 'Slemmestad', 'Slemmestad', 59.7807400, 10.4970100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102096, 'Skui', 'Skui', '', 59.9274600, 10.4475000, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102097, 'Skudeneshavn', 'Skudeneshavn', 'Skudeneshavn,Skudeneskhavn,Skudneshavn,Скуденесхавн', 59.1485600, 5.2568700, 'NO', '2011-11-06', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102098, 'Skreia', 'Skreia', 'Skreia', 60.6525700, 10.9356400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102099, 'Skotterud', 'Skotterud', 'Skotterud', 59.9828100, 12.1282500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102100, 'Skoppum', 'Skoppum', 'Skoppum,XUR', 59.3861300, 10.4107700, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102101, 'Skogn', 'Skogn', 'Skogn', 63.7037400, 11.1926200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102102, 'Skoger', 'Skoger', 'Skoger', 59.7132700, 10.2535600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102103, 'Skodje', 'Skodje', 'Skodje', 62.5046800, 6.6932200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102104, 'Skjeberg', 'Skjeberg', 'Skjeberg', 59.2114800, 11.1902500, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102105, 'Skjærhalden', 'Skjaerhalden', 'Skjaerhalden,Skjaerhallen,Skjaerholla,Skjaerhollen,Skjærhalden,Skjærhallen,Skjærholla,Skjærhollen', 59.0252600, 11.0368500, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102106, 'Skien', 'Skien', 'Gorad Shyen,Kommun Skien,SKE,Seins,Shien,Shijen,Sienas,Skien,Skieni vald,shien,sien,skayn,skiyena,xi en,Šienas,Šėins,Горад Шыен,Шиен,Шијен,Шієн,سکائن,স্কিয়েন,シーエン,希恩,시엔', 59.2096200, 9.6089700, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102107, 'Ski', 'Ski', 'Kommun Ski,Shi,Si,Ski,Ski kommun,YVS,ski,xi,Ši,Ши,স্কি,希', 59.7194900, 10.8357600, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102108, 'Skaun', 'Skaun', 'Kommun Skaun,Skauan,Skaun,Skauns kommun,Skjoun,sakauna,si kai yu en,Скёун,সকৌন,斯凱于恩', 63.2514900, 10.0523600, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102109, 'Skarnes', 'Skarnes', 'Skarnes,Skarnes Stasjonsby', 60.2539100, 11.6848500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102110, 'Skaland', 'Skaland', 'Skaland', 69.4445600, 17.2983200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102111, 'Sjøvegan', 'Sjovegan', 'Sjovegan,Sjøvegan', 68.8736300, 17.8470600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102112, 'Skjønhaug', 'Skjonhaug', 'Sjonhaug,Sjønhaug', 59.6406900, 11.3159100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102113, 'Sjøholt', 'Sjoholt', 'Sjoholt,Sjøholt,Soholt,Söholt', 62.4826300, 6.8137600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102114, 'Sistranda', 'Sistranda', 'Sistranda,Sistranden', 63.7252300, 8.8331800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102115, 'Siljan', 'Siljan', 'Siljan', 59.2884300, 9.7100000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102116, 'Setermoen', 'Setermoen', 'Saetermoen,Sætermoen', 68.8609900, 18.3485700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102117, 'Sem', 'Sem', 'Sem', 59.2823000, 10.3300400, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102118, 'Selvik', 'Selvik', 'Selvik', 59.5664500, 10.2600400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102119, 'Seljord', 'Seljord', '', 59.4847700, 8.6301700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102120, 'Selje', 'Selje', 'QFK', 62.0444000, 5.3473900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102121, 'Sauda', 'Sauda', 'Sauda,Sauda kommun', 59.6505900, 6.3541500, 'NO', '2017-02-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102122, 'Sarpsborg', 'Sarpsborg', 'Gorad Sarpsborg,Kommun Sarpsborg,Sarpsborg,Sarpsborgas,Sarpsborgs kommun,Sarpsbuorgs,XKQ,sa er pu si bao,saleubseuboleugeu,sarpasaborga,sarpsbwrg,sarupusuborugu,Горад Сарпсборг,Сарпсборг,سارپسبورگ,সার্পসবোর্গ,サルプスボルグ,萨尔普斯堡,사릅스보르그', 59.2839100, 11.1096200, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102123, 'Sandvika', 'Sandvika', 'Sandviken,Sandvikja', 64.4637700, 13.5912500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102124, 'Sandvika', 'Sandvika', 'Sandvik,Sandvika,Sandviken,Sannvika,Sanvika,sang wei ka,sndwyka,Санвика,Сандвика,Саннвика,سندویکا,桑維卡', 59.8907300, 10.5277400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102125, 'Sandnessjøen', 'Sandnessjoen', 'SSJ,Sandnessheen,Sandnessjoen,Sandnessjøen,Sannessh''oen,Sannesshjoehn,Санднессйоен,Санднесшеен,Саннесшьоен,Саннесшёэн', 66.0216600, 12.6315800, 'NO', '2015-10-25', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102126, 'Sandnes', 'Sandnes', 'Sandnes,Sandnes kommun', 58.8524400, 5.7352100, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102127, 'Sandefjord', 'Sandefjord', 'Kommun Sandefjord,Sandefjord,Sandefjord kommuna,Sandefjordas,Sandefjordi vald,Sanef''or,Sannef''ord,Sannefiord,ZYS,sanadephajarda,sang de er fu de,sannepioleu,Сандефјорд,Санефьор,Саннефьорд,Саннефіорд,সানডেফজর্ড,桑德尔福德,산네피오르', 59.1311800, 10.2166500, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102128, 'Sande', 'Sande', 'Sande,Sande i Sunnfjord', 61.3251100, 5.7977300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102129, 'Sande', 'Sande', 'Kommun Sande,Sande,Sande i Vestfold,Sande kommun,Sande kommune i Vestfold,Sande vald,Sanne,sang ne,Санне,桑訥', 59.5867900, 10.2080900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102130, 'Sandane', 'Sandane', 'SDN,Sandane,Sandene', 61.7727700, 6.2149600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102131, 'Sand', 'Sand', 'Nord Odalen,Nord-Odal,Sand', 60.3922000, 11.5403000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102132, 'Sagvåg', 'Sagvag', '', 59.7813900, 5.3899600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102133, 'Sætre', 'Saetre', 'Saetre,Saetre i Hurum,Setre,Sætre,Sætre i Hurum', 59.6812900, 10.5274900, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102134, 'Rygge', 'Rygge', 'Rjugge,Рюгге', 59.3776200, 10.7503400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102135, 'Rubbestadneset', 'Rubbestadneset', 'Rubben,Rubbestadneset', 59.8155900, 5.2682200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102136, 'Røyrvik', 'Royrvik', 'Royrvik,Røyrvik', 64.8839400, 13.5625600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102137, 'Røyken', 'Royken', '', 59.7472400, 10.3883200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102138, 'Rotnes', 'Rotnes', 'Rotnes', 60.0570700, 10.8613500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102139, 'Røst', 'Rost', '', 67.5175400, 12.1176000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102140, 'Rosendal', 'Rosendal', 'Rosendal', 59.9858900, 6.0115700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102141, 'Rørvik', 'Rorvik', 'RVK,Rjorvik,Rorvik,Rørvik,Рёрвик', 64.8618500, 11.2396900, 'NO', '2016-10-23', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102142, 'Røros', 'Roros', 'Gorad Rorus,Kommun Roros,Kommun Røros,Plassje,R''oros,RRS,Reros,Rerusas,Rjorus,Roros,Roros kommun,Rorosi vald,Røros,Røros kommun,Rørosi vald,lei luo si,rarosa,rerosu,riorusi,rrws,Горад Рорус,Рерос,Рьорос,Рёрус,ררוס,রারোস,რიორუსი,レーロース,勒羅斯', 62.5746800, 11.3842000, 'NO', '2016-12-11', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102143, 'Rollag', 'Rollag', 'Rollag,Rollang,Rolloug', 59.9843100, 9.2964400, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102144, 'Rognan', 'Rognan', 'Rognan,ZXM', 67.1002100, 15.3908600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102145, 'Roa', 'Roa', '', 60.2909300, 10.6158500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102146, 'Rjukan', 'Rjukan', 'R''jukan,Rjukan,liukan,you kan,Рьюкан,Рюкан,Рјукан,尤坎,리우칸', 59.8789100, 8.5941100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102147, 'Risør', 'Risor', 'Kommun Risor,Kommun Risør,Ris''or,Risjor,Risor,Risori vald,Risors kommun,Risør,Risøri vald,Risørs kommun,li se er,risara,Рисьор,Рисёр,রিসার,里瑟爾', 58.7205700, 9.2342200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102148, 'Rindal', 'Rindal', 'Rindal,Rindal pa Nordmore,Rindal på Nordmøre,Rindalen', 63.0554700, 9.2115100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102149, 'Rena', 'Rena', 'Rena,XKE', 61.1322200, 11.3715600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102150, 'Reinsvoll', 'Reinsvoll', 'Reinsvoll', 60.6797700, 10.6217500, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102151, 'Rensvik', 'Rensvik', 'Reinsvik,Rensvik', 63.0984300, 7.8202600, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102152, 'Reine', 'Reine', 'Rejne,Reyne,lei ne,renu,ryyn,Рейне,Рејне,Ռեյնե,رئین,レーヌ,雷讷', 67.9324900, 13.0895500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102153, 'Raufoss', 'Raufoss', 'ZMQ', 60.7260400, 10.6133000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102154, 'Ranemsletta', 'Ranemsletta', 'Ranemsletta', 64.4944700, 11.9491200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102155, 'Randaberg', 'Randaberg', 'Randaberg,Randaberg kommun,Randaberg pa Jaeren,Randaberg på Jaeren', 58.9995500, 5.6187100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102156, 'Ramberg', 'Ramberg', '', 68.0899100, 13.2298900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102157, 'Rakkestad', 'Rakkestad', '', 59.4251300, 11.3453500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102158, 'Råholt', 'Raholt', 'Raholt,Råholt', 60.2751300, 11.1790100, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102159, 'Prestfoss', 'Prestfoss', 'Prestfoss', 60.0434300, 9.6352000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102160, 'Prestestranda', 'Prestestranda', 'Prestestrand,Prestestranda', 59.0977300, 9.0586600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102161, 'Porsgrunn', 'Porsgrunn', 'Kommun Porsgrunn,Porsgrun,Porsgrund,Porsgrunn,Porsgrunni vald,Porsgrunns kommun,Posgriunas,Poshgrun,Pošgriūnas,Pushgrjon,XKP,bo shen ge lun,poleuseugeulun,porsagruna,Порсгрун,Порсгрунн,Пошгрун,Пушгрён,পোর্সগ্রুন,波什格伦,포르스그룬', 59.1405400, 9.6561000, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102162, 'Øystese', 'Oystese', 'Oysteso,Öystesö', 60.3882500, 6.1925100, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102163, 'Farnes', 'Farnes', 'Farnes,Ovre Aardal,Ovre Ardal,Øvre Aardal,Øvre Årdal', 61.3085000, 7.7969400, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102164, 'Otta', 'Otta', 'Otta,XOR', 61.7712000, 9.5352900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102165, 'Osøyro', 'Osoyro', 'Oosoren,Oosøren,Osora,Osoren,Osoyri,Osøra,Osøren,Osøyri', 60.1838500, 5.4638000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102166, 'Oslo', 'Oslo', 'Asloa,Christiania (historical),Gorad Osla,Kristiania (historical),OSL,Ohoro,Oslas,Oslo,Oslo osh,Oslu,Osló,ao si lu,asalo,aslw,awslw,osalo,oseullo,oslea,oslo,osuro,xxslo,ywslw,Òslo,Ósló,Ōhoro,Όσλο,Горад Осла,Осло,Осло ош,Օսլո,אוסלו,أوسلو,ئوسلو,ئۆسلۆ,اسلو,اوسلو,ܐܘܣܠܘ,ओस्लो,ওসলো,ਓਸਲੋ,ଅସଲୋ,ஒஸ்லோ,ഓസ്ലൊ,ออสโล,ཨོ་སི་ལོ།,အော့စလိုမြို့,ოსლო,ኦስሎ,オスロ,奥斯陆,오슬로', 59.9127300, 10.7460900, 'NO', '2014-10-06', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102167, 'Os', 'Os', 'Os,Os i Hedmark,Os i Osterdalen,Os i Østerdalen,Os im Osterdalen,Os im Østerdalen,Os w Hedmark', 62.4964700, 11.2232600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102168, 'Ørnes', 'Ornes', 'Ornes,Ørnes', 66.8687800, 13.7057900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102169, 'Orkanger', 'Orkanger', 'Orkanger,Оркангер', 63.3066800, 9.8502500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102170, 'Ørje', 'Orje', 'Orje,Ørje', 59.4802300, 11.6601600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102171, 'Oppdal', 'Oppdal', 'Kommun Oppdal,Opdal,Oppdal,Oppdali vald,Oppdals kommun,Uvdal,ao pu da er,oppadala,Опдал,Оппдал,ওপ্পডাল,奧普達爾', 62.5943100, 9.6912000, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102172, 'Ølen', 'Olen', '', 59.6043700, 5.8079900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102173, 'Odda', 'Odda', 'Odda,Odda kommun,Odde,Одда', 60.0691200, 6.5456500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102174, 'Notodden', 'Notodden', 'NTB,Notodden', 59.5593600, 9.2585300, 'NO', '2013-11-03', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102175, 'Norheimsund', 'Norheimsund', 'Nordheimsund,Norheimsund', 60.3708900, 6.1456200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102176, 'Noresund', 'Noresund', 'Nore Sundet', 60.1798500, 9.6241100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102177, 'Nordfjordeid', 'Nordfjordeid', 'Nordfjordeidet', 61.9122000, 5.9855700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102178, 'Nodeland', 'Nodeland', 'Naadeland,Nadeland,Nodeland,Noteland,Nådeland', 58.1551700, 7.8357600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102179, 'Nesna', 'Nesna', '', 66.1981700, 13.0184400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102180, 'Nesbyen', 'Nesbyen', 'Nesbyen,XUL', 60.5680900, 9.1027400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102181, 'Naustdal', 'Naustdal', 'Naustdal,Naustdal i Sunnfjord', 61.5110800, 5.7169400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102182, 'Narvik', 'Narvik', 'Kommun Narvik,NVK,Narviika,Narvik,Narvikas,Narviks kommun,Narwik,na er wei ke,naleubikeu,narbhika,naruvu~iku,nrwwyq,Νάρβικ,Нарвик,Нарвік,Նարվիկ,נרוויק,নার্ভিক,ナルヴィク,纳尔维克,나르비크', 68.4383800, 17.4272000, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102183, 'Namsskogan', 'Namsskogan', '', 64.9288600, 13.1595400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102184, 'Namsos', 'Namsos', 'Kommun Namsos,Namsos,Namsus,Njaarke,OSY,na mu suo si,namasosa,namsos,namsoseu,namsws,namusosu,Намсос,Намсус,نامسوس,নামসোস,ナムソス,納姆索斯,남소스', 64.4662400, 11.4957200, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102185, 'Nærbø', 'Naerbo', 'Naerbo,Narbo,Narbø,Nærbø', 58.6654600, 5.6378800, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102186, 'Mysen', 'Mysen', 'Mysen', 59.5535400, 11.3257800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102187, 'Myre', 'Myre', '', 69.1058800, 15.9630800, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102188, 'Myra', 'Myra', '', 58.7492100, 8.8625400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102189, 'Mosterhamn', 'Mosterhamn', 'Moster,Mosterham,Mosterhamn,Mosterhavn', 59.6991900, 5.3858500, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102190, 'Moss', 'Moss', 'Kommun Moss,Mos,Mosas,Moss,Moss kommun,Mossi vald,XKM,mo si,mosa,moseu,mosi,mws,mws  nrwzh,Мос,Мосс,מוס,موس,موس، نروژ,মোস,მოსი,莫斯,모스', 59.4340300, 10.6577100, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102191, 'Mosjøen', 'Mosjoen', 'MJF,Mosjoen,Mosjøen,Mush''oen,Mushjoehn,mo she en,Мушьоен,Мушёэн,莫舍恩', 65.8359900, 13.1907600, 'NO', '2015-11-22', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102192, 'Moldjord', 'Moldjord', 'Moldjord,Moldjorden', 67.0060100, 14.5743000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102193, 'Molde', 'Molde', 'Gorad Mole,Kommun Molde,MOL,Molde,Molde kommun,Moldė,Muolde,Muoldė,mo er de,molade,molde,morude,mwldh,Горад Моле,Молде,مولده,مولڈے,মোলডে,モルデ,莫尔德,몰데', 62.7375200, 7.1591200, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102194, 'Fyresdal', 'Fyresdal', 'Fyresdal,Kyrkjebygdi,Moland', 59.1834300, 8.0921000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102195, 'Mo i Rana', 'Mo i Rana', 'MQN,Mo,Mo i Rana,Mu i Ran,Mu i Rana,Mu-i-Rana,mo cheng,moilana,mw ay rana,Мо и Рана,Му и Рана,Му-и-Рана,مو إي رانا,モー・イ・ラーナ,摩城,모이라나', 66.3127800, 14.1427800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102196, 'Moi', 'Moi', '', 58.4567400, 6.5518400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102197, 'Moen', 'Moen', 'Moen,Moen i Malselv,Moen i Målselv', 69.1304300, 18.6122600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102198, 'Moelv', 'Moelv', 'Moelv,Moelven,XUJ', 60.9333300, 10.7000000, 'NO', '2012-01-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102199, 'Mo', 'Mo', '', 60.8162500, 5.8057500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102200, 'Mjøndalen', 'Mjondalen', 'Mjondalen,Mjøndalen', 59.7507500, 10.0247700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102201, 'Midsund', 'Midsund', 'Midsund,Midsund kommun,Misund', 62.6738700, 6.6741200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102202, 'Meråker', 'Meraker', 'Kommun Meraker,Kommun Meråker,Maraker,Maråker,Meraaker,Meraker,Merakers kommun,Meroker,Meråker,Meråkers kommun,Muorahka,Muorahká,mei luo ke,merokora,Мерокер,মেরোকোর,梅羅克', 63.4140600, 11.7429800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102203, 'Melsomvik', 'Melsomvik', 'Melsomvik', 59.2239400, 10.3361600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102204, 'Melhus', 'Melhus', '', 63.2855500, 10.2780600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102205, 'Melbu', 'Melbu', 'Melbu', 68.5024600, 14.7996200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102206, 'Maura', 'Maura', 'Maura', 60.2583000, 11.0319200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102207, 'Masfjorden', 'Masfjorden', 'Masfjorden,Masfjorden kommun,Masfjordnes', 60.7988700, 5.3041800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102208, 'Manger', 'Manger', '', 60.6414500, 5.0413600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102209, 'Mandal', 'Mandal', 'Kommun Mandal,Mandal,Mandali vald,Mandalis,Mandals kommun,man da er,manadala,mandal,mandaru,Мандал,মানডাল,マンダール,曼达尔,만달', 58.0274000, 7.4534200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102210, 'Malvik', 'Malvik', 'Malvik,Malvik kommun,Малвик', 63.4333300, 10.6833300, 'NO', '2012-12-18', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102211, 'Måløy', 'Maloy', 'Maaloey,Maloy,Maloya,Mol''oj,Moldo,Moldö,Molej,Moljoj,Måløy,Måløya,mo lu,Молеј,Мольой,Молёй,莫呂', 61.9353500, 5.1136200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102212, 'Malm', 'Malm', '', 64.0753400, 11.2239800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102213, 'Lysaker', 'Lysaker', 'XUI', 59.9099400, 10.6354500, 'NO', '2012-02-28', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102214, 'Lyngdal', 'Lyngdal', 'Lyngdal,Lyngdal kommun', 58.1376000, 7.0700200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102215, 'Lunde', 'Lunde', 'Lunde,Lunde i Telemark', 59.2983200, 9.1026800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102216, 'Lundamo', 'Lundamo', 'Lund,Lundamo,Lunde,Lundemo', 63.1521600, 10.2855500, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102217, 'Løten', 'Loten', 'Loiten,Loten,Löiten,Løten', 60.8194100, 11.3420900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102218, 'Løpsmarka', 'Lopsmarka', 'Laupsmarka,Lopsmarka,Lopsmarken,Löpsmarken,Løpsmarka', 67.3134300, 14.4493400, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102219, 'Lonevåg', 'Lonevag', 'Lonevaag,Lonevag,Lonevåg', 60.5255600, 5.4956300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102220, 'Fossbergom', 'Fossbergom', 'Fossbergom,Lom,Loms kommun,Лом', 61.8377200, 8.5684200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102221, 'Lødingen', 'Lodingen', 'Lodingen,Loedingen,Lødingen', 68.4137300, 15.9962600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102222, 'Løding', 'Loding', 'Loding,Løding', 67.3005500, 14.7385200, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102223, 'Lindås', 'Lindas', '', 60.7363900, 5.1610200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102224, 'Lillestrøm', 'Lillestrom', 'Lilestr''om,Lilestrem,Lilestriomas,Lillestrem,Lillestrjom,Lillestrom,Lillestrøm,li lei si te luo mu,Лилестрем,Лилестрьом,Лиллестрём,Ліллестрем,利勒斯特罗姆', 59.9559700, 11.0491800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102225, 'Lillesand', 'Lillesand', 'Lillesand,Lillesand kommun,Lillesann,Лиллесанн', 58.2487900, 8.3778000, 'NO', '2012-12-18', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102226, 'Lillehammer', 'Lillehammer', 'Gorad Lilekhamer,Lelehameris,Lilechamer,Lilehameris,Lilekhamer,Lillegammer,Lillehammer,Lillehammere,Lillehammers kommun,Lillekhammer,Lėlehameris,XXL,li lei ha mo er,lillehamera,lillehammeleu,lylhamr,rirehanmeru,Λιλεχάμερ,Горад Лілехамер,Лилехамер,Лиллехаммер,Ліллегаммер,לילהאמר,للیہیمر,ليلهامر,لیلهامر,লিল্লেহামের,リレハンメル,利勒哈默尔,릴레함메르', 61.1151400, 10.4662800, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102227, 'Liknes', 'Liknes', 'Liknes', 58.3121600, 6.9618000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102228, 'Levanger', 'Levanger', 'Kommun Levanger,Levanger,Levangers kommun,Lievenge,XUH,lai wang e er,lebang-eleu,lebhanera,Левангер,লেভাঙের,莱旺厄尔,레방에르', 63.7464400, 11.2996300, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102229, 'Lervik', 'Lervik', 'Lervik', 59.2711900, 10.7461000, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102230, 'Lensvik', 'Lensvik', 'Lensvik,Lensviken', 63.5138900, 9.8061100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102231, 'Lena', 'Lena', 'Lena', 60.6739100, 10.8131700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102232, 'Leland', 'Leland', '', 66.0640600, 12.9432500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102233, 'Leknes', 'Leknes', 'Leknes', 65.1000000, 11.7000000, 'NO', '2014-04-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102234, 'Leirvik', 'Leirvik', 'Leirvik', 59.7797700, 5.5005100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102235, 'Leirsund', 'Leirsund', 'Leirsund', 59.9968200, 11.0874600, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102236, 'Lauvsnes', 'Lauvsnes', 'Lauvsnes', 64.5006100, 10.8939600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102237, 'Larvik', 'Larvik', 'Kommun Larvik,Larvik,Larvikas,Larviki vald,Larviks kommun,XKK,la er wei ke,laleubikeu,larabhika,raruvu~iku,Ларвик,Ларвік,লারভিক,ラルヴィク,拉尔维克,라르비크', 59.0532800, 10.0351700, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102238, 'Larsnes', 'Larsnes', 'Larnes,Larsnes', 62.2028200, 5.5772900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102239, 'Larkollen', 'Larkollen', 'Larkollen,Laurkollen', 59.3319600, 10.6668700, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102240, 'Langevåg', 'Langevag', 'Langevaag,Langevag,Langevåg', 62.4408500, 6.1913700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102241, 'Langesund', 'Langesund', 'Langesund', 59.0007100, 9.7487600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102242, 'Lærdalsøyri', 'Laerdalsoyri', 'Laerdal,Lærdal', 61.1000100, 7.4737400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102243, 'Kyrksæterøra', 'Kyrksaeterora', 'Kirksaeteroren,Kirksaeterören,Kyrksaeterora,Kyrkseterora,Kyrkseterøra,Kyrksæterøra', 63.2905700, 9.0890900, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102244, 'Kviteseid', 'Kviteseid', '', 59.4022300, 8.4926700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102245, 'Krokstadøra', 'Krokstadora', 'Krokstadora,Krokstadoren,Krokstadören,Krokstadøra', 63.4009900, 9.5006200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102246, 'Kristiansund', 'Kristiansund', 'KSU,Kristiansund,Kristiansund Nord,Kristiansund kommun,Kristiansunn,Кристиансунн', 63.1104500, 7.7279500, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102247, 'Kristiansand', 'Kristiansand', 'Christiansand,KRS,Krisjansanna,Krisjānsanna,Kristiansand,Kristiansand Sor,Kristiansand Sør,Kristiansann,Kryscijansan,ke li si di an sang,Кристиансанд,Кристиансанн,Крысціянсан,כריסטיאנסנד,克里斯蒂安桑', 58.1467100, 7.9956000, 'NO', '2013-06-21', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102248, 'Kragerø', 'Kragero', 'Kommun Kragero,Kommun Kragerø,Krager''o,Kragerjo,Kragero,Kragero kommun,Kragero vald,Kragerø,Kragerø kommun,Kragerø vald,ke la ge lei,kragera,Крагерьо,Крагерё,ক্রাগেরা,克拉格勒', 58.8693000, 9.4149400, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102249, 'Korgen', 'Korgen', 'Korgen', 66.0766200, 13.8216000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102250, 'Koppang', 'Koppang', 'Koppang', 61.5721900, 11.0465900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102251, 'Kopervik', 'Kopervik', 'Kopervik,ke po wei ke,Копервик,科珀維克', 59.2835400, 5.3066900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102252, 'Konsmo', 'Konsmo', 'Konsmo', 58.2852900, 7.3559800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102253, 'Kongsvinger', 'Kongsvinger', 'Kommun Kongsvinger,Kongsvinger,Kongsvingeris,XZD,kansabhinajera,kong si wen e er,kongseubing-eleu,Конгсвингер,কঙ্সভিনজের,孔斯温厄尔,콩스빙에르', 60.1904900, 11.9977200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102254, 'Kongsberg', 'Kongsberg', 'Kongsberg,Kongsberg kommun,XKB,Конгсберг', 59.6685800, 9.6501700, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102255, 'Kolvereid', 'Kolvereid', 'Kolnereid,Kolvereid', 64.8654900, 11.6046500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102256, 'Kolbotn', 'Kolbotn', 'Kolbotn,Kollbotn', 59.8105600, 10.8038900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102257, 'Knarvik', 'Knarvik', 'Knarrevik,Knarrvik,Knarrviki,Knarvik', 60.5453000, 5.2820800, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102258, 'Knappstad', 'Knappstad', 'Knappstad,Knapstad', 59.6242400, 11.0327400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102259, 'Knappskog', 'Knappskog', 'Knappskog', 60.3790600, 5.0560200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102260, 'Kløfta', 'Klofta', '', 60.0740700, 11.1380500, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102261, 'Kleppestø', 'Kleppesto', 'Kleppesto,Kleppestø', 60.4084400, 5.2276000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102262, 'Kjøpsvik', 'Kjopsvik', 'Kjonsvik,Kjopsvik,Kjönsvik,Kjøpsvik', 68.0969600, 16.3741600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102263, 'Kirkenær', 'Kirkenaer', 'Kirkenaer,Kirkenaer i Solor,Kirkenær,Kirkenær i Solør', 60.4579000, 12.0585500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102264, 'Karlshus', 'Karlshus', 'Carlshuus,Karlsbunden,Karlshus,Rade,Råde', 59.3519500, 10.8722600, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102265, 'Kabelvåg', 'Kabelvag', 'Kabelvaag,Kabelvag,Kabelvåg', 68.2106600, 14.4755400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102266, 'Judaberg', 'Judaberg', 'Judaberg', 59.1720400, 5.8761700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102267, 'Jørpeland', 'Jorpeland', 'Jorpeland,Jørpeland', 59.0225100, 6.0407800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102268, 'Jondal', 'Jondal', 'Jondal,Jondal kommun', 60.2756100, 6.2522900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102269, 'Jevnaker', 'Jevnaker', '', 60.2397900, 10.3870900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102270, 'Jessheim', 'Jessheim', 'Jeskhajm,Jesseim,Jesskhejm,Йессхейм,Йесхайм', 60.1415100, 11.1751500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102271, 'Jaren', 'Jaren', 'Jaren', 60.3927300, 10.5615500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102272, 'Isdalstø', 'Isdalsto', 'Isdalssto,Isdalsstø,Isdalsto,Isdalstø', 60.5551900, 5.2694200, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102273, 'Inndyr', 'Inndyr', 'Indyr,Inndyr', 67.0335300, 14.0266300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102274, 'Hyllestad', 'Hyllestad', 'Hyllestad,Hyllestad kommun', 61.1710900, 5.2960300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102275, 'Hylkje', 'Hylkje', 'Hylkje', 60.5102800, 5.3544400, 'NO', '2012-05-06', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102276, 'Hvittingfoss', 'Hvittingfoss', 'Hvittingfoss,Vittingfos,Vittingfoss', 59.4857200, 10.0117300, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102277, 'Hundorp', 'Hundorp', 'Hundorp', 61.5552300, 9.9406900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102278, 'Høyanger', 'Hoyanger', '', 61.2234800, 6.0847100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102279, 'Hovden', 'Hovden', 'Hovde,Hovden', 59.5604500, 7.3567000, 'NO', '2013-11-23', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102280, 'Hov', 'Hov', 'Hov,Hov i Land', 60.6987000, 10.3519300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102281, 'Horten', 'Horten', 'Horten,Hortenas,Hortens kommun,Khorten,Khuten,Kommun Horten,holeuten,hortena,huo er teng,hwrtn,Хортен,Хутен,هورتن,হোর্টেন,霍尔滕,호르텐', 59.4172100, 10.4834300, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102282, 'Hopen', 'Hopen', '', 63.4653900, 8.0143700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102283, 'Hønefoss', 'Honefoss', 'Hionefosas,Honefoss,Hønefoss,Kh''onefos,Khenefos,Khjonefoss,he ne fu si,hoeneposeu,hwnfws,Хенефос,Хьонефос,Хёнефосс,هونفوس,赫讷福斯,회네포스', 60.1680400, 10.2564700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102284, 'Hommelvik', 'Hommelvik', '', 63.4108300, 10.7942400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102285, 'Holmestrand', 'Holmestrand', 'Holmestrand,Holmestrand kommun,XUG', 59.4876100, 10.3176100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102286, 'Hol', 'Hol', '', 68.5490200, 16.3921800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102287, 'Hokksund', 'Hokksund', 'Hokksund', 59.7707700, 9.9098700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102288, 'Hjelset', 'Hjelset', 'Hjellset,Hjelset', 62.7805000, 7.4927700, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102289, 'Herre', 'Herre', 'Herre', 59.1035100, 9.5619500, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102290, 'Hermansverk', 'Hermansverk', '', 61.1846100, 6.8501600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102291, 'Hemsedal', 'Hemsedal', 'Khemsedal'',Хемседаль', 60.8629300, 8.5533700, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102292, 'Hemnesberget', 'Hemnesberget', 'Hemnesberget', 66.2248900, 13.6164300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102293, 'Heggenes', 'Heggenes', '', 61.1438300, 9.0694200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102294, 'Hauknes', 'Hauknes', 'Hauknes', 66.2833300, 14.0666700, 'NO', '2012-01-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102295, 'Haugesund', 'Haugesund', 'Gaugesun,HAU,Haugesiundas,Haugesund,Khaugesun,Khaugezund,Khavesund,Khjougesunn,Kommun Haugesund,hai yu ge song,haugesun,haugesunda,he-ugesun,Гаугесун,Хавесунд,Хаугезунд,Хаугесун,Хёугесунн,হৌগেসুন্ড,ハウゲスン,海于格松,헤우게순', 59.4137800, 5.2680000, 'NO', '2012-03-01', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102296, 'Hauge i Dalane', 'Hauge i Dalane', 'Hauge', 58.3436100, 6.2812100, 'NO', '2013-01-04', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102297, 'Harstad', 'Harstad', 'EVE,HRD,Harsta,Harstad,Hárštá,Kharstad,Харстад', 68.7983300, 16.5416500, 'NO', '2017-06-18', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102298, 'Hareid', 'Hareid', 'Hareid,Indre Hareid,Midtre Hareid,Ytre Hareid', 62.3704100, 6.0290200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102299, 'Hardbakke', 'Hardbakke', 'Hardbakke', 61.0756200, 4.8411100, 'NO', '2013-03-16', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102300, 'Hansnes', 'Hansnes', 'Hansnes', 69.9670100, 19.6275200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102301, 'Hamnvik', 'Hamnvik', '', 68.7792700, 17.1717900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102302, 'Hamar', 'Hamar', 'Gamar,Gorad Khamar,HMR,Hamar,Hamaras,Hamars,Hammaria,Hámar,Khamar,Kommun Hamar,ha ma er,hamaleu,hamara,hamaru,Гамар,Горад Хамар,Хамар,ہمار,হামার,ハーマル,哈马尔,하마르', 60.7945000, 11.0679800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102303, 'Halden', 'Halden', 'Fredrikshald,Halden,Khalden,XKD,Халден', 59.1247800, 11.3875400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102304, 'Hagavik', 'Hagavik', 'Hagavik', 60.1807600, 5.4014600, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102305, 'Gvarv', 'Gvarv', 'Gvarv', 59.3876700, 9.1724000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102306, 'Gullhaug', 'Gullhaug', 'Guldhaug,Gullaug,Gullhaug', 59.5013000, 10.2522400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102307, 'Gryllefjord', 'Gryllefjord', '', 69.3630400, 17.0528400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102308, 'Grua', 'Grua', 'Grua', 60.2570100, 10.6622200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102309, 'Grong', 'Grong', 'XKG', 64.4645900, 12.3160100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102310, 'Grimstad', 'Grimstad', 'Grimsta,Grimstad,Grimstadi vald,Kommun Grimstad,ge li mu si ta,geulimseutadeu,grimastada,gurimusutaddo,Гримста,Гримстад,গ্রিমস্টাড,グリムスタッド,格里姆斯塔,그림스타드', 58.3405000, 8.5934300, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102311, 'Gravdal', 'Gravdal', 'Gravdal', 68.1183200, 13.5533900, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102312, 'Gratangen', 'Gratangen', 'Gratangen', 68.6500000, 17.6833300, 'NO', '2014-04-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102313, 'Granvin', 'Granvin', 'Granvin,Granvin kommun', 60.5240800, 6.7194000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102314, 'Gol', 'Gol', 'GLL,Gol,Gol kommun', 60.7014000, 8.9457200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102315, 'Glomfjord', 'Glomfjord', 'Glaamen,Glamfjord,Glomfjord,Glåmfjord', 66.8166300, 13.9440400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102316, 'Gladstad', 'Gladstad', 'Gladstad', 65.6768300, 11.9621800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102317, 'Justvik', 'Justvik', 'Gjusvig', 58.1969100, 8.0310700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102318, 'Gjøvik', 'Gjovik', 'Gjoevik,Gjovik,Gjoviki vald,Gjoviks kommun,Gjövik,Gjøvik,Gjøviki vald,Gjøviks kommun,Jevik,Jjovik,Jovik,Jovikas,Kommun Gjovik,Kommun Gjøvik,gajabhika,yebikeu,yue wei ke,Јевик,Йовик,Йёвик,গজাভিক,约维克,예비크', 60.7957400, 10.6915500, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102319, 'Gjerstad', 'Gjerstad', '', 58.8808300, 9.0186100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102320, 'Geilo', 'Geilo', 'Geilo,Gejlo,Gielo,Gjelo,Гейло', 60.5336900, 8.2053900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102321, 'Frogner', 'Frogner', 'Frogner', 60.0246300, 11.1028400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102322, 'Frekhaug', 'Frekhaug', 'Frekhaug', 60.5132100, 5.2425200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102323, 'Fredrikstad', 'Fredrikstad', 'Frederikstad,Fredrikstad,XKF,furedorikusuta,Фредрикстад,フレドリクスタ', 59.2181000, 10.9298000, 'NO', '2011-02-28', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102324, 'Fossby', 'Fossby', 'Fosby,Fossby', 59.2221800, 11.6992800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102325, 'Fosnavåg', 'Fosnavag', 'Forsnevaag,Fosnavag,Fosnavåg', 62.3419400, 5.6339600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102326, 'Førde', 'Forde', 'FDE,Forde,Fords,Førde', 61.4521700, 5.8571700, 'NO', '2013-04-12', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102327, 'Folldal', 'Folldal', 'Foldal,Folldal', 62.1324600, 9.9968000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102328, 'Florø', 'Floro', 'FRO,Flore,Floro,Florø,Flur''o,Flurjo,Kinn,flwra  shhr,fu lu lei,Флоре,Флурьо,Флурё,فلورا، شهر,弗盧勒', 61.5995700, 5.0328000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102329, 'Flekkefjord', 'Flekkefjord', 'Flekef''or,Flekkef''ord,Flekkefjord,Flekkefjords kommun,Kommun Flekkefjord,fu lai ke fei you er,furekkefiyoru,phlekkephajorda,Флекефьор,Флеккефьорд,ফ্লেক্কেফজোর্ড,フレッケフィヨール,弗萊克菲尤爾', 58.2970500, 6.6606900, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102330, 'Flateby', 'Flateby', 'Flateby', 59.8295100, 11.1534500, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102331, 'Flå', 'Fla', 'Fla,Flaa,Flå', 60.4302100, 9.4619700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102332, 'Fitjar', 'Fitjar', 'Fitjar,Fitjar kommun', 59.9180300, 5.3167400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102333, 'Finnsnes', 'Finnsnes', 'Finnsnes,Finsnes,fen si nei si,Финнснес,Финснес,芬斯內斯', 69.2295900, 17.9811400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102334, 'Fillan', 'Fillan', 'Fillan', 63.6063800, 8.9696100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102335, 'Fevik', 'Fevik', 'Fevig,Fevik', 58.3782000, 8.6760100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102336, 'Fetsund', 'Fetsund', '', 59.9246300, 11.1571100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102337, 'Fedje', 'Fedje', 'Fedje,Fedje kommun', 60.7789000, 4.7148500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102338, 'Fauske', 'Fauske', 'Fauske,Фауске', 67.2588300, 15.3918100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102339, 'Farsund', 'Farsund', '', 58.0947900, 6.8046800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102340, 'Fagerstrand', 'Fagerstrand', 'Fagerstrand', 59.7374600, 10.5940400, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102341, 'Fagernes', 'Fagernes', 'Coalbmi,Fagernes,Fagernesas,Fajernes,VDB,fa ge nei si,Čoalbmi,Фагернес,Фајернес,法格內斯', 60.9858400, 9.2323600, 'NO', '2013-03-25', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102342, 'Evjen', 'Evjen', '', 68.2666700, 13.7333300, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102343, 'Evje', 'Evje', 'Evje', 58.5856900, 7.8036300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102344, 'Evenskjer', 'Evenskjer', 'Evenskjaer,Evenskjer,Evenskjær,Skearri,Vierva,Viervá', 68.5828300, 16.5720300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102345, 'Etne', 'Etne', 'Etne,Etne kommun,Etnesjoen,Etnesjøen', 59.6652800, 5.9370800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102346, 'Espeland', 'Espeland', 'Espeland', 60.3824900, 5.4657000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102347, 'Elverum', 'Elverum', 'Ehl''verum,Elverum,Elverumi vald,Kommun Elverum,XUC,ai er wo lu mu,elabheruma,Елверум,Эльверум,এলভেরুম,埃尔沃吕姆', 60.8819100, 11.5623100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102348, 'Eivindvik', 'Eivindvik', 'Eivindvik,Eivinvik,Ejvindvik', 60.9813300, 5.0749700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102349, 'Eikelandsosen', 'Eikelandsosen', '', 60.2417500, 5.7443300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102350, 'Eike', 'Eike', 'Eike', 59.3983300, 5.3638900, 'NO', '2012-01-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102351, 'Eidsvoll', 'Eidsvoll', 'Eidsvold,Eidsvoll,Eidsvoll kommun', 60.3311000, 11.2626400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102352, 'Eidsvåg', 'Eidsvag', 'Eidsvaag,Eidsvag,Eidsvåg', 62.7765600, 8.0655000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102353, 'Eidfjord', 'Eidfjord', 'Ehjdf''ord,Eidfjord,Eidfjord i Hardanger,Eidfjords kommun,Ejdf''ord,Kommun Eidfjord,Oyfjord,ai de fei you er,idaphajorda,Öyfjord,Ейдфьорд,Эйдфьорд,ইদফজোর্ড,埃德菲尤爾', 60.4675000, 7.0719300, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102354, 'Eide', 'Eide', 'Eide,Eide kommun,Eide pa Nordmore,Eide på Nordmøre', 62.9173500, 7.4466900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102355, 'Egersund', 'Egersund', 'Ajersun,Egersund,Ejersund,XRD,agshn,ai ge er song,aygrswnd,Айерсун,Ејерсунд,اگشن,ایگرسوند,埃格尔松', 58.4513300, 5.9997000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102356, 'Drøbak', 'Drobak', 'Dr''obak,Drebak,Drjobak,Drobak,Drøbak,de lei ba ke,drwbak,Дребак,Дрьобак,Дрёбак,دروباك,德勒巴克', 59.6633300, 10.6297500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102357, 'Drammen', 'Drammen', 'Dramen,Dramenas,Dramens,Drammen,Gorad Dramen,Kommun Drammen,Ntramen,XND,de la men,deulammen,doranmen,dram men,dramena,dramn,Ντράμεν,Горад Драмен,Драмен,Драммен,דראמן,درامن,ڈرامن,ড্রামেন,ดรัมเมน,ドランメン,德拉门,드람멘', 59.7438900, 10.2044900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102358, 'Dovre', 'Dovre', '', 61.9875000, 9.2555600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102359, 'Dombås', 'Dombas', 'Dombaas,du mu ao si,杜姆奥斯', 62.0755400, 9.1278500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102360, 'Dokka', 'Dokka', 'Dokka', 60.8350000, 10.0736200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102361, 'Dalen', 'Dalen', 'Dalen,Dalen i Telemark', 59.4449900, 8.0049200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102362, 'Dale', 'Dale', 'Dale,Dale i Sunnfjord,Fjaler', 61.3635300, 5.4003600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102363, 'Dale', 'Dale', 'Dale,Dale i Bruvik', 60.5863900, 5.8188800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102364, 'Bygland', 'Bygland', '', 58.8285000, 7.7961600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102365, 'Bryne', 'Bryne', 'Bryne,XOB', 58.7353600, 5.6476600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102366, 'Brumunddal', 'Brumunddal', 'Brumunddal,Brumunddalen,ZVB', 60.8809500, 10.9394800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102367, 'Bruflat', 'Bruflat', 'Bruflat,Etnedalen', 60.8878100, 9.6414300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102368, 'Brønnøysund', 'Bronnoysund', 'BNN,Br''on''ojsun,Brjonnjojsunn,Bronno,Bronnoy,Bronnoysund,Brønnø,Brønnøy,Brønnøysund,bu lun ni,Брьоньойсун,Брённёйсунн,布倫尼', 65.4625000, 12.1997300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102369, 'Svortland', 'Svortland', 'Bremnes,Svortland', 59.7928400, 5.1722600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102370, 'Brekstad', 'Brekstad', 'Brekkstad,Brekstad,Brokstad,Брекстад', 63.6869700, 9.6654100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102371, 'Brattvåg', 'Brattvag', 'Brattvag,Brattvåg,Bratvaag', 62.5999100, 6.4442600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102372, 'Botngård', 'Botngard', 'Botngaard,Botngard', 63.7648400, 9.8086300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102373, 'Borkenes', 'Borkenes', 'Borkenes', 68.7726100, 16.1711500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102374, 'Ránda', 'Randa', 'Bogen,Bogen i Ofoten,Randa,Ránda', 68.5264700, 16.9928000, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102375, 'Bodø', 'Bodo', 'BOO,Bode,Bodo,Bodo vald,Bodoe,Bodö,Bodø,Bodø vald,Bodė,Bud''o,Bude,Budejju,Budjo,Budė,Būdē,Gorad Budzjo,Kommun Bodo,Kommun Bodø,bo de,boda,bodo,bodoe,bwdw,bwdw  nrwzh,Боде,Бодо,Буде,Будьо,Будё,Горад Будзё,بودو,بودو، نروژ,بوڈو,বোডা,ボードー,博德,보되', 67.2800000, 14.4050100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102376, 'Bø', 'Bo', 'Bo,Bo i Telemark,Bø,Bø i Telemark', 59.4129900, 9.0693000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102377, 'Blakstad', 'Blakstad', 'Blakkstad,Blakstad', 59.8191000, 10.4645000, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102378, 'Bjørkelangen', 'Bjorkelangen', 'Bjorkelangen,Bjørkelangen', 59.8835700, 11.5639600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102379, 'Bjerkvik', 'Bjerkvik', 'Bjerkvik,Bjorkvang,Bjorkvik,Bjørkvang,Bjørkvik', 68.5491700, 17.5570900, 'NO', '2013-07-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102380, 'Birkeland', 'Birkeland', '', 58.3309100, 8.2322900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102381, 'Berkåk', 'Berkak', 'Berkaak,Berkak,Berkåk', 62.8249600, 10.0117700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102382, 'Berger', 'Berger', 'Berger,Berger i Vestfold', 59.5499400, 10.3864100, 'NO', '2013-03-17', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102383, 'Bergen', 'Bergen', 'BGO,Bargen,Berga,Bergen,Bergena,Bergenas,Bergn,Bernken,Birgon,Bjoergvin,Björgvin,Gorad Bergen,baragena,bargana,bei er gen,beleugen,bergeni,berugen,brghn,brgn,perkan,Μπέργκεν,Берген,Горад Берген,ברגן,برغن,برگن,बार्गन,বারগেন,பேர்கன்,แบร์เกน,ბერგენი,ベルゲン,卑爾根,베르겐', 60.3929900, 5.3241500, 'NO', '2011-06-16', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102384, 'Batnfjordsøra', 'Batnfjordsora', 'Batnfjordsora,Batnfjordsoren,Batnfjordsören,Batnfjordsøra,Battenfjordsoren,Battenfjordsören', 62.8946300, 7.6725100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102385, 'Barkåker', 'Barkaker', 'Barkaaker,Barkaker,Barkåker', 59.3185900, 10.3896300, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102386, 'Ballangen', 'Ballangen', 'Balak,Balangen,Balat,Ballangen,Ballangeni vald,Ballangens kommun,Bálat,Bálák,Kommun Ballangen,ba lang en,ballanena,barangen,Баланген,Балланген,বাল্লাঙেন,バランゲン,巴朗恩', 68.3428300, 16.8314500, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102387, 'Balestrand', 'Balestrand', 'Balestrand,Balestrands kommun,Balestrann,Kommun Balestrand,ba lei si te lan,balestranda,Балестранн,বালেস্ট্রান্ড,巴勒斯特蘭', 61.2096200, 6.5360800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102590, 'Yangor', 'Yangor', '', -0.5353600, 166.9104800, 'NR', '2015-11-26', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102591, 'Uaboe', 'Uaboe', 'Uaboe,Waboe', -0.5139300, 166.9238400, 'NR', '2013-08-05', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102592, 'Baiti', 'Baiti', 'Baiti,Baitis,Baitsi,Baitsi District,bai di qu,baichi de qu,baiti gu,Баити,Բաիտի,ბაიტი,バイチ地区,白帝區,바이티 구', -0.5080300, 166.9294500, 'NR', '2013-08-10', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102593, 'Ijuw', 'Ijuw', 'Ijub,Ijuh,Ijuw', -0.5210000, 166.9581300, 'NR', '2013-08-10', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102594, 'Anibare', 'Anibare', 'Anibare,Enniberri', -0.5279200, 166.9524900, 'NR', '2013-07-04', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102595, 'Anabar', 'Anabar', 'Anabar,Aneber', -0.5084500, 166.9532600, 'NR', '2013-08-05', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102596, 'Yaren', 'Yaren', 'Giaren,INU,Jarehn,Jaren,Jarena,Jarenas,Jareno,Makwa,Moqua,Yaren,Yaren District,Yareni ringkond,Yarèn,dahyt yaryn,iareni,ya lun qu,ya ren,yalen gu,yarana zil''ha,yaren de qu,yaren mavattam,yarn,Γιαρέν,Јарен,Ярен,Ярэн,Յարեն,יארן,ضاحية يارين,یارن,ਯਾਰਨ ਜ਼ਿਲ੍ਹਾ,யாரென் மாவட்டம்,ยาเรน,ཡ་རེན།,იარენი,ያሬን,ヤレン地区,亞倫區,야렌 구', -0.5508500, 166.9252000, 'NR', '2016-10-03', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102597, 'Arijejen', 'Arijejen', '', -0.5254500, 166.9124700, 'NR', '2012-05-30', 155);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102525, 'Wāling', 'Waling', 'Waling,Walling,Wāling', 27.9833300, 83.7666700, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102526, 'Tulsīpur', 'Tulsipur', 'Tulsipur,Tulsīpur', 28.1309900, 82.2972600, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102527, 'Tīkāpur', 'Tikapur', 'Tikapur,Tīkāpur', 28.5000000, 81.1333300, 'NP', '2013-05-22', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102528, 'Tānsen', 'Tansen', 'Tansen,Tansing,Tānsen,Tānsing,Тансен', 27.8673100, 83.5467000, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102529, 'Siraha', 'Siraha', 'Shirha,Siraha,Sirakha,Sirha,Sirāhā,Сираха', 26.6542200, 86.2079500, 'NP', '2017-07-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102530, 'Salyān', 'Salyan', 'Sallyan,Sallyana,Sallyān,Sallyāna,Salyan,Salyān', 28.3785800, 82.1703000, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102531, 'Rāmechhāp', 'Ramechhap', '', 27.3256000, 86.0876800, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102532, 'Rājbirāj', 'Rajbiraj', 'Rajbiraj,Rājbirāj', 26.5333300, 86.7500000, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102533, 'Pyūthān', 'Pyuthan', 'Piuthan,Piuthān,Pyuthan,Pyūthān', 28.0886700, 82.8842700, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102534, 'Pokhara', 'Pokhara', 'PKR,Pakhra,Pokara,Pokhar,Pokhara,Pokhra,Pokkhara,bo ke la,bwkhara,pokala,pokara,pokh ra,pokhara,pokhara gavisa,pokhara upamahanagarapalika,pokkara,Ποκάρα,Покхара,פוקארה,بوخارا,پوکھرا,पोखरा,पोखरा उपमहानगरपालिका,पोखरा गाविस,பொக்காரா,ಪೊಖರಾ,โปขรา,ポカラ,博克拉,포카라', 28.2668900, 83.9685100, 'NP', '2011-03-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102535, 'Pātan', 'Patan', 'Lalitapura,Lalitpur,Manigal,Patan,Pātan,Yala,Лалитпур', 27.6765800, 85.3141700, 'NP', '2013-05-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102536, 'Panauti̇̄', 'Panauti', 'Panaoti,Panauti,Panauti Village,Panauti̇̄,Panautī', 27.5845300, 85.5148400, 'NP', '2015-06-08', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102537, 'Namche Bazar', 'Namche Bazar', 'Namche Bazar,Namche-Bazar,Nanche Bazar,Nauche,Nāmche Bāzār,SYH,Намче-Базар', 27.8052800, 86.7105800, 'NP', '2013-11-02', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102538, 'Nagarkot', 'Nagarkot', 'Nagarkot,Нагаркот', 27.7152200, 85.5207500, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102539, 'Malaṅgawā', 'Malangawa', 'Malangawa,Malangwa,Malankwa,Malaṅgawā', 26.8565800, 85.5594000, 'NP', '2017-07-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102540, 'Mahendranagar', 'Mahendranagar', 'Mahen Dkanagar,Mahendranagar,XMG', 28.9166700, 80.3333300, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102541, 'Lobujya', 'Lobujya', 'Lobuche,Lobuje,Lobujya', 27.9500000, 86.8166700, 'NP', '2013-05-22', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102542, 'Lamjung', 'Lamjung', 'Lamjung', 28.2099200, 84.3638000, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102543, 'Lahān', 'Lahan', 'Lahan,Lahān', 26.7202200, 86.4825800, 'NP', '2017-07-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102544, 'Kothari', 'Kothari', 'Kodali,Kodari,Kodāri,Kodāri̇̄,Kodārī,Kothari,Кодари', 27.9605700, 85.9566700, 'NP', '2015-06-08', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102545, 'Kirtipur', 'Kirtipur', 'Kirtipur,ji er di bu er,kipu nagarapalika,kirtipura,kirtipura nagarapalika,kirutipuru,krtypwr,Киртипур,کرتیپور,किपू नगरपालिका,कीर्तिपुर,कीर्तिपुर नगरपालिका,キルティプル,吉爾蒂布爾', 27.6787200, 85.2775000, 'NP', '2015-05-06', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102546, 'Khāndbāri', 'Khandbari', 'Khanbari,Khandbari,Khāndbāri', 27.3746900, 87.2039000, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102547, 'Kathmandu', 'Kathmandu', 'Catmandu,Catmandum,Gorad Katmandu,KTM,Kantipur,Kantipura,Katemandu,Kathmandau,Kathmandou,Kathmandu,Katmando,Katmandoe,Katmandou,Katmandu,Katmanduo,Katmandó,Katmandú,Katmandû,Katmandū,Katmantou,Khatmandu,Káthmandu,Káthmándú,jia de man dou,kateumandu,kath manthu,kathamadaum,kathamadaum mahanagarapalika,kathamadu,kathamandu,kathmandu,katmandw,katmandww,katmantu,katomanzu,qtmndw,yem jilla,Κατμαντού,Горад Катманду,Катманду,Կատմանդու,קאטמאנדו,קטמנדו,كاتماندو,كاتماندۇ,کاتماندو,کاتماندوو,کھٹمنڈو,काठमांडू,काठमाडौं,काठमाडौं महानगरपालिका,काठमाण्डू,येँ जिल्ला,কাঠমাণ্ডু,কাঠমান্ডু,ਕਠਮੰਡੂ,કાઠમંડુ,କାଠମାଣ୍ଡୁ,காட்மாண்டு,కాఠ్మండు,ಕಠ್ಮಂಡು,കാഠ്മണ്ഡു,කත්මන්ඩු,กาฐมาณฑุ,ཀ་ཏ་མན་ཏ།,ཀ་ཏ་མན་ཏུ།,კატმანდუ,ካትማንዱ,カトマンズ,加德滿都,카트만두', 27.7016900, 85.3206000, 'NP', '2015-03-20', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102548, 'Jumla', 'Jumla', 'JUM,Jumla', 29.2747200, 82.1838300, 'NP', '2013-09-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102549, 'Janakpur', 'Janakpur', 'Dzanakpuras,Dzhanakpur,Džanakpuras,JKR,Janakpur,Janakpur Dham,gu na ke bu er,janagpuleu,janakapura,janakapura nagarapalika,janakapura upamahanagarapalika,janakupuru,jnkpwr,Джанакпур,جنکپور,जनकपुर,जनकपुर उपमहानगरपालिका,जनकपुर नगरपालिका,ジャナクプル,賈納克布爾,자낙푸르', 26.7182800, 85.9064600, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102550, 'Jaleswar', 'Jaleswar', 'Jaleshwar,Jaleswar', 26.6471100, 85.8008100, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102551, 'Titahari', 'Titahari', 'Itahari,Ithari,Titahari,Īṭahari̇̄', 26.6637100, 87.2740300, 'NP', '2017-07-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102552, 'Ilām', 'Ilam', 'Ilam,Ilām', 26.9094300, 87.9282400, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102553, 'Hetauda', 'Hetauda', 'Hetauda,Hetauda Bazar,Hetaunda,Hetaura,Heṭauḍā,Hithaura,Hitura,Khetauda,hei dao da,hetauda,hetaunda,hetaunda upamahanagarapalika,hetoura,Хетауда,ہیٹوڈا,हेटौंडा,हेटौंडा उपमहानगरपालिका,हेटौडा,ヘトウラ,黑道達', 27.4283900, 85.0321900, 'NP', '2015-05-07', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102554, 'Gulariyā', 'Gulariya', 'Gularia,Gulariya,Gulariyā', 28.2333300, 81.3333300, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102555, 'Gaur', 'Gaur', 'Gaur,Gaura,Gour,Гаура', 26.7644800, 85.2784100, 'NP', '2016-09-09', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102556, 'Dharān Bāzār', 'Dharan Bazar', 'Dharan,Dharan Bazar,Dharān Bāzār', 26.8124800, 87.2835500, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102557, 'Dhankutā', 'Dhankuta', 'Dhankuta,Dhankuta Bazar,Dhankutta,Dhankutā', 26.9833300, 87.3333300, 'NP', '2011-03-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102558, 'Dhangarhi', 'Dhangarhi', 'DHI,Dhangadhi,Dhangarhi,Dhantardhi', 28.7079200, 80.5961100, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102559, 'Dārchulā', 'Darchula', 'Darchula,Dharchul,Dharchula,Dhārchul,Dhārchulā,Dārchulā,Khalanga', 29.8412100, 80.5287400, 'NP', '2013-11-04', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102560, 'Dailekh', 'Dailekh', '', 28.8443400, 81.7101100, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102561, 'Dadeldhurā', 'Dadeldhura', 'Dadeldhura,Dadeldhurā,Dandeldhura,Dandelhura', 29.2984200, 80.5805900, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102562, 'Butwāl', 'Butwal', 'Butaul,Butwai,Butwal,Butwaī,Butwāl', 27.7005500, 83.4483600, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102563, 'Bīrganj', 'Birganj', 'Birganj,Birgunj,Bīrganj', 27.0104300, 84.8773500, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102564, 'Biratnagar', 'Biratnagar', 'BIR,Biratnagar,Biratnagur,bi la de ne ge er,bilasnagaleu,biratanagara,biratanagara upamahanagarapalika,biratonagaru,viratanagara,Биратнагар,बिराटनगर,बिराटनगर उपमहानगरपालिका,विराटनगर,ビラートナガル,比拉德訥格爾,비랏나가르', 26.4550500, 87.2700700, 'NP', '2016-04-12', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102565, 'Bhojpur', 'Bhojpur', '', 27.9356500, 81.7755500, 'NP', '2013-05-22', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102566, 'Bhojpur', 'Bhojpur', 'BHP', 27.1715000, 87.0460700, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102567, 'Bharatpur', 'Bharatpur', 'BHR,Bharatpur,Bhâratpur,balaspuleu,baratopuru,bharatapura,bharatapura upamahanagarapalika,bharatapura  nepala,po luo duo bu er,بھرتپور، نیپال,भरतपुर,भरतपुर उपमहानगरपालिका,भरतपुर  नेपाल,バラトプル,婆羅多布爾,바랏푸르', 27.6833300, 84.4333300, 'NP', '2013-11-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102568, 'Bhaktapur', 'Bhaktapur', 'Badagaon,Baktapur,Bhadgaon,Bhaktapur,Bhaktapuras,Bhatgaon,Bhatgoan,Bhādgaon,Bkhaktapur,ba ke ta pu er,bagtapuleu,bakutapuru,bhaktapura,khvapa nagarapalika,phakt pu ra,Бактапур,Бхактапур,بھگتاپور,ख्वप नगरपालिका,भक्तपुर,ภักตปุระ,バクタプル,巴克塔普爾,박타푸르', 27.6729800, 85.4300500, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102569, 'Siddharthanagar', 'Siddharthanagar', 'Bhairahawa,Bhairawa,Bhairhwa,Bhairwa,Bhairāhawā,Siddharthanagar', 27.5000000, 83.4500000, 'NP', '2016-11-03', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102570, 'Bhadrapur', 'Bhadrapur', 'BDP,Bhadrapur', 26.5440400, 88.0943600, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102571, 'Bardiyā', 'Bardiya', 'Bardia,Bardiya,Bardiyā,Bardīa', 28.3005800, 81.3536000, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102572, 'Banepā', 'Banepa', 'Banepa,Banepa Bazar,Banepā,Panepa', 27.6324500, 85.5219200, 'NP', '2015-06-08', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102573, 'Bāglung', 'Baglung', 'Baglung,Baglung Bazar,Bāglung,Баглунг', 28.2718900, 83.5897500, 'NP', '2013-05-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102574, 'Achhām', 'Achham', '', 29.0500000, 81.3000000, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102575, 'Besisahar', 'Besisahar', 'Besisahar,Besisakhar,Бесисахар', 28.2341700, 82.4127800, 'NP', '2014-01-15', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102576, 'Birendranagar', 'Birendranagar', 'Birendra Nagar,Birendranagan,Birendranagar,Birendranagara,bi lan de la na jia er,birendoranagaru,bryndrngr,virendranagara,virendranagara nagarapalika,Бирендранаган,Бирендранагар,بریندرنگر,वीरेन्द्रनगर,वीरेन्द्रनगर नगरपालिका,ビレンドラナガル,比蘭德拉納加爾', 28.6019400, 81.6338900, 'NP', '2011-03-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102577, 'Dipayal', 'Dipayal', 'Dipayal Silgadhi,SIH', 29.2608300, 80.9400000, 'NP', '2017-07-08', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102578, 'Nepalgunj', 'Nepalgunj', 'KEP,Nepalganj,Nepalgun,Nepālganj,Непалгун', 28.0500000, 81.6166700, 'NP', '2017-06-16', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102579, 'Pisang', 'Pisang', '', 28.6146500, 84.1472100, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102580, 'Chame', 'Chame', '', 28.5536900, 84.2509700, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102581, 'Khudi', 'Khudi', '', 28.2821600, 84.3591200, 'NP', '2011-07-31', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102582, 'Chitre', 'Chitre', '', 28.4267300, 83.6907600, 'NP', '2011-03-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102583, 'Surkhet', 'Surkhet', '', 28.5174600, 81.7787000, 'NP', '2011-03-10', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102584, 'Jomsom', 'Jomsom', 'Dzongsam,JMO,Jomsom,New Fort', 28.7843600, 83.7351300, 'NP', '2013-09-21', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102585, 'Nawal', 'Nawal', '', 28.6483100, 84.1027900, 'NP', '2012-04-16', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102586, 'kankrabari Dovan', 'kankrabari Dovan', '', 27.6288100, 85.4593400, 'NP', '2012-02-12', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102587, 'Hari Bdr Tamang House', 'Hari Bdr Tamang House', '', 27.6289000, 85.4589300, 'NP', '2013-03-12', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102588, 'Bhattarai Danda', 'Bhattarai Danda', 'bhattara''i damda,भट्टराई डाँडा', 27.8833300, 83.9333300, 'NP', '2017-05-05', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102589, 'Dihi', 'Dihi', '', 27.8755200, 83.9275900, 'NP', '2017-04-13', 156);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102599, 'Woodend', 'Woodend', '', -43.3166700, 172.6666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102600, 'Whitianga', 'Whitianga', 'WTZ', -36.8333300, 175.7000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102601, 'Whangamata', 'Whangamata', '', -37.2000000, 175.8666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102602, 'Wellsford', 'Wellsford', 'Welsford', -36.2833300, 174.5166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102603, 'Wellington', 'Wellington', 'Gorad Velingtan,Hie-ling-dong,Hiê-lìng-dóng,Ouellin''nkton,Ouellinkton,Te Whanga-nui-a-Tara,Ueligitone,Uelingtun,Velington,Velingtona,Velingtonas,Velingtono,Vellington,Vellingtonia,Vellinqton,WLG,Welinton,Welintòn,Wellington,Wellinton,Weolingtun,Weolingtūn,Whanga-nui-a-Tara,hui ling dun,oyelintana,raelintana,uelingtʼoni,u~erinton,vailigatana,velingatana,velingtana,velingtoni,velintan,vellingtan,wei ling dun,wellingtan,wellingteon,wlyngtwn,wylynghtwn,wylynjtwn,Ουέλλιγκτον,Ουέλλινγκτον,Велингтон,Веллингтон,Веллінгтон,Горад Велінгтан,Уелингтън,Վելինգտոն,ולינגטון,װעלינגטאן,ولینگتون,ويلينجتون,ويلينغتون,ویلنگٹن,ۋېللىنگتون,वेलिंगटन,वेलिंग्टन,वेलिङ्गटन,ওয়েলিংটন,ৱেলিংটন,ਵੈਲਿੰਗਟਨ,વેલિંગ્ટન,வெலிங்டன்,ವೆಲ್ಲಿಂಗ್ಟನ್,വെല്ലിംഗ്ടൺ,เวลลิงตัน,ཝེ་ལིང་ཐོན།,ဝယ်လင်တန်မြို့,ველინგთონი,უელინგტონი,ዌሊንግተን,ウェリントン,威靈頓,惠灵顿,웰링턴', -41.2866400, 174.7755700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102604, 'Warkworth', 'Warkworth', 'Uorkuehrt,Warkworth Town District,Warkworth pa New Zealand,Warkworth på New Zealand,Уоркуэрт', -36.4000000, 174.6666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102605, 'Wanganui', 'Wanganui', 'Vanganui,WAG,Вангануи', -39.9333300, 175.0500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102606, 'Wakefield', 'Wakefield', '', -41.4000000, 173.0500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102607, 'Waiuku', 'Waiuku', 'Waiuku Town District', -37.2480600, 174.7348900, 'NZ', '2015-03-17', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102608, 'Waiouru', 'Waiouru', 'Warouru', -39.4775300, 175.6683400, 'NZ', '2015-03-09', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102609, 'Waimate North', 'Waimate North', '', -35.3166700, 173.8833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102610, 'Waihi Beach', 'Waihi Beach', '', -37.4000000, 175.9333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102611, 'Turangi', 'Turangi', 'Taupahi,Tokaanu Junction,Tongariro Bridge,Turangi', -38.9903700, 175.8083700, 'NZ', '2012-05-30', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102612, 'Tokoroa', 'Tokoroa', 'TKZ,Tokoroa,ტოკოროა', -38.2333300, 175.8666700, 'NZ', '2014-11-03', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102613, 'Tinwald', 'Tinwald', 'Tinwald Town District', -43.9166700, 171.7166700, 'NZ', '2012-06-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102614, 'Timaru', 'Timaru', 'Distretto di Timaru,TIU,Te Tihi-o-Maru,Timaru,Timaru City,Timaru-Distrikt,ti ma lu,tim-alu,timaru,Тимару,Тімару,ضلع تیمارو,ტიმარუ,ティマルー,提馬魯,팀아루', -44.3967200, 171.2536400, 'NZ', '2015-05-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102615, 'Te Kauwhata', 'Te Kauwhata', 'Kauwhata,Te Kaiwhata,Te Kauwhata Town District', -37.4000000, 175.1500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102616, 'Te Anau', 'Te Anau', 'TEU,Te Anau', -45.4166700, 167.7166700, 'NZ', '2013-06-22', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102617, 'Taupo', 'Taupo', 'TUO,Taupo,Taupo Town District,Taupo-nui-a-Tia,Taupō-nui-a-Tia,tao bo,taupo,Таупо,ტაუპო,タウポ,陶波,타우포', -38.6833300, 176.0833300, 'NZ', '2015-03-04', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102618, 'Takaka', 'Takaka', 'KTF,Takaka Town District', -40.8500000, 172.8000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102619, 'Tairua', 'Tairua', '', -37.0166700, 175.8500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102620, 'Taipa', 'Taipa', '', -34.9960400, 173.4666500, 'NZ', '2015-03-04', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102621, 'Rolleston', 'Rolleston', '', -43.5833300, 172.3833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102622, 'Richmond', 'Richmond', 'Richmond Borough,lichimeondeu,richmondi,رچمنڈ، نیوزی لینڈ,რიჩმონდი,리치먼드', -41.3333300, 173.1833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102623, 'Rakaia', 'Rakaia', 'South Rakaia', -43.7500000, 172.0166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102624, 'Raglan', 'Raglan', 'RAG', -37.8000000, 174.8833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102625, 'Pukekohe East', 'Pukekohe East', '', -37.2000000, 174.9500000, 'NZ', '2015-03-05', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102626, 'Prebbleton', 'Prebbleton', '', -43.5833300, 172.5166700, 'NZ', '2014-07-28', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102627, 'Portobello', 'Portobello', '', -45.8500000, 170.6500000, 'NZ', '2012-06-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102628, 'Motueka', 'Motueka', 'MZP', -41.1333300, 173.0166700, 'NZ', '2017-06-05', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102629, 'Porirua', 'Porirua', 'Porirua,bo li lu a,polilua,Порируа,პორირუა,波里魯阿,포리루아', -41.1333300, 174.8500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102630, 'Pleasant Point', 'Pleasant Point', 'Pleasant Point Town District', -44.2666700, 171.1333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102631, 'Wanaka', 'Wanaka', 'Pembroke,WKA,Wanaka,wa na ka,wanaka,ואנקה,ワナカ,瓦納卡,와나카', -44.7000000, 169.1500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102632, 'Paraparaumu', 'Paraparaumu', 'PPQ,Paraparaumu,Парапарауму', -40.9166700, 175.0166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102633, 'Parakai', 'Parakai', '', -36.6500000, 174.4333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102634, 'Papatowai', 'Papatowai', '', -46.5606900, 169.4706800, 'NZ', '2015-03-06', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102635, 'Palmerston North', 'Palmerston North', 'PMR,Palmerston Nort,Palmerston Nortas,Palmerston Norte,Palmerston North,Palmerston North City,Palmerston Utara,Palmerston-Nort,Palmy,Te Papa-i-oea,bei pa mo si dun,palmrstwn nwrth,pamasuton''nosu,pameoseuteonnoseu,Палмерстон Норт,Палмерстон-Норт,پالمرستون نورث,پامرسٹن نارتھ,პალმერსტონ-ნორთი,パーマストンノース,北帕莫斯顿,파머스턴노스', -40.3563600, 175.6111300, 'NZ', '2015-02-24', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102636, 'Paihia', 'Paihia', '', -35.2806700, 174.0910300, 'NZ', '2013-11-20', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102637, 'Oxford', 'Oxford', '', -43.3000000, 172.1833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102638, 'Otorohanga', 'Otorohanga', 'Otorohanga Town District', -38.1833300, 175.2000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102639, 'North Shore', 'North Shore', 'Boreia Akte,Nort-Shor,North Shore,bei an shi,Βόρεια Ακτή,Норт-Шор,北岸市', -36.8000000, 174.7500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102640, 'Ngunguru', 'Ngunguru', '', -35.6166700, 174.5000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102641, 'Ngatea', 'Ngatea', '', -37.2833300, 175.5000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102642, 'New Plymouth', 'New Plymouth', 'Aberplymm Nowydh,Distretto di New Plymouth,N''ju Plimut,N''ju-Plimut,NPL,Naujasis Plimutas,New Plymouth,New Plymouth City,New Plymouth Ngamotu,New Plymouth Ngāmotu,Ngamotu,Ngāmotu,Nieu-Plymouth,Nju Plimut,Nueva Plymouth,nyupeullimeoseu,nyupurimasu,xin pu li mao si,Њу Плимут,Нью Плимут,Нью-Плимут,Нью-Плімут,ნიუ-პლიმუთი,ニュープリマス,新普利茅斯,뉴플리머스', -39.0666700, 174.0833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102643, 'Nelson', 'Nelson', 'Gorad Nel''san,NSN,Nel''son,Nelson,Nelson City,Nelson eskualdea,Nelson pa New Zealand,Nelson på New Zealand,Nelsonas,Nelsun,Whakatu,Whakatū,nelcan,nelsana,nelseun,nelsoni,neruson,ni er xun,nlswn,nlswn  nywzlnd,nylswn,Горад Нельсан,Нелсон,Нелсън,Нельсон,נלסון,نلسون، نیوزلند,نيلسون,نیلسن، نیوزی لینڈ,नेल्सन,நெல்சன்,നെൽസൺ,ნელსონი,ネルソン,尼爾遜,넬슨', -41.2707800, 173.2840400, 'NZ', '2014-07-18', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102644, 'Napier', 'Napier', 'Ahuriri,NPE,Napier,Napier City,Napier pa New Zealand,Napier på New Zealand,Neipiras,Nejpijer,Nejpir,nei pi er,neipieo,nepia,nepiyar,nepiyara,neppiyar,nypyr,Нейпир,Нейпір,Нејпијер,نیپئر، نیوزی لینڈ,نیپیر,नेपियर,நேப்பியர்,నేపియర్,നേപ്പിയർ,ნეიპირი,ネーピア,內皮爾,네이피어', -39.4926000, 176.9123300, 'NZ', '2017-05-24', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102645, 'Murupara', 'Murupara', 'Murapara,Muripara', -38.4666700, 176.7000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102646, 'Muriwai Beach', 'Muriwai Beach', 'Muriwai', -36.8166700, 174.4500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102647, 'Moerewa', 'Moerewa', '', -35.3833300, 174.0333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102648, 'Methven', 'Methven', '', -43.6333300, 171.6500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102649, 'Maungatapere', 'Maungatapere', '', -35.7500000, 174.2000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102650, 'Mapua', 'Mapua', '', -41.2500000, 173.1000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102651, 'Manukau City', 'Manukau City', 'Manukau', -36.9928200, 174.8798600, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102652, 'Mangere', 'Mangere', '', -36.9680700, 174.7987500, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102653, 'Maketu', 'Maketu', '', -37.7666700, 176.4500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102654, 'Lower Hutt', 'Lower Hutt', 'Awakairangi,Hutt Bawah,Louehr-Khatt,Louer Hatas,Lower Hutt,Lower Hutt City,lowoheos,xia ha te,Лоуэр-Хатт,ლოუერ-ჰატი,下哈特,로워헛', -41.2166700, 174.9166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102655, 'Lincoln', 'Lincoln', 'Linkol''n,lingkeon,rinkan,Линкольн,لنکن، نیوزی لینڈ,リンカーン,링컨', -43.6500000, 172.4833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102656, 'Leeston', 'Leeston', 'Leeston Town District', -43.7666700, 172.3000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102657, 'Kingston', 'Kingston', '', -45.3333300, 168.7000000, 'NZ', '2012-06-03', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102658, 'Kerikeri', 'Kerikeri', 'KKE,kai li kai li,kelikeli,kerikeri,ケリケリ,凯里凯里,케리케리', -35.2267600, 173.9473900, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102659, 'Kelburn', 'Kelburn', '', -41.2833300, 174.7666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102660, 'Kawerau', 'Kawerau', 'Distretto di Kawerau,ضلع کاوراو', -38.1000000, 176.7000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102661, 'Kawakawa', 'Kawakawa', 'Kawakawa Town District', -35.3833300, 174.0666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102662, 'Katikati', 'Katikati', '', -37.5500000, 175.9166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102663, 'Invercargill', 'Invercargill', 'IVC,Inbhir Chargaill,Invercargill,Inverkargilas,Inverkargill,Ostium Cargillense,Waihopai,anfrkarjl,anwrkargl,aynwrkargyl,inbakagiru,inbeokagil,xin wexr kharkill,yin fu ka ji er,Інверкаргілл,Инверкаргилл,אינברקרגיל,إنفركارجل,انورکارگل,اینورکارگیل,อินเวอร์คาร์กิลล์,ინვერკარგილი,インバーカーギル,因弗卡吉尔,인버카길', -46.4000000, 168.3500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102664, 'Hastings', 'Hastings', 'Daerah Hastings,Hastings,Hastings pa New Zealand,Hastings på New Zealand,Heretaunga,Khejstings,NPE,hastynjs,heiseutingseu,heisutinguzu,Хейстингс,Хејстингс,ضلع ہیسٹنگز,هاستينجس,ჰეისტინგსი,ヘイスティングズ,헤이스팅스', -39.6381000, 176.8491800, 'NZ', '2014-01-06', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102665, 'Hamilton', 'Hamilton', 'Gamil''ton,Gorad Gamil''tan,HLZ,Hameldun,Hameldūn,Hamilton,Hamilton City,Hamilton pa New Zealand,Hamilton på New Zealand,Hamiltonas,Khamilt"n,Khamilton,Kirikiriroa,amiltan,ha mi er dun,haemilteon,haimilatana,haimiltana,hamiruton,hamyltwn,hemiltana,Гамильтон,Гамільтон,Горад Гамільтан,Хамилтон,Хамилтън,هاميلتون,هامیلتون,ہیملٹن، نیوزی لینڈ,हॅमिल्टन,हैमिल्टन,ਹੈਮਿਲਟਨ,ஆமில்டன்,ഹാമിൽടൺ,ჰამილტონი,ハミルトン,哈密尔顿,해밀턴', -37.7833300, 175.2833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102666, 'Edgecumbe', 'Edgecumbe', '', -37.9833300, 176.8333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102667, 'Dunedin', 'Dunedin', 'DUD,Dunedin,Dunidin,Otepoti,Taieri,dan ni ding,Ōtepoti,Дънидин,但尼丁', -45.8741600, 170.5036100, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102668, 'Dargaville', 'Dargaville', 'DGR,Dargavill,da ge wei er,Даргавилл,達格維爾', -35.9333300, 173.8833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102669, 'Darfield', 'Darfield', 'Horndon', -43.4833300, 172.1166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102670, 'Coromandel', 'Coromandel', 'CMV,Coromandel', -36.7611000, 175.4963400, 'NZ', '2014-09-12', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102671, 'Christchurch', 'Christchurch', 'CHC,Christchurch,Christopolis,Cristcirice,Crīstcirice,Gorad Krajstchehrch,Kraistcerca,Kraistcercas,Kraisttserts,Kraistčerčas,Kraistčērča,Krajstcherch,Krajstchjorch,Krajstchurch,Krayscoerc,Kraystcherch,Kraysçörç,Kristkirko,Otautahi,ji du cheng,ke lai si te che qi,keulaiseuteucheochi,khi rstcheirch,kiraistcerc,kra''istacarca,kraystshrsh,kuraisutochachi,qryystzrz,Ōtautahi,Κράισττσερτς,Горад Крайстчэрч,Крайстчерч,Крайстчърч,Крайстчёрч,Крајстчерч,קרייסטצרץ,كرايستشرش,کرائسٹ چرچ,کرایست‌چرچ,क्राइस्टचर्च,ক্রাইস্টচার্চ,கிறைஸ்ட்சேர்ச்,ക്രൈസ്റ്റ്‌ചർച്ച്‍,ไครสต์เชิร์ช,ခရစ်ချပ်ချ်မြို့,კრაისტჩერჩი,クライストチャーチ,克赖斯特彻奇,基督城,크라이스트처치', -43.5333300, 172.6333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102672, 'Castlepoint', 'Castlepoint', 'Kaslpoint,Каслпоинт', -40.9000000, 176.2166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102673, 'Burnham', 'Burnham', '', -43.6166700, 172.3166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102674, 'Bulls', 'Bulls', 'Bulls Town District', -40.1748700, 175.3846300, 'NZ', '2015-03-18', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102675, 'Brooklyn', 'Brooklyn', '', -41.3166700, 174.7500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102676, 'Brightwater', 'Brightwater', '', -41.3833300, 173.1166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102677, 'Auckland', 'Auckland', 'AKL,Auckland,Aucland,Aucopolis,Awklanda,Gorad Oklend,Okland,Oklandas,Oklant,Oklend,Oklenda,Tamaki-makau-rau,Tāmaki-makau-rau,akland,aklant,ao ke lan dou hui qu,awkland,awklnd,okalanda,okalenda,okeullaendeu,oklainda,okurando,yavkland,Ώκλαντ,Горад Окленд,Окланд,Окленд,Օկլենդ,אוקלנד,آوکلند,أوكلاند,ئاۋكلاند,ऑकलंड,ऑक्लैण्ड,ઓકલેન્ડ,ஆக்லன்ட்,ఆక్లాండ్,ಆಕ್ಲೆಂಡ್‌,ഓക്‌ലൻഡ്,โอกแลนด์,အော့ကလန်မြို့,ოკლენდი,オークランド,奧克蘭都會區,오클랜드', -36.8485300, 174.7634900, 'NZ', '2017-05-23', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102678, 'Amberley', 'Amberley', '', -43.1558900, 172.7297500, 'NZ', '2017-06-05', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102679, 'Ahipara', 'Ahipara', '', -35.1666700, 173.1666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102680, 'Opunake', 'Opunake', '', -39.4555600, 173.8583300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102681, 'Eltham', 'Eltham', '', -39.4291700, 174.3000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102682, 'Hawera', 'Hawera', 'hau~era,havera,ჰავერა,ハウェラ', -39.5916700, 174.2833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102683, 'Patea', 'Patea', '', -39.7583300, 174.4833300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102684, 'Foxton', 'Foxton', '', -40.4666700, 175.3000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102685, 'Levin', 'Levin', '', -40.6333300, 175.2750000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102686, 'Otaki', 'Otaki', '', -40.7583300, 175.1500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102687, 'Wairoa', 'Wairoa', '', -39.0333300, 177.3666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102688, 'Gisborne', 'Gisborne', 'East Cape,GIS,Gisborn,Gisborne,Gisborne eskualdea,Te Tai-rawhiti,Te Tai-rāwhiti,gijeubeon,gisborna,gizborni,gizubon,gyzbrn,ji si bo en,Гисборн,גיזברן,گسبورن، نیوزی لینڈ,गिस्बॉर्न,გიზბორნი,ギズボーン,吉斯伯恩,기즈번', -38.6533300, 178.0041700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102689, 'Waipawa', 'Waipawa', '', -41.4122200, 175.5152800, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102690, 'Masterton', 'Masterton', 'Distretto di Masterton,MRO,Masterton,ma si te dun,maeseuteoteon,mstrtn,Мастертон,ضلع ماسٹرٹن,مسترتن,მასტერტონი,马斯特顿,매스터턴', -40.9597200, 175.6575000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102691, 'Hokitika', 'Hokitika', 'HKK', -42.7166700, 170.9666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102692, 'Greymouth', 'Greymouth', 'GMN,Grejmut,Mawhera,Māwhera,geuleimauseu,gureimausu,Греймут,グレイマウス,그레이마우스', -42.4666700, 171.2000000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102693, 'Westport', 'Westport', 'WSZ,Westport,uesutopoto,weseuteupoteu,უესტპორტი,ウエストポート,웨스트포트', -41.7526200, 171.6037000, 'NZ', '2013-11-28', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102694, 'Bluff', 'Bluff', 'beulleopeu,burufu,ブルーフ,블러프', -46.6000000, 168.3333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102695, 'Riverton', 'Riverton', '', -46.3500000, 168.0166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102696, 'Winton', 'Winton', '', -46.1500000, 168.3333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102697, 'Tauranga', 'Tauranga', 'TRG,Tauranga,Tauranga-moana,ta''iranga,tao lang jia,taranga,taulang-ga,tauranga,taywranga,Тауранга,טאורנגה,تائورانگا,ٹورانگا,टाइरंगा,ടൗരാംഗ,ტაურანგა,タウランガ,陶朗加,타우랑가', -37.6861100, 176.1666700, 'NZ', '2012-02-14', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102698, 'Waitara', 'Waitara', 'Waitara', -39.0015800, 174.2383600, 'NZ', '2015-03-05', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102699, 'Milton', 'Milton', '', -46.1208300, 169.9694400, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102700, 'Balclutha', 'Balclutha', 'Baile Chluaidh', -46.2338900, 169.7500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102701, 'Paeroa', 'Paeroa', '', -37.3666700, 175.6666700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102702, 'Waihi', 'Waihi', '', -37.3833300, 175.8333300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102703, 'Papakura', 'Papakura', '', -37.0657300, 174.9439300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102704, 'Whakatane', 'Whakatane', 'Distretto di Whakatane,Fakatane,WHK,fakatany,hua ka ta ni,hwakatane,Факатане,ضلع وہاکاٹانے,فاکاتانی,ფაკატანე,華卡塔尼,화카타네', -37.9585500, 176.9854500, 'NZ', '2012-02-13', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102705, 'Opotiki', 'Opotiki', '', -38.0091500, 177.2870600, 'NZ', '2015-03-04', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102706, 'Thames', 'Thames', 'TMZ,Tems,Thames pa New Zealand,Thames på New Zealand,tai wu shi,Темс,泰晤士', -37.1383200, 175.5401100, 'NZ', '2014-09-28', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102707, 'Waitangi', 'Waitangi', '', -43.9535300, -176.5597300, 'NZ', '2011-11-06', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102708, 'Gore', 'Gore', 'Distretto di Gore,Gor,Gore pa New Zealand,Gore på New Zealand,go-eo,Гор,ضلع گور,고어', -46.1028200, 168.9435700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102709, 'Queenstown', 'Queenstown', 'Distretto di Queenstown,Kuinstaun,Kvinstaun,Queenstown,Queenstown pa New Zealand,Queenstown på New Zealand,ZQN,huang hou zhen,kuinzutaun,kwinseutaun,kwyynztawn  nywzylnd,Квинстаун,Квінстаун,Куинстаун,קווינסטאון,ضلع قوینزٹاؤن-لیکس,کویینزتاون، نیوزیلند,ക്വീൻസ്ടൗൺ,クイーンズタウン,皇后镇,퀸스타운', -45.0302300, 168.6627100, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102710, 'Arrowtown', 'Arrowtown', 'Ehrroutaun,Эрроутаун', -44.9383700, 168.8100700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102711, 'Oamaru', 'Oamaru', 'OAM,Oamaru,Te Oha-a-Maru,oamaru,omaru,Оамару,ოამარუ,オマルー', -45.0975800, 170.9708700, 'NZ', '2017-05-24', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102712, 'Ashburton', 'Ashburton', 'ASG,Ashberton,Ashburton pa New Zealand,Ashburton på New Zealand,Distretto di Ashburton,aesyubeoteon,ashubaton,Ашбертон,ضلع ایشبرٹن,アシュバートン,애슈버턴', -43.8983400, 171.7301100, 'NZ', '2017-04-19', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102713, 'Kaiapoi', 'Kaiapoi', '', -43.3783200, 172.6401300, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102714, 'Kaitaia', 'Kaitaia', 'KAT,Kaitaia,kai ta ya,kaitaia,Каитаиа,カイタイア,凱塔亞,카이타이아', -35.1148500, 173.2636600, 'NZ', '2012-02-20', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102715, 'Whangarei', 'Whangarei', 'Distretto di Whangarei,Fangarei,Fangarej,Vangarei,Vangarejus,Vangarėjus,WRE,Whangarei,Whangarei-terenga-paraoa,Whangārei-terenga-paraoa,fanaryy,fangarei,hwang-alei,uangarei,wang a lei,Вангареи,Фангареи,Фангареј,فانارئی,უანგარეი,ファンガレイ,旺阿雷,황아레이', -35.7316700, 174.3239100, 'NZ', '2011-02-28', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102716, 'Ruakaka', 'Ruakaka', '', -35.9081800, 174.4501900, 'NZ', '2015-03-04', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102717, 'Takanini', 'Takanini', '', -37.0482000, 174.9001900, 'NZ', '2014-07-03', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102718, 'Red Hill', 'Red Hill', '', -37.0582000, 174.9701900, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102719, 'Rothesay Bay', 'Rothesay Bay', '', -36.7260200, 174.7406400, 'NZ', '2012-09-30', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102720, 'Murrays Bay', 'Murrays Bay', '', -36.7281900, 174.7501900, 'NZ', '2016-06-22', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102721, 'Wiri', 'Wiri', '', -36.9982000, 174.8601900, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102722, 'Pakuranga', 'Pakuranga', '', -36.8833300, 174.9166700, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102723, 'Tamaki', 'Tamaki', '', -36.8882000, 174.8601900, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102724, 'Titirangi', 'Titirangi', '', -36.9375400, 174.6558400, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102725, 'Matamata', 'Matamata', 'MTA,Matamata,mtmatt,Матамата,مطماطة', -37.8106000, 175.7623700, 'NZ', '2017-02-04', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102726, 'Cambridge', 'Cambridge', 'Cambridge pa New Zealand,Cambridge på New Zealand,Kejmbridzh,Кеймбридж,کیمبرج، نیوزی لینڈ', -37.8782200, 175.4402000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102727, 'Rotorua', 'Rotorua', 'Distretto di Rotorua,ROT,Rotorua,Rotorua-nui-a-Kahu,lotolua,luo tuo lu ya,rotorua,rwtwrwa,Роторуа,רוטורואה,روتوروا,ضلع روٹوروا,როტორუა,ロトルア,罗托路亚,로토루아', -38.1387400, 176.2451600, 'NZ', '2012-04-27', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102728, 'Picton', 'Picton', 'PCN,Picton,Pikton,pigteon,pikuton,Пиктон,ピクトン,픽턴', -41.2906700, 174.0080100, 'NZ', '2017-05-24', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102729, 'Blenheim', 'Blenheim', 'BHE,Blenem,Blenheim,Blenkhejm,Waiharakeke,beulleneom,bu lun heng,burenamu,Бленем,Бленхейм,بلینہائم، نیوزی لینڈ,ブレナム,布倫亨,블레넘', -41.5160300, 173.9528000, 'NZ', '2014-07-16', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102730, 'Petone', 'Petone', '', -41.2282700, 174.8701900, 'NZ', '2010-09-22', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102731, 'Upper Hutt', 'Upper Hutt', 'Apper-Khatt,Hutt Atas,eopeoheos,Аппер-Хатт,აპერ-ჰატი,어퍼헛', -41.1382700, 175.0502000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102732, 'Taradale', 'Taradale', 'Taradale,Taradale Town District', -39.5333300, 176.8500000, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102733, 'Ngaruawahia', 'Ngaruawahia', 'Ngaruawahia,Ngāruawāhia', -37.6673800, 175.1555400, 'NZ', '2015-03-18', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102734, 'Waitakere', 'Waitakere', '', -36.9175400, 174.6577300, 'NZ', '2012-05-17', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102735, 'Kaikoura', 'Kaikoura', 'Daerah Kaikoura,Distretto di Kaikoura,Kaikoura,kaikoula,kaikoura,Каикоура,ضلع کائیکورا,კაიკურა,カイコウラ,카이코우라', -42.4074900, 173.6813200, 'NZ', '2011-08-01', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102736, 'Rosebank', 'Rosebank', 'Rosebank,Rosebank Peninsula', -36.8749500, 174.6699100, 'NZ', '2012-05-17', 159);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102598, 'Alofi', 'Alofi', 'Alofi,Alofis,Alofo,Pasjolak Alofi,a luo fei,alaphi,allopi,alophi,alopi,alwfy,arofi,xalofi,Αλόφι,Алофи,Алофі,Пасёлак Алофі,الوفی,अलोफी,അലാഫി,อาโลฟี,ალოფი,アロフィ,阿洛菲,알로피', -19.0545100, -169.9176800, 'NU', '2016-06-28', 163);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102388, 'Bagn', 'Bagn', 'Bagn', 60.8224900, 9.5520700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102389, 'Austrheim', 'Austrheim', '', 60.7774000, 4.9323000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102390, 'Aursmoen', 'Aursmoen', 'Aurskog,Urskog', 59.9276300, 11.4427500, 'NO', '2013-07-08', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102391, 'Aure', 'Aure', 'Aure,Aure kommun,Ehure,Kommun Aure,ai yu lei,aure,Ауре,Эуре,ঔরে,艾于勒', 63.2679000, 8.5291300, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102392, 'Auli', 'Auli', '', 60.0345000, 11.3604600, 'NO', '2010-10-14', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102393, 'Askim', 'Askim', 'Ashim,Askim,Askimi vald,Kommun Askim,a xi mu,asim,askima,Ашим,আস্কিম,阿希姆,아심', 59.5832600, 11.1628600, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102394, 'Asker', 'Asker', 'Asker,Asker koezseg,Asker kommuna,Asker község,Askeri vald,Askeris,Askers kommun,Kommun Asker,XGU,a si ke er,asakera,aseukeleu,asuke,Аскер,আসকের,アスケー,阿斯克尔,아스케르', 59.8333300, 10.4372100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102395, 'Ask', 'Ask', '', 60.0713100, 11.0362000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102396, 'Åsgårdstrand', 'Asgardstrand', 'Aasgaardstrand,Asgardstrand,Åsgårdstrand', 59.3488900, 10.4675000, 'NO', '2012-01-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102397, 'Aas', 'Aas', 'Aas,As,Ås', 63.0500000, 11.6500000, 'NO', '2014-04-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102398, 'Ås', 'As', 'Aas,As,Ås', 59.6647200, 10.7946500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102399, 'Åros', 'Aros', 'Aros,Åros', 59.7061000, 10.5109200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102400, 'Årnes', 'Arnes', 'Aarnes,Arnes,Årnes', 63.9611400, 10.2260100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102401, 'Årnes', 'Arnes', 'Aarnes', 60.1223700, 11.4700500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102402, 'Indre Arna', 'Indre Arna', 'Arna,Indre Arna', 60.4176800, 5.4708700, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102403, 'Arendal', 'Arendal', 'Arendal,Arendale,Arendales,Arendali vald,Arendalis,Arendals kommun,Arendalės,Gorad Arehndal,Kommun Arendal,XGD,a lun da er,alendal,arenadala,arendaru,arndal,Ārendāle,Арендал,Горад Арэндал,أرندال,ارنڈل,আরেনডাল,アーレンダール,阿伦达尔,아렌달', 58.4615100, 8.7725300, 'NO', '2017-04-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102404, 'Årdalstangen', 'Ardalstangen', 'Ardalstangen,Årdalstangen', 61.2358100, 7.7037000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102405, 'Åneby', 'Aneby', 'Aaneby,Aneby,Åneby', 60.0892600, 10.8699800, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102406, 'Andenes', 'Andenes', 'ANX,Andenes,an de nei si,andyns,Анденес,اندینس,安德內斯', 69.3142800, 16.1193900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102407, 'Åndalsnes', 'Andalsnes', 'Anbalsnes,Andalsnes,Ondalsnes,ondarusunesu,weng da er si nei si,Åndalsnes,Ондалснес,オンダルスネス,翁達爾斯內斯', 62.5674900, 7.6870900, 'NO', '2012-12-18', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102408, 'Åmot', 'Amot', '', 59.5697400, 7.9887100, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102409, 'Åmli', 'Amli', 'Amli,Amli kommun,Amli vald,Kommun Amli,Kommun Åmli,Omli,amali,ao mu li,Åmli,Åmli kommun,Åmli vald,Омли,আমলি,奧姆利', 58.7656600, 8.4839200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102410, 'Alvdal', 'Alvdal', 'Alvdal,Alvdal kommun,XJA', 62.1076600, 10.6307300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102411, 'Ålgård', 'Algard', 'Aalgaard,Algard,Ålgård', 58.7641700, 5.8525300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102412, 'Ålesund', 'Alesund', 'AES,Aalesund,Alasund,Alesund,Estrecio Anguilla,Kommun Alesund,Kommun Ålesund,Olesiundas,Olesun,Olesund,Olesunn,alesunda,ao lei song,ollesun,oresun,Álasund,Ålesund,Олесун,Олесунд,Олесунн,অলেসুন্ড,オーレスン,奥勒松,올레순', 62.4722500, 6.1549200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102413, 'Ålen', 'Alen', 'Aalen,Alen,Ålen', 62.8418500, 11.3013000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102414, 'Ål', 'Al', 'Aal,Al,Ali vald,Als kommun,Kommun Al,Kommun Ål,Ol,Uolis,ala,ao er,oru,Ål,Åli vald,Åls kommun,Ол,অল,オール,奧爾', 60.6302400, 8.5607100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102415, 'Åkrehamn', 'Akrehamn', 'Aakrehamn,Akrahamn,Akrehamn,Akrehavn,Åkrahamn,Åkrehamn', 59.2605300, 5.1868900, 'NO', '2013-03-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102416, 'Ågotnes', 'Agotnes', 'Agotnes,Ågotnes', 60.4030600, 5.0192700, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102417, 'Å i Åfjord', 'A i Afjord', 'A,A i Afjord,A i Aford,Afjord,Afjord kommun,Ao,As,Å,Å i Åfjord,Å i Åford,Åfjord,Åfjord kommun,Åo', 63.9606800, 10.2246800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102418, 'Vormedal', 'Vormedal', 'Vormedal', 59.3560700, 5.3196200, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102419, 'Tingvoll', 'Tingvoll', '', 62.9131800, 8.2052600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102420, 'Oppeid', 'Oppeid', 'Oppeid', 68.0852200, 15.6094200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102421, 'Hommersåk', 'Hommersak', 'Hommarsak,Hommarsåk,Hommersak,Hommersåk', 58.9255600, 5.8510400, 'NO', '2013-07-05', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102422, 'Vikevåg', 'Vikevag', '', 59.0975400, 5.6979000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102423, 'Årøysund', 'Aroysund', 'Aroysund,Aroysundet,Årøysund,Årøysundet', 59.1832100, 10.4574300, 'NO', '2013-07-13', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102424, 'Myre', 'Myre', 'Mjure,Мюре', 68.9140000, 15.0784300, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102425, 'Nesoddtangen', 'Nesoddtangen', '', 59.8624400, 10.6630800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102426, 'Askøy', 'Askoy', 'Askjoj,Askoy,Askoy kommun,Askoy vald,Askøy,Askøy kommun,Askøy vald,Kommun Askoy,Kommun Askøy,a si ke yu,asakaya,Аскёй,আসকায়,阿斯克于', 60.4000000, 5.1833300, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102427, 'Ørsta', 'Orsta', 'Ehrsta,HOV,Joshha,Kommun Orsta,Kommun Ørsta,Orsta,arsta,e shen ta,Ørsta,Йоща,Эрста,আর্স্টা,厄什塔', 62.1998300, 6.1290400, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102428, 'Ryggebyen', 'Ryggebyen', '', 59.3750000, 10.7500000, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102429, 'Vedavågen', 'Vedavagen', 'Veavagen,Veavågen,Vedavagen,Vedavågen', 59.2948300, 5.2187400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102430, 'Vestnes', 'Vestnes', 'Vestnes,Vestnes kommun', 62.6254400, 7.0869600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102431, 'Fjellfoten', 'Fjellfoten', '', 60.0896700, 11.4722200, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102432, 'Neskollen', 'Neskollen', '', 60.1215900, 11.3392600, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102433, 'Kinsarvik', 'Kinsarvik', 'Kinsarvik,Кинсарвик', 60.3756700, 6.7194800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102434, 'Sjølyststranda', 'Sjolyststranda', '', 59.9210500, 10.6801700, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102435, 'Skei', 'Skei', '', 61.5715000, 6.4791000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102436, 'Ytrebygda', 'Ytrebygda', '', 60.3050400, 5.2823600, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102437, 'Sandsli', 'Sandsli', '', 60.3032300, 5.2855400, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102438, 'Stjørdal', 'Stjordal', '', 63.4680300, 10.9177600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102439, 'Frosta', 'Frosta', 'Frosta,Фроста', 63.5891000, 10.7423000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102440, 'Vik', 'Vik', 'Vik,Вик', 61.0571200, 6.5780600, 'NO', '2010-10-15', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102441, 'Sogndal', 'Sogndal', 'Kommun Sogndal,SOG,Sogdal'',Sogndal,Sogndalis,sognadala,song da er,Согдаль,Согндал,সোগ্নডাল,松達爾', 61.2290800, 7.0967400, 'NO', '2017-04-27', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102442, 'Rømskog', 'Romskog', '', 59.7497000, 11.8112000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102443, 'Meieribyen', 'Meieribyen', '', 59.4745300, 11.1608300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102444, 'Kirkebygda', 'Kirkebygda', '', 59.4921000, 10.8743200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102445, 'Elvestad', 'Elvestad', '', 59.6240100, 10.9508000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102446, 'Forsand', 'Forsand', '', 58.9033000, 6.1048000, 'NO', '2010-12-12', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102447, 'Fjerdingby', 'Fjerdingby', '', 59.9262600, 11.0652700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102448, 'Kirkebygda', 'Kirkebygda', '', 59.7645200, 11.1449200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102449, 'Kjenn', 'Kjenn', '', 59.9309800, 10.9537300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102450, 'Teigebyen', 'Teigebyen', '', 60.2206900, 11.0176000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102451, 'Hurdal', 'Hurdal', '', 60.4351800, 11.0670700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102452, 'Flisa', 'Flisa', '', 60.6131800, 12.0108800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102453, 'Bergset', 'Bergset', 'Bergset,Berset', 61.8912600, 11.0776900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102454, 'Engerdal', 'Engerdal', 'Ehngerdal,Engerdal,Engerdals kommun,Kommun Engerdal,en e da er,engeradala,Энгердал,এঙ্গেরডাল,恩厄達爾', 61.7590400, 11.9593700, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102455, 'Lesja', 'Lesja', '', 62.1183700, 8.8642400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102456, 'Bismo', 'Bismo', '', 61.8840600, 8.2666500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102457, 'Ringebu', 'Ringebu', 'Ringebu,XUQ', 61.5296500, 10.1388900, 'NO', '2014-06-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102458, 'Segalstad bru', 'Segalstad bru', '', 61.2281900, 10.2225500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102459, 'Slidre', 'Slidre', '', 61.0880200, 8.9814100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102460, 'Vang', 'Vang', 'Kommun Vang,Vang,Vang i Valdres,Vangi vald,Vangs kommun,bham,fangh,wang,wng  aplnd,Ванг,فانغ,ونگ، اپلند,ভাং,旺', 61.1252900, 8.5729000, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102461, 'Vik', 'Vik', '', 60.0770600, 10.2790800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102462, 'Trøim', 'Troim', '', 60.8611400, 8.5653700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102463, 'Hol', 'Hol', 'Hol,Hols kommun,Huoles,Huolės,Khul'',Kommun Hol,hola,huo er,Хуль,হোল,霍爾', 60.6151100, 8.2939800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102464, 'Lierbyen', 'Lierbyen', '', 59.7865100, 10.2444700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102465, 'Lampeland', 'Lampeland', '', 59.8348600, 9.5791200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102466, 'Rødberg', 'Rodberg', '', 60.2672200, 8.9472100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102467, 'Hof', 'Hof', 'Hof,Hofs kommun,Khuf,Kommun Hof,huo fu,Хуф,霍夫', 59.5301300, 10.0903200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102468, 'Revetal', 'Revetal', '', 59.3724000, 10.2630800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102469, 'Andebu', 'Andebu', '', 59.3059200, 10.1765300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102470, 'Borgheim', 'Borgheim', '', 59.2262900, 10.4074500, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102471, 'Svarstad', 'Svarstad', '', 59.4016800, 9.9614400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102472, 'Sauland', 'Sauland', '', 59.6161000, 8.9375500, 'NO', '2013-05-26', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102473, 'Blakstad', 'Blakstad', '', 58.5046000, 8.6464800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102474, 'Birketveit', 'Birketveit', '', 58.4590900, 7.9169200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102475, 'Helland', 'Helland', '', 58.1934400, 7.5243100, 'NO', '2014-05-29', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102476, 'Kyrkjebygda', 'Kyrkjebygda', '', 58.6152300, 7.4139100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102477, 'Kleppe', 'Kleppe', '', 58.7742300, 5.6293600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102478, 'Hjelmelandsvågen', 'Hjelmelandsvagen', '', 59.2369200, 6.1790700, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102479, 'Sand', 'Sand', '', 59.4846800, 6.2510900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102480, 'Ydstebøhamn', 'Ydstebohamn', '', 59.0622700, 5.4024900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102481, 'Bokn', 'Bokn', '', 59.2306200, 5.4352400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102482, 'Aksdal', 'Aksdal', '', 59.4240800, 5.4455300, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102483, 'Skogsvågen', 'Skogsvagen', '', 60.2551200, 5.1016100, 'NO', '2012-03-28', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102484, 'Straume', 'Straume', '', 60.3613100, 5.1219900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102485, 'Aurlandsvangen', 'Aurlandsvangen', '', 60.9057800, 7.1870600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102486, 'Gaupne', 'Gaupne', '', 61.4047200, 7.2945800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102487, 'Askvoll', 'Askvoll', '', 61.3467300, 5.0622400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102488, 'Hornindal', 'Hornindal', '', 61.9692100, 6.5241800, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102489, 'Fiskå', 'Fiska', '', 62.1005900, 5.5578800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102490, 'Stordal', 'Stordal', 'Stordal,Stordalen', 62.3820300, 6.9862900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102491, 'Sykkylven', 'Sykkylven', '', 62.3959400, 6.5875000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102492, 'Valderøy', 'Valderoy', '', 62.5007000, 6.1347200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102493, 'Falkhytta', 'Falkhytta', '', 62.8050000, 6.8872200, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102494, 'Elnesvågen', 'Elnesvagen', '', 62.8542600, 7.1376900, 'NO', '2014-08-30', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102495, 'Bruhagen', 'Bruhagen', '', 63.0525900, 7.6341600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102496, 'Surnadal', 'Surnadal', 'Kommun Surnadal,Surnadal,Surnadals kommun,suranadala,xu na da er,Сурнадал,সুরনাডাল,敘納達爾', 62.9739700, 8.7247200, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102497, 'Liabøen', 'Liaboen', '', 63.1224900, 8.3158700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102498, 'Rissa', 'Rissa', 'Kommun Rissa,Rissa,Rissa kommun,li sa,ris''sa,rysa,Рисса,ريسا,রিস্সা,里薩', 63.5836800, 9.9598900, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102499, 'Roan', 'Roan', 'Kommun Roan,Roan,Roans kommun,Ruan,lu an,rwan,Руан,روان,魯安', 64.1726900, 10.2289800, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102500, 'Steinsdalen', 'Steinsdalen', '', 64.2987500, 10.5128400, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102501, 'Meldal', 'Meldal', '', 63.0472100, 9.7133700, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102502, 'Støren', 'Storen', 'si te lun,斯特倫', 63.0391000, 10.2850100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102503, 'Børsa', 'Borsa', '', 63.3267200, 10.0692000, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102504, 'Klæbu', 'Klaebu', 'Klaebu,Klaebu kommun,Klebu,Klæbu,Klæbu kommun,Kommun Klaebu,Kommun Klæbu,ke lai bi,klayebu,Клебу,ক্লায়েবু,克萊比', 63.2976200, 10.4826100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102505, 'Mebonden', 'Mebonden', '', 63.2303400, 11.0309900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102506, 'Leksvik', 'Leksvik', '', 63.6727400, 10.6232000, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102507, 'Namdalseid', 'Namdalseid', '', 64.2218600, 11.2231900, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102508, 'Høylandet', 'Hoylandet', '', 64.6288700, 12.3020600, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102509, 'Jøa', 'Joa', '', 64.6591000, 11.2653500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102510, 'Silvalen', 'Silvalen', '', 65.9832000, 12.2885600, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102511, 'Hattfjelldal', 'Hattfjelldal', 'Aarporte,Arbordi,Hattfjelldal,Hattfjelldals kommun,Khattf''ell''dal,Kommun Hattfjelldal,ha te fei ye er da er,hattephajeladala,Árbordi,Хаттфьелльдал,হাট্টেফজেলডাল,哈特菲耶爾達爾', 65.5973600, 13.9879100, 'NO', '2016-12-02', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102512, 'Lurøy', 'Luroy', '', 66.4188700, 12.8424800, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102513, 'Husøya', 'Husoya', '', 66.5015900, 12.0964500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102514, 'Vågaholmen', 'Vagaholmen', '', 66.7136700, 13.2871100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102515, 'Leinesfjorden', 'Leinesfjorden', '', 67.7754800, 15.0154500, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102516, 'Leknes', 'Leknes', 'LKN', 68.1474600, 13.6115100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102517, 'Tennevoll', 'Tennevoll', '', 68.7471000, 17.8062100, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102518, 'Sørreisa', 'Sorreisa', 'Arjesraisa,Orjjes-Raisa,Orjješ-Ráisa,Sorreisa,Sørreisa,Årjesraisa', 69.1452700, 18.1529200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102519, 'Brøstadbotn', 'Brostadbotn', '', 69.0887300, 17.6948900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102520, 'Hatteng', 'Hatteng', 'Hahtta,Hatteng,Hattu,Háhtta', 69.2707200, 19.9594400, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102521, 'Breivikbotn', 'Breivikbotn', 'Breidvikbotn,Breivikbotn', 70.5887700, 22.2871200, 'NO', '2014-08-19', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102522, 'Tana bru', 'Tana bru', '', 70.1990900, 28.1903900, 'NO', '2010-12-07', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102523, 'Ulsteinvik weather pws station', 'Ulsteinvik weather pws station', 'Ulsteinvik veret,Ulsteinvik weather,ulsteinvik vaeret,ulsteinvik været', 62.3433800, 5.8438500, 'NO', '2013-02-25', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102524, 'Billingstad', 'Billingstad', 'Billingstad', 59.8754800, 10.4823000, 'NO', '2013-05-24', 166);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102737, 'Sur', 'Sur', 'As Sur,As Sūr,SUH,Sour,Sur,Suras,Súr,su er,suleu,suru,swr,wlayt swr,Şūr,Σουρ,Сур,صور,صور، عمان,ولاية صور,スール,苏尔,수르', 22.5666700, 59.5288900, 'OM', '2016-01-23', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102738, 'Sohar', 'Sohar', 'Al Sohar,As Suhar,Aş Şuḩār,OHS,Sahar,Sohar,Soharas,Suhar,Suhár,Sukhar,shar,sohaleu,soharu,su ha er,wlayt shar,Şuḩār,Сухар,صحار,ولاية صحار,ソハール,苏哈尔,소하르', 24.3474500, 56.7093700, 'OM', '2017-05-24', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102739, 'Sufālat Samā’il', 'Sufalat Sama''il', 'Sama''il,Samā’il,Sifalat Samail,Sifālat Samāil,Sufalat Sama''il,Sufālat Samā’il', 23.3166700, 58.0166700, 'OM', '2014-10-01', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102740, 'Shināş', 'Shinas', 'Al Shinas,Ash Shinas,Ash Shinās,Shinas,Shināş', 24.7433300, 56.4658300, 'OM', '2012-11-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102741, 'Şalālah', 'Salalah', 'Al Kathir,As Salala,As Salalah,Aş Şalālah,SLL,Salala,Salalah,slalh,slalt,Āl Kathīr,Şalālah,Салала,صلالة,صلاله', 17.0150500, 54.0923700, 'OM', '2014-07-21', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102742, 'Şaḩam', 'Saham', 'As Saham,As Şaham,Saham,Saham Town,Sahb,Sahm,Salam,Şaḩam,Şaḩm,Салам', 24.1722200, 56.8886100, 'OM', '2014-10-29', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102743, 'Nizwá', 'Nizwa', 'Nazwah,Nizva,Nizwa,Nizwá,nzwy,Низва,نزوى', 22.9333300, 57.5333300, 'OM', '2012-01-18', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102744, 'Muscat', 'Muscat', 'Gorad Maskat,MCT,Maeskat,Mascat,Mascate,Maskat,Maskata,Maskatas,Maskate,Maskato,Maskˌat,Masqat,Masqaţ,Masqaṭ,Masquat,Maszkat,Mouskat,Muscat,Muskat,Mäskat,Múskat,ma si ka te,ma si ke te,masakata,maskarr,maskat,maskata,masqata,masukatto,msqt,museukateu,Μουσκάτ,Горад Маскат,Маскат,Масқат,Мускат,Մասկատ,מסקט,مسقط,مسقط، عمان,مۇسكات,مەسقەت,मस्कत,मस्क़त,মাস্কাট,ਮਸਕਟ,ମସ୍କଟ,மஸ்கத்,మస్కట్,മസ്കറ്റ്,มัสกัต,མི་སི་ཁ་ཁྲི།,მასკატი,መስከት,マスカット,馬斯喀特,马斯喀特,무스카트', 23.5841300, 58.4077800, 'OM', '2016-01-21', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102745, 'Khasab', 'Khasab', 'Al Khasab,Al Khasal,Al Khaşab,Al-Chasab,Al-Khasab,Chasab,Chasabas,Ehl''-Khasab,Hasab,Jasab,KHS,Khasab,Khaşab,al-Chasab,hasabeu,hasabu,khsb,wlayt khsb,Эль-Хасаб,خصب,خصب، عمان,ولاية خصب,ハサブ,하사브', 26.1799300, 56.2477400, 'OM', '2017-04-25', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102746, 'Izkī', 'Izki', 'Azki,Azkī,Izki,Izkī,Ziki', 22.9333300, 57.7666700, 'OM', '2012-04-05', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102747, '‘Ibrī', '`Ibri', 'Ibri,`Ibri,‘Ibrī', 23.2257300, 56.5157200, 'OM', '2010-08-03', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102748, 'Ibrā’', 'Ibra''', 'Bira,Ibra,Ibra'',Ibrā,Ibrā’,Sufalat Ibra'',Sufālat Ibrā’,Ибра,إبراء', 22.6905700, 58.5333700, 'OM', '2013-07-11', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102749, 'Haymā’', 'Hayma''', 'Haima,Hayma,Hayma'',Haymā,Haymā’,hyma,هيما,هيماء', 19.9593100, 56.2757500, 'OM', '2013-11-12', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102750, 'Dib Dibba', 'Dib Dibba', 'Dib Dibba,Diba Dib`,Dibba Al''-Bajakh,Dibba Dib,Dibā Dib‘,Дибба Аль-Баях', 26.1977800, 56.2577800, 'OM', '2012-01-18', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102751, 'Bidbid', 'Bidbid', 'Bidbid', 23.4078700, 58.1283000, 'OM', '2012-04-05', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102752, 'Bawshar', 'Bawshar', 'Baushar,Bawshar,bwshr,بوشر', 23.5556300, 58.3989000, 'OM', '2012-01-18', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102753, 'Barkā’', 'Barka''', 'Barka'',Barkah,Barkā’', 23.7073900, 57.8890800, 'OM', '2012-04-05', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102754, 'Bahlā’', 'Bahla''', 'Bahla'',Bahlah,Bahlā’', 22.9733900, 57.2995800, 'OM', '2012-04-05', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102755, 'Badīyah', 'Badiyah', 'Badiya,Badiyah,Badīyah', 22.4500000, 58.8000000, 'OM', '2014-10-01', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102756, 'As Suwayq', 'As Suwayq', 'As Suwaiq,As Suwayq,Suwaik,Suwayq', 23.8494400, 57.4386100, 'OM', '2012-11-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102757, 'Seeb', 'Seeb', 'Al-Sib,Al-Sīb,As Seeb al Jadidah,As Sib,As Sib al Jadidah,As Sīb,As Sīb al Jadīdah,As-Sib,Ehs-Sib,Seeb,Sib,Sybas,Szib,Szíb,Síb,alsyb,alsyb aljdydt,sibeu,xi bo,Сиб,Эс-Сиб,السيب,السيب الجديدة,السیب,锡卜,시브', 23.6702700, 58.1891100, 'OM', '2015-11-30', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102758, 'Rustaq', 'Rustaq', 'Ar Rustaq,Ar Rustāq,MNH,Qal`at Kasra,Qal‘at Kasrá,Rostak,Rustaka,Rustaq,Rustāq,alrstaq,Рустака,الرستاق', 23.3908300, 57.4244400, 'OM', '2013-08-10', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102759, 'Al Qābil', 'Al Qabil', 'Al Qabil,Al Qābil,Gabil,Qabil,Qabil al Hirth,Qābil al Hirth', 22.5710000, 58.6947200, 'OM', '2012-11-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102760, 'Al Liwā’', 'Al Liwa''', 'Al Liwa'',Al Liwā’,Hillat al Hisn,Liwa'',Liwā’,Ḩillat al Ḩisn', 24.5361100, 56.5655600, 'OM', '2012-11-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102761, 'Al Khābūrah', 'Al Khaburah', 'Al Khabura,Al Khaburah,Al Khābūra,Al Khābūrah,Al-Khabourah,Khabura,Khaburah,Khābūrah', 23.9886400, 57.0983800, 'OM', '2012-11-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102762, 'Al Buraymī', 'Al Buraymi', 'Al Buraymi,Al Buraymī,Baraimi,Bireimi,Buraimi,Burami,RMB,albrymy,البريمي', 24.2508800, 55.7931200, 'OM', '2017-04-24', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102763, 'Ādam', 'Adam', 'AOM,Adam,Ādam', 22.3756000, 57.5233400, 'OM', '2017-04-24', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102764, 'Yanqul', 'Yanqul', 'Yanqul', 23.5905100, 56.5500700, 'OM', '2012-04-06', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102765, 'Bayt al ‘Awābī', 'Bayt al `Awabi', 'Bayt al `Awabi,Bayt al ‘Awābī', 23.3032400, 57.5245900, 'OM', '2012-04-06', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102766, 'Al Mazyūnah', 'Al Mazyunah', 'Al Mazyunah,Al Mazyūnah,almzywnt,المزيونة', 17.8383600, 52.6604200, 'OM', '2017-04-08', 167);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102767, 'Zapotillo', 'Zapotillo', 'Zapotillo', 8.0053200, -81.5065300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102768, 'Zangüengas', 'Zanguengas', 'La Zanguenga,Zanguenga,Zanguengas,Zangüengas', 8.9560900, -79.8703700, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102769, 'Yaviza', 'Yaviza', 'PYV,Yavisa,Yaviza', 8.1528600, -77.6973100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102770, 'Yape', 'Yape', 'Yape', 8.0929900, -77.5997500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102771, 'Volcán', 'Volcan', 'El Hato,El Hato del Volcan,El Hato del Volcán,El Volcan,El Volcán,Hato de Volcan,Hato del Volcan,Hato del Volcán,Volcan,Volcán', 8.7729100, -82.6382300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102772, 'Vista Hermosa', 'Vista Hermosa', '', 8.5268700, -80.3748600, 'PA', '2014-07-25', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102773, 'Vista Alegre', 'Vista Alegre', 'Vista Alegre', 8.9277200, -79.7028000, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102774, 'Villa Rosario', 'Villa Rosario', 'Villa Rosario', 8.7737900, -79.8754700, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102775, 'Villa Carmen', 'Villa Carmen', 'Villa Carmen', 8.7983200, -79.8692900, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102776, 'Viguí', 'Vigui', 'Vigui,Viguí', 8.3392100, -81.4982300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102777, 'Viento Frío', 'Viento Frio', 'Viento Frio,Viento Frío', 9.5789100, -79.4116500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102778, 'Veracruz', 'Veracruz', 'Camaron,Camarón,Cameron,Camerón,Veracruz', 8.8898800, -79.6260300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102779, 'Veladero', 'Veladero', 'Veladero', 8.2313600, -81.6541700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102780, 'Vallerriquito', 'Vallerriquito', 'Valle Riquito,Vallerriquito', 7.6216300, -80.3197500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102781, 'Valle Rico', 'Valle Rico', 'Valle Rico', 7.6226200, -80.3573900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102782, 'Utirá', 'Utira', 'Utira,Utirá', 7.9720800, -81.2177700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102783, 'Ustupo', 'Ustupo', 'Concepcion,Concepción,UTU,Ustupo,Ustupo Ogobsucun,Yantupo', 9.1311200, -77.9262000, 'PA', '2013-11-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102784, 'Tucutí', 'Tucuti', 'Tucuti,Tucutí', 7.9279400, -77.9456200, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102785, 'Tubualá', 'Tubuala', 'Tubuala,Tubuala Numero Dos,Tubualá,Tubualá Número Dos', 9.5166700, -79.0333300, 'PA', '2012-01-19', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102786, 'Tres Quebradas', 'Tres Quebradas', 'Tres Quebradas', 7.8401800, -80.4074000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102787, 'Toza', 'Toza', 'Toza', 8.3454200, -80.6401200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102788, 'Tonosí', 'Tonosi', 'Tonosi,Tonosí', 7.4068400, -80.4421700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102789, 'Tolé', 'Tole', 'Tole,Tolé', 8.2398900, -81.6716800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102790, 'Tocumen', 'Tocumen', 'Tocumen,Tokumen,Токумен', 9.0893900, -79.3831000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102791, 'Tobobe', 'Tobobe', 'Tobobe', 9.1211100, -81.8247100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102792, 'Toabré', 'Toabre', 'Toabre,Toabré', 8.6513100, -80.3201700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102793, 'Tinajas', 'Tinajas', 'Tinajas,Tinajas Abajo', 8.5528100, -82.4596300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102794, 'Tijeras', 'Tijeras', 'Tijera,Tijeras', 8.4751400, -82.5605800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102795, 'Tebario', 'Tebario', 'Mariato,Tebario', 7.7136900, -80.9782500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102796, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo,Taimati,Taimatí', 8.1503600, -78.2503000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102797, 'Sortova', 'Sortova', 'Sortoua,Sortova,Sortová', 8.5464200, -82.6517000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102798, 'Sorá', 'Sora', 'Sora,Sorá', 8.6319100, -80.0088800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102799, 'Soná', 'Sona', 'Sona,Soná', 8.0122300, -81.3216300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102800, 'Sitio Prado', 'Sitio Prado', 'Sitio Praco,Sitio Prado', 8.3723300, -81.5814100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102801, 'Sioguí Arriba', 'Siogui Arriba', 'Siogui Arriba,Sioguí Arriba', 8.5386500, -82.6861900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102802, 'Sioguí Abajo', 'Siogui Abajo', 'Siogui Abajo,Sioguí Abajo', 8.4867800, -82.6653900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102803, 'Sardinilla', 'Sardinilla', 'Sardinilla', 9.2982800, -79.6395600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102804, 'San Vicente de Bique', 'San Vicente de Bique', 'San Vicente de Bique', 8.9114300, -79.6736000, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102805, 'Santo Tomás', 'Santo Tomas', 'El Tullido,Santo Tomas,Santo Tomás', 8.3895900, -82.6505800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102806, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 8.5080300, -82.7129500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102807, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 7.7461400, -80.2417300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102808, 'Santiago de Veraguas', 'Santiago de Veraguas', 'SYP,Santiago,Santiago Veraguas,Santjago de Veragvasa,Veragvaso Santjagas,santiagodebelagwaseu,sheng de ya ge-de bei la gua si,سانتیاگو دے ویراگواس,სანტიაგო-დე-ვერაგუასი,圣地亚哥-德贝拉瓜斯,산티아고데베라과스', 8.1000000, -80.9833300, 'PA', '2017-07-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102809, 'Santa Rosa Número Uno', 'Santa Rosa Numero Uno', 'Santa Rosa,Santa Rosa Numero Uno,Santa Rosa Número Uno', 8.8645900, -80.0992300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102810, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', 8.5995800, -82.6848900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102811, 'Santa Rita', 'Santa Rita', 'Santa Rita', 8.8568100, -79.8795400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102812, 'Santa Rita', 'Santa Rita', 'Santa Rita', 8.4930700, -80.1829800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102813, 'Santa Marta', 'Santa Marta', 'Santa Marta', 8.5140600, -82.6987000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102814, 'Santa María', 'Santa Maria', 'Santa Maria,Santa María', 8.1114300, -80.6658200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102815, 'Santa Isabel', 'Santa Isabel', 'Santa Isabel', 9.5371800, -79.1907900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102816, 'Santa Fé', 'Santa Fe', 'Santa Fe,Santa Fé', 8.6552500, -78.1614000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102817, 'Santa Fé', 'Santa Fe', 'Santa Fe,Santa Fé', 8.5106300, -81.0780200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102818, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 8.6426900, -82.7593900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102819, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 8.2321900, -81.9132300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102820, 'Santa Clara', 'Santa Clara', 'Santa Clara', 9.0287500, -79.7544300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102821, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', 8.7819300, -81.3279000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102822, 'Santa Ana Arriba', 'Santa Ana Arriba', 'Santa Ana Arriba,Tembladera', 7.9330000, -80.3636900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102823, 'San Pedro del Espino', 'San Pedro del Espino', 'San Pedro,San Pedro del Espino', 8.1401100, -81.0866300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102824, 'San Pablo Viejo Abajo', 'San Pablo Viejo Abajo', 'La Plaza,San Pablo Viejo Abajo', 8.4533900, -82.5017900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102825, 'San Pablo Nuevo Abajo', 'San Pablo Nuevo Abajo', 'San Pablo,San Pablo Nuevo Abajo', 8.4255800, -82.5017300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102826, 'San Miguelito', 'San Miguelito', 'San Miguel,San Miguelito', 9.0503200, -79.4706800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102827, 'San Miguel', 'San Miguel', 'San Miguel', 8.4523600, -78.9369400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102828, 'San Marcelo', 'San Marcelo', 'San Marcelo', 8.2725200, -81.1598800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102829, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 8.3056100, -82.1011400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102830, 'San Juan', 'San Juan', 'San Juan', 8.3031100, -81.0157500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102831, 'San Juan', 'San Juan', 'Cerrillos,San Jan,San Juan', 8.2772400, -81.9934500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102832, 'San José', 'San Jose', 'San Jose,San José', 8.5324000, -79.9308900, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102833, 'San José', 'San Jose', 'San Jose,San José', 8.4670400, -80.8051400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102834, 'San José', 'San Jose', 'San Jose,San José', 8.3726100, -81.4048600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102835, 'San José', 'San Jose', 'San Jose,San José', 7.6739500, -80.2443800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102836, 'San Ignacio de Tupile', 'San Ignacio de Tupile', 'San Ignacio de Tupile', 9.2890500, -78.1520600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102837, 'San Francisco', 'San Francisco', 'San Francisco', 8.2465200, -80.9747200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102838, 'San Francisco', 'San Francisco', '', 8.0666700, -81.3666700, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102839, 'San Félix', 'San Felix', 'San Felix,San Félix', 8.2906300, -81.8670200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102840, 'San Carlos', 'San Carlos', 'San Carlos', 8.5166300, -82.5090600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102841, 'San Carlos', 'San Carlos', 'San Carlos', 8.4732300, -79.9610400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102842, 'San Bartolo', 'San Bartolo', 'San Bartolo', 8.2106300, -81.2757200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102843, 'San Antonio', 'San Antonio', 'San Antonio', 8.0729000, -80.9318700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102844, 'San Andrés', 'San Andres', 'San Andreas,San Andres,San Andrés', 8.6026000, -82.7258800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102845, 'Salud', 'Salud', 'Salud,Salud Numero Uno,Salud Número Uno', 9.1984100, -80.1318600, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102846, 'Sabanitas', 'Sabanitas', 'Sabanita,Sabanitas', 9.3426900, -79.8096100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102847, 'Sabana Grande', 'Sabana Grande', 'Sabana Grande', 7.8800200, -80.6381800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102848, 'Sabana Grande', 'Sabana Grande', 'Sabana Grande', 7.8354300, -80.3649000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102849, 'Rovira Arriba', 'Rovira Arriba', 'Rovira Arriba', 8.6382200, -82.4996500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102850, 'Rodeo Viejo', 'Rodeo Viejo', 'Rodeo Viejo', 8.1120500, -81.3168400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102851, 'Valle del Risco', 'Valle del Risco', 'Risco,Valle del Risco', 9.2306400, -82.4274800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102852, 'Río Sereno', 'Rio Sereno', 'Rio Sereno,Río Sereno,Sereno', 8.8174100, -82.8573100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102853, 'Río Rita', 'Rio Rita', 'Rio Rita,Río Rita', 9.3029600, -79.7923400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102854, 'Río Hondo', 'Rio Hondo', 'Rio Hondo,Río Hondo', 7.7119200, -80.3590400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102855, 'Río Hato', 'Rio Hato', 'RIH,Rio Hato,Río Hato', 8.3794000, -80.1662100, 'PA', '2014-02-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102856, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande,Vaca del Monte', 8.6193300, -81.2883000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102857, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', 8.4267900, -80.4845700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102858, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', 7.7096800, -81.3442400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102859, 'Gatún', 'Gatun', 'Gatun,Gatún,Rio Gatun,Río Gatún', 9.2892200, -79.7720400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102860, 'Río Duque', 'Rio Duque', 'Rio Duque,Río Duque', 9.2568800, -79.6793700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102861, 'Río de Jesús', 'Rio de Jesus', 'Rio de Jesus,Río de Jesús', 7.9788200, -81.1616200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102862, 'Río Congo', 'Rio Congo', 'El Arado,Rio Congo,Río Congo', 8.9666600, -79.7610500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102863, 'Río Alejandro', 'Rio Alejandro', 'Rio Alejandro,Río Alejandro', 9.3714900, -79.7880900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102864, 'Rincón Hondo', 'Rincon Hondo', 'Rincon Hondo,Rincón Hondo', 7.8443600, -80.6039700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102865, 'Rincón', 'Rincon', 'Rincon,Rincon de Gualaca,Rincón,Rincón de Gualaca', 8.4637400, -82.2795100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102866, 'Remedios', 'Remedios', 'Remedios', 8.2243600, -81.8274700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102867, 'Arco Iris', 'Arco Iris', 'Arco Iris,Rainbow City,Rambow City,Silver City', 9.3340400, -79.8917200, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102868, 'Querévalo', 'Querevalo', 'Querebalo,Querevalo,Querevalos,Querévalo,Querévalos', 8.3717400, -82.5267000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102869, 'Quebrada de Piedra', 'Quebrada de Piedra', 'Quebrada Piedra,Quebrada de Piedra', 8.0941800, -81.6791500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102870, 'Quebrada de Oro', 'Quebrada de Oro', 'Quebrada de Oro', 8.0370600, -81.3939800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102871, 'Quebrada de Loro', 'Quebrada de Loro', 'Quebrada Loro,Quebrada de Loro', 8.3592400, -81.9272400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102872, 'Quebrada Canoa', 'Quebrada Canoa', 'Canoa,Quebrada Canoa', 8.4333300, -81.7833300, 'PA', '2012-01-19', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102873, 'Quebrada Bonita Adentro', 'Quebrada Bonita Adentro', 'Quebrada Bonita Adentro', 9.2966200, -79.7060600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102874, 'Punta Róbalo', 'Punta Robalo', 'Punta Robalo,Punta Rovalo,Punta Róbalo,Rabala,Robala,Robalo,Rovalo', 9.0363100, -82.2495200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102875, 'Punta Laurel', 'Punta Laurel', 'Punta Laurel', 9.1410000, -82.1271700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102876, 'Punta Peña', 'Punta Pena', 'Chiriquicito Numero Tres,Chiriquicito Número Tres,Punta Pena,Punta Peña,Punta de Pena,Punta de Peña', 8.9049800, -82.1849600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102877, 'Punta de Burica', 'Punta de Burica', 'Burica,Punta de Burica', 8.0333300, -82.8666700, 'PA', '2012-01-19', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102878, 'Puerto Vidal', 'Puerto Vidal', 'Puerto Vidal', 8.0483400, -81.6049900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102879, 'Puerto Pilón', 'Puerto Pilon', 'Puerto Pilon,Puerto Pilón', 9.3631600, -79.7933300, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102880, 'Puerto Obaldía', 'Puerto Obaldia', 'Obaldia,PUE,Puerto Obaldia,Puerto Obaldía', 8.6695500, -77.4155000, 'PA', '2014-08-04', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102881, 'Puerto Escondido', 'Puerto Escondido', '', 9.1933300, -80.0883300, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102882, 'Puerto Caimito', 'Puerto Caimito', 'Chorrera Landing,Port of La Chorrera,Puerto Caimito,Puerto Chorrera,Puerto de Chorrera,Puerto de la Chorrera', 8.8702200, -79.7142300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102883, 'Puerto Armuelles', 'Puerto Armuelles', 'AML,Armuelles,Puerto Armuelles,Rabo de Puerco', 8.2777500, -82.8620600, 'PA', '2013-11-01', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102884, 'Pueblo Viejo', 'Pueblo Viejo', 'Pueblo Viejo', 8.2508100, -81.6625900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102885, 'Pueblo Nuevo', 'Pueblo Nuevo', '', 8.5839900, -82.4228200, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102886, 'Púcuro', 'Pucuro', 'Pucro,Pucuro,Púcuro', 7.9736500, -77.4859800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102887, 'Progreso', 'Progreso', '', 8.4466900, -82.8385900, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102888, 'Potuga', 'Potuga', 'Potuga', 8.0631700, -80.6227100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102889, 'Potrero Grande', 'Potrero Grande', 'Potrero Grande', 8.8805100, -79.8279500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102890, 'Potrero de Caña', 'Potrero de Cana', 'Potrero de Cana,Potrero de Caña', 8.2934500, -81.6990300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102891, 'Potrerillos Arriba', 'Potrerillos Arriba', 'Potrerillos Arriba', 8.6854700, -82.4909000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102892, 'Potrerillos Abajo', 'Potrerillos Abajo', 'Potrerillos,Potrerillos Abajo,Potrreillo Abajo', 8.6397800, -82.4856000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102893, 'Portobelo', 'Portobelo', 'Portobelas,Portobello,Portobelo,Puerto Bello,bo tuo wei luo,poleutobello,porutobero,pwrtwblw,Портобело,פורטובלו,პორტობელო,ポルトベロ,波托韦洛,포르토벨로', 9.5500000, -79.6500000, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102894, 'Portobelillo', 'Portobelillo', 'Porto Bello,Portobelillo', 8.0173800, -80.5953800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102895, 'Ponuga', 'Ponuga', 'Ponuga', 7.8824500, -80.9788000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102896, 'Pocrí', 'Pocri', 'Pocri,Pocrí', 8.2581400, -80.5500000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102897, 'Pocrí', 'Pocri', 'Pocri,Pocrí,Porci', 7.6581600, -80.1211900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102898, 'Plaza de Caisán', 'Plaza de Caisan', 'Plaza de Caisan,Plaza de Caisán', 8.7367200, -82.8196800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102899, 'Playón Chico', 'Playon Chico', 'PYC,Playon Chico,Playón Chico', 9.3112800, -78.2327000, 'PA', '2013-11-24', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102900, 'Playa Leona', 'Playa Leona', 'La Playa,Playa Leon,Playa Leona,Playa Leone', 8.7838900, -79.7754700, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102901, 'Playa Chiquita', 'Playa Chiquita', 'Playa Chiquita', 9.5630600, -79.2961500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102902, 'Plan de Chorcha', 'Plan de Chorcha', 'Plan de Chorcha,Plan de Galera', 8.4616800, -82.1592400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102903, 'Pinogana', 'Pinogana', 'Pinogana', 8.1130100, -77.6885100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102904, 'Piedras Gordas', 'Piedras Gordas', 'Piedras Gordas,Piedras Goroas', 8.6377700, -80.5102400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102905, 'Piedras Gordas', 'Piedras Gordas', 'Piedras Gordas', 8.5241900, -80.9115200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102906, 'Piedra Roja', 'Piedra Roja', 'Piedra Roja', 8.5703000, -81.7466100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102907, 'Pesé', 'Pese', 'Pese,Pesé', 7.9016500, -80.6160100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102908, 'Perales', 'Perales', 'Perales', 7.7746100, -80.3249400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102909, 'Penonomé', 'Penonome', 'Penonome,Penonomé', 8.5188900, -80.3572700, 'PA', '2014-07-25', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102910, 'Peñas Chatas', 'Penas Chatas', 'Penas Chatas,Peñas Chatas', 8.0150200, -80.8036600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102911, 'Peña Blanca', 'Pena Blanca', 'Pena Blanca,Peña Blanca', 8.4617100, -81.6788000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102912, 'Peña Blanca', 'Pena Blanca', 'Pena Blanca,Peña Blanca', 7.7193100, -80.2836600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102913, 'Pedregal', 'Pedregal', 'Pedregal,Puerto Pedregal', 8.3658600, -82.4352400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102914, 'Pedasí', 'Pedasi', 'PDM,Pedasi,Pedasí', 7.5303400, -80.0269900, 'PA', '2013-11-23', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102915, 'Paya', 'Paya', 'Paya', 7.9007100, -77.3896500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102916, 'Paso Blanco', 'Paso Blanco', 'Paso Blanco', 9.1234300, -79.2483600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102917, 'Paritilla', 'Paritilla', 'Paritilla', 7.6284800, -80.1724000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102918, 'Parita', 'Parita', 'Parita', 7.9939300, -80.5209700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102919, 'París', 'Paris', 'El Sucio,Paris,París', 8.0505300, -80.5540900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102920, 'Paraíso', 'Paraiso', '', 9.0331500, -79.6274900, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102921, 'Paraíso', 'Paraiso', 'Paraiso,Paraíso', 8.6584200, -82.5862500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102922, 'Paraíso', 'Paraiso', 'Paraiso,Paraíso', 7.6851000, -80.1608200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102923, 'Panamá', 'Panama', 'Ciudad de Panama,Ciudad de Panamá,Ciutat de Panama,Ciutat de Panamà,PTY,Panama,Panama City,Panama Hiria,Panama by,Panama-Stadt,Panama-Urbo,Panama-stad,Panamurbo,Panamá,Pole tou Panama,Ziuda de Panama,Ziudá de Panamá,ba na ma cheng,panama si,panama siti,panamashiti,panamasiti,pnmh syty,shhr panama,Πόλη του Παναμά,Панама,פנמה סיטי,شهر پاناما,पनामा सिटी,ปานามาซิตี,ፓናማ ከተማ,パナマシティ,巴拿馬城,파나마 시,파나마시티', 8.9936000, -79.5197300, 'PA', '2017-06-22', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102924, 'Palo Grande', 'Palo Grande', 'Palo Grande', 8.3465400, -82.6058900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102925, 'Palmira Centro', 'Palmira Centro', 'Palmira Centro,Palmiras Centro', 8.7395600, -82.4522800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102926, 'Palmira', 'Palmira', 'Culebra,Palmira', 9.5435900, -79.2194600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102927, 'Palmira', 'Palmira', '', 8.7340100, -82.4588700, 'PA', '2015-01-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102928, 'Palmira', 'Palmira', 'Palmira', 7.6634700, -80.3572800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102929, 'Palmas Bellas', 'Palmas Bellas', 'Lagarto,Palmas Bellas', 9.2200200, -80.0836900, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102930, 'Palenque', 'Palenque', 'Palenque', 9.5697000, -79.3634100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102931, 'Paja de Sombrero', 'Paja de Sombrero', 'Paja de Sombrero', 8.6833500, -82.3191100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102932, 'Pacora', 'Pacora', 'Pacora', 9.0793700, -79.2899700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102933, 'Olá', 'Ola', 'Ola,Olá', 8.4180700, -80.6512300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102934, 'Ocú', 'Ocu', 'Ocu,Ocú', 7.9405200, -80.7793600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102935, 'Nuevo Vigía', 'Nuevo Vigia', 'Nuevo Vigia,Nuevo Vigía,Vigia', 9.2426300, -79.6075600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102936, 'Nuevo San Juan', 'Nuevo San Juan', 'Nuevo San Juan', 9.2220500, -79.6660200, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102937, 'Nuevo Emperador', 'Nuevo Emperador', 'Nuevo Emperador,Paja', 9.0027300, -79.7314100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102938, 'Nuevo Chagres', 'Nuevo Chagres', 'Nuevo Chagres', 9.2288800, -80.0815500, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102939, 'Nuevo Arraiján', 'Nuevo Arraijan', 'Nuevo Arraijan,Nuevo Arraiján', 8.9245300, -79.7200400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102940, 'Nueva Providencia', 'Nueva Providencia', 'New Providence,Nueva Providencia', 9.2633300, -79.8155600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102941, 'Nueva Gorgona', 'Nueva Gorgona', 'Gorgona,Nueva Gorgona', 8.5500000, -79.8754700, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102942, 'Nueva Arenosa', 'Nueva Arenosa', 'Nueva Arenosa', 8.8694400, -79.9947200, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102943, 'Nuestro Amo', 'Nuestro Amo', 'Nuestro Amo', 8.4448500, -80.5893400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102944, 'Nuario', 'Nuario', 'Nuario', 7.5304700, -80.3269200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102945, 'Nombre de Dios', 'Nombre de Dios', 'Nombre de Dios', 9.5793700, -79.4710900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102946, 'Natá', 'Nata', 'Nata,Natá', 8.3320900, -80.5196900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102947, 'Narganá', 'Nargana', 'NGN,Nargana,Narganá,Rio Diablo,Rio Diablo Village,Río Diablo,Yandup', 9.4439400, -78.5866600, 'PA', '2014-08-04', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102948, 'Mulatupo', 'Mulatupo', 'Gallinazo,Isla Gallinazo,MPP,Mulatupo,Mulatupo Sasardi,Mulatupo Sasardí', 8.9467200, -77.7508000, 'PA', '2013-12-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102949, 'Mortí', 'Morti', 'Boca de Morti,Boca de Mortí,Iquinina,Morti,Morti Abajo,Mortinak,Mortí,Mortí Abajo', 8.8419100, -77.9795900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102950, 'Montijo', 'Montijo', 'Montijo', 7.9885800, -81.0564300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102951, 'Monte Lirio', 'Monte Lirio', 'Monte Lirio', 8.7893500, -82.8286500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102952, 'La Montañuela', 'La Montanuela', 'La Montanuela,La Montañuela,Montanuela,Montañuela', 8.0248700, -80.8632500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102953, 'Monjarás', 'Monjaras', 'Monjaras,Monjarás', 8.3694200, -80.8666700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102954, 'Monagrillo', 'Monagrillo', 'Monagrillo', 7.9817900, -80.4376400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102955, 'Mogollón', 'Mogollon', 'Mogollon,Mogollón', 7.6426100, -80.4595000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102956, 'Miramar', 'Miramar', 'Miramar', 9.5701700, -79.3388100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102957, 'Miramar', 'Miramar', 'Miramar', 8.9948200, -82.2414700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102958, 'Miguel de La Borda', 'Miguel de La Borda', 'Donoso,Miguel de La Borda', 9.1454400, -80.3012400, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102959, 'Metetí', 'Meteti', 'Meteti,Metety,Metetí', 8.4990900, -77.9789700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102960, 'Mendoza', 'Mendoza', 'Mendoza', 9.0147100, -79.8507300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102961, 'Mata del Nance', 'Mata del Nance', 'Mata del Nance', 8.4505600, -82.4005700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102962, 'María Chiquita', 'Maria Chiquita', 'Maria Chiquita,María Chiquita', 9.4399100, -79.7545500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102963, 'Mariabé', 'Mariabe', 'Mariabe,Mariabé', 7.5826500, -80.0661000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102964, 'Las Margaritas', 'Las Margaritas', 'Las Margaritas,Margarita,Margarita-Escondido', 9.3260300, -79.8902800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102965, 'Maraca', 'Maraca', 'Maraca', 8.3730200, -81.7274100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102966, 'Macaracas', 'Macaracas', 'Macaracas', 7.7316800, -80.5536400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102967, 'Los Valles', 'Los Valles', 'Los Valles', 8.4485100, -81.1988600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102968, 'Los Santos', 'Los Santos', 'Los Santos', 7.9333300, -80.4166700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102969, 'Los Pozos', 'Los Pozos', 'Los Pozo,Los Pozos', 7.7830000, -80.6452400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102970, 'Los Olivos', 'Los Olivos', 'Los Olivos', 7.9158900, -80.4888400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102971, 'Los Naranjos', 'Los Naranjos', 'Los Naranjos', 8.7921000, -82.4466500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102972, 'Los Lotes', 'Los Lotes', 'Los Lotes', 9.1242500, -79.2892900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102973, 'Los Llanitos', 'Los Llanitos', 'Los Llanitos', 8.5978700, -80.0950300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102974, 'Los Higos', 'Los Higos', 'Los Higos', 8.2038400, -80.8666700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102975, 'Los Corotúes', 'Los Corotues', 'Los Corotues,Los Corotúes', 8.4201400, -81.1042100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102976, 'Los Cerros de Paja', 'Los Cerros de Paja', 'Cerro de Paja,Los Cerros de Paja', 7.7182100, -80.6727300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102977, 'Los Cerritos', 'Los Cerritos', 'Cerrillos,Cerritos,Los Cerritos', 7.7974600, -80.6107100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102978, 'Los Castillos', 'Los Castillos', 'Los Castillos', 8.0232600, -81.1194100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102979, 'Los Castillos', 'Los Castillos', 'Los Castillos', 7.9856500, -80.6188600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102980, 'Los Canelos', 'Los Canelos', 'Los Canelos', 8.1172200, -80.7076900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102981, 'Los Boquerones', 'Los Boquerones', 'Boquerones,Los Boquerones', 8.0791200, -80.8549400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102982, 'Los Asientos', 'Los Asientos', 'Los Asientos', 7.5165600, -80.1352100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102983, 'Los Ángeles', 'Los Angeles', 'Los Angeles,Los Ángeles', 8.5227100, -82.1999700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102984, 'Los Ángeles', 'Los Angeles', 'Los Angeles,Los Ángeles', 7.8842200, -80.3577200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102985, 'Los Anastacios', 'Los Anastacios', 'Los Anastacios', 8.5302700, -82.4229500, 'PA', '2015-05-16', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102986, 'Los Algarrobos', 'Los Algarrobos', 'Algarrabo,Algarrobo,Los Algarrobos', 8.4960100, -82.4241700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102987, 'Los Algarrobos', 'Los Algarrobos', 'Los Algarrobos', 8.1089800, -81.0135500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102988, 'Lolá', 'Lola', 'Lola,Lolá', 8.0932600, -81.4716300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102989, 'Buabidi', 'Buabidi', 'Buabidi,Buabti,Buäbti,Llano Tugri,Llano Tugrí', 8.4745700, -81.6982700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102990, 'Llano Ñopo', 'Llano Nopo', 'Llano Nopa,Llano Nopo,Llano Ñopa,Llano Ñopo', 8.4199600, -81.6186500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102991, 'Llano Marín', 'Llano Marin', 'Llano Marin,Llano Marín', 8.4769600, -80.3249900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102992, 'Llano Largo', 'Llano Largo', 'Llano Largo', 7.9060700, -80.4256100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102993, 'Llano Grande', 'Llano Grande', 'Llano Grande', 8.6381700, -80.4384800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102994, 'Llano Grande', 'Llano Grande', 'Llano Grande', 8.4505300, -80.2267600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102995, 'Llano Grande', 'Llano Grande', 'Llano Grade,Llano Grande', 8.0747300, -81.1362600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102996, 'Llano Grande', 'Llano Grande', 'Llano Grande', 7.9740600, -80.7110300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102997, 'Llano de Piedra', 'Llano de Piedra', 'Llano de Piedra', 7.6597200, -80.5634700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102998, 'Llano de La Cruz', 'Llano de La Cruz', 'Juan La Cruz,Juan de la Cruz,Llano de La Cruz', 7.9517800, -80.6423900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(102999, 'Llano Bonito', 'Llano Bonito', 'Llano Bonito', 7.9763700, -80.4164600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103000, 'Llano Abajo', 'Llano Abajo', 'Llano Abajo,Llano Bajo', 7.7859800, -80.4106000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103001, 'Limones', 'Limones', 'Limones,Puerto Limones,Puerto Limónes', 8.1000700, -82.8667900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103002, 'Limón de Tijeras', 'Limon de Tijeras', 'Limon de Tijeras,Limón de Tijeras', 7.8175600, -80.9133500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103003, 'Lídice', 'Lidice', 'Lidice,Lídice', 8.7486900, -79.9097400, 'PA', '2015-08-06', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103004, 'Leones Arriba', 'Leones Arriba', 'Leones Arriba', 7.7659000, -80.8451500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103005, 'Leones Arriba', 'Leones Arriba', 'Leones Arriba', 7.7530000, -81.1212400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103006, 'La Yeguada', 'La Yeguada', 'La Yeguada', 8.4306000, -80.8575200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103007, 'La Victoria', 'La Victoria', '', 8.4500000, -82.2500000, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103008, 'La Tronosa', 'La Tronosa', 'La Tronosa', 7.4360900, -80.5869800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103009, 'La Trinidad', 'La Trinidad', 'La Trinidad,La Trinidad Obispo,Trinidad', 7.9145700, -80.7033200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103010, 'La Tiza', 'La Tiza', 'La Tiza', 7.7511000, -80.2921600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103011, 'Las Uvas', 'Las Uvas', 'Las Uvas', 8.4593700, -80.0007500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103012, 'Las Trancas', 'Las Trancas', 'Las Trancas', 7.7340000, -80.3738400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103013, 'Las Tablas', 'Las Tablas', 'Las Tablas', 7.7647200, -80.2748300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103014, 'Las Sabanas', 'Las Sabanas', 'Las Sabanas', 8.5814100, -80.6797800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103015, 'Las Palmitas', 'Las Palmitas', 'Las Palmitas', 7.7652300, -80.2935000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103016, 'Las Palmas', 'Las Palmas', 'Las Palmas', 8.1356400, -81.4567400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103017, 'Las Palmas', 'Las Palmas', 'Las Palmas', 7.6788100, -80.4957000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103018, 'Las Ollas Arriba', 'Las Ollas Arriba', 'Las Ollas,Las Ollas Arriba,Las Ollas Arribas,Ollas Arriba', 8.8067500, -79.9131100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103019, 'La Soledad', 'La Soledad', 'La Soledad', 7.8789900, -81.2761100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103020, 'Las Minas', 'Las Minas', 'Las Minas', 8.6411800, -80.3943200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103021, 'Las Minas', 'Las Minas', 'Las Minas', 7.7958100, -80.7457000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103022, 'Las Marias', 'Las Marias', 'Las Marias', 8.8880900, -80.2189300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103023, 'Las Margaritas', 'Las Margaritas', 'La Margarita,Las Margaritas', 9.1842600, -79.0873000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103024, 'Las Lomas', 'Las Lomas', 'Las Lomas', 8.5081800, -80.3738100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103025, 'Las Lomas', 'Las Lomas', 'Las Lomas,Llano del Medio', 8.4292700, -82.3874300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103026, 'Lajas de Tolé', 'Lajas de Tole', 'Laja de Tole,Lajas de Tole,Lajas de Tolé,Las Lajas de Tole,Las Lajas de Tolé', 8.1699400, -81.6965400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103027, 'Las Lajas', 'Las Lajas', 'Las Lajas', 8.5496300, -79.9352100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103028, 'Las Lajas', 'Las Lajas', 'Lajas,Las Lajas', 8.2418400, -81.8693100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103029, 'Las Huacas del Quije', 'Las Huacas del Quije', 'Huacas del Quije,Las Huacas,Las Huacas del Quije', 8.4670200, -80.7508900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103030, 'Las Huacas', 'Las Huacas', 'La Huacas,Las Huacas', 7.9016700, -81.1405600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103031, 'Las Guabas', 'Las Guabas', 'Las Guaba,Las Guabas', 7.9094900, -80.8070600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103032, 'Las Guabas', 'Las Guabas', 'Guabas,Las Guabas', 7.8122600, -80.4960100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103033, 'Las Cumbres', 'Las Cumbres', 'Las Cumbres', 9.0891600, -79.5280900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103034, 'Las Cruces', 'Las Cruces', 'Las Cruces', 7.8228500, -80.4300300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103035, 'Las Colinas', 'Las Colinas', '', 8.5500000, -80.0833300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103036, 'Las Cabras', 'Las Cabras', 'Las Cabras', 7.8756100, -80.5491200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103037, 'La Raya de Santa María', 'La Raya de Santa Maria', 'La Raya de Santa Maria,La Raya de Santa María,La Victoria Numero Uno,La Victoria Número Uno', 8.1642900, -80.8214300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103038, 'La Raya de Calobre', 'La Raya de Calobre', 'La Raya de Calobre,Raya de Calobre', 8.2163000, -80.8272900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103039, 'La Punta', 'La Punta', 'Gobernadora,La Punta', 7.5570200, -81.1910900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103040, 'Pitaloza Arriba', 'Pitaloza Arriba', 'La Pitaloza Arriba,Pitaloza Arriba', 7.6421600, -80.6678800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103041, 'La Pintada', 'La Pintada', 'La Pintada', 8.5929900, -80.4434900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103042, 'La Peña', 'La Pena', 'La Pena,La Peña', 8.1278400, -81.0269300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103043, 'La Pasera', 'La Pasera', 'La Pasera,Llano del Hato', 7.7975700, -80.3034200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103044, 'La Palma', 'La Palma', 'La Palma,PLP', 8.4060800, -78.1396400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103045, 'La Palma', 'La Palma', '', 7.7166700, -80.3833300, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103046, 'La Palma', 'La Palma', 'La Palma', 7.6886400, -80.1964700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103047, 'La Mitra', 'La Mitra', 'La Mitra', 8.8409100, -79.7864800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103048, 'La Miel', 'La Miel', 'La Miel', 7.5560700, -80.3323400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103049, 'La Mesa', 'La Mesa', 'La Mesa', 9.1730800, -79.2740100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103050, 'La Mesa', 'La Mesa', 'La Mesa,Las Mesa', 8.1470700, -81.1811400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103051, 'La Mesa', 'La Mesa', 'La Mesa', 7.6567000, -80.6179400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103052, 'La Loma', 'La Loma', 'La Loma', 8.1666700, -80.6374200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103053, 'La Loma', 'La Loma', 'La Loma', 7.4370800, -80.8911800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103054, 'La Laja', 'La Laja', 'La Laja', 7.7310200, -80.2529800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103055, 'La Laguna', 'La Laguna', 'La Laguna', 9.0440400, -79.8421500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103056, 'La Laguna', 'La Laguna', 'La Laguna', 8.6040900, -80.0471600, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103057, 'La Laguna', 'La Laguna', 'La Laguna', 8.3388200, -80.7294900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103058, 'Lajas Adentro', 'Lajas Adentro', 'Lajas Adentro,Las Adentro', 8.2498100, -81.8777900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103059, 'Lajamina', 'Lajamina', 'Lajamina', 7.5858700, -80.1321200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103060, 'La Herradura', 'La Herradura', 'La Herradura', 8.8484800, -79.8040400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103061, 'La Guinea', 'La Guinea', 'Guinea,La Guinea', 8.3425000, -78.9343000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103062, 'Lagarterita', 'Lagarterita', 'Amador,Lagarterita,Lagarterito', 9.0794400, -79.9138900, 'PA', '2016-12-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103063, 'La Garceana', 'La Garceana', 'La Garceana', 7.9370800, -81.0164300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103064, 'La Estrella', 'La Estrella', 'La Estrella', 8.5157200, -82.6721200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103065, 'La Espigadilla', 'La Espigadilla', 'La Espigadilla', 7.8838900, -80.3903900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103066, 'La Esperanza', 'La Esperanza', 'La Esperanza', 8.4034400, -82.7919700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103067, 'La Esmeralda', 'La Esmeralda', 'Esmeralda,Hafafa,La Esmeralda,Mafafa', 8.2645100, -78.9280100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103068, 'La Ermita', 'La Ermita', 'Ermita,Hermita,La Ermita', 8.4562200, -80.0683500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103069, 'La Ensenada', 'La Ensenada', 'La Ensenada', 8.3622700, -78.8493800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103070, 'La Enea', 'La Enea', 'La Enea', 7.8333300, -80.2741700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103071, 'La Encantada', 'La Encantada', 'Alcarreto,La Encantada', 9.0870300, -80.1915800, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103072, 'La Concepción', 'La Concepcion', 'Concepcion,Concepción,La Concepcion,La Concepción', 8.5121200, -82.6185800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103073, 'La Colorada', 'La Colorada', 'La Colorada', 8.0131900, -80.9859000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103074, 'La Colorada', 'La Colorada', 'La Colorada', 7.8236200, -80.5555200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103075, 'La Chorrera', 'La Chorrera', 'Chorrera,La Chorrera', 8.8802800, -79.7833300, 'PA', '2016-12-06', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103076, 'La Carrillo', 'La Carrillo', 'La Carrillo,Los Carrillos', 7.9695300, -80.8837700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103077, 'Cabuya', 'Cabuya', 'Cabuya,La Cabuya', 7.9826700, -80.7643500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103078, 'La Cabima', 'La Cabima', 'La Cabima,La Cabina', 9.1186500, -79.5366000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103079, 'Boca del Guásimo', 'Boca del Guasimo', 'Boca del Guasimo,Boca del Guásimo,La Boca del Guasimo,La Boca del Guásimo', 9.0505300, -80.3287800, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103080, 'La Arena', 'La Arena', 'La Arena', 7.9676600, -80.4652300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103081, 'La Arena', 'La Arena', 'La Arena', 7.7503300, -80.5928300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103082, 'Juay', 'Juay', 'Juay,Las Mareas', 8.2841500, -81.9463300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103083, 'Juan Díaz', 'Juan Diaz', 'Juan Diaz,Juan Díaz', 8.4624000, -80.2828000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103084, 'Jaramillo Arriba', 'Jaramillo Arriba', 'Jaramillo Arriba', 8.7977100, -82.4243100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103085, 'Jaqué', 'Jaque', 'JQE,Jague,Jagué,Jaque,Jaqué,Jarque', 7.5182600, -78.1634300, 'PA', '2013-05-11', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103086, 'Horconcitos', 'Horconcitos', 'Horconcitos,Horoncitos', 8.3114200, -82.1510200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103087, 'Hato Pilón', 'Hato Pilon', 'Hato Pilon,Hato Pilón', 8.3981300, -81.8652500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103088, 'Hato Juli', 'Hato Juli', 'Hato Juli,Los Juli,Los Julí', 8.3498100, -81.8450300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103089, 'Hato Jobo', 'Hato Jobo', 'Hato Jobo', 8.3919800, -81.8862000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103090, 'Hato Culantro', 'Hato Culantro', 'Hato Culantro', 8.4684700, -81.8571400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103091, 'Hato Corotú', 'Hato Corotu', 'Hato Corotu,Hato Corotú', 8.3232700, -81.9727800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103092, 'Hato Chami', 'Hato Chami', 'Hato Chame,Hato Chami', 8.4428100, -81.7719600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103093, 'Guzman', 'Guzman', 'Guzman', 8.5196900, -80.5840500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103094, 'Las Guías Abajo', 'Las Guias Abajo', 'Guias Abajo,Guías Abajo,Las Guias Abajo,Las Guías Abajo', 8.1945100, -80.7549400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103095, 'Guayabito', 'Guayabito', 'Guayabito', 8.5482800, -80.0135000, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103096, 'Guayabal', 'Guayabal', 'Guayabal', 8.6219300, -82.5793500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103097, 'Guarumal', 'Guarumal', 'Guarumal', 8.3452300, -82.5320500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103098, 'Guarumal', 'Guarumal', 'Guarumal', 7.7940400, -81.2590400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103099, 'Guararé Arriba', 'Guarare Arriba', 'Guarare Arriba,Guararé Arriba', 7.8002300, -80.3598300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103100, 'Guararé', 'Guarare', 'Guarare,Guararé', 7.8153100, -80.2834500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103101, 'Gualaca', 'Gualaca', 'Gualaca', 8.5300600, -82.2995900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103102, 'Guadalupe', 'Guadalupe', 'Guadalupe,La Laguna', 8.8545200, -79.8140800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103103, 'Guaca Arriba', 'Guaca Arriba', 'Guaca Arriba', 8.5373300, -82.4928100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103104, 'Guabito', 'Guabito', 'Guabito', 9.4896800, -82.6127900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103105, 'Guabal', 'Guabal', 'Guabal', 8.5746600, -82.5373000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103106, 'Gonzalo Vásquez', 'Gonzalo Vasquez', 'Gonzalo Vasquez,Gonzalo Vásquez', 8.4146600, -78.4561200, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103107, 'Gómez', 'Gomez', 'Gomez,Gomez Arriba,Gómez,Gómez Arriba', 8.5608500, -82.7414200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103108, 'Gobea', 'Gobea', 'Gobea,Guabilla', 9.1591400, -80.2506400, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103109, 'Gatú', 'Gatu', 'Gatu,Gatuncillo,Gatuncito,Gatú', 8.5375400, -80.9510900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103110, 'Garachiné', 'Garachine', 'GHE,Garachine,Garachiné', 8.0668400, -78.3643600, 'PA', '2013-12-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103111, 'Flores', 'Flores', 'Flores', 7.4815700, -80.4069500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103112, 'Finca Corredor', 'Finca Corredor', 'Corredor,Finca Corredor', 8.3427000, -82.8736400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103113, 'Finca Blanco', 'Finca Blanco', 'Blanco,Finca Blanco,Finca Blanco Numero Uno,Finca Blanco Número Uno', 8.3797900, -82.8738500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103114, 'Escobal', 'Escobal', 'Escobal', 9.1437300, -79.9643900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103115, 'El Toro', 'El Toro', 'El Toro', 7.7511000, -80.8694300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103116, 'El Tejar', 'El Tejar', 'El Tejar', 8.4297300, -82.5729400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103117, 'Sesteadero', 'Sesteadero', 'El Sesteadero,Sesteadero', 7.7388500, -80.2485400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103118, 'El Roble', 'El Roble', 'El Roble', 8.1685000, -80.6589700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103119, 'El Rincón', 'El Rincon', 'El Rincon,El Rincón', 8.1842200, -81.4333300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103120, 'El Rincón', 'El Rincon', 'El Rincon,El Rincón', 8.1192300, -80.6170700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103121, 'El Retiro', 'El Retiro', 'El Retiro', 8.4801400, -80.1542600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103122, 'Quinteño', 'Quinteno', 'El Quiteno,El Quiteño,Quinteno,Quinteño,Quiteno', 8.4710200, -82.3935200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103123, 'El Progreso', 'El Progreso', '', 9.2666700, -79.1166700, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103124, 'El Prado', 'El Prado', 'El Prado', 8.2373200, -81.5042200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103125, 'El Potrero', 'El Potrero', 'El Potrero', 8.5214600, -80.5168100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103126, 'El Potrero', 'El Potrero', 'El Potrero', 8.3769200, -80.7943400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103127, 'El Porvenir', 'El Porvenir', 'El Porvenir,PVE', 9.5527600, -78.9523000, 'PA', '2013-11-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103128, 'El Piro', 'El Piro', 'El Piro,El Piro Numero Uno,El Piro Número Uno', 8.2094200, -81.5270600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103129, 'El Pilón', 'El Pilon', 'El Pilon,El Pilón,Pilon,Pilón', 7.9541300, -81.0763700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103130, 'El Picador', 'El Picador', 'El Picador', 8.3780300, -81.2562100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103131, 'El Peñón', 'El Penon', 'El Penon,El Peñón', 8.3500000, -80.9762000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103132, 'El Pedregoso', 'El Pedregoso', 'El Pedregoso,Pedregoso', 7.9364200, -80.6380700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103133, 'El Pedregoso', 'El Pedregoso', 'El Pedregoso,Pedregoso', 7.6917300, -80.3279300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103134, 'El Pantano', 'El Pantano', 'El Pantano', 8.5375500, -81.0694100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103135, 'El Pájaro', 'El Pajaro', 'El Pajaro,El Pájaro', 7.9534200, -81.1215400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103136, 'El Pájaro', 'El Pajaro', 'El Pajaro,El Pájaro,Pajaro', 7.9433800, -80.5701000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103137, 'El Nancito', 'El Nancito', 'El Nancito,Nancito', 8.2381100, -81.7321800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103138, 'El Muñoz', 'El Munoz', 'El Munoz,El Muñoz', 7.6758200, -80.3213000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103139, 'El María', 'El Maria', 'El Maria,El María', 8.0301500, -81.4478600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103140, 'El Marañón', 'El Maranon', 'El Maranon,El Marañón,Maranon,Marañon', 8.0358200, -81.2148900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103141, 'El Manantial', 'El Manantial', 'El Manantial', 7.7824500, -80.2471300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103142, 'Salto Dupí', 'Salto Dupi', 'El Machin,El Machín,Salto Dupi,Salto Dupi Numero Uno,Salto Dupí,Salto Dupí Número Uno', 8.3514600, -81.8865900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103143, 'El Macano', 'El Macano', 'El Macano', 7.6848900, -80.4030900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103144, 'El Limón', 'El Limon', 'El Limon,El Limón', 8.0580500, -80.7728900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103145, 'El Líbano', 'El Libano', 'El Libano,El Líbano', 8.6168500, -79.8348300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103146, 'El Higo', 'El Higo', 'El Higo', 8.4473100, -80.0360300, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103147, 'El Hato', 'El Hato', 'El Hato', 7.7931600, -80.3826700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103148, 'El Guásimo', 'El Guasimo', 'El Guasimo,El Guásimo', 7.8064000, -80.5299100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103149, 'El Guabo', 'El Guabo', 'El Guabo', 9.0784200, -80.0831600, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103150, 'El Giral', 'El Giral', 'El Giral,Giral,Jiral', 9.2450900, -79.6926600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103151, 'El Espino de Santa Rosa', 'El Espino de Santa Rosa', 'El Espino,El Espino de Santa Rosa,Espino', 8.0928600, -80.8238000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103152, 'El Espino Amarillo', 'El Espino Amarillo', 'El Espino Amarillo,Espino Amarillo', 7.6760500, -80.4389600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103153, 'El Espino', 'El Espino', 'El Espino', 8.8379500, -79.8492500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103154, 'El Espino', 'El Espino', 'El Espino,Espino', 8.4776100, -80.0128000, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103155, 'El Espinal', 'El Espinal', 'El Espinal,Espinal', 7.8666700, -80.3193600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103156, 'Entradero', 'Entradero', 'El Entradero,El Entradero Marica,Entradero', 8.5688000, -80.2074300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103157, 'El Ejido', 'El Ejido', 'Ejido,El Egido,El Ejido', 7.9163400, -80.3868600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103158, 'El Cristo', 'El Cristo', 'El Cristo', 8.2507100, -80.6209300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103159, 'El Cortezo', 'El Cortezo', 'Cortezo,El Cortezo', 8.3455600, -80.5872100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103160, 'El Cortezo', 'El Cortezo', 'Corteza,Cortezo,El Cortezo', 7.4266100, -80.6331100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103161, 'El Copé', 'El Cope', 'Cope,Copé,El Cope,El Copé', 8.6203600, -80.5843300, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103162, 'El Copé', 'El Cope', 'El Cope,El Copé', 8.4377300, -80.6792900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103163, 'El Coco', 'El Coco', 'Coco,El Coco', 8.8700900, -79.8041500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103164, 'El Coco', 'El Coco', 'El Coco', 8.3971600, -80.3500000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103165, 'El Coclá', 'El Cocla', 'El Cocla,El Coclá', 8.3214300, -80.9206900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103166, 'El Cocal', 'El Cocal', 'Cacal,El Cocal', 7.7369700, -80.2798000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103167, 'El Chirú', 'El Chiru', 'Chiru,Chirú,El Chiru,El Chirú', 8.3987600, -80.1872100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103168, 'El Cedro', 'El Cedro', 'El Cedro', 7.6856500, -80.6592700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103169, 'El Carate', 'El Carate', 'Carate,El Carate', 7.7312400, -80.2969100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103170, 'El Capurí', 'El Capuri', 'El Capuri,El Capurí', 7.7257100, -80.6434900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103171, 'El Caño', 'El Cano', 'El Cano,El Caño', 8.4019500, -80.5179100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103172, 'El Cañafístulo', 'El Canafistulo', 'El Canafistulo,El Cañafístulo', 7.6176800, -80.2332200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103173, 'El Calabacito', 'El Calabacito', 'El Calabacito', 7.7184300, -80.5975700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103174, 'El Cacao', 'El Cacao', 'El Cacao', 8.7613400, -80.0129400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103175, 'El Cacao', 'El Cacao', 'Cacao,El Cacao', 7.4457000, -80.4093800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103176, 'Bongo Arriba', 'Bongo Arriba', 'Bongo Arriba,El Bongo', 8.5888100, -82.6225300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103177, 'El Bebedero', 'El Bebedero', 'Bebedero,El Bebedero', 7.4097200, -80.4564100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103178, 'El Barrito', 'El Barrito', 'El Barrito', 7.9605900, -80.9480100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103179, 'El Barrero', 'El Barrero', 'El Barrero', 7.9334400, -80.5135800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103180, 'Cerro Banco', 'Cerro Banco', 'Cerro Banco,El Banco', 8.4579700, -82.0308100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103181, 'El Bale', 'El Bale', 'El Bale', 8.3574500, -81.3609900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103182, 'El Alto', 'El Alto', 'El Alto', 8.5119100, -81.0364600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103183, 'Dos Ríos Abajo', 'Dos Rios Abajo', 'Dos Rios Abajo,Dos Ríos Abajo', 8.5283400, -82.3867700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103184, 'Dolega District', 'Dolega District', 'Dolega', 8.5666700, -82.4140700, 'PA', '2014-08-01', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103185, 'Divalá', 'Divala', 'Davala,Davalá,Divala,Divalá', 8.4106600, -82.7133200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103186, 'David', 'David', 'Ciudad de David,DAV,David,Davida,Davidas,Dehvid,San Jose de David,San José de David,dabiddo,dabideu,dai wei,davidi,dwyd,Давид,Дэвид,דויד,ڈیوڈ، چیرکی,დავიდი,ダビッド,戴维,다비드', 8.4272900, -82.4308500, 'PA', '2010-05-11', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103187, 'Kusapín', 'Kusapin', 'Cusapin,Cusapín,Kusapin,Kusapín', 9.1782300, -81.8848400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103188, 'Cuipo', 'Cuipo', 'Cuipo', 9.0689600, -80.0487800, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103189, 'Cucunatí', 'Cucunati', 'Cucunati,Cucunatí', 8.5750800, -78.2567100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103190, 'Cuango', 'Cuango', 'Cuango', 9.5666700, -79.3166700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103191, 'Corozal', 'Corozal', 'Coroza,Corozal', 8.0771200, -81.4399000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103192, 'Cordillera', 'Cordillera', 'Cordillera,Cordillera Abajo', 8.7068300, -82.6032700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103193, 'Colón', 'Colon', 'Aspinwall,Ciudad de Colon,Ciudad de Colón,Colon,Colón,Kolon,Kolona,Kolonas,ONX,gao lang,ke long,kollon,koron,kwlwn  panama,qwlwn,Колон,Կոլոն,קולון,کولون، پاناما,კოლონი,コロン,告郎,科隆,콜론', 9.3545100, -79.9001100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103194, 'Coclé del Norte', 'Cocle del Norte', 'Cocle del Norte,Coclé del Norte', 9.0668500, -80.5694800, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103195, 'Coclecito', 'Coclecito', 'Coclecito', 8.8081700, -80.5560700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103196, 'Coclé', 'Cocle', 'Cocle,Coclé', 8.4560100, -80.4289900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103197, 'Cochea Abajo', 'Cochea Abajo', 'Cochea Abajo', 8.5051200, -82.3587800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103198, 'Cirí de Los Sotos', 'Ciri de Los Sotos', 'Ciri de Los Sotos,Ciricito Los Sotos,Ciricito de los Sotos,Cirí de Los Sotos', 8.9720600, -80.0920900, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103199, 'Churuquita Grande', 'Churuquita Grande', 'Churiquita Grande,Churuquita Grande', 8.5944900, -80.2718200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103200, 'Churuquita Chiquita', 'Churuquita Chiquita', 'Chiquita,Churiquita Chiquita,Churuquita,Churuquita Chiquita', 8.5755500, -80.2716100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103201, 'Chupampa', 'Chupampa', 'Chupampa', 8.0762000, -80.7765600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103202, 'Chupá', 'Chupa', 'Chupa,Chupá', 7.8000000, -80.5745100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103203, 'Chumical', 'Chumical', 'Chumical,Chumical Arriba', 7.8448200, -80.7262700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103204, 'Chitré', 'Chitre', 'CTD,Chitre,Chitré', 7.9608200, -80.4294400, 'PA', '2017-02-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103205, 'Chiriquí Grande', 'Chiriqui Grande', 'Chiriqui Grande,Chiriquí Grande', 8.9455700, -82.1176900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103206, 'Chiriquí', 'Chiriqui', 'Chiriqui,Chiriquí', 8.3929100, -82.3199300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103207, 'Chimán', 'Chiman', 'Chiman,Chimon,Chimán,Chimón', 8.6912500, -78.6357000, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103208, 'Chilibre', 'Chilibre', 'Chilibre', 9.1509300, -79.6209800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103209, 'Chiguirí Arriba', 'Chiguiri Arriba', 'Chiguiri Arriba,Chiguirí Arriba,Chiguri Arriba', 8.6718700, -80.1897500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103210, 'Chigoré', 'Chigore', 'Chicore,Chigore,Chigoré', 8.5303500, -80.3511700, 'PA', '2014-07-25', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103211, 'Chichica', 'Chichica', 'Chichica', 8.3588500, -81.6658200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103212, 'Chepo', 'Chepo', 'Chepo', 9.1701900, -79.1008300, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103213, 'Chepillo', 'Chepillo', 'Chepillo', 8.9513100, -79.1314600, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103214, 'Chepigana', 'Chepigana', 'Chepigana', 8.2862800, -78.0518500, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103215, 'Changuinola', 'Changuinola', 'CHX,Changuinola', 9.4300000, -82.5200000, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103216, 'Chame', 'Chame', 'Chame', 8.5775300, -79.8859500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103217, 'Chacarero', 'Chacarero', 'Chacarero', 8.4889900, -82.5983400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103218, 'Cerro Viejo', 'Cerro Viejo', 'Cerro Viejo', 8.2534900, -81.5765800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103219, 'Cerro Venado', 'Cerro Venado', 'Cerro Venado', 8.2281800, -81.5742100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103220, 'Cerro Punta', 'Cerro Punta', 'Cerro Punta', 8.8496800, -82.5726100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103221, 'Cerro Plata', 'Cerro Plata', 'Cerro Plata', 8.4730800, -81.5381200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103222, 'Cerro de Plata', 'Cerro de Plata', 'Cerro Plata,Cerro de Plata', 8.2877700, -81.3684400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103223, 'Cerro Largo', 'Cerro Largo', 'Cerro Largo', 7.8337700, -80.8316800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103224, 'Cerro Iglesias', 'Cerro Iglesias', 'Cerro Iglesia,Cerro Iglesias', 8.2852300, -81.7980400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103225, 'Cerro Iglesias', 'Cerro Iglesias', 'Cerro Iglesia,Cerro Iglesias', 8.3189200, -81.5642700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103226, 'Cerro Caña', 'Cerro Cana', 'Cerro Cana,Cerro Caña', 8.3517400, -81.6105000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103227, 'Cerro Cama', 'Cerro Cama', 'Cerro Cama', 9.0280200, -79.9074400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103228, 'Cerro Azul', 'Cerro Azul', 'Cerro Azul', 9.1573500, -79.4209700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103229, 'Cermeño', 'Cermeno', 'Cermeno,Cermeño', 8.7408200, -79.8529900, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103230, 'Cauchero', 'Cauchero', 'Cauchero,Punta de Bongo', 9.1491500, -82.2663500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103231, 'Cativá', 'Cativa', 'Cativa,Catival,Cativá', 9.3621800, -79.8323200, 'PA', '2016-08-16', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103232, 'Cascabel', 'Cascabel', 'Cascabel', 8.5268000, -81.8740300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103233, 'Cartí Sugdup', 'Carti Sugdup', 'Carti Sugdup,Carti Suitupo,Carti Sutupo,Cartí Sugdup,Cartí Suitupo,Cartí Sutupo,Suctupo', 9.4646000, -78.9593100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103234, 'Capira', 'Capira', 'Capira', 8.7563600, -79.8799600, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103235, 'Capellanía', 'Capellania', 'Capellania,Capellanía,Las Guabas', 8.2985800, -80.5548000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103236, 'Canto del Llano', 'Canto del Llano', 'Canto del Llano', 8.1247200, -80.9637400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103237, 'Kankintú', 'Kankintu', 'Canquintu,Canquintú,Kankintu,Kankintú', 8.8433900, -81.8149600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103238, 'Cañita', 'Canita', 'Canita,Cañita,Tumaganti,Tumagantí', 9.2156600, -78.8897300, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103239, 'Cañazas', 'Canazas', 'Canazas,Cañazas', 8.3200400, -81.2115200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103240, 'Cañaveral', 'Canaveral', 'Canaveral,Cañaveral', 8.5170000, -80.4291600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103241, 'Cañas Gordas', 'Canas Gordas', 'Canas Gordas,Cañas Gordas', 8.7430900, -82.9127500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103242, 'Cañas', 'Canas', 'Canas,Cañas', 7.4471300, -80.2648000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103243, 'Cambutal', 'Cambutal', 'Cambutal', 7.2653400, -80.4910500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103244, 'Camarón Arriba', 'Camaron Arriba', 'Camaron Arriba,Camarón Arriba,Cienaquita', 8.3832400, -81.9934500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103245, 'Calzada Larga', 'Calzada Larga', 'Calzada Larga,Casa Larga', 9.1727200, -79.5621200, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103246, 'Calovébora', 'Calovebora', 'Calovebora,Calovébora', 8.7828200, -81.2079000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103247, 'Calobre', 'Calobre', 'Calobre,Colobre', 8.3188600, -80.8406700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103248, 'Calidonia', 'Calidonia', 'Calidonia', 7.9591700, -81.3897200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103249, 'Caldera', 'Caldera', 'Caldera', 8.6490700, -82.3805800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103250, 'Calabacito', 'Calabacito', 'Calabacito', 8.2481700, -81.0818700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103251, 'Caimito', 'Caimito', 'Caimito', 8.8114300, -79.9473800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103252, 'Caimitillo', 'Caimitillo', 'Caimitillo', 9.1555900, -79.5397400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103253, 'Cacique', 'Cacique', 'Cacique', 9.6089800, -79.6166700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103254, 'Cabuya', 'Cabuya', 'Cabuya', 8.5747200, -79.9271400, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103255, 'Cabuya', 'Cabuya', 'Cabuya', 8.5439600, -80.1631100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103256, 'Cabuya', 'Cabuya', 'Cabuya,Cabuyao', 8.0313800, -80.6322700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103257, 'Cabra Número Uno', 'Cabra Numero Uno', 'Cabra,Cabra Numero Uno,Cabra Número Uno', 9.1086300, -79.3369400, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103258, 'Caballero', 'Caballero', 'Caballero', 8.5434300, -80.1976900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103259, 'Bugaba', 'Bugaba', 'Bugaba', 8.4825500, -82.6199100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103260, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 8.6314600, -79.9477500, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103261, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires', 8.4138400, -81.4844000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103262, 'Buena Vista', 'Buena Vista', 'Buena Vista', 9.2735600, -79.6955100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103263, 'Brujas', 'Brujas', 'Brujas,Punta Bruja', 8.5853600, -78.5300800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103264, 'Breñón', 'Brenon', 'Brenon,Breñón', 8.6249100, -82.8127700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103265, 'Boró', 'Boro', 'Boro,Boró', 8.1693300, -81.3007100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103266, 'Boquete', 'Boquete', 'Bajo Boquete,Boquete', 8.7802400, -82.4413600, 'PA', '2015-01-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103267, 'Boquerón', 'Boqueron', 'Boqueron,Boquerón', 8.5051000, -82.5702500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103268, 'Boquerón', 'Boqueron', 'Boqueron,Boquerón', 8.2441400, -80.8589700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103269, 'Bocas del Toro', 'Bocas del Toro', 'BOC,Bocas Town,Bocas del Toro,Bokas del Toras,Bokas-del''-Toro,Gorad Bokas-dehl''-Tora,bo ka si de er tuo luo,bokaseudeltolo,Бокас-дель-Торо,Горад Бокас-дэль-Тора,بوکاس ٹاؤن، بوکاس دیل تورو,ბოკას-დელ-ტორო,博卡斯德尔托罗,보카스델토로', 9.3403100, -82.2420400, 'PA', '2014-08-19', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103270, 'Soloy', 'Soloy', 'Boca de Soloy,Soloy', 8.4897300, -82.0713600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103271, 'Boca de Parita', 'Boca de Parita', 'Boca de Parita', 8.0079600, -80.4532000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103272, 'Boca de Río Indio', 'Boca de Rio Indio', 'Boca de Rio Indio,Boca de Río Indio,Boca del Rio Indio,Boca del Río Indio,Chila,Chilar,La Boca de Rio Indio,La Boca de Río Indio,Rio Indio,Río Indio', 9.1829300, -80.1906300, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103273, 'Boca del Río Chiriquí', 'Boca del Rio Chiriqui', 'Boca de Chiriqui,Boca del Rio Chiriqui,Boca del Río Chiriquí,Perla Paraiso', 8.8451700, -81.5726500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103274, 'Boca del Monte', 'Boca del Monte', 'Boca de Monte,Boca del Monte', 8.3529600, -82.1137900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103275, 'Boca de Cupé', 'Boca de Cupe', 'Boca de Cupe,Boca de Cupé', 8.0300300, -77.5897800, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103276, 'Boca Chica', 'Boca Chica', 'Boca Chica', 8.2191100, -82.2159200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103277, 'Bisvalles', 'Bisvalles', 'Bisvalles,Bisvaya', 8.1829800, -81.2209200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103278, 'Bisira', 'Bisira', 'Arteda,Bisira,Bisiria', 8.8955300, -81.8535200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103279, 'Bijagual', 'Bijagual', 'Bijagual', 8.5032100, -82.3340400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103280, 'Bella Vista', 'Bella Vista', '', 7.7500000, -80.2333300, 'PA', '2006-01-17', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103281, 'Bejuco', 'Bejuco', 'Bejuco', 8.6003700, -79.8898800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103282, 'Bayano', 'Bayano', 'Bayano', 7.6301400, -80.3820100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103283, 'Isla Bastimentos', 'Isla Bastimentos', 'Isla Provision,Isla Provisión,Isla de Bastimentos,Old Bank Island', 9.3000000, -82.1333300, 'PA', '2008-09-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103284, 'Bastimentos', 'Bastimentos', 'Bastimentos', 9.3470700, -82.2088000, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103285, 'Barranco Colorado', 'Barranco Colorado', 'Barranco Colorado', 8.3893700, -80.6354600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103286, 'Barranco', 'Barranco', 'Barranco,Riverside', 9.5198400, -82.7042400, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103287, 'Barnizal', 'Barnizal', 'Barnizal', 8.4046000, -80.7776500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103288, 'Bajos de Güera', 'Bajos de Guera', 'Bajo de Guera,Bajo de Güera,Bajos de Guera,Bajos de Güera,El Bajo de Guera,El Bajo de Güera', 7.5436000, -80.6250500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103289, 'Bajo Corral', 'Bajo Corral', 'Bajo Corral', 7.6046300, -80.2601600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103290, 'Bajo Boquete', 'Bajo Boquete', 'Bajo Boquete', 8.7705800, -82.4330600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103291, 'Bahía Honda', 'Bahia Honda', 'Bahia Honda,Bahía Honda', 7.7051700, -80.4534200, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103292, 'Bahía Azul', 'Bahia Azul', 'Bahia Azul,Bahía Azul', 9.1350000, -81.8883900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103293, 'Bágala', 'Bagala', 'Bagala,Bágala', 8.4639900, -82.5261700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103294, 'Ave María', 'Ave Maria', 'Ave Maria,Ave María', 7.3248100, -80.4536100, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103295, 'Atalaya', 'Atalaya', 'Atalaya', 8.0421300, -80.9252800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103296, 'Aserrío de Gariché', 'Aserrio de Gariche', 'Aserria,Aserrio,Aserrio de Gariche,Aserrío,Aserrío de Gariché,San Antonio', 8.4825700, -82.7908600, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103297, 'Arraiján', 'Arraijan', 'Arraijan,Arraiján', 8.9518700, -79.6601100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103298, 'Arosemena', 'Arosemena', 'Arosemena,Quebrada Grande', 8.9709100, -79.9664100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103299, 'Arenosa', 'Arenosa', 'Arenosa', 9.0397800, -79.9512800, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103300, 'Arenas', 'Arenas', 'Arenas', 7.3686500, -80.8626800, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103301, 'Antón', 'Anton', 'Anton,Antón', 8.3973300, -80.2606300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103302, 'Ancón', 'Ancon', 'Ancon,Ancón', 8.9601500, -79.5514000, 'PA', '2014-11-29', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103303, 'Altos de Güera', 'Altos de Guera', 'Alto de Guera,Alto de Güera,Altos de Guera,Altos de Güera,Los Altos', 7.5300200, -80.6210900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103304, 'Alto del Espino', 'Alto del Espino', 'Alto del Espino', 8.8421300, -79.8455100, 'PA', '2017-01-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103305, 'Alto de La Estancia', 'Alto de La Estancia', 'Alto de La Estancia,Cabecera de Sofre', 8.5879200, -80.1844300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103306, 'Alto Caballero', 'Alto Caballero', 'Alto Caballero', 8.2898900, -81.6734900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103307, 'Alto Boquete', 'Alto Boquete', 'Alto Boquete', 8.7345800, -82.4321300, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103308, 'Almirante', 'Almirante', 'Almirante', 9.3009100, -82.4018000, 'PA', '2014-06-30', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103309, 'Alcalde Díaz', 'Alcalde Diaz', 'Alcalde Diaz,Alcalde Díaz,Alcaldediaz,Alcaldedíaz,Penoncito,Peñoncito', 9.1201600, -79.5564100, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103310, 'Alanje', 'Alanje', 'Alanje', 8.3979100, -82.5594700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103311, 'Ailigandí', 'Ailigandi', 'AIL,Ailigandi,Ailigandí,Ailingandi,Ailingandí', 9.2281000, -78.0277800, 'PA', '2013-11-24', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103312, 'Aguadulce', 'Aguadulce', 'Aguadulce', 8.2418300, -80.5460900, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103313, 'Agua de Salud', 'Agua de Salud', 'Agua de Salud', 8.5048600, -81.4639700, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103314, 'Agua Buena', 'Agua Buena', 'Agua Buena', 7.8346500, -80.3940500, 'PA', '2015-07-03', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103315, 'Achutupo', 'Achutupo', 'ACU,Achutupo,Achutupo Numero 2,Achutupo Numero Dos,Achutupo Número 2,Achutupo Número Dos', 9.1982700, -77.9872900, 'PA', '2017-06-07', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103316, 'Achiote', 'Achiote', 'Achiote', 9.2112100, -80.0133800, 'PA', '2015-06-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103317, 'Pásiga', 'Pasiga', 'Pasiga,Pásiga,Rio Pasiga,Río Pasiga', 8.9364700, -78.9091700, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103318, 'Jingurudó', 'Jingurudo', 'Jingurudo,Jingurudó,Jungurudo,Jungurudó', 7.8796200, -78.0768900, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103319, 'Santa Rita Arriba', 'Santa Rita Arriba', 'Santa Rita Arriba', 9.3303200, -79.7936300, 'PA', '2015-04-08', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103320, 'Lajas Blancas', 'Lajas Blancas', 'Lajas Blancas', 8.4148200, -77.8116100, 'PA', '2015-04-09', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103321, 'Unión Chocó', 'Union Choco', '', 8.0840400, -77.5350700, 'PA', '2013-08-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103322, 'Villa Lourdes', 'Villa Lourdes', 'Villa Lourdes', 7.8114100, -80.4702900, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103323, 'Cedro Arriba', 'Cedro Arriba', 'Cedro Arriba', 7.7809700, -80.5305700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103324, 'San Juan Bautista', 'San Juan Bautista', 'San Juan Bautista', 7.9609900, -80.4128300, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103325, 'Oria Arriba', 'Oria Arriba', 'Oria Arriba', 7.5050500, -80.2056700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103326, 'Tortí', 'Torti', 'Torti,Tortí', 8.9213200, -78.4054600, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103327, 'Barriales', 'Barriales', 'Barriales', 8.5840200, -78.3882200, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103328, 'Platanilla', 'Platanilla', 'Platanilla', 8.8280000, -78.3843500, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103329, 'Setegantí', 'Seteganti', 'Seteganti,Setegantí', 8.2938100, -78.1002500, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103330, 'Camogantí', 'Camoganti', 'Camoganti,Camogantí', 8.0388000, -77.8904100, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103331, 'Corozal', 'Corozal', 'Corozal', 8.1978200, -77.6003700, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103332, 'Agua Fría Número Uno', 'Agua Fria Numero Uno', 'Agua Fria Numero Uno,Agua Fría Número Uno', 8.8583900, -78.1975000, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103333, 'Bayamón', 'Bayamon', 'Bayamon,Bayamón', 7.9681700, -78.2164800, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103334, 'Unión Santeña', 'Union Santena', 'Union Santena,Unión Santeña', 8.8352500, -78.6510400, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103335, 'Contadora', 'Contadora', 'Contadora', 8.6248300, -79.0374800, 'PA', '2015-04-10', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103336, 'Norteño', 'Norteno', 'Norteno,Norteño', 9.0030800, -82.3147600, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103337, 'Sieyic', 'Sieyic', 'Sieyic', 9.3832300, -82.6520600, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103338, 'Quebrada del Rosario', 'Quebrada del Rosario', 'Quebrada del Rosario', 7.7123800, -80.7422200, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103339, 'Rámbala', 'Rambala', 'Rambala,Rámbala', 8.9204600, -82.1806000, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103340, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo', 8.8849400, -82.2006400, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103341, 'Valle de La Mina', 'Valle de La Mina', 'Valle de La Mina', 8.6642700, -82.2319600, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103342, 'Quebrada Tula', 'Quebrada Tula', 'Quebrada Tula', 8.8403700, -81.9964500, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103343, 'Boca de Balsa', 'Boca de Balsa', 'Boca de Balsa', 8.5258900, -82.0339400, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103344, 'Cuoronte', 'Cuoronte', 'Cuoronte', 8.6745700, -81.7858600, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103345, 'Oma', 'Oma', 'Oma', 8.3501900, -81.8017700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103346, 'Cabecera de Cerro Puerco', 'Cabecera de Cerro Puerco', 'Cabecera de Cerro Puerco', 8.3185600, -81.7595100, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103347, 'El Porvenir', 'El Porvenir', 'El Porvenir', 8.2291900, -81.8327800, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103348, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 8.2312300, -81.8261300, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103349, 'El Puerto', 'El Puerto', 'El Puerto', 8.2123800, -81.8079700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103350, 'Mirones', 'Mirones', 'Mirones', 8.5575700, -81.7257400, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103351, 'Bajo Solis', 'Bajo Solis', 'Bajo Solis', 8.3475100, -81.5291200, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103352, 'Bella Vista', 'Bella Vista', 'Bella Vista', 8.2061700, -81.6212300, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103353, 'Cerro Pelado', 'Cerro Pelado', 'Cerro Pelado', 8.1624700, -81.5391700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103354, 'Lajero Arriba', 'Lajero Arriba', 'Lajero Arriba', 8.2906000, -81.7704700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103355, 'Loma Yuca', 'Loma Yuca', 'Loma Yuca', 8.7181700, -81.4049200, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103356, 'San Juan de Dios', 'San Juan de Dios', 'San Juan de Dios', 8.5511900, -80.2262300, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103357, 'Río Luís', 'Rio Luis', 'Rio Luis,Río Luís', 8.6836100, -81.2160800, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103358, 'Güibale', 'Guibale', 'Guibale,Güibale', 8.5122500, -81.3625700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103359, 'Paredón Arriba', 'Paredon Arriba', 'Paredon Arriba,Paredón Arriba', 8.4597700, -81.1959200, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103360, 'Guayabito', 'Guayabito', 'Guayabito', 8.5394900, -81.4822500, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103361, 'Alto de Jesús', 'Alto de Jesus', 'Alto de Jesus,Alto de Jesús', 8.2732500, -81.4827700, 'PA', '2015-07-05', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103362, 'Ciricito Abajo', 'Ciricito Abajo', 'Ciricito Abajo', 8.7995000, -80.0774700, 'PA', '2017-01-06', 171);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103363, 'Zorritos', 'Zorritos', 'Puerto Villar,Zorritos', -3.6804600, -80.6781900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103364, 'Yurimaguas', 'Yurimaguas', 'Jurimaguas,YMS,Yurimaguas,Yurimahuas,Юримагуас', -5.9018100, -76.1223400, 'PE', '2014-07-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103365, 'Yuracyacu', 'Yuracyacu', '', -5.9313900, -77.2266700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103366, 'Yungay', 'Yungay', 'Yungay', -9.1383300, -77.7436100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103367, 'Yungar', 'Yungar', '', -9.3777800, -77.5930600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103368, 'Yorongos', 'Yorongos', '', -6.1397200, -77.1438900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103369, 'Yauya', 'Yauya', '', -8.9833300, -77.3000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103370, 'Yanas', 'Yanas', '', -9.7141700, -76.7482200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103371, 'Yanama', 'Yanama', '', -9.0333300, -77.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103372, 'Yanac', 'Yanac', '', -8.6166700, -77.8666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103373, 'Yambrasbamba', 'Yambrasbamba', '', -5.7500000, -77.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103374, 'Yamango', 'Yamango', 'Yamange,Yamango', -5.1775000, -79.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103375, 'Vista Alegre', 'Vista Alegre', '', -6.1513900, -77.3005600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103376, 'Virú', 'Viru', 'Viru,Virú', -8.4155400, -78.7520100, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103377, 'Vice', 'Vice', '', -5.4166700, -80.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103378, 'Uticyacu', 'Uticyacu', 'Uticyacu,Utigiaco', -6.6333300, -78.8000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103379, 'Usquil', 'Usquil', '', -7.8166700, -78.4166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103380, 'Ucuncha', 'Ucuncha', 'Ucuncha,Ucunche', -7.1333300, -77.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103381, 'Uco', 'Uco', 'Uca,Uco', -9.1883900, -76.9276700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103382, 'Uchiza', 'Uchiza', 'Uchisa,Uchiza', -8.4591700, -76.4633300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103383, 'Tunal', 'Tunal', 'Tunal,Tunal Hacienda', -5.2091700, -79.6752800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103384, 'Tumbes', 'Tumbes', 'Gorad Tumbes,TBP,Tumbes,Tumbesas,Tumbez,Tumpis,Tumpiurbo,tong bei si,to~unbesu,tumbeseu,twmbs,twmbys  pyrw,Горад Тумбес,Тумбес,تومبس,تومبیس، پیرو,ტუმბესი,トゥンベス,通贝斯,툼베스', -3.5669400, -80.4515300, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103385, 'Túcume', 'Tucume', 'Tucume,Tucumo,Túcume', -6.5063700, -79.8572500, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103386, 'Trujillo', 'Trujillo', 'Gorad Trukhil''jo,TRU,Troxillo,Truchiljas,Truhillu,Trujillo,Trukhijo,Trukhil''o,Trukhiljo,Turgalium,te lu xi e,teuluhiyo,toruhiryo,trwhyw,trwkhyw,trwkhyw  byrw,Горад Трухільё,Трухильо,Трухилјо,Трухійо,טרוחיו,تروخيو، بيرو,تروخیو,ტრუხილიო,トルヒーリョ,特鲁希略,트루히요', -8.1159900, -79.0299800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103387, 'Trompeteros', 'Trompeteros', 'Corrientes Trompeteros,TDP,Trompeteros,Villa Trompeteros', -3.8141700, -75.0583300, 'PE', '2013-11-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103388, 'Trinidad', 'Trinidad', '', -7.3500000, -79.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103389, 'Tres Unidos', 'Tres Unidos', '', -6.8069400, -76.2294400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103390, 'Tournavista', 'Tournavista', 'Bosque Nacional de Iparia,Pueblo de Tournavista', -8.9294700, -74.7077100, 'PE', '2014-07-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103391, 'Totora', 'Totora', '', -6.4925000, -77.4730600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103392, 'Tocmoche', 'Tocmoche', 'Tocmache,Tocmoche', -6.4125000, -79.3619400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103393, 'Tocache', 'Tocache', 'San Juan de Tocache,Tocache', -8.1877000, -76.5204600, 'PE', '2014-07-04', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103394, 'Tingo María', 'Tingo Maria', 'TGI,Tingo Maria,Tingo María,Tinku Mariya,ting ge ma li ya,tyngw marya,تینگو ماریا,廷戈瑪麗亞', -9.2961600, -75.9983100, 'PE', '2016-01-25', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103395, 'Tingo', 'Tingo', '', -6.3716700, -77.9119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103396, 'Tinco', 'Tinco', '', -9.2697200, -77.6794400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103397, 'Ticapampa', 'Ticapampa', '', -9.7500000, -77.4500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103398, 'Tembladera', 'Tembladera', '', -7.2666700, -79.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103399, 'Tayabamba', 'Tayabamba', 'Tayabamba', -8.2769400, -77.2963900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103400, 'Taurija', 'Taurija', '', -8.3086100, -77.4219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103401, 'Tauca', 'Tauca', '', -8.4833300, -78.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103402, 'Tarica', 'Tarica', '', -9.3936100, -77.5747200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103403, 'Tarapoto', 'Tarapoto', 'San Martin,TPP,Tarapotas,Tarapoto,Taraputu,ta la bo tuo,tarapwtw,Тарапото,تاراپوتو,ტარაპოტო,塔拉波托', -6.5013900, -76.3655600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103404, 'Tantamayo', 'Tantamayo', '', -9.3911400, -76.7233100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103405, 'Tambo Grande', 'Tambo Grande', '', -4.9269400, -80.3447200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103406, 'Tamarindo', 'Tamarindo', '', -4.8772200, -80.9730600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103407, 'Tamanco', 'Tamanco', 'Tamanco,Tamanco Viejo,Viejo Tamanco', -5.8500000, -74.3166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103408, 'Talara', 'Talara', 'Puerto Talara,TYL,Talara,ta la la,talara,tallala,tarara,Талара,تالارا,ტალარა,タララ,塔拉拉,탈라라', -4.5772200, -81.2719400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103409, 'Tacabamba', 'Tacabamba', '', -6.3833300, -78.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103410, 'Tabalosos', 'Tabalosos', '', -6.3500000, -76.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103411, 'Tabaconas', 'Tabaconas', 'Tabaconas,Tabacones', -5.3147200, -79.2827800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103412, 'Suyo', 'Suyo', '', -4.5139200, -80.0031300, 'PE', '2016-06-22', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103413, 'Sullana', 'Sullana', 'Sul''jana,Sulana,Sullana,su ya na,suliana,swyana,Сульяна,Суљана,سویانا,სულიანა,蘇亞納', -4.9038900, -80.6852800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103414, 'Sucre', 'Sucre', 'Sucre,Villa Sucre', -8.9500000, -77.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103415, 'Sucre', 'Sucre', 'Huauco,Sucre', -6.9333300, -78.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103416, 'Succha', 'Succha', '', -9.8333300, -77.6500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103417, 'Sorochuco', 'Sorochuco', '', -6.9108300, -78.2550000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103418, 'Soritor', 'Soritor', '', -6.1391700, -77.1038900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103419, 'Sondorillo', 'Sondorillo', '', -5.3391700, -79.4302800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103420, 'Sondor', 'Sondor', '', -5.3122200, -79.4063900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103421, 'Soloco', 'Soloco', '', -6.2622200, -77.7444400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103422, 'Sojo', 'Sojo', 'Sojo,Sojo Hacienda,Sujo', -4.9008300, -80.8158300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103423, 'Socota', 'Socota', '', -6.3000000, -78.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103424, 'Sitabamba', 'Sitabamba', 'Citabamba,Sitabamba', -8.0333300, -77.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103425, 'Sinsicap', 'Sinsicap', '', -7.8333300, -78.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103426, 'Singa', 'Singa', 'Singa,Singo', -9.3874500, -76.8126200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103427, 'Sinchao', 'Sinchao', 'Sinchao,Sinchao Hacienda', -5.4166700, -80.6666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103428, 'Simbal', 'Simbal', '', -7.9763900, -78.8136000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103429, 'Sillapata', 'Sillapata', '', -9.7579400, -76.7744300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103430, 'Sihuas', 'Sihuas', 'Sihuas', -8.5666700, -77.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103431, 'Shupluy', 'Shupluy', 'Shupluy,Suplay', -9.2177800, -77.6941700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103432, 'Shunqui', 'Shunqui', '', -9.7338400, -76.7865100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103433, 'Shucushuyacu', 'Shucushuyacu', 'Shucshuyacu,Shucushuyacu', -6.0166700, -75.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103434, 'Shirac', 'Shirac', '', -7.3500000, -78.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103435, 'Shilla', 'Shilla', '', -9.2308300, -77.6250000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103436, 'Shapaja', 'Shapaja', 'Shapaja,Shapaya', -6.5797200, -76.2627800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103437, 'Shamboyacu', 'Shamboyacu', '', -7.0230800, -76.1329800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103438, 'Sexi', 'Sexi', 'Seccempampa,Sexi', -6.5636100, -79.0513900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103439, 'Sechura', 'Sechura', 'Sechura', -5.5569400, -80.8222200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103440, 'Sayapullo', 'Sayapullo', '', -7.6000000, -78.4666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103441, 'Sauce', 'Sauce', 'Sauce,Sausi', -6.6913900, -76.2147200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103442, 'Sartimbamba', 'Sartimbamba', 'Sartibamba,Sartimbamba,Sartin,Sartín', -7.6991700, -77.7436100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103443, 'Saquena', 'Saquena', '', -4.6666700, -73.5166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103444, 'Saposoa', 'Saposoa', 'SQU,Saposoa', -6.9339500, -76.7715800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103445, 'Sapillica', 'Sapillica', 'Sapillica,Sapillica Ciudad', -4.7783800, -79.9826300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103446, 'Sapalache', 'Sapalache', 'Sapalache,Zapalache,Zapalache Ciudad', -5.1511100, -79.4347200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103447, 'Santo Domingo', 'Santo Domingo', '', -5.0261100, -79.8741700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103448, 'Santiago de Chuco', 'Santiago de Chuco', 'Santiago de Chuco', -8.1409900, -78.1732900, 'PE', '2013-04-04', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103449, 'Santiago de Cao', 'Santiago de Cao', 'Santiago de Cao', -7.9588900, -79.2391700, 'PE', '2014-04-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103450, 'Santa Rosa', 'Santa Rosa', '', -6.8811100, -79.9197200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103451, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa,Santa Rosa Hacienda', -6.7577200, -79.8274700, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103452, 'Santa Rosa', 'Santa Rosa', '', -6.6833300, -76.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103453, 'Santa Isabel', 'Santa Isabel', '', -5.7666700, -74.5166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103454, 'Santa Elena', 'Santa Elena', '', -6.0333300, -74.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103455, 'Santa Cruz', 'Santa Cruz', '', -5.5500000, -75.8000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103456, 'Santa', 'Santa', '', -8.9886100, -78.6119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103457, 'San Rafael', 'San Rafael', '', -7.0304000, -76.4749900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103458, 'San Pedro de Lloc', 'San Pedro de Lloc', 'San Pedro,San Pedro Lluq,San Pedro de Lloc,sheng pei de luo de yue ke,聖佩德羅德約克', -7.4289000, -79.5041600, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103459, 'San Pablo', 'San Pablo', 'San Pablo', -7.1166700, -78.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103460, 'San Pablo', 'San Pablo', '', -6.8192300, -76.5757800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103461, 'San Marcos', 'San Marcos', '', -9.5249100, -77.1568100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103462, 'San Marcos', 'San Marcos', 'San Marcos', -7.3333300, -78.1833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103463, 'San Luis', 'San Luis', 'San Luis', -9.0833300, -77.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103464, 'San Lorenzo', 'San Lorenzo', '', -4.8166700, -76.6000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103465, 'San Juan', 'San Juan', '', -7.3000000, -78.5000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103466, 'Sisa', 'Sisa', 'San Jose de Sisa,San José de Sisa,Sisa', -6.6108500, -76.6930200, 'PE', '2015-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103467, 'San José', 'San Jose', 'San Jose,San José', -6.7381300, -79.8275000, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103468, 'San Jacinto', 'San Jacinto', 'San Jacinto,San Jacinto Hacienda', -4.8433300, -80.8763900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103469, 'San Jacinto', 'San Jacinto', 'Peligro,San Jacinto', -3.6419400, -80.4475000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103470, 'San Ignacio', 'San Ignacio', '', -5.1458300, -79.0013900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103471, 'San Gregorio', 'San Gregorio', '', -7.0500000, -79.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103472, 'San Felipe', 'San Felipe', '', -5.7677800, -79.3116700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103473, 'San Carlos', 'San Carlos', '', -5.9666700, -77.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103474, 'San Bernardino', 'San Bernardino', '', -7.1833300, -78.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103475, 'San Benito', 'San Benito', '', -7.4333300, -78.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103476, 'San Antonio', 'San Antonio', '', -6.3666700, -76.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103477, 'Saña', 'Sana', 'Sana,Saña,Zana,Zaña,Зана', -6.9188800, -79.5820000, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103478, 'Samanco', 'Samanco', 'Puerto Samanco,Samanco,Samancos', -9.2616700, -78.4961100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103479, 'Salpo', 'Salpo', '', -8.0000000, -78.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103480, 'Sallique', 'Sallique', '', -5.6550000, -79.3133300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103481, 'Salitral', 'Salitral', '', -4.8572200, -80.6811100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103482, 'Salinera Colán', 'Salinera Colan', '', -5.0333300, -81.0666700, 'PE', '2006-01-17', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103483, 'Guadalupito', 'Guadalupito', 'Guadalupito,Salina Guadalupito', -8.9502800, -78.6227800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103484, 'Salaverry', 'Salaverry', 'Puerto de Salaverry,Salaverry', -8.2210000, -78.9769800, 'PE', '2014-04-22', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103485, 'Salas', 'Salas', '', -6.2747200, -79.6041700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103486, 'Sacanche', 'Sacanche', '', -7.0693500, -76.7148400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103487, 'Roque', 'Roque', '', -6.4000000, -76.8000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103488, 'Rondos', 'Rondos', '', -9.9837200, -76.6883900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103489, 'Rioja', 'Rioja', 'RIJ,Rioja', -6.0567500, -77.1665100, 'PE', '2014-07-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103490, 'Requena', 'Requena', '', -5.0608300, -73.8502800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103491, 'Reque', 'Reque', 'Reque,Tranca de Reque', -6.8655600, -79.8177800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103492, 'Recuay', 'Recuay', 'Recuai,Requay', -9.7221500, -77.4563000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103493, 'Ranrahirca', 'Ranrahirca', 'Rangrairca,Ranrahirca', -9.1713900, -77.7219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103494, 'Ramón Castilla', 'Ramon Castilla', '', -4.2606600, -69.9571400, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103495, 'Quivilla', 'Quivilla', '', -9.5992900, -76.7249400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103496, 'Quiruvilca', 'Quiruvilca', 'Ouiruvilca,Quiruvilca', -7.9666700, -78.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103497, 'Quinuabamba', 'Quinuabamba', '', -8.7333300, -77.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103498, 'Quinjalca', 'Quinjalca', 'Quinjalca', -6.0922200, -77.6780600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103499, 'Quillo', 'Quillo', '', -9.3291700, -78.0413900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103500, 'Quiches', 'Quiches', 'Quiches,Quiches Heights', -8.3950000, -77.4908300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103501, 'Querocoto', 'Querocoto', 'Quereccoto,Querecoto,Querocoto', -6.3588900, -79.0358300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103502, 'Querocotillo', 'Querocotillo', 'Querecotillo,Querocotillo', -6.2738900, -79.0380600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103503, 'Querecotillo', 'Querecotillo', '', -4.8377800, -80.6455600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103504, 'Puños', 'Punos', '', -9.4973500, -76.8846900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103505, 'Punchao', 'Punchao', 'Punchac,Punchao', -9.4622100, -76.8195300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103506, 'Puerto Santa', 'Puerto Santa', 'Puerto Santa', -8.9877200, -78.6472700, 'PE', '2015-09-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103507, 'Puerto Rico', 'Puerto Rico', 'Esperanza,Puerto Rico', -6.9922200, -76.4191700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103508, 'Puerto Inca', 'Puerto Inca', 'Inca,Puerto Inca', -9.3770000, -74.9656400, 'PE', '2016-11-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103509, 'Puerto Galilea', 'Puerto Galilea', '', -4.0574300, -77.7584800, 'PE', '2017-03-21', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103510, 'Puerto Casma', 'Puerto Casma', 'Comte Noel,Puerto Casma,Puerto de Casma', -9.4636100, -78.3825000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103511, 'Chao', 'Chao', 'Chao,Puente de Chao', -8.5430600, -78.6791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103512, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nuevo,Pueblo Nuevo de Ildefonso,Pueblo Nuevo de San Ildefonso', -7.1880600, -79.5152800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103513, 'Pueblo Nuevo', 'Pueblo Nuevo', '', -5.7166700, -79.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103514, 'Pucallpa', 'Pucallpa', 'Callaria,PCL,Pucallpa,Pucalpa,Pukal''pa,Pukal''pae,Pukallpa,Pukalpa,Pulcalla,pu ka er pa,pu ki pa,pu lan er pa,pukaipa,pukaruba,pwkaaypa,pwkaypa,Пукалпа,Пукальпæ,Пукальпа,پوکاایپا,پوکایپا,ปูไกปา,პუკალიპა,プカルバ,普兰尔帕,普卡尔帕,푸카이파', -8.3791500, -74.5538700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103515, 'Pucacaca', 'Pucacaca', '', -6.8516700, -76.3416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103516, 'Posic', 'Posic', 'Posic,Tambo Rio Negro', -6.0138900, -77.1636100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103517, 'Poroto', 'Poroto', '', -8.0112500, -78.7676900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103518, 'Pomalca', 'Pomalca', '', -6.7675000, -79.7772200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103519, 'Pomahuaca', 'Pomahuaca', '', -5.9286100, -79.2261100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103520, 'Pomabamba', 'Pomabamba', 'Pamabamba,Pomabamba', -8.8333300, -77.4666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103521, 'Piura', 'Piura', 'Gorad Pjura,P''jura,PIU,Piura,Piwra,Pjuro,pi wu la,piula,piura,piw ra,pywra,pywrh,Горад Пюра,Пиура,Пьюра,Піура,פיורה,پیورا,ปิวรา,პიურა,ピウラ,皮乌拉,피우라', -5.1944900, -80.6328200, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103522, 'Piscoyacu', 'Piscoyacu', '', -6.9798400, -76.7681300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103523, 'Pira', 'Pira', '', -9.5666700, -77.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103524, 'Pimentel', 'Pimentel', '', -6.8366700, -79.9341700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103525, 'Pilluana', 'Pilluana', '', -6.7775000, -76.2905600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103526, 'Picsi', 'Picsi', 'Picsi,Piksi,Pisci,Pixi,Пикси', -6.7177800, -79.7697200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103527, 'Picota', 'Picota', '', -6.9203300, -76.3314200, 'PE', '2015-06-23', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103528, 'Pelejo', 'Pelejo', 'Palejo Isla,Pelejo', -6.2166700, -75.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103529, 'Pebas', 'Pebas', 'Pebas,Pevas,Pévas', -3.3287900, -71.8550500, 'PE', '2014-07-28', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103530, 'Paucas', 'Paucas', '', -9.1522700, -76.8990600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103531, 'Paltashaco', 'Paltashaco', 'Paltashaco,Pattashaco', -5.0997200, -79.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103532, 'Parinari', 'Parinari', '', -4.5666700, -74.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103533, 'Papayal', 'Papayal', '', -3.5966700, -80.2088900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103534, 'Pantoja', 'Pantoja', 'Cabo Pantoja,Pantoja,Posto Peruviano', -0.9666700, -75.1666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103535, 'Panao', 'Panao', '', -9.8977800, -75.9933300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103536, 'Pampas', 'Pampas', '', -9.6666700, -77.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103537, 'Pampas', 'Pampas', '', -8.2000000, -77.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103538, 'Pamparomas', 'Pamparomas', 'Pamparoma,Pamparomas', -9.0736100, -77.9813900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103539, 'Pampa Hermosa', 'Pampa Hermosa', '', -7.2000000, -75.3000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103540, 'Pallasca', 'Pallasca', '', -8.2500000, -78.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103541, 'Paita', 'Paita', 'Paita,Pajta,Payta,pai ta,payta,Паита,Пайта,پایتا,派塔', -5.0891700, -81.1144400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103542, 'Paimas', 'Paimas', '', -4.6269000, -79.9445600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103543, 'Paiján', 'Paijan', 'Paijan,Paiján', -7.7329100, -79.3015000, 'PE', '2013-04-04', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103544, 'Pacora', 'Pacora', '', -6.4288900, -79.8388900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103545, 'Paclas', 'Paclas', 'Pacla,Paclas,San Jeronimo,San Jerónimo', -6.0622200, -77.9766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103546, 'Pachas', 'Pachas', '', -9.7065100, -76.7711300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103547, 'Paccha', 'Paccha', '', -6.4977800, -78.4183300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103548, 'Pacasmayo', 'Pacasmayo', 'Pacasmayo,Puerto de Pacasmayo', -7.4005600, -79.5713900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103549, 'Pacanga', 'Pacanga', 'Pacahoa,Pacanga', -7.1666700, -79.5000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103550, 'Pacaipampa', 'Pacaipampa', 'Pacaipampa,Pacaypampa', -4.9950200, -79.6677300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103551, 'Oyotún', 'Oyotun', 'Oyontun,Oyontún,Oyotun,Oyotún', -6.8443800, -79.3009300, 'PE', '2015-08-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103552, 'Oxamarca', 'Oxamarca', 'Ocsamarca,Oxamarca', -7.0333300, -78.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103553, 'Otuzco', 'Otuzco', 'Otuzco', -7.9000000, -78.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103554, 'Orellana', 'Orellana', '', -6.9000000, -75.1666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103555, 'Omia', 'Omia', '', -6.4686100, -77.3944400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103556, 'Olto', 'Olto', 'Olto,Ulto', -6.1025000, -77.9594400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103557, 'Olmos', 'Olmos', '', -5.9847200, -79.7452800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103558, 'Olleros', 'Olleros', '', -9.6333300, -77.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103559, 'Olleros', 'Olleros', '', -6.0486100, -77.6458300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103560, 'Obas', 'Obas', '', -9.7953500, -76.6655700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103561, 'Nueva Arica', 'Nueva Arica', '', -6.8727800, -79.3427800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103562, 'Niepos', 'Niepos', '', -6.9269400, -79.1286100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103563, 'Nepeña', 'Nepena', '', -9.1725000, -78.3588900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103564, 'Negritos', 'Negritos', '', -4.6538900, -81.3047200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103565, 'Navarro', 'Navarro', '', -6.3333300, -75.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103566, 'Nauta', 'Nauta', '', -4.5333300, -73.5500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103567, 'Nanchoc', 'Nanchoc', 'Nancho,Nanchoc', -6.9597200, -79.2422200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103568, 'Namora', 'Namora', '', -7.2000000, -78.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103569, 'Namballe', 'Namballe', '', -5.0035200, -79.0890700, 'PE', '2014-07-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103570, 'Moyobamba', 'Moyobamba', 'Gorad Majabamba,MBP,Moiobamba,Mojobamba,Moyobamba,Muyupampa,mo yue ban ba,moiobamba,moyobamba,mwjwbamba,mwywbamba,Горад Маябамба,Мойобамба,موجوبامبا,مویوبامبا,მოიობამბა,莫約班巴,모요밤바', -6.0341600, -76.9716800, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103571, 'Motupe', 'Motupe', '', -6.1519400, -79.7141700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103572, 'Morropón', 'Morropon', '', -5.1868000, -79.9707600, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103573, 'Mórrope', 'Morrope', 'Morrope,Mórrope', -6.5353600, -80.0110400, 'PE', '2016-01-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103574, 'Moro', 'Moro', '', -9.1388900, -78.1819400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103575, 'Montevideo', 'Montevideo', 'Montevideo,San Ildefonso', -6.6158300, -77.8025000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103576, 'Montero', 'Montero', '', -4.6306600, -79.8285500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103577, 'Monsefú', 'Monsefu', 'Monsefu,Monsefú', -6.8743100, -79.8687100, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103578, 'Mollepata', 'Mollepata', '', -8.2000000, -77.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103579, 'Mocupe', 'Mocupe', '', -6.9894400, -79.6191700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103580, 'Mochumí', 'Mochumi', 'Mochumi,Mochumí,Muchumi', -6.5436400, -79.8621700, 'PE', '2015-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103581, 'Moche', 'Moche', '', -8.1711100, -79.0091700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103582, 'Miraflores', 'Miraflores', '', -9.4939600, -76.8187000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103583, 'Miracosta', 'Miracosta', 'Cachen,Cachén,Miracosta', -6.4041700, -79.2844400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103584, 'Milpuc', 'Milpuc', 'Milpac,Milpuc', -6.4936100, -77.4350000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103585, 'Mendoza', 'Mendoza', 'Mendoza,Mondoza,San Nicolas', -6.3944400, -77.4816700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103586, 'Matapalo', 'Matapalo', 'Matagalo,Matapalo', -3.6827100, -80.1989900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103587, 'Masisea', 'Masisea', '', -8.6052800, -74.3047200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103588, 'Marcavelica', 'Marcavelica', 'Marcavelica,Marcavelica Hacienda', -4.8777800, -80.7052800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103589, 'Marcara District', 'Marcara District', 'Macara,Macará,Marcara', -9.3225000, -77.6036100, 'PE', '2015-03-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103590, 'Marcabal', 'Marcabal', 'Marcabal,Marcabalito', -7.7000000, -78.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103591, 'Mancos', 'Mancos', '', -9.1911100, -77.7133300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103592, 'Máncora', 'Mancora', 'Hacienda Mancora,Mancora,Mancora Hacienda,Máncora,Máncora Hacienda', -4.1077800, -81.0475000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103593, 'Malvas', 'Malvas', '', -9.9166700, -77.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103594, 'Maino', 'Maino', 'Maino,Mayno', -6.3366700, -77.8800000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103595, 'Magdalena', 'Magdalena', '', -7.2500000, -78.6666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103596, 'Magdalena', 'Magdalena', '', -6.3730600, -77.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103597, 'Mache', 'Mache', 'Mache', -8.0333300, -78.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103598, 'Macate', 'Macate', '', -8.7666700, -78.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103599, 'Luya', 'Luya', '', -6.1638900, -77.9452800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103600, 'Lucmapampa', 'Lucmapampa', 'Jorge Chavez,Lucmapampa', -6.9500000, -78.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103601, 'Lucma', 'Lucma', '', -8.9166700, -77.4166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103602, 'Lucma', 'Lucma', '', -7.6333300, -78.5500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103603, 'Los Organos', 'Los Organos', '', -4.1780600, -81.1247200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103604, 'Lonya Grande', 'Lonya Grande', 'Lonya Grande', -6.0950000, -78.4213900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103605, 'Lonya Chico', 'Lonya Chico', 'Lonia Chica,Lonya Chico', -6.2311100, -77.9563900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103606, 'Longuita', 'Longuita', '', -6.4141700, -77.9686100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103607, 'Longotea', 'Longotea', 'Langotea,Longotea', -7.0666700, -77.9166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103608, 'Lobitos', 'Lobitos', '', -4.4486100, -81.2755600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103609, 'Lluchubamba', 'Lluchubamba', '', -7.5216700, -77.9708300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103610, 'Llata', 'Llata', '', -9.4166700, -76.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103611, 'Llapa', 'Llapa', '', -6.9833300, -78.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103612, 'Llama', 'Llama', '', -8.8833300, -77.3000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103613, 'Llama', 'Llama', '', -6.5144400, -79.1202800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103614, 'Llacanora', 'Llacanora', 'Ilacanora,Liacanora,Llacanora', -7.2000000, -78.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103615, 'Licupis', 'Licupis', '', -6.4244400, -79.2416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103616, 'Levanto', 'Levanto', '', -6.3083300, -77.8986100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103617, 'La Unión', 'La Union', 'La Union,La Unión', -9.8270200, -76.8019900, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103618, 'La Unión', 'La Union', '', -5.4023200, -80.7422400, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103619, 'Las Palmas', 'Las Palmas', '', -9.3841200, -76.0050500, 'PE', '2014-07-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103620, 'Las Lomas', 'Las Lomas', '', -4.6533300, -80.2466700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103621, 'Laredo', 'Laredo', 'Laredo,Laredo Hacienda,Ларедо', -8.0896500, -78.9602000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103622, 'La Peca', 'La Peca', 'La Peca,La Peca Nueva', -5.6111100, -78.4350000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103623, 'La Pampa', 'La Pampa', '', -8.6500000, -77.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103624, 'Lamud', 'Lamud', 'Lamud', -6.1372200, -77.9536100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103625, 'La Merced', 'La Merced', '', -9.7352000, -77.6168600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103626, 'Lambayeque', 'Lambayeque', 'Lambajeke,Lambayeque,Lampalliqi,lambaykh  prw,lan ba ye ke,Ламбайеке,لامبایکه، پرو,兰巴耶克', -6.7011100, -79.9061100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103627, 'Lamas', 'Lamas', 'Lamas', -6.4166700, -76.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103628, 'Lajas', 'Lajas', '', -6.5666700, -78.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103629, 'La Jalca', 'La Jalca', 'Jalca,La Jalca', -6.4861100, -77.8152800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103630, 'La Huaca', 'La Huaca', 'La Huaca,Lattuaca', -4.9116700, -80.9600000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103631, 'Lagunas', 'Lagunas', 'La Laguna,Lagunas,San Antonio de la Laguna', -5.2269400, -75.6752800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103632, 'Lagunas', 'Lagunas', 'Lagunas,Lagunas Ciudad', -4.7894000, -79.8443900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103633, 'La Grama', 'La Grama', '', -7.4666700, -78.1333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103634, 'La Esperanza', 'La Esperanza', '', -8.0764000, -79.0437100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103635, 'La Cuesta', 'La Cuesta', '', -7.9166700, -78.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103636, 'Lacabamba', 'Lacabamba', '', -8.2666700, -77.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103637, 'La Arena', 'La Arena', '', -5.3333300, -80.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103638, 'Juanjuí', 'Juanjui', 'JJI,Juanjui,Juanjuí', -7.1769700, -76.7277400, 'PE', '2017-02-05', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103639, 'Juan Guerra', 'Juan Guerra', '', -6.5827800, -76.3300000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103640, 'Jilili', 'Jilili', 'Jilili,Jilili Ciudad', -4.5827000, -79.7971300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103641, 'Jepelacio', 'Jepelacio', 'Jepelacio,Jepelecio', -6.1166700, -76.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103642, 'Jeberos', 'Jeberos', 'Jeberos,Jeveros,Nuestra Senora de la Concepcion de Jeberos,Nuestra Señora de la Concepcíon de Jeberos', -5.2833300, -76.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103643, 'Jayanca', 'Jayanca', '', -6.3908300, -79.8219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103644, 'Jangas', 'Jangas', 'Jancas,Jangas', -9.4025000, -77.5758300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103645, 'Jamalca', 'Jamalca', '', -5.8672200, -78.2616700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103646, 'Jaén', 'Jaen', 'JAE,Jaen,Jaén,Khaehn,Хаэн', -5.7072900, -78.8078500, 'PE', '2016-02-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103647, 'Iquitos', 'Iquitos', 'Gorad Ikitas,IQT,Ikitos,Ikitosas,Ikitus,Iquitos,Iquitum,akytws,aykytws,ikitoseu,ikitosu,xiki tos,yi ji tuo si,Ікітос,Горад Ікітас,Икитос,איקיטוס,اکیتوس,ایکیتوس,อีกีโตส,იკიტოსი,イキトス,伊基托斯,이키토스', -3.7491200, -73.2538300, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103648, 'Iparia', 'Iparia', '', -9.3000000, -74.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103649, 'Inguilpata', 'Inguilpata', '', -6.2408300, -77.9572200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103650, 'Incahuasi', 'Incahuasi', 'Incahuas,Incahuasi', -6.2355600, -79.3169400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103651, 'Inahuaya', 'Inahuaya', '', -7.1500000, -75.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103652, 'Iberia', 'Iberia', '', -5.6666700, -74.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103653, 'Huicungo', 'Huicungo', '', -7.3186000, -76.7755600, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103654, 'Huaylillas', 'Huaylillas', 'Huailillas,Huaylillas', -8.1872200, -77.3425000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103655, 'Huata', 'Huata', '', -9.0161100, -77.8608300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103656, 'Huarmaca', 'Huarmaca', 'Huarmaca,Huarmaco', -5.5658300, -79.5219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103657, 'Huaripampa', 'Huaripampa', '', -8.9500000, -77.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103658, 'Huari', 'Huari', 'Huari', -9.3333300, -77.2333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103659, 'Huaraz', 'Huaraz', 'Gorad Guaras,Huaras,Huarasas,Huaraz,Uaras,Uaraz,Varas,Waras,awaraz,ualaseu,uarasi,wa la si,waras,warasu,Горад Гуарас,Уараз,Уарас,ואראס,اواراز,واراس,უარასი,ワラス,瓦拉斯,우아라스', -9.5277900, -77.5277800, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103660, 'Huaranchal', 'Huaranchal', '', -7.6833300, -78.4500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103661, 'Huánuco', 'Huanuco', 'HUU,Huanuco,Huanukas,Huánuco,Uanuko,Vanucum,Wanuku,awanwkw,uanuko,wa nu ke,wanuko,wanwkw,Ŭanuko,Уануко,اوانوکو,وانوکو,უანუკო,ワヌコ,瓦努科,우아누코', -9.9306200, -76.2422300, 'PE', '2016-12-05', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103662, 'Huandoval', 'Huandoval', 'Huadoval,Huandoval', -8.3333300, -77.9833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103663, 'Huanchay', 'Huanchay', '', -9.7333300, -77.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103664, 'Huanchaco', 'Huanchaco', 'Huanchaco,Wanchaku', -8.0833300, -79.1166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103665, 'Huancas', 'Huancas', '', -6.1741700, -77.8652800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103666, 'Huancabamba', 'Huancabamba', 'Huancabamba', -5.2386100, -79.4505600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103667, 'Huambos', 'Huambos', '', -6.4666700, -78.9666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103668, 'Huamachuco', 'Huamachuco', 'Huamachuco', -7.8000000, -78.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103669, 'Huallanca', 'Huallanca', '', -9.8979600, -76.9408900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103670, 'Huallanca', 'Huallanca', '', -8.8166700, -77.8666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103671, 'Hualgayoc', 'Hualgayoc', '', -6.7666700, -78.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103672, 'Huacrachuco', 'Huacrachuco', '', -8.6500000, -77.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103673, 'Huachis', 'Huachis', 'Huachis,Rahuapampa', -9.4166700, -77.1166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103674, 'Huacchis', 'Huacchis', 'Huacchis,Huachis', -9.2003300, -76.7878000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103675, 'Huacaybamba', 'Huacaybamba', 'Huacaibamba,Huacaybamba,Huacaypamba,Huancaybamba', -9.0381900, -76.9529300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103676, 'Huacaschuque', 'Huacaschuque', '', -8.3000000, -78.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103677, 'Huacapampa', 'Huacapampa', 'Huacapampa,Jose Galvez', -6.9333300, -78.1333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103678, 'Huacachi', 'Huacachi', '', -9.3167400, -76.9395300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103679, 'Honoria', 'Honoria', '', -8.7691700, -74.7100800, 'PE', '2015-06-17', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103680, 'Habana', 'Habana', '', -6.0816700, -77.0908300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103681, 'Guzmango', 'Guzmango', '', -7.3833300, -78.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103682, 'Guadalupe', 'Guadalupe', '', -7.2500000, -79.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103683, 'Granada', 'Granada', 'Granada,Jambajalca,Yambajalca', -6.0991700, -77.6266700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103684, 'Frias', 'Frias', '', -4.9295800, -79.9479600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103685, 'La Florida', 'La Florida', 'Florida,La Florida', -6.8697200, -79.1211100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103686, 'Ferreñafe', 'Ferrenafe', 'Ferrenafe,Ferreñafe,Terrenafe,Terreñafe', -6.6388900, -79.7888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103687, 'Eten', 'Eten', 'Eten,Villa Eten', -6.9080600, -79.8641700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103688, 'Encañada', 'Encanada', '', -7.0833300, -78.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103689, 'El Prado', 'El Prado', '', -7.0333300, -79.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103690, 'El Porvenir', 'El Porvenir', '', -8.0833300, -79.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103691, 'El Parco District', 'El Parco District', 'El Parco', -5.6243600, -78.4759400, 'PE', '2014-07-29', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103692, 'El Alto', 'El Alto', '', -4.2685100, -81.2171900, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103693, 'Dos Pueblos', 'Dos Pueblos', '', -5.4500000, -80.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103694, 'Cutervo', 'Cutervo', '', -6.3666700, -78.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103695, 'Curgos', 'Curgos', '', -7.8597200, -77.9433300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103696, 'Cumba', 'Cumba', '', -5.9330600, -78.6627800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103697, 'La Caleta Culebras', 'La Caleta Culebras', 'Culebras,La Caleta Culebras', -9.9488900, -78.2252800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103698, 'Cujillo', 'Cujillo', '', -6.1166700, -78.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103699, 'Cuispes', 'Cuispes', 'Cuispes,Cuispis,Cuspis', -5.9166700, -77.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103700, 'Corongo', 'Corongo', '', -8.5833300, -77.9166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103701, 'Coris', 'Coris', '', -9.8333300, -77.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103702, 'Contamana', 'Contamana', 'Contamana,Contamena', -7.3333300, -75.0166700, 'PE', '2014-04-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103703, 'Concordia', 'Concordia', '', -4.5666700, -74.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103704, 'Conchucos', 'Conchucos', '', -8.2666700, -77.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103705, 'Colcamar', 'Colcamar', '', -6.3011100, -77.9725000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103706, 'Colcabamba', 'Colcabamba', '', -9.5833300, -77.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103707, 'Colasay', 'Colasay', 'Colasay,Colassay', -5.9752800, -79.0661100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103708, 'Coishco', 'Coishco', 'Coisco,Coishco,Coshco', -9.0230600, -78.6155600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103709, 'Cochabamba', 'Cochabamba', '', -9.4936100, -77.8594400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103710, 'Cochabamba', 'Cochabamba', '', -6.4833300, -78.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103711, 'Cocabamba', 'Cocabamba', '', -6.6000000, -78.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103712, 'Churuja', 'Churuja', '', -6.0141700, -77.9533300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103713, 'Churubamba', 'Churubamba', '', -9.8255700, -76.1332700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103714, 'Chuquis', 'Chuquis', '', -9.6765800, -76.7039600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103715, 'Chuquibamba', 'Chuquibamba', '', -6.9341700, -77.8522200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103716, 'Chumuch', 'Chumuch', 'Chimuch,Chumuch,Chumush', -6.6000000, -78.2166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103717, 'Chulucanas', 'Chulucanas', 'Chulucana,Chulucanas,Chulukanasa,Чулуканаса', -5.0925000, -80.1625000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103718, 'Chugur', 'Chugur', '', -6.6666700, -78.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103719, 'Chugay', 'Chugay', 'Chugay,Chugay Hacienda', -7.7816700, -77.8683300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103720, 'Chota', 'Chota', 'Chota', -6.5500000, -78.6500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103721, 'Choros', 'Choros', '', -5.9013900, -78.6941700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103722, 'Chongoyape', 'Chongoyape', '', -6.6405600, -79.3891700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103723, 'Chocope', 'Chocope', '', -7.7913900, -79.2216700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103724, 'Chisquilla', 'Chisquilla', '', -5.8833300, -77.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103725, 'Chirinos', 'Chirinos', '', -5.3050000, -78.8983300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103726, 'Chiriaco', 'Chiriaco', '', -5.1600000, -78.2888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103727, 'Chingas', 'Chingas', '', -9.1196700, -76.9912600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103728, 'Chimbote', 'Chimbote', 'CHM,Chimbote,Chimputi,Cimbote,Cimboto,chimbote,chinbote,chymbwth,qin bo te,Ĉimboto,Čimbotė,Чимботе,Чімботе,چیمبوته,ჩიმბოტე,チンボテ,钦博特,침보테', -9.0852800, -78.5783300, 'PE', '2017-02-05', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103729, 'Chillia', 'Chillia', 'Chilia,Chillia', -8.1000000, -77.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103730, 'Chilete', 'Chilete', 'Chileta,Chilete,Chileto', -7.2333300, -78.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103731, 'Chiguirip', 'Chiguirip', 'Chiguirip,Chiquirip', -6.4166700, -78.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103732, 'Chiclayo', 'Chiclayo', 'CIX,Chiclaium,Chiclayo,Chiklajo,Chiklayu,Ciklajus,Gorad Chyklaja,chikeullayo,chikurayo,chyklayw,qi ke la yue,tshyklayw,Čiklajus,Горад Чыклая,Чиклайо,Чиклајо,Чіклайо,ציקלאיו,تشيكلايو,چیکلایو,ჩიკლაიო,チクラーヨ,奇克拉约,치클라요', -6.7713700, -79.8408800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103733, 'Chicama', 'Chicama', '', -7.8447200, -79.1469400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103734, 'Chetilla', 'Chetilla', '', -7.1500000, -78.6666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103735, 'Chepén', 'Chepen', 'Chepen,Chepén', -7.2243600, -79.4247600, 'PE', '2016-01-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103736, 'Chavinillo', 'Chavinillo', 'Chavanillo,Chavinillo', -9.8585000, -76.6085500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103737, 'Chazuta', 'Chazuta', 'Chasuta,Chazuta', -6.5708700, -76.1375300, 'PE', '2016-06-22', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103738, 'Charat', 'Charat', '', -7.8333300, -78.4500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103739, 'Chalaco', 'Chalaco', '', -5.0388900, -79.7938900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103740, 'Chaglla', 'Chaglla', 'Chaclla,Chaglla,Chaqlla,Choglia', -9.8436100, -75.9030600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103741, 'Chachapoyas', 'Chachapoyas', 'CHH,Cacapojasas,Chachapoias,Chachapojas,Chachapoyas,Chachapuyas,cha cha bo ya si,chachapoyaseu,chachapwyas,chachapwyas  pyrw,Čačapojasas,Чачапояс,Чачапојас,چاچاپویاس,چاچاپویاس، پیرو,ჩაჩაპოიასი,查查波亚斯,차차포야스', -6.2316900, -77.8690300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103742, 'Chacas', 'Chacas', 'Cakasas,Chacas,Chakas,cha ka si,Čakasas,查卡斯', -9.2333300, -77.3833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103743, 'Celendín', 'Celendin', 'Celendin,Celendín', -6.8659000, -78.1458500, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103744, 'Cauday', 'Cauday', '', -7.5833300, -78.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103745, 'Catache', 'Catache', 'Catache,Catachi', -6.6752800, -79.0330600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103746, 'Catacaos', 'Catacaos', 'Catacaos', -5.2666700, -80.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103747, 'Catac', 'Catac', '', -9.8000000, -77.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103748, 'Caspisapa', 'Caspisapa', 'Caspisapa,Caspizapa', -6.9569400, -76.4180600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103749, 'Casma', 'Casma', 'Casma,Puerto Casma', -9.4747200, -78.3016700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103750, 'Cascas', 'Cascas', 'Cascas', -7.4833300, -78.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103751, 'Cascapara', 'Cascapara', 'Cascapara,Caskapara,Kascapara', -9.2258300, -77.7163900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103752, 'Casa Grande', 'Casa Grande', 'Casa Grande,Casa Grande Hacienda,Hacienda Casa Grande', -7.7438900, -79.1863900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103753, 'Carhuaz', 'Carhuaz', 'Carhuaz', -9.2819400, -77.6447200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103754, 'Carás', 'Caras', 'Caras,Caraz,Carás,Cavas,Cavás', -9.0469200, -77.8090100, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103755, 'Carabamba', 'Carabamba', 'Carabamba,Carabamba Hacienda', -8.1166700, -78.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103756, 'Canchaque', 'Canchaque', 'Canchaque,Canchaqui', -5.3730600, -79.6002800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103757, 'Cancas', 'Cancas', '', -3.9466700, -80.9416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103758, 'Cañaveral', 'Canaveral', 'Canaveral,Cañaveral', -3.9416700, -80.6508300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103759, 'Cañaris', 'Canaris', 'Canares,Canaris,Cañares,Cañaris,Lanares', -6.0461100, -79.2647200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103760, 'Calzada', 'Calzada', '', -6.0319400, -77.0663900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103761, 'Caleta Cruz', 'Caleta Cruz', '', -3.6375000, -80.5916700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103762, 'Cajaruro', 'Cajaruro', 'Cajarura,Cajaruro', -5.7363900, -78.4255600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103763, 'Cajamarquilla', 'Cajamarquilla', '', -9.6333300, -77.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103764, 'Cajamarca', 'Cajamarca', 'CJA,Cajamarca,Caxamarca,Gorad Kakhamarka,Kachamarka,Kakhamarka,Kasamarko,Kashamarka,Kaŝamarko,Qajamarka,Qashamarka,ka ha ma ka,ka ha mar ka,kahamaleuka,kahamaruka,kakhamarka,Горад Кахамарка,Кахамарка,کاخامارکا,กาฮามาร์กา,კახამარკა,カハマルカ,卡哈馬卡,카하마르카', -7.1637800, -78.5002700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103765, 'Cajabamba', 'Cajabamba', 'Cajabamba', -7.6166700, -78.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103766, 'Cahuac', 'Cahuac', 'Cahua,Cahuac', -9.8526100, -76.6303500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103767, 'Cachachi', 'Cachachi', '', -7.4500000, -78.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103768, 'Cabana', 'Cabana', 'Cabana', -8.4000000, -78.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103769, 'Caballococha', 'Caballococha', 'Caballococha,Cabalo Cocha', -3.9058300, -70.5163900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103770, 'Buenos Aires', 'Buenos Aires', '', -8.1386100, -79.0402800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103771, 'Buenos Aires', 'Buenos Aires', 'Buenos Aires,Buenos Aires Hacienda', -5.2608300, -79.9641700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103772, 'Breu', 'Breu', '', -9.4833300, -72.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103773, 'Bretaña', 'Bretana', '', -5.2666700, -74.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103774, 'Bolognesi', 'Bolognesi', '', -8.3500000, -78.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103775, 'Bernal', 'Bernal', '', -5.4500000, -80.7500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103776, 'Bellavista', 'Bellavista', 'BLP,Bellavista', -7.0561400, -76.5911000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103777, 'Bellavista', 'Bellavista', '', -5.6641700, -78.6772200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103778, 'Barranquita', 'Barranquita', '', -6.2666700, -76.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103779, 'Barranca', 'Barranca', '', -4.8329800, -76.6758200, 'PE', '2012-09-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103780, 'Bambas', 'Bambas', '', -8.6000000, -78.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103781, 'Bambamarca', 'Bambamarca', '', -6.6833300, -78.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103782, 'Balsas', 'Balsas', '', -6.8333300, -78.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103783, 'Bagua Grande', 'Bagua Grande', 'Bagua Grande', -5.7561100, -78.4411100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103784, 'Bagua', 'Bagua', 'Bagua,Bagua Chica,Bagva,Gorad Bagua,ba gua,bagva,bagwa  prw,Багва,Багуа,Горад Багуа,باگوآ، پرو,ბაგვა,巴瓜', -5.6331100, -78.5343100, 'PE', '2014-07-29', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103785, 'Ayabaca', 'Ayabaca', '', -4.6398300, -79.7149100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103786, 'Aucayacu', 'Aucayacu', 'Aucayacu,Ucayacu', -8.9313900, -76.1131500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103787, 'Ascope', 'Ascope', 'Ascope', -7.7144400, -79.1077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103788, 'Aricapampa', 'Aricapampa', 'Aricabamba,Aricapamba Hacienda,Aricapampa', -7.8058300, -77.7172200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103789, 'Arenal', 'Arenal', 'Arenal,El Arenal', -4.8833300, -81.0275000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103790, 'Arancay', 'Arancay', 'Arancai,Arancay', -9.1722700, -76.7489500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103791, 'Aramango', 'Aramango', 'Aramango', -5.4163900, -78.4358300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103792, 'Anta', 'Anta', 'ATA,Anta', -9.3586100, -77.5972200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103793, 'Angasmarca', 'Angasmarca', 'Angasmarca,Angasmarca Hacienda,Hacienda Asgasmarca', -8.1333300, -78.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103794, 'Amotape', 'Amotape', '', -4.8816700, -81.0155600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103795, 'Amashca', 'Amashca', '', -9.2391700, -77.6463900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103796, 'Aija', 'Aija', '', -9.7810500, -77.6094000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103797, 'Aguas Verdes', 'Aguas Verdes', 'Aguas Verdes', -3.4813900, -80.2450000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103798, 'Agua Blanca', 'Agua Blanca', 'Agua Bianca,Agua Blanca,Yurac Yacu', -6.7234300, -76.6964300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103799, 'Agallpampa', 'Agallpampa', '', -7.9833300, -78.5500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103800, 'Aczo', 'Aczo', '', -9.1519300, -76.9892500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103801, 'Acopampa', 'Acopampa', 'Acco-Pampa,Acopampa', -9.2972200, -77.6177800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103802, 'Acomayo', 'Acomayo', '', -9.8010500, -76.0719400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103803, 'Aco', 'Aco', '', -8.5333300, -77.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103804, 'Puerto Callao', 'Puerto Callao', 'Puerto Callao', -8.3580600, -74.5736100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103805, 'Campoverde', 'Campoverde', 'Campoverde', -8.4753300, -74.8070900, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103806, 'Nueva Requena', 'Nueva Requena', 'Nueva Requena', -8.3113900, -74.8622200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103807, 'La Coipa', 'La Coipa', '', -5.4336100, -78.8636100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103808, 'La Sacilia', 'La Sacilia', '', -5.9516700, -78.7272200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103809, 'Alianza Cristiana', 'Alianza Cristiana', '', -3.4752800, -76.4344400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103810, 'Utco', 'Utco', '', -6.9166700, -78.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103811, 'Las Pirias', 'Las Pirias', '', -5.6272200, -78.8527800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103812, 'Zapatero', 'Zapatero', '', -6.5297200, -76.4925000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103813, 'Cuñumbuqui', 'Cunumbuqui', 'Cunumbuque,Cunumbuqui,Cuñumbuque,Cuñumbuqui', -6.5111100, -76.4800000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103814, 'Utcurarca', 'Utcurarca', '', -6.6630600, -76.2866700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103815, 'Buenos Aires', 'Buenos Aires', '', -6.7911100, -76.3263900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103816, 'Manuel Antonio Mesones Muro', 'Manuel Antonio Mesones Muro', '', -6.6436100, -79.7380600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103817, 'La Breita', 'La Breita', 'La Brea,La Breita', -4.2569100, -80.8859900, 'PE', '2016-01-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103818, 'Papayal', 'Papayal', '', -4.0777100, -80.7369000, 'PE', '2012-10-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103819, 'Zarumilla', 'Zarumilla', '', -3.5030600, -80.2730600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103820, 'Zurite', 'Zurite', 'Surite,Zurite', -13.4547200, -72.2555600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103821, 'Zepita', 'Zepita', 'Zepita', -16.5000000, -69.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103822, 'Yura', 'Yura', 'Balneario de Yura,Yura', -16.2522300, -71.6796900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103823, 'Yunguyo', 'Yunguyo', 'Yunguyo', -16.2500000, -69.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103824, 'Yunga', 'Yunga', '', -16.2000000, -70.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103825, 'Yucay', 'Yucay', 'Yucay', -13.3213900, -72.0822200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103826, 'Yauyos', 'Yauyos', 'Yauyos', -12.4594400, -75.9172200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103827, 'Yaurisque', 'Yaurisque', 'Llaurisque Pueblo,Yaurisqque,Yaurisque', -13.6669400, -71.9211100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103828, 'Yauli', 'Yauli', '', -11.7136600, -75.4746600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103829, 'Yauli', 'Yauli', '', -11.6650000, -76.0863900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103830, 'Yauca', 'Yauca', '', -15.6611100, -74.5272200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103831, 'Yarabamba', 'Yarabamba', '', -16.5472200, -71.4766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103832, 'Yanque', 'Yanque', '', -15.6491700, -71.6577800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103833, 'Yangas', 'Yangas', '', -11.6950000, -76.8455600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103834, 'Yanaquihua', 'Yanaquihua', 'Yanaquigua,Yanaquihua,Yanaquinua', -15.7738900, -72.8766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103835, 'Yanaoca', 'Yanaoca', '', -14.2180600, -71.4316700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103836, 'Yanahuaya', 'Yanahuaya', '', -14.2666700, -69.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103837, 'Yanahuanca', 'Yanahuanca', '', -10.5166700, -76.4986100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103838, 'Yanacancha', 'Yanacancha', '', -12.2000000, -75.4166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103839, 'Yanacancha', 'Yanacancha', 'Yanacancha,Yanacocha', -10.2411100, -76.6455600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103840, 'Yanaca', 'Yanaca', 'Tapairihua,Yanaca', -14.2177800, -73.1411100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103841, 'Vizcachane', 'Vizcachane', '', -15.8086100, -71.2011100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103842, 'Vitis', 'Vitis', '', -12.2236100, -75.8063900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103843, 'Vitarte', 'Vitarte', '', -12.0333300, -76.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103844, 'Vischongo', 'Vischongo', '', -13.5891700, -73.9944400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103845, 'Viraco', 'Viraco', '', -15.6569400, -72.5252800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103846, 'Vinchos', 'Vinchos', '', -13.2408300, -74.3530600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103847, 'Viñac', 'Vinac', '', -12.9311100, -75.7786100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103848, 'Vilque Chico', 'Vilque Chico', '', -15.2166700, -69.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103849, 'Vilque', 'Vilque', '', -15.7666700, -70.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103850, 'Villa Tupac Amaru', 'Villa Tupac Amaru', 'Villa Tupac Amaru', -13.7113500, -76.1498000, 'PE', '2016-03-10', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103851, 'Villa Rica', 'Villa Rica', '', -10.7394400, -75.2697200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103852, 'Vilcanchos', 'Vilcanchos', 'Vilcancho,Vilcanchos', -13.6116700, -74.5319400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103853, 'Vilcabamba', 'Vilcabamba', 'Huilcabamba,Vilcabamba', -14.0755600, -72.6258300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103854, 'Vilcabamba', 'Vilcabamba', '', -10.4780600, -76.4475000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103855, 'Vilca', 'Vilca', '', -12.4833300, -75.1833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103856, 'Vilavila', 'Vilavila', 'Vilavila,Vilayila,Villa-Villa', -15.1869400, -70.6600000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103857, 'Ventanilla', 'Ventanilla', 'Ventanilla', -11.8752800, -77.1183300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103858, 'Velinga', 'Velinga', '', -15.2733300, -73.0216700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103859, 'Velille', 'Velille', '', -14.5088900, -71.8852800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103860, 'Végueta', 'Vegueta', '', -11.0225300, -77.6437800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103861, 'Usicayos', 'Usicayos', '', -14.1247200, -69.9661100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103862, 'Urubamba', 'Urubamba', 'Urubamba', -13.3047200, -72.1158300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103863, 'Uripa', 'Uripa', '', -13.5325000, -73.6772200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103864, 'Urcos', 'Urcos', 'Urcos', -13.6861100, -71.6227800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103865, 'Urasqui', 'Urasqui', '', -16.0286100, -73.1705600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103866, 'Upahuacho', 'Upahuacho', 'Haipahuacho,Huipahuacha,Hupahuacho,Upahuacho', -14.9016700, -73.4011100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103867, 'Uñon', 'Unon', '', -15.7294400, -72.4297200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103868, 'Umachiri', 'Umachiri', 'Umachire,Umachiri', -14.8575000, -70.7561100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103869, 'Uchumayo', 'Uchumayo', '', -16.4250800, -71.6721500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103870, 'Ubinas', 'Ubinas', 'Ubinas', -16.4000000, -70.8666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103871, 'Tuti', 'Tuti', '', -15.5330600, -71.5508300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103872, 'Turpo', 'Turpo', '', -13.7852800, -73.4736100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103873, 'Turpay', 'Turpay', '', -14.2191700, -72.6238900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103874, 'Tupe', 'Tupe', '', -12.7408300, -75.8083300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103875, 'Tungasuca', 'Tungasuca', '', -14.1638900, -71.4766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103876, 'Totos', 'Totos', '', -13.5672200, -74.5236100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103877, 'Totoral', 'Totoral', '', -17.4062000, -70.3646400, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103878, 'Toro', 'Toro', '', -15.2641700, -72.9288900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103879, 'Toraya', 'Toraya', 'Toraya,Toroya', -14.0505600, -73.2972200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103880, 'Torata', 'Torata', '', -17.0769400, -70.8433300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103881, 'Tomepampa', 'Tomepampa', '', -15.1730600, -72.8308300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103882, 'Tomay Kichwa', 'Tomay Kichwa', 'Tomaiquichua,Tomay Kichwa,Tomayquichwa', -10.0772200, -76.2119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103883, 'Tomas', 'Tomas', '', -12.2386100, -75.7452800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103884, 'Tocota', 'Tocota', '', -15.6594400, -74.0905600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103885, 'Tibillo', 'Tibillo', 'Tibillo,Tivillo', -14.0930600, -75.1719400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103886, 'Tisco', 'Tisco', '', -15.3461100, -71.4477800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103887, 'Tirapata', 'Tirapata', 'Tirapata', -14.9500000, -70.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103888, 'Tiquillaca', 'Tiquillaca', 'Tiguillaca,Tiquillaca', -15.8166700, -70.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103889, 'Tinyahuarco', 'Tinyahuarco', 'Fundicion de Tinyahuarco,Fundición de Tinyahuarco,La Fundicion,La Fundición,Smelter,Tinllahuarco,Tinyahuarco', -10.7677100, -76.2752300, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103890, 'Tintay', 'Tintay', '', -13.9591700, -73.1858300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103891, 'Tinta', 'Tinta', '', -14.1450000, -71.4069400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103892, 'Ticrapo', 'Ticrapo', 'Ticrapo,Ticropo', -13.3500000, -75.4166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103893, 'Ticllos', 'Ticllos', '', -10.2540300, -77.1908800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103894, 'Ticllas', 'Ticllas', '', -13.1325000, -74.3327800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103895, 'Ticaco', 'Ticaco', '', -17.4463900, -70.0469400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103896, 'Tiabaya', 'Tiabaya', '', -16.4500000, -71.5900000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103897, 'Taurisma', 'Taurisma', '', -15.1750000, -72.8502800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103898, 'Tauripampa', 'Tauripampa', '', -12.5833300, -76.1166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103899, 'Tauria', 'Tauria', '', -15.3561100, -73.2325000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103900, 'Tarucani', 'Tarucani', 'Pueblo Tarucane,Tarucane,Tarucani', -16.1833300, -71.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103901, 'Tarucachi', 'Tarucachi', 'Tarucache,Tarucachi', -17.5247200, -70.0283300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103902, 'Tarma', 'Tarma', 'Tarma,ta er ma,tarma,Тарма,تارما,塔爾馬', -11.4189900, -75.6899200, 'PE', '2015-03-29', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103903, 'Tarata', 'Tarata', 'Tarata', -17.4744400, -70.0327800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103904, 'Taraco', 'Taraco', '', -15.3000000, -69.9666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103905, 'Taquile', 'Taquile', 'Intika,Isla de Taquili,Taquila,Taquile', -15.7666700, -69.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103906, 'Tapo', 'Tapo', '', -11.3905600, -75.5636100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103907, 'Tapay', 'Tapay', 'Cahuara,Tapay', -15.5780600, -71.9391700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103908, 'Tapairihua', 'Tapairihua', 'Tapairihua,Tapayrigua', -14.1402800, -73.1427800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103909, 'Tapacocha', 'Tapacocha', '', -10.0166700, -77.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103910, 'Tanta', 'Tanta', '', -12.1166700, -76.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103911, 'Tamburco', 'Tamburco', '', -13.6166700, -72.8713900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103912, 'Tambo Quemado', 'Tambo Quemado', 'Leoncio Prado,Tambo Quemado', -14.7333300, -74.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103913, 'Tambopata', 'Tambopata', '', -12.6719100, -69.3554700, 'PE', '2014-07-22', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103914, 'Tambobamba', 'Tambobamba', 'Tambobamba,Tampobamba', -13.9452800, -72.1713900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103915, 'Tambo', 'Tambo', '', -14.7984700, -73.9243800, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103916, 'Tambo', 'Tambo', '', -12.9333300, -74.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103917, 'Tambillo', 'Tambillo', '', -13.1919400, -74.1113900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103918, 'Talavera', 'Talavera', '', -13.6530600, -73.4291700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103919, 'Tacna', 'Tacna', 'Gorad Takna,TCQ,Tacna,Takna,Takno,Taqna,ta ke na,tak na,takeuna,takna,takuna,Горад Такна,Такна,Տակնա,טאקנה,تاكنا,تاکنا,ตักนา,ტაკნა,タクナ,塔克纳,타크나', -18.0146500, -70.2536200, 'PE', '2013-11-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103920, 'Susapaya', 'Susapaya', '', -17.3530600, -70.1319400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103921, 'Surcubamba', 'Surcubamba', '', -12.1333300, -74.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103922, 'Santiago de Surco', 'Santiago de Surco', 'Santiago de Surco,Surco', -12.1358800, -77.0074200, 'PE', '2016-01-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103923, 'Surco', 'Surco', '', -11.8847200, -76.4397200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103924, 'Supe', 'Supe', '', -10.7975000, -77.7130600, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103925, 'Sunampe', 'Sunampe', '', -13.4270400, -76.1636300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103926, 'Sumbilca', 'Sumbilca', '', -11.4075000, -76.8200000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103927, 'Suitucancha', 'Suitucancha', 'Sintocancha,Suitu-Cancha,Suitucancha', -11.7873400, -75.9361200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103928, 'Subtanjalla', 'Subtanjalla', '', -14.0188900, -75.7580600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103929, 'Soraya', 'Soraya', '', -14.1627800, -73.3125000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103930, 'Soras', 'Soras', '', -14.1150000, -73.6044400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103931, 'Socos', 'Socos', '', -13.2150000, -74.2891700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103932, 'Socabaya', 'Socabaya', 'Socabaya', -16.4702500, -71.5275800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103933, 'Sitajara', 'Sitajara', '', -17.3755600, -70.1322200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103934, 'Sincos', 'Sincos', 'Cincos,Sincos', -11.8911900, -75.3874500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103935, 'Sina', 'Sina', '', -14.5000000, -69.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103936, 'Sicuani', 'Sicuani', '', -14.2694400, -71.2261100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103937, 'Sicaya', 'Sicaya', 'Sicaya', -12.0333300, -75.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103938, 'Sibayo', 'Sibayo', 'Sibayo,Sivayo', -15.4869400, -71.4583300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103939, 'Sepahua', 'Sepahua', 'Sepahua,Shepahua', -11.1458300, -73.0427800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103940, 'Saylla', 'Saylla', 'Saila,Sailla,Saylla', -13.5613900, -71.8488900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103941, 'Sayán', 'Sayan', 'San Jeronimo de Sayan,Sayan,Sayán', -11.1333300, -77.1946000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103942, 'Saurama', 'Saurama', 'Saucama,Saurama', -13.6936100, -73.7586100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103943, 'Satipo', 'Satipo', 'San Francisco de Satipo,Satipo', -11.2522200, -74.6386100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103944, 'Sarhua', 'Sarhua', '', -13.6741700, -74.3200000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103945, 'Sapallanga', 'Sapallanga', '', -12.1500000, -75.1833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103946, 'San Vicente de Cañete', 'San Vicente de Canete', 'Canete,Cañete,Pueblo Nuevo,San Vicente de Canete,San Vicente de Cañete', -13.0755600, -76.3852800, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103947, 'Santiago', 'Santiago', 'Santiago', -14.1846900, -75.7112400, 'PE', '2016-01-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103948, 'Santa Teresa', 'Santa Teresa', '', -13.1322200, -72.5905600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103949, 'Santa Rosa', 'Santa Rosa', '', -14.6111100, -70.7861100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103950, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa,Santa Rosa Hacienda', -14.1500000, -72.6666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103951, 'Santa Rosa', 'Santa Rosa', '', -11.7991700, -77.1733300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103952, 'Santa María', 'Santa Maria', 'SMG,Santa Maria,Santa María', -12.0053800, -76.8932900, 'PE', '2014-12-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103953, 'Santa Lucía', 'Santa Lucia', '', -15.6978800, -70.6061000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103954, 'Santa Eulalia', 'Santa Eulalia', '', -11.9008300, -76.6633300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103955, 'Santa Eulalia', 'Santa Eulalia', 'Santa Eulalia', -11.8971600, -76.6625600, 'PE', '2013-12-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103956, 'Santa Cruz', 'Santa Cruz', 'Paccho,Santa Cruz', -11.0600000, -76.9302800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103957, 'Santa Ana', 'Santa Ana', '', -13.0500000, -75.1333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103958, 'Santa Ana', 'Santa Ana', '', -12.8666700, -72.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103959, 'San Salvador', 'San Salvador', '', -13.4936100, -71.7738900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103960, 'San Ramón', 'San Ramon', 'San Ramon,San Ramón,San Roman', -11.1241700, -75.3573300, 'PE', '2014-06-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103961, 'San Rafael', 'San Rafael', '', -10.3380600, -76.1833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103962, 'San Pedro de Cajas', 'San Pedro de Cajas', 'Cajas,San Pedro de Cacas,San Pedro de Cajas', -11.2506100, -75.8611600, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103963, 'San Pedro', 'San Pedro', '', -14.7666700, -74.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103964, 'San Pedro', 'San Pedro', '', -14.1866700, -71.3416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103965, 'San Pedro', 'San Pedro', '', -13.3988900, -76.1590400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103966, 'San Pablo', 'San Pablo', '', -14.2027800, -71.3155600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103967, 'San Miguel de Cauri', 'San Miguel de Cauri', '', -10.1381800, -76.6228800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103968, 'San Miguel', 'San Miguel', 'San Miguel', -13.0125000, -73.9808300, 'PE', '2012-07-20', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103969, 'San Mateo', 'San Mateo', '', -11.7594400, -76.3005600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103970, 'San Luis', 'San Luis', 'San Luis', -12.0767400, -76.9943500, 'PE', '2014-12-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103971, 'San Lorenzo', 'San Lorenzo', '', -11.8468400, -75.3814600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103972, 'San Lorenzo', 'San Lorenzo', '', -11.4666700, -69.3000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103973, 'San Juan Bautista', 'San Juan Bautista', 'Juan Bautista,San Juan,San Juan Bautista', -14.0108300, -75.7358300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103974, 'San Juan de Marcona', 'San Juan de Marcona', 'Puerto San Juan,SJA,San Juan de Marcona', -15.3652800, -75.1622200, 'PE', '2013-11-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103975, 'San Juan', 'San Juan', '', -14.6500000, -74.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103976, 'San Juan', 'San Juan', 'Huanac,San Juan,San Juan Huanaco,San Juan de Cacrillo,San Juan de Castrovirreyna', -13.2000000, -75.6500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103977, 'San Jerónimo', 'San Jeronimo', 'San Geronimo,San Jeronimo,San Jerónimo', -13.6513800, -73.3638800, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103978, 'San Jerónimo', 'San Jeronimo', 'San Geronimo,San Gerónimo,San Jeronimo,San Jeronimo de Tunan,San Jerónimo,San Jerónimo de Tunán', -11.9559100, -75.2841100, 'PE', '2014-06-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103979, 'San Isidro', 'San Isidro', '', -12.1166700, -77.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103980, 'Sangallaya', 'Sangallaya', 'Sangallalla,Sangallaya', -12.1666700, -76.2666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103981, 'San Francisco', 'San Francisco', '', -12.6000000, -73.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103982, 'Sandia', 'Sandia', 'Sandia', -14.2333300, -69.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103983, 'San Clemente', 'San Clemente', '', -13.6666700, -76.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103984, 'San Buenaventura', 'San Buenaventura', 'Buenaventura,San Buenaventura', -11.4888900, -76.6619400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103985, 'San Bartolo', 'San Bartolo', 'San Bartolo,Сан Бартоло', -12.3833300, -76.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103986, 'Sañayca', 'Sanayca', 'Sanaica,Sanayca,Sañaica,Sañayca,Zanaica', -14.2069400, -73.3355600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103987, 'San Agustin', 'San Agustin', 'San Agustin,San Agustin de Cajas,San Agustín,San Agustín de Cajas', -11.9719500, -75.2556200, 'PE', '2014-06-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103988, 'Samegua', 'Samegua', '', -17.1794400, -70.8988900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103989, 'Sama Grande', 'Sama Grande', '', -17.7925000, -70.4947200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103990, 'Salcabamba', 'Salcabamba', '', -12.2000000, -74.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103991, 'Sacsamarca', 'Sacsamarca', '', -13.9463900, -74.3113900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103992, 'Sabandia', 'Sabandia', '', -16.4666700, -71.5000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103993, 'Rosaspata', 'Rosaspata', 'Rosapata,Rosaspata', -15.2166700, -69.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103994, 'Río Grande', 'Rio Grande', 'Rio Grande,Río Grande', -14.5160000, -75.1993300, 'PE', '2015-10-05', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103995, 'Ricardo Palma', 'Ricardo Palma', 'Ricardo Palma', -11.9197800, -76.6561000, 'PE', '2013-12-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103996, 'Ranracancha', 'Ranracancha', 'Rangracancha,Ranracancha', -13.5336100, -73.6052800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103997, 'Quito-Arma', 'Quito-Arma', '', -13.5333300, -75.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103998, 'Quiquijana', 'Quiquijana', '', -13.8227800, -71.5394400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(103999, 'Quinua', 'Quinua', 'Comunidad de Quinua,Quinua', -13.0491700, -74.1386100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104000, 'Quiñota', 'Quinota', '', -14.3077800, -72.1361100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104001, 'Quinocay', 'Quinocay', '', -12.3666700, -76.2333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104002, 'Quinistaquillas', 'Quinistaquillas', 'Quinistaquilla,Quinistaquillas', -16.7500000, -70.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104003, 'Quince Mil', 'Quince Mil', 'UMI', -13.2309200, -70.7540100, 'PE', '2017-02-05', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104004, 'Quilmaná', 'Quilmana', 'Quillmana,Quilmana,Quilmaná', -12.9486000, -76.3811200, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104005, 'Quillabamba', 'Quillabamba', '', -12.8633400, -72.6930600, 'PE', '2015-03-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104006, 'Quilcata', 'Quilcata', '', -15.2477800, -73.4538900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104007, 'Quilca', 'Quilca', '', -16.7141700, -72.4352800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104008, 'Quilahuani', 'Quilahuani', '', -17.3177800, -70.2580600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104009, 'Quicacha', 'Quicacha', 'Quicacha,Quicacha Pueblo', -15.6258300, -73.7983300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104010, 'Quiaca', 'Quiaca', '', -14.4333300, -69.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104011, 'Queropalca', 'Queropalca', '', -10.1813900, -76.8038900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104012, 'Querobamba', 'Querobamba', '', -14.0133300, -73.8397200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104013, 'Quequeña', 'Quequena', '', -16.5577800, -71.4511100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104014, 'Quellouno', 'Quellouno', '', -12.6366700, -72.5594400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104015, 'Quehue', 'Quehue', '', -14.3800000, -71.4550000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104016, 'Quebrada Honda', 'Quebrada Honda', '', -12.7666700, -72.2333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104017, 'Putina', 'Putina', '', -15.4764000, -69.4329200, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104018, 'Putina', 'Putina', '', -14.9166700, -69.8666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104019, 'Pusi', 'Pusi', '', -15.4333300, -69.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104020, 'Puquio', 'Puquio', 'Puquio,Puqure', -14.7000000, -74.1333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104021, 'Puquina', 'Puquina', '', -16.6236100, -71.1844400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104022, 'Punta Hermosa', 'Punta Hermosa', 'Punta Hermosa', -12.3333300, -76.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104023, 'Punta de Bombón', 'Punta de Bombon', 'Bombon,La Punta,Punta de Bombon,Punta de Bombón', -17.1719000, -71.7924000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104024, 'Puno', 'Puno', 'Gorad Puna,Pouno,Punas,Punjo,Puno,Punu,Punum,San Carlos de Puno,pu no,pu nuo,puno,Πούνο,Горад Пуна,Пуно,Պունո,ปูโน,პუნო,プーノ,普诺,푸노', -15.8422000, -70.0199000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104025, 'Pullo', 'Pullo', '', -15.2166700, -73.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104026, 'Pujocucho', 'Pujocucho', '', -17.1577800, -70.3522200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104027, 'Puyca', 'Puyca', 'Puica,Puyca', -15.0600000, -72.6908300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104028, 'Puerto Supe', 'Puerto Supe', 'Puerto Supe', -10.8013500, -77.7433300, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104029, 'Puerto Ocopa', 'Puerto Ocopa', 'Puerto Ocapa,Puerto Ocopa', -11.1469400, -74.3058300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104030, 'Puerto Maldonado', 'Puerto Maldonado', 'Gorad Puehrta-Mal''danada,Maldonado,PEM,Portus Maldonatus,Puehrto-Mal''donado,Puerto Maldonadas,Puerto Maldonado,Puerto-Mal''donado,ma er duo na duo gang,pueleutomaldonado,pueruto・marudonado,pwrytw maldwnadw,pwyrtw maldwnadw,Горад Пуэрта-Мальданада,Пуерто Малдонадо,Пуерто-Мальдонадо,Пуэрто-Мальдонадо,פוארטו מלדונדו,پوئرتو مالدونادو,پوریتو مالدونادو,პუერტო-მალდონადო,プエルト・マルドナド,馬爾多納多港,푸에르토말도나도', -12.5933100, -69.1891300, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104031, 'Pueblo Nuevo', 'Pueblo Nuevo', 'Pueblo Nueva,Pueblo Nuevo', -14.1280600, -75.7066700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104032, 'Pucyura', 'Pucyura', 'Pucyura,Pukiura,Puquiura', -13.4788900, -72.1116700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104033, 'Pucusana', 'Pucusana', 'Pucusana,Puerto Chilca', -12.4833300, -76.8000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104034, 'Pucara', 'Pucara', '', -15.9799300, -71.4598800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104035, 'Pozuzo', 'Pozuzo', 'Posuso,Pozuso,Pozuzo', -10.0666700, -75.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104036, 'Potoni', 'Potoni', 'Potoni', -14.3833300, -70.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104037, 'Poroy', 'Poroy', 'Poro,Poroy', -13.4950000, -72.0433300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104038, 'Pomata', 'Pomata', '', -16.2666700, -69.3000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104039, 'Pomacocha', 'Pomacocha', '', -14.0844400, -73.5888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104040, 'Pomacocha', 'Pomacocha', '', -12.8500000, -74.5166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104041, 'Pomacanchi', 'Pomacanchi', '', -14.0269400, -71.5672200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104042, 'Pomacancha', 'Pomacancha', '', -11.7382800, -75.6244800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104043, 'Pomabamba', 'Pomabamba', '', -13.6044400, -74.2352800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104044, 'Pocsi', 'Pocsi', '', -16.5163900, -71.3883300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104045, 'Pocollay', 'Pocollay', 'Pocolla,Pocollay', -17.9916700, -70.2133300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104046, 'Pocohuanca', 'Pocohuanca', '', -14.2166700, -73.0833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104047, 'Pitumarca', 'Pitumarca', '', -13.9722200, -71.4100000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104048, 'Pisco', 'Pisco', 'Byen Pisco,PIO,Pisco,Piskas,Pisko,Pisqu llaqta,pi si ke,Писко,პისკო,皮斯科', -13.7102900, -76.2053800, 'PE', '2013-11-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104049, 'Pisac', 'Pisac', 'Pisac,Pisak,Писак', -13.4225000, -71.8466700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104050, 'Pirca', 'Pirca', '', -11.2344400, -76.6555600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104051, 'Pilpichaca', 'Pilpichaca', '', -13.3261100, -74.9975000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104052, 'Pillpinto', 'Pillpinto', '', -13.9541700, -71.7597200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104053, 'Pillcopata', 'Pillcopata', '', -13.0666700, -71.1666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104054, 'Pilcuyo', 'Pilcuyo', '', -16.1000000, -69.5666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104055, 'Pilcomay', 'Pilcomay', 'Pilcomay,Pilcomayo', -12.0472200, -75.2493100, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104056, 'Pilchaca', 'Pilchaca', '', -12.4000000, -75.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104057, 'Pichirhua', 'Pichirhua', 'Pichirgua,Pichirhua', -13.8608300, -73.0736100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104058, 'Pichigua', 'Pichigua', 'Pichigua,Pichihua,Santa Lucia,Santa Lucia de Pichigua,Santa Lucía de Pichigua', -14.6813900, -71.4169400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104059, 'Pichari', 'Pichari', 'Pichari', -12.5000000, -73.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104060, 'Phara', 'Phara', '', -14.1516700, -69.6630600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104061, 'Perené', 'Perene', 'Hacienda Perene,Hacienda Perené,Perene,Perené', -10.9451000, -75.2239400, 'PE', '2015-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104062, 'Pazos', 'Pazos', 'Pasos,Pazos', -12.2666700, -75.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104063, 'Pausa', 'Pausa', 'Pausa', -15.2797200, -73.3458300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104064, 'Paucartambo', 'Paucartambo', 'Paucartambo', -13.3152200, -71.5936400, 'PE', '2014-06-29', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104065, 'Paucarcolla', 'Paucarcolla', '', -15.7333300, -70.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104066, 'Paucarbamba', 'Paucarbamba', '', -12.5500000, -74.5500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104067, 'Paucar', 'Paucar', '', -10.3711100, -76.4436100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104068, 'Pativilca', 'Pativilca', 'Pativilca', -10.7000000, -77.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104069, 'Pataypampa', 'Pataypampa', 'Pataypampa,Patiapampa', -14.1750000, -72.6738900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104070, 'Patambuco', 'Patambuco', '', -14.3597200, -69.6188900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104071, 'Paruro', 'Paruro', 'Paruro', -13.7633300, -71.8494400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104072, 'Parco', 'Parco', '', -11.8001500, -75.5460300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104073, 'Paratia', 'Paratia', '', -15.4525000, -70.5986100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104074, 'Paramonga', 'Paramonga', 'Hacienda Paramonga,Paramonga,Paramonga Hacienda,Parmonga,Парамонга', -10.6666700, -77.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104075, 'Paracas', 'Paracas', 'Paracas,Parakas,Паракас', -13.8666700, -76.2666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104076, 'Pangoa', 'Pangoa', 'Pangoa,Pangos,Pongos-Casa', -12.1166700, -73.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104077, 'Pancan', 'Pancan', 'Pancan,Pancán', -11.7489900, -75.4863500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104078, 'Pampas Chico', 'Pampas Chico', '', -10.1153200, -77.3978300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104079, 'Pampas', 'Pampas', '', -13.2288900, -73.8941700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104080, 'Pampas', 'Pampas', 'Pampas,Pampasas,pan pa si,潘帕斯', -12.3949000, -74.8668700, 'PE', '2014-01-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104081, 'Pampamarca', 'Pampamarca', '', -14.1463900, -71.4594400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104082, 'Pampacolca', 'Pampacolca', 'Pampacola,Pampacolca', -15.7130600, -72.5741700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104083, 'Pampachiri', 'Pampachiri', 'Pampachiri', -14.1869400, -73.5438900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104084, 'Pampa Cangallo', 'Pampa Cangallo', 'Pampa Cangallo,Pampagallo', -13.5591700, -74.1952800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104085, 'Palpacachi', 'Palpacachi', 'Paipacachi,Palpacache,Palpacachi', -13.8700000, -72.5038900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104086, 'Palpa', 'Palpa', 'Palpa', -14.5336100, -75.1855600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104653, 'Atuona', 'Atuona', 'AUQ,Atouana,Atuana,Atuona', -9.8034200, -139.0420200, 'PF', '2016-07-25', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104654, 'Rikitea', 'Rikitea', 'Rihirea,Rikitea', -23.1202800, -134.9691700, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104655, 'Vaitape', 'Vaitape', 'Vaitape', -16.5074100, -151.7491300, 'PF', '2014-08-19', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104656, 'Vairao', 'Vairao', 'Port Vairao,Vaieri,Vairao', -17.7833300, -149.2833300, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104657, 'Uturoa', 'Uturoa', 'RFP,Uturoa', -16.7289100, -151.4448200, 'PF', '2013-11-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104658, 'Tohautu', 'Tohautu', 'Toahotu,Tohautu', -17.7500000, -149.3166700, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104659, 'Tiarei', 'Tiarei', '', -17.5333300, -149.3333300, 'PF', '2006-01-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104660, 'Tevaitoa', 'Tevaitoa', 'Peavitoa,Te Avi Toa,Tevaitoa', -16.7913900, -151.4889300, 'PF', '2017-01-09', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104661, 'Teavaro', 'Teavaro', '', -17.5000000, -149.7666700, 'PF', '2016-01-07', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104662, 'Teahupoo', 'Teahupoo', 'Teahupo,Teahupoo,Teahupu', -17.8333300, -149.2666700, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104663, 'Tautira', 'Tautira', 'Tautera,Tautira', -17.7333300, -149.1500000, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104664, 'Taunoa', 'Taunoa', 'Papeari,Taunoa', -17.7500000, -149.3500000, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104665, 'Punaauia', 'Punaauia', 'Punaauia,Punaavia', -17.6333300, -149.6000000, 'PF', '2013-11-02', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104666, 'Pueu', 'Pueu', 'Pucu,Pueu', -17.7333300, -149.2166700, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104667, 'Pirae', 'Pirae', 'Pirae', -17.5166700, -149.5333300, 'PF', '2013-08-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104668, 'Papetoai', 'Papetoai', 'Papeotai,Papetoai', -17.4953800, -149.8743700, 'PF', '2016-01-07', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104669, 'Papeete', 'Papeete', 'Gorad Papeehteh,PPT,Pape''ete,Papeehte,Papeete,Papeetė,Papeiti,Papete,Pape’ete,Papiete,Papiti,Vaiete,babyty,pa pe xe te,pa pi ti,papeete,papete,papiti,papyth,Παπεέτε,Горад Папеэтэ,Папеете,Папете,Папеэте,Պապեետե,بابيتي,پاپیته,پاپیٹی,पापीती,ปาเปเอเต,პაპეეტე,パペーテ,帕皮提,파페에테', -17.5373300, -149.5665000, 'PF', '2013-12-15', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104670, 'Papao', 'Papao', 'Papao,Papara', -17.7500000, -149.5500000, 'PF', '2013-08-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104671, 'Paopao', 'Paopao', 'Paopao', -17.5186300, -149.8219300, 'PF', '2016-01-07', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104672, 'Paea', 'Paea', 'Paca,Paea', -17.6833300, -149.5833300, 'PF', '2013-08-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104673, 'Otutara', 'Otutara', 'Mataiea,Otutara', -17.7666700, -149.4166700, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104674, 'Moerai', 'Moerai', '', -22.4513300, -151.3419100, 'PF', '2013-11-10', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104675, 'Mahina', 'Mahina', '', -17.5064800, -149.4889900, 'PF', '2013-08-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104676, 'Hitiaa', 'Hitiaa', 'Hitia,Hitiaa', -17.6000000, -149.3000000, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104677, 'Haapiti', 'Haapiti', '', -17.5635200, -149.8690500, 'PF', '2016-01-07', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104678, 'Fitii', 'Fitii', '', -16.7353500, -151.0327000, 'PF', '2015-03-31', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104679, 'Fare', 'Fare', 'Fane,Fané,Fare,Faré,HUH,Owharre', -16.7108500, -151.0345500, 'PF', '2015-04-04', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104680, 'Faaone', 'Faaone', 'Faaone,Faone', -17.6666700, -149.3000000, 'PF', '2012-01-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104681, 'Faanui', 'Faanui', 'Faanui,Fanui', -16.4867900, -151.7410200, 'PF', '2013-11-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104682, 'Faaa', 'Faaa', 'Faa''a,Faaa,Faa’a,Torea', -17.5500000, -149.6000000, 'PF', '2014-08-19', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104683, 'Arue', 'Arue', 'Arue,Arve', -17.5166700, -149.5000000, 'PF', '2013-08-18', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104684, 'Anau', 'Anau', '', -16.5166700, -151.7333300, 'PF', '2006-01-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104685, 'Afareaitu', 'Afareaitu', '', -17.5500000, -149.7833300, 'PF', '2016-01-07', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104686, 'Afaahiti', 'Afaahiti', '', -17.7500000, -149.2833300, 'PF', '2006-01-17', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104687, 'Taiohae', 'Taiohae', 'Hakapehi', -8.9109300, -140.0997200, 'PF', '2013-08-10', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104688, 'Tapuarava', 'Tapuarava', '', -18.4664700, -136.4632800, 'PF', '2017-01-09', 78);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104689, 'Wewak', 'Wewak', 'Vevak,Vevakas,WWK,Wewak,u~ewaku,wei wa ke,wewakeu,wwak,Вевак,وواک,ウェワク,韦瓦克,웨와크', -3.5496400, 143.6322900, 'PG', '2015-03-29', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104690, 'Wau', 'Wau', 'WUG,Wau', -7.3377800, 146.7164900, 'PG', '2015-04-02', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104691, 'Wabag', 'Wabag', 'WAB,Wabag', -5.4911900, 143.7215100, 'PG', '2017-07-07', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104692, 'Vanimo', 'Vanimo', 'Angriffs-Hafen,Attack Bay,VAI,Vanimo,Vanimo Government Station,Wanimo', -2.6837200, 141.3019500, 'PG', '2016-04-10', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104693, 'Vanimo', 'Vanimo', 'Vanimo', -2.6666700, 141.2666700, 'PG', '2013-07-11', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104694, 'Tari', 'Tari', 'TIZ,Tari,Tauri', -5.9022000, 142.9351100, 'PG', '2017-06-11', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104695, 'Rabaul', 'Rabaul', 'Exung,Gorad Rabaul,Nankai Shi,RAB,Rabaul,Rabaulas,Simpson Harbour,Simpson-Hafen,Simpsonhafen,la bao er,labaul,li bao,rabaula,rabauru,rabaywl,Горад Рабаул,Рабаул,רבאול,رابائول,रबौल,ラバウル,拉包爾,笠包,라바울', -4.1997900, 152.1642900, 'PG', '2016-04-14', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104696, 'Port Moresby', 'Port Moresby', 'Gorad Port-Morsbi,POM,Po Moresbi,Port Moresby,Port Moresmpi,Port Morsbi,Port Morsbis,Port-Moresbo,Port-Morsbi,Portmorsbi,Portus Moresbiensis,Pot Mosbi,Puerto Moresby,Pò Moresbi,bwrt mwrsby,mo er ci bi gang,mo er zi bi gang,phxrt mxr sbi,porata moraisabi,porta moresbi,poteumoleujeubi,potomoresubi,pwrt mwrsby,Πορτ Μόρεσμπι,Горад Порт-Морсбі,Порт Морсби,Порт-Морсби,Порт-Морсбі,Պորտ Մորսբի,פורט מורסבי,بورت مورسبي,صوبہ پورٹ مورسبائی,مورېسبى پورتى,پورت مورسبی,پورٹ مورسبی,پۆرت مۆرسبی,पोर्ट मॉरेस्बी,पोर्ट मोरेस्बी,ਪੋਰਟ ਮੋਰੈਸਬੀ,พอร์ตมอร์สบี,པོ་རོ་ཊི་མོ་རེ་སི་བི།,პორტ-მორზბი,ፖርት ሞርስቢ,ポートモレスビー,莫尔兹比港,포트모르즈비', -9.4431400, 147.1797200, 'PG', '2010-05-30', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104697, 'Porgera', 'Porgera', 'Porgera,RGE', -5.4630000, 143.1480000, 'PG', '2017-06-07', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104698, 'Popondetta', 'Popondetta', 'PNP,Popendetta,Popondetta,Попондетта', -8.7653600, 148.2325200, 'PG', '2015-04-02', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104699, 'Panguna', 'Panguna', 'Panguna', -6.3163900, 155.4848300, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104700, 'Mount Hagen', 'Mount Hagen', 'HGU,Hagen,Mount Hagen,Mt Hagen', -5.8574600, 144.2305800, 'PG', '2014-12-14', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104701, 'Morehead', 'Morehead', 'MHY,Morehead', -8.7106500, 141.6366800, 'PG', '2012-05-05', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104702, 'Minj', 'Minj', 'MZN,Minj', -5.9075200, 144.6915900, 'PG', '2013-05-03', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104703, 'Mendi', 'Mendi', 'MDU,Mendi,Менди', -6.1475500, 143.6563300, 'PG', '2015-04-12', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104704, 'Madang', 'Madang', 'Friedrich Wilhelms Harbour,Friedrich-Wilhelmshafen,MAG,Madang,Маданг', -5.2163900, 145.7987000, 'PG', '2015-04-11', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104705, 'Lorengau', 'Lorengau', 'Leronguan,Lorangau,Lorengau,Lorungau,Losa,Rorengau', -2.0341000, 147.2717300, 'PG', '2014-10-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104706, 'Lae', 'Lae', 'LAE,Lae,Laeh,Laeh shaary,Laė,la-e,lai cheng,layh,rae,Лае,Лаэ,Лаэ шаары,לאה,لائه,لائے,ラエ,莱城,라에', -6.7220800, 146.9846900, 'PG', '2014-08-18', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104707, 'Kwikila', 'Kwikila', '', -9.8184700, 147.6596800, 'PG', '2014-09-27', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104708, 'Kundiawa', 'Kundiawa', 'CMU,Kundiawa', -6.0166700, 144.9666700, 'PG', '2013-12-01', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104709, 'Kokopo', 'Kokopo', 'Kokopo', -4.3520200, 152.2632700, 'PG', '2012-01-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104710, 'Kokoda', 'Kokoda', 'KKD,Kodoka,Kokoda', -8.8777800, 147.7364200, 'PG', '2014-10-31', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104711, 'Kiunga', 'Kiunga', 'Kiunga,UNG', -6.1219300, 141.2906100, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104712, 'Kimbe', 'Kimbe', 'Kimbe,jin bei,kymbh,Кимбе,کمبے,کیمبه,金貝', -5.5508500, 150.1376600, 'PG', '2015-04-06', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104713, 'Kieta', 'Kieta', 'KIE,Kieta', -6.2166700, 155.6333300, 'PG', '2015-03-07', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104714, 'Kerema', 'Kerema', 'KMA,Kerema', -7.9630900, 145.7785100, 'PG', '2012-01-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104715, 'Kavieng', 'Kavieng', 'KVG,Kaewieng,Kavieng,Kawieng,Käwieng,ka wei en,kabien,kawyng,Кавиенг,Кавіенг,کاوینگ,カビエン,卡維恩', -2.5778300, 150.8072700, 'PG', '2015-04-23', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104716, 'Kandrian', 'Kandrian', 'KDR,Kandrian', -6.2043000, 149.5356800, 'PG', '2013-04-13', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104717, 'Kainantu', 'Kainantu', 'Kainantu,kainantu,kayynantw,Каинанту,کائینانتو,카이난투', -6.2887200, 145.8654800, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104718, 'Ihu', 'Ihu', 'IHU,Ihu', -7.8956900, 145.3940500, 'PG', '2015-04-07', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104719, 'Ialibu', 'Ialibu', '', -6.2820800, 143.9935400, 'PG', '2011-07-09', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104720, 'Goroka', 'Goroka', 'GKA,Garoka,Goroka,New Garoka', -6.0833600, 145.3873500, 'PG', '2012-01-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104721, 'Finschhafen', 'Finschhafen', 'FIN,Finschafen,Finschaven,Finschhafen', -6.6024300, 147.8681400, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104722, 'Daru', 'Daru', 'DAU,Dagwa,Daru,Daru Government Station,da lu,dalu,daru,darw,Дару,دارو,ダル,達魯,다루', -9.0778600, 143.2089300, 'PG', '2015-04-18', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104723, 'Bulolo', 'Bulolo', 'BUL,Bubolo,Bulolo', -7.2036000, 146.6401400, 'PG', '2017-06-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104724, 'Arawa', 'Arawa', 'Arava,Arawa,RAW,Арава', -6.2297700, 155.5659800, 'PG', '2015-02-04', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104725, 'Angoram', 'Angoram', 'AGG,Angoram,Angorum', -4.0625300, 144.0660900, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104726, 'Ambunti', 'Ambunti', 'AUJ,Ambunti', -4.2171700, 142.8183200, 'PG', '2013-12-24', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104727, 'Aitape', 'Aitape', 'ATP,Aitape,Berlin Harbour,Berlinhafen,Bodinhafen,Eitape', -3.1534100, 142.3629000, 'PG', '2016-05-16', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104728, 'Samarai', 'Samarai', 'Samarai,Samarar,Samaria', -10.6166700, 150.6666700, 'PG', '2012-01-17', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104729, 'Alotau', 'Alotau', 'Alotau,GUR,a luo tao,alwtayw,arotau,Алотау,آلوتائو,アロタウ,阿洛陶', -10.3150900, 150.4574200, 'PG', '2014-01-05', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104730, 'Buka', 'Buka', '', -5.4326100, 154.6709800, 'PG', '2015-03-12', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104731, 'Rauna', 'Rauna', '', -5.7359000, 144.2883400, 'PG', '2014-12-11', 172);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104087, 'Pallanchacra', 'Pallanchacra', '', -10.4152800, -76.2355600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104088, 'Palcamayo', 'Palcamayo', '', -11.2947200, -75.7736100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104089, 'Palca', 'Palca', '', -17.7752800, -69.9602800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104090, 'Palca', 'Palca', '', -15.2336100, -70.5972200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104091, 'Palca', 'Palca', '', -11.3461100, -75.5686100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104092, 'Paico', 'Paico', 'Paico,Payco', -14.0377800, -73.6436100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104093, 'Pacucha', 'Pacucha', '', -13.6088900, -73.3436100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104094, 'Pacocha', 'Pacocha', 'Pacoch,Pacocha', -17.5833300, -71.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104095, 'Pacobamba', 'Pacobamba', '', -13.6163900, -73.0861100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104096, 'Pachaconas', 'Pachaconas', '', -14.2225000, -73.0255600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104097, 'Paccho', 'Paccho', '', -10.9572200, -76.9322200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104098, 'Paccha', 'Paccha', '', -11.8541100, -75.5076700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104099, 'Paccha', 'Paccha', '', -11.4738900, -75.9600000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104100, 'Paccaritambo', 'Paccaritambo', 'Pacarientambo,Paccarictambo,Paccaritambo,Pajarictambo', -13.7591700, -71.9550000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104101, 'Pacaycasa', 'Pacaycasa', 'Pacaycasa,Pacayccasa', -13.0569400, -74.2136100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104102, 'Pacaraos', 'Pacaraos', 'Pacaraos,Pacaroos', -11.1861100, -76.6475000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104103, 'Pacapausa', 'Pacapausa', 'Pacapausa', -14.9513900, -73.3677800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104104, 'Paca', 'Paca', '', -11.7153900, -75.5158600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104105, 'Oyón', 'Oyon', 'Oyon,Oyón', -10.6684600, -76.7716500, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104106, 'Oyolo', 'Oyolo', '', -15.1797200, -73.1861100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104107, 'Oxapampa', 'Oxapampa', 'Oxapampa', -10.5775000, -75.4016700, 'PE', '2013-03-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104108, 'Otoca', 'Otoca', '', -14.4833300, -74.7000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104109, 'Orurillo', 'Orurillo', '', -14.7300000, -70.5130600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104110, 'Oropesa', 'Oropesa', 'Oropesa,Oropeza', -14.2561100, -72.5550000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104111, 'Oropesa', 'Oropesa', '', -13.5927800, -71.7719400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104112, 'Orcotuna', 'Orcotuna', '', -11.9688600, -75.3078000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104113, 'Orcopampa', 'Orcopampa', '', -15.2661100, -72.3416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104114, 'Ongoy', 'Ongoy', '', -13.4036100, -73.6697200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104115, 'Ondores', 'Ondores', 'Ondores,Ordones', -11.0865100, -76.1483100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104116, 'Omate', 'Omate', 'Omate', -16.6833300, -70.9833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104117, 'Omas', 'Omas', '', -12.5166700, -76.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104118, 'Omacha', 'Omacha', '', -14.0713900, -71.7397200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104119, 'Ollantaytambo', 'Ollantaytambo', 'Ol''jantajtambo,Olantajtambo,Oljantaintambas,Ollantaitambo,Ollantaytambo,Ullantaytampu,Ullantaytanpu,ao yang tai tan bo,oryantaitanbo,Олантајтамбо,Ольянтайтамбо,ოლიანტაიტამბო,オリャンタイタンボ,奧揚泰坦博', -13.2572200, -72.2630600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104120, 'Ollachea', 'Ollachea', '', -13.8166700, -70.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104121, 'Ocuviri', 'Ocuviri', '', -15.1111100, -70.9077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104122, 'Ocucaje', 'Ocucaje', 'Hacienda Ocucaje,Ocucaje,Ocucaje Hacienda', -14.3486100, -75.6691700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104123, 'Ocros', 'Ocros', '', -13.3913900, -73.9150000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104124, 'Ocros', 'Ocros', 'Ocros', -10.4029400, -77.3966600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104125, 'Ocoyo', 'Ocoyo', 'Ocoye,Ocoyo', -14.0080600, -75.0219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104126, 'Ocoruro', 'Ocoruro', '', -15.0525000, -71.1288900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104127, 'Ocongate', 'Ocongate', '', -13.6269400, -71.3852800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104128, 'Ocoña', 'Ocona', 'Ocona,Ocona Occidental,Ocoña,Ocoña Occidental,Pueblo Nuevo', -16.4330600, -73.1077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104129, 'Ocobamba', 'Ocobamba', 'Occobamba,Ocobamba', -13.4819400, -73.5611100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104130, 'Ocaña', 'Ocana', '', -14.3833300, -74.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104131, 'Ñuñoa', 'Nunoa', 'Nunoa,Ñuñoa', -14.4778800, -70.6358300, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104132, 'Nuevo Imperial', 'Nuevo Imperial', '', -13.0754100, -76.3171900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104133, 'Ninacaca', 'Ninacaca', '', -10.8500000, -76.1166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104134, 'Asentamiento Humano Nicolas de Pierola', 'Asentamiento Humano Nicolas de Pierola', 'Asentamiento Humano Nicolas de Pierola', -11.9357300, -76.7061100, 'PE', '2013-12-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104135, 'Nicasio', 'Nicasio', 'Nicasio', -15.2333300, -70.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104136, 'Nazca', 'Nazca', 'NZC,Nasca,Naska,Nazca,Placa de Nazca,Plaskowyz Nazca,Provincia de Nazca,Płaskowyż Nazca,na si ka,Наска,ნასკა,納斯卡', -14.8309800, -74.9389500, 'PE', '2013-02-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104137, 'Muquiyauyo', 'Muquiyauyo', '', -11.8137100, -75.4548200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104138, 'Muqui', 'Muqui', '', -11.8336400, -75.4346200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104139, 'Mungui', 'Mungui', '', -15.1827800, -72.9055600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104140, 'Muñani', 'Munani', 'Munani,Muñani', -14.7666700, -69.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104141, 'Mosca', 'Mosca', '', -10.3427800, -76.2916700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104142, 'Morococha', 'Morococha', 'Morococha', -11.5997200, -76.1411100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104143, 'Morcolla', 'Morcolla', '', -14.1105600, -73.8713900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104144, 'Moquegua', 'Moquegua', 'Gorad Makegua,Moceva,Mokegua,Mokegva,Moquegua,Mukiwa,Muqiwa,mo ke gua,mokegwa,mwkgwa,mwkygwa,Горад Макегуа,Мокегуа,Мокеґуа,موکگوا,موکیگوا,მოკეგუა,莫克瓜,모케과', -17.1983200, -70.9356700, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104145, 'Mollepampa', 'Mollepampa', '', -13.3000000, -75.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104146, 'Mollendo', 'Mollendo', 'Mol''endo,Moljendas,Mollendo,Mullintu,mo yan duo,Мольендо,莫延多', -17.0230600, -72.0147200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104147, 'Mollebamba', 'Mollebamba', '', -14.4213900, -72.9119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104148, 'Molinos', 'Molinos', '', -11.7364200, -75.4435600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104149, 'Moho', 'Moho', 'Moho', -15.3500000, -69.5000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104150, 'Miraflores', 'Miraflores', '', -12.2736100, -75.8500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104151, 'Mazo Cruz', 'Mazo Cruz', 'Mazo Cruz,Mazocruz Hacienda', -16.7500000, -69.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104152, 'Mazamari', 'Mazamari', 'MZA,Mazamani,Mazamari', -11.3258300, -74.5308300, 'PE', '2015-12-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104153, 'Mayocc', 'Mayocc', 'Mayoc,Mayocc', -12.7833300, -74.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104154, 'Matucana', 'Matucana', 'Matucana', -11.8500000, -76.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104155, 'Matalaque', 'Matalaque', '', -16.4833300, -70.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104156, 'Mariposa', 'Mariposa', '', -11.4025000, -74.7508300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104157, 'Mariatana', 'Mariatana', '', -12.2500000, -76.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104158, 'Margos', 'Margos', '', -10.0061100, -76.5225000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104159, 'Minas de Marcona', 'Minas de Marcona', 'Marcona,Mina Marcona,Minas de Marcona', -15.2119400, -75.1102800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104160, 'Marco', 'Marco', '', -11.7411700, -75.5627900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104161, 'Marcas', 'Marcas', '', -12.8833300, -74.3833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104162, 'Marcapomacocha', 'Marcapomacocha', 'Marcapomacocha,Marcopomacocha', -11.4069200, -76.3362800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104163, 'Marcapata', 'Marcapata', '', -13.5897200, -70.9722200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104164, 'Marcabamba', 'Marcabamba', '', -15.1505600, -73.3419400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104165, 'Marca', 'Marca', '', -10.0883300, -77.4743100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104166, 'Maray', 'Maray', '', -10.9355600, -76.8338900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104167, 'Maras', 'Maras', 'Maras', -13.3350000, -72.1566700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104168, 'Maranura', 'Maranura', '', -12.9630600, -72.6647200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104169, 'Maranganí', 'Marangani', '', -14.3567200, -71.1692400, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104170, 'Mara', 'Mara', '', -14.0852800, -72.1080600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104171, 'Mangas', 'Mangas', '', -10.3741100, -77.1020500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104172, 'Mañazo', 'Manazo', 'Manaso,Manazo,Mañaso,Mañazo', -15.8000000, -70.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104173, 'Mamara', 'Mamara', '', -14.2294400, -72.5861100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104174, 'Mala', 'Mala', '', -12.6580600, -76.6308300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104175, 'Madrigal', 'Madrigal', '', -15.6077800, -71.8080600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104176, 'Madean', 'Madean', '', -12.9444400, -75.7766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104177, 'Macusani', 'Macusani', 'Macusani', -14.0833300, -70.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104178, 'Macari', 'Macari', '', -14.7686100, -70.9019400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104179, 'Macachacra', 'Macachacra', 'Macachacra,Macrachaca', -12.9833300, -74.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104180, 'Maca', 'Maca', '', -15.6416700, -71.7694400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104181, 'Luricocha', 'Luricocha', '', -12.8500000, -74.2666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104182, 'Lucre', 'Lucre', '', -13.9491700, -73.2261100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104183, 'Lucre', 'Lucre', '', -13.6355600, -71.7375000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104184, 'Lucanas', 'Lucanas', '', -14.6000000, -74.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104185, 'Los Aquijes', 'Los Aquijes', '', -14.0966700, -75.6908300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104186, 'Locumba', 'Locumba', 'Locumba', -17.6133300, -70.7627800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104187, 'Locroja', 'Locroja', 'Locroja,Lucroja', -12.6833300, -74.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104188, 'Lluta', 'Lluta', '', -16.0147200, -72.0141700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104189, 'Llusco', 'Llusco', '', -14.3311100, -72.1147200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104190, 'Lloque', 'Lloque', '', -16.3333300, -70.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104191, 'Llocllapampa', 'Llocllapampa', '', -11.8178100, -75.6238200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104192, 'Llipata', 'Llipata', '', -14.5641700, -75.2077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104193, 'Llipa', 'Llipa', '', -10.3819500, -77.2057900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104194, 'Llauta', 'Llauta', '', -14.2666700, -74.9166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104195, 'Llalli', 'Llalli', '', -14.9333300, -70.8827800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104196, 'Llacllin', 'Llacllin', '', -10.0666700, -77.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104197, 'Llaclla', 'Llaclla', '', -10.2987500, -77.1453500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104198, 'Livitaca', 'Livitaca', 'Livitaca,Livitica', -14.3019400, -71.6872200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104199, 'Lircay', 'Lircay', '', -13.0000000, -74.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104200, 'Lincha', 'Lincha', '', -12.7986100, -75.6650000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104201, 'Limbani', 'Limbani', '', -14.1477800, -69.6888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104202, 'Limatambo', 'Limatambo', '', -13.4791700, -72.4425000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104203, 'Lima', 'Lima', 'Gorad Lima,LIM,Lim,Lima,Limae,Limaq,Lime,Limma,Limo,Lioma,Lungsod ng Lima,Lìmma,Líma,Líoma,Lîma,li ma,lima,lyma,lymh,rima,Λίμα,Горад Ліма,Лимæ,Лима,Лиме,Ліма,Լիմա,לימא,לימה,لىما,ليما,لیما,लिमा,लीमा,লিমা,ਲੀਮਾ,ଲିମା,லிமா,ലിമ,ลิมา,ལི་མ།,ლიმა,ሊማ,リマ,利馬,리마', -12.0431800, -77.0282400, 'PE', '2010-12-02', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104204, 'Leticia', 'Leticia', '', -11.3797200, -75.7538900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104205, 'Layo', 'Layo', '', -14.4936100, -71.1550000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104206, 'La Tinguiña', 'La Tinguina', '', -14.0358300, -75.7002800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104207, 'Las Yaras', 'Las Yaras', '', -17.8641700, -70.5627800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104208, 'Lari', 'Lari', '', -15.6222200, -71.7688900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104209, 'Lares', 'Lares', '', -13.1033300, -72.0438900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104210, 'Laraqueri', 'Laraqueri', '', -16.1333300, -70.0500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104211, 'Laraos', 'Laraos', '', -12.3466700, -75.7863900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104212, 'Laraos', 'Laraos', '', -11.6647200, -76.5394400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104213, 'Laramate', 'Laramate', 'Laramate', -14.2500000, -74.8666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104214, 'La Pampa', 'La Pampa', '', -16.6136100, -72.6963900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104215, 'La Oroya', 'La Oroya', 'La Oroja,La Oroya,La-Oroja,Oroya,Uruya,Uruya llaqta,la ao luo ya,Ла-Оройа,拉奧羅亞', -11.5189300, -75.8993500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104216, 'Lanlacuni Bajo', 'Lanlacuni Bajo', 'Lanlacuni,Lanlacuni Bajo,San Gaban', -13.4833300, -70.4166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104217, 'Langui', 'Langui', '', -14.4319400, -71.2730600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104218, 'Lampian', 'Lampian', '', -11.2377800, -76.8397200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104219, 'Lampa', 'Lampa', 'Lampa', -15.3500000, -70.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104220, 'Lampa', 'Lampa', '', -15.1844400, -73.3488900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104221, 'La Molina', 'La Molina', 'La Molina', -12.0833300, -76.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104222, 'La Merced', 'La Merced', 'La Merced', -11.0614600, -75.3350500, 'PE', '2014-06-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104223, 'Lambrama', 'Lambrama', '', -13.8666700, -72.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104224, 'Lamay', 'Lamay', '', -13.3641700, -71.9238900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104225, 'Lahuaytambo', 'Lahuaytambo', '', -12.1000000, -76.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104226, 'La Esmeralda', 'La Esmeralda', 'Anco,La Esmeralda', -12.6333300, -74.6000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104227, 'La Curva', 'La Curva', '', -17.1466700, -71.8216700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104228, 'Lachaqui', 'Lachaqui', '', -11.5533300, -76.6233300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104229, 'La Capilla', 'La Capilla', '', -16.7569400, -71.1791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104230, 'Kishuara', 'Kishuara', 'Kishuara,Quishuara', -13.6944400, -73.1163900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104231, 'Junín', 'Junin', 'Junin,Junín', -11.1589500, -75.9930400, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104232, 'Juliaca', 'Juliaca', 'Hullaqa,JUL,Juliaca,Khul''jaka,Khulijaka,furiaka,hu li ya ka,hulliaka,khwlyaka,Хулијака,Хульяка,خولیاکا,ხულიაკა,フリアカ,胡利亞卡,훌리아카', -15.5000000, -70.1333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104233, 'Juli', 'Juli', 'Juli,Juliaca', -16.2166700, -69.4500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104234, 'Julcan', 'Julcan', 'Julcan,Julcán', -11.7602500, -75.4358700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104235, 'Julcamarca', 'Julcamarca', '', -13.0127800, -74.4422200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104236, 'Jivia', 'Jivia', '', -10.0238900, -76.6791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104237, 'Jauja', 'Jauja', 'JAU,Jauja,Khaukha,Хауха', -11.7758400, -75.4965600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104238, 'Jatun Orcochiri', 'Jatun Orcochiri', '', -15.7500300, -71.3464100, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104239, 'Jarpa', 'Jarpa', 'Jarpa,San Juan de Jarpa', -12.1166700, -75.4666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104240, 'Jucul', 'Jucul', 'Jacul,Jucul,Jujul', -10.9486100, -76.7450000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104241, 'Izcuchaca', 'Izcuchaca', '', -12.4833300, -75.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104242, 'Iray', 'Iray', 'Irai,Iray', -15.8563900, -72.6255600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104243, 'Iquipi', 'Iquipi', '', -15.9402800, -73.1300000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104244, 'Ingenio', 'Ingenio', '', -11.8895000, -75.2655400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104245, 'Independencia', 'Independencia', '', -13.7000000, -76.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104246, 'Independencia', 'Independencia', '', -11.9900000, -77.0458300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104247, 'Incuyo', 'Incuyo', '', -15.2500000, -73.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104248, 'Inchupalla', 'Inchupalla', 'Ichupalla,Inchupalla', -15.0000000, -69.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104249, 'Iñapari', 'Inapari', 'Bolpebra,Inapari,Iñapari,Tacna', -10.9500000, -69.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104250, 'Imperial', 'Imperial', '', -13.0592700, -76.3526900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104251, 'Ilo', 'Ilo', 'ILQ,Ilas,Ilo,Ilu,New Ilo,Pacocha,ilo,yi luo,Іло,Ило,ილო,伊洛', -17.6394400, -71.3375000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104252, 'Ilave', 'Ilave', 'Ilave,Ylave', -16.0833300, -69.6666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104253, 'Ilabaya', 'Ilabaya', '', -17.4208300, -70.5133300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104254, 'Ihuari', 'Ihuari', 'Hiuari,Ihuari', -11.1891700, -76.9513900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104255, 'Ichupampa', 'Ichupampa', '', -15.6497200, -71.6875000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104256, 'Ichuña', 'Ichuna', '', -16.1500000, -70.5666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104257, 'Ica', 'Ica', 'Gorad Ika,Ica,Ika,aka  pyrw,ayka  prw,ika,yi ka,Іка,Горад Іка,Ика,اکا، پیرو,ایکا، پرو,იკა,イカ,伊卡,이카', -14.0677700, -75.7286100, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104258, 'Iberia', 'Iberia', 'IBP,Iberia', -11.3500000, -69.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104259, 'Humay', 'Humay', 'Huamai,Humay', -13.7166700, -75.9000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104260, 'Umamarca', 'Umamarca', 'Humamarca,Umamarca', -14.0527800, -73.5655600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104261, 'Huayucachi', 'Huayucachi', '', -12.1333300, -75.2333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104262, 'Huayrapata', 'Huayrapata', '', -15.3000000, -69.3333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104263, 'Huayllay', 'Huayllay', 'Huaillay,Huallay,Huayllay', -11.0036700, -76.3645200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104264, 'Huayllapampa', 'Huayllapampa', '', -10.0500000, -77.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104265, 'Huayllahuara', 'Huayllahuara', '', -12.4000000, -75.1666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104266, 'Huayllabamba', 'Huayllabamba', 'Huayabamba,Huayllabamba', -13.3380600, -72.0652800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104267, 'Huayana', 'Huayana', '', -14.0483300, -73.6097200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104268, 'Huayacundo Arma', 'Huayacundo Arma', '', -13.5363900, -75.3052800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104269, 'Huaura', 'Huaura', 'Huaura', -11.0700000, -77.5994400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104270, 'Huata', 'Huata', 'Huata,Huatta', -15.6166700, -69.9666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104271, 'Huasta', 'Huasta', '', -10.1238500, -77.1573300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104272, 'Huasahuasi', 'Huasahuasi', '', -11.2652700, -75.6472200, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104273, 'Huaros', 'Huaros', '', -11.4058300, -76.5769400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104274, 'Huarocondo', 'Huarocondo', 'Huaracondo,Huarocondo', -13.4133300, -72.2063900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104275, 'Huaro', 'Huaro', '', -13.6883300, -71.6358300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104276, 'Huarmey', 'Huarmey', 'Huarmei,Huarmey,Puerto de Huarmey', -10.0680600, -78.1522200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104277, 'Huaripampa', 'Huaripampa', '', -11.8081600, -75.4714300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104278, 'Huaribamba', 'Huaribamba', '', -12.2666700, -74.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104279, 'Huariaca', 'Huariaca', '', -10.4416700, -76.1902800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104280, 'Huaral', 'Huaral', 'Huaral,Uaral'',Waral,awaral,wa la er,Уараль,اوارال,瓦拉爾', -11.4950000, -77.2077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104281, 'Huaquirca', 'Huaquirca', 'Huadquirca,Huaquirca', -14.3313900, -72.8902800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104282, 'Huanza', 'Huanza', '', -11.6566700, -76.5033300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104283, 'Huanuara', 'Huanuara', 'Huanahuara,Huanuara', -17.3138900, -70.3219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104284, 'Huanta', 'Huanta', 'Huanta,Wanta,awanta,wan ta,اوانتا,萬塔', -12.9333300, -74.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104285, 'Huanoquite', 'Huanoquite', 'Huanoquite,Huanuquite', -13.6827800, -72.0166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104286, 'Huanipaca', 'Huanipaca', '', -13.5000000, -72.9333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104287, 'Huangascar', 'Huangascar', '', -12.8988900, -75.8311100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104288, 'Huancayo', 'Huancayo', 'Gorad Guankajo,Huancaya,Huancayo,Huankajus,Uankajo,Vancaium,Wankayu,awankayw,uangkayo,wan ka yue,wankashw,wankayo,wankayw,x wng kiy xo,Горад Гуанкаё,Уанкайо,Уанкајо,اوانکایو,وانكاشو,وانکایو,อวงไกย์โอ,უანკაიო,ワンカヨ,万卡约,우앙카요', -12.0651300, -75.2048600, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104289, 'Huancaya', 'Huancaya', '', -12.2030600, -75.7980600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104290, 'Huancavelica', 'Huancavelica', 'Huancavelica,Huankavelika,Uankavelika,Wankawillka,awankawlyka,uangkabellika,wan ka wei li ka,wankabylyka,Уанкавелика,Уанкавеліка,اوانکاولیکا,وانکابیلیکا,უანკაველიკა,萬卡韋利卡,우앙카벨리카', -12.7826100, -74.9726600, 'PE', '2014-01-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104291, 'Huancarqui', 'Huancarqui', '', -16.0958300, -72.4727800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104292, 'Huancaray', 'Huancaray', '', -13.7586100, -73.5275000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104293, 'Huancarama', 'Huancarama', '', -13.6452800, -73.0863900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104294, 'Huancapi', 'Huancapi', '', -13.7566700, -74.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104295, 'Huancano', 'Huancano', '', -13.6000000, -75.6166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104296, 'Hacienda Huancane', 'Hacienda Huancane', 'Hacienda Huancane,Huancane Hacienda', -15.8232700, -70.8854000, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104297, 'Huancabamba', 'Huancabamba', 'Huancabamba,Tingo de Huancabamba', -10.3500000, -75.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104298, 'Huampara', 'Huampara', '', -12.3500000, -76.1833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104299, 'Huambo', 'Huambo', 'Huambo', -15.7308300, -72.1075000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104300, 'Huambalpa', 'Huambalpa', '', -13.7497200, -73.9311100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104301, 'Huamatambo', 'Huamatambo', 'Huamantambo,Huamatambo', -13.1166700, -75.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104302, 'Huamantanga', 'Huamantanga', 'Huamantanga,Huamantango', -11.4991700, -76.7488900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104303, 'Huamanquiquia', 'Huamanquiquia', 'Huamanquiqui,Huamanquiquia', -13.7300000, -74.2727800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104304, 'Huamanguilla', 'Huamanguilla', '', -13.0111100, -74.1780600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104305, 'Huamali', 'Huamali', '', -11.8072200, -75.4243900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104306, 'Hualmay', 'Hualmay', '', -11.0963900, -77.6138900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104307, 'Huacrapuquio', 'Huacrapuquio', '', -12.1833300, -75.2166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104308, 'Huachos', 'Huachos', '', -13.2000000, -75.5166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104309, 'Huachocolpa', 'Huachocolpa', '', -13.0277800, -74.9458300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104310, 'Huacho', 'Huacho', 'Huacho,Uacho,Wachu llaqta,awachw,uacho,wa qiao,wachw,Уачо,اواچو,واچو,უაჩო,瓦喬,우아초', -11.1066700, -77.6050000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104311, 'Huacar', 'Huacar', '', -10.1602800, -76.2369400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104312, 'Huacaña', 'Huacana', '', -14.1736100, -73.8863900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104313, 'Hongos', 'Hongos', 'Hongos,Ongos', -12.8113900, -75.7650000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104314, 'Haquira', 'Haquira', '', -14.2127800, -72.1900000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104315, 'Guadalupe', 'Guadalupe', 'Guadalopi,Guadalupe,Salas', -13.9666700, -75.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104316, 'Goyllarisquizga', 'Goyllarisquizga', 'Goillarisquisga,Goyllarisquisga,Goyllarisquizga', -10.4738900, -76.4094400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104317, 'Gorgor', 'Gorgor', 'Corgor,Gorgor', -10.5833300, -77.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104318, 'Estique', 'Estique', '', -17.5416700, -70.0186100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104319, 'El Tambo', 'El Tambo', 'El Tambo,El Tambor', -12.0666700, -75.2166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104320, 'Progreso', 'Progreso', 'El Progreso,Progreso', -14.0725000, -72.4727800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104321, 'El Ingenio', 'El Ingenio', 'El Ingenio,Ingenio', -14.6452800, -75.0583300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104322, 'El Descanso', 'El Descanso', 'Descanso,El Descanso', -14.5333300, -71.3055600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104323, 'El Carmen', 'El Carmen', 'Carmen,El Carmen', -13.4971400, -76.0572400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104324, 'El Cardo', 'El Cardo', '', -16.6033300, -72.7263900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104325, 'Desaguadero', 'Desaguadero', '', -16.5655600, -69.0416700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104326, 'Cuyocuyo', 'Cuyocuyo', 'Cuyo Cuyo,Cuyocuyo', -14.4713900, -69.5372200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104327, 'Cusipata', 'Cusipata', '', -13.9075000, -71.4986100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104328, 'Cusco', 'Cusco', 'CUZ,Ciudad del Cuzco,Cosco,Cuschum,Cusco,Cuscu,Cuzco,Gorad Kuska,Kousko,Kuskas,Kusko,Qusqu,kosko,ku s ko,ku si ke,kucukko,kuseuko,kusko,kusuko,kuzko,kwzkw,qwsqw,Κούσκο,Горад Куска,Куско,Կուսկո,קוסקו,قوسقو,کوزکو,कुज़्को,कुस्को,কোস্কো,குசுக்கோ,กุสโก,კუსკო,クスコ,庫斯科,쿠스코', -13.5226400, -71.9673400, 'PE', '2013-03-16', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104329, 'Curibaya', 'Curibaya', '', -17.3825000, -70.3347200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104330, 'Curahuasi', 'Curahuasi', '', -13.5500000, -72.7000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104331, 'Cupi', 'Cupi', '', -14.9061100, -70.8741700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104332, 'Cullhuas', 'Cullhuas', '', -12.2333300, -75.1666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104333, 'Cuenca', 'Cuenca', 'Cuenca', -12.4333300, -75.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104334, 'Cuchumbaya', 'Cuchumbaya', 'Cachambaya,Cuchumbaya', -16.7500000, -70.6833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104335, 'Cruz Blanca', 'Cruz Blanca', '', -11.0972200, -77.5925000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104336, 'Crucero', 'Crucero', '', -14.3500000, -70.0000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104337, 'Coyllurqui', 'Coyllurqui', 'Collurque,Coyllurqui,Cuyllurqui', -13.8363900, -72.4308300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104338, 'Coya', 'Coya', 'Ceya,Colla,Coya', -13.3880600, -71.8997200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104339, 'Cotaruse', 'Cotaruse', 'Cotarosi,Cotaruse', -14.4158300, -73.2077800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104340, 'Cotaparaco', 'Cotaparaco', '', -10.0000000, -77.6000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104341, 'Cotahuasi', 'Cotahuasi', 'Cotahuasi', -15.2130600, -72.8886100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104342, 'Cotabambas', 'Cotabambas', '', -13.7463900, -72.3566700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104343, 'Corpanqui', 'Corpanqui', '', -10.2850800, -77.1987900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104344, 'Corire', 'Corire', 'Coiriri,Corire', -16.2236100, -72.4711100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104345, 'Corculla', 'Corculla', '', -15.2625000, -73.2005600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104346, 'Corani', 'Corani', '', -13.8711100, -70.6066700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104347, 'Coracora', 'Coracora', 'Coracora', -15.0333300, -73.7833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104348, 'Coporaque', 'Coporaque', '', -15.6272200, -71.6461100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104349, 'Coporaque', 'Coporaque', 'Coporaque,Corporaque', -14.8000000, -71.5325000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104350, 'Copa', 'Copa', '', -10.3882100, -77.0795600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104351, 'Copa', 'Copa', '', -10.3718100, -77.4874400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104352, 'Conima', 'Conima', 'Confina,Conima', -15.4333300, -69.4333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104353, 'Congas', 'Congas', '', -10.3371200, -77.4418800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104354, 'Condoroma', 'Condoroma', '', -15.2400000, -71.0822200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104355, 'Concho', 'Concho', 'Cconcho,Concho', -11.7250300, -75.5708600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104356, 'Conchamarca', 'Conchamarca', '', -10.0377800, -76.2152800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104357, 'Concepción', 'Concepcion', 'Concepcion,Concepción', -11.9176200, -75.3140100, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104358, 'Combapata', 'Combapata', '', -14.1011100, -71.4294400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104359, 'Comas', 'Comas', '', -11.7174000, -75.0811800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104360, 'Colta', 'Colta', 'Colpa,Colta', -15.1622200, -73.2947200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104361, 'Colquepata', 'Colquepata', '', -13.3558300, -71.6697200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104362, 'Colquemarca', 'Colquemarca', '', -14.2822200, -72.0419400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104363, 'Colpas', 'Colpas', '', -10.2688900, -76.4141700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104364, 'Colonia', 'Colonia', 'Colonia,Pampas', -12.6327800, -75.8905600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104365, 'Colcha', 'Colcha', '', -13.8519400, -71.8033300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104366, 'Colcabamba', 'Colcabamba', '', -14.0077800, -73.2477800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104367, 'Colcabamba', 'Colcabamba', 'Colcabamba,Colcabomba', -12.4000000, -74.7000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104368, 'Colca', 'Colca', '', -13.7147200, -74.0330600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104369, 'Colca', 'Colca', '', -12.3000000, -75.2166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104370, 'Cojata', 'Cojata', 'Cojasa,Cojata', -15.0166700, -69.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104371, 'Cochas', 'Cochas', '', -11.6570900, -75.1011900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104372, 'Cocharcas', 'Cocharcas', '', -13.6100000, -73.7400000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104373, 'Cocas', 'Cocas', '', -13.2666700, -75.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104374, 'Cocachacra', 'Cocachacra', 'Cocachacra,Cocahacra', -17.0883300, -71.7575000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104375, 'Cocachacra', 'Cocachacra', '', -11.9133300, -76.5383300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104376, 'Coayllo', 'Coayllo', '', -12.7333300, -76.4666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104377, 'Coata', 'Coata', '', -15.5666700, -69.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104378, 'Coasa', 'Coasa', '', -14.0000000, -69.9666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104379, 'Coalaque', 'Coalaque', '', -16.6505600, -71.0213900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104380, 'Circa', 'Circa', 'Circa,Sirca', -13.8741700, -72.8727800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104381, 'Cieneguilla', 'Cieneguilla', 'Cieneguilla,Cieneguilla Hacienda', -12.1333300, -76.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104382, 'Chuschi', 'Chuschi', 'Chuschi', -13.5855600, -74.3505600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104383, 'Churcampa', 'Churcampa', '', -12.7000000, -74.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104384, 'Chuquibambilla', 'Chuquibambilla', 'Chuquibambilla', -14.1019400, -72.7066700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104385, 'Chuquibamba', 'Chuquibamba', 'Chuquibamba', -15.8380600, -72.6536100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104386, 'Chupamarca', 'Chupamarca', '', -13.0333300, -75.6000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104387, 'Chupaca', 'Chupaca', '', -12.0666700, -75.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104388, 'Chupa', 'Chupa', 'Chupa', -15.1000000, -69.9833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104389, 'Chungui', 'Chungui', 'Chungui,Chunqui', -13.2186100, -73.6191700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104390, 'Chumpi', 'Chumpi', '', -15.1000000, -73.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104391, 'Chucatamani', 'Chucatamani', '', -17.4805600, -70.1225000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104392, 'Chosica', 'Chosica', 'Chosica,Nueva Chosica', -11.9430600, -76.7094400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104393, 'Chontabamba', 'Chontabamba', '', -10.5833300, -75.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104394, 'Chojata', 'Chojata', 'Choiata,Chojata', -16.4000000, -70.7333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104395, 'Chocos', 'Chocos', '', -12.9141700, -75.8630600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104396, 'Choco', 'Choco', '', -15.5755600, -72.1300000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104397, 'Chivay', 'Chivay', 'Chivay', -15.6383300, -71.6011100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104398, 'Chipispaya', 'Chipispaya', '', -17.4979000, -70.2171400, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104399, 'Chipao', 'Chipao', '', -14.3661100, -73.8766700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104400, 'Chincho', 'Chincho', '', -12.9666700, -74.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104401, 'Chincheros', 'Chincheros', 'Chincheros', -13.5183300, -73.7222200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104402, 'Chinchero', 'Chinchero', 'Chinchero,Chincheros', -13.3922200, -72.0477800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104403, 'Chinchaypujio', 'Chinchaypujio', 'Chinchaipujio,Chinchaipuquio,Chinchaypucyo,Chinchaypujio,Chinchaypuquio', -13.6300000, -72.2333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104404, 'Chincha Baja', 'Chincha Baja', '', -13.4589400, -76.1632500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104405, 'Chincha Alta', 'Chincha Alta', 'Chincha,Chincha Alta,Chincha-Al''ta,Cinca Alta,Hanan Chincha,chyncha alta,shang qin cha,Činča Alta,Чинча Алта,Чинча-Альта,چینچا آلتا,ჩინჩა-ალტა,上欽查', -13.4098500, -76.1323500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104406, 'Chilcas', 'Chilcas', '', -13.1713900, -73.9069400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104407, 'Chilca', 'Chilca', 'Chilca,Salinas', -12.5211100, -76.7372200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104408, 'Chiguata', 'Chiguata', 'Chiguata,Chihuata', -16.4000000, -71.4000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104409, 'Chicla', 'Chicla', '', -11.7063900, -76.2683300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104410, 'Chichas', 'Chichas', '', -15.5475000, -72.9186100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104411, 'Chicche', 'Chicche', '', -12.3000000, -75.2833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104412, 'Chiara', 'Chiara', '', -13.8680600, -73.6672200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104413, 'Chiara', 'Chiara', 'Chiapa,Chiara', -13.2727800, -74.2047200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104414, 'Checca', 'Checca', 'Checa,Checca', -14.4727800, -71.3938900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104415, 'Checacupe', 'Checacupe', 'Checacupe,Checcacupe', -14.0269400, -71.4527800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104416, 'Chaviña', 'Chavina', 'Chavina,Chaviña', -14.9833300, -73.8333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104417, 'Chaupimarca', 'Chaupimarca', '', -10.4069600, -76.4616800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104418, 'Chasquitambo', 'Chasquitambo', '', -10.3000000, -77.6000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104419, 'Charcana', 'Charcana', '', -15.2405600, -73.0711100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104420, 'Characato', 'Characato', '', -16.4666700, -71.4833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104421, 'Chapimarca', 'Chapimarca', '', -13.9752800, -73.0650000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104422, 'Changuillo', 'Changuillo', 'Chaguillo,Changuillo,San Juan de Changuillo,Shanguillo', -14.6641700, -75.2233300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104423, 'Chancay', 'Chancay', '', -11.5713900, -77.2672200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104424, 'Chambara', 'Chambara', '', -12.0166700, -75.3833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104425, 'Chamaca', 'Chamaca', '', -14.3083300, -71.8430600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104426, 'Challhuahuacho', 'Challhuahuacho', 'Callahuacho,Calluahuacho,Challahuacho,Challhuahuacho', -14.1166700, -72.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104427, 'Challabamba', 'Challabamba', '', -13.2041700, -71.6544400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104428, 'Chalhuanca', 'Chalhuanca', 'Calhuanca,Chalhuanca,Challhuanca', -14.3005600, -73.2308300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104429, 'Chalcos', 'Chalcos', 'Chalcos', -13.8477800, -73.7533300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104430, 'Chala', 'Chala', 'Chala,Puerto Chala', -15.8658300, -74.2469400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104431, 'Chaclacayo', 'Chaclacayo', 'Chaclacayo', -11.9827800, -76.7675000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104432, 'Chaccrampa', 'Chaccrampa', '', -13.9597200, -73.6091700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104433, 'Chacapampa', 'Chacapampa', '', -12.3500000, -75.2500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104434, 'Chacapalpa', 'Chacapalpa', 'Chacapalca,Chacapalpa', -11.7331500, -75.7557300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104435, 'Cerro de Pasco', 'Cerro de Pasco', 'Cerro de Pasco,Collis Pasca,Pasqu qullu,Pasqu urqu,Sero de Paskas,Serro-de-Pasko,krw dh paskw,sai luo de pa si ke,selodepaseuko,Серро-де-Паско,سیرو دے پاسکو,کرو ده پاسکو,სერო-დე-პასკო,セロ・デ・パスコ,塞羅德帕斯科,세로데파스코', -10.6674800, -76.2566800, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104436, 'Ccorca', 'Ccorca', 'Ccorca,Corca', -13.5850000, -72.0597200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104437, 'Ccapi', 'Ccapi', 'Capi,Ccapi', -13.8527800, -72.0791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104438, 'Cayna', 'Cayna', 'Caina,Cayna', -10.2716700, -76.3888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104439, 'Cayarani', 'Cayarani', '', -14.6722200, -72.0219400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104440, 'Cayara', 'Cayara', '', -13.7947200, -73.9888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104441, 'Cauri', 'Cauri', 'Cauri,Causi', -10.1416700, -76.6247200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104442, 'Ccatca', 'Ccatca', 'Catca,Ccatca,Ccatsa', -13.6047200, -71.5594400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104443, 'Catahuasi', 'Catahuasi', '', -12.7988900, -75.8919400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104444, 'Castrovirreyna', 'Castrovirreyna', 'Castrovirreina,Castrovirreyna,Castrovirriena', -13.2666700, -75.3166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104445, 'Carumas', 'Carumas', 'Caromas,Carumas', -16.8166700, -70.7166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104446, 'Carmen Alto', 'Carmen Alto', '', -13.1822200, -74.2247200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104447, 'Carhuanca', 'Carhuanca', '', -13.7425000, -73.7883300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104448, 'Carhuamayo', 'Carhuamayo', '', -10.9166700, -76.0333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104449, 'Carapo', 'Carapo', '', -13.8388900, -74.3119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104450, 'Carania', 'Carania', '', -12.3441700, -75.8683300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104451, 'Carampoma', 'Carampoma', '', -11.6608300, -76.5144400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104452, 'Caracoto', 'Caracoto', '', -15.5666700, -70.1000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104453, 'Carac', 'Carac', '', -11.1919400, -76.7802800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104454, 'Carabayllo', 'Carabayllo', 'Carabayllo', -11.8533300, -77.0377800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104455, 'Capaya', 'Capaya', '', -14.1194400, -73.3180600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104456, 'Capacmarca', 'Capacmarca', '', -14.0080600, -71.9980600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104457, 'Capachica', 'Capachica', 'Capachica,Capachico', -15.6333300, -69.8166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104458, 'Canta', 'Canta', 'Canta', -11.4672200, -76.6241700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104459, 'Canis', 'Canis', '', -10.3389900, -77.1694300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104460, 'Cangallo', 'Cangallo', 'Cangallo', -13.6286100, -74.1438900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104461, 'Candarave', 'Candarave', 'Candarave', -17.2677800, -70.2494400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104462, 'Canchayllo', 'Canchayllo', 'Canchaillo,Canchayllo,Chancayllo', -11.8058000, -75.7165000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104463, 'Canaria', 'Canaria', '', -13.9213900, -73.9052800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104464, 'Caminaca', 'Caminaca', '', -15.3166700, -70.0666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104465, 'Camilaca', 'Camilaca', '', -17.2680600, -70.3780600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104466, 'Camaná', 'Camana', 'Camana,Camaná', -16.6237500, -72.7105500, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104467, 'Callao', 'Callao', 'Callao,El Callao,Gorad Kal''jaa,Kajao,Kal''jao,Kalao,Kaljao,Kallao,Kallaw,Kalyao,Regio de Callao,Regió de Callao,ka ya e,kayao,kayaw,kayayw,klaw,Горад Кальяа,Кальяо,Каляо,Каяо,Каљао,Կալյաո,كاياو,کایائو,کایاو,کلاؤ,კალიაო,カヤオ,卡亞俄,카야오', -12.0565900, -77.1181400, 'PE', '2012-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104468, 'Callanmarca', 'Callanmarca', '', -12.8666700, -74.6333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104469, 'Callalli', 'Callalli', 'Callali,Callalli', -15.5083300, -71.4455600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104470, 'Callahuanca', 'Callahuanca', '', -11.8283300, -76.6163900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104471, 'Caleta de Carquín', 'Caleta de Carquin', 'Carquin,Carquín', -11.0925000, -77.6266700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104472, 'Calca', 'Calca', 'Calca,Colca', -13.3333300, -71.9500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104473, 'Calapuja', 'Calapuja', 'Calapuja', -15.3166700, -70.2166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104474, 'Calango', 'Calango', '', -12.5261100, -76.5427800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104475, 'Calana', 'Calana', 'Calana,Catana', -17.9416700, -70.1869400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104476, 'Calacoa', 'Calacoa', '', -16.7500000, -70.7000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104477, 'Cajacay', 'Cajacay', 'Cajacay', -10.1550200, -77.4396300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104478, 'Caja', 'Caja', '', -12.8833300, -74.4666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104479, 'Cairani', 'Cairani', '', -17.2858300, -70.3636100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104480, 'Caicay', 'Caicay', 'Caicai,Caicay', -13.5950000, -71.6994400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104481, 'Cahuacho', 'Cahuacho', '', -15.5061100, -73.4791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104482, 'Cacra', 'Cacra', 'Cacra,Cacras', -12.8127800, -75.7830600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104483, 'Cachora', 'Cachora', '', -13.5133300, -72.8100000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104484, 'Cachimayo', 'Cachimayo', '', -13.4758300, -72.0722200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104485, 'Cabanilla', 'Cabanilla', 'Cabanilla,Cabanillas', -15.6166700, -70.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104486, 'Cabanaconde', 'Cabanaconde', 'Cabaconde,Cabanaconde', -15.6213900, -71.9788900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104487, 'Cabana', 'Cabana', '', -15.6500000, -70.3166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104488, 'Cabana', 'Cabana', '', -14.2908300, -73.9666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104489, 'Bolognesi', 'Bolognesi', '', -10.0644400, -74.0050000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104490, 'Barranca', 'Barranca', 'Barranca', -10.7500000, -77.7666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104491, 'Baños', 'Banos', '', -10.0766700, -76.7352800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104492, 'Azángaro', 'Azangaro', 'Asangaro,Asángaro,Azangaro,Azángaro', -14.9084300, -70.1961600, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104493, 'Ayrampuni', 'Ayrampuni', '', -15.0500000, -69.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104494, 'Ayo', 'Ayo', '', -15.6816700, -72.2741700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104495, 'Ayna', 'Ayna', '', -12.6500000, -73.9166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104496, 'Ayaviri', 'Ayaviri', '', -14.8863900, -70.5888900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104497, 'Ayacucho', 'Ayacucho', 'AYP,Ajakucas,Ajakucho,Ajakuco,Ajakuĉo,Ajakučas,Ayacucho,Ayaquchu,Gorad Ajakucha,Vamanga,Wamanqa,a ya ku qiao,ayakucho,ayakwchw,Аякучо,Горад Аякуча,آیاکوچو,ایاکوچو,აიაკუჩო,アヤクーチョ,阿亚库乔,아야쿠초', -13.1587800, -74.2232100, 'PE', '2014-01-13', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104498, 'Aucallama', 'Aucallama', '', -11.5577800, -77.1808300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104499, 'Atuncolla', 'Atuncolla', '', -15.6833300, -70.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104500, 'Atiquipa', 'Atiquipa', '', -15.7961100, -74.3636100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104501, 'Atico', 'Atico', 'Alico,Atico', -16.2094400, -73.6222200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104502, 'Ataura', 'Ataura', 'Atahura,Ataura', -11.8013500, -75.4396900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104503, 'Asquipata', 'Asquipata', '', -14.0550000, -73.9100000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104504, 'Asillo', 'Asillo', 'Asillo', -14.7833300, -70.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104505, 'Asia', 'Asia', '', -12.7833300, -76.5666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104506, 'Arma', 'Arma', '', -13.1166700, -75.5333300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104507, 'Arequipa', 'Arequipa', 'AQP,Arecipa,Arekip,Arekipa,Arekipo,Arequipa,Arikipa,Ariqipa,Gorad Arehkipa,a lei ji pa,alekipa,arekipa,arekkippa,arkypa,arykyba,arykypa,xareki pa,Αρεκίπα,Арекипа,Арекіпа,Горад Арэкіпа,ארקיפה,أريكيبا,ارکیپا,اریکیپا,अरेकिपा,அரேக்கிப்பா,อาเรกีปา,არეკიპა,アレキパ,阿雷基帕,아레키파', -16.3988900, -71.5350000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104508, 'Arapa', 'Arapa', 'Arapa', -15.1333300, -70.1166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104509, 'Arahuay', 'Arahuay', 'Araguay,Arahuai,Arahuay', -11.6222200, -76.6694400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104510, 'Aquia', 'Aquia', '', -10.0740900, -77.1442300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104511, 'Apongo', 'Apongo', 'Apongo,Aspongo', -14.0147200, -73.9330600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104512, 'Aplao', 'Aplao', 'Aplao', -16.0758300, -72.4938900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104513, 'Apata', 'Apata', 'Apata,Aypata', -11.8546100, -75.3534400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104514, 'Antauta', 'Antauta', '', -14.4000000, -70.3666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104515, 'Antaparco', 'Antaparco', '', -13.0736100, -74.4119400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104516, 'Antabamba', 'Antabamba', 'Antabamba', -14.3605600, -72.8755600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104517, 'Anta', 'Anta', '', -13.4705600, -72.1483300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104518, 'Aniso', 'Aniso', '', -14.8086100, -73.2911100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104519, 'Andaray', 'Andaray', '', -15.7966700, -72.8605600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104520, 'Andarapa', 'Andarapa', '', -13.5261100, -73.3661100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104521, 'Andamarca', 'Andamarca', '', -14.3872200, -73.9608300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104522, 'Andamarca', 'Andamarca', '', -11.7319400, -74.8027800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104523, 'Andajes', 'Andajes', '', -10.7922200, -76.9094400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104524, 'Andahuaylillas', 'Andahuaylillas', 'Andahuailillas,Andahuaylillas,Andalmailillas', -13.6725000, -71.6794400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104525, 'Andahuaylas', 'Andahuaylas', 'ANS,Andahuailas,Andahuailasas,Andahuavlas,Andahuaylas,Antawaylla,an da wei la si,andahwaylas,andauailasi,انداهوایلاس,ანდაუაილასი,安達韋拉斯', -13.6555600, -73.3872200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104526, 'Anchonga', 'Anchonga', '', -12.8833300, -74.7000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104527, 'Ancahuasi', 'Ancahuasi', '', -13.4425000, -72.3108300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104528, 'Ananea', 'Ananea', 'Ananea,Poto', -14.7000000, -69.5500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104529, 'Ambo', 'Ambo', 'Ambo', -10.1308300, -76.2047200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104530, 'Ambar', 'Ambar', '', -10.7333300, -77.2666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104531, 'Alis', 'Alis', 'Alip,Alis', -12.2786100, -75.7869400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104532, 'El Algarrobal', 'El Algarrobal', 'Algarrobal,El Algarrobal', -17.6227800, -71.2677800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104533, 'Alca', 'Alca', '', -15.1347200, -72.7647200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104534, 'Ajoyani', 'Ajoyani', '', -14.1000000, -70.2000000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104535, 'Ayrihuanca', 'Ayrihuanca', 'Airihuanca,Ayrihuanca', -14.1047200, -72.6125000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104536, 'Ahuac', 'Ahuac', '', -12.0666700, -75.3500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104537, 'Acos', 'Acos', 'Acos,Acos Pueblo', -13.9508300, -71.7372200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104538, 'Acos', 'Acos', '', -11.2736100, -76.8208300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104539, 'Acoria', 'Acoria', '', -12.6166700, -74.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104540, 'Acomayo', 'Acomayo', 'Acomayo', -13.9166700, -71.6811100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104541, 'Acolla', 'Acolla', '', -11.7319300, -75.5463400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104542, 'Acocro', 'Acocro', '', -13.2177800, -74.0433300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104543, 'Acobambilla', 'Acobambilla', 'Acobambilla,Sallca Acobambilla', -12.6500000, -75.3833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104544, 'Acobamba', 'Acobamba', '', -12.8666700, -74.5666700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104545, 'Acobamba', 'Acobamba', '', -11.3525200, -75.6621100, 'PE', '2015-03-29', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104546, 'Accocunca', 'Accocunca', 'Acco Cunca,Accocunca,Aco,Acoccunca,Acocunca', -14.7694400, -71.2541700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104547, 'Aco', 'Aco', '', -11.9570700, -75.3699600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104548, 'Aco', 'Aco', '', -10.4971800, -77.2414900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104549, 'Achoma', 'Achoma', '', -15.6608300, -71.7008300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104550, 'Achaya', 'Achaya', 'Achaya', -15.2666700, -70.1500000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104551, 'Achanizo', 'Achanizo', '', -15.8061100, -73.9669400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104552, 'Accomarca', 'Accomarca', '', -13.8000000, -73.9030600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104553, 'Accha', 'Accha', '', -13.9738900, -71.8266700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104554, 'Acas', 'Acas', '', -10.4577800, -77.3272900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104555, 'Acarí', 'Acari', 'Acari,Acarí', -15.4239300, -74.6136100, 'PE', '2015-11-08', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104556, 'Abancay', 'Abancay', 'Abancai,Abancaius,Abancay,Abankaj,Abankajus,Abankay,Avan''kai,Awankay,Gorad Abankaj,a ban kai,abangkai,abankai,abankay,awankayy,Αβανκάι,Абанкай,Горад Абанкай,آبانکای,اوانکائی,აბანკაი,アバンカイ,阿班凯,아방카이', -13.6338900, -72.8813900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104557, 'Mosoc Llacta', 'Mosoc Llacta', '', -14.1200000, -71.4727800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104558, 'Taray', 'Taray', '', -13.4275000, -71.8675000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104559, 'Huayllati', 'Huayllati', 'Huaillati,Huayllati', -13.9277800, -72.4838900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104560, 'Sabaino', 'Sabaino', '', -14.3088900, -72.9466700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104561, 'Ayahuay', 'Ayahuay', '', -14.2077800, -73.0663900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104562, 'Huayllo', 'Huayllo', '', -14.1325000, -73.2686100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104563, 'Santo Tomas', 'Santo Tomas', '', -14.4455600, -72.0841700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104564, 'Caraybamba', 'Caraybamba', '', -14.3772200, -73.1613900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104565, 'San Antonio', 'San Antonio', '', -14.1647200, -72.6211100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104566, 'Curpahuasi', 'Curpahuasi', '', -14.0622200, -72.6697200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104567, 'Lomas', 'Lomas', '', -15.5680600, -74.8505600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104568, 'Huarancante', 'Huarancante', '', -15.7680300, -71.4595200, 'PE', '2012-11-09', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104569, 'Ccolo', 'Ccolo', '', -15.5061100, -71.4918400, 'PE', '2012-11-09', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104570, 'Huarichancara', 'Huarichancara', '', -15.6397200, -71.0611100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104571, 'Llongasora', 'Llongasora', '', -15.6395100, -71.2992100, 'PE', '2012-11-09', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104572, 'Jayune', 'Jayune', '', -15.5627700, -71.3031200, 'PE', '2012-11-09', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104573, 'Chuquitira', 'Chuquitira', '', -17.2889100, -70.0436300, 'PE', '2012-11-09', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104574, 'Pueblo Nuevo', 'Pueblo Nuevo', '', -17.6150000, -71.3383300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104575, 'Callanca', 'Callanca', '', -14.1813700, -71.1407000, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104576, 'Cullcuyre', 'Cullcuyre', '', -14.0927200, -71.3311900, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104577, 'Cahuanuyo', 'Cahuanuyo', '', -14.3414700, -71.4631100, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104578, 'Ccaquiracunca', 'Ccaquiracunca', '', -14.2768300, -71.4502600, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104579, 'Chignayhua', 'Chignayhua', '', -14.2461000, -71.4444200, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104580, 'Ccuntuma', 'Ccuntuma', '', -14.1254000, -71.4121600, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104581, 'Lima Pampa', 'Lima Pampa', '', -14.0897600, -71.3366400, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104582, 'Jayobamba', 'Jayobamba', '', -14.0942500, -71.3392200, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104583, 'Queromarca', 'Queromarca', '', -14.1839100, -71.3834300, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104584, 'Qquea', 'Qquea', '', -14.0541700, -71.3858300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104585, 'Conchopata', 'Conchopata', '', -14.4696800, -71.1984300, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104586, 'Mosoc Cancha', 'Mosoc Cancha', '', -14.2851400, -71.0877300, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104587, 'Huayna Alcalde', 'Huayna Alcalde', '', -14.2698900, -71.0959900, 'PE', '2012-12-06', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104588, 'Aucara', 'Aucara', '', -14.2808300, -73.9761100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104589, 'Huasahuasi', 'Huasahuasi', '', -11.2650000, -75.6508300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104590, 'Caujul', 'Caujul', '', -10.8052800, -76.9788900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104591, 'Bajo Pichanaqui', 'Bajo Pichanaqui', '', -10.9275000, -74.8741700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104592, 'Huaccana', 'Huaccana', 'Huaccana,Huajana', -13.3875000, -73.6897200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104593, 'Echarate', 'Echarate', 'Escharti,Ychupampa', -12.7351300, -72.6156800, 'PE', '2014-07-07', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104594, 'Genaro Herrera', 'Genaro Herrera', 'Jenaro Herrera', -4.9074100, -73.6677900, 'PE', '2014-07-28', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104595, 'Coviriali', 'Coviriali', '', -11.2925000, -74.6275000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104596, 'Kelluyo', 'Kelluyo', '', -16.7241700, -69.2555600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104597, 'Providencia', 'Providencia', '', -6.2975000, -78.2400000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104598, 'Chalamarca', 'Chalamarca', '', -6.4913900, -78.4686100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104599, 'Choropampa', 'Choropampa', '', -6.4375000, -78.3497200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104600, 'Collonce', 'Collonce', '', -6.2811100, -78.2127800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104601, 'Santa Catalina', 'Santa Catalina', '', -6.1116700, -78.0613900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104602, 'Duraznopampa', 'Duraznopampa', '', -6.5930600, -77.8080600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104603, 'Matacoto', 'Matacoto', '', -9.1783300, -77.7491700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104604, 'Carhuac', 'Carhuac', '', -9.2616700, -77.6927800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104605, 'Aco', 'Aco', '', -9.3691700, -77.5633300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104606, 'Cheto', 'Cheto', '', -6.2563900, -77.7002800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104607, 'Daguas', 'Daguas', '', -6.2266700, -77.7405600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104608, 'Longar', 'Longar', '', -6.3827800, -77.5452800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104609, 'Cochamal', 'Cochamal', '', -6.4063900, -77.5833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104610, 'Huambo', 'Huambo', '', -6.4280600, -77.5361100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104611, 'Parcoy', 'Parcoy', '', -8.0338900, -77.4791700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104612, 'Urpay', 'Urpay', '', -8.3472200, -77.3894400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104613, 'Ullulluco', 'Ullulluco', '', -8.4555600, -77.4266700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104614, 'Challas', 'Challas', '', -8.4383300, -77.3205600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104615, 'Huancaspata', 'Huancaspata', '', -8.4566700, -77.2983300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104616, 'Naranjos', 'Naranjos', '', -5.7427800, -77.4972200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104617, 'Bajo Naranjillo', 'Bajo Naranjillo', '', -5.8152800, -77.3827800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104618, 'Nueva Cajamarca', 'Nueva Cajamarca', '', -5.9405600, -77.3080600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104619, 'Saramiriza', 'Saramiriza', '', -4.5655600, -77.4158300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104620, 'Nuevo Progreso', 'Nuevo Progreso', '', -8.4525000, -76.3238900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104621, 'San Juan', 'San Juan', '', -3.8850000, -73.5672200, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104622, 'Yanahuanca', 'Yanahuanca', 'Yanahuanca', -10.4913900, -76.5166700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104623, 'Huabal', 'Huabal', '', -5.6161100, -78.9233300, 'PE', '2012-08-21', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104624, 'Buenos Aires', 'Buenos Aires', '', -9.1241700, -78.4975000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104625, 'Yuyapichis', 'Yuyapichis', '', -9.6273200, -74.9765800, 'PE', '2014-07-03', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104626, 'Pampamarca', 'Pampamarca', '', -9.7055300, -76.7020600, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104627, 'Llata', 'Llata', '', -9.5499900, -76.8161300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104628, 'Jacas Grande', 'Jacas Grande', '', -9.5396500, -76.7363900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104629, 'Cayhuayna', 'Cayhuayna', '', -9.9585100, -76.2485300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104630, 'Huancapallac', 'Huancapallac', '', -9.8941200, -76.4145500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104631, 'Paucarbamba', 'Paucarbamba', '', -9.9445900, -76.2232300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104632, 'El Rosario', 'El Rosario', '', -11.7853100, -75.6740800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104633, 'Masma Chicche', 'Masma Chicche', '', -11.7859300, -75.3784900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104634, 'Sausa', 'Sausa', '', -11.7931900, -75.4841400, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104635, 'Huertas', 'Huertas', '', -11.7680000, -75.4744100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104636, 'Mucllo', 'Mucllo', '', -11.6160700, -75.0911500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104637, 'Masma', 'Masma', '', -11.7850900, -75.4259700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104638, 'Matahuasi', 'Matahuasi', '', -11.8916100, -75.3435000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104639, 'Hualhuas', 'Hualhuas', '', -11.9714700, -75.2506500, 'PE', '2014-06-27', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104640, 'Saño', 'Sano', '', -11.9567100, -75.2568500, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104641, 'Quilcas', 'Quilcas', '', -11.9358100, -75.2595900, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104642, 'Quichuay', 'Quichuay', '', -11.8898200, -75.2857100, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104643, 'Rapayan', 'Rapayan', '', -9.2027300, -76.7596700, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104644, 'Anra', 'Anra', '', -9.2329000, -76.9232800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104645, 'Cochabamba', 'Cochabamba', '', -9.0953600, -76.8368800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104646, 'San Pedro De Cachora', 'San Pedro De Cachora', '', -13.6333300, -72.8833300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104647, 'Ledoy', 'Ledoy', '', -7.1282300, -76.6501800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104648, 'Pajarillo', 'Pajarillo', '', -7.1829800, -76.6933000, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104649, 'Shatoja', 'Shatoja', '', -6.5282100, -76.7182300, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104650, 'La Rinconada', 'La Rinconada', '', -14.6312600, -69.4463800, 'PE', '2012-07-19', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104651, 'Urb. Santo Domingo', 'Urb. Santo Domingo', '', -11.8765500, -77.0334500, 'PE', '2014-10-15', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104652, 'Indiana', 'Indiana', '', -3.4998900, -73.0513600, 'PE', '2015-06-24', 174);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104732, 'Zumarraga', 'Zumarraga', 'Zumarraga', 11.6388000, 124.8417000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104733, 'Zarraga', 'Zarraga', 'Zarraga,Zarrago', 10.8197200, 122.6080600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104734, 'Zaragoza', 'Zaragoza', 'Zaragoza', 16.3871000, 119.9443000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104735, 'Zamboanguita', 'Zamboanguita', 'Zamboanguit,Zamboanguita', 9.1025000, 123.1996000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104736, 'Zamboanga', 'Zamboanga', 'Burleigh School,Ciudad ti Zamboanga,Dakbayan sa Zamboanga,Lungsod ng Zamboanga,Syudad han Zamboanga,ZAM,Zamboanga,Zamboanga City,Zamboanga Lakanbalen,samboang-ga,san bao yan,sanboanga,Замбоанга,サンボアンガ,三宝颜,삼보앙가', 6.9102800, 122.0738900, 'PH', '2013-11-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104737, 'Yumbing', 'Yumbing', 'Yumbing', 9.2393000, 124.6578000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104738, 'Yubo', 'Yubo', 'Yubo', 10.3896000, 123.0690000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104739, 'Yook', 'Yook', 'Yooc,Yook', 13.2260800, 121.9640000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104740, 'Ilaya', 'Ilaya', 'Ilaya,Ylaya', 5.8152800, 125.2266700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104741, 'Yeban Norte', 'Yeban Norte', 'Yeban,Yeban Norte', 17.0219500, 121.9419400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104742, 'Wright', 'Wright', 'Wright', 11.7702800, 125.0219400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104743, 'Wines', 'Wines', 'Wines', 7.1938900, 125.3891700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104744, 'Wawa', 'Wawa', 'Wawa', 14.3019000, 121.4595000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104745, 'Wawa', 'Wawa', 'Uaua,Wawa', 13.7401000, 121.0529000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104746, 'Wawa', 'Wawa', 'Wawa', 13.4632000, 120.7441000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104747, 'Wao', 'Wao', '', 7.6833300, 124.6666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104748, 'Wañgan', 'Wangan', '', 7.1597200, 125.4452800, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104749, 'Vizal Santo Niño', 'Vizal Santo Nino', 'Vizal Santo Ninio,Vizal Santo Nino,Vizal Santo Niñio,Vizal Santo Niño', 15.0292400, 120.9050500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104750, 'Vizal San Pablo', 'Vizal San Pablo', 'Bisal,Visal,Vizal San Pablo', 15.0624700, 120.9002100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104751, 'Vito', 'Vito', 'Vito', 10.9031000, 123.5154000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104752, 'Vitali', 'Vitali', 'Tali,Vitali', 7.3711100, 122.2886100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104753, 'Vista Alegre', 'Vista Alegre', 'Vista Alegre', 9.9984000, 122.7663000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104754, 'Viriato', 'Viriato', 'Veriate,Virato,Viriato', 12.2903100, 124.3533300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104755, 'Virac', 'Virac', 'VRC,Virac,Virak,wyrak  katandwanys,Вирак,ویراک، کاتاندوانیس', 13.5848000, 124.2374000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104756, 'Vinzons', 'Vinzons', 'Indan,Vinzons', 14.1737000, 122.9066000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104757, 'Vintar', 'Vintar', 'Vintar', 18.2284000, 120.6475000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104758, 'Villaviciosa', 'Villaviciosa', 'Villaviciosa', 17.4379000, 120.6262000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104759, 'Villa Verde', 'Villa Verde', 'Villa Verde', 16.5988800, 121.1877400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104760, 'Villasis', 'Villasis', 'Villasis', 15.9016700, 120.5883300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104761, 'Villarosa', 'Villarosa', 'Villa Rosa,Villarosa', 15.5500000, 120.7500000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104762, 'Villareal', 'Villareal', 'Villareal', 11.5659000, 124.9281000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104763, 'Villanueva', 'Villanueva', 'Villanueva', 15.7984100, 120.5465400, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104764, 'Villanueva', 'Villanueva', 'Villanueva', 8.5888900, 124.7755600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104765, 'Villamor', 'Villamor', 'Villamor', 6.7047200, 124.5186100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104766, 'Villa Isla', 'Villa Isla', 'Villa Isla', 15.7703000, 120.8666000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104767, 'Villahermosa', 'Villahermosa', 'Hemosa,Villahermosa', 13.0458000, 123.7133000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104768, 'Villaba', 'Villaba', 'Villaba', 11.2135000, 124.3921000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104769, 'Villa Aglipay', 'Villa Aglipay', 'Villa Aglipay', 15.4660500, 120.4527300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104770, 'Vigo', 'Vigo', 'Vigo', 13.8266600, 120.1792200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104771, 'Viga', 'Viga', 'Viga,Vigo', 12.5162000, 125.0528000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104772, 'Vigan', 'Vigan', 'Cidade Historica de Vigan,Cidade Histórica de Vigan,Ciudad Fernandina,Dakbayan sa Vigan,Kota Vigan,Lungsod ng Vigan,Siyudad na Vigan,VGN,Vigan,Vigan City,Vigan Lakanbalen,Vigan shaary,Vinkan,bhigana,bigan,mei an,vigani,wi kan,wygan,Βιγκάν,Виган,Виган шаары,ויגאן,ویگان,भिगन,വിഗൻ,วีกัน,ვიგანი,ビガン,美岸,비간', 17.5747200, 120.3869400, 'PH', '2015-01-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104773, 'Biga', 'Biga', 'Biga,Bigaa,Viga,Vigo', 13.9040100, 120.6487500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104774, 'Viga', 'Viga', 'Viga', 13.8719000, 124.3091000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104775, 'Victorias', 'Victorias', 'Dakbayan sa Victorias,Syudad han Victorias,Victorias,Victorias City', 10.9015400, 123.0705000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104776, 'Victoria', 'Victoria', 'Victoria', 15.5775000, 120.6822000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104777, 'Victoria', 'Victoria', 'Nanhaya,Victoria,Viktorija,Виктория', 14.2277000, 121.3292000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104778, 'Victoria', 'Victoria', '', 13.1772200, 121.2780600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104779, 'Victoria', 'Victoria', 'Victoria,Viktorija,Виктория', 12.4472200, 124.3111100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104780, 'Biay', 'Biay', 'Biay,Viay', 15.7402000, 119.9067000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104781, 'Veruela', 'Veruela', 'Veruela', 8.0731000, 125.9558000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104782, 'Vargas', 'Vargas', 'Vargas', 15.5933200, 120.4870900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104783, 'Vallehermoso', 'Vallehermoso', 'Vallehermoso', 10.3349000, 123.3259000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104784, 'Valle Hermoso', 'Valle Hermoso', 'Valle Hermoso', 9.7939000, 124.2365000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104785, 'Valladolid', 'Valladolid', 'Valladolid', 10.4616000, 122.8245000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104786, 'Valenzuela', 'Valenzuela', 'Valenzuela', 14.7000000, 120.9667000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104787, 'Valencia', 'Valencia', '', 11.1088900, 124.5725000, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104788, 'East Valencia', 'East Valencia', 'East Valencia,South Valencia,Valencia', 10.6680000, 122.7100000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104789, 'Valencia', 'Valencia', 'Valencia', 10.1360000, 123.6126000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104790, 'Valencia', 'Valencia', 'Valencia', 9.7715800, 123.3674200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104791, 'Valencia', 'Valencia', 'Valencia,Valensija,Валенсия', 9.6097000, 124.2080000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104792, 'Valencia', 'Valencia', 'Luzuriaga,Luzurriaga,Valencia', 9.2815000, 123.2455000, 'PH', '2016-12-15', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104793, 'NIA Valencia', 'NIA Valencia', 'Kota Valencia,Valencia,Valencia City,Valencia Lakanbalen,Valensija,ba lun xi ya cheng,ballensia,Валенсия,巴伦西亚城,발렌시아', 7.9063900, 125.0941700, 'PH', '2017-04-28', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104794, 'Valderrama', 'Valderrama', 'Valderama,Valderrama', 11.4059100, 122.0837100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104795, 'Uyugan', 'Uyugan', 'San Antonio,Uyugan', 20.3504500, 121.9377700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104796, 'Uyong', 'Uyong', 'Oyong,Uyong', 16.0500200, 120.1207400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104797, 'Uyaan', 'Uyaan', 'Uyaan', 7.8630600, 124.0411100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104798, 'Uson', 'Uson', 'Uson', 12.2253000, 123.7834000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104799, 'Usab', 'Usab', 'Usab', 12.3297400, 123.5809100, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104800, 'Urdaneta', 'Urdaneta', 'Kota Urdaneta,Urdaneta Lakanbalen,Urdaneta de Pangasinan,Urdaneta de Pangasinán', 15.9761100, 120.5711100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104801, 'Urbiztondo', 'Urbiztondo', 'Urbistondo,Urbiztondo', 15.8227000, 120.3295000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104802, 'Upper San Mateo', 'Upper San Mateo', 'Upper San Mateo', 7.1730600, 124.5822200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104803, 'Upper Klinan', 'Upper Klinan', 'Upper Klinan', 6.2272200, 125.1208300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104804, 'Upig', 'Upig', 'Upeg,Upig', 15.0255100, 120.9919300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104805, 'Upi', 'Upi', 'Upi,Upi Norte,Upie', 17.0826200, 121.8345300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104806, 'Upi', 'Upi', 'North Upi,Upi,Upi Nuro', 7.0258300, 124.1666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104807, 'Unzad', 'Unzad', 'Unzad,Unzao', 15.9188900, 120.5391700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104808, 'Unisan', 'Unisan', 'Unisan', 13.8413200, 121.9752200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104809, 'Union', 'Union', 'Inyauan,Union', 11.7612000, 121.8963000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104810, 'Union', 'Union', 'Union', 10.6695000, 124.3252000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104811, 'Union', 'Union', 'Union', 10.0475000, 124.5151000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104812, 'Union', 'Union', 'Union', 9.7566700, 126.1102800, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104813, 'Unidos', 'Unidos', 'Unidos', 11.9067700, 122.0005100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104814, 'Unidos', 'Unidos', 'Unidos', 8.5942000, 123.6680000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104815, 'Unidad', 'Unidad', 'Unidad', 8.5355600, 126.2286500, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104816, 'Ungca', 'Ungca', 'Ungka', 10.7500000, 122.5500000, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104817, 'Umiray', 'Umiray', 'Umiray,Umirey', 15.2206000, 121.4111000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104818, 'Umingan', 'Umingan', 'Umingan', 15.9002100, 120.7984100, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104819, 'Umanday Centro', 'Umanday Centro', 'Umanday,Umanday Centro', 15.9380000, 120.2153000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104820, 'Umaganhan', 'Umaganhan', 'Omaganhan,Umaganhan', 11.3292000, 124.3770000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104821, 'Umabay', 'Umabay', 'Umabay', 12.3095400, 123.6796100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104822, 'Uling', 'Uling', 'Uling', 10.2804800, 123.7100000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104823, 'Ula', 'Ula', '', 7.1322200, 125.4922200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104824, 'Ugad', 'Ugad', 'Ugad', 17.3075000, 121.8004200, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104825, 'Ugac Sur', 'Ugac Sur', 'Ugac,Ugac Sur,Ugoc', 17.6132500, 121.7158300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104826, 'Uddiawan', 'Uddiawan', 'Uddiawan', 16.5588800, 121.1512400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104827, 'Odala', 'Odala', 'Odala,Udalo', 13.4776000, 120.8223000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104828, 'Ubay', 'Ubay', 'Ubay,ywbay  bhl,ابے، بوہول,یوبای، بهل', 10.0560000, 124.4729400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104829, 'Ualog', 'Ualog', 'Ualog', 10.5739600, 123.3933000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104830, 'Uacon', 'Uacon', 'Uacon', 15.6787000, 119.9403000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104831, 'Tuyum', 'Tuyum', 'Tuyom,Tuyum', 9.9769000, 122.5582000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104832, 'Tuyan', 'Tuyan', '', 6.0000000, 125.2833300, 'PH', '2011-09-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104833, 'Tuy', 'Tuy', 'Tuy', 14.0183000, 120.7296000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104834, 'Tutubigan', 'Tutubigan', 'Totubigan,Tutubigan,Tutugiban', 11.8397200, 125.0613900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104835, 'Tutay', 'Tutay', 'Tulay,Tutay', 10.2463000, 123.5805000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104836, 'Tupsan', 'Tupsan', 'Tupsan,Tupsan Pequeno', 9.1991700, 124.7769400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104837, 'Tupi', 'Tupi', 'Tupi', 6.3344400, 124.9527800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104838, 'Tupang', 'Tupang', 'Tupang', 17.9048300, 121.6409900, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104839, 'Tuod', 'Tuod', 'Tuod', 8.3433300, 124.3541700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104840, 'Tungol', 'Tungol', 'Tunggol,Tungol', 7.0808300, 124.7530600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104841, 'Tungawan', 'Tungawan', 'Lower Tungawan,Tungauan,Tungawan', 7.5080600, 122.3711100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104842, 'Tungao', 'Tungao', '', 8.7836800, 125.5958700, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104843, 'Tunga', 'Tunga', '', 11.2455600, 124.7516700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104844, 'Tumcon Ilawod', 'Tumcon Ilawod', 'Tumcon,Tumcon Ilauod,Tumcon Ilawod', 10.9166700, 122.6666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104845, 'Tumbagaan', 'Tumbagaan', 'Leug Tumbagaan,Tumbagaan', 5.3656000, 120.3139000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104846, 'Tumauini', 'Tumauini', 'Tumauini', 17.2766300, 121.8085400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104847, 'Tumarbong', 'Tumarbong', 'Tumarbong', 10.3765900, 119.4579000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104848, 'Tumalim', 'Tumalim', 'Tumalim', 14.0801000, 120.7231000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104849, 'Tumalaytay', 'Tumalaytay', 'Tumalaytay', 12.2758400, 123.2320100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104850, 'Tulunan', 'Tulunan', 'Tolonan,Tulunan', 6.8344400, 124.8769400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104851, 'Tuli', 'Tuli', 'Tuli', 7.2333300, 125.4166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104852, 'Tulay na Lupa', 'Tulay na Lupa', 'Tulay na Lupa', 14.0934000, 122.7862000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104853, 'Tulay', 'Tulay', 'Tulay', 14.2696900, 120.7692500, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104854, 'Tucuran', 'Tucuran', 'Tucuran,Tukuran', 7.8524000, 123.5743000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104855, 'Tuhian', 'Tuhian', 'Tuhian,Tuquian', 13.6222000, 122.2178000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104856, 'Tuguegarao', 'Tuguegarao', 'Lungsod ng Tuguegarao,TUG,Tuguegarao,Tuguegarao City,Tuguegaro', 17.6157700, 121.7228500, 'PH', '2016-09-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104857, 'Tugos', 'Tugos', 'Tugos', 14.2666700, 122.7500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104858, 'Tugdan', 'Tugdan', 'Tugdan', 12.3134000, 122.0853000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104859, 'Tugbong', 'Tugbong', '', 11.0166700, 124.6000000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104860, 'Tuganay', 'Tuganay', 'Tuganay', 7.3688900, 125.7230600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104861, 'Tuding', 'Tuding', 'Tocding,Toeding,Tuding', 16.4108500, 120.6422000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104862, 'Tudela', 'Tudela', 'Tudela', 10.6383000, 124.4728700, 'PH', '2015-04-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104863, 'Tudela', 'Tudela', 'Tudela', 8.2472000, 123.8424000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104864, 'Tucdao', 'Tucdao', 'Tucdao,Tucdaw', 11.7011000, 124.4719000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104865, 'Tuburan', 'Tuburan', 'Tuburan', 13.2417000, 123.5520300, 'PH', '2014-11-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104866, 'Tuburan', 'Tuburan', 'Tuburan', 10.7273000, 123.8257000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104867, 'Tuburan', 'Tuburan', 'Tuburan,Tuburan Proper', 6.6438900, 122.2736100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104868, 'Tubungan', 'Tubungan', 'Tubugon,Tubungan', 10.7640500, 122.3177000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104869, 'Tubod-dugoan', 'Tubod-dugoan', 'Tubod,Tubod-dugoan', 10.0443000, 123.4994000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104870, 'Tubod', 'Tubod', 'Tubod,Tubud', 9.9962500, 123.5725200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104871, 'Tubod', 'Tubod', 'Tubod', 9.5625000, 125.5708300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104872, 'Tubod', 'Tubod', 'Tubod,Tubud,twbd  lanayw dl nwrth,twbwd  lanaw shmaly,توبد، لانائو دل نورته,توبود، لاناؤ شمالی', 8.0555000, 123.7904000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104873, 'Tubod', 'Tubod', 'Tubod', 7.3716700, 125.6447200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104874, 'Tubli', 'Tubli', 'Tubli', 13.9318000, 124.1478000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104875, 'Tublay', 'Tublay', 'Tublay,twbly  bngwt,توبلی، بنگوت,توبلے، بنگوت', 16.5431000, 120.6096000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104876, 'Tibigan', 'Tibigan', 'Tibigan,Tubigon', 9.9518000, 123.9622000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104877, 'Tubigan', 'Tubigan', 'Tubigan', 8.5322200, 124.3122200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104878, 'Tubigagmanoc', 'Tubigagmanoc', 'Bubigagmanok,Tibugagmanok,Tubigagmanak,Tubigagmanoc,Tubigagmanok,Tubigmanoc,Tubigmanok', 10.6282000, 123.7489000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104879, 'Tubay', 'Tubay', 'Tubay', 9.1669400, 125.5238900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104880, 'Tubaran', 'Tubaran', '', 7.7666700, 124.1666700, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104881, 'Tubao', 'Tubao', 'Tubao,twbw  la ywnywn,twbwa  la ywnyn,توبو، لا یونیون,توبوا، لا یونین', 16.3482000, 120.4122000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104882, 'Tuban', 'Tuban', 'Tuban', 12.8122000, 120.8323000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104883, 'Tuban', 'Tuban', 'Tuban', 6.8227800, 125.3869400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104884, 'Tubalan', 'Tubalan', 'Tabalan,Tubalan', 6.4950000, 125.5661100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104885, 'Tubajon', 'Tubajon', '', 10.3316700, 125.5619400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104886, 'Tuba', 'Tuba', '', 16.3170900, 120.5492400, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104887, 'Tuao', 'Tuao', 'Tuao', 17.7364100, 121.4563500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104888, 'Tuao', 'Tuao', 'Tuao,Tuao Norte,Tuao Sur', 16.5883300, 121.2577800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104889, 'Sabang', 'Sabang', 'Sabang,Trinidad', 12.0746000, 124.5414000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104890, 'Trinidad', 'Trinidad', '', 10.0795500, 124.3432400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104891, 'Trento', 'Trento', 'Trento', 8.0458300, 126.0636100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104892, 'Trapiche', 'Trapiche', 'Trapiche,Trapichi', 10.6841700, 122.4322200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104893, 'Tranca', 'Tranca', 'Tranca', 14.1181500, 121.0574100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104894, 'Tran', 'Tran', 'Tran', 6.7202800, 124.0550000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104895, 'Totolan', 'Totolan', 'Totolan,Tutolan', 9.6328600, 123.8470200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104896, 'Tortosa', 'Tortosa', 'Tortosa,Tortoso', 10.9329400, 123.0900000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104897, 'Torrijos', 'Torrijos', 'Torrijos', 13.3167600, 122.0820500, 'PH', '2014-09-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104898, 'Toritori', 'Toritori', 'Tori-Tori,Toritori', 16.2382700, 119.9956100, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104899, 'Topdac', 'Topdac', 'Topdac,Topdak', 16.5553000, 120.7116000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104900, 'Toong', 'Toong', 'Toong', 14.0706300, 120.7633300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104901, 'Tongouson', 'Tongouson', 'Tong-Gusong,Tongouson,Tungosong', 5.0214000, 120.1328000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104902, 'Tondol', 'Tondol', 'Tondol,Tondul', 16.3104000, 120.0131000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104903, 'Tondod', 'Tondod', 'Tondad,Tondod,Tundod', 15.7182000, 120.9680000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104904, 'Tominhao', 'Tominhao', 'Tominhao,Tominjao,Tuminhau,Tuminhaw', 11.2356300, 124.0352600, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104905, 'Tomingad', 'Tomingad', 'Tomingad', 12.4431100, 122.0210600, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104906, 'Tombod', 'Tombod', 'Tombod', 15.9316800, 120.5672100, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104907, 'Tamayong', 'Tamayong', 'Tamayong,Tomayong', 7.1330600, 125.3797200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104908, 'Tomas Oppus', 'Tomas Oppus', 'San Isidro,Tomas Oppus', 10.2505600, 124.9830600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104909, 'Tomado', 'Tomado', 'Tomado', 7.1925000, 124.6080600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104910, 'Tolosa', 'Tolosa', '', 11.1000000, 125.0166700, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104911, 'Toledo', 'Toledo', 'Ciudad ti Toledo,Dakbayan sa Talisay,Toledo,Toledo City,Толедо', 10.3773000, 123.6386000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104912, 'Tocok', 'Tocok', 'Tocok', 15.7500000, 120.3000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104913, 'Tococ East', 'Tococ East', 'Tococ,Tococ East', 15.8249800, 120.4260500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104914, 'Tobuan', 'Tobuan', 'Tobuan,Tubuan', 16.0556200, 120.1102400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104915, 'Toboy', 'Toboy', 'Taboy,Taboy Norte,Toboy', 16.0271000, 120.6369000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104916, 'Toboso', 'Toboso', 'Escalante,Toboso', 10.7143500, 123.5162000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104917, 'Tiwi', 'Tiwi', 'Tiwi', 13.4585000, 123.6805000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104918, 'Tiwi', 'Tiwi', 'Tiwi', 10.9297200, 122.7341700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104919, 'Titay', 'Titay', 'Tifay,Titay', 7.8125000, 122.5344400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104920, 'Tiring', 'Tiring', 'Tiring', 10.8500000, 122.5067000, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104921, 'Tipo-Tipo', 'Tipo-Tipo', 'Tipo-Tipo', 6.5813900, 122.1794400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104922, 'Tipolo', 'Tipolo', 'Tipolo', 10.0196000, 124.5144000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104923, 'Tipaz', 'Tipaz', 'Tipas,Tipaz', 13.8285000, 121.4250600, 'PH', '2015-04-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104924, 'Tiparak', 'Tiparak', 'Tiparak', 8.0341000, 123.5288000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104925, 'Tinutulan', 'Tinutulan', 'Tinutulan', 7.1000000, 124.6500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104926, 'Tinongan', 'Tinongan', 'Tinongan,Tinungan', 10.2150000, 123.0352800, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104927, 'Tinubuan', 'Tinubuan', 'Tinubdan,Tinubuan', 11.1860000, 124.0078000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104928, 'Tinoto', 'Tinoto', 'Tinoto,Tinto', 5.8866700, 125.0705600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104929, 'Tinogboc', 'Tinogboc', 'Tinabooc,Tinaboot,Tinobog,Tinogboc', 12.0073700, 121.4122100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104930, 'Tiniguiban', 'Tiniguiban', 'Teneguiban,Tiniguiban', 11.3574000, 119.5049000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104931, 'Brgy. Tinigao, Kalibo', 'Brgy. Tinigao, Kalibo', '', 11.7000000, 122.3666700, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104932, 'Tingloy', 'Tingloy', 'Tinglay,Tingloy,Tingluy', 13.6609100, 120.8711000, 'PH', '2016-11-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104933, 'Tinglayan', 'Tinglayan', '', 17.2761100, 121.1625000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104934, 'Tindog', 'Tindog', 'Tindog,Tindog Norte,Tindug', 11.1247000, 124.0118000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104935, 'Tinawagan', 'Tinawagan', 'Tinalwagan,Tinawagan', 13.6500000, 123.4833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104936, 'Tinaogan', 'Tinaogan', 'Tinaogan,Tinoongan', 9.7791000, 123.1503000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104937, 'Tinang', 'Tinang', 'Tinang', 15.3762600, 120.6534300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104938, 'Tinampo', 'Tinampo', 'Tinampo', 13.2282500, 123.5072300, 'PH', '2014-11-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104939, 'Tinambacan', 'Tinambacan', 'Tinambacan', 12.0943000, 124.5025000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104940, 'Tinambac', 'Tinambac', 'Tinambac', 13.8164000, 123.3261000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104941, 'Tinalmud', 'Tinalmud', 'Tinalmud', 13.5941000, 122.8780000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104942, 'Tinago', 'Tinago', 'Tinago', 13.1833300, 123.6500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104943, 'Tinagacan', 'Tinagacan', 'Tinagakan,Tinagaken', 6.1991700, 125.2294400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104944, 'Tinaan', 'Tinaan', '', 11.2666700, 123.7500000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104945, 'Timpas', 'Timpas', 'Timpas', 11.4790000, 122.7324000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104946, 'Timonan', 'Timonan', 'Timonan', 8.2117000, 123.0682000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104947, 'Tiling', 'Tiling', 'Tiling', 9.9736000, 122.6544000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104948, 'Tilik', 'Tilik', 'Tilic,Tilig,Tilik,Titik', 13.8143600, 120.2002200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104949, 'Tikiw', 'Tikiw', 'Tikiw,Tiquio', 15.3119300, 120.8611600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104950, 'Ticala-an', 'Ticala-an', 'Ticala-an,Tikalaan', 8.0352800, 124.6208300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104951, 'Tigum', 'Tigum', 'Tigum', 10.7833300, 122.5666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104952, 'Tiguisan', 'Tiguisan', 'Tiguisan', 12.8394100, 121.4605200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104953, 'Tiguion', 'Tiguion', 'Tiguion', 13.3347000, 121.8610000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104954, 'Tiguib', 'Tiguib', 'Tiguib', 9.8008000, 123.1352000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104955, 'Tigui', 'Tigui', 'Tigiui,Tigui,Tiguion,Tigwi', 13.2681000, 122.0415000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104956, 'Tigtabon', 'Tigtabon', 'Tabtabon,Tagtabon', 6.8955600, 122.1669400, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104957, 'Tignoan', 'Tignoan', 'Tignoan,Tignuan', 14.5652200, 121.6178600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104958, 'Tignapalan', 'Tignapalan', 'Tignapoloan', 8.2638900, 124.5747200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104959, 'Tiglauigan', 'Tiglauigan', 'Tiglauigan,Tiglawigan', 10.9527000, 123.3575000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104960, 'Tigbinan', 'Tigbinan', 'Tigbinan', 14.1864800, 122.4692300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104961, 'Tigbauan', 'Tigbauan', 'Tigbauan,Tigbuan', 10.6746600, 122.3776000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104962, 'Tigbao', 'Tigbao', 'Tigbao,Tigbaw', 12.5546000, 123.3389000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104963, 'Tigbaw', 'Tigbaw', 'Tigbao,Tigbaw', 12.1483000, 123.5909000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104964, 'Tigbao', 'Tigbao', '', 7.4283300, 122.3275000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104965, 'Tigaon', 'Tigaon', 'Tigaon', 13.6331000, 123.4968000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104966, 'Tigao', 'Tigao', 'Tigao', 9.2088900, 126.1761100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104967, 'Tiep', 'Tiep', 'Tiep', 16.2382000, 119.8609000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104968, 'Tidman', 'Tidman', '', 8.2986100, 126.3388900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104969, 'Tiblawan', 'Tiblawan', 'Ascension,Tiblauan,Tiblawan', 6.4783400, 126.1082800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104970, 'Tibiao', 'Tibiao', 'Tibiao', 11.2915200, 122.0354100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104971, 'Tibanbang', 'Tibanbang', 'Tibanban,Tibanbang', 6.6315300, 126.1054800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104972, 'Tibagon', 'Tibagon', 'Tibagon', 7.2327000, 125.8628000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104973, 'Tiaong', 'Tiaong', 'Tiaong', 13.9638300, 121.3212100, 'PH', '2012-06-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104974, 'Ternate', 'Ternate', 'Ternate', 14.2897000, 120.7168000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104975, 'Teresita', 'Teresita', 'Teresita', 6.4136100, 124.7072200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104976, 'Teresa', 'Teresa', 'Teresa,Tereza,Тереза', 14.5612000, 121.2195000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104977, 'Telbang', 'Telbang', 'Telbang', 16.1724100, 120.0607400, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104978, 'Telafas', 'Telafas', 'Telafas', 6.6352800, 124.9750000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104979, 'Telabastagan', 'Telabastagan', 'Telabastagan', 15.1185400, 120.6077300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104980, 'Tebag East', 'Tebag East', 'Tebag,Tebag East', 15.9812300, 120.4674000, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104981, 'T”boli', 'T"boli', '', 6.2000000, 124.8333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104982, 'Taywanak Ilaya', 'Taywanak Ilaya', 'Taywanak,Taywanak Ilaya', 14.1575900, 120.8465500, 'PH', '2014-03-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104983, 'Tayum', 'Tayum', 'Tayum', 17.6172000, 120.6542000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104984, 'Tayug', 'Tayug', 'Tayug', 16.0274000, 120.7434000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104985, 'Tayud', 'Tayud', 'Tayud', 10.3799100, 124.0052200, 'PH', '2016-09-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104986, 'Taytayan', 'Taytayan', 'Taytayan', 10.8787000, 123.9771000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104987, 'Taytayan', 'Taytayan', 'San Antonio,Taytayan', 7.7338900, 126.5019400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104988, 'Taytay', 'Taytay', 'Taytay', 14.5588300, 121.1328500, 'PH', '2014-09-24', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104989, 'Taytay', 'Taytay', 'Taytay', 14.1256700, 121.4039900, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104990, 'Taytay', 'Taytay', 'Taytay', 10.8178800, 119.4985100, 'PH', '2014-09-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104991, 'Taytay', 'Taytay', 'Taytay', 8.5411100, 124.5397200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104992, 'Taysan', 'Taysan', 'Taysan', 13.8697000, 121.0971000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104993, 'Taysan', 'Taysan', 'Taysan', 13.7976000, 121.1896000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104994, 'Tayasan', 'Tayasan', 'Tayasan', 9.9240000, 123.1699000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104995, 'Tayaman', 'Tayaman', 'Tayaman', 13.2295000, 120.5726000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104996, 'Tayabo', 'Tayabo', 'Rosaldo,Tayabo', 15.8345000, 121.0309000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104997, 'Tayabas', 'Tayabas', 'Tayabas', 14.0259000, 121.5929000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104998, 'Tawan tawan', 'Tawan tawan', 'Tawan tawan', 7.1691700, 125.3727800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(104999, 'Tawagan', 'Tawagan', 'Tanagun,Tawagan Sur', 7.8450000, 123.4752800, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105000, 'Taviran', 'Taviran', 'Tariran,Taviran', 7.1233300, 124.3197200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105001, 'Taungoh', 'Taungoh', 'Taungo,Taungoh,Taungon,Taungu', 4.7065400, 119.4929600, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105002, 'Tawala', 'Tawala', 'Taiwala,Tauala,Tawala', 9.5542100, 123.7695500, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105003, 'Tarusan', 'Tarusan', 'Tarusan', 8.6546100, 117.5104000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105004, 'Tartaro', 'Tartaro', 'Taltaro,Tartaro', 15.1666700, 121.0166700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105005, 'Tarragona', 'Tarragona', 'Tarragona', 7.0491000, 126.4470800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105006, 'Tarong', 'Tarong', 'Tarong', 11.5314000, 123.1320000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105007, 'Tarlac City', 'Tarlac City', 'Tarlac,Tarlac City', 15.4801700, 120.5979400, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105008, 'Tariric', 'Tariric', 'Tariric', 13.5723000, 123.2235000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105009, 'Tariji', 'Tariji', 'Tariji', 15.5211200, 120.6144200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105010, 'Tarangnan', 'Tarangnan', 'Taranga,Tarangan,Tarangnan', 11.9009000, 124.7459000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105011, 'Tara', 'Tara', 'Tara', 13.8166700, 122.9833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105012, 'Tapon', 'Tapon', 'Tapon', 10.0631000, 123.4453000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105013, 'Tapon', 'Tapon', 'Tapon', 9.7715000, 123.5268000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105014, 'Tapilon', 'Tapilon', 'Tablon,Tapilon', 11.2774000, 124.0306000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105015, 'Tapikan', 'Tapikan', 'Tapikan', 6.8519400, 124.3225000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105016, 'Tapia', 'Tapia', 'Tapia', 7.7541700, 126.0119400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105017, 'Tapel', 'Tapel', 'Tapal,Tapel', 18.2890700, 122.0291500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105018, 'Tapas', 'Tapas', 'Tapas,Tapaz', 11.2613000, 122.5364000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105019, 'Tapayan', 'Tapayan', 'Tapayan', 7.2944400, 124.2661100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105020, 'Tanza', 'Tanza', 'Tanza', 14.6753000, 120.9389000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105021, 'Tanza', 'Tanza', '', 14.3983400, 120.8554400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105022, 'Tanza', 'Tanza', 'Tanza', 11.5825000, 122.7836100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105023, 'Tanza', 'Tanza', 'Tanza', 10.8348400, 123.0110000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105024, 'Tanudan', 'Tanudan', '', 17.2955600, 121.2377800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105025, 'Tantangan', 'Tantangan', 'Tantangan', 6.6150000, 124.7488900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105026, 'Tangke', 'Tangke', 'Tangke,Tanke,Tanque', 10.2545100, 123.8651600, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105027, 'Tanolong', 'Tanolong', 'Tanolong', 15.8041100, 120.4140900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105028, 'Tanlad', 'Tanlad', 'Tanglad,Tanlad', 6.6022200, 125.4450000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105029, 'Tanjay', 'Tanjay', 'Kota Tanjay,Tanjay,Tanjay City,Tanjay Lakanbalen', 9.5162000, 123.1580000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105030, 'Tangub', 'Tangub', 'Tangob,Tangub,Tangub City', 8.0618000, 123.7477000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105031, 'Tañgo', 'Tango', 'Tango,Tañgo', 5.8808300, 125.2219400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105032, 'Tangnan', 'Tangnan', '', 9.6072200, 123.7735700, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105033, 'Tangalan', 'Tangalan', 'Dapdap Tangalan,Tangalan', 11.7789000, 122.2634000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105034, 'Tangal', 'Tangal', 'Tangal,Tangol', 13.8453600, 120.1008200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105035, 'Tandoc', 'Tandoc', 'Tandoc', 15.9592900, 120.3291400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105036, 'Tandayag', 'Tandayag', 'Tandayag', 9.4547000, 123.2299000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105037, 'Tandag', 'Tandag', 'Dakbayan sa Tandag,Kota Tandag,Lungsod ng Tandag,TDG,Tandag,Tandag City,Tandag Lakanbalen,tandag,تانداگ', 9.0783300, 126.1986100, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105038, 'Tanay', 'Tanay', 'Tanay', 14.4968000, 121.2846000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105039, 'Tanauan', 'Tanauan', 'Kota Tanauan,Tanauan City,Tanauan Lakanbalen', 14.0862700, 121.1497500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105040, 'Tanauan', 'Tanauan', 'Tanauan', 11.1094400, 125.0155600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105041, 'Tamugan', 'Tamugan', 'Tamugan', 7.2308300, 125.3763900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105042, 'Tampocon', 'Tampocon', 'Tampocon', 9.8500000, 123.1333300, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105043, 'Tampilisan', 'Tampilisan', '', 8.0166700, 122.6833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105044, 'Tampayan', 'Tampayan', 'Tampayan', 12.4941100, 122.5330900, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105045, 'Tamparan', 'Tamparan', 'Tamparan', 7.8791700, 124.3330600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105046, 'Tampakan', 'Tampakan', 'Tampacan,Tampakan', 6.4441700, 124.9263900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105047, 'Tampakan', 'Tampakan', 'Tampacan,Tampakan', 4.9227800, 119.7938900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105048, 'Tamorong', 'Tamorong', '', 17.3333300, 120.4333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105049, 'Tamontaka', 'Tamontaka', 'Tamontaca', 7.1805600, 124.2255600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105050, 'Tamnag', 'Tamnag', 'Tamnag', 6.5677800, 124.8505600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105051, 'Tamlang', 'Tamlang', 'Tamlang,Tamlang Nuevo', 10.8254400, 123.4541000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105052, 'Tamiso', 'Tamiso', 'T. Real,Tamiso,Tamisu', 9.6314000, 123.0873000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105053, 'Tamisan', 'Tamisan', 'Tamisan', 6.8437200, 126.2983800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105054, 'Tambulig', 'Tambulig', 'Tambuig,Tambulig', 8.0702000, 123.5348000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105055, 'Tambalan', 'Tambalan', 'Tambalan,Tambulan', 9.9085000, 123.0896000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105056, 'Tambongon', 'Tambongon', 'Tambongon', 10.9677000, 123.9244000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105057, 'Tombongon', 'Tombongon', 'Tambongon,Tombongon', 7.0792000, 125.9486000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105058, 'Tambong', 'Tambong', 'Tambong', 12.9639100, 121.4846200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105059, 'Tambo', 'Tambo', 'Tambo', 13.5468000, 123.0358000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105060, 'Tambo', 'Tambo', 'Tambo', 13.2553000, 123.2906000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105061, 'Tambo', 'Tambo', 'Tambo', 9.8950000, 123.0556000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105062, 'Tambo', 'Tambo', 'Tambo', 7.1569400, 125.6991700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105063, 'Tambilil', 'Tambilil', 'Tambilil,Tamblil', 5.9622200, 124.6697200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105064, 'Tambalisa', 'Tambalisa', 'Tambalisa,Tambaliza', 11.2698000, 123.1650000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105065, 'Tambac', 'Tambac', 'Tambac,Tambak', 11.6705000, 122.4112000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105066, 'Tambak', 'Tambak', 'Tambac,Tambak', 6.7263900, 124.6263900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105067, 'Tamayo', 'Tamayo', 'Tamayo', 15.8774600, 120.2845500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105068, 'Taluya', 'Taluya', 'Taluya', 5.8116700, 125.1727800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105069, 'Talusan', 'Talusan', '', 7.4266700, 122.8102800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105070, 'Taluksangay', 'Taluksangay', '', 6.9541700, 122.1838900, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105071, 'Talugtug', 'Talugtug', 'San Isidro,Talogtog,Talugtog,Talugtogbalite,Talugtug,Talugtug-bali', 15.7778000, 120.8111000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105072, 'Taltal', 'Taltal', 'Taltal', 15.5878000, 119.9455000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105073, 'Taloy', 'Taloy', 'Taloy', 16.3333300, 120.5000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105074, 'Taloy', 'Taloy', 'Taloy', 15.9241000, 120.3964900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105075, 'Platagata', 'Platagata', 'Platagata,Taloto-an', 11.3030000, 123.1567000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105076, 'Talospatang', 'Talospatang', 'Talospatang', 15.9170100, 120.4414100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105077, 'Talon', 'Talon', 'Talon', 11.5600000, 122.6811100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105078, 'Talomo', 'Talomo', 'Talomo', 7.5286100, 125.7227800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105079, 'Talokgañgan', 'Talokgangan', '', 11.0077800, 122.8450000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105080, 'Taloc', 'Taloc', 'Taloc,Taluc', 10.5746000, 122.8954000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105081, 'Talubatib', 'Talubatib', 'Talobatib,Talubatib', 14.1825000, 122.7853000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105082, 'Talitay', 'Talitay', 'Talita,Talitay', 7.0333300, 124.7000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105083, 'Talisayan', 'Talisayan', 'Talisayan', 10.9500000, 124.7000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105084, 'Talisayan', 'Talisayan', '', 9.0003000, 124.8809100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105085, 'Talisayan', 'Talisayan', '', 6.9872200, 121.9272200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105086, 'Talisay', 'Talisay', 'Talisay', 14.1343000, 122.9226000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105087, 'Talisay', 'Talisay', 'Talisay', 14.0925000, 121.0219400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105088, 'Talisay', 'Talisay', 'Talisay', 13.9706000, 121.2051000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105089, 'Talisay', 'Talisay', 'Talisay', 13.9148400, 120.6232600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105090, 'Talisay', 'Talisay', 'Talisay', 13.1805600, 122.6236100, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105091, 'Talisay', 'Talisay', 'Tailsay,Talisay', 11.2450400, 124.0549100, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105092, 'Talisay', 'Talisay', 'Talisay', 10.7375000, 122.9666000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105093, 'Talisay', 'Talisay', 'Ciudad ti Talisay,Talisay,Talisay City,tarisai,タリサイ', 10.2447200, 123.8494400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105094, 'Talisay', 'Talisay', '', 9.8188900, 125.6155600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105095, 'Talisay', 'Talisay', 'Talisay', 6.7197300, 126.0999800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105096, 'Talipao', 'Talipao', 'Bila''an,Bilaan Constabulary Post,Bila’an,Camp Romandier,Romandies,Talipao,Talipaw', 5.9763900, 121.1161100, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105097, 'Talipan', 'Talipan', '', 13.9333300, 121.6833300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105098, 'Tal I Mun Doc', 'Tal I Mun Doc', 'Tal I Mun Doc', 15.2121000, 120.6849000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105099, 'Taligaman', 'Taligaman', '', 8.9044400, 125.6558300, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105100, 'Talibon', 'Talibon', '', 10.1491700, 124.3250000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105101, 'Talayan', 'Talayan', '', 6.9805600, 124.3819400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105102, 'Talavera', 'Talavera', 'Talavera,Талавера', 15.5883000, 120.9192000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105103, 'Talangnan', 'Talangnan', 'Talangnan', 9.6340000, 123.3344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105104, 'Talang', 'Talang', 'Talang', 15.0248800, 120.8378200, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105105, 'Talalora', 'Talalora', 'Talalora', 11.5293000, 124.8362000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105106, 'Talakag', 'Talakag', 'Talacag,Talakag', 8.2336100, 124.6002800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105107, 'Talaibon', 'Talaibon', 'Talaibon', 13.8378000, 121.1398000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105108, 'Talahib Payap', 'Talahib Payap', 'Talahib,Talahib Payap,Talahib Payapa', 13.6608300, 121.1363900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105109, 'Talahiban I', 'Talahiban I', 'Talahiban,Talahiban I,Talahiban Primero,Talahiban Uno', 13.8064500, 121.3811600, 'PH', '2015-04-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105110, 'Talaga', 'Talaga', 'Talaga', 15.3840300, 120.5893300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105111, 'Talaga', 'Talaga', 'Talaga', 13.7364600, 120.9361800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105112, 'Talacogon', 'Talacogon', '', 8.4561100, 125.7841700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105113, 'Talaban', 'Talaban', 'Talaban', 10.1254000, 122.8671000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105114, 'Tala', 'Tala', 'Tala', 13.2742000, 122.5859000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105115, 'Tacub', 'Tacub', 'Tacub,Takub', 8.1875000, 124.1080600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105116, 'Takub', 'Takub', 'Tacub,Takub', 6.8563900, 125.4225000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105117, 'Tajao', 'Tajao', 'Tahao,Tajao,Tanaw', 10.3148000, 123.5835000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105118, 'Tagusao', 'Tagusao', 'Tagusao', 9.1923800, 117.8141000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105119, 'Tagum Norte', 'Tagum Norte', 'Tagum,Tagum Norte', 10.0745400, 124.3892500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105120, 'Magugpo', 'Magugpo', 'Kota Tagum,Magugpo,Tagum,Tagum City,Tagum Lakanbalen,Taum,Taúm,tagum,tagwm,تاگوم,타굼', 7.4475000, 125.8046000, 'PH', '2016-10-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105121, 'Taguisa', 'Taguisa', 'Taguisa', 6.6983300, 124.0358300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105122, 'Taguing', 'Taguing', 'Taguing', 17.9463600, 121.7552100, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105123, 'Taguig', 'Taguig', 'City of Taguig,Santa Ana,Tagig,Taguig,Тагиг', 14.5243000, 121.0792000, 'PH', '2014-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105124, 'Tagudin', 'Tagudin', 'Tagudin', 16.9355000, 120.4442000, 'PH', '2011-08-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105125, 'Tagudin', 'Tagudin', 'Tagudin,Taguding', 16.0806000, 119.9539000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105126, 'Tagasilay', 'Tagasilay', 'Tagasilay,Tagsilay', 7.3025000, 122.2586100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105127, 'Taypano', 'Taypano', 'Tagpangi', 8.3708300, 124.5594400, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105128, 'Tagoytoy', 'Tagoytoy', 'Tagoytoy', 13.4158000, 123.6780000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105129, 'Tagoloan', 'Tagoloan', 'Tagoloan', 8.5395400, 124.7541100, 'PH', '2015-04-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105130, 'Tago', 'Tago', '', 9.0211100, 126.2316700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105131, 'Patikul', 'Patikul', 'Patikul,Tagibi,Taglibi', 6.0891700, 121.1052800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105132, 'Tagkawayan Sabang', 'Tagkawayan Sabang', 'Tagkawayan Sabang', 13.9909000, 122.5298000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105133, 'Tagdanua', 'Tagdanua', 'Tagdangua,Tagdanua', 7.2043000, 125.8841000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105134, 'Tagcatong', 'Tagcatong', 'Tagcatong', 9.0022200, 125.2569400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105135, 'Tagburos', 'Tagburos', '', 9.8286100, 118.7319400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105136, 'Tagbubungang Diot', 'Tagbubungang Diot', 'Tabubunga,Tagbobunga,Tagbubunga,Tagbubungang Diot', 11.1257000, 124.4028000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105137, 'Tagbina', 'Tagbina', 'Tagbina', 8.4519400, 126.1713900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105138, 'Tagbilaran City', 'Tagbilaran City', 'Dakbayan sa Tagbilaran,Syudad han Tagbilaran,TAG,Tagbilaran,Tagbilaran City', 9.6555600, 123.8521900, 'PH', '2014-05-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105139, 'Tagbacan Ibaba', 'Tagbacan Ibaba', 'Tagbacan,Tagbacan Ibaba', 13.6028000, 122.3687000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105140, 'Tagbak', 'Tagbak', 'Tabbac,Tagbac,Tagbak', 13.8416600, 120.0887200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105141, 'Tugaya', 'Tugaya', 'Tagaya,Tugaya', 7.8827700, 124.1740000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105142, 'Tagas', 'Tagas', 'Tagas', 13.1666700, 123.7166700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105143, 'Tagapul-an', 'Tagapul-an', 'Tagapul-an', 12.0500000, 124.1500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105144, 'Taganak', 'Taganak', 'Taganak,Turtle Islands', 6.0732800, 118.3122600, 'PH', '2016-02-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105145, 'Tagana-an', 'Tagana-an', 'Tagana-an,Taganaan,Taganaán', 9.6972200, 125.5855600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105146, 'Tagakpan', 'Tagakpan', 'Tagakpad', 7.1127800, 125.4291700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105147, 'Tayabas Ibaba', 'Tayabas Ibaba', 'Tagabas,Tayabas Ibaba', 13.6222000, 122.2814000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105148, 'Taft', 'Taft', 'Taft', 11.9011100, 125.4188900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105149, 'Tadian', 'Tadian', 'Tadian', 16.9956000, 120.8203000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105150, 'Tacurong', 'Tacurong', 'Kota Tacurong,Tacorong,Tacurong,Tacurong City,Tacurong Lakanbalen,Takrong,Takurong', 6.6925000, 124.6763900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105151, 'Taclobo', 'Taclobo', 'Taclobo', 12.3074400, 122.5860100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105152, 'Tacloban', 'Tacloban', 'Bandaraya Tacloban,Ciudad ti Tacloban,Dakbayan sa Tacloban,Dakuban,Dayeuh Tacloban,Kota Tacloban,Lungsod ng Tacloban,Syudad han Tacloban,Syudad nin Tacloban,TAC,Taclaban,Tacloban,Tacloban City,Tacloban Lakanbalen,Takloban,Taklobana,Taklobanas,Taklompan,Taklopan,Tocloban,Urbs Taclobana,du lu wan shi,tak lo ban,takeulloban,taklwban,takuroban,teklobena,tqlwbn,Τακλομπάν,Таклобан,Таклопан,טאקלאבאן,טקלובן,تاكلوبان,تاکلوبان,ટેક્લોબેન,ตักโลบัน,ታክሎባን,タクロバン,独鲁万市,타클로반', 11.2433300, 125.0047200, 'PH', '2017-07-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105153, 'Tacligan', 'Tacligan', 'Tacligan,Taclingan,Takligan', 13.3975000, 121.0626000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105154, 'Tacadang', 'Tacadang', 'Tacadang', 16.7264000, 120.6405000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105155, 'Tagbita', 'Tagbita', 'TGB,Taburi,Tagbita', 8.6753100, 117.3398900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105156, 'Tabonok', 'Tabonok', 'Tabonak,Tabonok,Tabunok', 10.8512000, 123.8766000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105157, 'Tabuk', 'Tabuk', 'Kota Tabuk,Tabuk,Tabuk City,tabukeu,tbwk  flpayn,تبوک، فلپائن,타부크', 17.4737800, 121.4679900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105158, 'Tabug', 'Tabug', 'Tabug', 18.0343000, 120.5488000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105159, 'Tabuelan', 'Tabuelan', 'Tabuelan', 10.8209000, 123.8689000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105160, 'Tabuc Pontevedra', 'Tabuc Pontevedra', 'Tabuc Pontevedra', 11.4833300, 122.8166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105161, 'Tabuating', 'Tabuating', 'Tabuating', 15.3921000, 120.9408400, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105162, 'Tabuan', 'Tabuan', 'Tabuan', 9.5155600, 122.8505600, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105163, 'Tabu', 'Tabu', 'Tabu', 9.8923000, 122.7098000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105164, 'Tubao', 'Tubao', 'Tabo-o,Tubao', 8.3340000, 123.8547000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105165, 'Tabontabon', 'Tabontabon', 'Tabontabon', 11.0408300, 124.9611100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105166, 'Tabunok', 'Tabunok', 'Tabonoc,Tabonok,Tabunok', 10.7767300, 124.0160200, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105167, 'Tabonoc', 'Tabonoc', 'Tabonoc,Tabunok', 10.3500000, 124.8000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105168, 'Tabon', 'Tabon', 'Tabon', 15.2709800, 120.9127300, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105169, 'Tabon', 'Tabon', 'Tabon', 10.3019000, 123.3260000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105170, 'Tabon', 'Tabon', 'Tabon', 9.8042000, 123.4563000, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105171, 'Tabon', 'Tabon', 'Tabon', 9.2387700, 117.9946000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105172, 'Tabogon', 'Tabogon', 'Tabogon', 10.9412000, 124.0282000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105173, 'Taboc', 'Taboc', 'Taboc', 8.8783300, 124.7975000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105174, 'Tablac', 'Tablac', 'Tablac', 17.2156800, 120.4542800, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105175, 'Tabio', 'Tabio', 'Tabia,Tabio', 16.8500000, 120.8000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105176, 'Tabing', 'Tabing', 'Tabing', 11.4000000, 124.3500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105177, 'Tabinay', 'Tabinay', 'Tabinay', 13.4871000, 120.9566000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105178, 'Tabina', 'Tabina', 'Tabina', 7.4669000, 123.4081000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105179, 'Tabid', 'Tabid', 'Tabia,Tabid,Tadid', 8.1085000, 123.7801000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105180, 'Tabiauan', 'Tabiauan', 'Tabialan,Tabiauan,Tavialan', 6.0280600, 121.8935500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105181, 'Tabango', 'Tabango', 'Tabango', 11.3077000, 124.3730000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105182, 'Tabalong', 'Tabalong', 'Tabalong', 9.6215700, 123.8123100, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105183, 'Tabaco', 'Tabaco', 'Kota Tabaco,Syudad nin Tabaco,Tabaco City,Tabaco Lakanbalen,Tobaco,tabako,tabako shi,タバコ市,타바코', 13.3586100, 123.7336100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105184, 'Tabaan', 'Tabaan', 'Tabaan', 16.3000000, 120.5166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105185, 'Taal', 'Taal', 'Taal,Таал', 13.8799200, 120.9231100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105186, 'Suyo', 'Suyo', 'Suyo,Urzadan,Uzzadan', 16.9762000, 120.5254000, 'PH', '2011-08-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105187, 'Suyan', 'Suyan', 'Suyan', 6.0602800, 125.3852800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105188, 'Suso', 'Suso', 'Suso', 17.3594000, 120.4611000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105189, 'Surup', 'Surup', 'Surop,Surup', 6.3903500, 126.1455800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105190, 'Surigao', 'Surigao', 'Ciudad ti Surigao,Dakbayan sa Surigao,Lungsod ng Surigao,SUG,Surigao,Surigao City,Surigao Lakanbalen,su li gao,suligao,surigao,スリガオ,苏里高,수리가오', 9.7890000, 125.4950000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105191, 'Surallah', 'Surallah', 'AAV,Surala,Surallah', 6.3752700, 124.7452100, 'PH', '2013-02-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105192, 'Sungai', 'Sungai', 'Sunga,Sungai,Sungay', 8.4513900, 124.4027800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105193, 'Sumpong', 'Sumpong', 'Sumpong', 8.1633300, 125.1183300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105194, 'Sumisip', 'Sumisip', 'Mangal,Sumipsip,Sumisip', 6.4197200, 121.9713900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105195, 'Sumilao', 'Sumilao', 'Sumilao,Sumílao,sumirao,スミラオ', 8.2872200, 124.9455600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105196, 'Sumagui', 'Sumagui', 'Sumagui', 12.7953200, 121.4740100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105197, 'Sumabnit', 'Sumabnit', 'Sumabnit', 16.0303000, 120.5832000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105198, 'Sulucan', 'Sulucan', 'Sulucan', 14.7944800, 120.9259400, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105199, 'Sultan Kudarat', 'Sultan Kudarat', 'Nuling,Sultan Kudarat,Sultan-Kudarat,Sultán Kudarat,sltan qdrt  magwyndanaw,Султан-Кударат,سلطان قدرت، ماگوئنداناؤ', 7.2288900, 124.2577800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105200, 'Sulop', 'Sulop', 'Sulop', 6.5986100, 125.3436100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105201, 'Sulit', 'Sulit', 'Sulit', 6.2361100, 125.0205600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105202, 'Sulat', 'Sulat', 'Sulat', 11.8102800, 125.4544400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105203, 'Sulangan', 'Sulangan', 'Sulangan', 11.1373000, 123.7228000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105204, 'Sulangan', 'Sulangan', 'Salanga,Salangan,Sulangan', 10.9360000, 125.8264000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105205, 'Sulangan', 'Sulangan', 'Sulangan', 10.8300000, 122.6900000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105206, 'Sula', 'Sula', 'Sula', 15.4572500, 120.3955300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105207, 'Sugpon', 'Sugpon', 'Sugpon', 16.8434000, 120.5157000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105208, 'Sugod', 'Sugod', 'Sugod', 12.9870000, 124.0805000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105209, 'Sugcad', 'Sugcad', 'Sugcad', 13.3666700, 123.7000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105210, 'Sugbongkogon', 'Sugbongkogon', 'Sugbongcogon,Sugbongkogon', 8.9569400, 124.7911100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105211, 'Sugal', 'Sugal', 'Sugal', 5.6622200, 125.4616700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105212, 'Sudipen', 'Sudipen', 'Sudipen', 16.9056000, 120.4617000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105213, 'Suklayin', 'Suklayin', 'Suclayin,Suklayin', 15.7574000, 121.5503000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105214, 'Subusub', 'Subusub', 'Sibusob,Subusob,Subusub', 16.2268900, 120.4951300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105215, 'Subic', 'Subic', 'Subic', 14.8799900, 120.2343300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105216, 'Subic', 'Subic', 'Subic', 13.9485900, 120.9401300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105217, 'Saaban', 'Saaban', 'Saaban,Subaan', 13.1304900, 121.3687200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105218, 'Suba', 'Suba', 'Suba', 10.8251200, 121.0069000, 'PH', '2016-08-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105219, 'Suay', 'Suay', 'Suay', 10.0533000, 122.8423000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105220, 'Suz-on', 'Suz-on', 'Sua-on,Suz-on', 7.6627800, 125.6383300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105221, 'Sual', 'Sual', 'Sual', 16.0668200, 120.0941400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105222, 'Soyung', 'Soyung', 'Soyon,Soyung,Suyong', 16.7001000, 121.6655000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105223, 'South Upi', 'South Upi', 'Looy,South Upi', 6.8333300, 124.1500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105224, 'Sorsogon', 'Sorsogon', '', 12.9738900, 123.9933300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105225, 'Songculan', 'Songculan', 'Songculan,Sunacolan,Sunculan,Sungculan', 9.6296500, 123.8289700, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105226, 'Solsona', 'Solsona', 'Solsona', 18.0933300, 120.7697200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105227, 'Solo', 'Solo', 'Solo', 13.7469100, 120.9011900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105228, 'Soledad', 'Soledad', 'Soledad', 15.4283800, 120.9835500, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105229, 'Solano', 'Solano', 'Solano,Солано', 16.5191800, 121.1812400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105230, 'Solana', 'Solana', 'Solana,Solano', 17.6528000, 121.6910000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105231, 'Solana', 'Solana', 'Colona,Coloña,Solana', 8.6230600, 124.7705600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105232, 'Sogod', 'Sogod', 'Sogod', 13.8333300, 123.3166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105233, 'Sogod', 'Sogod', 'Sogod,Sugod', 12.3763500, 122.6636800, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105234, 'Sogod', 'Sogod', 'Sogod', 10.7508300, 123.9947200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105235, 'Sogod', 'Sogod', 'Sogod', 10.3847000, 124.9814000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105236, 'Socorro', 'Socorro', 'Soccoro,Socorro', 13.0669000, 121.3985800, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105237, 'Socorro', 'Socorro', 'Socorro', 9.6213900, 125.9666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105238, 'Sitangkai', 'Sitangkai', 'Si Tangkay,Sitangkai,Sitankai,Venice of the Philippines', 4.6611500, 119.3964700, 'PH', '2016-12-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105239, 'Sison', 'Sison', 'Baley na Sison', 16.1738900, 120.5152800, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105240, 'Sison', 'Sison', 'Sison', 9.6602800, 125.5286100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105241, 'Siruma', 'Siruma', 'Siruma', 14.0000000, 123.2500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105242, 'Sirib', 'Sirib', 'Serib,Sirib', 7.1333300, 125.4072200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105243, 'Siraway', 'Siraway', 'Siraguay,Sirawai,Siraway,Sirawi', 7.5852800, 122.1397200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105244, 'Siquijor', 'Siquijor', 'Siguijor,Siquijor', 9.2142000, 123.5150000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105245, 'Sipocot', 'Sipocot', 'Sipoco,Sipocot', 13.7680000, 122.9762000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105246, 'Sipalay', 'Sipalay', '', 9.7519400, 122.4041700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105247, 'Siocon', 'Siocon', 'Siacon,Sicogon,Siocin,Siocon,Siokon,Siokun,XSO', 7.7061100, 122.1352800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105248, 'Sinuknipan', 'Sinuknipan', 'Sinoknipan,Sinuknipan,Sinuknipan I', 13.8894000, 122.6375000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105249, 'Sinubong', 'Sinubong', 'Sinubong,Sinubung', 7.0280600, 121.9252800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105250, 'Sinonoc', 'Sinonoc', 'Sinonoc,Sinonuc', 8.3096000, 123.8461000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105251, 'Sinolon', 'Sinolon', 'Sinolon', 6.2438900, 124.8144400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105252, 'Sinubong', 'Sinubong', 'Sinobong,Sinubong', 8.0684000, 125.9308000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105253, 'Sinisian', 'Sinisian', 'Sinisian,Sinisian Calaca', 13.9156000, 120.8440100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105254, 'Siniloan', 'Siniloan', 'Siniloan', 14.4216000, 121.4463000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105255, 'Sinilian First', 'Sinilian First', 'Sinilian,Sinilian First,Sinilian Primero', 15.6932700, 120.4593600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105256, 'Sindon', 'Sindon', 'Sindon', 17.0603400, 122.0151400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105257, 'Sindangan', 'Sindangan', 'Sindangan', 8.2376000, 122.9974000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105258, 'Sinayawan', 'Sinayawan', 'Sinayawan', 6.7125000, 125.3094400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105259, 'Sinawilan', 'Sinawilan', 'Sinawilan', 6.7544400, 125.2463900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105260, 'Sinamar', 'Sinamar', 'Sinamar', 16.9000000, 121.5666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105261, 'Sinala', 'Sinala', 'Sinala', 13.8057000, 120.9746300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105262, 'Sinait', 'Sinait', 'Sinait', 17.8664000, 120.4583000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105263, 'Sinait', 'Sinait', 'Sinait', 15.5367000, 120.5851000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105264, 'Sinacaban', 'Sinacaban', 'Nacavan,Navacan,Sinacaban,Sinakaban', 8.2864000, 123.8399000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105265, 'Simunul', 'Simunul', 'Simunul,Tubig Indangan', 4.8983300, 119.8494400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105266, 'Simimbaan', 'Simimbaan', 'Simimbaan', 17.1185600, 121.5813800, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105267, 'Simanu Sur', 'Simanu Sur', 'Simanu Sur', 17.4852300, 121.8342600, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105268, 'Simala', 'Simala', 'Simala', 9.9732600, 123.6164800, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105269, 'Silway 7', 'Silway 7', 'Silway,Silway 7,Silway Pito,Silway Seven', 6.1771100, 125.1206800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105270, 'Silvino Lobos', 'Silvino Lobos', 'Silvino Lobos', 12.3000000, 124.8333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105271, 'Silongin', 'Silongin', 'Silongin', 13.2999000, 122.5217000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105272, 'Sillon', 'Sillon', 'Silion,Sillion,Sillon', 11.1990000, 123.7675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105273, 'Sillawit', 'Sillawit', 'Silawit,Sillawit', 16.8731600, 121.7592400, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105274, 'Silanga', 'Silanga', 'Silanga', 11.8180600, 124.8430600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105275, 'Silang', 'Silang', '', 14.2156700, 120.9713700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105276, 'Silago', 'Silago', 'Silago', 10.5291000, 125.1618000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105277, 'Silae', 'Silae', 'Silae,Siloe', 8.1588900, 125.2825000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105278, 'Silab', 'Silab', 'Silab', 9.4383000, 123.1792000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105279, 'Sikatuna', 'Sikatuna', 'Sikatuna', 9.6883000, 123.9751000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105280, 'Sigma', 'Sigma', 'Sigma', 11.4214000, 122.6662000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105281, 'Sigay', 'Sigay', '', 17.0833300, 120.6000000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105282, 'Cigaras', 'Cigaras', 'Cigaras,Segaras,Sigaras', 14.2266000, 121.4298000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105283, 'Sierra Bullones', 'Sierra Bullones', 'Sierra Bollones,Sierra Bullones', 9.8081000, 124.2921000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105284, 'Siempre Viva', 'Siempre Viva', 'Siempre Viva', 17.2287400, 121.6329400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105285, 'Sico Uno', 'Sico Uno', 'Sico I,Sico Primero,Sico Uno', 13.8301000, 121.3712300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105286, 'Siclong', 'Siclong', 'Siclong', 15.5808000, 121.2239000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105287, 'Sibutao', 'Sibutao', 'Sibutad,Sibutao', 8.5916000, 123.4859000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105288, 'Sibulan', 'Sibulan', 'Sibulan', 14.7500000, 121.9333300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105289, 'Sibulan', 'Sibulan', 'Sibulan', 9.3584000, 123.2850000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105290, 'Sibulan', 'Sibulan', 'Sibulan', 6.9336100, 125.4622200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105291, 'Sibul', 'Sibul', 'Sibul', 15.8000000, 121.0000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105292, 'Sibul', 'Sibul', 'Sibul,Sibul Springs', 15.1690000, 121.0616000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105293, 'Sibuco', 'Sibuco', 'Sibuco,Sibuko', 7.2911100, 122.0655600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105294, 'Sibucao', 'Sibucao', 'Gibucao,Sibucao', 10.4179000, 122.8870000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105295, 'Sibonga', 'Sibonga', 'Sibonga', 10.0168000, 123.6171000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105296, 'Sibalom', 'Sibalom', 'Sibalom', 10.7900000, 122.0178000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105297, 'Sibaguan', 'Sibaguan', 'Sibaguan', 11.5577800, 122.7138900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105298, 'Sibagat', 'Sibagat', 'Sibagat,Sibagat Viejo', 8.8225000, 125.6975000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105299, 'Siayan', 'Siayan', 'Siayan', 8.2666700, 123.1000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105300, 'Siay', 'Siay', 'Siay', 7.6961100, 122.8630600, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105301, 'Siaton', 'Siaton', 'Siaton', 9.0648000, 123.0339000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105302, 'Siasi', 'Siasi', 'Banting,Maddas,Muddas,SSV,Si Ase,Siasi', 5.5462000, 120.8145000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105303, 'Siari', 'Siari', 'Siare,Siari', 8.3245000, 122.9881000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105304, 'Sexmoan', 'Sexmoan', 'Sasmoan,Sasmuan,Sexmoan', 14.9438000, 120.6229000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105305, 'Sevilla', 'Sevilla', 'Sevilla', 9.7038300, 124.0482900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105306, 'Sergio Osmeña Sr', 'Sergio Osmena Sr', '', 8.1666700, 123.5000000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105307, 'Seres', 'Seres', 'Seres', 8.4803000, 123.2629000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105308, 'Salunayan', 'Salunayan', 'Salunayan,Serenaya', 7.1544400, 124.4975000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105309, 'Semut', 'Semut', 'Semmut,Semut', 6.6636100, 122.2188900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105310, 'Semirara', 'Semirara', 'Semirara', 12.0696700, 121.3986100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105311, 'Siguinon', 'Siguinon', 'Seguinon,Siguinon', 10.9423000, 124.6806000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105312, 'Sebu', 'Sebu', 'Sebu', 6.2200000, 124.6936100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105313, 'Sebaste', 'Sebaste', 'Sebaste', 11.5901000, 122.0945000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105314, 'Sebaste', 'Sebaste', 'Sebaste', 10.4963000, 122.6570000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105315, 'Saysain', 'Saysain', 'Saysain', 14.5611100, 120.3925000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105316, 'Satan', 'Satan', 'Satan', 6.8630600, 124.4086100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105317, 'Sarrat', 'Sarrat', 'Sarrat', 18.1574000, 120.6470000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105318, 'Sariaya', 'Sariaya', 'Sariaya', 13.9624000, 121.5265000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105319, 'Saraza', 'Saraza', 'Saraza', 8.7355600, 117.7800000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105320, 'Sarangani', 'Sarangani', 'Sarangani,Сарангани', 5.4033300, 125.4636100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105321, 'Sara', 'Sara', 'Sara', 11.2579000, 123.0138000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105322, 'Sapu Padidu', 'Sapu Padidu', 'Sapu,Sapu Padidu,Sapu-Padido', 5.9172200, 125.2669400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105323, 'Sapol', 'Sapol', 'Sapol,Sapul', 13.3650000, 121.1893000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105324, 'Sapian', 'Sapian', 'Saipan,Sapian', 11.4943000, 122.6027000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105325, 'Sapang Dalaga', 'Sapang Dalaga', 'Sapang Dalaga', 8.5399000, 123.5624000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105326, 'Sapang Buho', 'Sapang Buho', 'Sapang Bato,Sapang Buho', 15.5903800, 121.1245400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105327, 'Sapang', 'Sapang', 'Sapang', 15.7032000, 120.5245000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105328, 'Sapadun', 'Sapadun', 'Sapad,Sapadun', 7.4833300, 124.2500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105329, 'Sapad', 'Sapad', '', 7.8500000, 123.8333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105330, 'Sapa', 'Sapa', 'Sapa', 5.1544000, 120.3241000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105331, 'San Vicente', 'San Vicente', 'San Vicente,San Vincente', 17.5969400, 120.3736100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105332, 'San Vicente', 'San Vicente', 'Caluis,Cobra,San Vicente', 15.2921000, 120.6549800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105333, 'San Vicente', 'San Vicente', 'San Vicente', 15.2132400, 120.8190100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105334, 'San Vicente', 'San Vicente', 'San Vicente', 14.9459400, 120.7485200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105335, 'San Vicente', 'San Vicente', 'San Vicente', 14.1061000, 122.8733000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105336, 'San Vicente', 'San Vicente', 'San Vicente', 13.8967000, 122.2047000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105337, 'San Vicente', 'San Vicente', 'San Vicente', 13.7000000, 123.2000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105338, 'San Vicente', 'San Vicente', 'San Vicente', 13.5737000, 123.0533000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105339, 'San Vicente', 'San Vicente', 'San Vicente,San Vincente', 13.4527000, 123.3729000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105340, 'San Vicente', 'San Vicente', 'San Vicente', 13.4081000, 123.4188000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105341, 'San Vincente', 'San Vincente', 'San Vicente,San Vincente', 13.4068000, 121.1750000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105342, 'San Vicente', 'San Vicente', 'San Vicente', 13.2615000, 123.4334000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105343, 'San Vicente', 'San Vicente', 'San Vicente', 12.9780600, 123.8222200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105344, 'San Vicente', 'San Vicente', '', 12.2711100, 124.1000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105345, 'San Vicente', 'San Vicente', 'San Vicente', 11.1183000, 124.5657000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105346, 'San Vicente', 'San Vicente', 'San Vicente,sn wysnth,سن ویسنته', 10.5500000, 119.2666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105347, 'San Vicente', 'San Vicente', 'La-ac,San Vicente', 7.8333300, 125.8166700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105348, 'San Vicente', 'San Vicente', 'San Vicente', 7.6511100, 125.0344400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105349, 'San Vicente', 'San Vicente', 'San Vicente', 6.4497200, 124.7947200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105350, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas', 17.3997200, 121.7645500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105351, 'Santo Tomas', 'Santo Tomas', 'Santa Tomas,Santo Thomas,Santo Tomas', 16.2798000, 120.3792000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105352, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas', 15.7497700, 120.9624100, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105353, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas', 15.0333000, 120.8000000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105354, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas', 14.1833300, 121.5000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105355, 'Santo Tomas', 'Santo Tomas', 'Santa Tomas,Santo Tomas,Santo-Tomas,Санто-Томас', 14.1079000, 121.1413600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105356, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas', 8.1858300, 125.8038900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105357, 'Santo Tomas', 'Santo Tomas', 'Santo Tomas,Tibal-og', 7.5336100, 125.6233300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105358, 'Santo Rosario', 'Santo Rosario', 'Santo Rosario', 15.6447000, 120.8612000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105359, 'Santo Rosario', 'Santo Rosario', 'Santo Rosario', 15.4342500, 120.8898100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105360, 'Santor', 'Santor', 'Santol,Santor', 14.0954900, 121.1087400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105361, 'Santo Niño', 'Santo Nino', 'Faire,Fraire,Santo Nino,Santo Niño', 17.8861000, 121.5691000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105362, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 15.3343300, 120.6261900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105363, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 13.8489000, 121.1328000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105364, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 13.7018000, 121.0949000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105365, 'Santo Niño', 'Santo Nino', 'Gayong,Santo Nino,Santo Niño', 13.1043000, 123.9682000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105366, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 11.9263000, 124.4492000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105367, 'Santo Niño', 'Santo Nino', '', 11.0630600, 124.5616700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105368, 'Santa Nino', 'Santa Nino', 'Santa Nino,Santo Nino,Santo Niño', 10.6890000, 123.7884000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105369, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 7.6236100, 125.6252800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105370, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 7.3277800, 125.7052800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105371, 'Santo Niño', 'Santo Nino', '', 6.4350000, 124.6975000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105372, 'Santol', 'Santol', 'Padayao,Santol', 16.7720000, 120.4604000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105373, 'Santol', 'Santol', '', 15.1622200, 120.5675000, 'PH', '2013-03-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105374, 'Santol', 'Santol', 'Santol', 10.1725000, 122.9947000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105375, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 17.6352800, 120.4108300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105376, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 17.1599900, 121.7518300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105377, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 15.5873000, 120.8770000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105378, 'Santo Domingo', 'Santo Domingo', 'Santa Domingo,Santo Domingo', 15.0728900, 120.7570300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105379, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 14.9912000, 120.7434100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105380, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 14.9653200, 120.5567200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105381, 'Santo Domingo', 'Santo Domingo', 'Santo Doming,Santo Domingo', 14.1338000, 122.8883000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105382, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 13.7000000, 123.1666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105383, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 13.4200000, 123.4486000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105384, 'Santo Domingo', 'Santo Domingo', 'Santo Domingo', 13.2352800, 123.7772200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105385, 'Santo Cristo', 'Santo Cristo', 'Santo Cristo', 15.3383600, 120.5933300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105386, 'Santo Cristo', 'Santo Cristo', 'Santo Cristo', 15.2968300, 120.8902500, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105387, 'Santa Angel', 'Santa Angel', 'Santa Angel,Santo Angel', 11.3068000, 122.6408000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105388, 'Santisimo Rosario', 'Santisimo Rosario', 'Santisimo Rosario,Santo Rosario', 13.9966100, 121.3091800, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105389, 'Santiago', 'Santiago', 'Santiago', 17.2939000, 120.4449000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105390, 'Santiago', 'Santiago', '', 16.6880800, 121.5487000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105391, 'Santiago', 'Santiago', 'Santiago', 14.9037100, 120.5113400, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105392, 'Santiago', 'Santiago', 'Santiago', 14.0211000, 121.2792000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105393, 'Santiago', 'Santiago', 'Santiago', 11.0580600, 122.9116700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105394, 'Santiago', 'Santiago', 'Santiago', 10.5897000, 124.3066000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105395, 'Santiago', 'Santiago', 'Santiago', 7.2888900, 126.5733300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105396, 'San Teodoro', 'San Teodoro', 'San Teodoro,Subaang', 13.4335400, 121.0144000, 'PH', '2015-04-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105397, 'Santa Teresita', 'Santa Teresita', 'Santa Teresita', 18.2472000, 121.9127000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105398, 'Santa Teresita', 'Santa Teresita', 'Santa Teresita', 13.8663900, 120.9813900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105399, 'Santa Teresita', 'Santa Teresita', 'Santa Teresita', 13.4786000, 123.4191000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105400, 'Santa Teresa First', 'Santa Teresa First', 'Santa Teresa,Santa Teresa First,Santa Teresa Primera,Santa Teresita First', 14.9265000, 120.5579100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105401, 'Santa Teresa', 'Santa Teresa', 'Lalawigan,Santa Teresa', 12.2518600, 121.1125100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105402, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 10.5854600, 122.5604000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105403, 'Santa Rosa Sur', 'Santa Rosa Sur', 'Danaw,Santa Rosa,Santa Rosa Sur', 14.2590000, 122.7233000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105404, 'Hacienda Santa Rosa', 'Hacienda Santa Rosa', 'Hacienda Santa Rosa,Santa Rosa,Santa Rosa Hacienda', 10.5722600, 123.1012000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105405, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', 15.4238000, 120.9378000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105406, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', 15.3675600, 120.6170300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105407, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', 14.4261200, 120.8793100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105408, 'Santa Rosa', 'Santa Rosa', 'Kota Santa Rosa,Santa Rosa City,Santa Rosa Lakanbalen,Santa-Rosa,Санта-Роса', 14.3122200, 121.1113900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105409, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', 13.5591000, 122.3776000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105410, 'Santa Rita', 'Santa Rita', 'Santa Rita', 15.6192300, 120.8696200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105411, 'Santa Rita', 'Santa Rita', 'Santa Maria,Santa Rita', 14.9993000, 120.6117000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105412, 'Santa Rita', 'Santa Rita', 'Santa Rita', 11.4502000, 124.9425000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105413, 'Santa Praxedes', 'Santa Praxedes', 'Langangan,Santa Praxedes', 18.5666700, 121.0000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105414, 'Santa Paz', 'Santa Paz', 'Santa Paz', 10.2666700, 124.7833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105415, 'Santander Poblacion', 'Santander Poblacion', 'Santander', 9.4252700, 123.3387900, 'PH', '2015-04-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105416, 'Santa Monica', 'Santa Monica', 'San Monica,Santa Monica', 15.3577100, 120.7200600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105417, 'Santa Monica', 'Santa Monica', 'Santa Monica', 10.7363900, 122.4533300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105418, 'Santa Monica', 'Santa Monica', 'Santa Monica,Sapao', 10.0200000, 126.0383300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105419, 'Santa Maria', 'Santa Maria', 'Santa Maria', 18.1414000, 121.6647300, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105420, 'Santa Maria', 'Santa Maria', '', 17.4663900, 121.7522200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105421, 'Santa Maria', 'Santa Maria', 'Santa Maria,Santa Maria de Ilocos,Santa María de Ilocos', 17.3665000, 120.4808000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105422, 'Santa Maria', 'Santa Maria', 'Santa Maria', 16.9518000, 120.4445000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105423, 'Santa Maria', 'Santa Maria', '', 15.9808300, 120.7002800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105424, 'Santa Maria', 'Santa Maria', 'Santa Maria', 15.6436500, 120.4263500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105425, 'Santa Maria', 'Santa Maria', 'Santa Maria', 15.5232000, 120.7925000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105426, 'Santa Maria', 'Santa Maria', 'Santa Maria', 15.0867200, 120.7699100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105427, 'Santa Maria', 'Santa Maria', 'Santa Maria,Santa María', 14.8208300, 120.9636100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105428, 'Santa Maria', 'Santa Maria', 'Santa Maria', 14.4719000, 121.4286000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105429, 'Santa Maria', 'Santa Maria', 'Santa Maria', 12.5788300, 121.4604100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105430, 'Santa Maria', 'Santa Maria', 'Santa Maria', 8.0333300, 126.1625000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105431, 'Santa Maria', 'Santa Maria', 'Santa Maria', 7.9916700, 126.4450000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105432, 'Santa Maria', 'Santa Maria', 'Basiauan,Basiawan,Santa Maria', 6.5536100, 125.4708300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105433, 'Santa Margarita', 'Santa Margarita', 'Santa Margarita', 12.0377800, 124.6577800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105434, 'Santa Marcela', 'Santa Marcela', 'Santa Marcela', 18.2833300, 121.4333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105435, 'Santa Magdalena', 'Santa Magdalena', 'Santa Magdalena', 12.6480000, 124.1093000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105436, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 17.1175000, 120.4530600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105437, 'Santa Lucia', 'Santa Lucia', 'Old Santa Lucia,Santa Lucia', 15.4818400, 120.7745600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105438, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 15.3680600, 120.4864300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105439, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 15.2097000, 121.0061000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105440, 'Santa Lucia', 'Santa Lucia', 'Santa Lucia', 14.0349000, 121.4312000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105441, 'Santa Justina', 'Santa Justina', 'Santa Justina', 13.3967000, 123.4731000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105442, 'Santa Juliana', 'Santa Juliana', 'Santa Juliana', 15.3282600, 120.4286300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105443, 'Santa Josefa', 'Santa Josefa', 'Santa Josefa', 7.9911100, 126.0300000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105444, 'Santa Ines West', 'Santa Ines West', 'Santa Ines,Santa Ines West', 15.5569400, 120.4644800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105445, 'Santa Ignacia', 'Santa Ignacia', 'Santa Ignacia,Stalgnacia', 15.6169000, 120.4358000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105446, 'Santa Filomena', 'Santa Filomena', 'Santa Felomena,Santa Filomena', 9.7518100, 123.3446300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105447, 'Santa Fe', 'Santa Fe', 'Santa Fe', 16.1595000, 120.9381000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105448, 'Santa Fe', 'Santa Fe', 'Santa Fe', 15.0103000, 120.2102000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105449, 'Santa Fe', 'Santa Fe', 'Santa Fe,سانتا فے، رومبلون', 12.1565600, 121.9941100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105450, 'Santa Fe', 'Santa Fe', '', 11.1855600, 124.9161100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105451, 'Santa Fe', 'Santa Fe', 'Santa Fe,سانتا فے، سیبو', 11.1544000, 123.8058000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105452, 'Santa Fe', 'Santa Fe', 'Santa Fe', 10.2375000, 124.7719400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105453, 'Santa Fe', 'Santa Fe', 'Santa Fe', 8.3425000, 124.7808300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105454, 'Santa Elena', 'Santa Elena', 'Santa Elena', 14.1702300, 122.3824600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105455, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 18.5164600, 121.3105200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105456, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa-Krus,Санта-Крус', 17.0855600, 120.4522200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105457, 'Santa Cruz', 'Santa Cruz', 'Sant Cruz,Santa Cruz,Santa-Krus,Санта-Крус', 15.7654000, 119.9092000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105458, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 15.3081500, 120.8531800, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105459, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 14.9127000, 120.5665900, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105460, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,santa krwz  lagwna,سانتا کروز، لاگونا', 14.2814000, 121.4161000, 'PH', '2017-06-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105461, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 14.1166700, 121.2833300, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105462, 'Santa Cruz', 'Santa Cruz', '', 14.0205600, 121.3572200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105463, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 13.8650000, 121.1887000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105464, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa-Krus,Санта-Крус', 13.4758000, 122.0275000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105465, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 13.0736000, 120.7226000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105466, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 12.8763000, 124.0566000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105467, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 10.6514000, 124.3386000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105468, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 10.6337600, 123.0821000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105469, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 10.0068000, 123.4140000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105470, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa Cruz Nuevo,Santa-Krus,Санта-Крус', 9.5352000, 123.1054000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105471, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz', 6.8369400, 125.4130600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105472, 'Santa Clara', 'Santa Clara', 'Santa Clara', 13.7536100, 121.0605600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105473, 'Santa Clara', 'Santa Clara', 'Santa Clara', 6.6782000, 122.0600000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105474, 'Santa Cecilia', 'Santa Cecilia', 'Santa Cecilia', 14.1054000, 122.2016000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105475, 'Santa Catalina Sur', 'Santa Catalina Sur', 'Santa Catalina Sur', 13.8738400, 121.4310400, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105476, 'Santa Catalina Norte', 'Santa Catalina Norte', 'Santa Catalina Norte', 13.8708300, 121.3575000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105477, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', 17.5966700, 120.3591700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105478, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', 14.1213000, 121.3419000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105479, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', 9.3337000, 122.8637000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105480, 'Santa Brigida', 'Santa Brigida', 'Santa Brigida', 12.5678300, 121.4890100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105481, 'Santa Barbara', 'Santa Barbara', 'Santa Barbara', 16.0009000, 120.4023000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105482, 'Santa Barbara', 'Santa Barbara', 'Santa Barbara', 15.3849400, 120.7961100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105483, 'Santa Barbara', 'Santa Barbara', 'Santa Barbara,Santa Bárbara', 10.8230600, 122.5344400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105484, 'Santa Ana', 'Santa Ana', 'Santa Ana,Santa-Ana,Санта-Ана', 18.4698600, 122.1477500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105485, 'Santa Ana', 'Santa Ana', 'San Joaquin,Santa Ana,Santa-Ana,Санта-Ана', 15.0955000, 120.7670000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105486, 'Santa Ana', 'Santa Ana', 'Santa Ana', 9.1927800, 125.5644400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105487, 'Santa Ana', 'Santa Ana', 'Santa Ana', 8.5166700, 124.7833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105488, 'Santa', 'Santa', 'Santa', 17.4860000, 120.4348000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105489, 'San Simon', 'San Simon', 'San Simon', 14.9996000, 120.7808000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105490, 'San Sebastian', 'San Sebastian', 'San Sebastian,San Sebastian Este', 17.6232700, 120.3635200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105491, 'San Sebastian', 'San Sebastian', 'San Sebastian', 13.7283000, 123.5939000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105492, 'San Sebastian', 'San Sebastian', 'San Sebastian', 11.7100000, 125.0180600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105493, 'San Roque Dau First', 'San Roque Dau First', 'San Roque,San Roque Dau,San Roque Dau First,San Roque Dau Primero', 14.9771100, 120.5768800, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105494, 'San Roque', 'San Roque', 'San Roque', 13.1547200, 123.7541700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105495, 'San Roque', 'San Roque', 'San Roque', 15.2614600, 120.6518300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105496, 'San Roque', 'San Roque', 'San Roque', 15.0094600, 120.9383100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105497, 'San Roque', 'San Roque', 'San Roque', 13.2837000, 123.7422000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105498, 'San Roque', 'San Roque', 'San Roque', 12.7393000, 124.0839000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105499, 'San Roque', 'San Roque', 'San Roque', 12.5333300, 124.8666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105500, 'San Roque', 'San Roque', 'San Roque', 11.0500000, 125.0166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105501, 'San Roque', 'San Roque', 'San Roque', 10.6043000, 123.7441000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105502, 'San Roque', 'San Roque', 'San Rogue,San Roque', 10.0919000, 124.3226200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105503, 'San Ricardo', 'San Ricardo', 'San Ricardo', 15.5959000, 120.9727000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105504, 'San Ricardo', 'San Ricardo', 'San Ricardo', 9.9128000, 125.2767000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105505, 'San Remigio', 'San Remigio', 'San Remigio', 11.0809000, 123.9381000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105506, 'San Remigio', 'San Remigio', 'Calagitan', 10.8327800, 122.0875000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105507, 'San Ramon', 'San Ramon', 'San Ramon', 17.4135000, 120.7076000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105508, 'San Ramon', 'San Ramon', 'San Ramon', 13.7221000, 123.5400000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105509, 'San Ramon', 'San Ramon', 'San Ramon', 13.6181000, 123.0383000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105510, 'San Rafael', 'San Rafael', 'San Rafael', 14.9483300, 120.9622200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105511, 'San Rafael', 'San Rafael', 'San Rafael', 14.8990600, 120.6935200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105512, 'San Rafael', 'San Rafael', 'San Rafael', 14.1284000, 121.4147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105513, 'San Rafael', 'San Rafael', 'San Rafael', 13.2166700, 123.6000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105514, 'San Rafael', 'San Rafael', 'San Rafael', 13.0941700, 122.9600000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105515, 'San Rafael', 'San Rafael', 'San Rafael', 12.8905000, 123.6823000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105516, 'San Rafael', 'San Rafael', 'San Rafael', 11.1781000, 122.8273000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105517, 'San Rafael', 'San Rafael', 'San Rafael', 7.7638900, 126.4558300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105518, 'San Quintin', 'San Quintin', 'San Quintin', 17.5424000, 120.5199000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105519, 'San Quintin', 'San Quintin', 'San Quintin', 15.9854000, 120.8132000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105520, 'Sonquil', 'Sonquil', 'Sanquil,Songuil,Sonquil', 15.9881400, 120.3905700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105521, 'San Policarpo', 'San Policarpo', 'Policarpio,San Policarpio,San Policarpo', 12.1791000, 125.5072000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105522, 'San Policarpio', 'San Policarpio', 'San Policarpio,San Policarpo', 12.0686000, 124.5695000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105523, 'San Pedro Apartado', 'San Pedro Apartado', 'San - Pedro,San Pedro,San Pedro Apartado,Сан - Педро', 15.8370200, 120.5652100, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105524, 'San Pedro', 'San Pedro', 'San Pedro', 17.2000000, 121.8833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105525, 'San Pedro', 'San Pedro', 'San Pedro', 14.3595000, 121.0473000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105526, 'San Pedro One', 'San Pedro One', 'Galo,San - Pedro,San Galo,San Pedro,San Pedro One,Сан - Педро', 14.0534100, 121.1453600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105527, 'San Pedro', 'San Pedro', 'San Pedro', 12.4608400, 121.0104100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105528, 'San Pedro', 'San Pedro', 'San Pedro', 12.0166700, 124.0000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105529, 'San Pedro', 'San Pedro', 'San Pedro', 10.9610000, 124.8197000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105530, 'San Pedro', 'San Pedro', 'San Pedro', 10.8018000, 121.9499000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105531, 'San Pedro', 'San Pedro', 'San Pedro', 7.3419400, 126.5175000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105532, 'San Patricio', 'San Patricio', 'San Patricio', 15.0977500, 120.7287600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105533, 'Lloren', 'Lloren', 'Lloren,San - Paskual'',San Pascual,Сан - Паскуаль', 16.3331000, 120.4329000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105534, 'San Pascual', 'San Pascual', 'San Pascual', 13.8104500, 121.0220000, 'PH', '2016-10-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105535, 'San Pascual', 'San Pascual', 'San - Paskual'',San Pascual,Сан - Паскуаль', 13.1288800, 122.9770900, 'PH', '2014-11-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105536, 'San Pascual', 'San Pascual', 'San Pascual', 9.9538000, 124.4287000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105537, 'San Pablo', 'San Pablo', 'Dakbayan sa San Pablo,Kota San Pablo,Lungsod ng San Pablo,San Pablo,San Pablo City,San Pablo Lakanbalen,Siyudad na San Pablo', 14.0683000, 121.3256000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105538, 'San Pablo', 'San Pablo', 'San Pablo', 10.9123400, 123.1418000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105539, 'San Pablo', 'San Pablo', 'San - Pablo,San Pablo,Сан - Пабло', 7.6563900, 123.4608300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105540, 'San Nicolas', 'San Nicolas', 'San Nicolas,San Nicolas de Ilocos,San Nicolás de Ilocos', 18.1725000, 120.5953000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105541, 'San Nicolas', 'San Nicolas', 'San Nicolas', 16.0703000, 120.7624000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105542, 'San Nicolas', 'San Nicolas', 'San Nicolas', 15.5841000, 120.6765000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105543, 'San Nicolas', 'San Nicolas', 'San Nicolas', 15.0417600, 120.7944300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105544, 'San Nicolas', 'San Nicolas', 'San Nicolas', 14.9490900, 120.0770300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105545, 'San Nicolas', 'San Nicolas', 'San Nicolas', 13.9282500, 120.9510000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105546, 'San Nicolas', 'San Nicolas', 'San Nicolas', 11.3213000, 122.5184000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105547, 'San Nicolas', 'San Nicolas', 'San Nicolas', 10.6844400, 122.4955600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105548, 'San Narciso', 'San Narciso', 'San Narcisco,San Narciso', 15.0143000, 120.0803000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105549, 'San Narciso', 'San Narciso', 'San Narciso', 13.5677000, 122.5667000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105550, 'San Miguel', 'San Miguel', 'San Miguel', 15.4439700, 120.5992300, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105551, 'San Miguel', 'San Miguel', 'San Miguel,San Muigel Mayumo', 15.1423000, 120.9756800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105552, 'San Miguel', 'San Miguel', 'San Miguel', 14.2013000, 121.3732000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105553, 'San Miguel', 'San Miguel', 'San Miguel', 13.8740000, 121.1983000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105554, 'San Miguel', 'San Miguel', 'San Miguel', 13.6414000, 124.3026000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105555, 'San Miguel', 'San Miguel', 'San Miguel', 13.4196000, 123.4082000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105556, 'San Miguel', 'San Miguel', '', 11.2672200, 124.8325000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105557, 'San Miguel', 'San Miguel', 'San Miguel', 11.2146000, 122.5425000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105558, 'San Miguel', 'San Miguel', '', 10.7800000, 122.4655600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105559, 'San Miguel', 'San Miguel', 'San - Migel'',San Migual,San Miguel,Сан - Мигель', 10.5960600, 122.5899000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105560, 'San Miguel', 'San Miguel', 'San Miguel', 10.5385600, 123.0830000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105561, 'San Miguel', 'San Miguel', 'San Miguel', 10.4154000, 123.0214000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105562, 'San Miguel', 'San Miguel', 'Cambangay,Cambangay Sur,Cambangays,San - Migel'',San Miguel,Сан - Мигель', 9.9869000, 124.3411000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105563, 'San Miguel', 'San Miguel', 'San Miguel', 9.8851000, 124.3264000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105564, 'San Miguel', 'San Miguel', 'San Miguel', 9.2239000, 123.2853000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105565, 'San Miguel', 'San Miguel', 'San Miguel', 8.9688900, 125.9450000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105566, 'San Miguel', 'San Miguel', 'San Miguel', 8.0300000, 124.7538900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105567, 'San Miguel', 'San Miguel', 'San - Migel'',San Miguel,Сан - Мигель', 7.6483300, 123.2675000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105568, 'San Miguel', 'San Miguel', 'San Miguel', 7.4850000, 125.6763900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105569, 'San Miguel', 'San Miguel', 'San Miguel', 6.4894400, 124.6952800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105570, 'San Mateo', 'San Mateo', 'San Mateo', 17.1375400, 121.7453400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105571, 'San Mateo', 'San Mateo', 'San Mateo', 16.8820600, 121.5869400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105572, 'San Mateo', 'San Mateo', 'San Mateo', 15.2000800, 120.7946000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105573, 'San Mateo', 'San Mateo', 'San Mateo', 14.6982000, 121.1236000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105574, 'San Martin', 'San Martin', 'San Martin', 8.5611100, 124.7713900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105575, 'San Mariano', 'San Mariano', 'Angela,San Mariana,San Mariano', 16.9826500, 122.0140400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105576, 'San Mariano', 'San Mariano', 'Mariano,San Mariano', 15.3208300, 120.8760900, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105577, 'San Mariano', 'San Mariano', 'San Mariano', 12.6414300, 121.4379100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105578, 'San Mariano', 'San Mariano', '', 7.5000000, 126.0000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105579, 'San Marcelino', 'San Marcelino', 'San Marcelino', 14.9741800, 120.1573300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105580, 'San Manuel', 'San Manuel', 'Callang,San Manuel', 17.0237500, 121.6357400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105581, 'San Manuel', 'San Manuel', 'San Manuel,San Manuel de Pangasinan,San Manuel de Pangasinán', 16.0647000, 120.6687000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105582, 'San Manuel', 'San Manuel', '', 15.7991700, 120.6086100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105583, 'San Manuel', 'San Manuel', 'San Manuel', 15.4905300, 120.6654300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105584, 'San Luis', 'San Luis', 'San Luis', 16.9645500, 121.8278400, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105585, 'San Luis', 'San Luis', 'San Luis,San Luis del Principe,San Luis del Príncipe', 15.7208000, 121.5205000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105586, 'San Luis', 'San Luis', 'San Luis', 15.0401000, 120.7883000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105587, 'San Luis', 'San Luis', 'San Luis', 13.8546900, 120.9165300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105588, 'San Luis', 'San Luis', 'San - Luis,San Luis,Сан - Луис', 8.4780600, 125.7438900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105589, 'San Luis', 'San Luis', 'San Luis', 8.4833300, 125.0000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105590, 'San Luis', 'San Luis', 'San Luis', 7.4413900, 126.5511100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105591, 'San Lucas', 'San Lucas', 'San Lucas', 13.7062000, 123.2032000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105592, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 18.1323000, 120.6305000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105593, 'San Lorenzo', 'San Lorenzo', 'San Lorenzo', 15.4862000, 119.9622000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105594, 'Sanlibo', 'Sanlibo', 'Sanlibo', 15.9166700, 120.5500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105595, 'San Leonardo', 'San Leonardo', 'San Leonardo', 15.3630000, 120.9639000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105596, 'Sankanan', 'Sankanan', 'Sankanam,Sankanan', 8.3155600, 124.8580600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105597, 'San Julian', 'San Julian', 'San Julian', 11.7536100, 125.4558300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105598, 'San Juan de Mata', 'San Juan de Mata', 'San Juan de Maja,San Juan de Mata', 15.5352000, 120.5302000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105599, 'San Juan', 'San Juan', 'Lapog,San Juan', 17.7422200, 120.4583300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105600, 'San Juan', 'San Juan', 'San Juan', 17.6829000, 120.7324000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105601, 'San Juan', 'San Juan', 'San Juan', 17.4056200, 121.7474500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105602, 'San Juan', 'San Juan', '', 16.6686100, 120.3413900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105603, 'San Juan', 'San Juan', 'San Juan', 15.2897000, 120.0648000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105604, 'San Juan', 'San Juan', 'San Juan', 15.0231000, 120.6771400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105605, 'San Juan', 'San Juan', 'San Juan,San Juan City,San Juan del Monte', 14.6000000, 121.0333000, 'PH', '2013-10-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105606, 'San Juan', 'San Juan', 'San Juan', 14.0571500, 121.2293100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105607, 'San Juan', 'San Juan', 'Bolboc,Bolbok,San Juan', 13.8337900, 121.3982000, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105608, 'San Juan', 'San Juan', 'San Juan', 13.5232000, 122.5813000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105609, 'San Juan', 'San Juan', '', 11.0005600, 124.5391700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105610, 'San Juan', 'San Juan', 'San Juan', 10.3865000, 122.8651000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105611, 'San Juan', 'San Juan', 'Cabalian,San Juan', 10.2669400, 125.1755600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105612, 'San Juan', 'San Juan', 'San Juan', 9.1603000, 123.4926000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105613, 'Malino', 'Malino', 'Malino,San Jose Malino', 15.1269500, 120.6743100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105614, 'San Jose del Monte', 'San Jose del Monte', 'Kota San Jose del Monte,Lungsod ng San Jose del Monte,San Jose Del Monte,San Jose del Monte,San Jose del Monte City,San Jose del Monte Lakanbalen,San José Del Monte,San José del Monte,San-Khose-del''-Monte,sanhosedelmonte,Сан-Хосе-дель-Монте,산호세델몬테', 14.8138900, 121.0452800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105615, 'San Jose de Buan', 'San Jose de Buan', 'San Jose de Buan', 12.0529000, 125.0251000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105616, 'San Jose', 'San Jose', 'San Jose', 17.8926900, 121.8712500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105617, 'San Jose', 'San Jose', 'San Jose', 17.1500000, 121.6000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105618, 'Tabacao', 'Tabacao', 'San Jose,Tabacao,Tabaco', 15.6497300, 120.9406600, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105619, 'San Jose', 'San Jose', 'San Jose', 15.0333000, 120.7833000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105620, 'San Jose', 'San Jose', 'San Jose', 13.8784000, 121.1045000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105621, 'San Jose', 'San Jose', 'San Jose', 13.8520900, 120.9495100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105622, 'San Jose', 'San Jose', 'San Jose', 13.6993000, 123.5178000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105623, 'San Jose', 'San Jose', 'Macaagnay,San Jose', 13.3500000, 123.5500000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105624, 'San Jose', 'San Jose', 'San Jose', 13.2462900, 123.3713600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105625, 'San Jose', 'San Jose', 'Carangian,Carangran,San Jose', 12.5296000, 124.4875000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105626, 'San Jose', 'San Jose', 'Pandurucan,SJI,San Jose', 12.3527500, 121.0676100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105627, 'Agcogon', 'Agcogon', 'Acogon,Agcogon,San Jose,Taft', 12.0614600, 121.9591100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105628, 'San Jose', 'San Jose', 'San Jose', 10.9888900, 125.0352800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105629, 'San Jose', 'San Jose', 'San Jose', 10.7702800, 122.5338900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105630, 'San Jose', 'San Jose', 'San Jose,San Jose de Buenavista,sanhose,سان ہوزے دے بیوناویستا، اینٹیک,サンホセ,산호세', 10.7450000, 121.9415000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105631, 'San Jose', 'San Jose', 'San Jose', 10.1800000, 125.5683300, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105632, 'San Jose', 'San Jose', '', 9.8005600, 118.7569400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105633, 'San Jose', 'San Jose', 'San Jose', 9.4119400, 123.2380600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105634, 'San Jose', 'San Jose', 'San Jose', 7.7366700, 125.0702800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105635, 'San Jorge', 'San Jorge', 'San Jorge', 11.9808300, 124.8238900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105636, 'San Joaquin', 'San Joaquin', 'San Joaquin', 14.0469500, 121.2186400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105637, 'San Joaquin', 'San Joaquin', 'San Joaquin,San Juaquin', 12.1669700, 124.4300300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105638, 'San Joaquin', 'San Joaquin', 'San Joaquin', 10.5880000, 122.1397000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105639, 'San Jacinto', 'San Jacinto', 'San Jacinto', 16.0726000, 120.4383000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105640, 'San Jacinto', 'San Jacinto', 'San Jacinto', 15.5449600, 120.6695900, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105641, 'San Jacinto', 'San Jacinto', 'San Jacinto', 12.5677000, 123.7337000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105642, 'Catigbian', 'Catigbian', 'Catigbian,San Jacinto', 9.8501000, 123.9994000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105643, 'Laug', 'Laug', 'Laug,San Isidro,San Isidro Laug', 15.0465900, 120.7514900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105644, 'San Isidro', 'San Isidro', 'San Isidro', 17.4650000, 120.6035000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105645, 'San Isidro', 'San Isidro', '', 16.7333300, 121.6166700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105646, 'San Isidro', 'San Isidro', 'San Isidro', 15.2350700, 120.6413400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105647, 'San Isidro', 'San Isidro', 'San Isidro', 15.0211600, 120.8201900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105648, 'San Isidro', 'San Isidro', 'San Isidro', 14.2086000, 121.3983000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105649, 'San Isidro', 'San Isidro', 'San Isidro', 14.0335300, 121.1095000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105650, 'San Isidro', 'San Isidro', 'San Isidro', 13.7686000, 121.2308000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105651, 'San Isidro', 'San Isidro', 'San Isidro', 13.6325000, 122.2428000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105652, 'San Isidro', 'San Isidro', 'San Isidro', 12.9741700, 123.8572200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105653, 'San Isidro', 'San Isidro', 'Bayan ng San Isidro,Bungto san San isidro,San Isidro', 12.3880600, 124.3313900, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105654, 'San Isidro', 'San Isidro', 'San Isidro', 11.4062000, 124.3521000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105655, 'San Isidro', 'San Isidro', 'San Isidro', 10.9629000, 124.4304000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105656, 'San Isidro', 'San Isidro', 'San Isidro', 10.5508000, 123.7335000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105657, 'San Isidro', 'San Isidro', '', 9.9369400, 126.0886100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105658, 'San Isidro', 'San Isidro', '', 9.9166700, 123.8833300, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105659, 'San Isidro', 'San Isidro', 'San Isidro', 9.7712000, 124.2527000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105660, 'San Isidro', 'San Isidro', 'San Isidro', 8.2583300, 124.5930600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105661, 'Batobato', 'Batobato', 'Batobato,San Isidro', 6.8252200, 126.0845800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105662, 'San Ildefonso', 'San Ildefonso', 'San Ildefonso', 17.6222200, 120.3966700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105663, 'San Ildefonso', 'San Ildefonso', 'San Ildefonso', 15.0809000, 120.9410000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105664, 'San Ignacio', 'San Ignacio', 'San Ignacio', 7.1189000, 126.4883800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105665, 'San Guillermo', 'San Guillermo', 'San Guillermo', 16.7254000, 121.8098000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105666, 'San Gregorio', 'San Gregorio', 'San Gregorio', 14.0297000, 121.2639000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105667, 'Sanghan', 'Sanghan', 'Sanghan', 9.0855600, 125.5727800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105668, 'Sañgay', 'Sangay', 'Sangay,Sañgay', 6.4450000, 124.0444400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105669, 'Sangat', 'Sangat', 'Sangat', 10.1360000, 123.6896000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105670, 'San Gabriel', 'San Gabriel', 'San Gabriel', 16.6755600, 120.4030600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105671, 'San Gabriel First', 'San Gabriel First', 'San Gabriel,San Gabriel First', 15.7665000, 120.4565500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105672, 'San Gabriel', 'San Gabriel', 'San Gabriel', 13.5666700, 123.1000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105673, 'Del Monte', 'Del Monte', 'Del Monte,San Francisco del Monte', 14.6418000, 121.0177000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105674, 'San Francisco', 'San Francisco', 'San Francisco', 15.6289000, 120.4363700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105675, 'San Francisco', 'San Francisco', 'Caysyan,San Francisco', 15.3556600, 120.8400100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105676, 'San Francisco', 'San Francisco', 'San Francisco', 14.9615400, 120.5452600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105677, 'San Francisco', 'San Francisco', '', 13.8980600, 121.2480600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105678, 'San Francisco', 'San Francisco', 'San Francisco', 13.7911000, 122.2876000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105679, 'Aurora', 'Aurora', 'Aurora,San Francisco', 13.3476000, 122.5195000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105680, 'San Francisco', 'San Francisco', 'San Francisco', 13.3166700, 123.7500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105681, 'San Francisco', 'San Francisco', 'San Francisco', 13.0367000, 123.7832000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105682, 'San Francisco', 'San Francisco', 'Potot,San Francisco', 12.7247200, 123.9063900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105683, 'San Francisco', 'San Francisco', 'San Francisco', 11.3196100, 122.0505100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105684, 'San Francisco', 'San Francisco', 'San Francisco', 10.6461000, 124.3816000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105685, 'San Francisco', 'San Francisco', 'San Francisco', 10.1601800, 124.3109800, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105686, 'San Francisco', 'San Francisco', 'San Francisco', 10.0600000, 125.1605600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105687, 'San Francisco', 'San Francisco', 'Anaaon,Anaoan,Anaoaon,San Francisco', 9.7769400, 125.4247200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105688, 'San Francisco', 'San Francisco', 'San Francisco', 9.5280600, 125.4855600, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105689, 'San Francisco', 'San Francisco', 'San Francisco', 8.5355600, 125.9500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105690, 'San Fernando', 'San Fernando', 'Dakbayan sa San Fernando,Kota San Fernando,Lungsod ng San Fernando,SFE,San Fernandas,San Fernando,San Fernando City,San Fernando Lakanbalen,San-Fernando,Siyudad na San Fernando,sanferunando,sanpeleunando,sheng fei er nan duo,Сан-Фернандо,سان فرنانڈو، لا یونین,サンフェルナンド,圣费尔南多,산페르난도', 16.6159100, 120.3166300, 'PH', '2017-07-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105691, 'San Fernando', 'San Fernando', 'San Fernando', 16.3892000, 121.1324000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105692, 'San Fernando', 'San Fernando', 'Dakbayan sa San Fernando,Kota San Fernando,Lungsod ng San Fernando,San Fernando,San Fernando Lakanbalen,San-Fernando,Santo Rosario,Siyudad na San Fernando,Urbs Sancti Ferdinandi,sanferunando,sanpeleunando,sheng fei er nan duo,Сан Фернандо,Сан-Фернандо,سان فرنانڈو، پامپانگا,サンフェルナンド,圣费尔南多,산페르난도', 15.0342500, 120.6844500, 'PH', '2016-10-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105693, 'San Fernando', 'San Fernando', 'San - Fernando,San Fernando,Сан - Фернандо', 13.5656000, 123.1453000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105694, 'San Fernando', 'San Fernando', 'San - Fernando,San Fernando,Сан - Фернандо', 12.4833000, 123.7622000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105695, 'San Fernando', 'San Fernando', 'San Fernando', 12.3036400, 122.6004100, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105696, 'San Fernando', 'San Fernando', 'San Fernando', 11.4585000, 123.2499000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105697, 'San Fernando', 'San Fernando', 'San Fernando', 10.7090000, 123.0695000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105698, 'San Fernando', 'San Fernando', 'San Fernando', 10.1624000, 123.7076000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105699, 'San Felipe', 'San Felipe', 'San Felipe', 15.8260800, 120.5975500, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105700, 'San Felipe Old', 'San Felipe Old', 'San Felipe,San Felipe Old', 15.5014000, 120.9078000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105701, 'Poblacion, San Felipe', 'Poblacion, San Felipe', '', 15.0622200, 120.0700000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105702, 'San Felipe', 'San Felipe', 'San Felipe', 14.0184000, 122.9295000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105703, 'San Fabian', 'San Fabian', 'Baley na San Fabian,San Fabian', 16.1231000, 120.4056000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105704, 'San Fabian', 'San Fabian', 'San Fabian', 15.5962900, 120.9066300, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105705, 'San Eugenio', 'San Eugenio', 'San Eugenio', 16.3598000, 120.3570000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105706, 'San Esteban', 'San Esteban', 'San Esteban', 17.3299000, 120.4451000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105707, 'San Enrique', 'San Enrique', 'San Enrique', 11.0712000, 122.6560000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105708, 'San Enrique', 'San Enrique', 'San Enrique', 10.6539000, 122.7172000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105709, 'San Enrique', 'San Enrique', 'San Enrique', 10.4161000, 122.8504000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105710, 'San Emilio', 'San Emilio', 'San Emilio', 17.2261100, 120.6116700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105711, 'San Eduardo', 'San Eduardo', 'San Eduardo', 12.1679000, 125.4503000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105712, 'Sandolot', 'Sandolot', 'Sandolo,Sandolot,Sandulot', 9.1047200, 123.0194400, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105713, 'San Dionisio', 'San Dionisio', 'Dionis,Dionisio,San Dionisio', 11.2710000, 123.0964000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105714, 'San Diego', 'San Diego', 'San Diego', 14.1872000, 121.4867000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105715, 'San Diego', 'San Diego', 'San Diego', 14.0422000, 120.6255000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105716, 'Sandiat Centro', 'Sandiat Centro', 'Sandiat,Sandiat Centro', 17.0729500, 121.6375200, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105717, 'Sandayong Sur', 'Sandayong Sur', 'Sandayong,Sandayong Norte,Sandayong Sur', 10.4958300, 123.9988900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105718, 'San Cristobal', 'San Cristobal', 'San Cristobal', 15.5538200, 120.7670300, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105719, 'San Clemente', 'San Clemente', 'San Clemente', 15.7124000, 120.3590000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105720, 'San Celestio', 'San Celestio', 'San Celestino,San Celestio', 13.9258000, 121.2349000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105721, 'San Casimiro', 'San Casimiro', '', 15.5530600, 120.7808300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105722, 'San Carlos', 'San Carlos', 'San Carlos', 15.5448000, 120.8931000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105723, 'San Carlos', 'San Carlos', 'San Carlos', 15.0396600, 120.7628500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105724, 'San Carlos', 'San Carlos', 'San Carlos', 13.8422000, 121.2416000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105725, 'San Carlos', 'San Carlos', 'San Carlos', 7.9597200, 125.0775000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105726, 'San Bernardo', 'San Bernardo', 'San Bernardino,San Bernardo', 17.4048100, 121.7515500, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105727, 'San Benito', 'San Benito', 'San Benito', 14.8515500, 120.4269300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105728, 'San Benito', 'San Benito', 'San Benito', 9.9577800, 126.0069400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105729, 'San Basilio', 'San Basilio', 'San Basilio', 15.0334100, 120.5842700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105730, 'San Aquilino', 'San Aquilino', 'San Aquilino', 12.5974300, 121.4867100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105731, 'San Antonio', 'San Antonio', 'San Antonio', 17.2732900, 121.7912100, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105732, 'San Antonio', 'San Antonio', 'San Antonio', 16.3502800, 121.1091700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105733, 'San Antonio', 'San Antonio', 'San Antonio', 15.3062000, 120.8560000, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105734, 'San Antonio', 'San Antonio', 'San Antonio', 15.2863600, 120.6716300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105735, 'San Antonio', 'San Antonio', 'San Antonio', 15.1525800, 120.6881700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105736, 'San Antonio', 'San Antonio', 'San Antonio', 14.9666800, 120.6118300, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105737, 'San Antonio', 'San Antonio', 'San Antonio', 14.9465900, 120.0867300, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105738, 'San Antonio', 'San Antonio', 'San Antonio', 14.2000000, 121.5000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105739, 'San Antonio', 'San Antonio', 'San Antonio', 13.8965400, 121.2901700, 'PH', '2012-06-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105740, 'San Antonio', 'San Antonio', 'San Antonio', 13.3710000, 123.4202000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105741, 'San Antonio', 'San Antonio', 'San Antonio', 12.4129000, 124.2791000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105742, 'San Antonio', 'San Antonio', 'San Antonio', 11.2768200, 125.0114100, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105743, 'San Antonio', 'San Antonio', 'San Antonio', 10.8000000, 122.4500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105744, 'San Antonio', 'San Antonio', 'San Antonio', 7.1200000, 125.7397200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105745, 'San Anton', 'San Anton', 'San Anton', 15.3478000, 120.9199100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105746, 'San Andres', 'San Andres', 'San Andres', 15.7192800, 120.7775200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105747, 'San Andres', 'San Andres', 'San Andres', 14.0500000, 121.2166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105748, 'San Andres', 'San Andres', 'San Andres', 14.0035300, 121.1513700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105749, 'San Andres', 'San Andres', 'San Andres', 13.6000000, 124.1000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105750, 'San Andres', 'San Andres', 'San Andres', 13.3227000, 122.6779000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105751, 'San Andres', 'San Andres', 'San Andres', 13.2614000, 123.7795000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105752, 'San Alfonso', 'San Alfonso', 'San Alfonso,San Alfonzo', 7.7802800, 126.4202800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105753, 'San Alejandro', 'San Alejandro', 'San Alejandro', 15.5609800, 120.8489600, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105754, 'San Agustin', 'San Agustin', 'San Agustin', 14.9903000, 120.6060000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105755, 'San Agustin', 'San Agustin', 'San Agustin', 14.9333300, 120.1500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105756, 'San Agustin', 'San Agustin', 'San Agustin', 13.5740000, 123.2641000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105757, 'San Agustin', 'San Agustin', 'Rawis,San Agustin', 13.3263000, 123.4177000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105758, 'San Agustin', 'San Agustin', 'San Agustin,San Augustin', 13.2772900, 121.3048200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105759, 'San Agustin', 'San Agustin', 'San Agustin', 12.5688900, 122.1313900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105760, 'San Agustin', 'San Agustin', 'San Agustin,San Augustin', 12.4198400, 120.9893100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105761, 'San Agustin', 'San Agustin', 'San Agustin', 9.6333300, 123.7833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105762, 'Sampiro', 'Sampiro', 'Sampiro', 13.7841700, 121.3841700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105763, 'Sampao', 'Sampao', 'Sampao', 7.5938900, 125.6611100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105764, 'Sampao', 'Sampao', 'Sampao', 6.8766700, 124.5955600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105765, 'Sampaloc', 'Sampaloc', 'Sampaloc,Sampalok', 14.5402000, 121.3602000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105766, 'Sampaloc', 'Sampaloc', 'Sampaloc', 15.8166700, 120.8666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105767, 'Sampaloc', 'Sampaloc', 'Sampaloc,San Isidro,San Roque', 14.1627000, 121.6396000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105768, 'Sampaloc', 'Sampaloc', 'Sampaloc', 14.0877600, 120.9709800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105769, 'Sampagar', 'Sampagar', 'Sampagar', 7.5138900, 124.9552800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105770, 'Samon', 'Samon', 'Samon', 15.9349500, 120.6507400, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105771, 'Sambuluan', 'Sambuluan', 'Sambulawan,Sambuluan', 6.8833300, 124.7000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105772, 'Samboan', 'Samboan', 'Samboan', 9.5276000, 123.3069000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105773, 'Samal', 'Samal', 'Samal,Самал', 14.7677800, 120.5430600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105774, 'Samal', 'Samal', 'Island Garden City of Samal,Kota Samal,Penaplata,Peñaplata,Pulung Lakanbalen Garden ning Samal,Samal,Sámal,Самал', 7.0744400, 125.7083300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105775, 'San Salvador', 'San Salvador', 'Salvador,San Salvador', 11.0027800, 122.8352800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105776, 'Salvador', 'Salvador', 'Balimbing', 7.8952800, 123.8436100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105777, 'Salvacion I', 'Salvacion I', 'Salvacion,Salvacion I,Salvacion Primera', 15.8396000, 120.9159000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105778, 'Salvacion', 'Salvacion', 'Mabalodbalod Giganoy,Salvacion', 13.6017000, 123.4738000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105779, 'Salvacion', 'Salvacion', 'Salvacion', 13.4633000, 123.3765000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105780, 'Salvacion', 'Salvacion', 'Salvacion', 13.0666700, 123.6166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105781, 'Salvacion', 'Salvacion', 'Salvacion', 12.6151000, 125.0390000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105782, 'Salvacion', 'Salvacion', 'Salvacion', 12.1328700, 119.9328100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105783, 'Salvacion', 'Salvacion', 'Salvacion', 10.6833300, 122.6166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105784, 'Salvacion', 'Salvacion', 'Salvacion', 10.4441000, 122.5332000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105785, 'Salvacion', 'Salvacion', 'Salvacion', 8.7127800, 126.2080600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105786, 'Salvacion', 'Salvacion', 'Salvacion', 8.6775000, 125.6991700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105787, 'Salvacion', 'Salvacion', 'Salvacion', 7.9995400, 126.1248000, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105788, 'Salug', 'Salug', 'Salog,Salug,Salum', 8.1147200, 122.7833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105789, 'Salogon', 'Salogon', 'Salogon,Salongon', 13.6586000, 123.5225000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105790, 'Salinungan Proper', 'Salinungan Proper', 'Salinongan,Salinungan,Salinungan Proper', 16.8690600, 121.6145400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105791, 'Salingogan', 'Salingogan', 'Salingogan,Salingogon', 13.4333000, 123.1923000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105792, 'Salinas', 'Salinas', 'Salinas', 16.3695000, 121.0188000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105793, 'Salimbao', 'Salimbao', '', 7.2225000, 124.2533300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105794, 'Salimbalan', 'Salimbalan', 'Salimbalan,Salimbalon', 8.2741700, 124.7219400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105795, 'Salcedo', 'Salcedo', 'Bauguen,Salcedo', 17.1547200, 120.5394400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105796, 'Salcedo', 'Salcedo', 'Salcedo', 15.8572200, 120.6000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105797, 'Salcedo', 'Salcedo', 'Salcedo', 12.8105200, 121.4674200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105798, 'Salcedo', 'Salcedo', 'Salcedo', 11.1469400, 125.6650000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105799, 'Salaza', 'Salaza', 'Salasa,Salaza', 15.4541000, 119.9553000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105800, 'Salay', 'Salay', 'Salay', 8.8591700, 124.7891700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105801, 'Salawagan', 'Salawagan', 'Salawagan', 7.7052800, 125.1150000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105802, 'Salapungan', 'Salapungan', 'Salapungan', 15.1339000, 120.9279400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105803, 'Salamanca', 'Salamanca', 'Salamanca', 10.7465500, 123.5300000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105804, 'Saint Bernard', 'Saint Bernard', 'Saint Bernard', 10.2833300, 125.1833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105805, 'Sagurong', 'Sagurong', 'Sagurong', 13.7805000, 122.9594000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105806, 'Sagunto', 'Sagunto', 'Sagundo,Sagunto', 16.2007000, 120.5149000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105807, 'Saguing', 'Saguing', 'Saguing', 6.9802800, 125.0780600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105808, 'Saguiaran', 'Saguiaran', 'Sagiaran,Saguiaran', 8.0330600, 124.2700000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105809, 'Sagud-Bahley', 'Sagud-Bahley', 'Sagud Baley,Sagud-Bahley', 16.1169300, 120.3910500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105810, 'Saguday', 'Saguday', 'Saguday', 16.5428000, 121.5638000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105811, 'Sagrada Familia', 'Sagrada Familia', 'Sagrada Familia', 13.2690000, 123.3977000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105812, 'Sagrada', 'Sagrada', 'Sagrada', 13.5301000, 123.4527000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105813, 'Sagpon', 'Sagpon', 'Sagpon', 13.1500000, 123.7333300, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105814, 'Sagnay', 'Sagnay', 'Sagnay', 13.6029000, 123.5225000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105815, 'Sagbayan', 'Sagbayan', 'Borja,Sagbayan,سگبیاں ، بوھول', 9.9144000, 124.0919000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105816, 'Sagay', 'Sagay', 'Kota Sagay,Sagay City,Sagay Lakanbalen,سگے، نیگروس وکڈینٹل', 10.9447200, 123.4241700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105817, 'Sagay', 'Sagay', 'Sagay', 9.1059000, 124.7243000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105818, 'Sagasa', 'Sagasa', 'Sagasa', 10.4680000, 122.8939000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105819, 'Sagasa', 'Sagasa', 'Sagasa', 6.7738900, 124.5747200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105820, 'Sagang', 'Sagang', 'Sagang', 10.3612000, 123.0722000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105821, 'Sagana', 'Sagana', 'Sagana,Susana', 15.5689000, 121.1522000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105822, 'Sagana', 'Sagana', 'Sagana', 12.7225200, 121.4867200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105823, 'Sagada', 'Sagada', 'Sagada', 17.0840000, 120.8996000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105824, 'Sadsalan', 'Sadsalan', 'Sadsalan', 6.8230600, 124.6222200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105825, 'Sadsadan', 'Sadsadan', 'Sadsadan', 16.9333000, 120.8667000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105826, 'Sadanga', 'Sadanga', 'Sacasacan,Sadanga', 17.1651400, 121.0172400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105827, 'Sabtang', 'Sabtang', 'Sabtang,San Vicente,San Vincente', 20.3356600, 121.8715700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105828, 'Sablig', 'Sablig', 'Sablig', 16.2688700, 119.9877000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105829, 'Sablayan', 'Sablayan', 'Sablayan', 12.8346000, 120.7690000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105830, 'Sablan', 'Sablan', 'Sablan', 16.4930000, 120.4954000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105831, 'Sabangan', 'Sabangan', 'Llagan,Sabangan', 17.0036000, 120.9232000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105832, 'Sabang', 'Sabang', 'Sabang', 14.6951000, 120.2507000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105833, 'Sabang', 'Sabang', 'Sabang', 14.3055600, 120.8036100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105834, 'Sabang Indan', 'Sabang Indan', 'Sabang,Sabang Indan', 14.2194000, 122.9151000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105835, 'Sabang', 'Sabang', '', 14.0633300, 120.7111100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105836, 'Sabang', 'Sabang', 'Sabang', 13.7218000, 123.5781000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105837, 'Sabang', 'Sabang', 'Sabang', 13.5092000, 120.9737000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105838, 'Sabang', 'Sabang', 'Sabang', 12.7333300, 123.9333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105839, 'Saavedra', 'Saavedra', 'Saavedra', 9.9851700, 123.3715800, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105840, 'Roxas', 'Roxas', 'Roxas', 17.1189400, 121.6201400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105841, 'Roxas', 'Roxas', 'Paclasan,Paglasan,Roxas', 12.5835000, 121.5176000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105842, 'Roxas City', 'Roxas City', 'RXS,Roxas,Roxas City', 11.5852800, 122.7511100, 'PH', '2012-08-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105843, 'Roxas', 'Roxas', 'Barbacan,Del Pilar,New Barbacan,Roxas,rwksas,روکساس', 10.3215000, 119.3451000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105844, 'Rotunda', 'Rotunda', 'Rotunda', 6.5219400, 124.8900000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105845, 'Rosario', 'Rosario', 'Rosario,Rosario de La Union,Rosario de La Unión', 16.2304000, 120.4863000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105846, 'Rosario', 'Rosario', '', 14.4182700, 120.8577000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105847, 'Rosario', 'Rosario', 'Old Rosario,Rosario', 13.8454400, 121.2047800, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105848, 'Rosario', 'Rosario', 'Rosario', 13.8635000, 122.2731000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105849, 'Rosario', 'Rosario', 'Rosario', 12.5223000, 124.4250000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105850, 'Rosario', 'Rosario', 'Rosario', 11.5832000, 122.3019000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105851, 'Rosario', 'Rosario', 'Rosario', 8.3869400, 126.0033300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105852, 'Rosales', 'Rosales', 'Rosales de Pangasinan,Rosales de Pangasinán', 15.8944400, 120.6327800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105853, 'Ronda', 'Ronda', 'Ronda', 9.9990000, 123.4095000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105854, 'Rominimbang', 'Rominimbang', 'Rominimbang', 7.5000000, 124.3000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105855, 'Romblon', 'Romblon', 'Romblon,Romblón,lombeullon,rwmblwn  rwmblwn,Ромблон,رومبلون، رومبلون,롬블론', 12.5751300, 122.2708100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105856, 'Rogongon', 'Rogongon', '', 8.2333300, 124.3333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105857, 'Rizal', 'Rizal', 'Rizal', 17.8486000, 121.3466000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105858, 'Liwan', 'Liwan', 'Liwan,Rizal', 17.5191000, 121.6320000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105859, 'Rizal', 'Rizal', '', 16.7186100, 121.5552800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105860, 'Rizal', 'Rizal', 'Nazaret,Rizal,Rizel,Ризал', 15.7118000, 121.1061000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105861, 'Rizal', 'Rizal', 'Rizal', 14.1094400, 121.3936000, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105862, 'Rizal', 'Rizal', 'Rizal', 13.9500000, 122.2833300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105863, 'Rizal', 'Rizal', 'Rizal', 13.8765000, 121.1590000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105864, 'Rizal', 'Rizal', 'Rizal', 12.9772200, 123.9141700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105865, 'Rizal', 'Rizal', 'Rizal', 12.8864000, 124.1343000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105866, 'Rizal', 'Rizal', '', 12.4666700, 120.9666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105867, 'Rizal', 'Rizal', 'Rizal', 11.4454000, 122.8607000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105868, 'Rizal', 'Rizal', '', 11.1763900, 124.5794400, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105869, 'Rizal', 'Rizal', 'Rizal', 10.8807000, 123.4178000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105870, 'Rizal', 'Rizal', 'Rizal', 10.6833300, 122.6333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105871, 'Rizal', 'Rizal', 'Rizal', 9.7804000, 125.4643000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105872, 'Rizal', 'Rizal', 'Risal,Rizal,Ризал', 8.9291700, 125.3986100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105873, 'Rissing', 'Rissing', 'Rissing', 16.8752000, 120.4345000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105874, 'Rio Tuba', 'Rio Tuba', 'Rio Tuba', 8.5061300, 117.4316900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105875, 'Rimus', 'Rimus', 'Rimos,Rimus', 16.8764000, 120.3966000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105876, 'Rimpeso', 'Rimpeso', 'Rimpes,Rimpeso', 7.0238900, 124.1002800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105877, 'Reina Mercedes', 'Reina Mercedes', 'Reina Mercedes,Reina Mercedes Nuevo', 16.9854500, 121.8266400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105878, 'Hacienda Refugio', 'Hacienda Refugio', 'Hacienda Refugio,Refugio', 10.5216600, 123.4445000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105879, 'Recodo', 'Recodo', 'Recodo', 11.9491400, 123.7369500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105880, 'Recodo', 'Recodo', '', 6.9519400, 121.9636100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105881, 'Robonkon', 'Robonkon', 'Rebokon,Robokon,Robonkon', 7.7535000, 123.4187000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105882, 'Real', 'Real', 'Keal,Real', 15.8089000, 120.3454900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105883, 'Real', 'Real', 'Puerto Real,Real', 14.6639700, 121.6041200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105884, 'Rapu-Rapu', 'Rapu-Rapu', 'Rapu-Rapu', 13.1866000, 124.1256000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105885, 'Ransang', 'Ransang', 'Ransang', 8.9602800, 117.5827800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105886, 'Ranao', 'Ranao', 'Ranao,Ronao', 16.2076000, 119.8155000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105887, 'Ramos West', 'Ramos West', 'Ramos,Ramos West,Romas', 16.6984000, 121.6136000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105888, 'Ramos', 'Ramos', 'Bani,Ramos', 15.6653000, 120.6406000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105889, 'Ramon Magsaysay', 'Ramon Magsaysay', 'Ramon Magsaysay', 8.0019400, 123.5094400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105890, 'Ramon', 'Ramon', 'Ramon,Рамон', 16.7841600, 121.5350400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105891, 'Ramain', 'Ramain', 'Ditsaan-Ramain,Ramain', 7.9708300, 124.3452800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105892, 'Rajal Norte', 'Rajal Norte', 'Rajal,Rajal Norte', 15.4448500, 120.8625600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105893, 'Ragay', 'Ragay', 'Ragay,Raike,Rakei', 13.8183000, 122.7923000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105894, 'Ragan Norte', 'Ragan Norte', 'Ragan Norte', 17.3231800, 121.7742800, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105895, 'Ragandang', 'Ragandang', 'Ragandang', 6.6638600, 124.1206300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105896, 'Quitang', 'Quitang', 'Quitang', 13.5513000, 123.0529000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105897, 'Quisao', 'Quisao', 'Quisao', 14.4347000, 121.3344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105898, 'Quirino', 'Quirino', 'Angaki,Quirino', 17.1555600, 120.6700000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105899, 'Quirino', 'Quirino', 'Quirino', 17.1333300, 121.7000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105900, 'Quipot', 'Quipot', 'Quipot', 13.9556000, 121.3190300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105901, 'Quipot', 'Quipot', 'Quipot', 11.2833300, 123.0000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105902, 'Quintong', 'Quintong', 'Quintong', 15.9558100, 120.3217100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105903, 'Quinipot', 'Quinipot', 'Quinipot,Quiniput,Quinput', 7.1802800, 122.2202800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105904, 'Kinatakutan', 'Kinatakutan', 'Kinatakutan,Quinatacutan', 13.9550000, 122.4678000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105905, 'Quinarayan', 'Quinarayan', 'Quinarayan', 17.4441000, 120.4722000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105906, 'Quinapundan', 'Quinapundan', 'Quinapondan,Quinapundan', 11.1583300, 125.5219400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105907, 'Quinagaringan', 'Quinagaringan', 'Kinagaringan,Quinagaringan', 11.1222000, 122.5875000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105908, 'Quinabigan', 'Quinabigan', 'Quinabigan', 12.9936000, 121.4781200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105909, 'Quilo-quilo', 'Quilo-quilo', 'Quilo-quilo', 13.8638000, 121.2209000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105910, 'Quiling', 'Quiling', 'Quiling', 18.0683300, 120.5438900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105911, 'Quibal', 'Quibal', 'Quibal', 17.7159000, 121.8113500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105912, 'Quiapo', 'Quiapo', 'Kiyabo,Quiapo,Quiapo District,kui a po qu,奎阿坡區', 14.6000000, 120.9833000, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105913, 'Quezon City', 'Quezon City', 'Keson-Siti,Quezon,Quezon City,Кесон-Сити', 14.6488000, 121.0509000, 'PH', '2012-05-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105914, 'Quezon', 'Quezon', 'Quezon,Quezón', 17.3130300, 121.6065400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105915, 'Quezon', 'Quezon', 'Keson-Siti,Quezon,Кесон-Сити', 16.5000000, 121.2666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105916, 'Quezon', 'Quezon', 'Keson-Siti,Quezon,Кесон-Сити', 15.5512000, 120.8147000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105917, 'Quezon', 'Quezon', 'Quezon', 14.0057000, 122.1838000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105918, 'Quezon', 'Quezon', 'Quezon', 12.6000000, 123.9500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105919, 'Quezon', 'Quezon', 'Quezon', 10.4361700, 123.2604000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105920, 'Quezon', 'Quezon', 'Alfonso XIII,Keson-Siti,Quezon,Quezón,kzwn  palawan,Кесон-Сити,کزون، پالاوان', 9.2411100, 118.0313900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105921, 'Quezon', 'Quezon', 'Keson,Kiokong,Quezon,Кесон', 7.7302800, 125.0988900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105922, 'Putol', 'Putol', 'Putol', 13.9922000, 120.7275000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105923, 'Putlod', 'Putlod', 'Putlod,Putlog,Putloo', 15.3706000, 120.8675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105924, 'Puting Kahoy', 'Puting Kahoy', 'Puting Kahoy', 14.2157000, 121.0310000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105925, 'Putingkahoy', 'Putingkahoy', 'Putingcahoy,Putingkahoy', 13.8302300, 121.3275300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105926, 'Putiao', 'Putiao', 'Putiao', 13.0195000, 123.7148000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105927, 'Putat', 'Putat', 'Putat', 10.7858000, 123.8469000, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105928, 'Puro Pinget', 'Puro Pinget', 'Pura Pinget,Puro,Puro Pinget,Puro Pingit,Puru Pinget', 17.6796700, 120.3588300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105929, 'Puro', 'Puro', 'Goldbag,Poro Landing,Puro,Rio Guinobatan', 12.4841000, 123.3827000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105930, 'Puricay', 'Puricay', 'Puricay,Purikay', 6.6861400, 124.0695700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105931, 'Porais', 'Porais', 'Porais,Purais', 15.7551000, 121.0427000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105932, 'Purac', 'Purac', 'Porac,Porach,Purac,Порач', 15.2520000, 120.0169000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105933, 'Pura', 'Pura', 'Pura', 15.6248000, 120.6480000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105934, 'Pontian', 'Pontian', 'Pontian,Puntian', 8.2811100, 124.9002800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105935, 'Punta Silum', 'Punta Silum', 'Punta Silum', 8.3816700, 124.2694400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105936, 'Paddaya', 'Paddaya', 'Paddaya,Punta,Punta Paddaya', 18.3236100, 121.7386600, 'PH', '2013-12-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105937, 'Punta', 'Punta', 'Punta', 14.2914000, 121.3074000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105938, 'Punta', 'Punta', 'Punta', 12.2441000, 122.0097000, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105939, 'Punta', 'Punta', 'Punta', 8.9897200, 125.3400000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105940, 'Punolu', 'Punolu', 'Punol,Punolu', 7.0500000, 124.5833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105941, 'Pongol', 'Pongol', 'Pongol,Pungol', 8.2786100, 124.7483300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105942, 'Puncan', 'Puncan', 'Puncan', 15.9071000, 120.9907000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105943, 'Punay', 'Punay', 'Punai,Punay', 5.9613900, 121.1980600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105944, 'Punao', 'Punao', 'Punao', 10.5651600, 123.4080000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105945, 'Punang', 'Punang', 'Punang,Punango', 9.0169000, 118.0495000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105946, 'Pulupandan', 'Pulupandan', 'Palupandan,Puhipandan,Pulupandan', 10.5203000, 122.8017000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105947, 'Pulung Santol', 'Pulung Santol', 'Balunsantol,Pulong Santol,Pulung Santol', 15.0457400, 120.5618800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105948, 'Pulungmasle', 'Pulungmasle', 'Pulungmasle', 15.0004000, 120.5577400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105949, 'Pulong Santa Cruz', 'Pulong Santa Cruz', 'Pulong Santa Cruz,Pulong Santa Rosa,Santa Cruz', 14.2732400, 121.0764300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105950, 'Pulong Sampalok', 'Pulong Sampalok', 'Pulong Sampaloc,Pulong Sampalok,Pulong Sampoloc', 14.9611000, 121.0609000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105951, 'Pulong Gubat', 'Pulong Gubat', 'Pulong Gubat,Pulongubat', 14.8593800, 120.9059900, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105952, 'Pulo', 'Pulo', 'Pulo', 15.2460000, 120.9285000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105953, 'Pulo', 'Pulo', 'Polo,Pulo', 14.9622000, 121.0147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105954, 'Pulilan', 'Pulilan', 'Pulilan', 14.9016700, 120.8491700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105955, 'Pulangbato', 'Pulangbato', 'Pulangbato', 13.7538700, 121.3926600, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105956, 'Pugo', 'Pugo', 'Pugo', 16.3221000, 120.4670000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105957, 'Puerto Princesa', 'Puerto Princesa', 'Dakbayan sa Puerto Princesa,Kota Puerto Princesa,Lungsod ng Puerto Princesa,PPS,Puehrto-Prinsesa,Puerta Princesa,Puerto Princesa,Puerto Princesa City,Puerto Princesa Lakanbalen,Puerto Prinsesa,Syudad han Puerto Princesa,Syudad nin Puerto Princesa,bwrtwbrnss,pu lin sai sa gang,pueleutopeulinsesa,pwrtwprnss,pwyrtw prnsysa,Пуерто Принсеса,Пуэрто-Принсеса,بورتوبرنسس,پورتوپرنسس,پویرتو پرنسیسا,プエルト・プリンセサ,普林塞薩港,푸에르토프린세사', 9.7391700, 118.7352800, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105958, 'Puerto Galera', 'Puerto Galera', 'Port Galera,Puerto Calero,Puerto Galera,Puerto Gallera', 13.5022300, 120.9516600, 'PH', '2015-04-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105959, 'Puerto Bello', 'Puerto Bello', 'Hacienda Porto Bello,Puerto Bello', 10.9733000, 124.5351000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105960, 'Puelay', 'Puelay', 'Puelay', 15.8868300, 120.5735800, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105961, 'Pudoc', 'Pudoc', 'Pudoc,Pudoc West', 16.9215000, 120.4235000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105962, 'Pudoc North', 'Pudoc North', 'Pudoc,Pudoc Norte,Pudoc North', 17.6096000, 120.3685200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105963, 'Pualas', 'Pualas', 'Pualas', 8.0172200, 123.8480600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105964, 'Pualas', 'Pualas', 'Pualas', 7.8162400, 124.0710500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105965, 'Prosperidad', 'Prosperidad', 'Prosperidad', 10.5159600, 123.3085000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105966, 'Prosperidad', 'Prosperidad', 'Prosperidad,brwsbrydad,peuloseupelidadeu,prwsprydad,prwsprydad  agwsan jnwby,بروسبريداد,پروسپریداد,پروسپریداد، اگوسان جنوبی,پروسپیریڈاڈ,프로스페리다드', 8.5800000, 125.8963900, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105967, 'Progreso', 'Progreso', 'Progreso', 13.9083000, 122.0906000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105968, 'Prinza', 'Prinza', 'Prinza', 14.1960700, 121.1369600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105969, 'Prieto Diaz', 'Prieto Diaz', 'Prieto Diaz', 13.0416700, 124.1938900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105970, 'President Roxas', 'President Roxas', 'Lotudlotud,Lutodlutod,President Roxas,President Roxax', 11.4310000, 122.9279000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105971, 'President Roxas', 'President Roxas', 'President Roxas,Roxas', 7.1544400, 125.0558300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105972, 'President Quirino', 'President Quirino', 'President Quirino,Sambulawan,Simbulawan', 6.7038900, 124.7372200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105973, 'Pitogo', 'Pitogo', 'Pitoco,Pitogo,President Carlos Polestico Garcia', 10.1214000, 124.5533000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105974, 'Parabcan', 'Parabcan', 'Parabcan,Parubcan,Presentacion', 13.7088000, 123.7450000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105975, 'Prinza', 'Prinza', 'Prenza,Prinza', 13.9967900, 120.6540900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105976, 'Prado Siongco', 'Prado Siongco', 'Prado,Prado Siongco', 14.8790000, 120.5129200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105977, 'Pozorrubio', 'Pozorrubio', 'Pozorrubio,Pozorrubio de Pangasinan,Pozorrubio de Pangasinán', 16.1110000, 120.5440000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105978, 'Pototan', 'Pototan', 'Pototan', 10.9437000, 122.6352000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105979, 'Potot', 'Potot', 'Potot', 12.2034500, 123.4319100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105980, 'Patong', 'Patong', 'Patong,Potong', 12.3364300, 125.2852100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105981, 'Potia', 'Potia', '', 16.8500000, 121.4833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105982, 'San Vicente', 'San Vicente', 'Port San Vicente,San Vicente,San Vincent,San Vincente', 18.5074600, 122.1503500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105983, 'Port Barton', 'Port Barton', 'Port Barton', 10.4755600, 119.2472200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105984, 'Port Area', 'Port Area', 'Port Area,Port District', 14.5833000, 120.9667000, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105985, 'Poro', 'Poro', 'Poro', 10.6292000, 124.4087000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105986, 'Porac', 'Porac', 'Porac,Porach,Порач', 15.0711000, 120.5423000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105987, 'Poona-Piagapo', 'Poona-Piagapo', '', 8.0833300, 124.1166700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105988, 'Pontevedra', 'Pontevedra', 'Pontevedra', 11.4812000, 122.8325000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105989, 'Pontevedra', 'Pontevedra', 'Pontevedra,Portevedra', 10.3746000, 122.8682000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105990, 'Ponso', 'Ponso', 'Ponso', 13.2910000, 123.5171000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105991, 'Ponot', 'Ponot', 'Jose Dalman,Ponot', 8.4520000, 123.0222000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105992, 'Ponong', 'Ponong', 'Ponong,Ponong Grande', 11.0829000, 122.6261000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105993, 'Pung-Pang', 'Pung-Pang', 'Pongpong,Pung-Pang', 6.4975000, 125.4633300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105994, 'Pantukan', 'Pantukan', 'Pantukan,Pongotan', 7.1633300, 125.8991700, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105995, 'Pondaguitan', 'Pondaguitan', 'Pondaguitan,Pundaguitan', 6.3611500, 126.1777800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105996, 'Puloypuloy', 'Puloypuloy', 'Poloy-Poloy,Puloypuloy', 6.6351700, 124.0960000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105997, 'Polopina', 'Polopina', 'Polopina', 11.2068000, 123.1659000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105998, 'Polonoling', 'Polonoling', 'Polongding,Polonoling', 6.2850000, 124.9683300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(105999, 'Polong Norte', 'Polong Norte', 'Polong,Polong Norte', 15.9030000, 120.4214900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106000, 'Polong', 'Polong', 'Polong', 15.9771000, 120.2009000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106001, 'Polomolok', 'Polomolok', 'Polomoloc,Polomolok', 6.2216700, 125.0639800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106002, 'Polo', 'Polo', 'Polo', 16.1963000, 119.9491000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106003, 'Pulo', 'Pulo', 'Polo,Pulo', 14.7146200, 121.6329300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106004, 'Polo', 'Polo', 'Polo', 11.5844000, 122.3122000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106005, 'Polo', 'Polo', 'Polo', 9.4816000, 123.1802000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106006, 'Polo', 'Polo', 'Polo', 6.2647200, 125.1125000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106007, 'Polloc', 'Polloc', 'Polloc', 7.3534000, 124.2208800, 'PH', '2016-06-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106008, 'Polillo', 'Polillo', 'Polillo', 14.7169900, 121.9488900, 'PH', '2015-04-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106009, 'Polangui', 'Polangui', 'Polangui', 13.2923000, 123.4855000, 'PH', '2011-08-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106010, 'Polañge', 'Polange', 'Polange,Polangi,Polangui,Polañge', 12.3966700, 124.6311100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106011, 'Polanco', 'Polanco', 'Polanco', 8.5329000, 123.3617000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106012, 'Polahongon', 'Polahongon', 'Palahongon,Polabongon,Polahongon', 10.5288000, 124.9694000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106013, 'Pola', 'Pola', 'Pola,Polo', 13.1437900, 121.4415200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106014, 'Pogonsili', 'Pogonsili', 'Pagonisili,Pogonsili', 15.8204800, 120.2601700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106015, 'Poctol', 'Poctol', 'Poctol', 13.8209500, 121.4418400, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106016, 'Plaridel', 'Plaridel', 'Plaridel', 15.6585300, 121.0200900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106017, 'Plaridel', 'Plaridel', 'Pandi,Plaridel,Quingua,Quinqua', 14.8872200, 120.8572200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106018, 'Plaridel', 'Plaridel', 'Plaridel,Siain', 13.9551000, 122.0208000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106019, 'Plaridel', 'Plaridel', 'Plaridel', 10.8974000, 123.4894000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106020, 'Plaridel', 'Plaridel', 'Plaridel,Tigbauan', 10.5667000, 124.7645000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106021, 'Plaridel', 'Plaridel', 'Plaridel', 9.3786000, 118.5017400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106022, 'Plaridel', 'Plaridel', 'Plaridel', 8.6214000, 123.7101000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106023, 'Placer', 'Placer', 'Paacer,Placer', 11.8687000, 123.9184000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106024, 'Placer', 'Placer', '', 9.6541700, 125.6025000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106025, 'Pitogo', 'Pitogo', 'Pitogo,Pitugu', 5.8882300, 121.3121500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106026, 'Pitogo', 'Pitogo', 'Pitogo', 13.7838000, 122.0902000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106027, 'Pitogo', 'Pitogo', 'Pitogo', 12.5074400, 121.0904100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106028, 'Pitogo', 'Pitogo', 'Pitogo', 7.4546000, 123.3111000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106029, 'Limbuhan', 'Limbuhan', 'Limbuhan,Limbujan,Pio V. Corpus,Pio V. Corpuz', 11.8837700, 124.0501100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106030, 'Pio Duran', 'Pio Duran', 'Pio Duran', 13.0292800, 123.4449600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106031, 'Pio', 'Pio', 'Pio', 15.0474100, 120.5189100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106032, 'Pinukpuk', 'Pinukpuk', '', 17.6166700, 121.4000000, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106033, 'Pinugay', 'Pinugay', 'Pinugay', 14.5967000, 121.2623000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106034, 'Pintuyan', 'Pintuyan', 'Pintuyan', 9.9441000, 125.2494000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106035, 'Pinoma', 'Pinoma', 'Pinoma', 16.8742100, 121.7066900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106036, 'Pinokawan', 'Pinokawan', 'Pinocawan,Pinokawan', 10.3411700, 123.2939000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106037, 'Pinit', 'Pinit', 'Pinit', 13.5686000, 123.4140000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106038, 'Pinili', 'Pinili', 'Pinili', 17.9517000, 120.5278000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106039, 'Pines', 'Pines', '', 8.4522200, 123.8075000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106040, 'Pandasan', 'Pandasan', 'Pandasan,Pindasan', 7.2838000, 125.8535000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106041, 'Pindangan Centro', 'Pindangan Centro', 'Pindangan,Pindangan Centro', 15.8605600, 120.5513900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106042, 'Pinayagan Norte', 'Pinayagan Norte', 'Pinayagan,Pinayagan Norte', 9.9333300, 123.9500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106043, 'Pinaring', 'Pinaring', 'Pinaring', 7.2288900, 124.3105600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106044, 'Pinamungahan', 'Pinamungahan', 'Pihamungajan,Pinamangajan,Pinamangayan,Pinamungahan,Pinamungajan,Pinamunganjan', 10.2708000, 123.5839000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106045, 'Pinamopoan', 'Pinamopoan', 'Pinamopoan', 11.3147200, 124.5738900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106046, 'Pinambaran', 'Pinambaran', 'Pinambaran', 15.2023300, 120.9779700, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106047, 'Pinamalayan', 'Pinamalayan', 'Pinamalayan,Pinamalayán,Wawa', 13.0460300, 121.4620500, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106048, 'Piñahan', 'Pinahan', 'Pinahan,Pinelands,Piñahan', 15.6266000, 121.0621000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106049, 'Pinagsibaan', 'Pinagsibaan', 'Pinagsibaan', 13.8347900, 121.3211800, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106050, 'Pinagsabangan', 'Pinagsabangan', 'Pinagsabangan', 13.2655900, 121.2681200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106051, 'Panadtaban', 'Panadtaban', 'Panadtaban,Pinadtaban', 6.9008300, 124.6427800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106052, 'Piña', 'Pina', 'Pina,Piña', 10.6395600, 122.6382000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106053, 'Pimbalayan', 'Pimbalayan', 'Pimbalayan', 6.8691700, 124.6725000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106054, 'Pililla', 'Pililla', 'Pililla', 14.4854000, 121.3062000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106055, 'Pilig', 'Pilig', 'Pilig', 17.3427800, 121.7738900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106056, 'Pili', 'Pili', '', 13.6666700, 123.3166700, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106057, 'Pili', 'Pili', 'Pili', 13.0664000, 121.5203200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106058, 'Pili', 'Pili', 'Pili', 12.9805600, 123.8641700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106059, 'Pili', 'Pili', 'Pili,Pill,Пили', 11.1196000, 123.0147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106060, 'Pilar', 'Pilar', 'Balioag,Pilar,Pilary', 17.4165000, 120.5954000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106061, 'Pilar', 'Pilar', 'Pilar', 14.6600000, 120.5652800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106062, 'Pilar', 'Pilar', 'Pilar', 12.9231000, 123.6724000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106063, 'Pilar', 'Pilar', 'Pilar,Pilar Town', 11.4870000, 122.9963000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106064, 'Pilar', 'Pilar', 'Pilar', 10.8065000, 124.5661000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106065, 'Pilar', 'Pilar', 'Pilar', 9.8650000, 126.0994400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106066, 'Pilar', 'Pilar', 'Pilar', 9.8290000, 124.3273000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106067, 'Pila', 'Pila', 'Pila,Pily,Пилы', 14.2325000, 121.3648000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106068, 'Pikit', 'Pikit', 'Fort Pikit,Pikit,Pikit Pagalungan', 7.0544400, 124.6719400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106069, 'Pigcawayan', 'Pigcawayan', 'Pigcawayan,Pigkawayan', 7.2772200, 124.4255600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106070, 'Pidsandawan', 'Pidsandawan', 'Pidsandawan', 6.9322200, 124.5908300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106071, 'Pidigan', 'Pidigan', 'Pidigan', 17.5700000, 120.5903000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106072, 'Piddig', 'Piddig', 'Piddig,Pidding', 18.1655000, 120.7175000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106073, 'Piat', 'Piat', 'Piat', 17.7905000, 121.4780000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106074, 'Pias', 'Pias', 'Pias', 15.3452500, 121.0747300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106075, 'Pias', 'Pias', 'Pias,Pias-Pias', 15.0169900, 120.5623800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106076, 'Piape I', 'Piape I', 'Piape,Piape I,Piapi', 10.7288000, 121.9724000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106077, 'Perrelos', 'Perrelos', 'Perrelos', 10.1169000, 123.6738000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106078, 'Perez', 'Perez', 'Perez', 14.1946500, 121.9263600, 'PH', '2012-06-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106079, 'Peñarrubia', 'Penarrubia', 'Penarrubia,Peñarrubia', 17.5647000, 120.6519000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106080, 'Peñaranda', 'Penaranda', 'Pen''jaranda,Penaranda,Peñaranda,Пеньяранда', 15.3511600, 121.0039300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106081, 'Peñablanca', 'Penablanca', 'Penablanca,Peñablanca', 17.6334200, 121.7811700, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106082, 'Piña', 'Pina', 'PeNa,Pina,Piña,Weyler', 12.1907800, 124.4015000, 'PH', '2016-09-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106083, 'Peña', 'Pena', 'Pena,Peña', 12.0890000, 123.9384000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106084, 'Pedtad', 'Pedtad', 'Pedtad', 7.1605600, 124.8144400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106085, 'Paypay', 'Paypay', 'Paypay', 11.2152000, 123.9762000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106086, 'Payocpoc Sur', 'Payocpoc Sur', 'Payocpoc Sur', 16.4944400, 120.3280600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106087, 'Payapa', 'Payapa', 'Payapa', 13.9980300, 120.8920700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106088, 'Payao', 'Payao', 'Payao', 10.1785000, 122.9236000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106089, 'Payao', 'Payao', '', 7.5866700, 122.8027800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106090, 'Pawing', 'Pawing', 'Pawing', 11.1800000, 125.0027800, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106091, 'Pawili', 'Pawili', 'Pauili,Pawili', 13.5166700, 123.2833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106092, 'Pawican', 'Pawican', 'Pawican', 12.0741000, 123.9706000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106093, 'Pawak', 'Pawak', 'Pawac,Pawak', 8.0163400, 124.2564700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106094, 'Pawa', 'Pawa', 'Pawa', 13.1773000, 123.7301000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106095, 'Pawa', 'Pawa', 'Pawa', 13.1335000, 123.8915000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106096, 'Pawa', 'Pawa', 'Pawa', 11.5628500, 122.8173600, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106097, 'Pavia', 'Pavia', 'Pavia,Payia,Ravia', 10.7761100, 122.5455600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106098, 'Paulba', 'Paulba', 'Paulba', 13.1787500, 123.4625200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106099, 'Pau', 'Pau', 'Pau', 15.0279000, 120.7243000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106100, 'Patuto', 'Patuto', 'Patuto', 14.1166700, 120.9666700, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106101, 'Patonan', 'Patonan', 'Patonan,Patun-an', 10.5681600, 123.4723000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106102, 'Pattao', 'Pattao', 'Pattao', 18.2469400, 121.8147000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106103, 'Patrocinio', 'Patrocinio', 'Patrocinio', 8.6125000, 124.8455600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106104, 'Patria', 'Patria', 'Patria,Patriya', 11.7403000, 122.0171000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106105, 'Patpata Segundo', 'Patpata Segundo', 'Patpata,Patpata Segundo', 17.1833300, 120.4333300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106106, 'Pato-o', 'Pato-o', 'Pato-o', 12.4302500, 122.0664000, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106107, 'Patnongon', 'Patnongon', 'Patnongon', 10.9132000, 121.9937000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106108, 'Patnanungan', 'Patnanungan', 'Patnanongan,Patnanungan', 14.7833300, 122.1833300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106109, 'Patindeguen', 'Patindeguen', 'Patindeguen', 7.2197200, 124.4983300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106110, 'Patin-ay', 'Patin-ay', 'Patin-ay', 8.5505600, 125.9372200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106111, 'Patique', 'Patique', 'Paticui,Patique', 10.2370000, 122.8993000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106112, 'Pateros', 'Pateros', '', 14.5391000, 121.0726000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106113, 'Patayac', 'Patayac', 'Patayac,Patayak', 15.9630000, 120.4225100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106114, 'Patawag', 'Patawag', 'Patauag,Patawag', 8.1063900, 122.6208300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106115, 'Patao', 'Patao', 'Patao,Patoa', 11.2202000, 123.6925000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106116, 'Patabog', 'Patabog', 'Patabog', 13.4432000, 122.4557000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106117, 'Pata', 'Pata', 'Pata', 17.7152000, 121.5018000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106118, 'Pasuquin', 'Pasuquin', 'Pasuquin', 18.3328000, 120.6177000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106119, 'Pastrana', 'Pastrana', 'Pastrana', 11.1366700, 124.8855600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106120, 'Passi', 'Passi', '', 11.1077800, 122.6419400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106121, 'Pasong Kawayan Primero', 'Pasong Kawayan Primero', 'Pasong Kawayan,Pasong Kawayan I,Pasong Kawayan Primero,Pasongcawayan', 14.3431700, 120.8815700, 'PH', '2013-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106122, 'Pasil', 'Pasil', '', 17.3833300, 121.1333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106123, 'Pasil', 'Pasil', 'Pasil', 10.8378000, 122.6098000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106124, 'Pasibi West', 'Pasibi West', 'Pasibe West,Pasibi,Pasibi Sur,Pasibi West', 15.8587000, 120.3793500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106125, 'Pasian', 'Pasian', 'Pasian,Santa Felomena', 7.9280600, 126.0672200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106126, 'Pasacao', 'Pasacao', 'Pasacao', 13.5118000, 123.0426000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106127, 'Parista', 'Parista', 'Parista', 15.8536000, 120.9282000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106128, 'Parioc Segundo', 'Parioc Segundo', 'Parioc,Parioc Segundo', 17.1750300, 120.4657600, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106129, 'Paringao', 'Paringao', 'Paringao,Paringaor', 16.5716700, 120.3241700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106130, 'Parian Dakula', 'Parian Dakula', 'Parian Dacula,Parian Dakula', 5.5566700, 120.7719400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106131, 'Parion', 'Parion', 'Parian,Parion', 11.4748000, 122.6972000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106132, 'Parangan', 'Parangan', 'Parangan', 5.0838900, 119.9383300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106133, 'Parang', 'Parang', 'Parang', 14.6331000, 120.4493000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106134, 'Parang', 'Parang', 'Parang', 9.2814900, 125.9420800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106135, 'Parang', 'Parang', '', 7.3703500, 124.2697300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106136, 'Parang', 'Parang', 'Parang', 5.9137000, 120.9056000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106137, 'Paraiso', 'Paraiso', 'Paraiso', 10.8849000, 123.3627000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106138, 'Paraiso', 'Paraiso', 'Paraiso', 6.4736100, 124.8108300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106139, 'Paradahan', 'Paradahan', 'Paradahan', 14.3212300, 120.8605900, 'PH', '2013-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106140, 'Paracelis', 'Paracelis', 'Paracelis', 17.2666700, 121.4666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106141, 'Paracale', 'Paracale', 'Paracale', 14.2804000, 122.7881000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106142, 'Papaya', 'Papaya', 'General Tinio,Papaya', 15.3201600, 120.8357400, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106143, 'Paombong', 'Paombong', 'Paombong,Paonbong', 14.8311100, 120.7891700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106144, 'Paulba', 'Paulba', 'Paolbo,Paulba', 13.7136000, 123.2496000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106145, 'Paoay', 'Paoay', 'Paoay', 18.0616000, 120.5221000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106146, 'Panukulan', 'Panukulan', 'Panukulan', 14.9337100, 121.8168500, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106147, 'Panognawan', 'Panognawan', 'Panognawan,Panugnawan', 11.1619000, 124.0050000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106148, 'Pantubig', 'Pantubig', 'Pantubig,Puting Tubig', 14.9680600, 120.9547200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106149, 'Pantijan No 2', 'Pantijan No 2', 'Pantihan No. 2,Pantijan,Pantijan No 2', 14.2330600, 120.8005600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106150, 'Pantay Na Matanda', 'Pantay Na Matanda', 'Pantay,Pantay Na Matanda', 14.1175000, 121.1211100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106151, 'Pantar', 'Pantar', 'Pantar', 8.0661100, 124.2583300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106152, 'Pantao-Ragat', 'Pantao-Ragat', 'Pantao-A-Ragat,Pantao-Ragat', 8.0833300, 124.1333300, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106153, 'Pantao', 'Pantao', 'Panta,Pantao', 13.1944000, 123.3271000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106154, 'Pantabangan', 'Pantabangan', 'Panabangan,Pantabangan', 15.8113000, 121.1443000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106155, 'Pansoy', 'Pansoy', 'Pansoy', 13.1817700, 122.5998900, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106156, 'Pansol', 'Pansol', 'Panso,Pansol', 13.8866000, 121.2432000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106157, 'Panlinlang', 'Panlinlang', 'Panlinlang', 15.1833300, 120.7000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106158, 'Panlaitan', 'Panlaitan', 'Panlaitan', 12.1190700, 119.8486100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106159, 'Panitan', 'Panitan', 'Panatan,Paniban,Panitan', 11.4660000, 122.7725000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106160, 'Panitian', 'Panitian', 'Panitan,Panitian', 9.0965000, 118.0864000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106161, 'Paniqui', 'Paniqui', 'Paniki,Paniqui,Паники', 15.6689000, 120.5806000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106162, 'Paniqui', 'Paniqui', 'Panique,Paniqui', 12.4532000, 123.3821000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106163, 'Panique', 'Panique', 'Panique', 12.4802500, 122.0146200, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106164, 'Panikihan', 'Panikihan', 'Panikihan', 13.9083000, 122.1310000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106165, 'Panikian', 'Panikian', 'Panikian', 9.3293500, 125.9338000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106166, 'Panikian', 'Panikian', 'Panikian', 7.0107000, 126.0241800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106167, 'Pangyan', 'Pangyan', 'Pangyan', 5.7008300, 125.2811100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106168, 'Simbahan', 'Simbahan', 'Pangutaran,Pangutatan,Simbahan,Simbanan', 6.3032000, 120.5836000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106169, 'Pangulayan', 'Pangulayan', 'Panggulayan,Pangulayan', 13.0398000, 121.4479200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106170, 'Panguiranan', 'Panguiranan', 'Panguiranan', 12.0698600, 123.3185100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106171, 'Pangpang', 'Pangpang', 'Pangpang', 15.9387500, 120.3093900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106172, 'Pangpang', 'Pangpang', 'Pangpang', 12.5692000, 125.0740000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106173, 'Pañgobilian', 'Pangobilian', 'Pangobilian,Pañgobilian', 8.8011100, 117.8594400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106174, 'Panglao', 'Panglao', '', 9.5780600, 123.7458300, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106175, 'Pangil', 'Pangil', 'Pangil', 14.4033000, 121.4650600, 'PH', '2015-04-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106176, 'Pangil', 'Pangil', 'Pangi,Pangil,Pañgi', 14.2010200, 120.9077800, 'PH', '2014-03-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106177, 'Pangian', 'Pangian', 'Pangian', 6.4627800, 125.5452800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106178, 'Pangdan', 'Pangdan', 'Pangdan,Pangdon', 11.7444400, 124.9166700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106179, 'Pangdan', 'Pangdan', 'Pandan,Pangdan', 10.2307800, 123.7379000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106180, 'Pangascasan', 'Pangascasan', 'Panasgasan,Pangacasan,Pangascasan', 16.1169100, 120.0866400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106181, 'Pangapisan', 'Pangapisan', 'Pangapisam,Pangapisan', 16.2160000, 119.9570000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106182, 'Pangao', 'Pangao', '', 13.9172200, 121.1255600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106183, 'Pangantocan', 'Pangantocan', 'Panatukan,Pangantocan,Pangantoean,Pangantukan', 7.8472200, 124.8125000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106184, 'Panganiban', 'Panganiban', 'Panganiban', 16.0075000, 120.7752000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106185, 'Panganiban', 'Panganiban', 'Panganiban,Payo', 13.9003300, 124.2981600, 'PH', '2014-09-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106186, 'Pangal Sur', 'Pangal Sur', 'Pangal,Pangal Sur', 16.6003600, 121.6697900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106187, 'Pangabuan', 'Pangabuan', 'Panagabuan,Pangabuan', 8.0569400, 123.6958300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106188, 'Pang', 'Pang', 'Pang', 5.9483700, 121.2883000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106189, 'Pando', 'Pando', 'Pando', 15.3939500, 120.6847300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106190, 'Pandi', 'Pandi', 'Panda,Pandi,Панда', 14.8650000, 120.9572200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106191, 'New Pandanon', 'New Pandanon', 'New Pandanon,Pandanon', 10.5569600, 123.1475000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106192, 'Pandan Niog', 'Pandan Niog', 'Pandan Niog,Pangdan', 6.2282000, 120.5631000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106193, 'Pandan', 'Pandan', 'Pandan', 14.0453000, 124.1694000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106194, 'Pandan', 'Pandan', 'Panadan,Pandan', 13.7421000, 123.0815000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106195, 'Pandan', 'Pandan', 'Pandan', 11.7195000, 122.0949000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106196, 'Pandan', 'Pandan', 'Padan,Pandan', 9.2388000, 124.7278000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106197, 'Pandacaqui', 'Pandacaqui', 'Pandacaqui,Pandakaki', 15.1719000, 120.6545700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106198, 'Pancol', 'Pancol', 'Pancol', 10.8715000, 119.4157000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106199, 'Pance', 'Pance', 'Pance', 15.6885000, 120.6201000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106200, 'Panaytayon', 'Panaytayon', 'Panaytayon', 9.9500000, 123.9833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106201, 'Panayacan', 'Panayacan', 'Panayacan,Panayakan', 11.7603000, 122.2236000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106202, 'Panay', 'Panay', 'Panay,Panay Town', 11.5577800, 122.7941700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106203, 'Pan-an', 'Pan-an', 'Pan-an,Pan-ay', 8.2191700, 123.8402800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106204, 'Panay', 'Panay', 'Panay', 6.4977800, 124.6383300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106205, 'Pananaw', 'Pananaw', 'Panamao,Panamaw,Pananaw,Sait Lake,Seit Lake,Siit', 5.9811100, 121.2147200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106206, 'Panan', 'Panan', 'Panan', 15.2134000, 120.0272000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106207, 'Panalo-on', 'Panalo-on', 'Panalo-on', 7.9166700, 123.7500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106208, 'Panalipan', 'Panalipan', 'Panalipan,Panalipon', 10.6483300, 124.0216700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106209, 'Panalingaan', 'Panalingaan', 'Panalingaan', 8.7841700, 117.4230600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106210, 'Panalanoy', 'Panalanoy', '', 11.2511100, 125.0063900, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106211, 'Panacan', 'Panacan', 'Panacan,Panakan', 9.2462700, 118.4082000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106212, 'Panabuan', 'Panabuan', 'Panabuan', 5.9616000, 120.9627000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106213, 'Panabo', 'Panabo', 'Kota Panabo,Panabo,Panabo City,Panabo Lakanbalen', 7.3080600, 125.6841700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106214, 'Panabingan', 'Panabingan', 'Panabingan', 15.3773200, 120.7649200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106215, 'Pamplona', 'Pamplona', 'Bidduang,Pamplona', 18.4663900, 121.3411100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106216, 'Pamplona', 'Pamplona', 'Pamplona', 13.5916000, 123.0816000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106217, 'Pamplona', 'Pamplona', 'Pamplona', 9.4724000, 123.1192000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106218, 'Pambujan', 'Pambujan', 'Pambuhan,Pambujan,Pambunan,Pamuhan', 12.5642000, 124.9276000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106219, 'Pambuhan', 'Pambuhan', 'Pambuhan,Panbuhan', 13.9736000, 123.0837000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106220, 'Pambisan', 'Pambisan', 'Pambisan', 13.0137000, 121.4128200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106221, 'Pamatawan', 'Pamatawan', 'Pamatawan', 14.9277900, 120.2136300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106222, 'Pamantingan', 'Pamantingan', 'Pamantingan', 6.7044400, 124.4588900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106223, 'Palusapis', 'Palusapis', 'Palusapig,Palusapis', 15.6832400, 120.8626700, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106224, 'Paluan', 'Paluan', 'Lipa,Paluan', 13.4160000, 120.4623000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106225, 'Palsong', 'Palsong', 'Palsong', 13.4248000, 123.2963000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106226, 'Palompon', 'Palompon', 'Palompan,Palompon', 11.0508000, 124.3843000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106227, 'Palomoc', 'Palomoc', 'Palomac,Palomoc,Palomok', 7.9153000, 122.5829000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106228, 'Palo', 'Palo', 'Palo,Polo', 11.1575000, 124.9908300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106229, 'Palma Gil', 'Palma Gil', 'Palma Gil', 7.6422200, 125.6291700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106230, 'Palkan', 'Palkan', 'Palkan', 6.2963900, 125.0316700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106231, 'Palimbang', 'Palimbang', 'Palimban,Palimbang', 6.2100200, 124.1888700, 'PH', '2016-08-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106232, 'Palian', 'Palian', 'Palian', 6.3738900, 124.9105600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106233, 'Palhi', 'Palhi', 'Palhi', 10.6498000, 124.8062000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106234, 'Palguyod', 'Palguyod', 'Palguyod,Palguyog,Palugyog', 16.1227000, 120.5200000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106235, 'Palestina', 'Palestina', 'Palestina', 13.6117000, 123.2490000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106236, 'Paldit', 'Paldit', '', 16.1666700, 120.5333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106237, 'Palayan City', 'Palayan City', 'Palayan,Palayan City', 15.5415000, 121.0848000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106238, 'Palauig', 'Palauig', 'Palauig', 15.4350000, 119.9045000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106239, 'Palaroo', 'Palaroo', 'Palarao,Palaraw,Palaroo', 11.4056000, 124.4830000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106240, 'Palapag', 'Palapag', 'Palapag', 12.5458000, 125.1147000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106241, 'Palanit', 'Palanit', 'Palanit', 12.3213400, 124.3434100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106242, 'Palangue', 'Palangue', 'Palangue,Palangui', 14.2841700, 120.8113900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106243, 'Palanas', 'Palanas', 'Palanas', 12.1458000, 123.9216000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106244, 'Palampas', 'Palampas', 'Palampas,Palanas,Paljampas', 10.5250600, 123.4208000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106245, 'Palali', 'Palali', 'Palale,Palali', 14.3062200, 122.4857100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106246, 'Palahanan Uno', 'Palahanan Uno', 'Palahanan I,Palahanan Primero,Palahanan Uno', 13.8311300, 121.3563900, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106247, 'Palagao Norte', 'Palagao Norte', 'Palagao,Palagao Norte', 18.0440600, 121.7187100, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106248, 'Palacpalac', 'Palacpalac', 'Palacpalac', 16.1312000, 120.5305000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106249, 'Pakil', 'Pakil', 'Pakil', 14.3835000, 121.4786000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106250, 'Pakiad', 'Pakiad', 'Kakiad,Pakiad,Pakiao', 10.7127800, 122.5241700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106251, 'Pajo', 'Pajo', 'Paho,Pajo', 11.2412100, 124.0106700, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106252, 'Paitan Este', 'Paitan Este', 'Paitan,Paitan Este,San Pedro Martir Paitan', 16.0853200, 120.0316400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106253, 'Paitan Norte', 'Paitan Norte', 'Paitan,Paitan Norte', 15.8333300, 120.7408600, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106254, 'Paitan', 'Paitan', 'Paitan', 6.6597200, 124.8713900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106255, 'Paiisa', 'Paiisa', 'Paiisa', 13.9262900, 121.3541500, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106256, 'Pagudpud', 'Pagudpud', 'Pagudpud,Pagupud', 18.5616000, 120.7868000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106257, 'Pagsanjan', 'Pagsanjan', 'Pagsanjan,Paxenheim', 14.2732000, 121.4552000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106258, 'Pagsanghan', 'Pagsanghan', 'Pagsanghan,Pagsanhan,Pagsanjan', 11.9657000, 124.7212000, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106259, 'Pagsañgahan', 'Pagsangahan', 'Pagsangahan,Pagsañgahan,Pasangahan', 13.2158300, 122.5430600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106260, 'Pagsanahan Norte', 'Pagsanahan Norte', 'Pagsana-an,Pagsanahan Norte,Pagsanahgn', 17.9193000, 120.4458000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106261, 'Pagsabangan', 'Pagsabangan', 'Pagsabangan', 7.4811100, 125.7494400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106262, 'Pagbilao', 'Pagbilao', 'Pagbilao', 13.9668900, 121.6983500, 'PH', '2015-01-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106263, 'Pagatin', 'Pagatin', 'Pagatin', 6.9730600, 124.4752800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106264, 'Pag-asa', 'Pag-asa', 'Pag-asa', 7.5755600, 125.6838900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106265, 'Pagangan', 'Pagangan', 'Pagangan', 7.1144400, 124.5952800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106266, 'Pagaluñgan', 'Pagalungan', 'Pagaluan,Pagalungan,Pagaluñgan', 7.1416700, 124.3805600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106267, 'Pagalungan', 'Pagalungan', 'Balumis,Balumis Pagalungan,Pagalungan,Pagatungan,Pikit Pagalungan', 7.0566700, 124.7008300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106268, 'Pagadian', 'Pagadian', 'Lungsod ng Pagad,PAG,Pagadian,Pagadian City', 7.8257000, 123.4370000, 'PH', '2013-08-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106269, 'Paete', 'Paete', 'Paete', 14.3647000, 121.4829000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106270, 'Padre Zamora', 'Padre Zamora', 'Padre Zamora', 10.0666700, 123.2500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106271, 'Padre Garcia', 'Padre Garcia', 'Lumang Bayan,Padre Garcia,Padre V. Garcia', 13.8791000, 121.2139000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106272, 'Padre Burgos', 'Padre Burgos', 'Burgos,Laguimanoc,Padre Burgos', 13.9226000, 121.8116300, 'PH', '2012-06-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106273, 'Padre Burgos', 'Padre Burgos', 'Padre Burgos', 10.0369400, 125.0191700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106274, 'Padong', 'Padong', 'Padong', 18.0543500, 120.7542700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106275, 'Paddaya', 'Paddaya', 'Padaya,Paddaya', 18.3127900, 121.7677000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106276, 'Padapada', 'Padapada', 'Padapada', 15.5517000, 120.5163000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106277, 'Padang', 'Padang', 'Padang', 13.2196000, 123.7655000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106278, 'Padada', 'Padada', '', 6.6411100, 125.3450000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106279, 'Paco Roman', 'Paco Roman', 'Paco Roman,Pacoroman', 15.6597000, 121.0877000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106280, 'Pacol', 'Pacol', '', 10.4500000, 122.8166700, 'PH', '2013-10-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106281, 'Paclolo', 'Paclolo', 'Paclolo', 12.3767500, 121.1735100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106282, 'Paatan', 'Paatan', 'Paalan,Paatan,Paatun', 7.1197200, 124.9238900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106283, 'Paagahan', 'Paagahan', 'Paagahan', 14.4447000, 121.4010000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106284, 'Ozamiz City', 'Ozamiz City', 'Ozamis,Ozamis City,Ozamiz,Ozamiz City', 8.1481000, 123.8405000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106285, 'Owak', 'Owak', 'Oac,Owak', 10.5500000, 123.7000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106286, 'Oton', 'Oton', 'Oton,Oton Town', 10.6930600, 122.4736100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106287, 'Utabi', 'Utabi', 'Otabe,Otavi,Utabe,Utabi,Utavi', 12.6417000, 123.9092000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106288, 'Osmeña', 'Osmena', 'Osmena,Osmeña', 12.7315000, 123.3318000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106289, 'Osmeña', 'Osmena', 'Osmena,Osmeña', 10.5208300, 119.9258300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106290, 'Oslob', 'Oslob', 'Oslob', 9.5211000, 123.4315000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106291, 'Osias', 'Osias', 'Osias', 7.6000000, 124.8166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106292, 'Osiao', 'Osiao', 'Osiao,San Pedro', 13.0914000, 123.9811000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106293, 'Oroquieta', 'Oroquieta', 'Kota Oroquieta,Oroguieta,Oroquieta,Oroquieta City,Oroquieta Lakanbalen,awrwkwyyta,olokieta,orokieta,اوروکوئیتا,オロキエタ,오로키에타', 8.4859000, 123.8048000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106294, 'Orong', 'Orong', 'Crong,Orang,Orong', 9.9373000, 122.8290000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106295, 'Ormoc', 'Ormoc', 'Ciudad ti Ormoc,Dakbayan sa Ormoc,Kota Ormoc,Lungsod ng Ormoc,MacArthur,OMC,Ormco,Ormoc,Ormoc City,Ormoc Lakanbalen,Oromoc,Syudad han Ormoc,awrmwk,oleumokeu,orumokku,اورموک,オルモック,오르모크', 11.0063900, 124.6075000, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106296, 'Orion', 'Orion', 'Orion,Орион', 14.6205600, 120.5816700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106297, 'Oras', 'Oras', 'Oras', 12.1406000, 125.4397000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106298, 'Orani', 'Orani', 'Orani', 14.8006000, 120.5371000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106299, 'Oracon', 'Oracon', 'Oracon', 10.4782000, 122.5839000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106300, 'Opol', 'Opol', 'Opal,Opol', 8.5213900, 124.5711100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106301, 'Ondoy', 'Ondoy', 'Omdoy,Ondoy', 11.8191700, 122.1261100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106302, 'Olutanga', 'Olutanga', 'Calida,Olutanga,Suba Nipa', 7.3105600, 122.8463900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106303, 'Olongapo', 'Olongapo', 'Bandaraya Olongapo,Ciudad ti Olongapo,Dakbayan sa Olongapo,Kota Olongapo,Lungsod ng Olongapo,Olongapo,Olongapo City,Olongapo Lakanbalen,Olóngapo,Siyudad na Olongapo,Siyudad na Olóngapo,Syodad nin Olongapo,ao long a bo,awlwngapw,ollong-gapo,اولونگاپو,奥隆阿波,올롱가포', 14.8291700, 120.2827800, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106304, 'Olingan', 'Olingan', 'Olingan', 8.5381000, 123.3216000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106305, 'Olea', 'Olea', 'Olea', 15.8623700, 120.4936600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106306, 'Okiot', 'Okiot', 'Okiot', 9.5666700, 123.1666700, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106307, 'Ogtongon', 'Ogtongon', 'Ogtongon,Udtongan', 10.7733400, 123.5200000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106308, 'Ogod', 'Ogod', 'Ogod', 12.9009000, 123.6170000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106309, 'Odiongan', 'Odiongan', 'Odiongan', 12.4016700, 121.9919400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106310, 'Odiongan', 'Odiongan', 'Odiongan', 8.8458300, 125.1663900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106311, 'Odiong', 'Odiong', 'Odiong', 12.5931000, 121.5032000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106312, 'Odiong', 'Odiong', 'Odiong', 11.5356000, 122.4666000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106313, 'Odiong', 'Odiong', 'Odiong', 10.2858000, 123.0526000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106314, 'Odicon', 'Odicon', 'Odicon', 13.5300000, 123.0588000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106315, 'Ocoy', 'Ocoy', 'Ocoy,Okoy', 11.1716000, 123.7948000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106316, 'Ochanado', 'Ochanado', 'Ochanado,Ochando', 11.6139000, 122.4833000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106317, 'Ocaña', 'Ocana', 'Ocana,Ocaña', 10.0656000, 123.6244000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106318, 'Ocampo', 'Ocampo', 'Ocampo', 13.5594000, 123.3761000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106319, 'Obong', 'Obong', 'Obong', 9.7410000, 123.5098000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106320, 'Obando', 'Obando', 'Obando', 14.7098000, 120.9362000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106321, 'Oaqui', 'Oaqui', 'Oaqui', 16.8583000, 120.4124000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106322, 'Numancia', 'Numancia', 'Numancia', 11.7059000, 122.3284000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106323, 'Noling', 'Noling', 'Noling,Nuling', 6.6598400, 124.0998100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106324, 'Nugas', 'Nugas', 'Nugas', 9.6968000, 123.4415000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106325, 'Nueva Vida Sur', 'Nueva Vida Sur', 'Nueva Vida,Nueva Vida Sur', 9.7846000, 124.1745000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106326, 'Nueva Valencia', 'Nueva Valencia', 'Igang,Nueva Valencia', 10.5107700, 122.5315000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106327, 'Nueva Fuerza', 'Nueva Fuerza', 'Nueva Fuerza', 9.8464000, 124.1670000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106328, 'Nueva Era', 'Nueva Era', 'Nueva Era', 17.9163000, 120.6641000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106329, 'Noveleta', 'Noveleta', '', 14.4292200, 120.8798900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106330, 'Novallas', 'Novallas', 'Novallas,Novallaso,Novollas', 9.5117000, 123.1225000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106331, 'Norzagaray', 'Norzagaray', 'Norzagaray,Norzugaray', 14.9109000, 121.0493000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106332, 'Norala', 'Norala', '', 6.5225000, 124.6591700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106333, 'Nuing', 'Nuing', 'Noing,Nuin,Nuing', 5.6327800, 125.4352800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106334, 'Niugan', 'Niugan', 'Niogan,Niugan', 14.9460700, 120.9672000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106335, 'Niugan', 'Niugan', 'Niogan,Niyugan', 14.6644400, 120.9552800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106336, 'Ninoy', 'Ninoy', 'Ninoy', 15.8596000, 120.2478000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106337, 'Nilombot', 'Nilombot', 'Nilombot,Nilombot Golden', 16.0306000, 120.4368500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106338, 'Nieves', 'Nieves', 'Nieves', 15.3284200, 120.9489200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106339, 'Nibaliw Central', 'Nibaliw Central', 'Nibalio,Nibaliw,Nibaliw Central', 16.1275000, 120.4027000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106340, 'New Washington', 'New Washington', 'New Washington,New Washington Town,Port Washington', 11.6508000, 122.4322000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106341, 'New Visayas', 'New Visayas', 'New Visayas', 7.5233300, 125.6233300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106342, 'New Sibonga', 'New Sibonga', 'New Sibonga', 7.5609000, 125.9298000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106343, 'New Panay', 'New Panay', 'New Panay', 6.7586100, 124.5891700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106344, 'New Panamao', 'New Panamao', 'New Panamao,Panglima Estimo', 5.9500000, 121.2000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106345, 'Lucena', 'Lucena', 'Lucena,New Lucena', 10.8794000, 122.5967000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106346, 'New Leyte', 'New Leyte', 'New Leyte', 7.5000000, 125.7500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106347, 'New Lagao', 'New Lagao', 'Lagao,New Lagao', 6.7027800, 124.6413900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106348, 'New Iloilo', 'New Iloilo', 'New Iloilo', 6.5477800, 124.7897200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106349, 'New Corella', 'New Corella', 'New Corella', 7.5866000, 125.8237000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106350, 'New Cebu', 'New Cebu', 'New Cebu', 7.0952800, 125.0336100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106351, 'New Bohol', 'New Bohol', 'New Bohol', 7.5233000, 125.8363000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106352, 'New Batu Batu', 'New Batu Batu', 'New Batu Batu', 5.0666700, 119.8833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106353, 'Bantacan', 'Bantacan', 'Bantacan,New Bataan', 7.6040000, 126.1298000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106354, 'New Agutaya', 'New Agutaya', 'New Agutaya', 10.5613900, 119.3077800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106355, 'Nenita', 'Nenita', 'Nenita', 12.4916700, 124.8044400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106356, 'Nena', 'Nena', 'Nena', 11.7658300, 125.4177800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106357, 'Navotas', 'Navotas', 'Lungsod ng Navotas', 14.6666700, 120.9500000, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106358, 'Navotas', 'Navotas', 'Nabotas,Navotas', 14.4167000, 121.2268000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106359, 'Navatat', 'Navatat', 'Navatat', 15.8497100, 120.3905400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106360, 'Naval', 'Naval', '', 11.5605600, 124.3975000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106361, 'Naujan', 'Naujan', 'Naujan,Nauján,Navjan', 13.3232800, 121.3028200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106362, 'Natalungan', 'Natalungan', 'Natalungan,Natulongan', 7.5316700, 125.0236100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106363, 'Natubleng', 'Natubleng', 'Natubleng', 16.6964700, 120.7805400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106364, 'Natonin', 'Natonin', 'Natonin', 17.1092500, 121.2761400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106365, 'Nato', 'Nato', 'Nato', 13.6105000, 123.5356000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106366, 'Nato', 'Nato', 'Nato', 10.1492000, 122.8619000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106367, 'Natividad', 'Natividad', 'Natividad', 16.0443000, 120.7987000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106368, 'Nattapian', 'Nattapian', 'Natapian,Natappian,Nattapian', 17.6753600, 121.7029600, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106369, 'Nasugbu', 'Nasugbu', 'Nasugbu', 14.0669400, 120.6318100, 'PH', '2015-04-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106370, 'Masonogan', 'Masonogan', 'Masonogan,Nasonogan,Nasonugan,Nasunogan', 11.3686000, 122.6753000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106371, 'Nasipit', 'Nasipit', 'Nasapit,Nasipit', 8.9691700, 125.2947200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106372, 'Narvacan', 'Narvacan', 'Narvacan', 17.4175000, 120.4753000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106373, 'Narra', 'Narra', 'Narra', 9.2687700, 118.4043000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106374, 'Naro', 'Naro', 'Naro,Naro Island', 11.8969700, 123.6739200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106375, 'Marawis', 'Marawis', 'Marawis,Narauis,Narawis', 10.2453000, 122.8869000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106376, 'Napuro', 'Napuro', 'Napuro', 12.0273000, 124.7082000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106377, 'Napoles', 'Napoles', 'Napoles', 10.5040000, 122.8979000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106378, 'Napnapan', 'Napnapan', 'Napnapan', 10.7084500, 122.3930000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106379, 'Napalitan', 'Napalitan', 'Napaliran,Napalitan', 8.7752800, 124.8022200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106380, 'Nanyo', 'Nanyo', 'Nanyo', 7.3330600, 125.6377800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106381, 'Nangka', 'Nangka', 'Nanca,Nangka,Nanka', 10.8556400, 123.0359000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106382, 'Nangka', 'Nangka', 'Nangka', 10.5500000, 123.9666700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106383, 'Nangka', 'Nangka', 'Nangka', 10.5324000, 123.7195000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106384, 'Nañgka', 'Nangka', '', 8.1666700, 124.1833300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106385, 'Nangka', 'Nangka', 'Nangca,Nangka', 9.4023000, 122.8244000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106386, 'Nangan', 'Nangan', 'Nangan', 6.4726400, 126.1243800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106387, 'Nangalisan', 'Nangalisan', 'Nagalisan,Nangalisan', 16.4344000, 120.4778000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106388, 'Nancamarinan', 'Nancamarinan', 'Nancamarian,Nancamarinan', 15.6752000, 120.5364000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106389, 'Nancalobasaan', 'Nancalobasaan', 'Nancalabasaan,Nancalobasaan', 15.9342000, 120.8426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106390, 'Namuac', 'Namuac', 'Namuac', 18.6109000, 121.1657000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106391, 'Nampicuan', 'Nampicuan', 'Nampicuan', 15.7314000, 120.6250000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106392, 'Namboongan', 'Namboongan', 'Namboongan', 16.3033000, 120.3758000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106393, 'Nambalan', 'Nambalan', 'Nambalan', 15.5991100, 120.4603100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106394, 'Nama', 'Nama', 'Nama', 16.1412000, 120.5426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106395, 'Nalus', 'Nalus', 'Nalus', 6.0122200, 124.5852800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106396, 'Nalundan', 'Nalundan', 'Nalundan', 9.7500000, 123.0666700, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106397, 'Nalsian Norte', 'Nalsian Norte', 'Nalsian,Nalsian Norte', 15.8447600, 120.4508400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106398, 'Brgy. Nalook, kalibo', 'Brgy. Nalook, kalibo', '', 11.6858600, 122.3691600, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106399, 'Naisud', 'Naisud', 'Naisud,Naisud Town', 11.8058000, 122.1939000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106400, 'Nailong', 'Nailong', 'Nailon,Nailong', 11.0537000, 124.0385000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106401, 'Naili', 'Naili', 'Cassia,Naile,Naili', 11.7666000, 122.1765000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106402, 'Naic', 'Naic', '', 14.3181200, 120.7660900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106403, 'Nahawan', 'Nahawan', 'Nahauan,Nahawan', 9.9711000, 124.0484000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106404, 'Naguilian', 'Naguilian', 'Naguihan,Naguilan,Naguilian,Naguillian', 17.0231500, 121.8370400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106405, 'Naguilian', 'Naguilian', 'Naguilian', 16.5338900, 120.3966700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106406, 'Naguilayan', 'Naguilayan', 'Naguilaryan,Naguilayan', 16.0030400, 120.2910800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106407, 'Naguelguel', 'Naguelguel', 'Naguelguel', 16.0058500, 120.2635100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106408, 'Nagtipunan', 'Nagtipunan', 'Nagtipunan', 16.2166700, 121.6000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106409, 'Nagsaing', 'Nagsaing', 'Nagsaing', 15.9806900, 120.3378700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106410, 'Nagrumbuan', 'Nagrumbuan', 'Nagrumboan,Nagrumbuan', 16.8995500, 121.7097400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106411, 'Nagpandayan', 'Nagpandayan', 'Nagpandayan', 15.6013800, 120.7689300, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106412, 'Nagiba', 'Nagiba', 'Nag-iba II,Nag-iba Segundo,Nagiba,Naguiba', 13.3301800, 121.2743200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106413, 'Naghalin', 'Naghalin', 'Naghalen,Naghalin', 11.1456000, 124.5671000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106414, 'Nagcarlan', 'Nagcarlan', 'Nagcarlan', 14.1364000, 121.4165000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106415, 'Nagbukel', 'Nagbukel', 'Nagbukel,Nagbuquel', 17.4471000, 120.5247000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106416, 'Nagbalaye', 'Nagbalaye', 'Nagbalaye,Nagbalayo', 9.2492000, 122.8759000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106417, 'Nagbacalan', 'Nagbacalan', 'Nagbacalan,Nagbakalan', 18.1159000, 120.5235000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106418, 'Naagas', 'Naagas', 'Naagas,Nagas', 13.4357000, 123.6781000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106419, 'Naga', 'Naga', 'Ciudad nin Naga,Dakbayan sa Naga,Kota Naga,Lungsod ng Naga,Maogmang Naga,Naga City,Naga Lakanbalen,Nagi,Syudad nin Naga,WNP,naga,naga  kamarynz jnwby,Наги,ناگا، کامارینز جنوبی,ナガ,나가', 13.6191700, 123.1813900, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106420, 'Naga', 'Naga', 'City of Naga,Kota Naga,Lungsod ng Naga,Naga,Naga City,naga  sybw,ناگا، سیبو', 10.2089800, 123.7580000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106421, 'Naga', 'Naga', '', 7.7702800, 122.7508300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106422, 'Nabunturan', 'Nabunturan', 'nabwntwran  wady kwmpwstyla,نابونتوران، وادی کومپوستیلا', 7.6077800, 125.9663900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106423, 'Nabulao', 'Nabulao', 'Jabulao,Nabulao', 9.6616000, 122.4577000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106424, 'Nabannagan West', 'Nabannagan West', 'Nabannagan,Nabannagan West,Nabuangan', 18.0715600, 121.5363000, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106425, 'Nabua', 'Nabua', 'Nabua', 13.4075000, 123.3724000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106426, 'Nabas', 'Nabas', 'Nabas,Nabas Town,Navas', 11.8310000, 122.0870000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106427, 'Nabangig', 'Nabangig', 'Nabangig,Napangig', 12.0989000, 123.9503000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106428, 'Naawan', 'Naawan', 'Naauan,Naawan', 8.4344400, 124.2888900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106429, 'Muti', 'Muti', '', 7.2758300, 122.2800000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106430, 'Muricay', 'Muricay', 'Muricay', 7.8275000, 123.4782000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106431, 'Murcia', 'Murcia', 'Murcia', 15.4042500, 120.6090300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106432, 'Murcia', 'Murcia', 'Murcia', 10.6051600, 123.0417000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106433, 'Muñoz East', 'Munoz East', 'Munoz,Munoz East,Muñoz,Muñoz East', 17.1575400, 121.6135400, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106434, 'Muñoz', 'Munoz', '', 15.7161100, 120.9030600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106435, 'Mungo', 'Mungo', 'Mongo,Mungo', 17.7241200, 121.4709600, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106436, 'Munai', 'Munai', 'Manay,Munai,Munay', 7.9758300, 124.0636100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106437, 'Mulauin', 'Mulauin', 'Mulauin,Mulawin', 13.8666700, 121.0166700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106438, 'Mulanay', 'Mulanay', 'Mulanay', 13.5222200, 122.4041700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106439, 'Muladbucad', 'Muladbucad', 'Muladbucad,Muladbukad', 13.2389000, 123.6057000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106440, 'Mozzozzin Sur', 'Mozzozzin Sur', 'Mozzozin,Mozzozzin,Mozzozzin Sur', 17.4568500, 121.7460700, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106441, 'Mozon', 'Mozon', 'Mozon,Muzon', 13.8526000, 120.9893500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106442, 'Motiong', 'Motiong', 'Motiong', 11.7800000, 124.9997200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106443, 'Morong', 'Morong', 'Moron,Morong,Моронг', 14.6788900, 120.2661100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106444, 'Morong', 'Morong', 'Morong,Моронг', 14.5184900, 121.2377800, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106445, 'Morobuan', 'Morobuan', 'Morobuan,Morubuan', 10.6256600, 122.5547000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106446, 'Moriones', 'Moriones', 'Mariones,Moriones', 15.4611600, 120.4657900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106447, 'Morales', 'Morales', 'Morales', 11.5456000, 122.3764000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106448, 'Moog', 'Moog', 'Moog', 8.6011100, 124.4658300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106449, 'Montilla', 'Montilla', 'Montilla', 10.2027000, 122.9261000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106450, 'Montevista', 'Montevista', '', 7.6933300, 125.9888900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106451, 'Montecillo', 'Montecillo', 'Montecillo,Monticello', 13.8906700, 121.4757500, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106452, 'Montaneza', 'Montaneza', 'Mantayosa,Montaneza', 9.6846000, 123.3289000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106453, 'Rodriguez', 'Rodriguez', 'Montalban,Rodriges,Rodriguez,Rodríguez,luo de li ge si,Родригес,罗德里格斯', 14.7601100, 121.1999300, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106454, 'Monreal', 'Monreal', 'Monreal', 12.6440000, 123.6648000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106455, 'Monpon', 'Monpon', 'Mongpong,Monpon', 10.9119400, 122.6377800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106456, 'Monkayo', 'Monkayo', 'Moncayo,Monkayo', 7.8152800, 126.0544400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106457, 'Mondragon', 'Mondragon', 'Mondragon', 12.5157000, 124.7523000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106458, 'Moncada', 'Moncada', 'Mancada,Moncada', 15.7354000, 120.5740000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106459, 'Monbon', 'Monbon', 'Monbon', 12.7307000, 124.0189000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106460, 'Monamon', 'Monamon', 'Monamon', 16.8833000, 120.8833000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106461, 'Molugan', 'Molugan', 'Malugan,Molugan', 8.5375000, 124.5622200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106462, 'Molave', 'Molave', 'Molave', 8.0844000, 123.4910000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106463, 'Moises Padilla', 'Moises Padilla', 'Moises Padilla', 10.2702800, 123.0780600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106464, 'Mogpog', 'Mogpog', 'Mogpog,Mopog', 13.4744400, 121.8613900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106465, 'Mobo', 'Mobo', 'Mobo', 12.3363000, 123.6574000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106466, 'Moalboal', 'Moalboal', 'Moalboal', 9.9433300, 123.3991700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106467, 'Miranda', 'Miranda', 'Miranda', 10.3047000, 122.8778000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106468, 'Minuyan', 'Minuyan', 'Minoyan,Minuyan', 10.5136600, 123.1049000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106469, 'Minuri', 'Minuri', 'Minuri', 16.5323300, 121.8553200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106470, 'Minolos', 'Minolos', 'Minilos,Minolos', 10.1019000, 123.4727000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106471, 'Minlagas', 'Minlagas', 'Minlagas,San Luis', 8.8783300, 125.0388900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106472, 'Minien East', 'Minien East', 'Menien,Minien,Minien East,Minien Este', 15.9772300, 120.4812700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106473, 'Minglanilla', 'Minglanilla', 'Minglanilla', 10.2449800, 123.7964000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106474, 'Mindupok', 'Mindupok', 'Mindupok', 6.0905600, 124.4233300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106475, 'Minapasoc', 'Minapasoc', 'Minapasoc,Minapasuk', 10.6988500, 123.3490000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106476, 'Minapan', 'Minapan', 'Minapan', 6.8150000, 124.8586100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106477, 'Minante Segundo', 'Minante Segundo', 'Minante,Minante II,Minante Segundo,Ninante', 16.9022000, 121.7619100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106478, 'Minanga Norte', 'Minanga Norte', 'Minanga,Minanga Norte', 17.4523300, 121.7853300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106479, 'Minanga Norte', 'Minanga Norte', 'Minanga,Minanga Norte', 17.7604000, 121.7294400, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106480, 'Minallo', 'Minallo', 'Minallo', 16.9868500, 121.8539400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106481, 'Minalin', 'Minalin', 'Minalin', 14.9676000, 120.6828000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106482, 'Minalabac', 'Minalabac', 'Minalabac', 13.5687000, 123.1838000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106483, 'Mina', 'Mina', 'Mina,Minal', 10.9313000, 122.5745000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106484, 'Mileb', 'Mileb', 'Mileb,Miteb', 6.8986100, 124.5838900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106485, 'Milaor', 'Milaor', 'Milaor,Santo Domingo', 13.5961000, 123.1772000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106486, 'Milagros', 'Milagros', 'Milagros', 12.2181400, 123.5095100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106487, 'Midsayap', 'Midsayap', '', 7.1908300, 124.5302800, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106488, 'Midsalip', 'Midsalip', 'Midsalip', 8.0000000, 123.2666700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106489, 'Miaray', 'Miaray', 'Miaray', 7.5747200, 125.0444400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106490, 'Mianay', 'Mianay', 'Mainay,Mianay', 11.4716000, 122.7011000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106491, 'Miagao', 'Miagao', 'Miag-ao,Miagao,Miagao Town', 10.6442000, 122.2352000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106492, 'Miaga', 'Miaga', 'Miaga', 12.2376000, 123.8167000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106493, 'Meycauayan', 'Meycauayan', 'Kota Meycauayan,Meycauayan,Meycauayan City,Meycawayan,myykawayan,میئکاوایان', 14.7369400, 120.9608300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106494, 'Mexico', 'Mexico', 'Mexico,México', 15.0646000, 120.7198000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106495, 'Merida', 'Merida', 'Meriba,Merida', 10.9098000, 124.5376000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106496, 'Mercedes', 'Mercedes', 'Mercedes,Meredes', 14.1093000, 123.0109000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106497, 'Mercedes', 'Mercedes', 'Mercedes', 10.6686000, 124.4021000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106498, 'Mercedes', 'Mercedes', 'Las Mercedes', 6.9586100, 122.1483300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106499, 'Mendez-Nuñez', 'Mendez-Nunez', 'Mendez,Mendez-Nunez,Mendez-Nuñez', 14.1286100, 120.9058300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106500, 'Medina', 'Medina', 'Medina', 8.9122200, 125.0244400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106501, 'Medellin', 'Medellin', 'Medelin,Medellin', 11.1286000, 123.9622000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106502, 'McKinley', 'McKinley', 'McKinley', 10.0844000, 123.2592000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106503, 'Maypangdan', 'Maypangdan', 'Maypandan,Maypangdan', 11.6519400, 125.4502800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106504, 'Mayorga', 'Mayorga', 'Mayorga,Mayorgac', 10.9000000, 125.0000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106505, 'Mayo', 'Mayo', 'Mayo', 7.0021100, 126.3319800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106506, 'Mayngaran', 'Mayngaran', 'Mayngaran', 12.3492000, 123.5996000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106507, 'Maygatasan', 'Maygatasan', 'Maigatasan,Maygatasan', 8.7094400, 125.7183300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106508, 'Maydolong', 'Maydolong', 'Maydolong', 11.5002100, 125.4981100, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106509, 'Mayapusi', 'Mayapusi', 'Mayaposi,Mayapusi', 9.6241000, 123.0188000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106510, 'Mayantoc', 'Mayantoc', 'Mayantoc', 15.6199000, 120.3770000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106511, 'Mayana', 'Mayana', 'Mayama,Mayana', 9.7561100, 124.3522200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106512, 'Mayabon', 'Mayabon', 'Mayabon', 9.0961000, 123.1738000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106513, 'Maya', 'Maya', 'Maya', 11.2744200, 124.0552600, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106514, 'Maxingal', 'Maxingal', 'Maxingal,Maxingul', 18.2148800, 121.6681500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106515, 'Mawab', 'Mawab', 'Mauav,Mawab', 7.5666700, 125.9833300, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106516, 'Mauraro', 'Mauraro', 'Mauraro', 13.1494000, 123.5953000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106517, 'Maulawin', 'Maulawin', '', 14.2666700, 121.4333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106518, 'Mauhao', 'Mauhao', 'Mauhao,Maujao', 12.2901500, 121.3007100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106519, 'Maugat West', 'Maugat West', 'Maugat,Maugat West', 13.8613000, 121.2827600, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106520, 'Mauban', 'Mauban', 'Mauban', 14.1910000, 121.7309000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106521, 'Maturanoc', 'Maturanoc', 'Maturanoc', 15.6571000, 120.7921000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106522, 'Matungao', 'Matungao', 'Matungao', 8.1361100, 124.1641700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106523, 'Matti', 'Matti', 'Matti', 6.7705600, 125.3086100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106524, 'Matnog', 'Matnog', 'Matnog', 14.0666700, 122.9333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106525, 'Matnog', 'Matnog', 'Matnog', 12.5878000, 124.0875000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106526, 'Matlang', 'Matlang', 'Matlang', 10.8902000, 124.4554000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106527, 'Matiompong', 'Matiompong', 'Matiompong', 6.6961100, 124.5661100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106528, 'Matingain', 'Matingain', 'Matingain', 13.9129000, 120.8800600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106529, 'Matinao', 'Matinao', 'Malinao,Matinao,Mulinao', 7.5916700, 124.6888900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106530, 'Maticmatic', 'Maticmatic', 'Maticmatic', 15.9863000, 120.4519200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106531, 'Matiao', 'Matiao', 'Matiao', 7.0828000, 125.9362000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106532, 'Mati', 'Mati', 'Mati', 9.7358000, 125.4680000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106533, 'Mat-i', 'Mat-i', 'Mat-i', 8.4019400, 124.3452800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106534, 'Mati', 'Mati', 'Kota Mati,MXI,Mati,Mati City,ma di,maty  dawayw shrqy,Мати,ماتی، داوائو شرقی,馬蒂', 6.9550800, 126.2165500, 'PH', '2013-06-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106535, 'Mataywanac', 'Mataywanac', 'Matayuanac,Mataywanac', 14.0311000, 120.7296000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106536, 'Matayumtayum', 'Matayumtayum', 'Matayumtayum', 15.5166000, 120.7098000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106537, 'Matanog', 'Matanog', 'Langkong,Matanog', 7.5161100, 124.2563900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106538, 'Matangad', 'Matangad', 'Matangad', 8.5769400, 124.3700000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106539, 'Matanao', 'Matanao', 'Matanao,Matinao', 6.6791700, 125.2550000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106540, 'Matalom', 'Matalom', 'Matalom', 10.2830600, 124.7877800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106541, 'Matalam', 'Matalam', 'Matalam,Matalan', 7.0863900, 124.9005600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106542, 'Matala', 'Matala', 'Matala', 13.8287000, 121.1549000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106543, 'Matagbak', 'Matagbak', 'Matagbak', 14.1305600, 120.8347200, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106544, 'Matacon', 'Matacon', 'Matacon,Matacos', 13.3284000, 123.4356000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106545, 'Matabao', 'Matabao', 'Matabao', 8.9572200, 125.3994400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106546, 'Mataas Na Kahoy', 'Mataas Na Kahoy', 'Mataas Na Kahoy,Mataasnacahoy', 13.9589000, 121.1138000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106547, 'Masoli', 'Masoli', 'Masoli,Masuli', 13.3593000, 123.3898000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106548, 'Maslog', 'Maslog', 'Maslog', 13.1046000, 123.7713000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106549, 'Maslog', 'Maslog', '', 12.1500000, 125.2333300, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106550, 'Masiu', 'Masiu', 'Masiu', 7.8116700, 124.3175000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106551, 'Masipi West', 'Masipi West', 'Masipi,Masipi West', 17.3793300, 121.8386100, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106552, 'Masinloc', 'Masinloc', 'Masinloc', 15.5363000, 119.9502000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106553, 'Masiga', 'Masiga', 'Masiga', 13.3607000, 121.8278000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106554, 'Masbate', 'Masbate', 'MBT', 12.3716900, 123.6249400, 'PH', '2013-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106555, 'Masaya Sur', 'Masaya Sur', 'Masaya Sur,Massaya Sur', 16.5001700, 121.7474300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106556, 'Masaya', 'Masaya', 'Masaya', 14.1518900, 121.2819000, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106557, 'Masarayao', 'Masarayao', 'Masarayas', 11.0897200, 124.6175000, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106558, 'Masaraway', 'Masaraway', 'Masarauag,Masarawag,Masaraway', 13.2268000, 123.6148000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106559, 'Masapang', 'Masapang', 'Masapang', 14.1971000, 121.3423000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106560, 'Masantol', 'Masantol', 'Masantol', 14.8960000, 120.7092000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106561, 'Masalukot Uno', 'Masalukot Uno', 'Masalukot,Masalukot I,Masalukot Uno', 13.9553300, 121.4188700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106562, 'Masalipit', 'Masalipit', 'Mansalipit,Masalipit', 15.1481000, 121.0373000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106563, 'Masaling', 'Masaling', 'Masaling', 9.9818000, 122.5369000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106564, 'Masaguisi', 'Masaguisi', 'Masaguisi', 12.7545200, 121.4484100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106565, 'Masaba', 'Masaba', 'Masaba', 10.5333300, 123.9666700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106566, 'Marupit', 'Marupit', 'Marupit', 13.6269000, 123.1663000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106567, 'Marogong', 'Marogong', 'Marogong', 7.6666700, 124.1500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106568, 'Mariveles', 'Mariveles', 'Mariveles', 14.4338500, 120.4856900, 'PH', '2014-11-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106569, 'Miliroc', 'Miliroc', 'Mariroc,Miliroc', 13.3449000, 123.7020000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106570, 'Maripipi', 'Maripipi', 'Maripipi', 11.7791700, 124.3491700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106571, 'Marintoc', 'Marintoc', 'Marintoc', 12.2855400, 123.7228100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106572, 'Marilao', 'Marilao', 'Marilao,Марилао', 14.7577800, 120.9483300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106573, 'Marihatag', 'Marihatag', 'Marihatag', 8.8059000, 126.2966000, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106574, 'Maricalom', 'Maricalom', 'Maricalom', 9.7049000, 122.4188000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106575, 'Maricaban', 'Maricaban', 'Maricaban', 11.1516000, 123.7679000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106576, 'Maribong', 'Maribong', 'Maribong', 11.1000000, 122.5333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106577, 'Maribojoc', 'Maribojoc', 'Maribojoc', 9.7417000, 123.8446000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106578, 'Mariano Marcos', 'Mariano Marcos', 'Mariano Marcos', 6.7333300, 124.6666700, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106579, 'Mariano', 'Mariano', 'Mariano', 8.8333300, 125.1166700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106580, 'Maria Cristina', 'Maria Cristina', '', 8.1660400, 124.2039600, 'PH', '2015-04-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106581, 'Maria Aurora', 'Maria Aurora', 'Maria Aurora,San Jose', 15.7967000, 121.4737000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106582, 'Maria', 'Maria', 'Maria', 9.1983000, 123.6544000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106583, 'Margosatubig', 'Margosatubig', 'Fort Margosatubig,Margosatubig', 7.5777000, 123.1658000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106584, 'Margen', 'Margen', 'Marhen', 11.0172200, 124.5283300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106585, 'Marcos', 'Marcos', 'Biding,Marcos', 18.0520000, 120.6898000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106586, 'Marbel', 'Marbel', 'Marbel', 7.1158300, 124.9125000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106587, 'Marawi City', 'Marawi City', 'City of Dansalan,Dansalan,Dansalan City,Islamic City of Marawi,Maraur,Marawi,Marawi City', 8.0034000, 124.2839500, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106588, 'Marawa', 'Marawa', 'Marawa', 15.4172700, 120.8381900, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106589, 'Maravilla', 'Maravilla', 'Maravilla', 10.9011000, 123.8918000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106590, 'Marao', 'Marao', 'Marao', 13.9143400, 121.8240900, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106591, 'Marantao', 'Marantao', 'Marantao', 7.9500000, 124.2333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106592, 'Maramag', 'Maramag', 'Maramag,XMA', 7.7633300, 125.0052800, 'PH', '2017-04-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106593, 'Maragondon', 'Maragondon', 'Maragandon,Maragondon', 14.2733000, 120.7377000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106594, 'Makiwalo', 'Makiwalo', 'Makiwalo,Maquinalo,Maquiualo', 12.5101000, 124.7060000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106595, 'Maquiling', 'Maquiling', 'Maguiling,Makiling,Maquiling', 10.7809400, 123.3938000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106596, 'Maquiapo', 'Maquiapo', 'Maquiapo', 14.9856100, 120.5585500, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106597, 'Maputi', 'Maputi', 'Maputi', 8.4497200, 124.2905600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106598, 'Mapulot', 'Mapulot', 'Mapulot', 14.0330000, 122.5399000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106599, 'Mapulo', 'Mapulo', 'Mapulo', 13.7317000, 121.1842000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106600, 'Mapolopolo', 'Mapolopolo', 'Mapolo Polo,Mapolopolo', 15.8808700, 120.3742200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106601, 'Mapili', 'Mapili', 'Mapili', 11.1081000, 122.7393000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106602, 'Mapaniqui', 'Mapaniqui', 'Mapaniqui', 15.1069600, 120.9228700, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106603, 'Mapandan', 'Mapandan', 'Mapandan', 16.0248000, 120.4547000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106604, 'Mapanas', 'Mapanas', 'Mapanas', 12.4750200, 125.2562100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106605, 'Mapalad', 'Mapalad', 'Mapalad', 15.4513300, 121.0838400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106606, 'Mapalacsiao', 'Mapalacsiao', 'Mapalacsiao,Mapaloxia', 15.4283100, 120.6525200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106607, 'Maonon', 'Maonon', 'Bonon,Maonon', 13.0364300, 123.3707400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106608, 'Manup', 'Manup', 'Manup', 11.5315000, 122.4980000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106609, 'Manuk Mangkaw', 'Manuk Mangkaw', 'Lokdatan,Luuk Datan,Manuk Mangaw,Manuk Mangkaw', 4.8000000, 119.8500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106610, 'Manukan', 'Manukan', '', 8.5333300, 123.1000000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106611, 'Manuel Roxas', 'Manuel Roxas', 'Manuel Roxas', 6.4452800, 124.6666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106612, 'Manubul', 'Manubul', 'Manubal,Manubul', 5.4732000, 120.7986000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106613, 'Manuangan', 'Manuangan', 'Manuangan', 7.2769400, 124.4044400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106614, 'Mantiquil', 'Mantiquil', 'Mantiquil', 9.1666700, 123.0500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106615, 'Manticao', 'Manticao', 'Manticao,Mantikao,Mantikaw,Mantikow', 8.4041700, 124.2866700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106616, 'Mantang', 'Mantang', 'Mantang', 11.8700000, 125.4283300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106617, 'Mantampay', 'Mantampay', '', 8.1666700, 124.2166700, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106618, 'Mantalongon', 'Mantalongon', 'Mantalongon', 10.1260000, 123.5808000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106619, 'Mantalongon', 'Mantalongon', 'Manta Longan,Mantalongon', 9.8106000, 123.4617000, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106620, 'Mansilingan', 'Mansilingan', '', 10.6311100, 122.9788900, 'PH', '2013-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106621, 'Mansalay', 'Mansalay', 'Bulalacao,Mansalay', 12.5204400, 121.4385100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106622, 'Manolo Fortich', 'Manolo Fortich', 'Maluko,Manolo Fortich', 8.3697200, 124.8644400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106623, 'Manoc-Manoc', 'Manoc-Manoc', 'Manocmanoc,Manok-Manok,Манок-Манок', 11.9415700, 121.9428100, 'PH', '2011-10-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106624, 'Maño', 'Mano', 'Mano,Maño', 11.0416700, 123.9447200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106625, 'Manlucahoc', 'Manlucahoc', 'Manlocahoc,Manlucahoc', 9.7399000, 122.4980000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106626, 'Malilinao', 'Malilinao', 'Manlilinac,Manlilinao', 11.1069400, 124.5011100, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106627, 'Manito', 'Manito', 'Manito', 13.1235000, 123.8693000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106628, 'Maninihon', 'Maninihon', 'Maninihon', 9.3711000, 122.8405000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106629, 'Manila', 'Manila', 'City of Manila,Dakbayan sa Manila,Gorad Manila,Lungsod ng Maynila,MNL,Mainile,Manila,Manilae,Manilla,Manillah,Manille,Manilo,Manyl,Maníla,Maynila,Menila,ma ni la,manila,manilla,manira,manyl,manyla,mnila,mnylh,myanila,Μανίλα,Горад Маніла,Манилæ,Манила,Маніла,מנילה,مانىلا,مانيلا,مانیل,مانیلا,मनिला,मनीला,ম্যানিলা,மணிலா,ಮನಿಲ,මැනිලා,มนิลา,มะนิลา,མ་ནི་ལ།,မနီလာမြို့,მანილა,ማኒላ,マニラ,马尼拉,마닐라', 14.6042000, 120.9822000, 'PH', '2016-04-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106630, 'Manikling', 'Manikling', 'Manikling', 6.8790700, 126.0606300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106631, 'Manika', 'Manika', 'Manika', 11.3880100, 122.2793100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106632, 'Manicahan', 'Manicahan', 'Manicaan,Manicahan', 7.0194400, 122.2011100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106633, 'Manibaug Pasig', 'Manibaug Pasig', 'Manibaug,Manibaug Pasig', 15.0962100, 120.5644500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106634, 'Manjoy', 'Manjoy', 'Manhoy,Manjoy', 11.3534000, 122.6663000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106635, 'Manquiring', 'Manquiring', 'Manguirin,Manguiring,Manquiring', 13.7341000, 123.2690000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106636, 'Mangoso', 'Mangoso', 'Mangoso', 11.4175000, 122.6382000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106637, 'Mangili', 'Mangili', 'Luayon,Mangile,Mangili', 6.0033300, 125.6838900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106638, 'Mangero', 'Mangero', 'Alonjiro,Mangero', 13.2705000, 122.6774000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106639, 'Mangatarem', 'Mangatarem', 'Mangatarem', 15.7874000, 120.2921000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106640, 'Mangas', 'Mangas', 'Mangas', 14.1176900, 120.8666100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106641, 'Mangarine', 'Mangarine', 'Mangaran,Mangarin,Mangarine', 12.3511500, 121.0980100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106642, 'Mangaldan', 'Mangaldan', 'Mangaldan', 16.0700000, 120.4025000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106643, 'Manaloal', 'Manaloal', 'Manaloal,Mangalcal', 7.3661100, 125.6602800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106644, 'Manggahan', 'Manggahan', 'Mangahan,Manggahan', 14.2919600, 120.9014500, 'PH', '2013-11-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106645, 'Manga', 'Manga', 'Manga,Mangga', 17.7012300, 121.8604800, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106646, 'Mangga', 'Mangga', 'Manga,Mangga', 15.2504100, 120.9087600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106647, 'Manga', 'Manga', 'Manga', 13.2719000, 123.4623000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106648, 'Manga', 'Manga', 'Manga', 6.2908300, 125.3083300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106649, 'Mandili', 'Mandili', 'Mandili', 15.1791200, 120.8772600, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106650, 'Mandih', 'Mandih', 'Mandih', 8.2087000, 123.0141000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106651, 'Mandaue City', 'Mandaue City', 'Dakbayan sa Mandaue,Lungsod ng Mandaue', 10.3236100, 123.9222200, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106652, 'Mandaon', 'Mandaon', 'Mandaon', 12.2259400, 123.2842100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106653, 'Mandangoa', 'Mandangoa', 'Mandangoa', 8.7727800, 124.7911100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106654, 'Mandaluyong City', 'Mandaluyong City', 'Mandaluyong,Mandayulong,San Felipe,San Felipe Neri', 14.5832000, 121.0409000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106655, 'Mancilang', 'Mancilang', 'Mancilang,Mansilang', 11.2835000, 123.7462000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106656, 'Mankayan', 'Mankayan', 'Mancayan,Mankayan', 16.8632000, 120.7829000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106657, 'Manay', 'Manay', 'Manay', 7.3416700, 125.5750000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106658, 'Manay', 'Manay', 'Manay', 7.2150000, 126.5397200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106659, 'Manaulanan', 'Manaulanan', 'Manaulanan', 7.0480600, 124.6194400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106660, 'Manaul', 'Manaul', 'Manaul', 12.4530000, 121.4107000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106661, 'Manatal', 'Manatal', 'Manatal', 14.8768800, 120.9163900, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106662, 'Manat', 'Manat', 'Manat', 7.5637000, 126.0184000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106663, 'Manat', 'Manat', 'Mainit,Manat', 7.5327000, 126.0173000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106664, 'Manaring', 'Manaring', 'Manaring', 17.1729400, 121.9025400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106665, 'Manapla', 'Manapla', 'Manapala,Manapla', 10.9580300, 123.1230000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106666, 'Manapa', 'Manapa', 'Manapa', 8.9777800, 125.4394400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106667, 'Manaoag', 'Manaoag', 'Manaoag', 16.0438000, 120.4861000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106668, 'Mananum', 'Mananum', 'Mananum', 8.8333300, 124.9500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106669, 'Manamrag', 'Manamrag', 'Manambrag,Manamrag', 13.7351000, 124.1064000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106670, 'Manalongon', 'Manalongon', 'Manalongan,Manalongon', 9.2209000, 122.8860000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106671, 'Manalad', 'Manalad', 'Manalad', 10.0056000, 122.7769000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106672, 'Manogpi', 'Manogpi', 'Managpi,Manogpi', 13.3108000, 121.2040000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106673, 'Managok', 'Managok', 'Managok', 8.0288900, 125.1886100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106674, 'Managa', 'Managa', 'Managa', 6.7461100, 125.2680600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106675, 'Manacsac', 'Manacsac', 'Manacsac', 15.5952000, 120.7911000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106676, 'Manabo', 'Manabo', 'Manabo', 17.4332000, 120.7053000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106677, 'Mamonit', 'Mamonit', 'Mamonit,Mamunit', 15.5871900, 120.3964400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106678, 'Mampurog', 'Mampurog', 'Mampurog,Manpurog', 14.0458000, 122.8836000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106679, 'Mambusao', 'Mambusao', 'Mambusao', 11.4335500, 122.5982000, 'PH', '2015-04-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106680, 'Mamburao', 'Mamburao', 'MBO,Mambulao,Mamburao', 13.2233000, 120.5960000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106681, 'Mambulo', 'Mambulo', 'Mambulo', 13.7166700, 123.0500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106682, 'Mambog', 'Mambog', 'Mambag-Buen,Mambog', 15.3137000, 120.0304000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106683, 'Mambayaan', 'Mambayaan', 'Mambay-an,Mambayaan', 8.7827800, 124.7841700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106684, 'Mambatangan', 'Mambatangan', 'Mambatangan', 8.4333300, 124.8333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106685, 'Mambajao', 'Mambajao', 'CGM,Mamajao,Mambajao', 9.2504000, 124.7156000, 'PH', '2016-11-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106686, 'Mabahin', 'Mabahin', 'Mabahin,Mambahin', 9.1855600, 126.1705600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106687, 'Mambago', 'Mambago', 'Mambago,Mambago-B', 7.1055600, 125.6944400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106688, 'Mambagatan', 'Mambagatan', 'Mambagatan', 10.1093000, 122.8882000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106689, 'Mamatid', 'Mamatid', 'Mamatid', 14.2349000, 121.1590200, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106690, 'Mamali', 'Mamali', 'Mamali', 6.7766700, 124.6450000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106691, 'Mamala', 'Mamala', 'Mamala,Mamalo', 14.0166700, 121.5166700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106692, 'Malvar', 'Malvar', 'Malvar', 14.0447200, 121.1586100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106693, 'Maluso', 'Maluso', 'Maluso', 6.5430000, 121.8753000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106694, 'Malusac', 'Malusac', 'Malusac,Malusak', 14.8584200, 120.6212000, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106695, 'Maluno Sur', 'Maluno Sur', 'Maluno,Maluno Sur', 16.9988500, 121.9643400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106696, 'Maluñgun', 'Malungun', 'Malungon,Malungun,Maluñgun', 6.2791700, 125.2816700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106697, 'Maluko', 'Maluko', 'Maluko', 8.3750000, 124.9538900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106698, 'Maluid', 'Maluid', 'Maluid', 15.5493000, 120.6528000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106699, 'Malway', 'Malway', 'Maluay,Malway', 9.1319000, 123.2203000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106700, 'Maluanluan', 'Maluanluan', 'Maluanluan', 13.0967000, 121.4235200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106701, 'Maltana', 'Maltana', 'Maltana', 6.4225000, 124.9372200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106702, 'Maloma', 'Maloma', 'Maloma', 15.1135000, 120.0639000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106703, 'Malolos', 'Malolos', 'Dakbayan sa Malolos,Lungsod ng Malolos,Malalos,Malolas,Malolos,Malolos City,Malolos Lakanbalen,Syudad nin Malolos,mallolloseu,Малолос,말롤로스', 14.8443000, 120.8103900, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106704, 'Maloh', 'Maloh', 'Maloh,Malok,Malon,Malut', 9.0560000, 122.9851000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106705, 'Maloco', 'Maloco', 'Maloco', 11.7832000, 122.1520000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106706, 'Malocloc', 'Malocloc', 'Malocloc', 11.5058300, 122.6783300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106707, 'Mallig', 'Mallig', 'Bayan ng Mallig,Mallig', 17.2128400, 121.6107400, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106708, 'Malitubog', 'Malitubog', 'Malitubog', 7.3155600, 124.6380600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106709, 'Malitbog', 'Malitbog', 'Malitbog', 12.7521200, 121.4659100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106710, 'Malitbog', 'Malitbog', 'Malitbog', 10.1600000, 124.9991700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106711, 'Malitbog', 'Malitbog', 'Malitbog', 8.5338900, 124.8830600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106712, 'Malita', 'Malita', 'Malit,Malita,malyta  dawayw ghrby,مالیتا، داوائو غربی', 6.4150000, 125.6116700, 'PH', '2017-01-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106713, 'Malisbeng', 'Malisbeng', 'Malisbeng,Malisbong', 6.1200000, 124.3547200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106714, 'Malinta', 'Malinta', 'Malinta', 12.3014400, 123.5581100, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106715, 'Malingin', 'Malingin', 'Malingin', 11.0500000, 123.9833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106716, 'Malinaw', 'Malinaw', 'Malinao,Malinaw', 8.8250000, 125.1930600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106717, 'Malinao Ilaya', 'Malinao Ilaya', 'Malinao,Malinao Ilaya', 13.9961100, 121.8357700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106718, 'Malinao', 'Malinao', 'Malinao', 13.3992000, 123.7069000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106719, 'Malinao', 'Malinao', 'Malinao', 11.6439000, 122.3083000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106720, 'Malinao', 'Malinao', 'Malinao', 6.6591700, 125.2866700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106721, 'Malimono', 'Malimono', 'Malimono', 9.6180600, 125.4022200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106722, 'Malilipot', 'Malilipot', 'Malilipot', 13.3188000, 123.7385000, 'PH', '2011-08-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106723, 'Maliig', 'Maliig', 'Maliig', 13.8455600, 120.1503200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106724, 'Maligaya', 'Maligaya', 'Maligaya', 15.6747000, 120.8887000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106725, 'Malidong', 'Malidong', 'Malidon,Malidong', 13.0133300, 123.4596200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106726, 'Malicboy', 'Malicboy', 'Malicboy,Malicbuy', 13.9815500, 121.7888800, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106727, 'Malibong East', 'Malibong East', 'Malibong,Malibong East', 15.8466000, 120.3269000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106728, 'Malibago', 'Malibago', 'Malibago', 13.2783000, 122.0228000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106729, 'Malhiao', 'Malhiao', 'Malhiao', 9.8848700, 123.4064100, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106730, 'Malbug', 'Malbug', 'Malbug,Malburg', 12.0563000, 123.6461000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106731, 'Malbug', 'Malbug', 'Malbago,Malbog,Malbug', 9.7327000, 123.3402000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106732, 'Malbang', 'Malbang', 'Malbang', 5.8555600, 125.0452800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106733, 'Malaybalay', 'Malaybalay', 'Dakbayan sa Malaybalay,Kota Malaybalay,Lungsod ng Malaybalay,Malajbalaj,Malaybalay,Malaybalay City,Malaybalay Lakanbalen,malaybalayy,mallaiballai,Малайбалай,مالایبالائی,말라이발라이', 8.1575000, 125.1277800, 'PH', '2012-08-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106734, 'Malayal', 'Malayal', 'Malaya,Malayal', 7.2080100, 121.9420400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106735, 'Malaya', 'Malaya', 'Malaya', 14.3971000, 121.3385000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106736, 'Malay', 'Malay', 'Malay', 11.9002700, 121.9091100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106737, 'Malawag', 'Malawag', 'Malauag,Malawag', 13.3833300, 123.2833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106738, 'Malawa', 'Malawa', 'Malaoa,Malawa', 15.9580400, 120.2778200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106739, 'Malatap', 'Malatap', 'Malatag,Malatap', 14.1871000, 122.5119000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106740, 'Malasugui', 'Malasugui', 'Malasugui,Malasugui Lica', 14.1439000, 122.8471000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106741, 'Malasiqui', 'Malasiqui', 'Malaquisi,Malasiqui', 15.9201000, 120.4140000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106742, 'Malasin', 'Malasin', 'Malasin', 16.8044400, 121.7842800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106743, 'Malasin', 'Malasin', 'Malasin', 16.3045000, 121.1062000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106744, 'Malasila', 'Malasila', 'Malasila', 6.9438900, 125.1294400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106745, 'Malaruhatan', 'Malaruhatan', 'Malaruhatan', 14.0306000, 120.6804000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106746, 'Malapatan', 'Malapatan', 'Malapatan', 5.9691700, 125.2894400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106747, 'Malapag', 'Malapag', 'Malapag', 7.1333300, 124.8166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106748, 'Malangas', 'Malangas', 'Bayan ng Malangas,Lungsud sa Malangas,Malangus,Municipio de Malangas', 7.6302800, 123.0316700, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106749, 'Malangabang', 'Malangabang', 'Malangaban,Malangabang,Malangbany', 11.2367000, 123.2062000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106750, 'Malanday', 'Malanday', 'Malanday', 14.7069000, 121.1306000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106751, 'Malanay', 'Malanay', 'Malanay,Malunay', 16.0086500, 120.4094000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106752, 'Malamote', 'Malamote', 'Malamote', 7.0738900, 124.9400000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106753, 'Malamig', 'Malamig', 'Malamig', 12.9500000, 121.3666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106754, 'Malalag', 'Malalag', 'Malalag,Malalag Beach', 6.5958300, 125.3991700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106755, 'Malainen Luma', 'Malainen Luma', 'Malainen Luma', 14.2703000, 120.7884000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106756, 'Malaiba', 'Malaiba', 'Malaiba', 10.3333300, 123.3166700, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106757, 'Malajog', 'Malajog', 'Malahog,Malajog', 12.1102000, 124.4793000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106758, 'Malayo-an', 'Malayo-an', 'Malaguan,Malaguig,Malayo-an,Malayu-an', 11.0979000, 123.0091000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106759, 'Malagos', 'Malagos', '', 7.1850000, 125.4222200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106760, 'Malaga', 'Malaga', 'Malaga', 12.2368600, 124.3752900, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106761, 'Malacampa', 'Malacampa', 'Malacampa', 15.6433500, 120.4110900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106762, 'Malabuyoc', 'Malabuyoc', 'Malabuyoc', 9.6525000, 123.3252000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106763, 'Malabugas', 'Malabugas', 'Malabugas', 9.3692000, 122.7702000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106764, 'Malabor', 'Malabor', 'Malabor', 11.2729200, 122.0466100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106765, 'Malabonot', 'Malabonot', 'Malabonot', 11.9681700, 121.9202100, 'PH', '2012-06-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106766, 'Malabon', 'Malabon', 'Malabon', 15.6361000, 119.9379000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106767, 'Malabon', 'Malabon', 'Malabon,Tanong', 14.6733300, 120.9397200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106768, 'Malabog', 'Malabog', 'Malabog', 13.1738000, 123.6865000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106769, 'Malabang', 'Malabang', 'MLP,Malabang', 7.5902800, 124.0702800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106770, 'Malabanban Norte', 'Malabanban Norte', 'Malabanban,Malabanban Norte', 13.9452100, 121.4306500, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106771, 'Malabanan', 'Malabanan', 'Malabanan', 14.0000000, 121.1333300, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106772, 'Malabago', 'Malabago', 'Malabago', 15.9815400, 120.3591300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106773, 'Malabag', 'Malabag', 'Malabag', 14.1552000, 120.9654700, 'PH', '2013-12-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106774, 'Makilala', 'Makilala', 'Makilala,Makitata', 6.9516700, 125.0969400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106775, 'Makati City', 'Makati City', 'Makati,Makati City', 14.5502700, 121.0326900, 'PH', '2012-05-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106776, 'Majayjay', 'Majayjay', 'Majayjay', 14.1463000, 121.4729000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106777, 'Maitum', 'Maitum', '', 6.0391700, 124.4986100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106778, 'Mainit Norte', 'Mainit Norte', 'Mainit Norte', 14.1654600, 121.9849600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106779, 'Mainit', 'Mainit', 'Mainit', 9.5350000, 125.5230600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106780, 'Mainit', 'Mainit', 'Mainit', 9.4335000, 123.3595000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106781, 'Mainit', 'Mainit', 'Mainit', 8.8436000, 117.8183000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106782, 'Maindang', 'Maindang', 'Maindang', 6.5955600, 124.8450000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106783, 'Maimbung', 'Maimbung', 'Maibun,Maimbung', 5.9332900, 121.0249400, 'PH', '2016-02-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106784, 'Mailag', 'Mailag', 'Mailag,Mailig', 7.9702800, 125.1375000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106785, 'Maigo', 'Maigo', 'Maibo,Maigo', 8.1613000, 123.9583000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106786, 'Maibu', 'Maibu', 'Maibo,Maibu', 6.5700000, 124.7936100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106787, 'Mahinog', 'Mahinog', 'Mahinog,Mallinog', 9.1577800, 124.7875000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106788, 'Mahayag', 'Mahayag', 'Mahayag', 9.9349000, 124.3164000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106789, 'Mahayag', 'Mahayag', 'Mahayag', 8.1183000, 123.4455000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106790, 'Mahayag', 'Mahayag', '', 7.2166700, 125.6194400, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106791, 'Mahatao', 'Mahatao', 'Mahatao,San Carlos', 20.4158500, 121.9470700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106792, 'Mahaplag', 'Mahaplag', '', 10.6045000, 124.9646000, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106793, 'Mahanob', 'Mahanob', 'Mahanob,Mahanub', 7.5732600, 126.5068400, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106794, 'Mahala', 'Mahala', 'Mahaela,Mahala', 5.9166700, 121.1333300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106795, 'Mahabang Parang', 'Mahabang Parang', 'Mahabang Parang', 13.9833300, 121.0833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106796, 'Mahaba', 'Mahaba', 'Mahaba', 13.2676000, 123.5514000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106797, 'Maguyam', 'Maguyam', 'Maguyam', 14.2627700, 121.0050000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106798, 'Maguling', 'Maguling', 'Maguling', 6.0950000, 124.4033300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106799, 'Maguinao', 'Maguinao', 'Maguinao', 15.0223100, 120.9340900, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106800, 'Maguilling', 'Maguilling', 'Maguiling,Maguilling', 17.7698200, 121.4977800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106801, 'Magtangol', 'Magtangol', 'Magtanggol,Magtangol', 15.7580000, 120.9156000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106802, 'Magtaking', 'Magtaking', 'Magtaguing,Magtaking', 15.9854000, 120.1832000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106803, 'Magsingal', 'Magsingal', 'Magsingal,Masingal', 17.6850000, 120.4244400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106804, 'Magsaysay', 'Magsaysay', 'Delfin Albano,Magsaysay,Ragan Sur,Ragen Sur', 17.3081300, 121.7775500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106805, 'Magsaysay', 'Magsaysay', '', 12.3333300, 121.1500000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106806, 'Magsaysay', 'Magsaysay', 'Magsaysay', 10.8738900, 121.0530600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106807, 'Magsaysay', 'Magsaysay', 'Linugos,Magsansay,Magsaysay', 9.0208300, 125.1825000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106808, 'Magsaysay', 'Magsaysay', 'Magsaysay', 7.3966700, 125.6350000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106809, 'Magsaysay', 'Magsaysay', 'Magsaysay', 6.7666700, 125.1833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106810, 'Magsalangi', 'Magsalangi', 'Magsalanga,Magsalangi', 12.1827500, 123.5666100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106811, 'Magpet', 'Magpet', 'Magpet,Magpit', 7.1001700, 125.1154800, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106812, 'Magnaga', 'Magnaga', 'Magnaga', 7.1694000, 125.8931000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106813, 'Maglamin', 'Maglamin', 'Lambagan,Maglamin,Miglamin', 8.0519400, 125.2616700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106814, 'Magdug', 'Magdug', 'Magdug', 6.5476400, 126.0950800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106815, 'Magdiwang', 'Magdiwang', 'Magallanes,Magdiwang', 12.4837200, 122.5147200, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106816, 'Magdalena', 'Magdalena', 'Magdalena', 16.9522500, 121.6654800, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106817, 'Magdalena', 'Magdalena', 'Magdalena', 14.1999000, 121.4290000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106818, 'Magdalena', 'Magdalena', 'Magdalena', 10.4236000, 121.9751000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106819, 'Magbay', 'Magbay', 'Magbay', 12.4101400, 121.0899100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106820, 'Magay', 'Magay', 'Magay', 10.4719000, 124.0132000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106821, 'Magatos', 'Magatos', 'Magatos', 7.5555600, 125.7266700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106822, 'Magarao', 'Magarao', 'Magarao', 13.6604000, 123.1869000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106823, 'Magapit', 'Magapit', 'Magapit', 18.1374100, 121.6694200, 'PH', '2014-09-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106824, 'Magapit, Aguiguican', 'Magapit, Aguiguican', 'Magapit', 18.1078800, 121.6770500, 'PH', '2014-09-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106825, 'Maganoy', 'Maganoy', 'Maganai,Maganoy,Maganui,Maganuy,Magonay', 6.8647200, 124.4416700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106826, 'Magallon Cadre', 'Magallon Cadre', 'Magallon,Magallon Cadre', 10.2885000, 123.0922000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106827, 'Magallanes', 'Magallanes', 'Magallanes', 16.0196000, 120.7390000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106828, 'Magallanes', 'Magallanes', '', 14.1883300, 120.7575000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106829, 'Magallanes', 'Magallanes', 'Magallanes', 12.8291700, 123.8363900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106830, 'Magallanes', 'Magallanes', 'Magallanes', 9.0200000, 125.5172200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106831, 'Magalang', 'Magalang', 'Magalan,Magalang', 15.2151000, 120.6596000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106832, 'Magalalag', 'Magalalag', 'Magalalab,Magalalag', 17.5773200, 121.7349700, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106833, 'Madulao', 'Madulao', 'Madulao', 13.5684000, 122.3413000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106834, 'Madridejos', 'Madridejos', 'Madridejos', 11.2980000, 123.7339000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106835, 'Madridejos', 'Madridejos', 'Madridejos,Nadridejos', 9.7911600, 123.3462000, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106836, 'Madrid', 'Madrid', 'Madrid', 9.2621100, 125.9643700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106837, 'Maddela', 'Maddela', 'Maddela,Pinapayan,Pinappagan', 16.3414000, 121.6849000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106838, 'Maddarulug Norte', 'Maddarulug Norte', 'Maddarulog,Maddarulug,Maddarulug Norte', 17.6073200, 121.6767000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106839, 'Madamba', 'Madamba', '', 7.8388900, 124.1102900, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106840, 'Madalum', 'Madalum', 'Madalum', 7.8542000, 124.1204800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106841, 'Madalag', 'Madalag', 'Madalag', 11.5272000, 122.3073000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106842, 'Madalag', 'Madalag', 'Madalag,Madolag', 10.8994400, 122.9828000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106843, 'Macrohon', 'Macrohon', 'Macrobon,Macrohon,میکروہون، سدرن لییٹی', 10.0797200, 124.9430600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106844, 'Maco', 'Maco', '', 7.3619400, 125.8552800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106845, 'Macayug', 'Macayug', 'Macayug,Mayog', 16.0937600, 120.4320100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106846, 'Makato', 'Makato', 'Dapdap Makato,Macato,Makato', 11.7120000, 122.2922000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106847, 'Macatbong', 'Macatbong', 'Macatbong,Macatbung', 15.5048000, 121.0791000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106848, 'MacArthur', 'MacArthur', 'MacArthur,McArthur', 10.8347200, 124.9952800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106849, 'Macarse', 'Macarse', 'Macarse', 15.4249500, 120.7747600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106850, 'Macapsing', 'Macapsing', 'Macapsing', 15.6783000, 121.1319000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106851, 'Macalva Norte', 'Macalva Norte', 'Macalva,Macalva Norte', 16.3485000, 120.3866000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106852, 'Macalong', 'Macalong', 'Macalong,Makalong', 16.0137000, 120.6586000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106853, 'Macalelon', 'Macalelon', 'Macalelon', 13.7469400, 122.1386100, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106854, 'Macalaya', 'Macalaya', 'Macalaya', 12.8894400, 123.7711100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106855, 'Macalamcam A', 'Macalamcam A', 'Macalamcam,Macalamcam A', 13.8566000, 121.3281400, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106856, 'Macabugos', 'Macabugos', 'Macabugos,Makabugos', 13.2362000, 123.3053000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106857, 'Macabuboni', 'Macabuboni', 'Macaboboni,Macabuboni', 16.1909000, 119.7802000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106858, 'Macabebe', 'Macabebe', 'Macabebe', 14.9089000, 120.7155000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106859, 'Macaas', 'Macaas', 'Macaas', 10.6988500, 124.0115400, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106860, 'Mabuttal East', 'Mabuttal East', 'Mabutal,Mabuttal,Mabuttal East', 18.3762000, 121.5147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106861, 'Mabusag', 'Mabusag', 'Mabusag,Mabusan', 17.9261000, 120.4976000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106862, 'Mabunga', 'Mabunga', 'Mabunga,Mabungo', 13.8634000, 122.0677000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106863, 'Mabuhay', 'Mabuhay', '', 7.4177800, 122.8366700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106864, 'Mabuhay', 'Mabuhay', 'Mabuhay', 7.3330600, 125.5475000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106865, 'Mabua', 'Mabua', 'Mabua', 9.8039000, 125.4409000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106866, 'Mabiton', 'Mabiton', 'Mabitan,Mabiton', 12.8334000, 123.2612000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106867, 'Mabitac', 'Mabitac', 'Mabitac', 14.4259000, 121.4290000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106868, 'Mabini', 'Mabini', 'Mabini', 17.0993600, 121.7345400, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106869, 'Mabini', 'Mabini', 'Balincaguin,Mabini,mabyny  pangasynan,مابینی، پانگاسینان', 16.0699000, 119.9391000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106870, 'Mabini', 'Mabini', '', 15.6000000, 120.9833300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106871, 'Mabini', 'Mabini', '', 13.7532400, 120.9404900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106872, 'Mabini', 'Mabini', 'Mabini', 11.4166700, 125.1666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106873, 'Mabini', 'Mabini', 'Mabini', 10.7959400, 123.4846000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106874, 'Mabini', 'Mabini', 'Mabini', 9.8649000, 124.5215000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106875, 'Mabini', 'Mabini', 'Guambog,Mabini', 7.3113900, 125.8527800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106876, 'Mabini', 'Mabini', 'Mabini', 6.5388900, 124.9000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106877, 'Mabinay', 'Mabinay', 'Mabina,Mabinay', 9.7272200, 122.9016700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106878, 'Mabilog', 'Mabilog', 'Mabilog', 15.3948500, 120.6657300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106879, 'Brgy. Mabilo, New Washington', 'Brgy. Mabilo, New Washington', 'Mabilog', 11.6777800, 122.4075000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106880, 'Mabilbila Sur', 'Mabilbila Sur', 'Mabilbila,Mabilbila Sur', 17.5070900, 120.4410000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106881, 'Mabilao', 'Mabilao', 'Mabilao', 16.1535100, 120.4249400, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106882, 'Mabilang', 'Mabilang', 'Mabilang', 15.6751100, 120.4883500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106883, 'Mabayo', 'Mabayo', 'Mabage,Mabayo,Maybayo', 14.7318000, 120.2781000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106884, 'Mabay', 'Mabay', 'Mabay', 6.0577200, 124.4666100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106885, 'Mabasa', 'Mabasa', 'Mabasa', 16.3210000, 121.1262000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106886, 'Mabalacat City', 'Mabalacat City', 'CRK,Mabalacat', 15.2230300, 120.5711700, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106887, 'Mababanaba', 'Mababanaba', 'Mababanaba', 15.4971500, 120.4605300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106888, 'Maayong Tubig', 'Maayong Tubig', 'Maayong Tubig,Tabig', 9.1672000, 123.2469000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106889, 'Maayon', 'Maayon', 'Maayon', 11.3867000, 122.7859000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106890, 'Maasin', 'Maasin', '', 10.8925000, 122.4347200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106891, 'Maasin', 'Maasin', 'City of Maasin,Maasin,Massin City', 10.1336100, 124.8447200, 'PH', '2012-06-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106892, 'Maasim', 'Maasim', 'Maasim,Maasin', 14.9955100, 121.0308200, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106893, 'Maasin', 'Maasin', 'Maasim,Maasin', 5.8575000, 125.0061100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106894, 'Maao', 'Maao', 'Ma-ao Barrio,Maao', 10.4896000, 122.9907000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106895, 'Maanas', 'Maanas', 'Maanas', 8.8938900, 125.0308300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106896, 'Maan', 'Maan', 'Maan', 5.9338900, 124.7355600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106897, 'Maagnas', 'Maagnas', 'Maagnas,Maangas,Maañgas', 13.7192000, 123.6675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106898, 'Lusong', 'Lusong', 'Lusong,Luzong,Luzong Sur', 16.8670000, 120.4420000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106899, 'Luzon', 'Luzon', 'Luzon', 6.5190400, 126.0940800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106900, 'Luuk Datan', 'Luuk Datan', 'Lokdata,Lokdatan,Luuk Datan,Manuk Mangaw', 4.8119400, 119.8452800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106901, 'Lu-uk', 'Lu-uk', 'Andres,Camp Andres,Lu-uk', 5.9684000, 121.3122000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106902, 'Lut-od', 'Lut-od', 'Lut-od', 10.2572200, 123.6294400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106903, 'Lutayan', 'Lutayan', 'Lutavan,Lutayan', 6.6200000, 124.8830600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106904, 'Kabayan', 'Kabayan', 'Kabayan,Lutab', 16.6238800, 120.8399400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106905, 'Lusacan', 'Lusacan', 'Lusacan', 13.9552300, 121.3447700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106906, 'Lurugan', 'Lurugan', 'Lurugan', 8.0166700, 124.9666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106907, 'Lupon', 'Lupon', 'Lupon,Sumlog', 6.8981400, 126.0096100, 'PH', '2010-08-15', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106908, 'Lupi Viejo', 'Lupi Viejo', 'Lupi,Lupi Viejo', 13.7897000, 122.9098000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106909, 'Lupi', 'Lupi', 'Lupi', 13.5333300, 123.1500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106910, 'Lapase', 'Lapase', 'Lapasa,Lapasan,Lapase,Lupasan', 8.1924000, 123.8632000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106911, 'Lupao', 'Lupao', 'Lupao', 15.8793000, 120.8983000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106912, 'Luntal', 'Luntal', 'Luntal', 14.0292000, 120.7174000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106913, 'Lun Pequeño', 'Lun Pequeno', 'Little Lun,Lun,Lun Padidu,Lun Pequeno,Lun Pequeño', 6.0377800, 125.2838900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106914, 'Lungog', 'Lungog', 'Lungog', 17.4645000, 120.4784000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106915, 'Lungaog', 'Lungaog', 'Lungaog', 7.5294400, 125.6877800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106916, 'Lunen', 'Lunen', 'Lonen,Lunen', 6.3591700, 124.9047200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106917, 'Lunec', 'Lunec', 'Lunec', 15.9539500, 120.4894900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106918, 'Lunas', 'Lunas', 'Lunas', 10.6402000, 123.7525000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106919, 'Lunao', 'Lunao', 'Lunao', 8.8502800, 125.0563900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106920, 'Luna', 'Luna', '', 18.3258300, 121.3536100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106921, 'Luna', 'Luna', 'Antatet,Luna,Puna', 16.9697500, 121.7292400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106922, 'Luna', 'Luna', 'Luna', 16.8528000, 120.3761000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106923, 'Luna', 'Luna', 'Luna', 10.9690000, 123.2419000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106924, 'Luna', 'Luna', 'Luna', 9.7370000, 125.4976000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106925, 'Luna', 'Luna', 'Luna', 7.5763900, 125.6672200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106926, 'Lumuyon', 'Lumuyon', 'Lomoyon,Lumayan,Lumuyon', 5.9158300, 124.7869400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106927, 'Lumil', 'Lumil', 'Lumil', 14.1814400, 121.0098900, 'PH', '2013-07-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106928, 'Lumbia', 'Lumbia', '', 8.3958300, 124.5938900, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106929, 'Lumbayao', 'Lumbayao', 'Lumbayao', 8.0166700, 125.1666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106930, 'Lumbayanague', 'Lumbayanague', 'Lumbayanague', 7.7825000, 124.2800000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106931, 'Lumbayan', 'Lumbayan', 'Lumbayao', 6.9472200, 122.1411100, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106932, 'Lumbatan', 'Lumbatan', 'Luinbatan,Lumbatan', 7.7850000, 124.2563900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106933, 'Lumbangan', 'Lumbangan', 'Lumbangan', 14.0524000, 120.6667000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106934, 'Lumbang', 'Lumbang', 'Lumban,Lumbang', 14.2973000, 121.4598000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106935, 'Lumatil', 'Lumatil', 'Lumatil', 5.8747200, 124.8883300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106936, 'Lumazal', 'Lumazal', 'Lumasal,Lumazal', 5.8852800, 124.8494400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106937, 'Lumangbayan', 'Lumangbayan', 'Lumangbayan', 13.4190000, 121.0348000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106938, 'Lumangbayan', 'Lumangbayan', 'Lumangbayan', 13.0483000, 121.4987200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106939, 'Luksuhin', 'Luksuhin', 'Luksuhin', 14.0966700, 120.8808300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106940, 'Luklukan', 'Luklukan', 'Luklukan', 14.3254000, 122.7124000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106941, 'Luisiana', 'Luisiana', 'Luisiana', 14.1850000, 121.5109000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106942, 'Lugus', 'Lugus', 'Lugus', 5.7036100, 120.8202800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106943, 'Lugui', 'Lugui', 'Lugui', 14.1131000, 122.7935000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106944, 'Lugo', 'Lugo', 'Lugo', 10.8167200, 123.9862600, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106945, 'Lugait', 'Lugait', 'Lugait', 8.3411100, 124.2591700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106946, 'Lucsuhin', 'Lucsuhin', 'Lucsuhin,Luksuhin', 13.8818600, 120.6413100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106947, 'Locmayan', 'Locmayan', 'Locmayan,Lucmayan', 10.4726000, 122.5190000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106948, 'Lucero', 'Lucero', 'Lucero', 16.4051000, 119.9124000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106949, 'Lucero', 'Lucero', 'Lucero', 11.4542000, 122.4643100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106950, 'Lucena', 'Lucena', 'Dakbayan sa Lucena,Kota Lucena,Lucena,Lucena City,Lucena Lakanbalen,Lungsod ng Lucena,Lusena,Siudad ti Lucena,lu sai na,lusena,lwsyna  flpayn,Лусена,لوسینا، فلپائن,卢塞纳,루세나', 13.9313900, 121.6172200, 'PH', '2012-06-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106951, 'Lucban', 'Lucban', 'Lucban', 14.1135600, 121.5557400, 'PH', '2014-09-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106952, 'Lukatan', 'Lukatan', 'Lucatan,Lukatan', 7.0096000, 126.4211800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106953, 'Lucapon', 'Lucapon', 'Lacapon,Locapon,Lucapon', 15.6998000, 119.9320000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106954, 'Lucap', 'Lucap', 'Lucap', 16.1903800, 120.0022100, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106955, 'Lubuagan', 'Lubuagan', 'Lubuagan', 17.3548000, 121.1747000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106956, 'Lubigan', 'Lubigan', 'Lubigan,Lubigan Sr', 13.7420000, 122.9373000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106957, 'Lucban', 'Lucban', 'Luban,Lubban,Lucban', 18.3364400, 121.4308200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106958, 'Lubao', 'Lubao', 'Lubao', 14.9405000, 120.6011000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106959, 'Lubang', 'Lubang', 'Lubang', 13.8583500, 120.1240200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106960, 'Luba', 'Luba', 'Luba', 17.3180000, 120.6945000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106961, 'Loyola', 'Loyola', 'Layola,Loyola', 8.3349200, 126.3336600, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106962, 'Lourdes', 'Lourdes', 'Lourdes', 15.0193000, 120.8511000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106963, 'Lourdes', 'Lourdes', 'Lourdes', 14.9666700, 120.6833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106964, 'Lourdes', 'Lourdes', 'Lourdes', 13.3899000, 123.3735000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106965, 'Lourdes', 'Lourdes', 'Lourdes', 8.5250000, 124.4322200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106966, 'Los Baños', 'Los Banos', 'Los Banos,Los Baños,Los-Ban''os,Лос-Баньос', 14.1702500, 121.2418100, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106967, 'Los Arcos', 'Los Arcos', 'Los Arcos', 8.6327800, 125.9855600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106968, 'Los Angeles', 'Los Angeles', 'Angeles', 9.0125000, 125.6080600, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106969, 'Loreto', 'Loreto', '', 10.3636100, 125.5730600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106970, 'Loreto', 'Loreto', 'Loreto', 8.1869400, 125.8530600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106971, 'Lupo', 'Lupo', 'Lapo,Lopo,Lupo', 11.5076000, 122.4791000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106972, 'Lopez Jaena', 'Lopez Jaena', 'Lopez Jaena', 10.8478000, 123.4141000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106973, 'Lopez Jaena', 'Lopez Jaena', 'Lopez Jaena,Manella', 8.5528000, 123.7615000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106974, 'Lopez', 'Lopez', 'Lopez', 13.8840000, 122.2604000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106975, 'Lope de Vega', 'Lope de Vega', 'Lope de Vega,Lope de Vegas', 12.2983000, 124.6238000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106976, 'Loon', 'Loon', 'Loon', 9.7998000, 123.7929000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106977, 'Lookan', 'Lookan', 'Lookan,Lookani,Luukan', 5.0370000, 120.1027000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106978, 'Looc', 'Looc', 'Looc,Look', 8.8433300, 124.7916700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106979, 'Looc', 'Looc', 'Looc,Looe', 14.1648000, 120.6293000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106980, 'Looc', 'Looc', 'Looc,San Rafael', 13.7203600, 120.2498200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106981, 'Looc', 'Looc', 'Looc', 12.2605000, 121.9926000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106982, 'Looc', 'Looc', 'Lo-ok,Looc', 11.4788000, 124.5542000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106983, 'Lono', 'Lono', 'Lono,Lonoy', 11.5136100, 122.7297200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106984, 'Lonoy', 'Lonoy', 'Lonoy', 11.5122200, 122.5533300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106985, 'Longos', 'Longos', 'Longos', 16.1073400, 120.3965800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106986, 'Lomboy', 'Lomboy', 'Lomboy', 15.4925500, 120.7172300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106987, 'Lombog', 'Lombog', 'Lombog', 9.7788000, 124.4174000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106988, 'Lombocan', 'Lombocan', '', 9.0076700, 125.5055800, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106989, 'Loma de Gato', 'Loma de Gato', 'Loma de Gato', 14.7886900, 120.9988900, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106990, 'Loqueb Este', 'Loqueb Este', 'Lokeb,Loqueb,Loqueb Este', 15.9448100, 120.4460700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106991, 'Logon', 'Logon', 'Logan,Logon', 11.3303000, 124.1146000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106992, 'Lobong', 'Lobong', 'Lobong', 16.0815000, 120.4704000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106993, 'Loboc', 'Loboc', 'Laboc,Loboc', 9.6383300, 124.0348200, 'PH', '2015-04-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106994, 'Lobo', 'Lobo', 'Lobo', 13.6481000, 121.2112000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106995, 'Loay', 'Loay', 'Loay', 9.6006000, 124.0142000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106996, 'Loacan', 'Loacan', 'Loacan', 16.5500000, 120.6666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106997, 'Llorente', 'Llorente', 'Llorente,Lorente', 11.4119400, 125.5458300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106998, 'Llanera', 'Llanera', 'Llanera', 15.6635000, 121.0182000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(106999, 'Little Baguio', 'Little Baguio', 'Little Baguio', 7.8938900, 125.2763900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107000, 'Litayan', 'Litayan', 'Litayan,Litayen', 7.3358300, 124.0347200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107001, 'Lipayran', 'Lipayran', 'Lipayran', 11.0593000, 123.6342000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107002, 'Lipay', 'Lipay', 'Lipay', 15.4561000, 119.9208000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107003, 'Lipahan', 'Lipahan', 'Lipahan', 13.8368700, 121.4016700, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107004, 'Lipa City', 'Lipa City', 'Ciudad ti Lipa,Lipa,Lipa City,Липа', 13.9411000, 121.1631000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107005, 'Liozon', 'Liozon', 'Lioson,Liozon', 15.3993000, 119.9330000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107006, 'Lintangan', 'Lintangan', 'Lintangan,Litangan', 7.2155400, 121.9520000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107007, 'Linoan', 'Linoan', 'Linoan', 7.6260000, 125.9741000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107008, 'Linmansangan', 'Linmansangan', 'Linmansangan', 15.8298000, 120.2959300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107009, 'Lingion', 'Lingion', 'Lingion', 8.1880600, 124.6097200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107010, 'Lingig', 'Lingig', 'Lingig', 8.0388900, 126.4125000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107011, 'Lingayen', 'Lingayen', 'Lingayen', 16.0218200, 120.2319400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107012, 'Lingating', 'Lingating', 'Lingating', 8.3316700, 124.6288900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107013, 'Lingasan', 'Lingasan', 'Lingasad,Lingasan', 8.4966000, 123.3997000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107014, 'Linay', 'Linay', '', 8.5166700, 123.1333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107015, 'San Miguel', 'San Miguel', 'Linapacan,San Miguel', 11.4924000, 119.8703000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107016, 'Linaon', 'Linaon', 'Linao,Linaon', 9.9499000, 122.4483000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107017, 'Linao', 'Linao', 'Linao', 7.1677800, 124.9675000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107018, 'Linao', 'Linao', 'Linao', 7.0172000, 125.9920000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107019, 'Linan', 'Linan', 'Linan', 6.4300000, 124.9755600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107020, 'Linamon', 'Linamon', 'Linamon,Tomas Cabili', 8.1860300, 124.1627600, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107021, 'Linabuan Sur', 'Linabuan Sur', 'Linabuan,Linabuan Sur', 11.6511100, 122.3450000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107022, 'Linabuan', 'Linabuan', 'Linabuan', 11.6510000, 122.3575000, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107023, 'Linabo', 'Linabo', 'Linabo', 8.0541700, 125.1550000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107024, 'Limulan', 'Limulan', 'Limulan', 6.5852800, 124.0618900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107025, 'Limpapa', 'Limpapa', '', 7.1197200, 121.9105600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107026, 'Limot', 'Limot', 'Limot', 7.0405000, 126.2726800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107027, 'Limon', 'Limon', 'Limon', 12.3000000, 122.0166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107028, 'Limon', 'Limon', 'Lemon,Limon', 11.2889000, 124.5671000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107029, 'Limanancong', 'Limanancong', 'Limanancang,Limanancany,Limanancong,Liminancong,Liminangcong,Liminangoon', 10.9893000, 119.3593000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107030, 'Limbo', 'Limbo', 'Limbo', 7.2516700, 124.2438900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107031, 'Limbalod', 'Limbalod', 'Limbalod', 7.1327800, 124.7988900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107032, 'Limbaan', 'Limbaan', 'Limbaan', 7.6396000, 125.8209000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107033, 'Limay', 'Limay', 'Limay', 14.5619400, 120.5983300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107034, 'Limaong', 'Limaong', '', 7.3605600, 122.3663900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107035, 'Limao', 'Limao', 'Limao', 7.0791700, 125.6736100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107036, 'Liloy', 'Liloy', 'Liloy,Pataong', 8.1144400, 122.6594400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107037, 'Liloan', 'Liloan', '', 11.0441700, 124.5505600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107038, 'Liloan', 'Liloan', 'Liloan', 10.3991000, 123.9992000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107039, 'Liloan', 'Liloan', 'Liloan,Poblacion', 10.1581100, 125.1180600, 'PH', '2016-09-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107040, 'Lilio', 'Lilio', 'Lilio,Liliw', 14.1313000, 121.4362000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107041, 'Liliongan', 'Liliongan', 'Liliongan', 7.3627800, 124.7927800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107042, 'Lila', 'Lila', 'Lila', 9.5918000, 124.0958000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107043, 'Ligayan', 'Ligayan', 'Ligayan,Ligayen', 4.6544200, 119.4706200, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107044, 'Ligaya', 'Ligaya', 'Ligaya', 15.5091000, 121.2872000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107045, 'Ligaya', 'Ligaya', 'Ligaya', 12.6599300, 120.8923100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107046, 'Ligao', 'Ligao', '', 13.2169700, 123.5192400, 'PH', '2014-11-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107047, 'Lidlidda', 'Lidlidda', 'Lidlidda', 17.2693000, 120.5213000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107048, 'Licuan', 'Licuan', 'Licuan', 17.6089000, 120.9059000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107049, 'Liciada', 'Liciada', 'Lachada,Liciada,Lisiada', 14.9148400, 120.9318200, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107050, 'Licab', 'Licab', 'Licab', 15.5439000, 120.7634000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107051, 'Libungan', 'Libungan', '', 7.2408300, 124.5200000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107052, 'Libuganon', 'Libuganon', 'Liboganon,Libuganon', 7.3488000, 125.7782000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107053, 'Liboro', 'Liboro', 'Liboro', 13.8245000, 122.7295000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107054, 'Liboran', 'Liboran', 'Liboran,Liburan', 8.3547200, 124.6488900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107055, 'Libona', 'Libona', 'Libona', 8.3388900, 124.7352800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107056, 'Libon', 'Libon', 'Libon', 13.2997000, 123.4386000, 'PH', '2011-08-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107057, 'Libog', 'Libog', 'Libog', 13.2349000, 123.7778000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107058, 'Libmanan', 'Libmanan', 'Libmanan', 13.6928000, 123.0596000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107059, 'Libjo', 'Libjo', 'Libja,Libjo', 10.1977800, 125.5352800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107060, 'Liberty', 'Liberty', 'Liberty', 10.8741700, 125.0025000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107061, 'Liberty', 'Liberty', 'Liberty', 6.5411100, 124.6288900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107062, 'Liberty', 'Liberty', 'Liberty', 6.4552800, 124.9819400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107063, 'Libertad', 'Libertad', 'Libertad', 12.4541200, 122.0082800, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107064, 'Libertad', 'Libertad', 'Libertad,Libertad Town', 11.7694000, 121.9190000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107065, 'Libertad', 'Libertad', '', 11.0363900, 124.5683300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107066, 'Libertad', 'Libertad', 'Libertad', 11.0352800, 122.7694400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107067, 'Libertad', 'Libertad', 'Libertad', 11.0304000, 124.0215000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107068, 'Libertad', 'Libertad', 'Libertad', 10.9166700, 124.4500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107069, 'Libertad', 'Libertad', 'Libertad', 10.8333300, 123.5666700, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107070, 'Libertad', 'Libertad', '', 8.9441700, 125.5019400, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107071, 'Libertad', 'Libertad', 'Libertad', 8.5611100, 124.3513900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107072, 'Libertad', 'Libertad', 'Libertad', 8.2755000, 123.8382000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107073, 'Libertad', 'Libertad', '', 8.2500000, 124.2333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107074, 'Libertad', 'Libertad', 'Libertad', 8.1075000, 126.0263900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107075, 'Libato', 'Libato', 'Libato', 13.8151400, 121.3346300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107076, 'Libas', 'Libas', 'Libas', 15.8778900, 120.3163300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107077, 'Libas', 'Libas', 'Libas', 13.2416700, 121.9555500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107078, 'Libas', 'Libas', 'Libas', 10.9388000, 124.5450000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107079, 'Libas', 'Libas', 'Libas', 9.8833300, 125.9833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107080, 'Libas', 'Libas', 'Libas', 6.5355600, 124.7788900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107081, 'Libagon', 'Libagon', 'Libagon', 10.3008300, 125.0558300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107082, 'Libacao', 'Libacao', 'Libacao', 11.4802000, 122.3042100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107083, 'Libacao', 'Libacao', 'Libacao', 10.1800000, 122.9137000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107084, 'Lianga', 'Lianga', 'Lianga', 8.6336100, 126.0947200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107085, 'Lian', 'Lian', 'Lian', 14.0336400, 120.6492800, 'PH', '2015-04-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107086, 'Leyte', 'Leyte', 'Leyte,lytt,ليتة', 11.3668700, 124.4823900, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107087, 'Leuteboro', 'Leuteboro', 'Leuteboro', 13.0610000, 121.3747200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107088, 'Lepanto', 'Lepanto', 'Lepanto', 9.6845000, 123.4026000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107089, 'Lepa', 'Lepa', 'Lepa', 15.8843800, 120.4508900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107090, 'Leones East', 'Leones East', 'Leones,Leones East', 16.3633000, 120.3919000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107091, 'Leon', 'Leon', 'Leon', 10.7808500, 122.3894000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107092, 'Lennec', 'Lennec', 'Lenec,Lennec', 15.6835000, 120.7338000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107093, 'Lemery', 'Lemery', 'Lemery', 13.8809000, 120.9138900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107094, 'Lemery', 'Lemery', 'Lemery', 11.2258000, 122.9275000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107095, 'Legaspi', 'Legaspi', 'LGP,Legaspi City,Legazpi,Legazpi City', 13.1412500, 123.7407300, 'PH', '2017-07-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107096, 'Legrada', 'Legrada', 'Legarda,Legarda 1,Legardo,Legrada', 7.6333000, 123.3045000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107097, 'Leganes', 'Leganes', 'Leganes', 10.7872200, 122.5891700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107098, 'Lebak', 'Lebak', 'LWA,Lebak,Salaman', 6.6438900, 124.0658300, 'PH', '2017-04-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107099, 'Lazi', 'Lazi', 'Lazi', 9.1287000, 123.6356000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107100, 'Layog', 'Layog', 'Layog', 7.0766700, 124.7305600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107101, 'Laylay', 'Laylay', 'Laylay', 13.4391000, 121.8202000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107102, 'Laya', 'Laya', 'Laya', 17.4726000, 121.4678000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107103, 'Lawang Kupang', 'Lawang Kupang', 'Lauang Cupang,Lawan Kupana,Lawang Kupang', 15.3480700, 120.8575200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107104, 'Lawa-an', 'Lawa-an', 'Laua-an,Lawa-an,Lawan', 11.1402800, 125.3013900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107105, 'Lawa-an', 'Lawa-an', 'Laua-an,Lava-an,Lawa-an', 11.1500000, 122.0333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107106, 'Lavezares', 'Lavezares', 'Lavezaras,Lavezares', 12.5336000, 124.3305000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107107, 'Laurel', 'Laurel', 'Laurel', 14.0554200, 120.9193200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107108, 'Laur', 'Laur', 'Laur,San Estaban', 15.5865000, 121.1834000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107109, 'La Union', 'La Union', 'La Union', 9.0855600, 125.5358300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107110, 'La Union', 'La Union', 'La Union,Uangon', 6.7041300, 126.0879800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107111, 'Lauigan', 'Lauigan', 'Lauigan,Lavigan,Lawigan', 10.4870000, 122.0354000, 'PH', '2016-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107112, 'Latung', 'Latung', 'Latung', 5.5000000, 120.8833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107113, 'La Trinidad', 'La Trinidad', 'La Trinidad,La-Trinidad,Trinidad,lateulinidadeu,Ла-Тринидад,لا ٹرینیڈاڈ، بینگیت,라트리니다드', 16.4550000, 120.5875000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107114, 'Las Piñas', 'Las Pinas', 'Las Pinas,Las Piñas', 14.4505600, 120.9827800, 'PH', '2016-10-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107115, 'Las Navas', 'Las Navas', 'Las Navas', 12.3392000, 125.0313000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107116, 'Lasang', 'Lasang', 'Lasong', 7.2669400, 125.6650000, 'PH', '2013-03-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107117, 'Lasam', 'Lasam', 'Lasam', 18.0651900, 121.6006500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107118, 'La Roxas', 'La Roxas', 'La Roxas', 7.8641700, 124.8869400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107119, 'Larion Alto', 'Larion Alto', 'Larion,Larion Acto,Larion Alto,Larion Altu', 17.6308200, 121.7606200, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107120, 'Larena', 'Larena', 'Canoan,Larena', 9.2452800, 123.5938900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107121, 'Larap', 'Larap', 'Larap', 14.2990000, 122.6504000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107122, 'Larap', 'Larap', 'Larap', 4.7615400, 119.4051100, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107123, 'Lapuz', 'Lapuz', 'Lapuz', 6.5233300, 124.6300000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107124, 'Lapuyan', 'Lapuyan', 'Lapuyan', 7.6379000, 123.1944000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107125, 'Lapu-Lapu City', 'Lapu-Lapu City', 'Dakbayan sa Lapu-Lapu,Lapu-Lapu,Lapu-Lapu City,Opon,Siudad ti Lapu-Lapu,la pu la pu shi,rapu=rapu shi,ラプ＝ラプ市,拉普拉普市', 10.3102800, 123.9494400, 'PH', '2013-08-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107126, 'Lapuan', 'Lapuan', 'Lapuan', 6.1444400, 125.7008300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107127, 'Lapolapo', 'Lapolapo', 'Lapolapo', 13.8341000, 121.1379000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107128, 'Lapinigan', 'Lapinigan', 'Lapinigan', 8.4205600, 125.9825000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107129, 'Lapinig', 'Lapinig', 'Lapinig', 12.3151000, 125.3032000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107130, 'Lapi', 'Lapi', 'Lapi,Lappi', 17.7160000, 121.8977500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107131, 'La Paz', 'La Paz', 'La Paz', 17.6746000, 120.6864000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107132, 'La Paz', 'La Paz', 'La Paz', 16.9107500, 121.6682400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107133, 'La Paz', 'La Paz', 'La Paz,La-Pas,Ла-Пас', 15.4412500, 120.7286300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107134, 'De la Paz', 'De la Paz', 'De la Paz,La Paz', 11.0644400, 122.7791700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107135, 'Lapaz', 'Lapaz', 'Lapaz', 10.9887000, 123.9797000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107136, 'La Paz', 'La Paz', 'La Paz,La-Pas,Ла-Пас', 10.8925000, 124.9558300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107137, 'La Paz', 'La Paz', 'La Paz', 10.4131000, 122.5162000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107138, 'La Paz', 'La Paz', 'La Pas,La Paz,La-Pas,Magabao Cove,Ла-Пас', 8.9847100, 126.2629900, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107139, 'La Paz', 'La Paz', 'La Paz,La-Pas,Ла-Пас', 8.2708300, 125.7997200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107140, 'La Paz', 'La Paz', 'La Paz', 7.3158300, 125.7333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107141, 'Laoang', 'Laoang', 'Laoang,Loangan', 12.5698000, 125.0141000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107142, 'Laoag', 'Laoag', 'Dakbayan sa Laoag,Kota Laoag,LAO,Laoag,Laoag City,Laoag Lakanbalen,Laoang,Laog,Loag,Lungsod ng Laoag,Siyudad na Laoag,Syudad nin Laoag,lao wo,laoageu,lawag,raoagu,Лаоаг,لاواگ,ལའ་ཨག,ལའོ་ཨག,ラオアグ,佬沃,라오아그', 18.1978000, 120.5957000, 'PH', '2013-11-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107143, 'Lao', 'Lao', '', 11.0180600, 124.5597200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107144, 'Lanuza', 'Lanuza', 'Lanuza', 9.2341700, 126.0644400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107145, 'Tairan Camp', 'Tairan Camp', 'Lantawan,Tairan,Tairan Camp', 6.6402000, 121.8395000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107146, 'Lantapan', 'Lantapan', 'Lantapan,Lantapán', 7.9977800, 125.0277800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107147, 'Lantangan', 'Lantangan', 'Lantangan', 12.1981500, 123.2710100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107148, 'Lantangan', 'Lantangan', 'Lantangan', 11.5882000, 123.3256000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107149, 'Lantangan', 'Lantangan', 'Lantangan', 11.3860000, 122.8887000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107150, 'Lanot', 'Lanot', 'Lanot', 11.5191700, 122.7572200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107151, 'Lanna', 'Lanna', 'Lanna', 17.6960000, 121.7001400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107152, 'Lanigay', 'Lanigay', 'Lanigay', 13.3166700, 123.5000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107153, 'Languyan', 'Languyan', 'Languyan', 5.2618000, 120.0807000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107154, 'Lañgub', 'Langub', 'Langub,Langud,Lañgub', 10.7975400, 123.5338000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107155, 'Langob', 'Langob', 'Langob,Langub', 10.5774000, 123.7309000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107156, 'Langtad', 'Langtad', 'Angtad,Langtad', 10.1856800, 123.7344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107157, 'Langtad', 'Langtad', 'Langtad', 9.8909400, 123.6043000, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107158, 'Langpas', 'Langpas', 'Langpas', 5.9750000, 120.9490000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107159, 'Langiden', 'Langiden', 'Langiden', 17.5771000, 120.5640000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107160, 'Langcangan', 'Langcangan', '', 8.4794400, 123.7558300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107161, 'Langatian', 'Langatian', 'Langatian', 8.5208000, 123.2324000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107162, 'Lanat', 'Lanat', 'Lanat', 15.7918900, 120.6046100, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107163, 'Lanas', 'Lanas', 'Cogon,Lanas', 12.0494600, 121.9185100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107164, 'Lanas', 'Lanas', 'Lanas', 10.2666700, 123.7333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107165, 'Lanao', 'Lanao', 'Lanao', 11.2563600, 124.0242300, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107166, 'Lamut', 'Lamut', 'Lamut', 16.6490700, 121.2247400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107167, 'Lampitak', 'Lampitak', 'Lampitak', 6.4322200, 125.0525000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107168, 'Lampari', 'Lampari', 'Lampari', 6.3125000, 124.8802800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107169, 'Lamitan City', 'Lamitan City', 'Lamitan', 6.6502000, 122.1295200, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107170, 'Lamitan', 'Lamitan', 'Lamidan,Lamitan', 6.0872200, 125.7022200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107171, 'Laminusa', 'Laminusa', 'Laminusa', 5.5549000, 120.9136000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107172, 'Lamian', 'Lamian', 'Lamian', 6.3091700, 124.8463900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107173, 'Lambunao', 'Lambunao', 'Lambunao', 11.0556300, 122.4759000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107174, 'Lambayong', 'Lambayong', 'Lambayong,Lombaying,Lombayong', 6.5194400, 125.0444400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107175, 'Lambakin', 'Lambakin', 'Lambakin', 15.3717100, 120.8607000, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107176, 'Lambakin', 'Lambakin', 'Lambakin', 14.7500000, 120.8666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107177, 'Lambo', 'Lambo', 'Lamba,Lambo', 6.3597200, 124.8122200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107178, 'Lamak', 'Lamak', 'Lamak', 10.3997200, 124.7388900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107179, 'Lallayug', 'Lallayug', 'Lallayug', 17.7068400, 121.4417500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107180, 'Lalig', 'Lalig', 'Lalig', 13.9825500, 121.3264700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107181, 'La Libertad', 'La Libertad', 'La Liberlao,La Libertad,Libertad', 10.0266000, 123.2335000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107182, 'La Libertad', 'La Libertad', 'La Libertad', 7.4802800, 125.6472200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107183, 'Lalauigan', 'Lalauigan', 'Lalauigan,Lalawigan', 11.5891700, 125.4697200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107184, 'Lalagsan', 'Lalagsan', 'Lalagsan', 10.2824000, 123.0130000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107185, 'Lalab', 'Lalab', 'Lalab', 11.5749000, 122.4284000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107186, 'Lala', 'Lala', '', 7.9730600, 123.7472200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107187, 'Lala', 'Lala', 'Lala', 7.9745000, 123.7458000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107188, 'Rancheria Payau', 'Rancheria Payau', 'Lakewood,Rancheria Payau', 7.8541000, 123.1598000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107189, 'Lajong', 'Lajong', 'Lajong', 12.8333300, 123.9666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107190, 'Laiya', 'Laiya', 'Laiya', 13.6803100, 121.4008100, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107191, 'Lais', 'Lais', 'Lais,Lias', 6.3327800, 125.6463900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107192, 'La Hacienda', 'La Hacienda', 'La Hacienda', 9.8815000, 124.3923000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107193, 'Laguitas', 'Laguitas', 'Laguitas', 8.0891700, 125.1305600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107194, 'Laguit Centro', 'Laguit Centro', 'Laguit,Laguit Centro', 15.9472000, 120.1904000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107195, 'Lagindingan', 'Lagindingan', 'Lagindingan,Laguindingan', 8.5747200, 124.4422200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107196, 'Laguilayan', 'Laguilayan', 'Laguilayan', 6.6525000, 124.5211100, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107197, 'La Granja', 'La Granja', 'La Granja,La Granja Experimental Farm', 10.4082000, 122.9898000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107198, 'Lagonoy', 'Lagonoy', 'Lagonoy', 13.7342000, 123.5207000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107199, 'Lagonglong', 'Lagonglong', 'Lagonglong,Lagonlong', 8.8072200, 124.7902800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107200, 'Lagayan', 'Lagayan', 'Lagayan', 17.7208000, 120.7067000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107201, 'Lagawe', 'Lagawe', 'Lagawe', 16.7999700, 121.1192400, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107202, 'Lagasit', 'Lagasit', 'Lagasit', 15.9934000, 120.7940000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107203, 'Lagangilang', 'Lagangilang', 'Lagangilang', 17.6125000, 120.7358000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107204, 'La Fortuna', 'La Fortuna', 'La Fortuna', 8.2797200, 125.0013900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107205, 'La Curva', 'La Curva', 'Curva,La Curva', 12.4048400, 121.0459100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107206, 'Lacson', 'Lacson', '', 7.2119400, 125.4422200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107207, 'Lacdayan', 'Lacdayan', 'Lacdayan', 13.6000000, 122.5333300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107208, 'La Castellana', 'La Castellana', 'La Castellana', 10.3239000, 123.0215000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107209, 'Lacaron', 'Lacaron', 'Lacaron', 11.4220000, 122.7422000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107210, 'Lacaron', 'Lacaron', 'Lacaron,Lakaran', 6.4488900, 125.5791700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107211, 'La Carlota', 'La Carlota', 'Kota La Carlota,La Calota,La Carlota,La Carlota City,La Carlota Lakanbalen,La-Karlota,la karlwta  nygrws ghrby,Ла-Карлота,لا کارلوتا، نیگروس غربی', 10.4242000, 122.9212000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107212, 'Lacag', 'Lacag', 'Lacag', 13.1553000, 123.6812000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107213, 'Labu-o', 'Labu-o', 'Labu-o', 7.1141700, 125.0452800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107214, 'Labuñgan', 'Labungan', 'Labungan,Labuñgan', 7.1030600, 124.2350000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107215, 'Labuan', 'Labuan', '', 7.0997200, 121.9041700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107216, 'Labrador', 'Labrador', 'Labrador,San Isidro Labrador', 16.0281200, 120.1442400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107217, 'Labog', 'Labog', 'Labog', 9.0558000, 118.0495000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107218, 'Labo', 'Labo', 'Labo', 14.1532000, 122.8303000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107219, 'Labnig', 'Labnig', 'Labnig', 13.3769000, 123.6788000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107220, 'Labney', 'Labney', 'Labney', 16.1028000, 120.4655000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107221, 'Labayug', 'Labayug', 'Labayug', 16.1528000, 120.5661000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107222, 'Labason', 'Labason', 'Labasan,Labason', 8.0691700, 122.5216700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107223, 'Labasan', 'Labasan', 'Baasan,Labasan', 12.7773200, 121.4692200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107224, 'Labangan', 'Labangan', 'Labangan', 7.8654000, 123.5123000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107225, 'Kumalisquis', 'Kumalisquis', 'Kumaliskis,Kumalisqui,Kumalisquis', 10.5072600, 123.2030000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107226, 'Kumalarang', 'Kumalarang', 'Kumalarang', 7.7478000, 123.1445000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107227, 'Cumadcad', 'Cumadcad', 'Cumadcad,Kumadcad,Kumadkad', 12.9805600, 123.7891700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107228, 'Kulempang', 'Kulempang', 'Kulempang,Kulumpang', 7.5194400, 124.3897200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107229, 'Culit', 'Culit', 'Culit,Kulit', 8.9472200, 125.3569400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107230, 'Kulay-Kulay', 'Kulay-Kulay', 'Kulay-Kulay', 5.9452800, 121.2325000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107231, 'Kolumbug', 'Kolumbug', 'Kolumbug,Kulambog', 6.5238900, 124.6083300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107232, 'Kulaman', 'Kulaman', 'Kulaman', 6.4594400, 124.0891700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107233, 'Kudanding', 'Kudanding', 'Kudanding', 6.5869400, 124.6230600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107234, 'Kuanos', 'Kuanos', 'Cuanos,Kuanos', 10.2829800, 123.7800000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107235, 'Koronadal', 'Koronadal', 'Koronadal,Koronadal City,Koronadal Lakanbalen,Kota Koronadal,Marbel,ke luo na da er,kolonadal,koronatal,kwrwnadal,کورونادال,கொரொனடால்,科罗纳达尔,코로나달', 6.5030600, 124.8469400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107236, 'Koronadal', 'Koronadal', 'Karonadal,Koronadal,Koronadal Proper', 6.2450100, 124.9874300, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107237, 'Comagascas', 'Comagascas', 'Comagascas,Comagasoan,Komagascas', 9.1397200, 125.5597200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107238, 'Kolape', 'Kolape', 'Kolape,Kularpy,Kulop', 5.0702800, 119.8969400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107239, 'Kolambugan', 'Kolambugan', 'Kolambuang,Kolambugan,Migcamiguing,Migcaniguing', 8.1144000, 123.8971000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107240, 'Cogon', 'Cogon', 'Cogon,Kogon', 10.0372000, 123.4539000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107241, 'Klinan', 'Klinan', 'Clinan,Klinan', 6.1868300, 125.1368400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107242, 'Kiupo', 'Kiupo', 'Kiupa,Kiupo', 5.8416700, 125.3191700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107243, 'Kitobo', 'Kitobo', 'Kitobo,Kitubo', 7.5744400, 125.1050000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107244, 'Kitcharao', 'Kitcharao', 'Kitcharao,Kitcharaw', 9.4550000, 125.5730600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107245, 'Kitapak', 'Kitapak', 'Kitapak,Kitapok', 6.9533300, 124.4255600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107246, 'Kitaotao', 'Kitaotao', 'Kitaotao,Kitawtaw', 7.6397200, 125.0088900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107247, 'Kitango', 'Kitango', 'Kitango', 6.9483300, 124.4411100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107248, 'Kisolon', 'Kisolon', 'Kisolon', 8.3300000, 124.9769400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107249, 'Kisante', 'Kisante', 'Kisante', 6.9230600, 125.1550000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107250, 'Quipot', 'Quipot', 'Kipot,Quipot', 13.7791100, 121.3972200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107251, 'Kipit', 'Kipit', 'Kipit', 8.0461100, 122.5322200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107252, 'Kipalbig', 'Kipalbig', 'Kipalbig', 6.4108300, 124.9250000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107253, 'Kinogitan', 'Kinogitan', '', 8.9855600, 124.7927800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107254, 'Kinangan', 'Kinangan', 'Kinangan', 6.3013900, 125.5850000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107255, 'Kinamayan', 'Kinamayan', 'Kinamayan', 7.4994400, 125.6736100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107256, 'Kinalansan', 'Kinalansan', 'Guinalansan,Kinalansan,Quinalansan', 13.7036000, 123.5531000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107257, 'Kinalaglagan', 'Kinalaglagan', 'Kinalaglagan,Kinalaglagon,Quinalaglagan,Quinalaglagon', 14.0014900, 121.0977200, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107258, 'Kinablangan', 'Kinablangan', 'Kinablangan,Kinablañgan', 7.6928000, 126.5491200, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107259, 'Kinabhangan', 'Kinabhangan', 'Kinabhangan,Kinabhangon,Kinabjangan', 8.9691700, 125.3575000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107260, 'Kimaya', 'Kimaya', 'Kimaya', 8.5647200, 124.8397200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107261, 'Kimanuit', 'Kimanuit', 'Kimanait,Kimanuit', 7.7577800, 124.7336100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107262, 'Kiloloran', 'Kiloloran', 'Kiloloran,Kiloloron,Kilolorum', 14.6357100, 121.6061700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107263, 'Kilim', 'Kilim', 'Kilim', 10.7118000, 124.7968000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107264, 'Kidapawan', 'Kidapawan', 'Kadapawan,Kidapavan,Kidapawan,Kidapawan Lakanbalen,Kota Kidapawan,kidapawan,kydapawan,Кидапаван,کیداپاوان,키다파완', 7.0083300, 125.0894400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107265, 'Kibureau', 'Kibureau', 'Kibureao,Kibureau', 7.6975000, 125.2325000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107266, 'Kibungan', 'Kibungan', 'Kibungan,Kimbunyan', 16.6950000, 120.6553000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107267, 'Kibonsod', 'Kibonsod', 'Kibongsod,Kibonsod', 9.0069400, 125.2094400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107268, 'Kiblawan', 'Kiblawan', 'Kiblagon,Kiblawan', 6.6141700, 125.2366700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107269, 'Kibawe', 'Kibawe', 'Kibawe', 7.5686100, 124.9877800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107270, 'Kibangay', 'Kibangay', 'Kibangay', 8.0497200, 124.8930600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107271, 'Kiangan', 'Kiangan', 'Kiangan', 16.7760700, 121.0858400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107272, 'Kiamba', 'Kiamba', 'Kiamba,Kiamba-Townsite', 5.9894400, 124.6241700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107273, 'Kaytitinga', 'Kaytitinga', 'Kaytitinga', 14.1072200, 120.8291700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107274, 'Kayapa', 'Kayapa', 'Kayapa,Pampang', 16.3592000, 120.8867000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107275, 'Kawit', 'Kawit', 'qwwyt,קוויט', 14.4442600, 120.9016400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107276, 'Kawit', 'Kawit', 'Kawit,Kawit Occidental', 8.1875000, 124.0666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107277, 'Kawayan', 'Kawayan', '', 11.6794400, 124.3566700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107278, 'Cawayan', 'Cawayan', 'Cauayan,Cawayan,Kawayan', 9.8039100, 123.5323600, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107279, 'Kawayan', 'Kawayan', 'Kawayan', 7.5383300, 122.8725000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107280, 'Kauswagan', 'Kauswagan', 'Kauswagan', 8.7897200, 124.7755600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107281, 'Kauswagan', 'Kauswagan', 'Kauswagan', 8.5166700, 125.7500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107282, 'Kauswagan', 'Kauswagan', 'Causwagan,Kauswagan', 8.1916700, 124.0847200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107283, 'Kauran', 'Kauran', 'Kauran', 6.7855600, 124.4733300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107284, 'Katuli', 'Katuli', 'Katuli', 7.4333300, 124.2166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107285, 'Katipunan', 'Katipunan', 'Katipunan,Lubangan', 8.5140000, 123.2829000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107286, 'Katidtuan', 'Katidtuan', 'Catictuan,Catidtuan,Katidtuan', 7.1886100, 124.3152800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107287, 'Katubao', 'Katubao', 'Katabao,Katabau,Katebao,Katubao', 5.8891700, 124.8294400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107288, 'Katangawan', 'Katangawan', '', 6.1722200, 125.2213900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107289, 'Kasibu', 'Kasibu', 'Casibu,Kasibu', 16.3167000, 121.2965000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107290, 'Casay', 'Casay', 'Casay,Kasay,Kasoy', 9.8204000, 123.5496000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107291, 'Karungdong', 'Karungdong', 'Karungdong,Karungdung', 5.8844000, 121.2630000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107292, 'Caromatan', 'Caromatan', 'Caromatan,Karomatan,Kurumatan', 7.7959000, 123.7145000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107293, 'Kaputian', 'Kaputian', '', 6.9658300, 125.7261100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107294, 'Kapinkong', 'Kapinkong', 'Kapingkong,Kapinkang,Kapinkong', 6.6691700, 124.6311100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107295, 'Kapatan', 'Kapatan', 'Kapatan', 5.9005600, 125.2375000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107296, 'Kapatalan', 'Kapatalan', 'Kapatalan', 14.4741000, 121.4903000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107297, 'Kapatagan', 'Kapatagan', 'Kapatagan', 7.9003000, 123.7692000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107298, 'Kapangan', 'Kapangan', 'Kapangan', 16.5746000, 120.5971000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107299, 'Kaongkod', 'Kaongkod', 'Kaongkod', 11.2502800, 123.7555600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107300, 'Kansipati', 'Kansipati', 'Kan Sipat,Kansipati,Seit,Siit', 6.0011100, 121.2344400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107301, 'Kanluran', 'Kanluran', 'Kanluran', 14.4166700, 120.8500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107302, 'Kanlagay', 'Kanlagay', 'Kanlagay', 5.8756800, 121.2914600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107303, 'Kananya', 'Kananya', 'Cananga,Kanaga,Kananga,Kananya', 11.1867000, 124.5601000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107304, 'Kampokpok', 'Kampokpok', 'Campokpok,Kampokpok', 11.2962000, 124.4050000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107305, 'Kambing', 'Kambing', 'Kambing', 5.9464600, 121.3075700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107306, 'Kamanga', 'Kamanga', 'Kamanga', 5.8577800, 125.0561100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107307, 'Kalugmanan', 'Kalugmanan', 'Kalugmanan', 8.2777800, 124.8597200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107308, 'Calumboyan', 'Calumboyan', 'Calumboyan,Kalomboyan', 10.7912900, 124.0274900, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107309, 'Kaliling', 'Kaliling', 'Caliling,Kaliling', 9.9804000, 122.4814000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107310, 'Kalilangan', 'Kalilangan', 'Kalilangan', 7.8211100, 124.7313900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107311, 'Kalibo (poblacion)', 'Kalibo (poblacion)', 'Banwa it Kalibo,KLO,Kalibo,Kalibo Town,Pueblo de Calivo,Калибо', 11.7061100, 122.3644400, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107312, 'Kalian', 'Kalian', 'Calian,Kalian', 6.1230600, 125.7002800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107313, 'Kalbugan', 'Kalbugan', 'Kalbugan,Kalbungan', 6.9597200, 124.6591700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107314, 'Kalbay', 'Kalbay', 'Kalbay', 5.7233300, 125.4986100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107315, 'Kalayaan', 'Kalayaan', 'Kalavaan,Kalayaan', 14.3500000, 121.5666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107316, 'Kalawit', 'Kalawit', 'Kalawit', 8.0666700, 122.5166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107317, 'Kalaisan', 'Kalaisan', 'Kalaisan,Kalasuyan', 7.0102800, 125.0450000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107318, 'Kalanganan', 'Kalanganan', 'Kalanganan', 8.0833300, 124.2466700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107319, 'Kalandagan', 'Kalandagan', 'Kalandagan', 6.6786100, 124.7233300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107320, 'Kalamansig', 'Kalamansig', 'Calamansig,Kalamansig', 6.5518700, 124.0511100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107321, 'Kalamangog', 'Kalamangog', 'Kalamangog', 6.7255600, 124.0688900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107322, 'Kagay', 'Kagay', 'Kagay', 6.0088000, 120.9074000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107323, 'Kadingilan', 'Kadingilan', 'Kadangilan,Kadañgilan,Kadingelan,Kadingilan,Kandingilan,Kandingilán', 7.6011100, 124.9086100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107324, 'Kabuynan', 'Kabuynan', 'Cabuynan,Kaboynan,Kabuynan', 11.0805600, 125.0247200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107325, 'Kabungahan', 'Kabungahan', 'Cabungahan,Kabungahan', 10.5166700, 123.9833300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107326, 'Kabulusan', 'Kabulusan', 'Kabulusan', 14.3615000, 121.4004000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107327, 'Kabulohan', 'Kabulohan', 'Cabulohan,Kabulohan', 8.0433300, 125.2766700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107328, 'Kabugao', 'Kabugao', 'Kabugao,kabwgaw  apayaw,کابوگاؤ، اپایاؤ', 18.0169800, 121.1817300, 'PH', '2015-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107329, 'Kabasalan', 'Kabasalan', '', 7.7972200, 122.7650000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107330, 'Kabasalan', 'Kabasalan', 'Kabasalan', 7.0666700, 124.6500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107331, 'Kabankalan', 'Kabankalan', 'Kabankalan', 9.9839000, 122.8142300, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107332, 'Kabalen', 'Kabalen', 'Kabalen,Kablen,Kablon', 6.3194400, 125.0105600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107333, 'Kabalantian', 'Kabalantian', 'Cabalantian,Kabalantian', 8.3708300, 124.3275000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107334, 'Kabacan', 'Kabacan', 'Kabacan,Kabakan', 7.1066700, 124.8291700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107335, 'Casuguran', 'Casuguran', 'Casiguran', 14.7167000, 122.3742200, 'PH', '2014-09-24', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107336, 'Julita', 'Julita', '', 10.9747200, 124.9616700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107337, 'Jugno', 'Jugno', 'Jugno', 9.4683000, 123.2038000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107338, 'Tugas', 'Tugas', 'Jugas,Tugas', 11.6130000, 122.3822000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107339, 'Jubasan', 'Jubasan', 'Hubasan,Jubasan', 12.4844000, 124.2872000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107340, 'Juban', 'Juban', 'Juban', 12.8477800, 123.9877800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107341, 'Jovellar', 'Jovellar', 'Jovellar', 13.0695000, 123.5999000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107342, 'Jovellar', 'Jovellar', 'Jovellar,Jovellari', 7.0635000, 126.4555800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107343, 'Jose Pañganiban', 'Jose Panganiban', 'Jose Panganiban,Jose Pañganiban,Mambulao', 14.2906000, 122.6917000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107344, 'Josefina', 'Josefina', '', 8.2000000, 123.5333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107345, 'Joroan', 'Joroan', 'Horoan,Joroan', 13.4885000, 123.6189000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107346, 'Jordan', 'Jordan', 'Jordan,Oracion,Oracon', 10.6583600, 122.5963000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107347, 'Jones', 'Jones', 'Cabanuangan,Jones', 16.5571000, 121.7029000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107348, 'Jolo', 'Jolo', 'Dzholi,JOL,Jolo,Joló,Kholo,Sug,Sulu,Suluk,hollo,horo,jwlw  swlw,Джоли,Холо,جولو، سولو,ホロ,홀로', 6.0522200, 121.0022200, 'PH', '2016-12-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107349, 'Hipadpad', 'Hipadpad', 'Hipadpad,Jewaran,Jipapad', 12.2855000, 125.2361000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107350, 'Jimenez', 'Jimenez', 'Jimenez,Jimenez de Misamis,Jiménez de Misamis', 8.3365000, 123.8383000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107351, 'Jimalalud', 'Jimalalud', 'Jimalalua,Jimalalud', 9.9797000, 123.1999000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107352, 'Jibao-an', 'Jibao-an', 'Jebaoan,Jibao-an', 10.7833300, 122.5000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107353, 'Jiabong', 'Jiabong', 'Jiabong,Malubago', 11.7625000, 124.9519400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107354, 'Jetafe', 'Jetafe', 'Getafe,Jetafe,Jetape', 10.1472200, 124.1538900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107355, 'Jayubó', 'Jayubo', 'Jayubo,Jayubó', 11.0500000, 122.3833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107356, 'Bugho', 'Bugho', 'Bugho,Bugno,Javier', 10.7921000, 124.9364000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107357, 'Javier', 'Javier', 'Javier', 8.4888900, 126.0850000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107358, 'Javalera', 'Javalera', 'Jalavera,Javalera', 14.2581300, 120.9155800, 'PH', '2013-11-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107359, 'Jasaan', 'Jasaan', 'Hasaan,Jaman,Jamán,Jasaan,جسان، مسمس ورئیینٹل', 8.6541700, 124.7555600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107360, 'Jaro', 'Jaro', 'Jaro', 11.1837500, 124.7826700, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107361, 'Japitan', 'Japitan', 'Apitan,Japitan', 10.7652400, 123.5444000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107362, 'Japitan', 'Japitan', 'Hapitan,Japitan', 10.1279000, 123.5035000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107363, 'Jantianon', 'Jantianon', 'Jantianon', 9.4442000, 123.1657000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107364, 'Janopol', 'Janopol', 'Janopol', 14.0858600, 121.0948900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107365, 'Janiuay', 'Janiuay', 'Janiuay,جانے، الویلو', 10.9493000, 122.5061000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107366, 'Jandayan Norte', 'Jandayan Norte', 'Jandayan,Jandayan Norte', 10.1685200, 124.1814800, 'PH', '2016-11-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107367, 'Janagdong', 'Janagdong', 'Janagdong', 13.9034000, 121.5134000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107368, 'Jampang', 'Jampang', 'Hampang,Jampang,Jampano', 9.9076100, 123.6001500, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107369, 'Hamoraon', 'Hamoraon', 'Hamoraon,Jamoraon,Jamorawon', 12.2256400, 123.5515100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107370, 'Jamindan', 'Jamindan', 'Jamindan', 11.4002300, 122.4983300, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107371, 'Jamabalod', 'Jamabalod', 'Jamabalod,Jamabalud', 10.8788000, 122.6212000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107372, 'Jalaud', 'Jalaud', 'Jalaud,Jalauod', 10.8933300, 122.7475000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107373, 'Jalaud', 'Jalaud', 'Banga Bante,Jalaud,Jalauod,Jalavod,Jaliaud', 10.8436000, 122.6404000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107374, 'Jalajala', 'Jalajala', 'Jalajala', 14.3530000, 121.3225000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107375, 'Jagupit', 'Jagupit', 'Jagupit', 9.2422200, 125.5580600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107376, 'Jaguimitan', 'Jaguimitan', 'Haguimitan,Jaguimitan', 11.1400000, 122.7236000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107377, 'Jagna', 'Jagna', 'Iagna,Jagna', 9.6531000, 124.3697000, 'PH', '2015-04-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107378, 'Jaena', 'Jaena', 'Jaena', 11.4166700, 122.4000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107379, 'Jaen', 'Jaen', 'Jaen,Khaehn,Хаэн', 15.3275000, 120.9192000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107380, 'Jaclupan', 'Jaclupan', 'Jaclupan', 10.3013800, 123.8165000, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107381, 'Jabonga', 'Jabonga', 'Jabonga', 9.3430600, 125.5155600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107382, 'Ivisan', 'Ivisan', 'Iuisan,Ivisan,Ivison', 11.5216700, 122.6908300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107383, 'Ivana', 'Ivana', 'Ivana', 20.3700500, 121.9145700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107384, 'Itogon', 'Itogon', 'Itogon', 16.3638900, 120.6769400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107385, 'Itbayat', 'Itbayat', 'Itabayat,Itbayat,Mayan', 20.7873300, 121.8417700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107386, 'Isulan', 'Isulan', 'Isulan,Kalawag,aswlan  sltan qdrt,اسولان، سلطان قدرت', 6.6294400, 124.6050000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107387, 'Isugod', 'Isugod', 'Isugod', 9.3407700, 118.1196000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107388, 'Isla', 'Isla', 'Isla', 15.8950700, 120.3013700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107389, 'Isabela', 'Isabela', 'Isabela,Isabella,Izabela,Изабела', 10.2048000, 122.9888000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107390, 'City of Isabela', 'City of Isabela', 'Basilan,Basilan City,City of Isabela,Isabel,Isabela,Isabela City,Izabela,Lungsod ng Isabela,Municipality of Isabela,Изабела', 6.7040700, 121.9711700, 'PH', '2012-07-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107391, 'Isabel', 'Isabel', 'Isabel,Quiot', 10.9267000, 124.4340000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107392, 'Isabang', 'Isabang', '', 13.9569400, 121.5708300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107393, 'Irosin', 'Irosin', 'Irosin', 12.7001300, 124.0322100, 'PH', '2014-09-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107394, 'Irirum', 'Irirum', 'Iriron,Irirum,Irirun', 12.6160300, 120.9306100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107395, 'Iriga City', 'Iriga City', 'Iriga,Iriga City', 13.4324000, 123.4115000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107396, 'Iraya', 'Iraya', 'Iraya', 13.2500000, 123.5166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107397, 'Irasan', 'Irasan', 'Irasan', 8.5260000, 123.2060000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107398, 'Iraray', 'Iraray', 'Iraray', 8.9936100, 118.0511100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107399, 'Irahuan', 'Irahuan', 'Irawan', 9.8079800, 118.6919100, 'PH', '2014-11-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107400, 'Iraga', 'Iraga', 'Iraga', 17.7015000, 121.6546000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107401, 'Ipilan', 'Ipilan', 'Ipilan', 8.8430600, 117.9033300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107402, 'Ipil', 'Ipil', 'Ipil', 13.5132000, 121.9841000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107403, 'Ipil', 'Ipil', '', 10.9747200, 124.6363900, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107404, 'Ipil', 'Ipil', 'Ipil', 9.7907000, 125.4386000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107405, 'Ipil', 'Ipil', 'IPE,Ipil,Sanito,Tayun', 7.7844400, 122.5861100, 'PH', '2013-05-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107406, 'Inobulan', 'Inobulan', 'Inobulan,Inubolan', 8.8863900, 124.7947200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107407, 'Intampilan', 'Intampilan', 'Intampilan', 11.4813000, 122.7434000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107408, 'Initao', 'Initao', 'Inatao,Initao', 8.4997200, 124.3038900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107409, 'Inicbulan', 'Inicbulan', 'Inicbulan', 13.8204300, 120.9834500, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107410, 'Infanta', 'Infanta', 'Infanta', 15.8264000, 119.9077000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107411, 'Infanta', 'Infanta', 'Infanta', 14.7449500, 121.6495300, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107412, 'Ineangan', 'Ineangan', 'Ineangan', 16.3181000, 121.0930000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107413, 'Indulang', 'Indulang', 'Indulang', 8.0902800, 124.5844400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107414, 'Indang', 'Indang', '', 14.1952800, 120.8769400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107415, 'Inayauan', 'Inayauan', 'Inayauan,Inayawan', 9.9005000, 122.4340000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107416, 'Inayagan', 'Inayagan', 'Inayagan', 10.2347800, 123.7690000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107417, 'Inawayan', 'Inawayan', 'Inauayan,Inawayan', 6.9608300, 125.4733300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107418, 'Inapatan', 'Inapatan', 'Inapatan', 13.3964000, 123.3227000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107419, 'Inangatan', 'Inangatan', 'Inangatan', 11.2500000, 124.4000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107420, 'Inabanga', 'Inabanga', 'Inabanga', 10.0307000, 124.0671000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107421, 'Inabaan Sur', 'Inabaan Sur', 'Inabaan,Inabaan Sur', 16.2630000, 120.4781000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107422, 'Imus', 'Imus', 'Imus,Imus Lakanbalen,Lungsod ng Imus,amws,Имус,اموس', 14.4297200, 120.9366700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107423, 'Impalutao', 'Impalutao', 'Impalutao,Impulatao', 8.2577800, 125.0275000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107424, 'Imelda', 'Imelda', 'Imelda', 14.0333300, 122.8833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107425, 'Imelda', 'Imelda', 'Imelda', 7.6470300, 122.9534900, 'PH', '2017-01-28', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107426, 'Imbatug', 'Imbatug', 'Imbatug', 8.0544400, 125.2838900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107427, 'Imbang', 'Imbang', 'Imbang', 10.7967000, 123.0213000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107428, 'Iloilo', 'Iloilo', 'ILO,Iloilo,Iloilo City,Iloilo Proper,Илоило', 10.6969400, 122.5644400, 'PH', '2017-07-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107429, 'Ilog', 'Ilog', 'Ilog', 10.0266000, 122.7684000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107430, 'Ilioilio', 'Ilioilio', 'Ilioilio,Ollio-ilio', 15.9616000, 119.7658000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107431, 'Ilihan', 'Ilihan', 'Ilihan,Ilijan', 13.6310000, 121.0709000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107432, 'Ilihan', 'Ilihan', 'Ilihan', 10.9054000, 123.9704000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107433, 'Iligan City', 'Iligan City', 'City of Iligan,Idigan,Iligan', 8.2500000, 124.4000000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107434, 'Iligan', 'Iligan', 'Dakbayan sa Iligan,IGN,Iligan City,Iligan Lakanbalen,Lungsod ng Iligan,illigan,irigan,yi li gan,イリガン,伊利甘,일리간', 8.2289000, 124.2434400, 'PH', '2015-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107435, 'Ilaya', 'Ilaya', 'Ilaya,Llaya,Ylaya', 8.5459000, 123.4308000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107436, 'Ilangay', 'Ilangay', 'Ilangay,Ilañgay', 6.9128400, 126.0500800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107437, 'Ilagan', 'Ilagan', 'Ilagan,alagan,Илаган,الاگان', 17.1485400, 121.8892400, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107438, 'Iguig', 'Iguig', 'Iguig', 17.7506000, 121.7364500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107439, 'Igpit', 'Igpit', 'Igpit', 8.5108300, 124.5866700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107440, 'Ignit', 'Ignit', 'Ignit,Igpit', 6.7008300, 125.2919400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107441, 'Igmaya-an', 'Igmaya-an', 'Igmaya-an', 10.5498600, 123.2206000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107442, 'Igcocolo', 'Igcocolo', 'Igcocolo', 10.6896600, 122.3193000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107443, 'Igbon', 'Igbon', 'Igbon', 11.2142000, 123.1655000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107444, 'Igbaras', 'Igbaras', 'Igbaras', 10.7156500, 122.2657000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107445, 'Igang', 'Igang', 'Igang', 10.9160000, 122.6388000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107446, 'Idtig', 'Idtig', 'Idtig,Itig', 6.7988900, 124.7727800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107447, 'Idio', 'Idio', 'Idio', 11.6238000, 122.0979000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107448, 'Ichon', 'Ichon', 'Ichon', 10.0949500, 124.9016800, 'PH', '2012-06-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107449, 'Ibarra', 'Ibarra', 'Ibarra', 10.1247200, 124.8841700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107450, 'Ibajay', 'Ibajay', 'Ibajay', 11.8199000, 122.1620000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107451, 'Yuni', 'Yuni', 'Ibabang Yuni,Yuni', 13.4124000, 122.4846000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107452, 'Ibabang Tayuman', 'Ibabang Tayuman', 'Ibabang Tayuman', 13.4042000, 122.5165000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107453, 'Ibaan', 'Ibaan', 'Ibaan', 13.8176000, 121.1330000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107454, 'Iba', 'Iba', 'Iba', 15.4539200, 120.4104800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107455, 'Iba', 'Iba', 'Iba,Ibra,ayba  zambalys,iba,yi ba,Ибра,ایبا، زامبالیس,イバ,伊巴,이바', 15.3276000, 119.9780000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107456, 'Hukay', 'Hukay', 'Hukay', 13.8451900, 120.7028700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107457, 'Hondagua', 'Hondagua', 'Bagacay,Hondagua,Hondagua Bagacay', 13.9455000, 122.2417000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107458, 'Hobo', 'Hobo', 'Hobo,Hubo,Ubo', 13.5101000, 123.1792000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107459, 'Hipasngo', 'Hipasngo', 'Hipasngo,Hiposngo,HipusNgo', 10.6624000, 124.8085000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107460, 'Hipona', 'Hipona', 'Hipona', 11.4174000, 122.8825000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107461, 'Hinundayan', 'Hinundayan', 'Hinundayan', 10.3523000, 125.2506000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107462, 'Hinunangan', 'Hinunangan', 'Hinunangan', 10.3940800, 125.1976800, 'PH', '2013-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107463, 'Hinlayagan Ilaud', 'Hinlayagan Ilaud', 'Hinlayagan,Hinlayagan Ilaud', 10.0306100, 124.3345700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107464, 'Hinigaran', 'Hinigaran', 'Hinigaran', 10.2706000, 122.8507000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107465, 'Hingatungan', 'Hingatungan', 'Hinatungan,Hingatungan', 10.5840000, 125.1852000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107466, 'Hindang', 'Hindang', '', 10.4341700, 124.7291700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107467, 'Hinatuan', 'Hinatuan', 'Hinatuan', 8.3722200, 126.3341700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107468, 'Hinapalanan', 'Hinapalanan', 'Hinapalanan,Hinaplanan', 8.6402800, 124.8730600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107469, 'Himensulan', 'Himensulan', 'Himensulan', 10.5967000, 124.2821000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107470, 'Himaya', 'Himaya', 'Himaya', 10.4516000, 122.8325000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107471, 'Gimampang', 'Gimampang', 'Gimampang,Gimangpang,Gumampang,Himangpang', 8.4713900, 124.2966700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107472, 'Himamaylan', 'Himamaylan', '', 10.0988900, 122.8705600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107473, 'Himaao', 'Himaao', 'Himaao,Himado,Imaao', 13.5448000, 123.3005000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107474, 'Hilotongan', 'Hilotongan', 'Gilutongan,Hilotongan,Hilutangan,Lutungan', 11.1440000, 123.6426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107475, 'Hilongos', 'Hilongos', 'Hilongos', 10.3744400, 124.7497200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107476, 'Hiju, Maco', 'Hiju, Maco', 'Hijo,Hiju', 7.3854100, 125.8282200, 'PH', '2015-04-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107477, 'Hibaiyo', 'Hibaiyo', 'Hibaiyo,Jibayo', 10.2726000, 123.3210000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107478, 'Herrera', 'Herrera', 'Herrera', 13.2693000, 123.5769000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107479, 'Hernani', 'Hernani', 'Barrto,Hernani', 11.3258300, 125.6194400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107480, 'Hermosa', 'Hermosa', 'Ehrmosa,Hermosa,Эрмоса', 14.8314000, 120.5081000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107481, 'Harrison', 'Harrison', 'Harrison', 13.4500000, 120.4333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107482, 'Jarigue', 'Jarigue', 'Arigi,Haregue,Harigue,Jarigue', 11.8653800, 121.4404100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107483, 'Hapao', 'Hapao', 'Hapao', 16.8796600, 121.0160400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107484, 'Hamtic', 'Hamtic', 'Antique,Hamtic,Hamtik', 10.7023000, 121.9824000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107485, 'Halog West', 'Halog West', 'Halog,Halog West', 16.3668000, 120.4147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107486, 'Haligue', 'Haligue', 'Haligue', 13.6666700, 121.1166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107487, 'Halayhayin', 'Halayhayin', 'Halayhayin', 14.1891000, 121.4075000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107488, 'Halayhay', 'Halayhay', 'Halayhay', 14.3738900, 120.8133300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107489, 'Halapitan', 'Halapitan', 'Halapitan', 7.9175000, 125.3300000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107490, 'Haguimit', 'Haguimit', 'Haguimit', 10.3999000, 123.0178000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107491, 'Hagonoy', 'Hagonoy', 'Hagonoy,Hagony,Hagunoy', 14.8341300, 120.7327100, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107492, 'Hagonoy', 'Hagonoy', 'Hagonoy', 6.6833300, 125.3255600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107493, 'Hagnaya', 'Hagnaya', 'Hagnaya', 11.0924000, 123.9435000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107494, 'Hagdan', 'Hagdan', 'Hagdan,Jagtan', 11.3333300, 123.9000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107495, 'Dolores', 'Dolores', 'Dolores,Hacienda Dolores', 15.0949800, 120.5288900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107496, 'Hacienda', 'Hacienda', 'Hacienda', 15.9360000, 120.1786000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107497, 'Guyong', 'Guyong', 'Guyong', 14.8361000, 120.9784400, 'PH', '2014-02-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107498, 'Guyam Malaki', 'Guyam Malaki', 'Guyam,Guyam Malaki', 14.1525000, 120.8611100, 'PH', '2013-12-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107499, 'Gutalac', 'Gutalac', 'Gutalac', 7.9825000, 122.4047200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107500, 'Gutad', 'Gutad', 'Gutad', 14.9274000, 120.4894000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107501, 'Guruyan', 'Guruyan', 'Goroyan,Guruyan', 12.7388900, 123.9391700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107502, 'Gupitan', 'Gupitan', 'Bubonao,Gupitan', 7.7758300, 125.6405600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107503, 'Gumian', 'Gumian', 'Gomian,Gumian,Gumilan', 14.7100600, 121.6186700, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107504, 'Gumaus', 'Gumaus', 'Gumaus', 14.3103000, 122.7229000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107505, 'Gumalang', 'Gumalang', '', 7.2083300, 125.4036100, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107506, 'Gumaca', 'Gumaca', 'Gumaca', 13.9210000, 122.1002000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107507, 'Gulod', 'Gulod', 'Gulod', 13.8751400, 120.6335900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107508, 'Guiwanon', 'Guiwanon', 'Guiwanon', 11.1975000, 123.7080000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107509, 'Guiuan', 'Guiuan', 'Guian,Guinan,Guiuan', 11.0308800, 125.7234200, 'PH', '2014-11-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107510, 'Guisijan', 'Guisijan', 'Guisihan,Guisijan', 11.0932000, 122.0461000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107511, 'Guisguis', 'Guisguis', 'Guisguis', 15.7928000, 119.9766000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107512, 'Guisguis', 'Guisguis', 'Guisguis', 13.8738000, 121.5189000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107513, 'Guiset East', 'Guiset East', 'Guiset,Guiset East,Guiset Este,Guiset Sur', 16.0666700, 120.6833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107514, 'Guirang', 'Guirang', 'Guirang', 11.3500000, 125.1166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107515, 'Guipos', 'Guipos', 'Guipas,Guipos', 7.7161000, 123.3219000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107516, 'Guiong', 'Guiong', 'Geong,Giong,Guiong', 6.4186100, 122.0258300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107517, 'Giawang', 'Giawang', 'Giawang,Giwang,Guio-ang', 9.7922000, 124.5090000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107518, 'Guintubhan', 'Guintubhan', 'Guintubhan,Guitubhan', 10.2074000, 122.9627000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107519, 'Guinticgan', 'Guinticgan', 'Guinticgan', 11.5641000, 123.1236000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107520, 'Guinisiliban', 'Guinisiliban', 'Ginsiliban,Guinciliban,Guinisiliban,Guinsilban,Guinsiliban', 9.0963900, 124.7827800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107521, 'Guinsang-an', 'Guinsang-an', 'Guinsang-an', 6.4800000, 124.6805600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107522, 'Guinsadan', 'Guinsadan', 'Guinsadan,Guinzaden', 16.9642000, 120.8680000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107523, 'Guinobatan', 'Guinobatan', 'Guinobatan', 13.1913000, 123.5987000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107524, 'Guinlo', 'Guinlo', 'Guinlo,New Guinlo', 10.8009000, 119.4383000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107525, 'Guindulman', 'Guindulman', 'Guindulman', 9.7629000, 124.4878000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107526, 'Guindarohan', 'Guindarohan', '', 10.2611100, 123.7655600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107527, 'Guindapunan', 'Guindapunan', 'Guindapunan', 11.3027800, 124.7058300, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107528, 'Guinoaliuan', 'Guinoaliuan', 'Guinbaliuan,Guinbaliwan,Guinoaliuan', 11.6576000, 122.3851000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107529, 'Guinayangan, Fourth District of Quezon', 'Guinayangan, Fourth District of Quezon', 'Guinayangan', 13.9002000, 122.4480800, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107530, 'Guinabsan', 'Guinabsan', 'Guinabsan,Guinapsan', 8.8975000, 125.4161100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107531, 'Guinacotan', 'Guinacotan', 'Ginacutan,Guinacotan,Guinacutan', 14.1569000, 122.8680000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107532, 'Guimbal', 'Guimbal', 'Guimbal', 10.6633000, 122.3228000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107533, 'Guimba', 'Guimba', 'Guimba', 15.6605000, 120.7683000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107534, 'Guiljungan', 'Guiljungan', 'Guiljungan,Guinjungan', 9.9805000, 122.6742000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107535, 'Guiling', 'Guiling', 'Guiling,Quiling', 15.8429500, 120.6151300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107536, 'Guijalo', 'Guijalo', 'Guijalo', 13.7373000, 123.8680000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107537, 'Guihulñgan', 'Guihulngan', 'Gihulngan,Guihulngan,Guihulñgan,Guilhulngan,Gulhulngan', 10.1214000, 123.2742000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107538, 'Guihing Proper', 'Guihing Proper', 'Guihing,Guihing Proper', 6.6844400, 125.3525000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107539, 'Guiguinto', 'Guiguinto', 'Guiguinto', 14.8333300, 120.8833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107540, 'Guiddam', 'Guiddam', 'Guiddam', 18.3349300, 121.4661700, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107541, 'Guibodangan', 'Guibodangan', 'Gibuangan,Guiboangan,Guibodangan,Guibuangan', 10.1157000, 123.4944000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107542, 'Gueset', 'Gueset', 'Gueset', 15.9500000, 120.6333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107543, 'Gubat', 'Gubat', 'Gubat', 12.9205600, 124.1230600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107544, 'Guba', 'Guba', 'Guba', 10.3131000, 123.2667000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107545, 'Guagua', 'Guagua', 'Guagua', 14.9653000, 120.6325000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107546, 'Guadalupe', 'Guadalupe', 'Guadalupe', 11.0044400, 124.0138900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107547, 'Guadalupe', 'Guadalupe', 'Guadalupe', 10.4544700, 123.3732000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107548, 'Guadalupe', 'Guadalupe', 'Guadalupe,Guadelupe', 10.1165000, 123.6072000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107549, 'Guadalupe', 'Guadalupe', 'Guadalupe', 9.7236000, 123.4018000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107550, 'Guadalupe', 'Guadalupe', 'Guadalupe', 8.5827800, 125.7080600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107551, 'Gregorio del Pilar', 'Gregorio del Pilar', 'Concepcion,Gregorio del Pilar', 17.1302800, 120.6119400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107552, 'Granada', 'Granada', 'Granada', 11.6333300, 123.3500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107553, 'Sigaboy', 'Sigaboy', 'Govenor Generoso,Governor Generoso,Jigabay,Segaboy,Sigaboy,Surup', 6.6541300, 126.0726800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107554, 'Gonzaga', 'Gonzaga', 'Gonzaga', 18.2593700, 121.9949500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107555, 'Goma', 'Goma', 'Goma,Guma', 6.7919400, 125.3208300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107556, 'Gocoton', 'Gocoton', 'Gocotan,Gocoton,Gokotan', 7.1561100, 124.6911100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107557, 'Goa', 'Goa', 'Goa,Гоа', 13.6978000, 123.4892000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107558, 'Gloria', 'Gloria', 'Gloria', 12.9833300, 121.4666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107559, 'Glan Peidu', 'Glan Peidu', 'Glan Padido,Glan Padidu,Glan Peidu,Sinabulad,Sinabulado', 5.8550000, 125.2186100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107560, 'Glan', 'Glan', 'Glan,Glan-Townsite,Глан', 5.8241700, 125.2033300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107561, 'Glamang', 'Glamang', 'Glamang', 6.1625500, 125.0839200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107562, 'Glad', 'Glad', 'Glad', 7.1483300, 124.5180600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107563, 'Gitagum', 'Gitagum', 'Gitagum,Gitagun,Hitagum', 8.5966700, 124.4063900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107564, 'Giporlos', 'Giporlos', 'Giporlos', 11.1200000, 125.4494400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107565, 'Gines-Patay', 'Gines-Patay', 'Gines,Gines-Patay', 10.9357000, 122.4932000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107566, 'Ginatilan', 'Ginatilan', 'Ginatilan,Ginatlian', 9.5694000, 123.3128000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107567, 'Ginabuyan', 'Ginabuyan', 'Ginabuyan,Hinabuyan,Jinabuyan', 11.2383000, 124.4047000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107568, 'Hilantagaan', 'Hilantagaan', 'Cabaliod,Caballod,Gilantagaan,Hilantagaan', 11.1943000, 123.8131000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107569, 'Gigmoto', 'Gigmoto', 'Gigmoto', 13.7796000, 124.3900000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107570, 'Gigaquit', 'Gigaquit', 'Gigaquit', 9.5944400, 125.6975000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107571, 'Gibong', 'Gibong', 'Gibon,Gibong,Hibung,Hibung Town', 11.8633800, 122.0394100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107572, 'Gibgos', 'Gibgos', 'Gibgos,Hibgos', 13.8590000, 123.7675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107573, 'Gibato', 'Gibato', 'Gibato', 11.2251000, 122.8143000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107574, 'Getulio', 'Getulio', 'Gelulio,Getulio', 10.7470000, 122.6660000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107575, 'Gerona', 'Gerona', 'Gerona,Zherona,Жерона', 15.6065000, 120.5978000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107576, 'General Trias', 'General Trias', 'General Trias Lakanbalen,Heneral Trias', 14.3869400, 120.8816700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107577, 'General Tinio', 'General Tinio', 'General Tinio,Papaya', 15.3507500, 121.0477300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107578, 'General Santos', 'General Santos', 'Dadiangas,Dakbayan sa General Santos,GES,General Santos City,General Santos Lakanbalen,General-Santos,Heneral Santos,Kota General Santos,Siyudad na Heneral Santos,jeneoleolsantoseu,jnral santws,jnrl santws,san tou si jiang jun shi,Генерал-Сантос,جنرال سانتوس,جنرل سانتوس,ジェネラル・サントス,三投斯將軍市,제너럴산토스', 6.1127800, 125.1716700, 'PH', '2016-06-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107579, 'General Nakar', 'General Nakar', 'General Nakar,Pamplona', 14.7636500, 121.6355900, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107580, 'General Mamerto Natividad', 'General Mamerto Natividad', 'General Mamerto Natividad,General Natividad,Natividad', 15.6025000, 121.0515000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107581, 'General MacArthur', 'General MacArthur', 'General MacArthur,General McArthur,Hermani,Hernani,Pambuhan Sur,Pambujan Sur,Paonbiyan Sur', 11.2463900, 125.5394400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107582, 'General Luna', 'General Luna', 'General Luna', 15.7306000, 121.1791000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107583, 'General Luna', 'General Luna', 'General Luna,Hingosa,Hingoso', 13.6866000, 122.1709000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107584, 'General Luna', 'General Luna', 'Cabuntog,Cabuntug,General Luna', 9.7841700, 126.1588900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107585, 'General Emilio Aguinaldo', 'General Emilio Aguinaldo', 'Bailen,General Emilio Aguinaldo', 14.1841700, 120.7958300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107586, 'Gayaman', 'Gayaman', 'Gayaman', 16.0140200, 120.3075700, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107587, 'Gattaran', 'Gattaran', 'Gattaran', 18.0615700, 121.6441000, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107588, 'Gatbo', 'Gatbo', 'Gatbo,Gatho', 13.5833300, 123.3833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107589, 'Gasan', 'Gasan', 'Gasan', 13.3237200, 121.8467500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107590, 'Garcia Hernandez', 'Garcia Hernandez', 'Garcia,Garcia Hernandez', 9.6144000, 124.2946000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107591, 'Garchitorena', 'Garchitorena', 'Anderson,Garchitorena', 13.8804000, 123.6946000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107592, 'Gappal', 'Gappal', 'Cappal,Gappal', 16.8364600, 121.8218400, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107593, 'Gapan', 'Gapan', 'Capan,Gapan', 15.3072000, 120.9464000, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107594, 'Ganyangan', 'Ganyangan', 'Gandiangan,Ganyangan,Ganyangan Junction', 7.6788900, 122.9094400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107595, 'Gansing', 'Gansing', 'Gansing', 6.7402800, 124.6588900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107596, 'Gang', 'Gang', 'Gang', 7.2458300, 124.2663900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107597, 'Gandara', 'Gandara', 'Gandara,Gandara Village', 12.0130000, 124.8118000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107598, 'Ganassi', 'Ganassi', 'Ganasi,Ganassi', 7.8269400, 124.1034400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107599, 'Gamut', 'Gamut', 'Gamut', 9.0044400, 126.1697200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107600, 'Gamut', 'Gamut', 'Gamut,Gamuton,Ganut', 8.5315300, 126.2411700, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107601, 'Gamu', 'Gamu', 'Gamu', 17.0497500, 121.8360400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107602, 'Gammad', 'Gammad', 'Gammad,Gammad Norte', 17.7104000, 121.7437000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107603, 'Gambang', 'Gambang', 'Gambang', 16.7500000, 120.7833000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107604, 'Gamay', 'Gamay', 'Gamay', 12.3854200, 125.2979100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107605, 'Galimuyod', 'Galimuyod', 'Galimuyad,Galimuyod', 17.1844400, 120.4719400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107606, 'Gainza', 'Gainza', 'Gainza', 13.6165000, 123.1419000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107607, 'Gadung', 'Gadung', 'Gadung', 6.8025000, 124.0200000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107608, 'Gadu', 'Gadu', 'Gadu', 17.6292000, 121.6105000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107609, 'Gabuyan', 'Gabuyan', 'Gabuyan', 7.6080600, 125.6688900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107610, 'Gabi', 'Gabi', 'Gabi Norte,Gabi Sur', 10.2630600, 123.9613900, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107611, 'Gabi', 'Gabi', 'Gabi', 11.5956000, 123.3376000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107612, 'Gabi', 'Gabi', 'Gabi', 7.6215000, 126.0920000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107613, 'Gabawan', 'Gabawan', 'Gabauan,Gabawan', 12.4271400, 122.0133200, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107614, 'Gabas', 'Gabas', 'Gabas', 10.7297000, 124.7961000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107615, 'Gabao', 'Gabao', 'Gabao,Gatbo', 12.9924000, 124.0169000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107616, 'Gabao', 'Gabao', 'Gabao', 12.7270900, 123.9783500, 'PH', '2014-09-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107617, 'Gabaldon', 'Gabaldon', 'Gabaldon', 15.4522000, 121.3387000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107618, 'Furao', 'Furao', 'Furao', 17.0346600, 121.7968900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107619, 'Fuerte', 'Fuerte', 'Feurte,Fuarte,Fuerte', 17.5341800, 120.3695000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107620, 'Floridablanca', 'Floridablanca', 'Floridablanca', 14.9775000, 120.5285000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107621, 'Flora', 'Flora', 'Flora', 18.2163000, 121.4185000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107622, 'Ferrol', 'Ferrol', 'Ferrol', 12.3383300, 121.9413900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107623, 'Feliciano', 'Feliciano', 'Feliciano', 11.5787000, 122.3583000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107624, 'Famy', 'Famy', 'Famy', 14.4376000, 121.4482000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107625, 'Fabrica', 'Fabrica', 'Fabrica', 13.4900000, 123.2940000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107626, 'Evangelista', 'Evangelista', 'Evangelista', 13.3335000, 121.0972000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107627, 'Eustaquio Lopez', 'Eustaquio Lopez', 'Eustapuio Lopez,Eustaquio Lopez,Lopez', 10.8195000, 123.0412000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107628, 'Estrella', 'Estrella', 'Estrella', 15.7500000, 121.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107629, 'Estrella', 'Estrella', 'Estrella', 13.3289800, 121.3109200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107630, 'Estipona', 'Estipona', 'Estipona', 15.5902000, 120.6377000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107631, 'Estefania', 'Estefania', 'Estafania,Estefania', 17.7995200, 121.7231000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107632, 'Estancia', 'Estancia', 'Estancia', 13.3589000, 123.6796000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107633, 'Estancia', 'Estancia', 'Estacia,Estancia,Estancia Town', 11.4551000, 123.1520000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107634, 'Estacion', 'Estacion', '', 15.6994400, 120.6083300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107635, 'Estaca', 'Estaca', 'Estaca', 9.6933000, 124.2722000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107636, 'Espiritu', 'Espiritu', 'Banna,Espiritu', 17.9809000, 120.6569000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107637, 'Esperanza East', 'Esperanza East', 'Esperanza,Esperanza East,Esperanza Este', 17.0232700, 121.6840200, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107638, 'Esperanza', 'Esperanza', 'Esperanza', 11.7365000, 124.0420000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107639, 'Esperanza', 'Esperanza', 'Esperanza', 10.7027000, 124.4143000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107640, 'Esperanza', 'Esperanza', 'Esperanza,Esperanzo', 10.6995000, 124.3143000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107641, 'Esperanza', 'Esperanza', 'Esperanza', 8.6769400, 125.6469400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107642, 'Esperanza', 'Esperanza', 'Esperanza', 8.1808300, 124.0072200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107643, 'Esperanza', 'Esperanza', 'Esperanza', 7.4916700, 125.7280600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107644, 'Esperanza', 'Esperanza', 'Esperanza', 6.7230600, 124.5197200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107645, 'España', 'Espana', 'Espana,España,Espina,Espiña', 12.3841400, 122.4990100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107646, 'Esmeralda', 'Esmeralda', 'Esmeralda', 15.8672200, 120.7150000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107647, 'Escalante', 'Escalante', 'Escalante City,Escalante Lakanbalen,Kota Escalante,ایسکالانتے، نیگروس غربی', 10.8402800, 123.4991700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107648, 'Ermita', 'Ermita', 'Ermita', 10.9000000, 122.7166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107649, 'Erenas', 'Erenas', 'Erenas', 12.4245000, 124.3238000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107650, 'Eraan', 'Eraan', 'Eraan,Eran,Iraan', 9.0628900, 117.7016000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107651, 'Entablado', 'Entablado', 'Entablado,Entablana', 15.2866100, 120.8630200, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107652, 'Enrique Villanueva', 'Enrique Villanueva', 'Enrique Villanueva,Talingting', 9.2761000, 123.6468000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107653, 'Saravia', 'Saravia', 'Enrique B. Magalona,Saravia', 10.8775400, 122.9677000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107654, 'Enrile', 'Enrile', 'Enrile,Entile', 17.5596000, 121.6974000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107655, 'El Salvador', 'El Salvador', 'El Salvador', 8.5630600, 124.5225000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107656, 'El Pardo', 'El Pardo', 'El Pardo,Pardo', 9.6600000, 123.4944000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107657, 'El Nido', 'El Nido', 'Bacuit,ENI,El Nido,El Nido Bacuit,ai ni dao,al nydw,elnido,erunido,ال نیدو,エルニド,愛妮島,엘니도', 11.1858300, 119.3955600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107658, 'Eguia', 'Eguia', 'Eguia', 15.9065000, 119.8858000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107659, 'Egaña', 'Egana', 'Egana,Egaña', 10.7472000, 122.0098400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107660, 'Eden', 'Eden', 'Eden', 17.0380900, 121.5979900, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107661, 'Ebcor Town', 'Ebcor Town', 'Ebcor Town,Edcor,Gallego Edcor', 7.4405600, 124.3972200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107662, 'Echague', 'Echague', 'Echague,Echaguee,Echagüe,Enchague', 16.7050900, 121.6763300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107663, 'Duran', 'Duran', 'Duran', 11.2618000, 122.5917000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107664, 'Dunguan', 'Dunguan', 'Dungguan,Dunguan', 6.9497200, 124.8608300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107665, 'Dumpay', 'Dumpay', 'Dompay,Dumpay', 15.8829500, 120.3889900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107666, 'Dumlan', 'Dumlan', 'Dumlan', 7.4275000, 125.8819000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107667, 'Dumingag', 'Dumingag', 'Dumingag', 8.1691700, 123.3505600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107668, 'Dumarao', 'Dumarao', 'Dumalao,Dumarao', 11.2654000, 122.6889000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107669, 'Dumaran', 'Dumaran', 'Dumaran', 10.5250000, 119.7671000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107670, 'Dumarais', 'Dumarais', 'Dumarais', 15.4345500, 120.6921300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107671, 'Dumanjog', 'Dumanjog', 'Dumanjog,Dumanjug', 10.0570000, 123.4361000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107672, 'Dumangas', 'Dumangas', 'Araut,Dumangas,Dumanoa', 10.8250000, 122.7130000, 'PH', '2015-01-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107673, 'Dumalneg', 'Dumalneg', 'Dumalneg', 18.5254000, 120.8094000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107674, 'Dumalinao', 'Dumalinao', 'Dumalinao', 7.8191000, 123.3694000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107675, 'Dumalaguing', 'Dumalaguing', 'Dumalaguing', 8.3469400, 125.0550000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107676, 'Dumalag', 'Dumalag', 'Dumalag', 11.3080000, 122.6236000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107677, 'Dumaguil', 'Dumaguil', 'Dumaguil', 6.6200000, 124.6533300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107678, 'Dumaguete', 'Dumaguete', 'Ciudad ti Dumaguete,DGT,Dumagete,Dumageute,Dumaguete,Dumaguete City,Dumaguete Lakanbalen,Dumaguette,Kota Dumaguete,Urbs Dumaguete,do~umagete,dumagete,dwmagwyty,lang mang ya de,Думагете,دوماگویتی,ドゥマゲテ,朗芒芽地,두마게테', 9.3072200, 123.3026100, 'PH', '2014-10-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107679, 'Dumabato', 'Dumabato', 'Dumabato,Dumabatu', 16.3166700, 121.7000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107680, 'Doljo', 'Doljo', 'Doljo,Duljo', 9.5874500, 123.7303300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107681, 'Dulig', 'Dulig', 'Dulig,Dulit', 16.0021200, 120.1686400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107682, 'Dulao', 'Dulao', 'Dulao', 10.5417600, 122.9383000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107683, 'Dulangan', 'Dulangan', 'Dulangan', 13.4685000, 120.9803000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107684, 'Dulangan', 'Dulangan', 'Dulangan', 13.3051000, 121.1129000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107685, 'Dulangan', 'Dulangan', 'Dulangan', 11.4561000, 122.9557000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107686, 'Dulag', 'Dulag', 'Dulag', 10.9525000, 125.0316700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107687, 'Dukay', 'Dukay', 'Dukay', 6.6691700, 124.5611100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107688, 'Dugongan', 'Dugongan', 'Dogongan,Dugongan,Dugungan', 14.1025000, 122.9066000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107689, 'Dugcal', 'Dugcal', 'Dugal,Dugcal,Dugkal', 13.6241000, 123.1612000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107690, 'Duero', 'Duero', 'Duero', 9.7090000, 124.4055000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107691, 'Dueñas', 'Duenas', 'Duenas,Dueñas', 11.0669800, 122.6154500, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107692, 'Dualing', 'Dualing', 'Dualing', 7.1516700, 124.5683300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107693, 'Doyong', 'Doyong', 'Doyong,Doyong Malabago', 15.9722400, 120.3538600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107694, 'Dos Hermanas', 'Dos Hermanas', 'Dos Hermanas,Dos Hermanos', 10.7421000, 123.0377000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107695, 'Dorongan Punta', 'Dorongan Punta', 'Darongan,Dorongan,Dorongan Punta,Doroñgan', 15.8147600, 120.3226600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107696, 'Doos', 'Doos', 'Doos', 10.4652800, 124.7294400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107697, 'Doong', 'Doong', 'Doong', 11.0786000, 123.6395000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107698, 'Donsol', 'Donsol', 'Donsol', 12.9055000, 123.5949000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107699, 'Don Pedro', 'Don Pedro', 'Don Pedro', 15.8851800, 120.4303600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107700, 'Talagutong', 'Talagutong', 'Don Marcelino,Tagalotok,Talaguton,Talagutong', 6.2644400, 125.6677800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107701, 'Dungon', 'Dungon', 'Dongon,Dungon', 11.7196000, 122.3160000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107702, 'Don Carlos', 'Don Carlos', 'Don Carlos,Don Carlos de Maramag', 7.6800000, 125.0050000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107703, 'Doña Remedios Trinidad', 'Dona Remedios Trinidad', 'Dona Remedios Trinidad,Doña Remedios Trinidad', 15.0000000, 121.0833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107704, 'Domampot', 'Domampot', 'Domampot,Domanpot,Dumanpot', 16.0000000, 120.6500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107705, 'Domalanoan', 'Domalanoan', 'Damaloguen,Domalandan,Domalanoan,Dumalandan', 16.0029200, 120.2115400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107706, 'Dolores', 'Dolores', 'Dolores', 17.6477000, 120.7091000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107707, 'Dolores', 'Dolores', 'Dolores', 14.0226500, 121.4100800, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107708, 'Dolores', 'Dolores', 'Dolores', 12.0371000, 125.4825000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107709, 'Dolores', 'Dolores', '', 11.0613900, 124.6133300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107710, 'Dologon', 'Dologon', 'Dologon,Dulogan,Dulugon', 7.8408300, 125.0444400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107711, 'Dolo', 'Dolo', 'Dolo', 6.8102800, 125.1916700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107712, 'Dodan', 'Dodan', 'Dodan', 17.6410700, 121.7944900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107713, 'Dobdoban', 'Dobdoban', 'Dobdoban,Dubduban', 12.5747000, 122.1138000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107714, 'Divisoria', 'Divisoria', 'Divisoria', 17.5226800, 121.7742100, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107715, 'Ditsaan', 'Ditsaan', 'Ditsa-an,Ditsaan', 7.9788900, 124.3511100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107716, 'Disod', 'Disod', 'Disod', 8.2611000, 123.0169000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107717, 'Dipolog', 'Dipolog', 'DPL,Dakbayan sa Dipolog,Dipolog,Dipolog City,Dipolog Lakanbalen,Dipólog,Kota Dipolog,Lungsod ng Dipolog,dipollogeu,diporogu,dypwlwg,Диполог,دیپولوگ,ディポログ,디폴로그', 8.5669700, 123.3347100, 'PH', '2015-05-28', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107718, 'Diplahan', 'Diplahan', '', 7.7166700, 123.0166700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107719, 'Dipolo', 'Dipolo', 'Dipald,Dipalo,Dipolo', 7.7828000, 123.1158000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107720, 'Dingras', 'Dingras', 'Dingras', 18.1032000, 120.6967000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107721, 'Dingle', 'Dingle', 'Dingle', 10.9995000, 122.6711000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107722, 'Dinganen', 'Dinganen', 'Dinganan,Dinganen', 7.3283300, 124.3783300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107723, 'Dingalan', 'Dingalan', 'Dingalan', 15.3897000, 121.3929000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107724, 'Dinalupihan', 'Dinalupihan', 'Dinalupian,Dinalupihan,Dinalupihari,Dinalupijan,Dinalupinan', 14.8782700, 120.4522100, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107725, 'Dinalongan', 'Dinalongan', 'Dilalongan,Dinalongan', 16.1404000, 121.9573000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107726, 'Dinaig', 'Dinaig', 'Ara Rancheria,Dinaig', 7.0255600, 124.3150000, 'PH', '2013-12-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107727, 'Dinahican', 'Dinahican', 'Binutasan', 14.7166700, 121.7166700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107728, 'Dinagat', 'Dinagat', '', 9.9561100, 125.5933300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107729, 'Dimiao', 'Dimiao', 'Dimiao,Dimlao', 9.6064000, 124.1633000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107730, 'Dimayon', 'Dimayon', 'Dimayon', 8.0666700, 124.1500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107731, 'Dimataling', 'Dimataling', 'Dimatalin,Dimataling', 7.5344000, 123.3738000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107732, 'Dimasalang', 'Dimasalang', 'Dimasalang', 12.1923000, 123.8592000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107733, 'Dimaluna', 'Dimaluna', 'Dimaluna,Dimaluno', 8.1218000, 123.7995000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107734, 'Diliman Primero', 'Diliman Primero', 'Diliman,Diliman Primero', 15.0247000, 120.9520800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107735, 'Dilan', 'Dilan', 'Dilan', 16.0879000, 120.5207000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107736, 'Bonifacio', 'Bonifacio', 'Bonifacio,Digson', 8.0525000, 123.6142000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107737, 'Digos', 'Digos', 'Digos City,Digos Lakanbalen,Kota Digos,dygws,دیگوس', 6.7497200, 125.3572200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107738, 'Digkilaan', 'Digkilaan', 'Dagquillan,Dikilan', 8.2511100, 124.3172200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107739, 'Digdig', 'Digdig', 'Digdig,Joson', 15.9490000, 120.9778000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107740, 'Digal', 'Digal', 'Digal', 6.7530600, 124.7963900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107741, 'Diffun', 'Diffun', 'Bayan ng Diffun,Diffun,Difun', 16.5900000, 121.5057000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107742, 'Dicayong', 'Dicayong', 'Dicayong,Dicoyong', 8.2206000, 123.0338000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107743, 'Dicamay', 'Dicamay', 'Dicamay,Dicamy', 16.7560600, 122.0037400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107744, 'Dicabisagan', 'Dicabisagan', 'Dicabisagan,Dicaoisagan', 17.0818400, 122.4157400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107745, 'Dibuluan', 'Dibuluan', 'Dibuluan', 16.5190700, 121.7647200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107746, 'Diaz', 'Diaz', 'Diaz', 15.8463000, 120.8347000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107747, 'Dian-ay', 'Dian-ay', 'Dian-ay', 10.8333300, 123.5500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107748, 'Diamantina', 'Diamantina', 'Diamantina,Diamantino', 16.9179500, 121.6267400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107749, 'Diadi', 'Diadi', 'Diadi', 16.7262000, 121.3589000, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107750, 'Del Rosario', 'Del Rosario', 'Del Rosario', 13.3057000, 123.3133000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107751, 'Del Pilar', 'Del Pilar', 'Del Pilar', 15.0360100, 120.6993500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107752, 'Del Pilar', 'Del Pilar', 'Del Pilar', 9.1519400, 125.5847200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107753, 'Daliciasao', 'Daliciasao', 'Daliciasao,Dalisiasa,Delicioso', 9.9859000, 122.7618000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107754, 'Del Gallego', 'Del Gallego', 'Danawin,Del Gallego', 13.9223000, 122.5954000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107755, 'Del Carmen', 'Del Carmen', 'Carman,Carmen,Del Carmen', 15.0054400, 120.5341200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107756, 'Del Carmen, Surigao del Norte', 'Del Carmen, Surigao del Norte', 'Del Carmen,Del Carmen  Surigao del Norte,IAO,Nomantag', 9.8694400, 125.9697200, 'PH', '2013-04-13', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107757, 'De la Paz', 'De la Paz', 'De la Paz,La Paz', 9.7000400, 123.8643300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107758, 'Daykitin', 'Daykitin', 'Daiquitin,Daykitin,Dayquitin', 13.2707300, 121.9108600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107759, 'Dayapan', 'Dayapan', 'Dayapan', 13.9372300, 120.9162000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107760, 'Dayap', 'Dayap', 'Dayap', 14.1801400, 121.3333500, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107761, 'Dawa-Dawa', 'Dawa-Dawa', 'Daua-Daua,Dawa-Dawa', 7.4683300, 122.8369400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107762, 'Davila', 'Davila', 'Davila', 18.4726000, 120.5763000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107763, 'Davao', 'Davao', 'Central,Ciudad ti Davao,DVO,Dakbayan sa Davao,Davao,Davao City,Davao Lakanbalen,Davao Stad,Davaó,Lungsod ng Dabaw,Syudad han Davao,da wo shi,dabao,dafaw,dawayw syty,Давао,دافاو,داوائو سیتی,ダバオ,达沃市,다바오', 7.0730600, 125.6127800, 'PH', '2014-07-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107764, 'Dauis', 'Dauis', 'Dauis,Dauis Union,Davis Union', 9.6252800, 123.8658300, 'PH', '2012-08-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107765, 'Dauin', 'Dauin', 'Dauin,Davin', 9.1914000, 123.2654000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107766, 'Davan', 'Davan', 'Cabuaga,Dauan,Davan,Dawan', 6.9148700, 126.1532300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107767, 'Datu Piang', 'Datu Piang', 'Datu Piang,Dulauan,Dulawan', 7.0283300, 124.5025000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107768, 'Datu Paglas', 'Datu Paglas', 'Datu Paglas', 6.7666700, 124.8500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107769, 'Datagon', 'Datagon', 'Datagon', 9.4461000, 123.0891000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107770, 'Dassun', 'Dassun', 'Dassun', 17.7451700, 121.7113700, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107771, 'Dasol', 'Dasol', 'Dasol', 15.9902000, 119.8828000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107772, 'Dasmariñas', 'Dasmarinas', 'Dasmarin''jas,Dasmarinas,Dasmarinas Lakanbalen,Dasmarines,Dasmariñas,Dasmariñas Lakanbalen,Kota Dasmarinas,Kota Dasmariñas,da si ma li ni ya si,daseumalinyaseu,dasmarngas,dasmarynyas,dasumarinyasu,Дасмариньяс,داسمارنگاس,داسمارینیاس,ダスマリニャス,达斯马里尼亚斯,다스마리냐스', 14.3294400, 120.9366700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107773, 'Darapidap', 'Darapidap', 'Darapidap', 17.2000700, 120.4180200, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107774, 'Daram', 'Daram', 'Daram', 11.6341000, 124.7947000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107775, 'Daraitan', 'Daraitan', 'Daraitan', 14.6028000, 121.4319000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107776, 'Daragutan', 'Daragutan', 'Daragutan', 17.0000000, 122.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107777, 'Daraga', 'Daraga', 'Daraga,Locsin', 13.1483000, 123.7124000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107778, 'Dapitan', 'Dapitan', 'Dapitan', 10.2624400, 123.9497000, 'PH', '2016-09-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107779, 'Dapitan', 'Dapitan', 'Dapitan,Dapitan City,Дапитан', 8.6561000, 123.4227000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107780, 'Dapdapan', 'Dapdapan', 'Dapdapan', 11.4943000, 122.6314000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107781, 'Dapdap', 'Dapdap', 'Dapdap', 12.2155000, 123.7662000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107782, 'Dapdap', 'Dapdap', 'Dapdap', 12.0620000, 125.4881000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107783, 'Dapawan', 'Dapawan', 'Dapauan,Dapawan', 12.4069400, 122.0277800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107784, 'Dapa', 'Dapa', 'Dapa,Dapa de Siargao', 9.7594400, 126.0530600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107785, 'Dao', 'Dao', 'Dao', 12.0998000, 125.4372000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107786, 'Dao', 'Dao', 'Dao,Dao Capiz', 11.3937000, 122.6856000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107787, 'Tobias Fornier', 'Tobias Fornier', 'Dao,Tobias Fornier', 10.5150000, 121.9461000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107788, 'Dansuli', 'Dansuli', 'Dansuli', 6.6425000, 124.5786100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107789, 'Dorsalanam', 'Dorsalanam', 'Dansolihon', 8.3066700, 124.5855600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107790, 'Danglas', 'Danglas', 'Danglas', 17.7009000, 120.6556000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107791, 'Dangcalan', 'Dangcalan', 'Dancalan,Dangcalan', 12.9168000, 123.5838000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107792, 'Dancagan', 'Dancagan', 'Dancagan,Dangcagan', 7.6091700, 125.0041700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107793, 'Dancalan', 'Dancalan', 'Dancalan', 9.9821000, 122.7386000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107794, 'Danao', 'Danao', 'Danao,Danao City,Idanao', 10.5208300, 124.0272200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107795, 'Danao', 'Danao', 'Danao', 9.9450000, 124.2233000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107796, 'Danao', 'Danao', 'Danao', 9.6333300, 124.2000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107797, 'Danao', 'Danao', 'Danao', 9.5542100, 123.7564800, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107798, 'Damulog', 'Damulog', 'Damolo,Damulog,Dumulug,New Damulog', 7.4836100, 124.9430600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107799, 'Dampol', 'Dampol', 'Dampol', 14.9012800, 120.8218700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107800, 'Damortis', 'Damortis', 'Damortis', 16.2405100, 120.4056500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107801, 'Damolog', 'Damolog', 'Damolog,Damulog', 10.7727100, 124.0063900, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107802, 'Damilag', 'Damilag', 'Damilag,Damilog', 8.3547200, 124.8122200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107803, 'Damayan', 'Damayan', 'Damayan', 11.4936000, 122.5531000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107804, 'Damawato', 'Damawato', 'Damawato', 6.7000000, 124.7833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107805, 'Damatulan', 'Damatulan', 'Damatulan', 7.0388900, 124.4827800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107806, 'Dalwangan', 'Dalwangan', 'Dalawangan,Dalwangan,Delauangon', 8.2005600, 125.0405600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107807, 'Dalupirip', 'Dalupirip', 'Dalupirip', 16.3260300, 120.7241400, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107808, 'Dalupaon', 'Dalupaon', 'Dalapaon,Dalopaon,Dalupaon', 13.5517000, 122.9457000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107809, 'Dalumangcob', 'Dalumangcob', 'Dalumangcob', 7.2166700, 124.3000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107810, 'Dalorong', 'Dalorong', 'Dalorong', 7.5858300, 125.1327800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107811, 'Dalirig', 'Dalirig', 'Dalirig,Dirilig', 8.3772200, 124.9013900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107812, 'Dalipuga', 'Dalipuga', '', 8.3158300, 124.2547200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107813, 'Dalipey', 'Dalipey', 'Dalipey', 16.8000000, 120.7166700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107814, 'Dalican', 'Dalican', 'Dalican', 6.9666700, 124.4000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107815, 'Daliao', 'Daliao', 'Daliao,Dalio', 5.8611100, 124.9533300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107816, 'Dalaoig', 'Dalaoig', 'Dalaoig,Dalauig', 17.9491700, 121.7148000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107817, 'Dalaguete', 'Dalaguete', 'Dalaguete,Dalaquete', 9.7612000, 123.5349000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107818, 'Dahay', 'Dahay', 'Dahay', 6.3969400, 124.7225000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107819, 'Dagupan', 'Dagupan', 'Dagupan', 17.7003900, 121.5044800, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107820, 'Dagup', 'Dagup', 'Dagap,Dagup', 16.6372200, 120.4455600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107821, 'Daguit', 'Daguit', 'Daguit', 14.1895000, 122.7266000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107822, 'Daguioman', 'Daguioman', 'Daguioman', 17.4509300, 120.9150500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107823, 'Dagumba-an', 'Dagumba-an', 'Dagombaan,Dagumba-an', 8.1530600, 124.5908300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107824, 'Dagohoy', 'Dagohoy', 'Dagohoy', 9.9001600, 124.2832200, 'PH', '2015-04-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107825, 'Dagatan', 'Dagatan', 'Dagatan', 14.0017000, 121.3767000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107826, 'Dagatan', 'Dagatan', 'Dagatan', 13.7389000, 121.1990000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107827, 'Dagami', 'Dagami', 'Dagami', 11.0608300, 124.9027800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107828, 'Daet', 'Daet', 'DTE,Daet,dayt  kamarynz shmaly,Дает,دایت، کامارینز شمالی', 14.1122000, 122.9553000, 'PH', '2016-12-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107829, 'Dadus', 'Dadus', 'Dados,Dadus', 7.0575000, 124.3216700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107830, 'Dacudao', 'Dacudao', 'Dacudao', 7.2152800, 125.4713900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107831, 'Da-an Sur', 'Da-an Sur', 'Da-an,Da-an Sur', 11.2612000, 122.4202000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107832, 'Viejo Daan Banua', 'Viejo Daan Banua', 'Da-an Banwa,Daan Banua,Viejo Daan Banua', 10.9035400, 123.0597000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107833, 'Daanbantayan', 'Daanbantayan', 'Candaya,Daanbantayan', 11.2468100, 124.0146200, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107834, 'Cuyo', 'Cuyo', 'CYU,Cugo,Cuyo,kwyw  palawan,کویو، پالاوان', 10.8525000, 121.0086100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107835, 'Cuyapo', 'Cuyapo', 'Cuya,Cuyapo', 15.7819400, 120.6647200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107836, 'Cut-cut Primero', 'Cut-cut Primero', 'Cut-cut Primero,Cutcut,Cutcut Primero', 15.4827700, 120.5860400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107837, 'Curuan', 'Curuan', 'Coroan,Curuan', 7.2052800, 122.2330600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107838, 'Curry', 'Curry', 'Curry,Cury', 13.6000000, 123.3000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107839, 'Currimao', 'Currimao', 'Currimao', 18.0182000, 120.4876000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107840, 'Culubasa', 'Culubasa', 'Culubasa', 15.1443100, 120.6522300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107841, 'Cullalabo del Sur', 'Cullalabo del Sur', 'Collalabo,Cullalabo,Cullalabo del Sur', 17.1026700, 121.7039400, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107842, 'Culianin', 'Culianin', 'Culianin,Kulianin', 14.9151100, 120.8984700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107843, 'Culianan', 'Culianan', 'Culianon', 6.9802800, 122.1466700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107844, 'Culasi', 'Culasi', 'Culasi', 11.4272100, 122.0560100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107845, 'Culasi', 'Culasi', 'Culasi', 11.0791700, 122.9819400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107846, 'Culaman', 'Culaman', 'Culaman,Kulaman', 5.9602800, 125.6586100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107847, 'Culaba', 'Culaba', 'Culaba', 11.6577800, 124.5425000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107848, 'Cuevas', 'Cuevas', 'Cuevas', 8.0191700, 126.0941700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107849, 'Cuenca', 'Cuenca', 'Cuenca,Kuehnka,Куэнка', 13.9020000, 121.0521000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107850, 'Cuartero', 'Cuartero', 'Cuariero,Cuartero', 11.3407000, 122.6694000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107851, 'Cuambog', 'Cuambog', 'Cuambog', 7.3086100, 125.8480600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107852, 'Cotmon', 'Cotmon', 'Cotmon', 13.1175000, 123.6637000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107853, 'Kotkot', 'Kotkot', 'Cotcot,Kotkot', 10.4250000, 124.0005000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107854, 'Cotabato', 'Cotabato', 'CBO,Catabate,Catabato,Cotabato,Cotabato City,Cottabato,Dakbayan sa Cotabato,Kota-Bato,Kotabato,kotabato,Котабато,コタバト', 7.2236100, 124.2463900, 'PH', '2012-07-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107855, 'Cosina', 'Cosina', 'Cosina,New Cosina', 8.1061100, 124.6197200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107856, 'Cortez', 'Cortez', 'Cortes,Cortez', 11.5301000, 122.3975000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107857, 'Cortes', 'Cortes', 'Cortes', 9.7220000, 123.8800000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107858, 'Cortes', 'Cortes', '', 9.2797200, 126.1911100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107859, 'Corrooy', 'Corrooy', 'Corrooy', 16.7962000, 120.4453000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107860, 'Coronon', 'Coronon', 'Coronon', 6.8791700, 125.4488900, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107861, 'Coron', 'Coron', 'Coron,Corón,XCN,kwrwn  palawan,کورون، پالاوان', 11.9986000, 120.2043000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107862, 'Corella', 'Corella', 'Corella', 9.6875000, 123.9218000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107863, 'Cordova', 'Cordova', 'Cordoba,Cordova,Kordoba,Кордоба', 10.7302800, 122.4013900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107864, 'Cordon', 'Cordon', 'Cordon', 16.6744000, 121.4658000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107865, 'Cordova', 'Cordova', 'Cordoba,Cordova,Corduba,Córdova,Kordoba,Кордоба', 10.2439400, 123.9422200, 'PH', '2016-10-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107866, 'Corcuera', 'Corcuera', 'Corcuera', 12.7833100, 122.0485100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107867, 'Conversion', 'Conversion', 'Convercion,Conversion', 15.8984000, 121.1277000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107868, 'Consuelo', 'Consuelo', 'Consuelo,Consuolo,Consvelo', 10.6348000, 124.3010000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107869, 'Consuelo', 'Consuelo', 'Consuelo', 9.9996000, 122.7580000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107870, 'Consuelo', 'Consuelo', 'Consuelo', 8.9016700, 125.1875000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107871, 'Consuegra', 'Consuegra', 'Consuegra', 11.2976000, 124.5124000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107872, 'Constancia', 'Constancia', 'Constancia', 10.5959600, 122.6415000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107873, 'Consolacion', 'Consolacion', 'Consolacion', 11.3284000, 122.6332000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107874, 'Consolacion', 'Consolacion', 'Consolacion,Consolation', 10.3766000, 123.9573000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107875, 'Conner', 'Conner', 'Connor,Ripang', 17.7963900, 121.3275000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107876, 'Conel', 'Conel', '', 6.2022200, 125.1872200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107877, 'Conduaga', 'Conduaga', 'Candawaga,Conduaga', 8.8620000, 117.4893000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107878, 'Concordia', 'Concordia', 'Concordia', 10.5076700, 122.5496000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107879, 'Concepcion', 'Concepcion', 'Concepcion', 15.4444700, 120.8007000, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107880, 'Concepcion', 'Concepcion', 'Concepcion,Conception,Konseps''on,Консепсьон', 15.3254600, 120.6572300, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107881, 'Concepcion', 'Concepcion', 'Concepcion', 15.2208900, 120.8311400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107882, 'Concepcion Ibaba', 'Concepcion Ibaba', 'Concepcion,Concepcion Ibaba', 13.9230900, 121.4609900, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107883, 'Concepcion', 'Concepcion', 'Concepcion,Konseps''on,Консепсьон', 12.3975000, 122.0936100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107884, 'Concepcion', 'Concepcion', 'Concepcion,Concepcion Town,Konseps''on,Консепсьон', 11.2161000, 123.1073000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107885, 'Concepcion', 'Concepcion', 'Concepcion', 10.6920000, 123.0608000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107886, 'Concepcion', 'Concepcion', 'Concepcion', 10.4052800, 124.7830600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107887, 'Compostela', 'Compostela', 'Compostela', 10.4550000, 124.0106000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107888, 'Compostela', 'Compostela', '', 7.6730600, 126.0888900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107889, 'Communal', 'Communal', 'Communal,Comunal', 13.2548000, 121.1366000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107890, 'Comillas Norte', 'Comillas Norte', 'Comillas,Comillas Norte', 16.9590000, 120.7469000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107891, 'Comillas', 'Comillas', 'Camillas,Comillas,Cornillas', 15.3983300, 120.7004500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107892, 'Columbio', 'Columbio', 'Columbio', 6.6963900, 124.9372200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107893, 'Colonia', 'Colonia', 'Colonia,Kolonia', 10.6553000, 123.7911000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107894, 'Colonia', 'Colonia', 'Colonia', 6.6436100, 122.1575000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107895, 'Colongolo', 'Colongolo', 'Colongolo', 6.3386100, 124.7216700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107896, 'Culasian', 'Culasian', 'Colasian,Culasian,Gulasian,Kulasian', 11.3069400, 124.6105600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107897, 'Culacling', 'Culacling', 'Colacling,Culacling', 13.7815000, 122.8767000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107898, 'Cogtong', 'Cogtong', 'Cogton,Cogtong,Kogtong', 9.8374000, 124.5291000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107899, 'Cogon', 'Cogon', 'Cogon,Cogow', 7.1508300, 125.7172200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107900, 'Cogon Cruz', 'Cogon Cruz', 'Cogon Cruz', 10.5094400, 123.9697200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107901, 'Cogon', 'Cogon', 'Cogon', 11.4641000, 122.8030000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107902, 'Cogon', 'Cogon', 'Cogon', 10.7133000, 123.8284000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107903, 'Cogon', 'Cogon', '', 10.2677800, 123.7586100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107904, 'Codcod', 'Codcod', 'Codcod', 10.4633700, 123.2495000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107905, 'Claveria', 'Claveria', 'Calvario,Claveria', 18.6074200, 121.0832200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107906, 'Claveria', 'Claveria', 'Claveria', 12.9035000, 123.2457000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107907, 'Claveria', 'Claveria', 'Claveria,Claveria de Jaman,Clavería de Jamán', 8.6100000, 124.8947200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107908, 'Claver', 'Claver', 'Calver,Claver', 9.5725000, 125.7330600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107909, 'Clarin', 'Clarin', 'Canogan,Clarin,Clorin', 9.9616000, 124.0252000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107910, 'Clarin', 'Clarin', 'Clarin,Loculan', 8.2023000, 123.8582000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107911, 'Chambrey', 'Chambrey', 'Chamberry,Chambery,Chambrey', 10.9768000, 123.1682000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107912, 'Cervantes', 'Cervantes', 'Cervantes', 16.9909000, 120.7359000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107913, 'Cervantes', 'Cervantes', 'Cervantes', 12.3686100, 124.6597200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107914, 'Cervantes', 'Cervantes', 'Cervantes', 10.8726000, 123.5209000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107915, 'Cebuano', 'Cebuano', 'Cebuano', 6.3880600, 124.9683300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107916, 'Cebu City', 'Cebu City', 'CEB,Cebu,Cebu City,City of Cebu,Ciudad de Cebu,Ciudad de Cebú,Dakbayan sa Sugbo,Sebu,sebu,Себу,세부', 10.3167200, 123.8907100, 'PH', '2017-06-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107917, 'Cayungnan', 'Cayungnan', 'Cayugnan,Cayungan,Cayungnan', 16.1332000, 119.8375000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107918, 'Cayhagan', 'Cayhagan', 'Cayhagan', 9.6783000, 122.4335000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107919, 'Cayanguan', 'Cayanguan', 'Cayanguan,Cayangwan', 11.6890000, 122.2909000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107920, 'Cayanga', 'Cayanga', 'Cayanga', 16.1150800, 120.3987500, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107921, 'Cayang', 'Cayang', 'Cayang', 11.0666700, 123.9833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107922, 'Kauit', 'Kauit', 'Cauit,Cawit Norte,Kauit,Kawit', 11.1860000, 123.9459000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107923, 'Cawayan Bugtong', 'Cawayan Bugtong', 'Cawayan Bugtang,Cawayan Bugtong,Cawayang Bugtong,Kawayah Bugtong', 15.6336200, 120.7769500, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107924, 'Cawayan', 'Cawayan', 'Cawayan', 13.3672000, 122.5094000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107925, 'Cawayan', 'Cawayan', 'Cawayan', 12.6557000, 121.5456000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107926, 'Cawayan', 'Cawayan', 'Cauayan,Cawayan', 11.6237000, 122.4649000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107927, 'Cavite', 'Cavite', 'Cavite', 15.6778500, 120.7697800, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107928, 'Cavite City', 'Cavite City', 'Bandar Cavite,Cavite,Cavite City,Cavite Lakanbalen,Ciudad ti Cavite,Dakbayan sa Cavite,Kavite,Lungsod ng Kabite,Siyudad na Cavite,Syudad han Cavite,jia mi de,kabite,kavu~ite,Кавите,カヴィテ,甲米地,카비테', 14.4836900, 120.8987800, 'PH', '2014-11-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107929, 'Cavinti', 'Cavinti', 'Cavinti', 14.2448200, 121.5079700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107930, 'Causwagan', 'Causwagan', 'Causwagan,Kauswagan', 8.4475000, 125.8402800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107931, 'Causip', 'Causip', 'Causip', 13.5159000, 123.2834000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107932, 'Cauayan', 'Cauayan', 'Cauayan,Cauayan City,Cauayan Lakanbalen,Cauayán,Cauyan,Kota Cauayan', 16.9347200, 121.7725000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107933, 'Cauayan', 'Cauayan', 'Cauayan,San Ildefonso', 15.1514900, 120.6716600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107934, 'Cawayan', 'Cawayan', 'Cauayan,Cavayan,Cawayan', 9.9718000, 122.6249000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107935, 'Catungawan Sur', 'Catungawan Sur', 'Catungawan,Catungawan Sur,Katungauan', 9.7817000, 124.4693000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107936, 'Catungan', 'Catungan', 'Catungan', 10.7706000, 122.0149000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107937, 'Catuday', 'Catuday', 'Catuday', 16.2923000, 119.8062000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107938, 'Catubig', 'Catubig', 'Catubig', 12.4098000, 125.0548000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107939, 'Cato', 'Cato', 'Cato', 15.8362000, 119.9151000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107940, 'Catmondaan', 'Catmondaan', 'Catmondaan,Daan Catmon', 10.6869200, 124.0149400, 'PH', '2012-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107941, 'Catmon', 'Catmon', 'Catmon', 11.5351600, 124.4311500, 'PH', '2014-09-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107942, 'Catmon', 'Catmon', 'Catmon', 10.7166700, 124.0000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107943, 'Caticugan', 'Caticugan', 'Caticugan', 9.1000000, 123.0000000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107944, 'Katico', 'Katico', 'Catico,Katico', 6.7616700, 124.7300000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107945, 'Caticlan', 'Caticlan', 'Caticlan,Katiklan,MPH,Tican,Ticlan,Катиклан', 11.9333700, 121.9598100, 'PH', '2015-10-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107946, 'Caterman', 'Caterman', 'Catarman,Caterman', 17.2173800, 120.4244200, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107947, 'Cateel', 'Cateel', 'Cateel', 7.7913900, 126.4533300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107948, 'Catbalogan', 'Catbalogan', 'Catbalogan,Catbalogan City,Kota Catbalogan,Lungsod ng Catbalogan,katbalwgan,کاتبالوگان', 11.7752800, 124.8861100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107949, 'Catayauan', 'Catayauan', 'Catayauan,Catayuan', 18.1607200, 121.6527100, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107950, 'Catarman', 'Catarman', 'CRM,Catarman,Catarmán,katarman  shmaly samar,کاتارمان، شمالی سامار', 12.4989000, 124.6377000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107951, 'Catarman', 'Catarman', 'Catarman', 9.6016900, 123.8611100, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107952, 'Catarman', 'Catarman', 'Catarman', 9.1255600, 124.6755600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107953, 'Catanauan', 'Catanauan', 'Catanauan,Catanuan', 13.5926000, 122.3215000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107954, 'Cataingan', 'Cataingan', 'Cataigan,Cataingan', 12.0030000, 123.9920000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107955, 'Catablan', 'Catablan', 'Catablan', 15.9757000, 120.4953000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107956, 'Catabangan', 'Catabangan', 'Catabangan', 13.8777000, 122.6615000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107957, 'Castillo', 'Castillo', 'Casillo,Castillo', 13.7313000, 123.1166000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107958, 'Castillejos', 'Castillejos', 'Caslillejos,Castillejos,Kastil''ekhosu,Кастильехосу', 14.9336300, 120.1978500, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107959, 'Castilla', 'Castilla', 'Castilla', 12.9486100, 123.8822200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107960, 'Castañas', 'Castanas', 'Castanas,Castañas', 13.8744000, 121.5533000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107961, 'Casisang', 'Casisang', 'Casisang', 8.1380600, 125.1250000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107962, 'Casiguran', 'Casiguran', 'Casiguran', 12.8736100, 124.0097200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107963, 'Casian', 'Casian', 'Casian', 11.0350000, 119.7136000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107964, 'Casay', 'Casay', 'Casay,Oasay', 13.2632000, 122.5217000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107965, 'Cassanayan', 'Cassanayan', 'Casanayan,Cassanayan', 11.5169000, 123.0512000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107966, 'Casambalangan', 'Casambalangan', 'Casambalangan', 18.3764600, 122.1274500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107967, 'Casala-an', 'Casala-an', 'Casala-an', 9.1166700, 123.0500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107968, 'Caruray', 'Caruray', 'Caruray', 10.3094000, 119.0128000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107969, 'Caronoan West', 'Caronoan West', 'Caronoan West,Caronuan,Carunoan', 16.2633000, 120.4463000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107970, 'Cartagena', 'Cartagena', 'Cartagena', 9.8203000, 122.4004000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107971, 'Carriedo', 'Carriedo', 'Carriedo', 16.0310000, 120.7549000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107972, 'Carriedo', 'Carriedo', 'Carriedo', 12.9344000, 124.1050000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107973, 'Carrascal', 'Carrascal', 'Carrascal', 9.3702800, 125.9491700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107974, 'Carranglan', 'Carranglan', 'Carraglan,Carranglan', 15.9613000, 121.0641000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107975, 'Carpenter', 'Carpenter', 'Carpenter', 6.4541700, 124.8725000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107976, 'Carot', 'Carot', 'Carot', 16.3446800, 119.9800500, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107977, 'Carusucan', 'Carusucan', 'Carosucan,Carusucan', 15.9658900, 120.6359800, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107978, 'Carmona', 'Carmona', 'Carmona', 14.3132000, 121.0576000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107979, 'Carmen', 'Carmen', 'Carmay,Carmen,Karmen,Кармен', 15.8864200, 120.5998400, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107980, 'Carmen', 'Carmen', 'Carmen', 15.4470200, 120.8267600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107981, 'Carmen', 'Carmen', 'Carman,Carmen,Karmen,Кармен', 12.6171000, 122.1211000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107982, 'Cogan', 'Cogan', 'Carmen,Cogan,Karmen,Old Carmen,Кармен', 10.5930600, 124.0177800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107983, 'Carmen Grande', 'Carmen Grande', 'Carmen,Carmen Grande,Karmen,Кармен', 10.3787000, 122.9156000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107984, 'Carmen', 'Carmen', 'Carmen,Karmen,Кармен', 9.8223000, 124.1964000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107985, 'Carmen', 'Carmen', '', 9.2263900, 126.0172200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107986, 'Carmen', 'Carmen', 'Carmen,Karmen,Кармен', 8.9886100, 125.2925000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107987, 'Carmen', 'Carmen', 'Carmen,Ising,Karmen,Кармен', 7.3605600, 125.7063900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107988, 'Carmen', 'Carmen', 'Carmen,Karmen,Кармен', 7.2044400, 124.7916700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107989, 'Carmelo', 'Carmelo', 'Carmelo', 11.0166700, 122.8166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107990, 'Carmelo', 'Carmelo', 'Carmelo', 10.7051000, 123.7935000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107991, 'Carles', 'Carles', 'Carles', 11.5726000, 123.1342000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107992, 'Carlagan', 'Carlagan', 'Carlagan', 14.9750000, 122.0455600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107993, 'Carigara', 'Carigara', 'Carigara,Garigara', 11.2981100, 124.6789500, 'PH', '2016-10-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107994, 'Carig', 'Carig', 'Carig', 17.6592900, 121.7435700, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107995, 'Caridad', 'Caridad', 'Caridad', 10.8315000, 124.7518000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107996, 'Caridad', 'Caridad', 'Caridad,Caridao', 10.4967000, 122.8974000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107997, 'Cardona', 'Cardona', 'Cardona', 15.5722000, 120.5897000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107998, 'Cardona', 'Cardona', 'Cardona,Kardona,Кардона', 14.4864600, 121.2275200, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(107999, 'Carcar', 'Carcar', 'Carcar', 10.1061000, 123.6402000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108000, 'Caraycayon', 'Caraycayon', 'Caraycayon', 13.6166700, 123.4833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108001, 'Caraycaray', 'Caraycaray', 'Caraycaray,Caraycary', 11.5551000, 124.4150000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108002, 'Carasi', 'Carasi', 'Carasi,Carazi', 18.1988900, 120.8683300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108003, 'Caranan', 'Caranan', 'Caranan,Carinan', 13.5167000, 123.0156000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108004, 'Caramutan', 'Caramutan', 'Caramutan', 15.9207400, 120.6101200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108005, 'Caramoran', 'Caramoran', 'Caramoan,Caramoran', 13.9849000, 124.1347000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108006, 'Caramoan', 'Caramoan', 'Caramoan', 13.7707000, 123.8631000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108007, 'Caramay', 'Caramay', 'Caramay', 10.1815000, 119.2360000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108008, 'Caraga', 'Caraga', 'Caraga', 7.3297200, 126.5675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108009, 'Caracal', 'Caracal', 'Caracal', 8.1272200, 122.8450000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108010, 'Carabalan', 'Carabalan', 'Carabalan', 10.0964000, 122.9460000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108011, 'Capuy', 'Capuy', 'Capuy', 12.9833300, 123.9333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108012, 'Capuluan', 'Capuluan', 'Capuluan,Capuluan Central', 13.8162000, 122.5158000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108013, 'Capulaan', 'Capulaan', 'Capulaan', 15.9049700, 120.5371900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108014, 'Capul', 'Capul', 'Capul', 12.4237000, 124.1811000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108015, 'Capucnasan', 'Capucnasan', 'Capocnasan', 13.6000000, 123.2166700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108016, 'Capoocan', 'Capoocan', 'Capoocan', 11.2933300, 124.6419400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108017, 'Capissayan Sur', 'Capissayan Sur', 'Capissavan,Capissayan,Capissayan Sur', 18.0509000, 121.8177000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108018, 'Capas', 'Capas', 'Capas,Capaz,Kapas,Капас', 15.3311700, 120.5898000, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108019, 'Capandanan', 'Capandanan', 'Capandanall,Capandanan', 15.9594300, 120.6951900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108020, 'Capalonga', 'Capalonga', 'Capalonga', 14.3306000, 122.4937000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108021, 'Capalayan', 'Capalayan', 'Capalayan', 9.7405600, 125.5444400, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108022, 'Capaga', 'Capaga', 'Capaga,Capagab,Capagao', 11.4379000, 122.7479000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108023, 'Caoayan', 'Caoayan', 'Caoayan,Cavayan', 17.5619400, 120.3975000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108024, 'Canubing No 2', 'Canubing No 2', 'Canubing No 2', 13.3500000, 121.1333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108025, 'Canturay', 'Canturay', 'Canturay', 9.7937000, 122.4543000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108026, 'Cantoria', 'Cantoria', 'Cantoria', 16.8441000, 120.4045000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108027, 'Cantilan', 'Cantilan', 'Cantilan,Cantilán', 9.3336100, 125.9775000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108028, 'Cantel', 'Cantel', 'Cantel,Cantil', 12.6176000, 121.5136000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108029, 'Cantapoy', 'Cantapoy', 'Cantapoy', 9.4905600, 125.4363900, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108030, 'Cantao-an', 'Cantao-an', 'Cantao-an,Kantauan', 10.2425800, 123.7496000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108031, 'Cansolungon', 'Cansolungon', 'Cansalongon,Cansaloñgon,Cansolungon,Cansulungon Hacienda,Casalongon', 10.1510000, 122.9978000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108032, 'Cansuje', 'Cansuje', 'Cansuje', 9.9231400, 123.4962900, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108033, 'Canroma', 'Canroma', 'Canroma', 10.3606000, 122.8790000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108034, 'Canomoy', 'Canomoy', 'Canomoy', 12.1573500, 123.2701100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108035, 'Corocotan', 'Corocotan', 'Canocotan,Corocotan', 7.3998000, 125.7727000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108036, 'Canmaya Diot', 'Canmaya Diot', 'Cangmaya,Canmaya,Canmaya Diot', 9.9384000, 124.0942000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108037, 'Canlaon', 'Canlaon', 'Canlaon,Canlaon City', 10.3869700, 123.2227000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108038, 'Canjulao', 'Canjulao', 'Canjulao,Kanhulao', 9.6605000, 124.3532000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108039, 'Caningay', 'Caningay', 'Caningay', 9.8297000, 122.6442000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108040, 'Canhaway', 'Canhaway', 'Canhaway,Kanhaway', 9.7501000, 124.4722000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108041, 'Canhandugan', 'Canhandugan', 'Canhandugan', 11.1350000, 124.7797200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108042, 'Candoni', 'Candoni', 'Candoni', 9.8170000, 122.6043000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108043, 'Candon', 'Candon', 'Candon Lakanbalen,Kota Candon,kandwn,کاندون', 17.1947200, 120.4516700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108044, 'Candijay', 'Candijay', 'Candijay', 9.8182000, 124.4977000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108045, 'Candiis', 'Candiis', 'Candiis', 8.9702800, 125.1841700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108046, 'Candelaria', 'Candelaria', 'Candelaria', 13.9311100, 121.4233300, 'PH', '2012-06-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108047, 'Candelaria', 'Candelaria', 'Candelaria', 11.2893000, 122.5228000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108048, 'Candating', 'Candating', 'Candating', 15.1505600, 120.8184700, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108049, 'Candabong', 'Candabong', 'Candabong,Kandabong', 9.7343000, 124.5383000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108050, 'Kandabong', 'Kandabong', 'Candabong,Kandabong', 9.6859000, 123.0728000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108051, 'Candaba', 'Candaba', 'Candaba', 15.0956000, 120.8267000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108052, 'Cansilayan', 'Cansilayan', 'Cancilayan,Cansilayan', 10.5597600, 123.0184000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108053, 'Canayan', 'Canayan', 'Canayan', 8.1955600, 125.1447200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108054, 'Canauay', 'Canauay', 'Canauay,Canaway', 9.0651000, 123.0524000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108055, 'Can-Avid', 'Can-Avid', 'Can-Avid,Canavio,Kanavid', 11.9952800, 125.4472200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108056, 'Can-asujan', 'Can-asujan', 'Can-asujan,Kanasujan,Kanasulan', 10.1299000, 123.6574000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108057, 'Ganapi', 'Ganapi', 'Canapi,Ganapi', 17.2017400, 121.8652400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108058, 'Canaoalan', 'Canaoalan', 'Canaoalan,Canoalan,Ganadalan', 16.0290200, 120.2964100, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108059, 'Canan Norte', 'Canan Norte', 'Canan,Canan Norte', 15.9098600, 120.4776300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108060, 'Canaman', 'Canaman', 'Canaman', 13.6480000, 123.1699000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108061, 'Camohaguin', 'Camohaguin', 'Camohaguin,Camuhaguin', 13.9089000, 122.1666000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108062, 'Campoyo', 'Campoyo', 'Campoyo,Campuyo', 9.6564000, 123.1479000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108063, 'Campusong', 'Campusong', 'Camposong,Campusong', 10.8158300, 124.0322200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108064, 'Camingawan', 'Camingawan', 'Camingawan', 9.8958000, 122.8625000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108065, 'Camindangan', 'Camindangan', 'Camindagan,Camindangan,Gamindangan', 9.9184000, 122.6296000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108066, 'Caminauit', 'Caminauit', 'Caminauit,Caminawit', 12.3313500, 121.0825100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108067, 'Camiling', 'Camiling', 'Camiling', 15.6866000, 120.4128000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108068, 'Camias', 'Camias', 'Camias,Kamias', 15.1667900, 120.9741600, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108069, 'Camp Flora', 'Camp Flora', 'Camflora,Camp Flora', 13.3508000, 122.6641000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108070, 'Cambuga', 'Cambuga', 'Cambuga', 13.6166700, 122.4500000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108071, 'Cambanay', 'Cambanay', 'Cambanay', 10.5436100, 123.9861100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108072, 'Gambalidio', 'Gambalidio', 'Cambalidio,Cambalidió,Gambalidio', 13.6205000, 122.8913000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108073, 'Camangcamang', 'Camangcamang', 'Camangcamang,Camangeamang,Mambulan,Mambulung', 10.1791000, 122.9865000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108074, 'Camandag', 'Camandag', 'Camandag', 10.3333300, 123.0666700, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108075, 'Camambugan', 'Camambugan', 'Camambugan,Camanbugan', 10.0584400, 124.4381100, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108076, 'Camalobalo', 'Camalobalo', 'Camalobalo', 10.2731000, 122.9505000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108077, 'Camaligan', 'Camaligan', 'Camaligan', 13.6224000, 123.1667000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108078, 'Camalig', 'Camalig', 'Camalig', 13.1821000, 123.6543000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108079, 'Camaley', 'Camaley', 'Camaley', 15.9972400, 120.3010700, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108080, 'Camalaniugan', 'Camalaniugan', 'Camalaniugan', 18.2740000, 121.6748000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108081, 'Cama Juan', 'Cama Juan', 'Cama Juan', 15.3922300, 120.7684800, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108082, 'Camachile', 'Camachile', 'Camachile,Camachili', 14.6436100, 120.5808300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108083, 'Caluya', 'Caluya', 'Caluya', 11.9310000, 121.5477000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108084, 'Calumpit', 'Calumpit', 'Calumpit', 14.9163900, 120.7658300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108085, 'Calumpang', 'Calumpang', 'Calumpang', 15.1740000, 121.0249000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108086, 'Calumpang', 'Calumpang', 'Calumbang,Kalumpang', 14.6228000, 121.0897000, 'PH', '2011-08-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108087, 'Calumpang', 'Calumpang', 'Calumpang', 14.1966000, 121.4020000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108088, 'Calumpang', 'Calumpang', 'Calumpang', 13.9897000, 121.5494000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108089, 'Calumpang', 'Calumpang', 'Calumpang', 13.8423900, 120.9755500, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108090, 'Calomboyan', 'Calomboyan', 'Calomboyan,Calumboyan', 15.9465200, 120.3034800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108091, 'San Isidro', 'San Isidro', 'Caluluan,Cululuan,San Isidro,Sitio', 15.4425000, 120.7256500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108092, 'Calubian', 'Calubian', 'Calubian', 11.4472000, 124.4281000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108093, 'Calubcub Dos', 'Calubcub Dos', 'Calubcob Segundo,Calubcub,Calubcub Dos,Calubcub Segundo,Culubcub 2,Culubcub II,Kalubcub Segundo,Kalubkob Segundo', 13.7393000, 121.4219300, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108094, 'Calsib', 'Calsib', 'Calsib', 15.8471100, 120.2641200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108095, 'Calongbuyan', 'Calongbuyan', 'Calongbuyan', 17.1647800, 120.4271600, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108096, 'Calolbon', 'Calolbon', 'Calolbon', 13.5960000, 124.0991000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108097, 'Calog Norte', 'Calog Norte', 'Calog,Calog Norte,Calug Norte', 18.3635900, 121.3853300, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108098, 'Caloc-an', 'Caloc-an', 'Caloocan', 9.0469400, 125.5305600, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108099, 'Callaguip', 'Callaguip', 'Callaguip,Callagulp', 18.0713900, 120.4866700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108100, 'Calizo', 'Calizo', 'Calizo', 11.5819000, 122.3857000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108101, 'Calituban', 'Calituban', 'Calituban', 10.2399500, 124.2919000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108102, 'Colipapa', 'Colipapa', 'Calipapa,Colipapa,Culipapa,Kalipapa,Kulipapa', 9.4726000, 122.5616000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108103, 'Calintaan', 'Calintaan', '', 12.5666700, 120.9333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108104, 'Calinog', 'Calinog', '', 11.1166700, 122.5666700, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108105, 'Calingcuan', 'Calingcuan', 'Calingcuan', 15.3333300, 120.5833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108106, 'Calinaoan Malasin', 'Calinaoan Malasin', 'Calinaoan,Calinaoan Malasin,Calinauan,Colinauan', 17.3518900, 121.7407400, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108107, 'Calilayan', 'Calilayan', 'Calilayan,Ilayang Calilayan,Kalilayan Ibaba', 13.8503000, 121.9300000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108108, 'Calidñgan', 'Calidngan', 'Calidngan,Calidñgan', 10.1000000, 123.6333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108109, 'Calibutbut', 'Calibutbut', 'Calibutbut', 15.1149400, 120.5981500, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108110, 'Calibungan', 'Calibungan', 'Calibungan,Kalibungan', 15.5982000, 120.7240000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108111, 'Calero', 'Calero', 'Calero', 10.3733100, 123.9978600, 'PH', '2016-09-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108112, 'Calepaan', 'Calepaan', 'Calepaan', 16.0195000, 120.6190000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108113, 'Calbiga', 'Calbiga', 'Calbiga', 11.6247200, 125.0163900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108114, 'Calbayog City', 'Calbayog City', 'CYP,Calbayog,Calbayog City,Dakbayan sa Calbayog,Syudad san Calbayog', 12.0668000, 124.5962000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108115, 'Calayaan', 'Calayaan', 'Calayaan', 15.5673900, 120.5143400, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108116, 'Calaya', 'Calaya', 'Calaya', 10.4916000, 122.6255000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108117, 'Calauan', 'Calauan', 'Calauan', 14.1498900, 121.3152000, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108118, 'Calauag', 'Calauag', 'Calauag,Calavag', 13.9575000, 122.2880000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108119, 'Calauag', 'Calauag', 'Calauag,Calawag', 10.6681700, 119.5705000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108120, 'Calatugas', 'Calatugas', 'Calategas,Calatugas', 9.1689800, 118.2235000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108121, 'Calatrava', 'Calatrava', 'Calatrava', 12.6198000, 122.0714000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108122, 'Calatrava', 'Calatrava', 'Calatrava', 10.5949600, 123.4838000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108123, 'Calatagan', 'Calatagan', 'Calalagan,Calatagan', 13.8322400, 120.6321900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108124, 'Calatagan', 'Calatagan', 'Calatagan', 13.5885000, 124.2065000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108125, 'Calasiao', 'Calasiao', 'Calasiao,Colasiao', 16.0111000, 120.3600000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108126, 'Calasgasan', 'Calasgasan', 'Calasgasan', 14.0833300, 122.9333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108127, 'Calape', 'Calape', 'Calape,Calapi', 10.2736000, 122.9743000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108128, 'Calape', 'Calape', 'Calape,Calapi', 11.9425000, 125.0213900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108129, 'Calape', 'Calape', 'Calape', 11.1756000, 124.0335000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108130, 'Calape', 'Calape', 'Calape', 9.8922000, 123.8748000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108131, 'Calapan', 'Calapan', 'Calapan,Calapan City,Calapan Lakanbalen,Calapán,Dakbayan sa Calapan,Kalapan,Kota Calapan,Lungsod ng Calapan,ka la pan,kalapan,kallapan,کالاپان,卡拉潘,칼라판', 13.4117000, 121.1803000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108132, 'Calaoagan', 'Calaoagan', 'Calaoagan,Calaogan', 18.0427900, 121.7232500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108133, 'Calantas', 'Calantas', 'Calantas,Kalantas', 15.0193300, 120.5179300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108134, 'Calantas', 'Calantas', 'Calantas', 13.9720200, 120.7745600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108135, 'Calantac', 'Calantac', 'Calantac', 17.9090400, 121.7228000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108136, 'Calanogas', 'Calanogas', 'Calanogas', 7.7500000, 124.1000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108137, 'Calangain', 'Calangain', 'Calangain', 14.8981500, 120.5587700, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108138, 'Calancuasan Norte', 'Calancuasan Norte', 'Calancuasan,Calancuasan Norte', 15.8013700, 120.6410200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108139, 'Calanasan', 'Calanasan', 'Bayag', 18.2550000, 121.0344400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108140, 'Calampisauan', 'Calampisauan', 'Calampisauan,Calampisawan', 10.6098500, 123.4765000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108141, 'Calamba', 'Calamba', 'Calamba,Calamba City,Calamba Lakanbalen,Calambá,Kalamba,Kota Calamba,Urbs Calamba,ka lan ba,kalamba  lagwna,kallamba,Каламба,کالامبا، لاگونا,卡兰巴,칼람바', 14.2116700, 121.1652800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108142, 'Calamba', 'Calamba', 'Calamba', 10.1755000, 123.2826000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108143, 'Calamba', 'Calamba', 'Calamba', 9.1036100, 125.5941700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108144, 'Calamba', 'Calamba', 'Calamba', 8.5587000, 123.6425000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108145, 'Calamagui East', 'Calamagui East', 'Calamagin,Calamagui,Calamagui East', 17.4881500, 121.7684500, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108146, 'Calachuchi', 'Calachuchi', 'Calachuche,Calachuchi,Calasuche,Calatuche', 12.2177500, 123.5306100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108147, 'Calaca', 'Calaca', 'Calaca', 13.9324400, 120.8132700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108148, 'Calabugao', 'Calabugao', 'Calabugao,Kalabugao', 8.4563900, 125.1588900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108149, 'Calabasa', 'Calabasa', '', 7.2463900, 122.2341700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108150, 'Calabanga', 'Calabanga', 'Calabanga,Calabunga', 13.7068000, 123.2087000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108151, 'Calabaca', 'Calabaca', 'Calabaca', 14.3001000, 122.4336400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108152, 'Calaba', 'Calaba', 'Calaba', 17.6178000, 120.6162000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108153, 'Calaba', 'Calaba', 'Calaba', 15.3005000, 120.8742300, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108154, 'Cajimos', 'Cajimos', 'Cajimos', 12.5946300, 122.2753100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108155, 'Cajidiocan', 'Cajidiocan', 'Cajidiocan', 12.3669600, 122.6814100, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108156, 'Cainta', 'Cainta', 'Cainta', 14.5786000, 121.1222000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108157, 'Caigangan', 'Caigangan', 'Caigangan', 13.2581100, 121.9336300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108158, 'Caibiran', 'Caibiran', 'Caibiran', 11.5716700, 124.5822200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108159, 'Cagwait', 'Cagwait', 'Caguait,Cagwait,Cagwan', 8.9186100, 126.3011100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108160, 'Cagsiay', 'Cagsiay', 'Cagsiay', 14.2166700, 121.7500000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108161, 'Cagmanaba', 'Cagmanaba', 'Cagmanaba', 13.0550100, 123.2970600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108162, 'Kaliliog', 'Kaliliog', 'Caglilag,Cagliliog,Caglilog,Kagliliog,Kaliliog', 13.9039000, 123.2925000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108163, 'Cagdianao', 'Cagdianao', 'Cadayanao,Cagdianao,Kagdyanao', 9.9211100, 125.6691700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108164, 'Cagbang', 'Cagbang', 'Cagbang', 10.7000000, 122.4988900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108165, 'Cagayan', 'Cagayan', 'Cagayan,Cagayan de Sulu,Cagayan de Tawi-Tawi,Kagayan,Kagayan de Tawi-Tawi,Mahalu,Tana'' Mapun,Tana’ Mapun', 6.9747000, 118.5144000, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108166, 'Cagayan de Oro', 'Cagayan de Oro', 'CGY,Cagayan de Oro,Cagayan de Oro City,Cagayan de Oro Lakanbalen,Cagayán de Oro,Dakbayan sa Cagayan de Oro,Kagajan de Oras,Kagajan-de-Oro,Lungsod ng Cagayan de Oro,ka jia yan de ao luo,kagayande-olo,Кагаян-де-Оро,カガヤン・デ・オロ,卡加延德奥罗,카가얀데오로', 8.4822200, 124.6472200, 'PH', '2017-07-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108167, 'Cagayancillo', 'Cagayancillo', 'Cagayancillo,Nalad Cagayancillo', 9.5769400, 121.2072200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108168, 'Cagamotan', 'Cagamotan', 'Cagamotan,Cagamutan', 12.3558300, 125.2839100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108169, 'Cafe', 'Cafe', 'Cafe', 15.3368600, 120.7062300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108170, 'Cadlan', 'Cadlan', 'Cadlan', 13.5971000, 123.2570000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108171, 'Cadiz', 'Cadiz', 'Cadiz,Cadiz Viejo', 10.9465000, 123.2880000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108172, 'Caditaan', 'Caditaan', 'Cadetaan,Caditaan', 12.8052800, 123.8491700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108173, 'Cadagmayan Norte', 'Cadagmayan Norte', 'Cadagmayan Norte', 10.8166700, 122.5000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108174, 'Cabuyao', 'Cabuyao', 'Cabuyao,Cabuyao City,Cabúyao,Lungsod ng Cabuyao,ka bu yao,卡布堯', 14.2726000, 121.1262000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108175, 'Cabusao', 'Cabusao', 'Baksalan,Cabusao', 13.7227000, 123.1169000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108176, 'Caburan', 'Caburan', 'Caburan', 5.9180600, 125.6411100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108177, 'Cabungan', 'Cabungan', 'Cabungan', 16.3399900, 119.9949000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108178, 'Cabulay', 'Cabulay', '', 16.7455600, 121.4975000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108179, 'Cabul-an', 'Cabul-an', 'Cabul-an', 10.1568400, 124.0439700, 'PH', '2016-11-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108180, 'Cabugao', 'Cabugao', 'Cabugao,Kabugao', 17.7931000, 120.4578000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108181, 'Cabugao', 'Cabugao', 'Cabugao', 13.5962000, 124.2804000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108182, 'Cabugao', 'Cabugao', 'Cabugao,Cabugao Lucena', 10.8102800, 122.5447200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108183, 'Cabucgayan', 'Cabucgayan', 'Cabucgayan', 11.4719400, 124.5750000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108184, 'Cabra', 'Cabra', 'Cabra', 13.8883300, 120.0494400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108185, 'Cabog', 'Cabog', 'Cabog', 15.3153000, 121.3703000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108186, 'Kablalan', 'Kablalan', 'Cablallan,Kablalan', 5.7797200, 125.1977800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108187, 'Cabittaogan', 'Cabittaogan', 'Cabittaogan', 17.5778800, 120.3591400, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108188, 'Cabitan', 'Cabitan', 'Cabitan', 12.2943400, 123.3412100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108189, 'Cabiraoan', 'Cabiraoan', 'Cabiraoan', 18.3237700, 122.0859500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108190, 'Cabinuangan', 'Cabinuangan', 'Cabinuangan', 7.6833300, 126.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108191, 'Cabilauan', 'Cabilauan', 'Cabilauan,Cabilawan,Kabilaoan,Kabilauan', 10.8922200, 122.6591700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108192, 'Kabilauan', 'Kabilauan', 'Cabilauan,Kabilaoan,Kabilauan', 10.8610000, 122.5734000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108193, 'Cabilao', 'Cabilao', 'Cabilao,Cabilao Pequeno,Cabilao Pequeño,Kabilao', 11.5396000, 123.1436000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108194, 'Cabiguan', 'Cabiguan', 'Cabibiang,Cabiguan', 12.9058300, 123.7313900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108195, 'Cabadiangan', 'Cabadiangan', 'Cabadiangan,Cabidiangan', 10.1459000, 122.9431000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108196, 'Cabiao', 'Cabiao', 'Cabiao', 15.2488000, 120.8548000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108197, 'Cabcaben', 'Cabcaben', 'Cabcaben', 14.4540000, 120.5914000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108198, 'Cabcab', 'Cabcab', 'Alibon,Cabcab', 13.6268000, 124.0515000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108199, 'Cabayaoasan', 'Cabayaoasan', 'Cabayaoasan', 15.6632300, 120.5513500, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108200, 'Cabayangan', 'Cabayangan', 'Cabayangan', 7.4072200, 125.7330600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108201, 'Cabay', 'Cabay', 'Cabay', 13.8708000, 121.3799200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108202, 'Cabay', 'Cabay', 'Cabay', 11.4455600, 125.4933300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108203, 'Cabatuan', 'Cabatuan', 'Cabatuan,Cabatuan Centro,Cabatuán', 16.9565500, 121.6685400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108204, 'Cabatuan', 'Cabatuan', 'Cabatoan,Cabatuan,Kabatoan', 12.5228000, 125.2202000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108205, 'Cabatuan', 'Cabatuan', 'Cabatuan', 10.8794000, 122.4860000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108206, 'Cabatang', 'Cabatang', 'Cabatang', 13.9669000, 121.3668000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108207, 'Cabarroguis', 'Cabarroguis', 'Cabarroguis,Cabarroquis', 16.5110500, 121.5211800, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108208, 'Cabaritan East', 'Cabaritan East', 'Cabaritan,Cabaritan East', 18.4178100, 121.4887200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108209, 'Cabano', 'Cabano', 'Cabano', 10.5869000, 122.7002000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108210, 'Cabannungan Second', 'Cabannungan Second', 'Cabannungan,Cabannungan II,Cabannungan Second', 17.1249000, 121.8506000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108211, 'Cabanglasan', 'Cabanglasan', 'Cabanglasan', 8.1213900, 125.3275000, 'PH', '2013-12-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108212, 'Cabangan', 'Cabangan', 'Cabangan', 15.1580000, 120.0569000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108213, 'Cabangahan', 'Cabangahan', 'Cabangahan,Cabangjan', 9.0781000, 122.9469000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108214, 'Cabangahan', 'Cabangahan', 'Cabangahan', 8.0227800, 125.1375000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108215, 'Cabanbanan', 'Cabanbanan', 'Cabanbanan', 14.2404000, 121.4341000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108216, 'Cabanbanan', 'Cabanbanan', 'Cabanbaan,Cabanbanan', 10.0852000, 122.9579000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108217, 'Cabanatuan City', 'Cabanatuan City', 'Cabanatuan,Cabanatuan City,Cabanatúan,Ciudad ti Cabanatuan', 15.4858600, 120.9664800, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108218, 'Cabaluay', 'Cabaluay', 'Cabaluay,Caboluoy', 7.0013900, 122.1802800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109192, 'Chuhar Jamāli', 'Chuhar Jamali', '', 24.3944000, 67.9929800, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109193, 'Timargara', 'Timargara', 'Timargara,Timugara,Timurgara,Tīmurgara', 34.8265900, 71.8442300, 'PK', '2015-07-02', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109194, 'Rāwala Kot', 'Rawala Kot', 'RAZ,Rawala Kot,Rawalkote,Rawlakot,Rāwala Kot', 33.8578200, 73.7604300, 'PK', '2017-04-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109195, 'Pir Jo Goth', 'Pir Jo Goth', 'Kingri,Pir Goth,Pir Jo Goth,Pir jo Goth,Pīr jo Goth', 27.5917800, 68.6184800, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109196, 'Khairpur', 'Khairpur', 'Khaipur,Khairpur,Khairpur Mirs,Khairpur Mīrs,Khajrpura,Хайрпура', 27.5294800, 68.7617000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109197, 'Ādilpur', 'Adilpur', 'Adalpur,Adilpur,Adulpoor,Us''mar Ruk Malpur,Us’mar Ruk Malpur,Ādalpur,Ādilpur', 27.9369700, 69.3186900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109198, 'Ziārat', 'Ziarat', 'Ziarat,Ziārat', 30.3824400, 67.7256200, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109199, 'Zhob', 'Zhob', 'Apozai,Fort Sandeman,Fort Sanderman,PZH,Zhob', 31.3408200, 69.4493000, 'PK', '2016-10-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109200, 'Zaida', 'Zaida', 'Zaida', 34.0595000, 72.4669000, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109201, 'Zāhir Pīr', 'Zahir Pir', 'Zahir Pir,Zāhir Pīr', 28.8123900, 70.5240500, 'PK', '2012-05-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109202, 'Zafarwāl', 'Zafarwal', 'Zafarwal,Zafarwāl,Zaffarwal', 32.3446400, 74.8999000, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109203, 'Yazman', 'Yazman', 'Yazman', 29.1212200, 71.7445900, 'PK', '2014-03-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109204, 'Wazīrābād', 'Wazirabad', 'Wazirabad,Wazīrābād', 32.4432400, 74.1200000, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109205, 'Warburton', 'Warburton', 'Uorberton,Warburton,Уорбертон', 31.5500000, 73.8333300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109206, 'Wārāh', 'Warah', '', 27.4480500, 67.7965400, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109207, 'Wana', 'Wana', 'Waha,Wana,Wano,Wāha,Wāna,Wāno', 32.2988900, 69.5725000, 'PK', '2014-09-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109208, 'Vihāri', 'Vihari', 'Vehari,Vihari,Vihāri', 30.0445000, 72.3556000, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109209, 'Utmānzai', 'Utmanzai', 'Utmanzai,Utmānzai,Uttamanza,Uttmanzai', 34.1877500, 71.7627400, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109210, 'Uthal', 'Uthal', 'Utal,Uthal', 25.8072200, 66.6219400, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109211, 'Usta Muhammad', 'Usta Muhammad', 'Ushda,Usta,Usta Muhammad', 28.1772300, 68.0436700, 'PK', '2016-09-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109212, 'Umarkot', 'Umarkot', '', 25.3615700, 69.7362400, 'PK', '2011-07-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109213, 'Ubauro', 'Ubauro', '', 28.1642900, 69.7311400, 'PK', '2016-06-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109214, 'Turbat', 'Turbat', 'TUK,Turbat,trbt,tu er ba te,turbt,Турбат,تربت,تُربت,土爾巴特', 26.0012200, 63.0484900, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109215, 'Topi', 'Topi', 'Topi,Топи', 34.0703400, 72.6214700, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109216, 'Toba Tek Singh', 'Toba Tek Singh', 'Toba Tek Singh', 30.9743300, 72.4826900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109217, 'Thul', 'Thul', 'Thul,Thul Sind', 28.2403500, 68.7758800, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109218, 'Thatta', 'Thatta', 'Tata,Tatta,Thatta,tatta,te da shi,thatta,Татта,טהאטה,ٹھٹہ,ٺٽو,ठट्टा,থাট্টা,თატა,タッター,特達市', 24.7474500, 67.9235300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109219, 'Thāru Shāh', 'Tharu Shah', '', 26.9423000, 68.1175900, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109220, 'Taunsa', 'Taunsa', 'Taunsa', 30.7048300, 70.6505100, 'PK', '2012-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109221, 'Tānk', 'Tank', '', 32.2170700, 70.3831500, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109222, 'Tangwāni', 'Tangwani', 'Tangwan,Tangwani,Tangwān,Tangwāni', 28.2788600, 68.9976000, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109223, 'Tangi', 'Tangi', 'Tangi', 34.3009000, 71.6523800, 'PK', '2015-07-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109224, 'Tando Muhammad Khān', 'Tando Muhammad Khan', 'Tando Mohammad Khan,Tando Muhammad Khan,Tando Muhammad Khān', 25.1238400, 68.5367700, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109225, 'Tāndo Mittha Khān', 'Tando Mittha Khan', 'Tando Mittha Khan,Tandomithakhan,Tāndo Mittha Khān', 25.9944400, 69.2024700, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109226, 'Tando Jām', 'Tando Jam', 'Tando Jam,Tando Jām', 25.4281300, 68.5292300, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109227, 'Tando Bāgo', 'Tando Bago', 'Tando Bago,Tando Bāgo', 24.7885700, 68.9661400, 'PK', '2012-05-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109228, 'Tando Allāhyār', 'Tando Allahyar', 'Tando Alahyar,Tando Allahyar,Tando Allāhyār', 25.4605000, 68.7174500, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109229, 'Tando Ādam', 'Tando Adam', '', 25.7681800, 68.6619600, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109230, 'Tāndliānwāla', 'Tandlianwala', 'Tandlianwala,Tāndliānwāla', 31.0333300, 73.1333300, 'PK', '2012-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109231, 'Talhār', 'Talhar', 'Talhar,Talhār', 24.8833300, 68.8166700, 'PK', '2014-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109232, 'Talamba', 'Talamba', 'Talamba,Tolamba,Tulamba Town', 30.5270800, 72.2401100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109233, 'Talagang', 'Talagang', 'Talagang', 32.9297300, 72.4158300, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109234, 'Tāl', 'Tal', 'Tal,Tal'',Thal,Tāl,Таль', 35.4790800, 72.2438500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109235, 'Swābi', 'Swabi', 'Swabi,Swābi', 34.1201800, 72.4698200, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109236, 'Surkhpur', 'Surkhpur', 'Surakhpur,Surkhpur', 32.7166700, 74.4500000, 'PK', '2013-06-26', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109237, 'Sūrāb', 'Surab', 'Soorab,Sorab,Surab,Sūrāb', 28.4927600, 66.2599900, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109238, 'Sukkur', 'Sukkur', 'Gorad Sukur,SKZ,Sukkur,Sukur,Sukuras,Szukkur,Szukkúr,sakhkhara,sakkaru,skr,skr  pakstan,su ku er,sukuleu,Горад Сукур,Суккур,Сукур,سکر,سکر، پاکستان,سکھر,सख्खर,サッカル,蘇庫爾,수쿠르', 27.7051600, 68.8573800, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109239, 'Sukheke Mandi', 'Sukheke Mandi', 'Sukheke Mandi', 31.8638800, 73.5112200, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109240, 'Sohbatpur', 'Sohbatpur', '', 28.5203800, 68.5429800, 'PK', '2016-09-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109241, 'Sodhri', 'Sodhri', 'Sodhra,Sodhri,Sodlira,Sohdra Town', 32.4621100, 74.1820700, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109242, 'Sobhodero', 'Sobhodero', 'Sobbodero,Sobhadero,Sobho Dero,Sobhodero,Sobhādero', 27.3047500, 68.3971500, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109243, 'Skārdu', 'Skardu', 'KDU,Shardu,Skardo,Skardu,Skārdu', 35.2978700, 75.6337200, 'PK', '2017-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109244, 'Sīta Road', 'Sita Road', '', 27.0333300, 67.8500000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109245, 'Sinjhoro', 'Sinjhoro', 'Sinjhoro,Sinjihoro', 26.0300800, 68.8086700, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109246, 'Sillānwāli', 'Sillanwali', 'Sillanwali,Sillānwāli', 31.8253900, 72.5406400, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109247, 'Sibi', 'Sibi', 'Ibis,SBQ,Sibi,Sibis,sby,Сиби,Сібі,سبي,سبی', 29.5429900, 67.8772600, 'PK', '2016-10-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109248, 'Sialkot', 'Sialkot', 'Gorad Sijalkot,SKT,Sialkot,Sialkotas,Sialkote,Sijalkot,Siālkot,ciyalkot,shiarukoto,si''alakota,sialkoteu,siyalakota,syalkwt  pakstan,syalkwٹ,xi ya er ke te,Горад Сіялкот,Сиалкот,Сиялкот,Сијалкот,سيالکوټ,سیالکوت، پاکستان,سیالکوٹ,सियालकोट,শিয়ালকোট,ਸਿਆਲਕੋਟ,சியால்கோட்,സിയാൽകോട്ട്,シアールコート,锡亚尔科特,시알코트', 32.4926800, 74.5313400, 'PK', '2014-08-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109249, 'Shujāābād', 'Shujaabad', 'Shujaabad,Shujabad,Shujāābād', 29.8796700, 71.2931300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109250, 'Shorkot', 'Shorkot', 'Shorko,Shorkot', 31.9102300, 70.8775700, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109251, 'Shinpokh', 'Shinpokh', 'Shinpokh,Shinpokh-Samsai,Shīnpokh', 34.3295900, 71.1785200, 'PK', '2015-10-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109252, 'Shikarpur', 'Shikarpur', 'Shikarpur,Shikārpur', 27.9555800, 68.6382300, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109253, 'Sheikhupura', 'Sheikhupura', 'Qila Sheikhupura,Sekhupura,Sheikhu Pura,Sheikhupura,Sheikkhupura,Shekhupura,Shekhūpura,Shekkhupura,ceykkuppura,sekhupura,shykhwpwra,shykhwpwrh,shykhwpwrh  pakstan,xie hu bu er,Śekhupura,Шеикхупура,Шекхупура,شيخوپوره,شیخوپورا,شیخوپوره، پاکستان,شیخوپورہ,ਸ਼ੇਖ਼ੂਪੁਰਾ,சேய்க்குப்புரா,謝胡布爾', 31.7130600, 73.9783300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109254, 'Sharqpur Sharīf', 'Sharqpur Sharif', 'Sharakpur,Shargpur,Sharqpur,Sharqpur Sharif,Sharqpur Sharīf', 31.4611600, 74.1009100, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109255, 'Shakargarh', 'Shakargarh', 'Shakargarh,Shakargarr', 32.2636100, 75.1600800, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109256, 'Shahr Sultān', 'Shahr Sultan', '', 29.5751700, 71.0220900, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109257, 'Shāhpur Chākar', 'Shahpur Chakar', 'Shahpur Chaka,Shahpur Chakar,Shahpur Chaker,Shāhpur Chaka,Shāhpur Chākar', 26.1541100, 68.6501300, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109258, 'Shāhpur', 'Shahpur', '', 32.2676000, 72.4720400, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109259, 'Shahkot', 'Shahkot', 'Shah kot,Shahkot,Shāh kot,Shāhkot', 31.5709000, 73.4853100, 'PK', '2012-07-31', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109260, 'Shāhdādpur', 'Shahdadpur', 'Shahdadpur,Shāhdādpur', 25.9253900, 68.6228000, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109261, 'Shahdād Kot', 'Shahdad Kot', 'Shahdad Kot,Shahdadkot,Shahdadpur,Shahdād Kot,Shāhdādkot,Shāhdādpur', 27.8472600, 67.9067900, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109262, 'Shabqadar', 'Shabqadar', 'Shabgadar Fort,Shabkadar,Shabqadar,Shapqadar', 34.2159900, 71.5548000, 'PK', '2015-07-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109263, 'Sehwān', 'Sehwan', 'SYW,Sehwan,Sehwān', 26.4249500, 67.8612600, 'PK', '2017-04-02', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109264, 'Sargodha', 'Sargodha', 'SGI,Sargoda,Sargodha,Sargodkha,sa ge da,saleugoda,saragodha,sarugoda,srgwdha,Саргода,Саргодха,سرگودها,سرگودھا,सरगोढा,ਸਰਗੋਧਾ,サルゴーダー,萨戈达,사르고다', 32.0836100, 72.6711100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109265, 'Sarāi Sidhu', 'Sarai Sidhu', '', 30.5947600, 71.9699000, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109266, 'Sarāi Naurang', 'Sarai Naurang', 'Naurang Sarai,Naurang Sarāi,Sarai Naurang,Sarāi Naurang', 32.8259100, 70.7813600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109267, 'Sarāi Ālamgīr', 'Sarai Alamgir', 'Sarai Alamgir,Sarāi Ālamgīr,srayے ʿalmgyr,سرائے عالمگیر', 32.9049500, 73.7551800, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109268, 'Sann', 'Sann', 'Sann', 26.0403000, 68.1376300, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109269, 'Sanjwāl', 'Sanjwal', '', 33.7610500, 72.4331500, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109270, 'Sangla Hill', 'Sangla Hill', 'Sangla Hill', 31.7166700, 73.3833300, 'PK', '2014-10-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109271, 'Sānghar', 'Sanghar', 'Sangar,Sanghar,Sānghar', 26.0469400, 68.9491700, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109272, 'Sambriāl', 'Sambrial', 'Sambrial,Sambriāl', 32.4783500, 74.3533800, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109273, 'Samaro', 'Samaro', 'Samara,Samaro', 25.2814300, 69.3962300, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109274, 'Sakrand', 'Sakrand', 'Sakrand,Sakrano', 26.1384500, 68.2744400, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109275, 'Saidu Sharif', 'Saidu Sharif', 'Saidu,Saidu Sharif,Saidu Sharīf', 34.7465500, 72.3556800, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109276, 'Sāhīwāl', 'Sahiwal', 'Sahiwal,Sakhivale,Sohiwal,Sāhīwāl,Sōhiwāl,Сахивале', 31.9738600, 72.3310900, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109277, 'Sahiwal', 'Sahiwal', 'Gorad Sakhival,Montgomery,SWN,Sahivalas,Sahiwal,Sakhival,Sāhīwāl,sa xi wa er,sahivala,sahywal,sahywal  pakstan,saہiwal,Горад Сахівал,Сахивал,ساهيوال,ساهیوال، پاکستان,ساہِيوال,ساہیوال,साहिवाल,ਸਾਹੀਵਾਲ,薩希瓦爾', 30.6666700, 73.1000000, 'PK', '2013-05-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109278, 'Sādiqābād', 'Sadiqabad', 'Sadikabad,Sadiqabad,Sādikābād,Sādiqābād', 28.3062300, 70.1306500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108219, 'Cabalitian', 'Cabalitian', 'Cabalician,Cabalitian', 16.0883000, 120.7922000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108220, 'Cabalawan', 'Cabalawan', 'Cabalawan,Kabalawan', 10.7413900, 123.9525000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108221, 'Cabalaoangan', 'Cabalaoangan', 'Cabalaoangan', 15.9833300, 120.7833300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108222, 'Kabac', 'Kabac', 'Cabac,Cabak,Kabac,Kabak', 11.2353000, 123.6979000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108223, 'Cabognon', 'Cabognon', 'Cabagnan,Cabognon', 13.1829000, 123.6777000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108224, 'Cabagan', 'Cabagan', 'Cabagan,Cabagán', 17.4278200, 121.7695500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108225, 'Cabodiongan', 'Cabodiongan', 'Cabadiangan,Cabodiongan,Kabadiangan', 12.6643000, 125.0456000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108226, 'Cabadiangan', 'Cabadiangan', 'Cabadiangan', 9.7534000, 122.4739000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108227, 'Cabadbaran', 'Cabadbaran', 'Cabadbaran', 9.1226100, 125.5354900, 'PH', '2015-04-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108228, 'Cabacuñgan', 'Cabacungan', 'Cabacongan,Cabacungan,Cabacuñgan', 10.9333300, 124.9816700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108229, 'Cabacungan', 'Cabacungan', 'Cabacungan', 10.3237000, 123.1331000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108230, 'Cabacao', 'Cabacao', 'Cabacao', 13.3356000, 120.6588000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108231, 'Caba', 'Caba', 'Caba', 16.4316000, 120.3446000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108232, 'Caabiangan', 'Caabiangan', 'Caabiangan,Cabilocaan', 16.0874000, 119.9245000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108233, 'Buyuan', 'Buyuan', 'Buyoan,Buyuan', 10.6708600, 122.3574000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108234, 'Buyo', 'Buyo', 'Buyo', 13.6813000, 123.4733000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108235, 'Buyo', 'Buyo', 'Buyo', 13.1144000, 123.8666000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108236, 'Buyabod', 'Buyabod', 'Buvabod,Buyabod,Buyabud', 13.4666000, 122.0526000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108237, 'Buug', 'Buug', 'Buug', 7.7294000, 123.0598000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108238, 'Butulan', 'Butulan', 'Butulan', 5.6144400, 125.4316700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108239, 'Butubut Norte', 'Butubut Norte', 'Butubat Norte,Butubot Norte,Butubut,Butubut Norte', 16.8034000, 120.4344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108240, 'Butuan', 'Butuan', 'BXU,Butuan,Butuan City,Butuan Lakanbalen,Butuanas,City of Butuan,Dakbayan sa Butuan,Kota Butuan,Lungsod ng Butuan,Syudad nin Butuan,buto~uan,butuan,bwtwan,putuvan,wu duan shi,بوتوان,புடுவன்,ブトゥアン,武端市,부투안', 8.9491700, 125.5436100, 'PH', '2016-02-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108241, 'Butigui', 'Butigui', 'Butigui,Butiqui', 17.1153400, 121.4330400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108242, 'Butig', 'Butig', 'Butig', 7.7244400, 124.3008300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108243, 'Butazon', 'Butazon', 'Butasan l,Butason,Butazon', 11.3072000, 124.4620000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108244, 'Butag', 'Butag', 'Butag', 12.6292000, 123.9335000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108245, 'Busuanga', 'Busuanga', 'Busuanga,USU', 12.1584700, 119.9178100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108246, 'Brgy. New Buswang, Kalibo', 'Brgy. New Buswang, Kalibo', 'Busuang', 11.7122200, 122.3847200, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108247, 'Bustos', 'Bustos', 'Bustos,Бустос', 14.9580600, 120.9177800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108248, 'Busing', 'Busing', 'Busing', 13.1513900, 122.9713900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108249, 'Busilak', 'Busilak', 'Busilac,Busilak', 16.4775000, 121.1241000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108250, 'Busdi', 'Busdi', 'Busde,Busdi', 8.2761100, 125.2513900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108251, 'Busay', 'Busay', 'Busay,Busay Hacienda', 10.5378000, 122.8860000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108252, 'Boroon', 'Boroon', 'Buru-un', 8.1827800, 124.1770100, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108253, 'Barurao', 'Barurao', 'Barurao', 6.8980600, 124.5975000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108254, 'Buruanga', 'Buruanga', 'Buruanga', 11.8442800, 121.8884100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108255, 'Burirao', 'Burirao', 'Burirao', 9.2000000, 118.1000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108256, 'Burias', 'Burias', 'Burias', 11.4463000, 122.5497000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108257, 'Burias', 'Burias', 'Burias', 5.7177800, 125.2536100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108258, 'Burgos', 'Burgos', 'Burgos', 18.5165800, 120.6449200, 'PH', '2015-04-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108259, 'Burgos', 'Burgos', 'Burgos', 17.3324000, 120.4954000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108260, 'Burgos', 'Burgos', 'Burgos', 17.0891400, 121.7025400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108261, 'Burgos', 'Burgos', 'Burgos', 16.8246000, 121.7331300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108262, 'Burgos', 'Burgos', '', 16.5186100, 120.4627800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108263, 'Burgos', 'Burgos', 'Burgos', 16.0718100, 121.0495400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108264, 'Burgos', 'Burgos', 'Burgos', 16.0583000, 119.8650000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108265, 'Burgos', 'Burgos', 'Burgos', 15.7289200, 120.5722400, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108266, 'Burgos', 'Burgos', 'Burgos', 15.4946500, 120.4045300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108267, 'Burgos', 'Burgos', 'Burgos', 9.2663900, 126.1883300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108268, 'Burdeos', 'Burdeos', 'Burdeos,Burdoes', 14.8430200, 121.9690600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108269, 'Buray', 'Buray', 'Buray', 10.7150000, 122.4594400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108270, 'Burauen', 'Burauen', 'Burauen', 10.9755600, 124.8927800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108271, 'Buracan', 'Buracan', 'Buracan,Burakan', 13.6000000, 123.5000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108272, 'Burabod', 'Burabod', 'Barabod,Burabod,Burabud', 13.2686000, 123.4162000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108273, 'Bukid', 'Bukid', 'Bukid,Buquid', 5.5716700, 125.4055600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108274, 'Bunol', 'Bunol', 'Bunal,Bunol', 15.6671000, 120.8344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108275, 'Bunog', 'Bunog', 'Bunog', 9.1402800, 117.7816700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108276, 'Bungoy', 'Bungoy', 'Bongoy,Bungoy', 13.9977900, 121.3656400, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108277, 'Bunguiao', 'Bunguiao', 'Bungiao,Bunguiao', 7.1044400, 122.1963900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108278, 'Bungahan', 'Bungahan', 'Bungahan', 13.9428600, 120.6617800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108279, 'Bunga', 'Bunga', 'Bonga,Bunga', 11.4838000, 124.5918000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108280, 'Bunga', 'Bunga', 'Bunga', 10.7731000, 124.7847000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108281, 'Bundoc', 'Bundoc', 'Bundoc', 15.4857500, 120.7174300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108282, 'Buawan', 'Buawan', 'Bunawan', 8.3166700, 124.3030600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108283, 'Bunawan', 'Bunawan', 'Bunauan,Bunawan', 8.1672200, 125.9908300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108284, 'Bumbaran', 'Bumbaran', 'Bumbaran', 7.8000000, 124.6500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108285, 'Brgy. Bulwang, Numancia', 'Brgy. Bulwang, Numancia', '', 11.7219400, 122.3611100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108286, 'Bulusan', 'Bulusan', 'Bulusan,Bulusani vald', 12.7493600, 124.1208700, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108287, 'Buluangan', 'Buluangan', 'Buluangan', 10.3870700, 123.3381000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108288, 'Buluang', 'Buluang', 'Buluang', 13.3068000, 123.3425000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108289, 'Buluang', 'Buluang', 'Buluang', 12.2333600, 119.8758100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108290, 'Buluan', 'Buluan', 'Buluan', 6.7202800, 124.8019400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108291, 'Bulualto', 'Bulualto', 'Balo Alto,Bulualto,Bulvalto', 15.2212700, 120.9532600, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108292, 'Bulu', 'Bulu', 'Bulo,Bulu', 17.3333300, 121.7666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108293, 'Bulog', 'Bulog', 'Buenlag,Bulog', 15.9602000, 120.4017000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108294, 'Bulod', 'Bulod', 'Bulod', 9.6833300, 123.1500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108295, 'Buliwao', 'Buliwao', 'Buliwao', 16.4833300, 121.2333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108296, 'Bulit', 'Bulit', 'Bulet,Bulit', 7.1152800, 124.7894400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108297, 'Buliran Segundo', 'Buliran Segundo', 'Buliran,Buliran Second,Buliran Segundo,Buliran Two', 15.2666700, 120.8666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108298, 'Buliran', 'Buliran', 'Buliran', 15.5460200, 120.9595900, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108299, 'Buliok', 'Buliok', 'Buliok,Buliuk', 7.0166700, 124.7000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108300, 'Bulihan', 'Bulihan', 'Bulihan', 14.8758100, 120.8956300, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108301, 'Bulihan', 'Bulihan', 'Bulihan', 14.1560000, 120.6441000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108302, 'Bulihan', 'Bulihan', 'Bulihan', 13.8091000, 121.2485000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108303, 'Buldon', 'Buldon', 'Buldon,Buldun,Calaan', 7.5097200, 124.3713900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108304, 'Bulaon', 'Bulaon', 'Bulaon,Bulaun', 15.0826200, 120.6628800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108305, 'Bulatukan', 'Bulatukan', 'Balatukan,Bulatukan', 6.9025000, 125.1608300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108306, 'Bulata', 'Bulata', 'Bulata', 9.8599000, 122.4016000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108307, 'Bulasa', 'Bulasa', 'Bulasa', 9.9320600, 123.6180200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108308, 'Bularit', 'Bularit', 'Bularit', 15.5682400, 120.6216700, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108309, 'Bolanon', 'Bolanon', 'Bolanon,Bulanon', 10.9171000, 123.4734000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108310, 'Bulan', 'Bulan', 'Bulan,Bulsan,Булан', 12.6713900, 123.8750000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108311, 'Bulalacao', 'Bulalacao', 'Bulalacao,Bulalakao', 12.3253500, 121.3435100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108312, 'Bulalacao', 'Bulalacao', 'Bulalacao', 16.8358000, 120.8085000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108313, 'Bulalacao', 'Bulalacao', 'Bulalacao', 11.7435000, 120.1715000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108314, 'Bulad', 'Bulad', 'Bulad', 10.2548000, 122.9983000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108315, 'Bulacnin', 'Bulacnin', 'Bulacanin,Bulacnin', 13.9903000, 121.1390000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108316, 'Bulacan', 'Bulacan', 'Bulacan', 14.7927800, 120.8788900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108317, 'Bulacan', 'Bulacan', 'Bulacan', 6.5675000, 125.4211100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108318, 'Bula', 'Bula', 'Bula', 13.4701000, 123.2780000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108319, 'Bula', 'Bula', 'Bula', 11.4480000, 122.5685000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108320, 'Bukal Sur', 'Bukal Sur', 'Bukal,Bukal Sur', 13.9380600, 121.3855600, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108321, 'Bukal', 'Bukal', 'Bucal,Bukal', 13.9132000, 121.5264000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108322, 'Bukal', 'Bukal', 'Bukal', 13.8364000, 121.0939000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108323, 'Buhi', 'Buhi', 'Buhi,Bulu', 13.4322000, 123.5170000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108324, 'Buhatan', 'Buhatan', 'Buhatan', 12.9755000, 124.0478000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108325, 'Buhangin', 'Buhangin', 'Buhangin', 6.4911100, 125.5475000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108326, 'Buguias', 'Buguias', 'Buguias,Bugujas', 16.7226700, 120.8283400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108327, 'Buguey', 'Buguey', 'Bugney,Buguey', 18.2882300, 121.8331000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108328, 'Bugsoc', 'Bugsoc', 'Bugsoc', 9.7834000, 124.2712000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108329, 'Bugo', 'Bugo', '', 8.5083300, 124.7594400, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108330, 'Bugko', 'Bugko', 'Bugko,Bugto,Bugtu', 12.5356000, 124.7923000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108331, 'Bugcaon', 'Bugcaon', 'Bugcaon', 8.0458300, 125.1127800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108332, 'Bugasong', 'Bugasong', 'Bugasong', 11.0446400, 122.0646300, 'PH', '2015-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108333, 'Bugasan', 'Bugasan', 'Bugasan,Bugasan Sur', 7.4408300, 124.2591700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108334, 'Bugas', 'Bugas', 'Bugas', 9.8980400, 123.4049200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108335, 'Bugang', 'Bugang', 'Bugang', 10.7418500, 123.3933000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108336, 'Bugallon', 'Bugallon', 'Bugallon', 15.9528000, 120.2155000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108337, 'Bugaan', 'Bugaan', 'Bugaan', 14.0398700, 120.9360900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108338, 'Buga', 'Buga', 'Buga', 13.2966000, 123.3596000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108339, 'Buga', 'Buga', 'Buga', 10.7166700, 122.2666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108340, 'Buensuseso', 'Buensuseso', 'Buensuceso,Buensuseso', 15.1933300, 120.6731400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108341, 'Buenlag', 'Buenlag', 'Buenlag', 15.8297600, 120.5113900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108342, 'Buenlag', 'Buenlag', 'Buenlag', 15.6274300, 120.5819900, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108343, 'Buenavista', 'Buenavista', 'Buenavista,Buenavista Norte', 10.0833300, 124.1161100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108344, 'Buenavista', 'Buenavista', 'Buenavista', 13.8670000, 123.3020000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108345, 'Buenavista', 'Buenavista', 'Buenavista', 13.2551100, 121.9414900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108346, 'Buenavista', 'Buenavista', 'Buenavista', 12.1763900, 123.7905600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108347, 'Buenavista', 'Buenavista', 'Buenavista', 10.7987400, 123.5544000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108348, 'Buenavista', 'Buenavista', '', 10.7011100, 122.6275000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108349, 'Buenavista', 'Buenavista', 'Buenavista', 10.6146600, 123.0994000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108350, 'Buenavista', 'Buenavista', 'Buenavista', 10.5440600, 123.4478000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108351, 'Buenavista', 'Buenavista', 'Buenavista', 10.1776000, 123.6013000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108352, 'Buenavista', 'Buenavista', 'Buenavista', 10.1379000, 123.2439000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108353, 'Buenavista', 'Buenavista', 'Buenavista', 9.8405600, 124.2225000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108354, 'Buenavista', 'Buenavista', 'Buenavista', 9.1150000, 126.1608300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108355, 'Buenavista', 'Buenavista', 'Buenavista', 8.9769400, 125.4088900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108356, 'Buenavista', 'Buenavista', '', 7.2361100, 122.2552800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108357, 'Bued', 'Bued', 'Bued', 16.1608600, 119.9988000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108358, 'Bued', 'Bued', 'Bued', 15.8365700, 120.6500600, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108359, 'Budta', 'Budta', 'Budta', 7.2041700, 124.4397200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108360, 'Bucloc', 'Bucloc', 'Bucloc,Lamao', 17.4411300, 120.8588500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108361, 'Buclad', 'Buclad', 'Buclad', 7.5277800, 125.7505600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108362, 'Bucay Pait', 'Bucay Pait', 'Bucay Pait,Bukay Pait', 6.5641700, 124.7675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108363, 'Bucay', 'Bucay', 'Bucay', 17.5404000, 120.7188000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108364, 'Babug', 'Babug', 'Babug,Bubog,Bubug', 12.3732500, 121.0417100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108365, 'Buayan', 'Buayan', 'Boayan', 6.1163900, 125.2347200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108366, 'Buanoy', 'Buanoy', 'Buanoy', 10.4674600, 123.6999000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108367, 'Buang', 'Buang', 'Buang', 13.3115000, 123.6421000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108368, 'Bualan', 'Bualan', 'Bualan', 7.7500000, 124.2666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108369, 'Bual', 'Bual', 'Bual', 7.1825000, 124.5058300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108370, 'Bual', 'Bual', 'Bialong,Bilan,Bual', 6.7958300, 124.9108300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108371, 'Buagsong', 'Buagsong', '', 10.2530200, 123.9390900, 'PH', '2016-10-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108372, 'Buadiposo-Buntong', 'Buadiposo-Buntong', 'Buadiposo-Buntong', 7.9666700, 124.3833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108373, 'Boton', 'Boton', 'Bogtong,Boton,Buton', 12.9287000, 124.0479000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108374, 'Botolan', 'Botolan', 'Botolan', 15.2896000, 120.0245000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108375, 'Botigues', 'Botigues', 'Botigues,Botiguis', 11.0995000, 123.6675000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108376, 'Botao', 'Botao', 'Botao', 15.9166700, 120.4166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108377, 'Boston', 'Boston', 'Boston', 7.8711100, 126.3641700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108378, 'Bosdak', 'Bosdak', 'Bosdak', 13.4000000, 122.5000000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108379, 'Borongan', 'Borongan', 'Borongan City,Kota Borongan,bwrwngan,بورونگان', 11.6080600, 125.4319400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108380, 'Yapak', 'Yapak', 'Japak,Япак', 11.9500000, 121.9333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108381, 'Borbon', 'Borbon', 'Borbon', 10.8380000, 124.0297000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108382, 'Borbon', 'Borbon', 'Borbon', 8.4841700, 125.8930600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108383, 'Boot', 'Boot', 'Boot', 14.0455600, 121.0772200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108384, 'Bood', 'Bood', 'Bood', 9.7450800, 123.8278300, 'PH', '2017-05-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108385, 'Bontoc', 'Bontoc', 'Bontoc,Bontoz', 17.0873100, 120.9768500, 'PH', '2014-09-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108386, 'Bontoc', 'Bontoc', 'Bontoc', 10.3556000, 124.9697000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108387, 'Bongued', 'Bongued', 'Bongued', 7.1166700, 124.4000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108388, 'Bungsuan', 'Bungsuan', 'Bongsu-an,Bungso-an,Bungsuan', 11.2404000, 122.6976000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108389, 'Bongao', 'Bongao', 'Bangaw,Bongao,Bongao Poblacion,Bonggao,Bonggaw,bongao,bwnagaw  tawy tawy,بوناگاؤ، تاوی تاوی,ボンガオ', 5.0291700, 119.7730600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108390, 'Boñgalon', 'Bongalon', 'Bongalon,Boñgalon', 16.0002200, 120.1590400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108391, 'Bungabon', 'Bungabon', 'Bongabong,Bungabon', 7.2221000, 125.8731000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108392, 'Bongabon', 'Bongabon', 'Bongabon', 15.6321000, 121.1448000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108393, 'Bonga', 'Bonga', 'Bonga,Bunga', 13.2799000, 123.7587000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108394, 'Bonga', 'Bonga', 'Bonga', 13.2166700, 123.5500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108395, 'Bone South', 'Bone South', 'Bone,Bone South', 16.2446000, 120.9958000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108396, 'Bonbon', 'Bonbon', 'Banban,Bonbon', 10.2245000, 123.5573000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108397, 'Bonawon', 'Bonawon', 'Bonauon,Bonawon', 9.1340000, 122.9193000, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108398, 'Bombon', 'Bombon', 'Bombon', 13.6887000, 123.2077000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108399, 'Bolong', 'Bolong', 'Bolong', 10.8166700, 122.5166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108400, 'Bolong', 'Bolong', '', 7.0983300, 122.2391700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108401, 'Bolo Bolo', 'Bolo Bolo', 'Bolo Bolo', 8.5583300, 124.5300000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108402, 'Bolo', 'Bolo', 'Bolo', 15.9948000, 120.1647000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108403, 'Bolo', 'Bolo', 'Bolo', 13.7899100, 120.9817300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108404, 'Bolo', 'Bolo', 'Bolo', 13.7530000, 122.9658000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108405, 'Bulo', 'Bulo', 'Bolo,Bulo', 12.4109000, 123.5672000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108406, 'Bolo', 'Bolo', 'Balo,Bolo', 11.5402800, 122.7572200, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108407, 'Boljoon', 'Boljoon', 'Baljoon,Boljoon', 9.6281000, 123.4785000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108408, 'Bolitoc', 'Bolitoc', 'Bolitoc,Longos', 15.7395000, 119.8769000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108409, 'Bolisong', 'Bolisong', '', 9.6911100, 123.1516700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108410, 'Bolingit', 'Bolingit', 'Bolingit,Bolinguit', 15.9587300, 120.3496000, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108411, 'Boliney', 'Boliney', 'Boliney', 17.4077300, 120.7811500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108412, 'Bolinao', 'Bolinao', 'Bolinao', 16.3883000, 119.8923000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108413, 'Bolilao', 'Bolilao', 'Bolilao', 10.8833300, 122.7333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108414, 'Bolila', 'Bolila', 'Bolila', 6.3716700, 125.5713900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108415, 'Bolboc', 'Bolboc', 'Bolboc', 14.0207400, 120.7559500, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108416, 'Bulawin', 'Bulawin', 'Bolawon,Bulawen,Bulawin', 15.4173000, 119.9564000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108417, 'Bolaoit', 'Bolaoit', 'Bolaoit,Bolawit', 15.9321800, 120.4307300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108418, 'Bokod', 'Bokod', 'Bokod', 16.4895000, 120.8313000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108419, 'Bogtong', 'Bogtong', 'Bogtong,Bugtong', 15.7553600, 120.3289900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108420, 'Bogo', 'Bogo', 'Bogo,Bogo City,Kota Bogo', 11.0517000, 124.0055000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108421, 'Bogo', 'Bogo', 'Bogo', 9.8568600, 123.5641700, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108422, 'Bodega', 'Bodega', 'Bodega', 14.9229000, 120.4798200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108423, 'Bocos', 'Bocos', 'Bocos', 16.9264600, 121.0573400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108424, 'Bocaue', 'Bocaue', 'Bocaue', 14.7983300, 120.9261100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108425, 'Bocana', 'Bocana', 'Bocana,Bocania', 10.0116000, 122.7217000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108426, 'Bobon Second', 'Bobon Second', 'Bobon,Bobon 2,Bobon Second,Bobon Segundo', 15.6565300, 120.3811900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108427, 'Bobonan', 'Bobonan', 'Bobonan', 16.1348000, 120.5271000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108428, 'Bobon', 'Bobon', 'Bobon', 12.5246000, 124.5636000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108429, 'Bobon', 'Bobon', 'Bobon', 6.8678200, 126.3283800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108430, 'Buayan', 'Buayan', 'Boayan,Buayan', 7.2611100, 124.5294400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108431, 'Buan', 'Buan', 'Bo''an,Bo’an,Buan', 5.1608000, 120.0426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108432, 'Boac', 'Boac', 'Boac,boakeu,bwak  maryndwk,بواک، ماریندوک,보아크', 13.4463000, 121.8400000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108433, 'Blinsung', 'Blinsung', 'Blensong,Blinsung', 7.0180600, 124.1805600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108434, 'Blingkong', 'Blingkong', 'Blingkong', 6.5722200, 124.8772200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108435, 'Biwang', 'Biwang', 'Biwang', 6.5972200, 124.5552800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108436, 'Bituñgol', 'Bitungol', 'Bitungol,Bituñgol', 14.8833300, 121.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108437, 'Biton', 'Biton', 'Bito-on', 11.2327900, 123.9993000, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108438, 'Bitoon', 'Bitoon', 'Bitoon', 10.0804000, 123.4587000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108439, 'Bitin', 'Bitin', 'Beaton,Bitin', 14.1164700, 121.2219400, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108440, 'Bitaogan', 'Bitaogan', 'Bitaogan,Bitaugan', 6.7684200, 126.0773800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108441, 'Bitanjuan', 'Bitanjuan', 'Bitahuan,Bitanghaun,Bitanghuan,Bitanhuan,Bitanjuan', 10.5955000, 124.7663000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108442, 'Bitangan', 'Bitangan', 'Bitangan', 14.2538900, 120.8783300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108443, 'Bitag Grande', 'Bitag Grande', 'Bitag,Bitag Grande', 17.9024400, 121.8501300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108444, 'Bitadtun', 'Bitadtun', 'Bitadton,Bitadtun', 11.4969000, 122.0851100, 'PH', '2016-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108445, 'Bislig', 'Bislig', 'Bislig,Bitlig', 11.0725000, 125.0336100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108446, 'Bislig', 'Bislig', 'BPH,Bislig,Bislig City,Bislig Lakanbalen,Dakbayan sa Bislig,Kota Bislig,Lungsod ng Bislig,bi si li ge shi,bslg,بسلگ,比斯利格市', 8.2152800, 126.3163900, 'PH', '2013-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108447, 'Biri', 'Biri', 'Beri,Biri', 12.6833300, 124.3636100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108448, 'Binantocan', 'Binantocan', 'Binantocan,Binantucan,Binuntucan', 11.4073000, 122.8602000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108449, 'Binulasan', 'Binulasan', 'Binolasan,Binulasan,Binulusan', 14.7315900, 121.6978100, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108450, 'Binucayan', 'Binucayan', 'Binucayan', 8.2500000, 125.7166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108451, 'Binubusan', 'Binubusan', 'Binabusan,Binubusan', 13.9694700, 120.6357200, 'PH', '2015-04-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108452, 'Binuangan', 'Binuangan', '', 8.9152800, 124.7883300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108453, 'Bintawan', 'Bintawan', 'Bintauan,Bintawan', 16.5758800, 121.1876400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108454, 'Bintacay', 'Bintacay', 'Bintacay,Bintakay', 13.4986000, 121.8768000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108455, 'Binonga', 'Binonga', 'Binonga', 10.7719000, 122.9817000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108456, 'Binon-an', 'Binon-an', 'Binon-an', 11.3947000, 123.1426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108457, 'Binodegahan', 'Binodegahan', 'Binodegahan', 13.0614000, 123.4579000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108458, 'Binmaley', 'Binmaley', 'Binmaley', 16.0323200, 120.2690400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108459, 'Binlod', 'Binlod', 'Binlod', 9.9184500, 123.6074300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108460, 'Binitinan', 'Binitinan', 'Binitinan', 8.7100000, 124.7755600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108461, 'Binitayan', 'Binitayan', 'Binitayan', 13.2945000, 123.7579000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108462, 'Binidayan', 'Binidayan', 'Binidayan', 7.8066800, 124.1684600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108463, 'Binguang', 'Binguang', 'Binguan,Binguang', 17.4589300, 121.7951900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108464, 'Bingawan', 'Bingawan', 'Bingawan', 11.2330000, 122.5672000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108465, 'Payabon', 'Payabon', 'Bindoy,Pagabon,Payabon', 9.7590000, 123.1412000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108466, 'Binday', 'Binday', 'Binday', 16.1281200, 120.4523800, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108467, 'Bincoñgan', 'Bincongan', 'Bincongan,Bincoñgan,Bincungan', 7.3666700, 125.7500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108468, 'Binay', 'Binay', 'Binay', 13.5019000, 122.5983000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108469, 'Binanwanaan', 'Binanwanaan', 'Binanuaan,Binanuaanan,Binanwanaan', 13.7000000, 123.3000000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108470, 'Binangonan', 'Binangonan', 'Binangonan', 14.4646000, 121.1929000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108471, 'Biñan', 'Binan', 'Binan,Binan City,Binyang,Biñan,Biñan City,Biñán,Ciudad nin Binan,Ciudad nin Biñan,Kota Binan,Kota Biñan,Lungsod ng Binan,Lungsod ng Biñan,bngan,بنگان', 14.3426700, 121.0807100, 'PH', '2017-05-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108472, 'Binalonan', 'Binalonan', 'Binalonan,Binalonán', 16.0503000, 120.5926000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108473, 'Binalbagan', 'Binalbagan', 'Binalbagan', 10.1948000, 122.8581000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108474, 'Binalan', 'Binalan', 'Binalan', 18.3275000, 121.5451000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108475, 'Binahaan', 'Binahaan', 'Binahaan,Binajaan,Binhaan', 13.9917000, 121.7539100, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108476, 'Binabalian', 'Binabalian', 'Binabalian,Binabalian Ricor', 16.4202000, 119.9279000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108477, 'Binabaan', 'Binabaan', 'Binaba-an Portigo,Binabaan', 11.0191000, 122.5221000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108478, 'Bilwang', 'Bilwang', 'Bilwang', 10.8834000, 124.4667000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108479, 'Bilog-Bilog', 'Bilog-Bilog', 'Bilog-Bilog', 14.1136100, 121.0886100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108480, 'Bil-Loca', 'Bil-Loca', 'Bil-Loca', 18.0875000, 120.5687000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108481, 'Biliran', 'Biliran', 'Biliran,Bilirano,Propinsi Biliran,Provincia de Biliran,Provincia de Bilirán,Provincia di Biliran,bi li lan sheng,billilan ju,biriran zhou,bylyran,Билиран,بيليران,بیلیران,ビリラン州,比利兰省,빌리란 주', 11.4669400, 124.4739600, 'PH', '2015-04-26', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108482, 'Bilaran', 'Bilaran', 'Bilaran,Bilnan', 14.0352800, 120.7102800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108483, 'Bilar', 'Bilar', 'Bilar', 9.7082500, 124.1071700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108484, 'Bilao', 'Bilao', 'Bilao', 11.4880000, 122.5599000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108485, 'Bilad', 'Bilad', 'Bilad', 15.7367600, 120.4332100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108486, 'Biking', 'Biking', 'Biking', 9.5938200, 123.8430300, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108487, 'Bignay Uno', 'Bignay Uno', 'Bignay,Bignay Uno', 13.8644500, 121.4879200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108488, 'Bigaan', 'Bigaan', 'Bigaan', 8.3172200, 126.2811100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108489, 'Bigaa', 'Bigaa', 'Bigaa', 13.1993000, 123.7566000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108490, 'Biga', 'Biga', 'Biga', 14.2575900, 120.9719500, 'PH', '2013-12-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108491, 'Biga', 'Biga', 'Biga', 13.3106000, 121.1610000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108492, 'Biga', 'Biga', 'Biga', 8.3577800, 124.2597200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108493, 'Bien Unido', 'Bien Unido', 'Bahabaha,Bien Unido,Buen Unido', 10.1372900, 124.3776100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108494, 'Bicos', 'Bicos', 'Bicos', 15.6602000, 121.0414000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108495, 'Bibiclat', 'Bibiclat', 'Bibiclat,Bibiclot,Biclot', 15.5218600, 120.8623500, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108496, 'Bical Norte', 'Bical Norte', 'Bical,Bical Norte', 15.8147100, 120.4350900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108497, 'Biasong', 'Biasong', 'Biasong', 10.5229000, 123.7360000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108498, 'Biao', 'Biao', 'Biao', 10.1088000, 122.9772000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108499, 'Biao', 'Biao', '', 7.1633300, 125.5211100, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108500, 'Bialong', 'Bialong', 'Bialong', 6.9805600, 124.8888900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108501, 'Biabas', 'Biabas', 'Biabas', 9.8000000, 124.4666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108502, 'Betwagan', 'Betwagan', 'Betwagan', 17.0833300, 120.9666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108503, 'Besao', 'Besao', 'Basac,Besao,Besao West', 17.0950000, 120.8579000, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108504, 'Benito Soliven', 'Benito Soliven', 'Benito Soliven', 16.9815500, 121.9599400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108505, 'Belison', 'Belison', 'Belison', 10.8384000, 121.9605000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108506, 'Belance', 'Belance', 'Belance', 16.1833300, 121.2500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108507, 'Begang', 'Begang', 'Begang', 6.6909000, 122.0168000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108508, 'Beddeng', 'Beddeng', 'Beddeng,Bedung', 14.9772800, 120.0849300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108509, 'Becerril', 'Becerril', 'Becerril,Becirel', 9.6531000, 123.4344000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108510, 'Beberon', 'Beberon', 'Beberon,Beberron', 13.5444000, 123.1405000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108511, 'Bayuin', 'Bayuin', 'Bayuin', 13.0411000, 121.3885200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108512, 'Bayugan', 'Bayugan', 'Bayugan', 8.7561100, 125.7675000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108513, 'Bayombong', 'Bayombong', 'Bayombong,baywmbwng,بائومبونگ', 16.4812000, 121.1497000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108514, 'Bayog', 'Bayog', '', 7.8666700, 123.0666700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108515, 'Baylo', 'Baylo', 'Baylo', 7.8551400, 126.0556300, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108516, 'Baybayin', 'Baybayin', 'Baybayin', 13.8208300, 121.2699200, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108517, 'Baybay', 'Baybay', 'Baybay', 13.4083000, 123.7135000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108518, 'Baybay', 'Baybay', 'Baybay,Baybay City,Kota Baybay,بےبے', 10.6785000, 124.8006000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108519, 'Bayawan', 'Bayawan', 'Bayawan,Bayawan Lakanbalen,Kota Bayawan,Tolong,Tolong Nuevo,Tulong,bayawan,بایاوان', 9.3649000, 122.8040000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108520, 'Bayasong', 'Bayasong', 'Bayasong', 6.6488900, 124.8730600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108521, 'Bayas', 'Bayas', 'Bayas', 11.4336000, 123.1816000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108522, 'Bayaoas', 'Bayaoas', 'Bayaoas', 15.8340400, 120.2647800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108523, 'Bay-ang', 'Bay-ang', 'Bay-ang', 11.0347200, 122.9416700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108524, 'Bayang', 'Bayang', 'Bayang', 7.7927800, 124.1916700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108525, 'Bayanan', 'Bayanan', 'Bayanan,Jolo', 13.3592000, 121.1699000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108526, 'Bayambang', 'Bayambang', 'Bayambang,Bayembang', 15.8127000, 120.4557000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108527, 'Bayabas', 'Bayabas', 'Bayabas', 16.4500000, 120.5166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108528, 'Bayabas', 'Bayabas', '', 8.9697200, 126.2861100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108529, 'Bay', 'Bay', 'Bay,Bej,Бей', 14.1836800, 121.2855400, 'PH', '2014-11-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108530, 'Bawison', 'Bawison', 'Bawisan,Bawison', 5.9375000, 120.8745000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108531, 'Bautista', 'Bautista', 'Bautista', 15.7836200, 120.4984800, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108532, 'Bautista', 'Bautista', 'Bautista', 13.9944400, 121.2777800, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108533, 'Baunu-Timbangan', 'Baunu'' Timbangan', 'Baunu'' Timbangan,Baunu-Timbangan,Bounu Timbagan,Timbangan', 6.0054700, 120.9940600, 'PH', '2011-09-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108534, 'Bauko', 'Bauko', 'Banko,Bauk,Bauko', 16.9898000, 120.8671000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108535, 'Baugo', 'Baugo', '', 10.3174500, 123.9190000, 'PH', '2015-03-28', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108536, 'Bauang', 'Bauang', '', 16.5308300, 120.3330600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108537, 'Bauan', 'Bauan', 'Bauan', 17.7225600, 121.6802800, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108538, 'Bauan', 'Bauan', 'Bauan', 13.7917000, 121.0085000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108539, 'Bau', 'Bau', 'Bao,Bau', 7.4052800, 124.6497200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108540, 'Batutitik', 'Batutitik', 'Batotitic,Batutitik,Tocawal,Tokawal,Tukawal', 6.2233300, 125.2519400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108541, 'Batuan', 'Batuan', 'Batuan', 12.3976000, 123.7627900, 'PH', '2016-06-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108542, 'Batuan', 'Batuan', 'Batuan', 9.7808000, 124.1484000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108543, 'Battung', 'Battung', 'Battung,Batung', 17.7226100, 121.4591400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108544, 'Batobalane', 'Batobalane', 'Batobalane,Batobalani', 14.2333300, 122.7500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108545, 'Bato', 'Bato', 'Bato', 13.6068000, 124.2986000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108546, 'Bato', 'Bato', 'Bato', 13.3528000, 123.3677000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108547, 'Bato', 'Bato', 'Bato', 10.8085400, 123.3733000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108548, 'Bato', 'Bato', 'Bato', 10.8250000, 119.4710000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108549, 'Bato', 'Bato', '', 10.3277800, 124.7911100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108550, 'Bato', 'Bato', 'Bato', 8.6027000, 123.6449000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108551, 'Bato', 'Bato', 'Bago', 7.0430600, 125.4730600, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108552, 'Batitang', 'Batitang', 'Batitang', 15.4004000, 120.8027600, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108553, 'Batiano', 'Batiano', 'Batiano', 7.5534000, 126.4907000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108554, 'Bateria', 'Bateria', 'Bateria', 11.1416000, 124.0267000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108555, 'Batasan Bata', 'Batasan Bata', 'Batasan,Batasan Bata,Batasan-A,Batasan-B', 15.1444200, 120.9407700, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108556, 'Batasan', 'Batasan', 'Batasan', 12.7666700, 120.7833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108557, 'Batasan', 'Batasan', 'Batasan', 7.0333300, 125.0500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108558, 'Batas', 'Batas', 'Batas', 14.2000000, 120.8166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108559, 'Batarasa', 'Batarasa', 'Batarasa,Bataraza', 8.6733500, 117.6279500, 'PH', '2016-03-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108560, 'Batangas', 'Batangas', 'Batangas,Batangas City,Батангас', 13.7567000, 121.0584000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108561, 'Batana', 'Batana', 'Batana,Batang', 13.2498000, 123.5641000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108562, 'Batan', 'Batan', 'Bataan,Batan,Батаан', 11.5857000, 122.4971000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108563, 'Batal', 'Batal', '', 16.6875000, 121.6008300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108564, 'Bataquil', 'Bataquil', 'Batakil,Bataquil', 16.1552800, 120.5275000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108565, 'Batad', 'Batad', 'Batad', 11.4180000, 123.1080000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108566, 'Batac City', 'Batac City', 'City of Batac,Ciudad ti Batac,Lungsod ng Batac', 18.0554000, 120.5648900, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108567, 'Basud', 'Basud', 'Basud,Busod', 14.0650000, 122.9642000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108568, 'Basud', 'Basud', 'Basud', 12.9888900, 123.9500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108569, 'Basud', 'Basud', 'Basud', 11.3663000, 124.3631000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108570, 'Basista', 'Basista', 'Basista', 15.8524000, 120.3976000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108571, 'Basing', 'Basing', 'Basing', 15.9850500, 120.2683100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108572, 'Basilisa', 'Basilisa', 'Basilisa', 10.0000000, 125.5000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108573, 'Basicao Coastal', 'Basicao Coastal', 'Basicao Coastal', 13.0458900, 123.4042300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108574, 'Basiao', 'Basiao', 'Basiao', 11.5486100, 122.6375000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108575, 'Basiad', 'Basiad', 'Basiad', 14.1561700, 122.3374900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108576, 'Basey', 'Basey', 'Basey', 11.2820500, 125.0698600, 'PH', '2016-07-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108577, 'Basdiot', 'Basdiot', 'Basdiot', 9.9471800, 123.3751500, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108578, 'Basco', 'Basco', 'BSO,Basco,Basko,ba shi gu,baseuko,baskw  batanys,basuko,Баско,باسکو، باتانیس,バスコ,巴士古,바스코', 20.4486500, 121.9701700, 'PH', '2016-12-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108579, 'Bascaron', 'Bascaron', 'Bascaran,Bascaron', 13.1029000, 123.6999000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108580, 'Basay', 'Basay', 'Basay,Basey', 9.4087000, 122.6400000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108581, 'Basak', 'Basak', 'Basak', 8.0411100, 124.8627800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108582, 'Basak', 'Basak', 'Basak', 6.7273600, 124.1511700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108583, 'Basag', 'Basag', '', 8.9254800, 125.6216700, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108584, 'Basak', 'Basak', 'Basac,Basak', 10.2264000, 123.3064000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108585, 'Basa', 'Basa', 'Basa', 8.0722200, 126.0641700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108586, 'Barugo', 'Barugo', 'Barugo', 11.3241700, 124.7383300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108587, 'Barucboc Norte', 'Barucboc Norte', 'Barucboc Norte,Barucboo Norte,Barucbuc', 17.2585700, 121.6056100, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108588, 'Barra', 'Barra', 'Bara,Barra', 12.0717000, 123.6395000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108589, 'Barra', 'Barra', 'Barra', 8.5102800, 124.6044400, 'PH', '2017-05-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108590, 'Baroy', 'Baroy', 'Baroy', 8.0269000, 123.7784000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108591, 'Barotac Viejo', 'Barotac Viejo', 'Baratac Viejo,Barotac Viejo,Barotac Viejo Town,Barotak Viejo', 11.0419400, 122.8522200, 'PH', '2015-02-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108592, 'Barotac Nuevo', 'Barotac Nuevo', 'Barotac Nueva,Barotac Nuevo,Boratac Nueva', 10.8941700, 122.7044400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108593, 'Barongis', 'Barongis', 'Barongis', 7.2611100, 124.5641700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108594, 'Barong Barong', 'Barong Barong', 'Barong Barong', 8.8535000, 117.8939000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108595, 'Barong', 'Barong', 'Barong', 18.0576000, 120.7340000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108596, 'Barobo', 'Barobo', '', 8.5352800, 126.1213900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108597, 'Baro', 'Baro', 'Baro', 15.9989500, 120.6735000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108598, 'Barlig', 'Barlig', 'Barlig,Gawana', 17.0372500, 121.1038400, 'PH', '2011-08-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108599, 'Bariw', 'Bariw', 'Bariw', 13.1333300, 123.7333300, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108600, 'Barira', 'Barira', '', 7.4872200, 124.2991700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108601, 'Barili', 'Barili', 'Barili', 10.1150000, 123.5103000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108602, 'Barcelona', 'Barcelona', 'Barcelona,Barcelonela,Barceloneta', 13.7715000, 123.0485000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108603, 'Barcelona', 'Barcelona', 'Barcelona', 12.8683000, 124.1419000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108604, 'Barcelona', 'Barcelona', 'Barcelona', 8.5275000, 123.4587000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108605, 'Barcelona', 'Barcelona', 'Barcelon,Barcelona', 8.1591700, 126.4341700, 'PH', '2016-11-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108606, 'Barbaza', 'Barbaza', 'Barbasa,Barbasa Town,Barbaza', 11.1957200, 122.0386100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108607, 'Barayong', 'Barayong', 'Barayong', 13.1000000, 123.7166700, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108608, 'Baras', 'Baras', 'Baras,Барас', 14.5169100, 121.2658000, 'PH', '2015-01-30', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108609, 'Baras', 'Baras', 'Baras', 13.6588000, 124.3700000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108610, 'Baras', 'Baras', 'Baras', 11.1833300, 125.0166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108611, 'Barangobong', 'Barangobong', 'Barangobong', 15.8777800, 120.5483300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108612, 'Barahan', 'Barahan', 'Barahan', 13.0121000, 120.7620000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108613, 'Baracatan', 'Baracatan', 'Baracatan,Baracaton', 6.9675000, 125.4158300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108614, 'Baquero Norte', 'Baquero Norte', 'Baquero,Baquero Norte', 15.7162000, 120.5543000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108615, 'Baon', 'Baon', 'Baon', 6.7956200, 126.0877800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108616, 'Baud', 'Baud', 'Balud,Baod,Baud', 11.2111000, 123.7031000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108617, 'Bantuanon', 'Bantuanon', 'Bantoanon,Bantuanon', 8.0152800, 125.0708300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108618, 'Bantogon', 'Bantogon', 'Bantogon', 6.5333300, 124.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108619, 'Bantog', 'Bantog', 'Bantog,Bantug', 16.0091000, 120.6929000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108620, 'Bantilan', 'Bantilan', 'Bantilan', 14.7581400, 121.6690200, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108621, 'Bantiqui', 'Bantiqui', 'Bantigue,Bantigui,Bantique,Bantiqui', 10.9245000, 124.4154000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108622, 'Bantayan', 'Bantayan', 'Bantayan', 12.5237000, 124.8283000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108623, 'Bantayan', 'Bantayan', 'Banatayan,Bantayan', 11.1683000, 123.7223000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108624, 'Bantay', 'Bantay', 'Bantay', 17.5847200, 120.3891700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108625, 'Bantay', 'Bantay', 'Bantay', 17.4379300, 120.7577500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108626, 'Bansud', 'Bansud', '', 12.8650000, 121.4563900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108627, 'Bansalan', 'Bansalan', 'Bansalan,Dansalan,Miral', 6.7861100, 125.2133300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108628, 'Bangkirohan', 'Bangkirohan', 'Bangkirohan,Bankerohan,Bankiruhan,Banquarohan,Banquerohan', 13.0553000, 123.7468000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108629, 'Banquero', 'Banquero', 'Banguero,Banquero', 17.0230500, 121.7783400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108630, 'Banos', 'Banos', 'Banos', 12.6455300, 120.9097200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108631, 'Banog Sur', 'Banog Sur', 'Banog,Banog Sur', 16.1654200, 119.8980200, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108632, 'Banugao', 'Banugao', 'Banogao,Banugaa,Banugao,Banugaw', 14.7482500, 121.6184000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108633, 'Banocboc', 'Banocboc', 'Banocboc', 14.3000000, 122.5833300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108634, 'Bankaw', 'Bankaw', 'Bankaw,Tong Bangkaw', 5.0192000, 120.0091000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108635, 'Banisilan', 'Banisilan', 'Banisilan', 7.4908300, 124.7241700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108636, 'Banilad', 'Banilad', 'Banilad', 14.0667000, 120.7347000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108637, 'Banilad', 'Banilad', 'Banilad', 9.2786000, 123.2936000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108638, 'Bani', 'Bani', 'Bani', 16.1850000, 119.8613000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108639, 'Bani', 'Bani', 'Bani', 15.5823000, 119.9335000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108640, 'Banhigan', 'Banhigan', 'Banhigan', 9.8590300, 123.3892600, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108641, 'Bangui', 'Bangui', 'Bangi,Bangui', 18.5376000, 120.7671000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108642, 'Bangued', 'Bangued', 'Banged,banghwyd,bangwyd,bangwyd  abra,Бангед,بانغويد,بانگوئد,بانگوید، ابرا', 17.6083300, 120.6380600, 'PH', '2016-12-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108643, 'Bangonay', 'Bangonay', 'Bangonay', 9.3144400, 125.5538900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108644, 'Bangkal', 'Bangkal', 'Bangkal', 6.0666700, 121.0666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108645, 'Bangar', 'Bangar', 'Bangar', 16.8936000, 120.4243000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108646, 'Bangao', 'Bangao', 'Bangao', 16.8211000, 120.8404000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108647, 'Bangan-Oda', 'Bangan-Oda', 'Bangan-Oda', 16.1087000, 119.8307000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108648, 'Banganan', 'Banganan', 'Banganan', 16.3144000, 121.0544000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108649, 'Bangahan', 'Bangahan', 'Bangahan', 7.8044400, 124.7288900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108650, 'Bangad', 'Bangad', 'Bangad', 17.4954300, 121.7771400, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108651, 'Bangad', 'Bangad', 'Bangad', 15.5019000, 121.0275000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108652, 'Bangad', 'Bangad', 'Bangad', 12.1612500, 123.4013100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108653, 'Bañga', 'Banga', 'Banga,Bañga', 11.6387000, 122.3341000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108654, 'Banga', 'Banga', 'Bagna,Banga', 10.5018000, 122.8289000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108655, 'Bañga', 'Banga', 'Banga,Bañga', 6.4238900, 124.7783300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108656, 'Bancasi', 'Bancasi', 'Bancase,Bancasi,Bancosi', 8.9666700, 125.4666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108657, 'Bancal', 'Bancal', 'Bancal,Bankal', 11.5591000, 123.1551000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108658, 'Banayoyo', 'Banayoyo', 'Banayoyo', 17.2333300, 120.4833300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108659, 'Banaybanay', 'Banaybanay', 'Banaybanay,Banaybanay I', 13.9331000, 121.1151000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108660, 'Banaybanay', 'Banaybanay', '', 13.8500000, 121.2000000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108661, 'Banaybanay', 'Banaybanay', 'Banay-Banay,Banaybanay', 6.9623300, 126.0171700, 'PH', '2010-08-15', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108662, 'Banaue', 'Banaue', 'Banaue,Banawe', 16.9135600, 121.0618400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108663, 'Banawang', 'Banawang', 'Banawang,Bangwang', 14.6121000, 120.3900000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108664, 'Banawa', 'Banawa', 'Banawa,Bannawag', 7.1536100, 124.8666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108665, 'Banate', 'Banate', '', 11.0022200, 122.8175000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108666, 'Banalo', 'Banalo', 'Banalo', 13.6464000, 121.1817000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108667, 'Banag', 'Banag', 'Banag', 13.3788900, 123.7033300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108668, 'Banaba', 'Banaba', 'Banaba', 14.2166700, 120.8500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108669, 'Banaba', 'Banaba', 'Banaba', 13.8966000, 121.2100000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108670, 'Bambang', 'Bambang', 'Bambang,banban,バンバン', 16.3865000, 121.1066000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108671, 'Bamban', 'Bamban', 'Bamban', 15.6747000, 120.3315000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108672, 'Baluyot', 'Baluyot', 'Baluyot,Buluyot', 15.7958600, 120.4608800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108673, 'Balutu', 'Balutu', 'Baluti,Baluto,Balutu', 15.2987500, 120.6922600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108674, 'Balutakay', 'Balutakay', 'Balutakai,Balutakay', 6.7211100, 125.3516700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108675, 'Balut', 'Balut', 'Balut,Bulate', 14.6833300, 120.5500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108676, 'Balungao', 'Balungao', '', 15.8980600, 120.6883300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108677, 'Balugo', 'Balugo', 'Balugo', 12.5792300, 121.4393100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108678, 'Balud', 'Balud', 'Balud,Balug', 12.0368600, 123.1935100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108679, 'Balud', 'Balud', 'Balod,Balud', 11.6166700, 125.4333300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108680, 'Balud', 'Balud', 'Balud', 10.1476000, 123.6953000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108681, 'Balucuc', 'Balucuc', 'Balucog,Balucuc', 14.9528200, 120.8145200, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108682, 'Balsic', 'Balsic', 'Balsic,Balsik', 14.8590600, 120.4824000, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108683, 'Baloy', 'Baloy', 'Baloy', 15.8053000, 120.7742000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108684, 'Bal-os', 'Bal-os', 'Bal-os', 9.4416000, 122.6257000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108685, 'Mamungan', 'Mamungan', 'Baloi,Mamungan,Momungan,Mumungan,Munamgan', 8.1172200, 124.2186100, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108686, 'Balogo', 'Balogo', 'Balogo', 15.9903200, 120.2830200, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108687, 'Balogo', 'Balogo', 'Baloga,Balogo,Balugo,Bologo', 13.5016000, 123.0638000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108688, 'Balogo', 'Balogo', 'Balogo,Balugo', 13.2871000, 123.5496000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108689, 'Balogo', 'Balogo', 'Balogo,Balugo', 10.8868000, 124.7105000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108690, 'Balogo', 'Balogo', 'Baloge,Balogo', 10.1148000, 123.1706000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108691, 'Balogo', 'Balogo', 'Balogo', 7.2823000, 124.4638800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108692, 'Balocawehay', 'Balocawehay', 'Balocawehay,Balocawihay', 10.7221000, 124.9678000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108693, 'Balucawi', 'Balucawi', 'Balocaue,Balocawe,Balucaue,Balucawi', 12.2013000, 123.8426000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108694, 'Baloc', 'Baloc', 'Baloc', 15.6435000, 120.8852000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108695, 'Ballesteros', 'Ballesteros', 'Ballesteros', 18.4126000, 121.5152000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108696, 'Baliwagan', 'Baliwagan', 'Baliuagan,Baliwagan', 8.7186100, 124.7905600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108697, 'Baliuag Nuevo', 'Baliuag Nuevo', 'Baliuag,Baliuag Nuevo', 13.5214000, 123.2016000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108698, 'Baliwagan', 'Baliwagan', 'Baliuagan,Baliwagan', 10.3971000, 122.8911000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108699, 'Baliuag', 'Baliuag', 'Baliuag,Baliwag,Balíuag', 14.9547200, 120.8969400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108700, 'Baliton', 'Baliton', 'Baletan,Baliton', 5.7436100, 125.2363900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108701, 'Balitoc', 'Balitoc', 'Balitoc', 13.8626900, 120.6355400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108702, 'Balite Segundo', 'Balite Segundo', 'Balete No 2,Balete Segundo,Balite,Balite Segundo,Baliti Segundo', 14.1832000, 120.9743300, 'PH', '2013-12-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108703, 'Balite', 'Balite', 'Balite', 14.8952400, 120.7872100, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108704, 'Balinsacayao', 'Balinsacayao', 'Balinsacayao,Balinsasayao', 10.6810000, 124.9595000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108705, 'Balingueo', 'Balingueo', 'Balingueo', 15.9583000, 120.4097300, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108706, 'Balingoan', 'Balingoan', 'Balingoan', 9.0038900, 124.8519400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108707, 'Balingcanaway', 'Balingcanaway', 'Balinganauay,Balingcanauay,Balingcanaway,Belingcanway', 15.4821500, 120.6854300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108708, 'Balingasay', 'Balingasay', 'Balingasay', 16.3573000, 119.8564000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108709, 'Balingasag', 'Balingasag', 'Babagasag,Balingasag', 8.7441700, 124.7769400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108710, 'Balindong', 'Balindong', 'Balindong,Uato,Uatu,Watu', 7.9166700, 124.2002800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108711, 'Balinad', 'Balinad', 'Balinad', 13.2926000, 123.5454000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108712, 'Balimbing', 'Balimbing', 'Balimbing,Panglima Sugala', 5.0825000, 119.9658300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108713, 'Balilihan', 'Balilihan', 'Balilihan,Balilinan', 9.7561000, 123.9730000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108714, 'Balili', 'Balili', 'Balili,Baliti', 7.8950000, 123.7337000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108715, 'Balila', 'Balila', 'Balila', 8.0027800, 125.0130600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108716, 'Baligang', 'Baligang', 'Baligang', 13.1537000, 123.6432000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108717, 'Balibago', 'Balibago', 'Balibago', 15.1624000, 120.5954000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108718, 'Balibago', 'Balibago', 'Balibago', 13.9257200, 120.6255600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108719, 'Balibago', 'Balibago', 'Balibago', 13.6093000, 121.2971000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108720, 'Balibagan Oeste', 'Balibagan Oeste', 'Balibagan,Balibagan Oeste', 10.8000000, 122.5166700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108721, 'Balite', 'Balite', 'Balete,Balite', 15.6445100, 120.6419600, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108722, 'Balete', 'Balete', 'Balete', 14.0198300, 121.0950600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108723, 'Balete', 'Balete', 'Balete', 13.0191700, 124.0319400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108724, 'Calamundingan', 'Calamundingan', 'Balete,Balite,Calamundingan', 12.9310100, 121.4706200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108725, 'Balete', 'Balete', 'Balete', 11.5556000, 122.3803000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108726, 'Baler', 'Baler', 'BQA,Baler,balleleu,balr,balyr  arwra,بالر,بالیر، آرورا,발레르', 15.7589000, 121.5607000, 'PH', '2015-03-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108727, 'Baleno', 'Baleno', 'Baleno', 12.4739000, 123.4982000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108728, 'Balele', 'Balele', 'Balele', 14.0653200, 121.0936300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108729, 'Balbalan', 'Balbalan', '', 17.4413900, 121.2019400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108730, 'Balayong', 'Balayong', 'Balayong', 9.4744000, 123.0623000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108731, 'Balayang', 'Balayang', 'Balayang', 15.5495000, 120.6943000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108732, 'Balayan', 'Balayan', 'Balajan,Balayan,Балаян', 13.9371400, 120.7322400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108733, 'Balatero', 'Balatero', 'Balatero', 13.5021000, 120.9244000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108734, 'Balatan', 'Balatan', 'Balatan', 13.3211100, 123.2333300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108735, 'Balasing', 'Balasing', 'Balasing', 14.8545000, 121.0127000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108736, 'Balasan', 'Balasan', 'Balasan,Balasan Town', 11.4728000, 123.0878000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108737, 'Balas', 'Balas', 'Balas', 6.6875000, 122.1380600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108738, 'Balaogan', 'Balaogan', 'Balaogan', 13.4328000, 123.2818000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108739, 'Balaoang', 'Balaoang', 'Balaoang', 15.6633000, 120.5147000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108740, 'Balaoan', 'Balaoan', 'Balaoan', 16.8219000, 120.4045000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108741, 'Balangonan', 'Balangonan', 'Balanganan,Balangonan', 5.5733300, 125.3538900, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108742, 'Balangkayan', 'Balangkayan', 'Balangkayan', 11.4713900, 125.5105600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108743, 'Balangiga', 'Balangiga', 'Balangiga', 11.1097200, 125.3875000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108744, 'Balangbalang', 'Balangbalang', 'Balangbalang', 9.0569400, 125.6227800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108745, 'Balanga', 'Balanga', 'Balanga City,Kota Balanga,Syudad Balanga,balanga siti,balanga  batan,بالانگا، باتآن,बलांगा सिटी', 14.6761100, 120.5361100, 'PH', '2016-12-22', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108746, 'Balanacan', 'Balanacan', 'Balanacan,Balanakan', 13.5289000, 121.8677000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108747, 'Balamban', 'Balamban', 'Balamban,Balanban', 10.5039000, 123.7156000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108748, 'Balagunan', 'Balagunan', 'Balagunan', 7.4922200, 125.5211100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108749, 'Balagui', 'Balagui', 'Balagui,Balaquid', 11.4752000, 124.5324000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108750, 'Balagtas', 'Balagtas', 'Balagtas,Balagtos', 11.1333000, 124.5192000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108751, 'Balagtasin', 'Balagtasin', 'Balagtasin', 13.9018000, 121.0889000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108752, 'Balagtas', 'Balagtas', 'Balagtas,Tabang', 14.8166700, 120.8666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108753, 'Balagon', 'Balagon', 'Balagon', 8.0063000, 123.2396000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108754, 'Balading', 'Balading', 'Balading', 13.3906000, 123.7121000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108755, 'Balabagan', 'Balabagan', 'Balabagan', 7.5263900, 124.1141700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108756, 'Balabag', 'Balabag', 'Balabag,Балабаг', 11.9700000, 121.9191700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108757, 'Balabag', 'Balabag', 'Balabag', 10.7633300, 122.4930600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108758, 'Balabac', 'Balabac', 'Balabac', 7.9836300, 117.0486800, 'PH', '2014-11-16', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108759, 'Bakung', 'Bakung', 'Bakong,Bakung,Bakung Bakung', 4.8911100, 119.7941700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108760, 'Bakun', 'Bakun', 'Bakum,Bakun', 16.7895000, 120.6631000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108761, 'Bachauan', 'Bachauan', 'Bachauan,Bakhauan,Bakhawan,Bakjawan', 11.2067000, 123.9634000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108762, 'Brgy. Bachaw Norte, Kalibo', 'Brgy. Bachaw Norte, Kalibo', 'Bacao,Bakhao,Bakhaw', 11.7180600, 122.3780600, 'PH', '2017-05-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108763, 'Baka', 'Baka', 'Baka', 7.2761100, 124.2641700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108764, 'Bais', 'Bais', 'Bais,Bais City,Bais Lakanbalen,Bajs,Ciudad ti Bais,Dakbayan sa Bais,Kota Bais,bays  nygrws shrqy,jzyrt byz,Байс,بایس، نیگروس شرقی,جزيرة بيز', 9.5911100, 123.1227800, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108765, 'Bairan', 'Bairan', 'Bairan', 10.1971800, 123.7271000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108766, 'Bailan', 'Bailan', 'Bailan', 11.4584000, 122.8301000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108767, 'Bail', 'Bail', 'Bail', 16.2867000, 120.4004000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108768, 'Baikingon', 'Baikingon', '', 8.4722200, 124.5536100, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108769, 'Baheli', 'Baheli', 'Baheli,Bahile', 10.0136900, 118.7729400, 'PH', '2014-11-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108770, 'Bah-Bah', 'Bah-Bah', 'Bah-Bah', 8.6072200, 125.9144400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108771, 'Bahay Pare', 'Bahay Pare', 'Bahay Pare,Bahay Pary,Banay Par,Banay Pare,Banay Pari', 15.0323800, 120.8808300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108772, 'Bahay', 'Bahay', 'Bahay', 13.5437000, 123.0407000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108773, 'Bao', 'Bao', 'Bahao,Bao', 13.6414000, 122.8314000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108774, 'Bagupaye', 'Bagupaye', 'Bagupaye', 13.5650000, 122.3902000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108775, 'Bagombong', 'Bagombong', 'Bagombong,Bagumbong', 14.3413000, 121.3775000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108776, 'Bagumbayan', 'Bagumbayan', 'Bagumbayan', 18.1939000, 121.6630200, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108777, 'Bagumbayan', 'Bagumbayan', 'Bagumbayan', 17.7227100, 121.4469500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108778, 'Bagumbayan', 'Bagumbayan', 'Bagumbayan', 13.4500000, 123.6666700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108779, 'Bagumbayan', 'Bagumbayan', 'Bagumbayan', 13.4653000, 123.3899000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108780, 'Bagumbayan', 'Bagumbayan', 'Bagumbayan', 10.4460000, 122.8348000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108781, 'Bagulin', 'Bagulin', 'Bagulin,Cambaly', 16.6083300, 120.4394400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108782, 'Baguio', 'Baguio', 'BAG,Bagijas,Bagio,Baguio,Baguio City,Baguio Lakanbalen,Ciudad ti Baguio,Dakbayan sa Baguio,Kota Baguio,Lungsod ng Baguio,Siyudad na Baguio,Syudad nin Baguio,ba keiy w,bagio,bagyw,bi yao shi,pakiyo,Багио,باگیؤ,باگیو,பாகியோ,บาเกียว,バギオ,碧瑶市,바기오', 16.4163900, 120.5930600, 'PH', '2017-07-21', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108783, 'Baguinge', 'Baguinge', 'Baguinge', 16.7776700, 121.1062400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108784, 'Baguer', 'Baguer', 'Baguer', 7.2561100, 124.5041700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108785, 'Bagu', 'Bagu', 'Bagu', 18.4244100, 121.3557300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108786, 'Bagtic', 'Bagtic', 'Bagtic,Bagtik', 9.6864000, 123.0122000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108787, 'Bagroy', 'Bagroy', 'Bagroy', 10.2031000, 122.9362000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108788, 'Bagontapay', 'Bagontapay', 'Bagontapay', 6.8588900, 124.9088900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108789, 'Bagong Tanza', 'Bagong Tanza', 'Bagong,Bagong Tanza', 16.9826900, 121.6110900, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108790, 'Bagong-Sikat', 'Bagong-Sikat', 'Bagong Sicat,Bagong-Sikat', 15.4801000, 121.3073000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108791, 'Bagong Sikat', 'Bagong Sikat', 'Bagong Sikat', 12.3674500, 121.0617100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108792, 'Bagong Barrio', 'Bagong Barrio', 'Bagon,Bagong,Bagong Barrio,Bagong Baryo', 14.8899300, 120.9409500, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108793, 'Bago City', 'Bago City', 'Bago,City of Bago', 10.5333300, 122.8333300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108794, 'Bagay', 'Bagay', 'Bagay', 11.1964000, 124.0350000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108795, 'Baganga', 'Baganga', 'Baganga,Bangaga,Central', 7.5738900, 126.5600000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108796, 'Bayanga', 'Bayanga', 'Baganga,Bayanga', 7.5213900, 124.2522200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108797, 'Bagan', 'Bagan', 'Bagan', 6.9255600, 124.4202800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108798, 'Bagamanoc', 'Bagamanoc', 'Bagamanoc', 13.9404000, 124.2896200, 'PH', '2014-09-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108799, 'Bagalangit', 'Bagalangit', 'Bagalangit', 13.7104100, 120.8846700, 'PH', '2016-10-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108800, 'Bagakay', 'Bagakay', 'Bagakay', 8.1454000, 123.8157000, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108801, 'Bagahanlad', 'Bagahanlad', 'Bagahanglad,Bagahanlad', 12.5797000, 123.6688000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108802, 'Bagacay', 'Bagacay', 'Bagacay,Bagacy,Bogacay', 13.7770000, 123.3032000, 'PH', '2017-05-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108803, 'Bagacay', 'Bagacay', 'Bagacay', 12.9821000, 124.1415000, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108804, 'Bagacay', 'Bagacay', 'Bagacay', 10.1520900, 124.2585700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108805, 'Bagacay', 'Bagacay', 'Bagacay', 9.8664000, 123.9180000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108806, 'Bagac', 'Bagac', 'Bagac', 14.5962000, 120.3928000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108807, 'Bagabag', 'Bagabag', 'Bagabag', 16.6068000, 121.2542000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108808, 'Baggabag B', 'Baggabag B', 'Bagabag,Baggabag B', 16.5058800, 121.1901400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108809, 'Buadtasan', 'Buadtasan', 'Badtasan,Buadtasan', 6.0049600, 124.6126600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108810, 'Badoc', 'Badoc', 'Badoc', 17.9265000, 120.4764000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108811, 'Badlan', 'Badlan', 'Badlan,Badlan Grande,Badlang', 11.1414000, 122.5200000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108812, 'Badiangan', 'Badiangan', 'Badiangan,Badiaugan', 11.0057300, 122.5005100, 'PH', '2013-12-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108813, 'Badian', 'Badian', 'Badian', 13.0316700, 123.3077800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108814, 'Badian', 'Badian', 'Badian', 9.8647200, 123.3963900, 'PH', '2013-07-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108815, 'Bacuyangan', 'Bacuyangan', 'Bacuyangan', 9.6370000, 122.4721000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108816, 'Bacungan', 'Bacungan', '', 9.9105600, 118.7022200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108817, 'Bacundao Weste', 'Bacundao Weste', 'Bacondao,Bacundao,Bacundao West,Bacundao Weste', 15.9153600, 120.4766800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108818, 'Baculongan', 'Baculongan', 'Baculongan', 16.8000000, 120.8333000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108819, 'Bakulong', 'Bakulong', 'Baculong,Bakulong', 15.5379000, 120.6385000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108820, 'Baculin', 'Baculin', 'Baculin', 7.4525000, 126.5841700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108821, 'Bacuag', 'Bacuag', 'Bacnag,Bacuag', 9.6080600, 125.6388900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108822, 'Bactad Proper', 'Bactad Proper', 'Bactad,Bactad Proper,Bactad West', 15.9784200, 120.6102600, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108823, 'Bacsay', 'Bacsay', 'Bacsay', 15.6206300, 120.3434100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108824, 'Bacoor', 'Bacoor', 'Bacoor Lakanbalen,Bakoor,Lungsod ng Bacoor,bakwwr,Бакоор,باکوور', 14.4590300, 120.9290300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108825, 'Leon Postigo', 'Leon Postigo', 'Bacangan,Bacongan,Bacungan,Leon Postigo,Leon T. Postigo', 8.1551000, 122.9311000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108826, 'Bacong', 'Bacong', 'Bacong', 9.7393000, 124.5656000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108827, 'Bacong', 'Bacong', 'Bacong', 9.2464000, 123.2956000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108828, 'Bacon', 'Bacon', '', 13.0377800, 124.0411100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108829, 'Bacolor', 'Bacolor', 'Bacolor,Baculud', 15.0003000, 120.6520000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108830, 'Bacolod City', 'Bacolod City', 'BCD,Baclod City,Bacolod,Bacolod City,Bacoloo City,Bacólod,Ciudad ti Bacolod,Dakbayan sa Bacolod,Lungsod ng Bacolod,Syudad han Bacolod', 10.6666700, 122.9500000, 'PH', '2015-06-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108831, 'Bacolod', 'Bacolod', 'Bacolod', 12.2285400, 123.5085100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108832, 'Bacolod', 'Bacolod', 'Bacolod,Baculod', 8.9316700, 126.2894400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108833, 'Bacolod', 'Bacolod', 'Bacolod', 8.1166700, 123.9166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108834, 'Baco', 'Baco', 'Baco', 13.3573000, 121.0983000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108835, 'Bacnotan', 'Bacnotan', 'Bacnaton,Bacnotan', 16.7222200, 120.3525000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108836, 'Bacnor East', 'Bacnor East', 'Bacnor,Bacnor East', 17.0344900, 121.7037500, 'PH', '2013-05-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108837, 'Bacnar', 'Bacnar', 'Bacnar', 15.8864100, 120.3441900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108838, 'Baclayon', 'Baclayon', 'Baclayon', 9.6263900, 123.8941700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108839, 'New Baclayon', 'New Baclayon', 'Baclayon,New Baclayon', 6.5841700, 125.3694400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108840, 'Bacayawan', 'Bacayawan', 'Bacayawan,Bakayawan', 7.7666700, 124.2333300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108841, 'Bacarra', 'Bacarra', 'Bacarra', 18.2529000, 120.6125000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108842, 'Bacalan', 'Bacalan', 'Bacalan', 11.5464000, 122.0849000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108843, 'Bacag', 'Bacag', 'Bacag', 15.9300000, 120.5822200, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108844, 'Bacacay', 'Bacacay', 'Bacacay', 13.2934000, 123.7919000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108845, 'Bacabac', 'Bacabac', 'Bacabac', 15.7247700, 120.4281600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108846, 'Babo-Pangulo', 'Babo-Pangulo', '', 15.0833300, 120.5166700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108847, 'Babatngon', 'Babatngon', 'BabaiNgon,Babatangon,Babatngon', 11.4238000, 124.8449000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108848, 'Babak', 'Babak', '', 7.1363900, 125.6875000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108849, 'Babag', 'Babag', 'Babag', 7.7330900, 126.0713000, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108850, 'Baay', 'Baay', 'Baay', 18.1188000, 120.5753000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108851, 'Baao', 'Baao', 'Baao', 13.4549000, 123.3653000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108852, 'Azagra', 'Azagra', 'Azagra', 9.4779000, 123.1367000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108853, 'Ayusan Uno', 'Ayusan Uno', 'Ayusan,Ayusan I,Ayusan Uno', 13.9560900, 121.3076500, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108854, 'Ayungon', 'Ayungon', 'Ayugon,Ayungon', 9.8589000, 123.1444000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108855, 'Ayugan', 'Ayugan', 'Ayogan,Ayugan', 13.5469000, 123.3217000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108856, 'Aya', 'Aya', 'Aya', 13.8945000, 121.1139000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108857, 'Awang', 'Awang', 'Awang', 7.1530600, 124.2211100, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108858, 'Awallan', 'Awallan', 'Awallan', 17.9243900, 121.9130500, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108859, 'Avila', 'Avila', 'Avila', 10.6920000, 122.7090000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108860, 'Aurora', 'Aurora', 'Aurora', 16.9906500, 121.6366400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108861, 'Aurora', 'Aurora', 'Aurora', 13.2322000, 121.1203000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108862, 'Aurora', 'Aurora', 'Aurora', 8.5930600, 125.8375000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108863, 'Aurora', 'Aurora', 'Aurora', 7.9506000, 123.5826000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108864, 'Aurelliana', 'Aurelliana', 'Aureliana,Aurellana,Aurelliana', 10.8849000, 121.9769000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108865, 'Aumbay', 'Aumbay', 'Aumbay', 7.1026000, 125.7837000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108866, 'Atulayan', 'Atulayan', 'Atulayan', 17.6648000, 121.6937000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108867, 'Atop-atop', 'Atop-atop', 'Atop-atop', 11.2322000, 123.7602000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108868, 'Atok', 'Atok', 'Atok', 16.5835500, 120.6994900, 'PH', '2014-07-13', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108869, 'Atipuluhan', 'Atipuluhan', 'Alipuluan,Atipuluan,Atipuluhan', 10.5133600, 122.9621000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108870, 'Atimonan', 'Atimonan', 'Antimonan,Atimonan', 14.0027000, 121.9207800, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108871, 'Atabayan', 'Atabayan', 'Atabayan', 10.6833300, 122.4166700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108872, 'Cambanugoy', 'Cambanugoy', 'Asuncion,Cambanogoy,Cambanugoy,Kambanogoy,Saug', 7.5413000, 125.7553000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108873, 'Asturias', 'Asturias', 'Asturias', 10.5669000, 123.7161000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108874, 'Asturga', 'Asturga', 'Astorga,Asturga', 11.2544900, 122.8018000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108875, 'Astorga', 'Astorga', 'Astorga', 6.9072200, 125.4558300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108876, 'Asingan', 'Asingan', 'Asingan', 16.0051000, 120.6695000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108877, 'Asia', 'Asia', 'Asia,Azija,Isio,Азия', 9.5506000, 122.5164000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108878, 'Arteche', 'Arteche', 'Arteche', 12.2645000, 125.4048000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108879, 'Aroroy', 'Aroroy', 'Aroio,Aroro,Aroroy,Port Aroroy', 12.5111000, 123.3977000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108880, 'Arminia', 'Arminia', 'Armenia,Armeria,Arminia', 15.4356300, 120.5637900, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108881, 'Armenia', 'Armenia', 'Armenia,Arminia', 12.2532400, 123.7436100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108882, 'Aritao', 'Aritao', 'Aritao', 16.2979000, 121.0345000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108883, 'Aringay', 'Aringay', 'Aringay', 16.3940000, 120.3545000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108884, 'Argao', 'Argao', '', 9.8794400, 123.5955600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108885, 'Arenas', 'Arenas', 'Arenas', 15.1704200, 120.6857100, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108886, 'Arcangel', 'Arcangel', 'Arcangel', 11.5395000, 122.3455000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108887, 'Arayat', 'Arayat', 'Arayat', 15.1505000, 120.7697000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108888, 'Aras-asan', 'Aras-asan', 'Aras-asan,Arrasasan', 8.8878100, 126.3112000, 'PH', '2012-09-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108889, 'Aranda', 'Aranda', 'Aranda', 10.2365000, 122.9467000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108890, 'Aranas Sur', 'Aranas Sur', 'Aranas,Aranas Sur', 11.5635000, 122.3901000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108891, 'Aramawayan', 'Aramawayan', 'Aramawayan,Aramaywan', 9.3424700, 118.1623000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108892, 'Aramayuan', 'Aramayuan', 'Aramayuan,Aramaywan', 9.1700800, 118.1872000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108893, 'Araceli', 'Araceli', 'Araceli,Dumaran', 10.5529000, 119.9913000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108894, 'Araal', 'Araal', 'Araal', 10.4195000, 123.0437000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108895, 'Aquino', 'Aquino', 'Aguino,Aquino', 11.8221000, 122.1088000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108896, 'Apurawan', 'Apurawan', 'Aporawan,Apurahuan,Apurauan,Apurawan', 9.5994000, 118.3489000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108897, 'Apud', 'Apud', 'Apud', 13.1392800, 123.2916400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108898, 'Apoya', 'Apoya', 'Apoloy,Apoya', 9.2207000, 122.9053000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108899, 'Aplaya', 'Aplaya', 'Aplaya', 14.3210600, 121.1136900, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108900, 'Santa Rita Aplaya', 'Santa Rita Aplaya', 'Aplaya,Cota,Santa Rita Aplaya', 13.7717300, 121.0349200, 'PH', '2016-10-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108901, 'Aplaya', 'Aplaya', 'Aplaya', 8.6086100, 124.7680600, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108902, 'Apitong', 'Apitong', 'Apitong', 13.2391000, 121.2075000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108903, 'Aparri', 'Aparri', 'Aparri,Apparri,a pa li,阿帕里', 18.3566000, 121.6406000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108904, 'Apalit', 'Apalit', 'Apalit', 14.9533300, 120.7700000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108905, 'Apad', 'Apad', 'Apad', 13.8150000, 122.7664000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108906, 'Anuling', 'Anuling', 'Anuling', 14.1238800, 120.8922000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108907, 'Anuling', 'Anuling', 'Anuling', 6.0355600, 121.0066700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108908, 'Anulid', 'Anulid', 'Anulid', 15.8256300, 120.4883400, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108909, 'Luna', 'Luna', 'Antonio Luna,Luna', 12.5492000, 123.7336000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108910, 'Antipolo', 'Antipolo', 'Antipolo', 15.6181000, 121.1900000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108911, 'Antipolo', 'Antipolo', '', 14.6257800, 121.1225100, 'PH', '2015-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108912, 'Antipolo', 'Antipolo', 'Antipolo', 13.5286000, 123.1622000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108913, 'Antipolo', 'Antipolo', 'Antipolo', 13.3927000, 123.5231000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108914, 'Antipolo', 'Antipolo', 'Antipolo', 11.1666700, 123.9500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108915, 'Antipolo', 'Antipolo', 'Anlipolo,Antipolo', 10.3565000, 122.9646000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108916, 'Anticala', 'Anticala', '', 9.0044400, 125.6452800, 'PH', '2015-01-27', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108917, 'Antequera', 'Antequera', 'Anteguera,Antequera', 9.7809000, 123.8988000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108918, 'Antagan Segunda', 'Antagan Segunda', 'Antagan,Antagan Dos,Antagan Segunda', 17.2826800, 121.8715300, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108919, 'Anoring', 'Anoring', 'Anoring', 11.2500000, 123.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108920, 'Anopog', 'Anopog', 'Anopog', 10.2500000, 123.2500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108921, 'Anonang', 'Anonang', 'Anonang', 11.0000000, 124.0333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108922, 'Anuling', 'Anuling', 'Anoling,Anuling', 13.2093000, 123.6761000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108923, 'Anito', 'Anito', 'Anito', 12.4497200, 125.2886100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108924, 'Aanislag', 'Aanislag', 'Aanislag,Anislag,Anistag', 13.0748000, 123.7030000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108925, 'Anini-y', 'Anini-y', 'Anini-y,Aniniry,Aniniy Town', 10.4312000, 121.9270000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108926, 'Anilao', 'Anilao', 'Anilao', 12.7140200, 121.5124200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108927, 'Anilao', 'Anilao', '', 10.9777800, 122.7522200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108928, 'Ani-e', 'Ani-e', 'Ani-e,Anii', 8.6136100, 124.8705600, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108929, 'Anibongan', 'Anibongan', 'Anibongan', 7.3933300, 125.7188900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108930, 'Angono', 'Angono', 'Angono', 14.5266000, 121.1536000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108931, 'Angeles City', 'Angeles City', 'Angeles,Angeles City,CRK,anghelleseu,앙헬레스', 15.1500000, 120.5833300, 'PH', '2017-07-28', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108932, 'Angatel', 'Angatel', 'Angatel', 15.8058900, 120.3432600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108933, 'Angat', 'Angat', 'Angat,Santa Cruz', 14.9285000, 121.0300000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108934, 'Angadanan', 'Angadanan', 'Angadanan,Angadangan,Angadauan', 16.7552600, 121.7483400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108935, 'Angad', 'Angad', 'Angad', 17.5849000, 120.6257000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108936, 'Andres Bonifacio', 'Andres Bonifacio', 'A Bonifacio,Andres Bonifacio,Bonifacio', 10.9166700, 123.2500000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108937, 'Andili', 'Andili', 'Andili', 7.4620000, 125.9701000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108938, 'Anda', 'Anda', 'Anda', 16.2892000, 119.9500000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108939, 'Anda', 'Anda', 'Anda', 9.7460000, 124.5767000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108940, 'Anao', 'Anao', 'Anao', 15.7291000, 120.6253000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108941, 'Anao', 'Anao', 'Anao', 15.1415000, 120.6913600, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108942, 'Anambongan', 'Anambongan', 'Anambongan', 15.8663400, 120.3885800, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108943, 'Anakan', 'Anakan', 'Anakan', 8.8477800, 125.1513900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108944, 'Anahawan', 'Anahawan', 'Anahawan', 10.3429000, 124.8782000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108945, 'Anahawan', 'Anahawan', 'Anahawan', 10.2772200, 125.2625000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108946, 'Amuñgan', 'Amungan', 'Amungan,Amungen,Amuñgan', 15.3652000, 119.9582000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108947, 'Amulung', 'Amulung', 'Amulong,Amulung', 17.8357000, 121.7237500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108948, 'Amucao', 'Amucao', 'Amucao', 15.4640500, 120.6864300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108949, 'Ampusungan', 'Ampusungan', 'Amposungan,Ampusungan', 16.7804000, 120.7247000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108950, 'Ampatuan', 'Ampatuan', 'Ampatuan,Ampuan', 6.8666700, 124.4666700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108951, 'Amlimay', 'Amlimay', 'Amlimay', 16.6937700, 120.8370400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108952, 'Amio', 'Amio', 'Amio', 9.3571000, 122.9413000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108953, 'Amdos', 'Amdos', 'Amdos,Amdus', 9.8821000, 123.0972000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108954, 'Ambulong', 'Ambulong', 'Ambulong', 14.0880400, 121.0612700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108955, 'Ambuclao', 'Ambuclao', 'Ambuclao,Ambuklao', 16.4833300, 120.7500000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108956, 'Ambulong', 'Ambulong', 'Ambolong,Ambulong', 11.5793000, 122.4987000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108957, 'Amas', 'Amas', 'Amas', 7.0569400, 124.9838900, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108958, 'Amagbagan', 'Amagbagan', 'Amagbagan', 16.0914000, 120.5232000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108959, 'Amaga', 'Amaga', 'Amaga', 8.5308300, 126.0702800, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108960, 'Amadeo', 'Amadeo', '', 14.1705600, 120.9236100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108961, 'Amacalan', 'Amacalan', 'Amacalan,Amacaran', 15.5815000, 120.6112000, 'PH', '2013-03-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108962, 'Alupay', 'Alupay', 'Alupay', 13.8469600, 121.3071900, 'PH', '2012-04-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108963, 'Alugan', 'Alugan', 'Alugan,Alugon', 12.2188000, 125.4808000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108964, 'Alubijid', 'Alubijid', 'Alubihid,Alubijid', 8.5733300, 124.4736100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108965, 'Alubijid', 'Alubijid', 'Alubihid,Alubijid', 8.9627800, 125.4258300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108966, 'Alua', 'Alua', 'Alua', 15.3115400, 120.8943300, 'PH', '2012-12-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108967, 'Altavas', 'Altavas', 'Altavas', 11.5380000, 122.4870000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108968, 'Aloleng', 'Aloleng', 'Aloleng', 16.1307000, 119.7824000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108969, 'Aloguinsan', 'Aloguinsan', 'Aloguinsan,Aloquinsan', 10.2219000, 123.5483000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108970, 'Almeria', 'Almeria', 'Almenia,Almeria', 11.6202800, 124.3816700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108971, 'Almendras', 'Almendras', 'Almendras', 15.2757600, 120.6987300, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108972, 'Almaguer North', 'Almaguer North', 'Almaguer,Almaguer North', 16.3497000, 121.0926000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108973, 'Almagro', 'Almagro', 'Almagro', 11.9109000, 124.2858000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108974, 'Allen', 'Allen', 'Allen,La Granja,Minapa-a', 12.5006000, 124.2849000, 'PH', '2016-09-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108975, 'Allangigan Primero', 'Allangigan Primero', 'Allangigan,Allangigan Primero', 17.1739300, 120.4919500, 'PH', '2012-07-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108976, 'Allacapan', 'Allacapan', 'Allacapan', 18.2259800, 121.5561500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108977, 'Alitagtag', 'Alitagtag', 'Alitagtag', 13.8645000, 121.0041000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108978, 'Alimono', 'Alimono', 'Alimono', 11.1855000, 122.7129000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108979, 'Alimodian', 'Alimodian', 'Alimodian', 10.8213900, 122.4311100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108980, 'Alemanguan', 'Alemanguan', 'Alemanguan,Alimanguan', 10.6117700, 119.3268000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108981, 'Alim', 'Alim', 'Alim', 9.5649000, 122.4876000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108982, 'Alilem', 'Alilem', 'Alilem', 16.8861000, 120.5304000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108983, 'Alijis', 'Alijis', 'Alijis', 10.4583000, 122.8348000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108984, 'Alicia', 'Alicia', 'Alicia,alysya  ayzabla,الیسیا، ایزابلا', 16.7793600, 121.6973400, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108985, 'Alicia', 'Alicia', 'Alicia,Batuanan', 9.8949000, 124.4422000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108986, 'Alicia', 'Alicia', 'Alicia,Chinkang,Chinkiang,Naga-Naga,Naganga', 7.5138900, 122.9300000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108987, 'Alicante', 'Alicante', 'Alicante', 10.8970400, 123.0185000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108988, 'Alibunan', 'Alibunan', 'Alibunan', 11.1465200, 122.4591100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108989, 'Alibug', 'Alibug', 'Alibog,Alibug', 12.2290600, 121.2281100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108990, 'Alibago', 'Alibago', 'Alibago,Alibagu', 17.1166700, 121.8666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108991, 'Aliang', 'Aliang', 'Aliang,Allang', 14.2833300, 120.8833300, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108992, 'Aliaga', 'Aliaga', 'Aliaga,Алиага', 15.5000000, 120.8430000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108993, 'Algeciras', 'Algeciras', 'Algeciras', 11.4154000, 120.8168000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108994, 'Alfonso', 'Alfonso', 'Alfonso,Alfonzo,alfansw  kawyt,الفانسو، کاویت', 14.1408300, 120.8538900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108995, 'Alpaco', 'Alpaco', 'Alfaco,Alpaco,Alpako', 10.2437800, 123.6825000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108996, 'Alejal', 'Alejal', 'Alejal', 7.3841700, 125.6600000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108997, 'Alegria', 'Alegria', 'Alegria', 12.3984000, 124.3261000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108998, 'Alegria', 'Alegria', 'Alegria', 10.6434500, 123.0836000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(108999, 'Alegria', 'Alegria', 'Alegria', 9.7289000, 123.3398000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109000, 'Alegria', 'Alegria', 'Alegria,Algeria', 9.4669400, 125.5772200, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109001, 'Alegria', 'Alegria', 'Alegria', 8.5066700, 126.0119400, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109002, 'Alcoy', 'Alcoy', 'Alcoy', 9.7102000, 123.5067000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109003, 'Alcantara', 'Alcantara', 'Alcantara,alkantara  ramblan,الکانتارا، رامبلان', 12.2589000, 122.0544000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109004, 'Alcantara', 'Alcantara', 'Alcantara', 9.9755600, 123.4061100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109005, 'Alcala', 'Alcala', 'Acala,Alcala', 17.9021000, 121.6559500, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109006, 'Alcala', 'Alcala', 'Alcala', 15.8472200, 120.5241700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109007, 'Alburquerque', 'Alburquerque', 'Albuquerque,Alburqerque,Alburquerque,albwrkwyrk  bhlwl,البورکویرک، بهلول', 9.6080600, 123.9580600, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109008, 'Albuera', 'Albuera', 'Albuara,Albuera', 10.9158000, 124.6945000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109009, 'Alayao', 'Alayao', 'Alayao', 14.2818000, 122.5524000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109010, 'Alannay', 'Alannay', 'Alannay,Launay', 18.0611400, 121.5861600, 'PH', '2013-06-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109011, 'Alanib', 'Alanib', 'Alanib', 8.0277800, 124.9861100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109012, 'Alangilanan', 'Alangilanan', 'Alangilanan', 9.6420000, 123.1059000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109013, 'Alangilan', 'Alangilan', 'Alangilan,Alangilang', 9.2793000, 122.8789000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109014, 'Alangalang', 'Alangalang', 'Alangalang', 11.2061100, 124.8466700, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109015, 'Alaminos', 'Alaminos', 'Alaminos,Alaminos Lakanbalen,Alaminos de Pangasinan,Alaminos de Pangasinán,Aliminos,Kota Alaminos,alamynas  pangasynan,alamynws  pangasynan,الامیناس، پانگاسینان,الامینوس، پانگاسینان', 16.1561100, 119.9811100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109016, 'Alaminos', 'Alaminos', 'Alaminos', 14.0639100, 121.2464900, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109017, 'Alamada', 'Alamada', 'Alamada', 7.3333300, 124.5666700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109018, 'Alae', 'Alae', 'Alae,Alai', 8.4244400, 124.8127800, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109019, 'Alad', 'Alad', 'Alad', 12.6168200, 122.2475100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109020, 'Alacaygan', 'Alacaygan', 'Alacaygan', 10.8401400, 123.0583000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109021, 'Alac', 'Alac', 'Alac', 15.9877000, 120.8065000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109022, 'Alabug', 'Alabug', 'Alabog,Alabug,Alabug East', 17.7326100, 121.4677300, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109023, 'Alabel', 'Alabel', 'Alabel', 6.1017900, 125.2904800, 'PH', '2010-11-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109024, 'Alabat', 'Alabat', 'Alabat', 14.1010000, 122.0125000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109025, 'Akle', 'Akle', 'Acle,Akle', 15.0482000, 121.0733000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109026, 'Ajuy', 'Ajuy', 'Ajuy,Ajuy Town', 11.1724000, 123.0197000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109027, 'Agutaya', 'Agutaya', 'Agatuya,Agutaya', 11.1480000, 120.9417000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109028, 'Agusan', 'Agusan', '', 8.4905600, 124.7372200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109029, 'Agupit', 'Agupit', 'Agupit,La Purisima', 13.4225000, 123.3247200, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109030, 'Aguisan', 'Aguisan', 'Aguisan,Aguisan Hacienda', 10.1603000, 122.8615000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109031, 'Aguining', 'Aguining', 'Aguinin,Aguining', 10.0861000, 124.5944000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109032, 'Aguilar', 'Aguilar', 'Aguilar', 15.8884000, 120.2378000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109033, 'Aguada', 'Aguada', 'Aguada', 12.8166700, 123.8333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109034, 'Agsungot', 'Agsungot', '', 10.4344400, 123.9061100, 'PH', '2015-08-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109035, 'Agpangi', 'Agpangi', 'Agpange,Agpangi,Agponge', 10.5771600, 123.4232000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109036, 'Agos', 'Agos', 'Agos', 13.3434000, 123.3983000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109037, 'Agoo', 'Agoo', 'Agoo,agw  la ywnyan,agw  la ywnywn,اگو، لا یونیان,اگو، لا یونیون', 16.3228000, 120.3666000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109038, 'Agoo', 'Agoo', 'Agoo', 16.0833300, 120.1000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109039, 'Agoncillo', 'Agoncillo', 'Agoncillo,Gitna,Guitna', 13.9355600, 120.9326100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109040, 'Agno', 'Agno', 'Agno,Agno de Pangasinan,Agno de Pangasinán,agnw  pangasynan,اگنو، پانگاسینان', 16.1161000, 119.7993000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109041, 'Aglipay', 'Aglipay', 'Aglipay,Guinalbin,Guinalvin', 16.4889000, 121.6450000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109042, 'Aglayan', 'Aglayan', 'Aglayan', 8.0550000, 125.1341700, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109043, 'Aglalana', 'Aglalana', 'Aglalana', 11.1803000, 122.6574000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109044, 'Aggugaddah', 'Aggugaddah', 'Aggugadaan,Aggugadan,Aggugaddah,Aggugaddan', 17.7001600, 121.8025000, 'PH', '2015-01-25', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109045, 'Agdangan', 'Agdangan', 'Agdangan', 13.8771000, 121.9130500, 'PH', '2012-06-09', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109046, 'Agbannawag', 'Agbannawag', 'Agbanawag,Agbannawag', 17.3764100, 121.5478000, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109047, 'Agbannawag', 'Agbannawag', 'Agbanawag,Agbannaoag,Agbannawag,Agbannaway', 15.6792000, 121.0833000, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109048, 'Agay', 'Agay', 'Agay', 9.0536100, 125.5866700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109049, 'Aganan', 'Aganan', 'Aganan', 10.7833300, 122.5333300, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109050, 'Ag-ambulong', 'Ag-ambulong', 'Ag-ambulong,Agamulong', 11.3684000, 122.5094000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109051, 'Aga', 'Aga', 'Aga', 14.0965000, 120.8021700, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109052, 'Afusing Centro', 'Afusing Centro', 'Afusing,Afusing Centro,Aposingbato', 17.8526000, 121.6269000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109053, 'Adtugan', 'Adtugan', 'Adtoyon,Adtugan,Adtuyon', 7.8119400, 124.8544400, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109054, 'Adlay', 'Adlay', 'Adlay', 9.4097200, 125.8975000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109055, 'Adlaon', 'Adlaon', '', 10.3000000, 123.9000000, 'PH', '2015-08-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109056, 'Adela', 'Adela', 'Adela', 12.4416400, 120.9729100, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109057, 'Adams', 'Adams', 'Adam,Adams', 18.4666700, 120.9000000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109058, 'Acli', 'Acli', 'Acle,Acli,Akli', 15.1227900, 120.6447000, 'PH', '2013-01-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109059, 'Accusilian', 'Accusilian', 'Accusilian,Accusillian,Acustilan', 17.7479100, 121.4625400, 'PH', '2013-02-08', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109060, 'Acao', 'Acao', 'Acao', 16.5255600, 120.3763900, 'PH', '2015-11-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109061, 'Abuyon', 'Abuyon', 'Abuyon', 13.6226000, 122.5191000, 'PH', '2012-06-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109062, 'Abuyog', 'Abuyog', 'Abuyog', 12.9461000, 124.0519000, 'PH', '2012-08-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109063, 'Abuyog', 'Abuyog', 'Abuyog,abwyag  lyyt,ابویاگ، لییت', 10.7470000, 125.0107000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109064, 'Abut', 'Abut', 'Abut', 17.3542300, 121.6013800, 'PH', '2013-04-03', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109065, 'Abulug', 'Abulug', 'Abulog,Abulug', 18.4452800, 121.4533300, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109066, 'Abucayan', 'Abucayan', 'Abucayan', 9.9290000, 123.9146000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109067, 'Abucay', 'Abucay', 'Abucay', 14.7334700, 120.5335800, 'PH', '2014-06-24', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109068, 'Abucay', 'Abucay', 'Abucay', 12.9820000, 123.6492000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109069, 'Abra de Ilog', 'Abra de Ilog', 'Abra de Ilog', 13.4437000, 120.7291000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109070, 'Aborlan', 'Aborlan', 'Aborlan', 9.4336100, 118.5487900, 'PH', '2014-08-21', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109071, 'Abis', 'Abis', 'Abis', 9.7173000, 122.9438000, 'PH', '2017-01-04', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109072, 'Abilay', 'Abilay', 'Abilay', 10.7333300, 122.5000000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109073, 'Abiera', 'Abiera', 'Abiera,Jabiera', 11.5749000, 122.0900000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109074, 'Abangay', 'Abangay', 'Abangay', 10.9666700, 122.6500000, 'PH', '2012-02-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109075, 'Abaca', 'Abaca', 'Abaca', 11.1342000, 122.7156000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109076, 'Abaca', 'Abaca', 'Abaca', 9.9204000, 124.5051000, 'PH', '2012-01-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109077, 'Tolosa', 'Tolosa', '', 7.0322200, 122.1613900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109078, 'Sangali', 'Sangali', '', 7.0694400, 122.2013900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109079, 'Lamisahan', 'Lamisahan', '', 7.0708300, 122.1583300, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109080, 'Dulian', 'Dulian', '', 7.1213900, 122.1788900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109081, 'Landang Laum', 'Landang Laum', '', 6.9688900, 122.2491700, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109082, 'Talabaan', 'Talabaan', '', 6.9411100, 122.1722200, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109083, 'Tablas', 'Tablas', 'Tablas', 6.6291700, 122.1747200, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109084, 'Mangusu', 'Mangusu', '', 7.3255600, 122.2775000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109085, 'Sibulao', 'Sibulao', '', 7.3241700, 122.2394400, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109086, 'Batu', 'Batu', 'Batu', 7.7533300, 122.8294400, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109087, 'Laparay', 'Laparay', 'Laparay', 7.4036100, 122.8172200, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109088, 'Monching', 'Monching', '', 7.7158300, 122.8663900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109089, 'Dalangin', 'Dalangin', 'Dalangin', 7.8505600, 122.5783300, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109090, 'Tigpalay', 'Tigpalay', 'Tigpalay', 7.4947900, 122.3449600, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109091, 'Tunggol', 'Tunggol', '', 5.8445800, 121.1543600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109092, 'Marsada', 'Marsada', 'Marsada', 5.9313900, 121.1069400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109093, 'Talipaw', 'Talipaw', 'Talipaw', 5.9100000, 121.0944400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109094, 'Katipunan', 'Katipunan', 'Katipunan', 7.5825000, 122.8305600, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109095, 'Sanga-Sanga', 'Sanga-Sanga', 'Sanga-Sanga', 5.0725000, 119.7852800, 'PH', '2017-05-10', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109096, 'Ungus-Ungus', 'Ungus-Ungus', '', 5.0508300, 119.8397200, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109097, 'Binuang', 'Binuang', 'Binuang', 5.9569400, 121.0600000, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109098, 'Pandakan', 'Pandakan', 'Pandakan', 5.9888900, 121.1658300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109099, 'Mauboh', 'Mauboh', 'Mauboh', 5.9900000, 121.0936100, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109100, 'Kulase', 'Kulase', 'Kulase,Kulasi', 5.9052000, 120.9569000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109101, 'Kalang', 'Kalang', 'Kalang', 5.9197200, 121.3630600, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109102, 'Andalan', 'Andalan', 'Andalan', 5.9594400, 121.3902800, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109103, 'Buansa', 'Buansa', 'Buansa,Buanza,Puansa', 6.0258000, 120.9614000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109104, 'Kajatian', 'Kajatian', 'Kajatian', 6.0311100, 120.9919400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109105, 'Bato Bato', 'Bato-Bato', 'Bata Bata,Bata-Bata,Bato Bato,Bato-Bato', 6.0344000, 120.9463000, 'PH', '2011-09-12', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109106, 'Sionogan', 'Sionogan', 'Sionogan', 6.0052800, 120.9486100, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109107, 'Payuhan', 'Payuhan', 'Payuhan', 5.9416700, 120.9011100, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109108, 'Buan', 'Buan', 'Buan', 5.5508000, 120.8815000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109109, 'Kungtad', 'Kungtad', 'Kungtad', 5.5572000, 120.8472000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109110, 'La Dicha', 'La Dicha', 'La Dicha', 7.6760000, 123.0023000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109111, 'Del Monte', 'Del Monte', 'Del Monte', 7.7258300, 123.0080600, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109112, 'Kalian', 'Kalian', 'Kalian', 7.5916000, 123.2319000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109113, 'Lumbog', 'Lumbog', 'Cabatan,Lumbog', 7.5581000, 123.2014000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109114, 'Tiguha', 'Tiguha', '', 7.7044400, 123.2113900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109115, 'Sagacad', 'Sagacad', '', 7.6861100, 123.3405600, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109116, 'East Migpulao', 'East Migpulao', '', 7.6325000, 123.3591700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109117, 'Binuatan', 'Binuatan', '', 7.6122200, 123.3441700, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109118, 'Guiniculalay', 'Guiniculalay', '', 7.6561100, 123.3913900, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109119, 'Danlugan', 'Danlugan', '', 7.8913900, 123.3727800, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109120, 'Kagawasan', 'Kagawasan', '', 7.8661100, 123.3950000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109121, 'Lapining', 'Lapining', 'Lapinig,Lapining', 7.9227000, 123.6883000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109122, 'Margos', 'Margos', 'Margos', 7.9320000, 123.6590000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109123, 'Taguitic', 'Taguitic', 'Tagaitic,Taguitic', 7.9387000, 123.6312000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109124, 'Sumalig', 'Sumalig', 'Sumalig', 7.9986000, 123.6627000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109125, 'Gubaan', 'Gubaan', 'Gubaan', 7.9748000, 123.5640000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109126, 'Lanipao', 'Lanipao', 'Lanipao', 7.9552800, 123.7766700, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109127, 'Maranding', 'Maranding', 'Maramding,Maranding', 7.9248000, 123.7715000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109128, 'Rebe', 'Rebe', 'Rebe', 7.9076000, 123.8155000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109129, 'Panubigan', 'Panubigan', 'Panubigan', 7.4281000, 123.3466000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109130, 'Malim', 'Malim', 'Malim', 7.4520000, 123.4312000, 'PH', '2010-08-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109131, 'Kapalong', 'Kapalong', '', 7.7705600, 125.5586100, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109132, 'Andop', 'Andop', 'Andop', 7.8611100, 125.7538900, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109133, 'Concepcion', 'Concepcion', 'Concepcion', 7.7505600, 125.7119400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109134, 'Kaligutan', 'Kaligutan', 'Kaligutan', 7.7030600, 125.8130600, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109135, 'Del Pilar', 'Del Pilar', 'Del Pilar', 7.5630600, 125.8266700, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109136, 'Tagnanan', 'Tagnanan', 'Tagnanan', 7.2836100, 125.8422200, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109137, 'Camudmud', 'Camudmud', 'Camudmud', 7.1761100, 125.6933300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109138, 'Maduao', 'Maduao', 'Maduao', 7.2941700, 125.6258300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109139, 'Katipunan', 'Katipunan', 'Katipunan', 7.3202800, 125.6202800, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109140, 'San Remigio', 'San Remigio', 'San Remigio', 6.9230600, 125.7758300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109141, 'Bonbon', 'Bonbon', 'Bonbon', 9.1052800, 124.7338900, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109142, 'Balas', 'Balas', 'Balas', 15.0499800, 120.5861100, 'PH', '2013-01-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109143, 'Magliman', 'Magliman', 'Magliman', 15.0354500, 120.6642100, 'PH', '2013-01-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109144, 'Motrico', 'Motrico', 'Motrico', 15.4135500, 120.6765300, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109145, 'San Pascual', 'San Pascual', 'San Pascual', 15.5015200, 120.6671800, 'PH', '2013-03-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109146, 'Santo Niño', 'Santo Nino', 'Santo Nino,Santo Niño', 15.2366400, 120.7120400, 'PH', '2013-01-11', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109147, 'Capitan Ramon', 'Capitan Ramon', 'Capitan Ramon,Kapitan Ramon', 10.7602000, 123.1148000, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109148, 'Malusay', 'Malusay', 'Malusay', 10.1439000, 123.2717000, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109149, 'Del Pilar', 'Del Pilar', 'Del Pilar', 15.6956000, 121.0863000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109150, 'Bulihan', 'Bulihan', 'Bulihan', 14.2782000, 120.9950300, 'PH', '2013-12-14', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109151, 'Magsaysay', 'Magsaysay', 'Magsaysay', 14.3388000, 121.0341000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109152, 'Gulod', 'Gulod', 'Gulod', 14.3449000, 121.2177000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109153, 'Badak', 'Badak', 'Badak', 6.8472200, 124.7205600, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109154, 'Bagong Pagasa', 'Bagong Pagasa', 'Bagong Pagasa,Pag-Asa', 14.6627000, 121.0328000, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109155, 'Lim-oo', 'Lim-oo', '', 11.1508300, 124.6308300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109156, 'Ibung', 'Ibung', 'Ibung', 16.6093800, 121.1861400, 'PH', '2012-01-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109157, 'Damabalas', 'Damabalas', 'Damabalas', 7.0155600, 124.5141700, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109158, 'Esperanza', 'Esperanza', 'Esperanza', 6.4994400, 124.6661100, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109159, 'Makir', 'Makir', 'Makir', 7.0308300, 124.3041700, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109160, 'Nunguan', 'Nunguan', 'Nunguan', 7.1282500, 124.6891200, 'PH', '2012-04-06', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109161, 'Basiawan', 'Basiawan', 'Basiawan', 6.5341700, 125.4869400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109162, 'Lumbac', 'Lumbac', 'Lumbac', 7.7341700, 124.2527800, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109163, 'Pagalungan', 'Pagalungan', 'Pagalungan', 6.2655600, 125.0133300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109164, 'Malandag', 'Malandag', 'Malandag', 6.3094400, 125.2427800, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109165, 'Malingao', 'Malingao', 'Malingao', 7.1608300, 124.4750000, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109166, 'Dado', 'Dado', 'Dado', 7.0500000, 124.4597200, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109167, 'Molundo', 'Molundo', '', 7.9386100, 124.3702800, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109168, 'Simuay', 'Simuay', 'Simuay', 7.2772200, 124.3072200, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109169, 'Bualan', 'Bualan', 'Bualan', 7.4477800, 124.2675000, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109170, 'Mataya', 'Mataya', 'Mataya', 7.4711100, 124.3719400, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109171, 'Nuyo', 'Nuyo', 'Nuyo', 7.4180600, 124.4108300, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109172, 'Tuka', 'Tuka', 'Tuka', 6.5200000, 124.5850000, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109173, 'Busok', 'Busok', 'Busok', 6.5061100, 124.5988900, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109174, 'Lopez Jaena', 'Lopez Jaena', 'Lopez Jaena', 6.5088900, 124.6825000, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109175, 'Lambontong', 'Lambontong', 'Lambontong', 6.3083300, 124.8105600, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109176, 'Daguma', 'Daguma', 'Daguma', 6.5866700, 124.5472200, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109177, 'Kapaya', 'Kapaya', 'Kapaya', 6.5711100, 124.5630600, 'PH', '2012-02-02', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109178, 'Simod', 'Simod', '', 7.4758300, 125.3408300, 'PH', '2014-03-01', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109179, 'Pasig City', 'Pasig City', 'Pasig', 14.5869100, 121.0614000, 'PH', '2012-05-15', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109180, 'Tubo', 'Tubo', 'Tubo', 17.2667000, 120.7355000, 'PH', '2011-07-31', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109181, 'Sambayanihan People''s Village', 'Sambayanihan People''s Village', '', 14.4555800, 120.9981600, 'PH', '2011-03-15', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109182, 'Tabuk', 'Tabuk', 'Tabuk', 17.4084000, 121.2785000, 'PH', '2016-09-18', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109183, 'Pandan', 'Pandan', 'Banwa kang Pandan,Bayan ng Pandan,Municipality of Pandan,Pandan,Пандан', 11.7447900, 122.1002700, 'PH', '2013-10-29', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109184, 'Subic Bay Freeport Zone', 'Subic Bay Freeport Zone', 'SBFZ,SFS,Subic Bay Freeport Zone', 14.7889900, 120.2798700, 'PH', '2013-03-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109185, 'Cambarus', 'Cambarus', '', 10.2134200, 122.5211700, 'PH', '2014-06-21', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109186, 'Barangay of Poblacion', 'Barangay of Poblacion', '', 13.3176800, 122.0793500, 'PH', '2014-09-07', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109187, 'Hanggan', 'Hanggan', '', 14.1887100, 121.3000900, 'PH', '2014-09-23', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109188, 'City of Ligao', 'City of Ligao', '', 13.2168400, 123.5141800, 'PH', '2014-11-17', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109189, 'Paranas', 'Paranas', '', 11.8502200, 125.1153100, 'PH', '2015-04-19', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109190, 'Apas', 'Apas', '', 10.3407600, 123.9026100, 'PH', '2015-08-20', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109191, 'Roseller Lim', 'Roseller Lim', 'Roseller Lim', 7.6560500, 122.4671400, 'PH', '2017-01-05', 175);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109279, 'Rustam', 'Rustam', 'Rustam,Rustam jo Goth,Rustom', 27.9670500, 68.8038600, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109280, 'Rojhān', 'Rojhan', '', 28.6873500, 69.9535000, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109281, 'Rohri', 'Rohri', 'Lohri,Rohri,rohari,روہڑی,रोहड़ी', 27.6922300, 68.8950600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109282, 'Renāla Khurd', 'Renala Khurd', 'Renala,Renala Khurd,Renāla,Renāla Khurd', 30.8787800, 73.5985700, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109283, 'Rawalpindi', 'Rawalpindi', 'Ralalpindi,Ravalpindi,Ravalpindis,Rawalpindi,Rawalpindî,Rávalpindí,Rāvalpindi,Rāwalpindi,iravalpinti,la wa er pin di,lawalpindi,ra''oyalapindi,ravalapidi,ravalapindi,ravalpyndy,rawa lpin di,rawarupindi,rawlbndy,rawlpndy,Равалпинди,Равалпінді,Ռավալպինդի,רוואלפינדי,راولبندي,راولپندی,راولپنڈی,راولپنڈی شہر,راولپنډي,راۋالپىندى,रावलपिंडी,रावळपिंडी,রাওয়ালপিন্ডি,ਰਾਵਲਪਿੰਡੀ,இராவல்பிண்டி,റാവൽപിണ്ടി,ราวัลปินดี,ラーワルピンディー,拉瓦尔品第,라왈핀디', 33.6007000, 73.0679000, 'PK', '2014-03-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109284, 'Ratodero', 'Ratodero', 'Dero,Rato,Ratodero', 27.8022700, 68.2890200, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109285, 'Rasūlnagar', 'Rasulnagar', 'Ramnagar,Rasulnagar,Rasulnager,Rasūlnagar,Rasūlnager,Rāmnagar', 32.3285300, 73.7813600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109286, 'Rānīpur', 'Ranipur', 'Ranipur,Raripur,Rānīpur', 27.2879200, 68.5050500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109287, 'Rājo Khanāni', 'Rajo Khanani', '', 24.9840500, 68.8535700, 'PK', '2011-07-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109288, 'Rājanpur', 'Rajanpur', 'Rajanpur,Rājanpur', 29.1035100, 70.3250400, 'PK', '2012-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109289, 'Rāja Jang', 'Raja Jang', 'Baja Jang,Raja Jang,Rāja Jang', 31.2207800, 74.2548300, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109290, 'Raiwind', 'Raiwind', 'Raiwind', 31.2489500, 74.2153400, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109291, 'Rādhan', 'Radhan', '', 27.1833300, 67.9500000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109292, 'Chenāb Nagar', 'Chenab Nagar', 'Chenab Nagar,Chenāb Nagar,Rabwah,Rabwāh', 31.7551100, 72.9140300, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109293, 'Quetta', 'Quetta', 'Gorad Kveta,Ketta,Kotah,Kueta,Kveta,Kvetta,Kvéta,Kwatah,Kweta,Quetta,Shal,Shalkot,Shāl,Shālkot,UET,khewt ta,ko''ita,koyeta,kuetta,kui da,kuvetta,kverra,kveta,kvetta,kweta,kwyth,Горад Квета,Квета,Кветта,Куета,كويته,کوئٹہ,کوټه,کویته,क्वेटा,क्वेट्टा,কোয়েটা,ਕੋਇਟਾ,குவெட்டா,ക്വെറ്റ,ක්වේටා‍,เควตตา,კვეტა,クエッタ,奎達,퀘타', 30.1841400, 67.0014100, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109294, 'Qila Saifullāh', 'Qila Saifullah', 'Kila Saifulla,Killa Saifulla Bazar,Killa-Saifulla,New Qila Saifullah,New Qila Saifullāh,Qila Saifullah,Qila Saifullāh', 30.7007700, 68.3598400, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109295, 'Qila Abdullāh', 'Qila Abdullah', 'Killa Abdullah,Qila Abdullah,Qila Abdullāh', 30.7280300, 66.6611700, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109296, 'Kambar', 'Kambar', 'Kambar,Qambar,Камбар', 27.5875300, 68.0006600, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109297, 'Qādirpur Rān', 'Qadirpur Ran', 'Qadirpur Ran,Qādirpur Rān', 30.2918400, 71.6716400, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109298, 'Pithoro', 'Pithoro', '', 25.5112200, 69.3780300, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109299, 'Pishin', 'Pishin', 'Pishin,pshy,Пишин,پشی', 30.5817600, 66.9940600, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109300, 'Pīr Mahal', 'Pir Mahal', '', 30.7666700, 72.4333300, 'PK', '2006-01-27', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109301, 'Pindi Gheb', 'Pindi Gheb', '', 33.2402300, 72.2660900, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109302, 'Pindi Bhattiān', 'Pindi Bhattian', 'Pindi Battian,Pindi Bhatian,Pindi Bhattian,Pindi Bhattiān', 31.8978100, 73.2730200, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109303, 'Pind Dādan Khān', 'Pind Dadan Khan', 'Pind Dadan Khan,Pind Dādan Khān,Pindi Dadan Khan', 32.5866200, 73.0445600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109304, 'Phūlji', 'Phulji', '', 26.8825100, 67.6807000, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109305, 'Phālia', 'Phalia', 'Phalia,Phālia', 32.4297300, 73.5774500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109306, 'Peshawar', 'Peshawar', 'Gorad Peshavar,PEW,Pesabar,Pesavar,Pesavara,Pesavaras,Pesavaro,Pesaver,Peschawar,Peshavar,Peshawar,Peshovar,Pesjawar,Peszawar,Pexauar,Peŝavaro,Peşaver,Pešavaras,Pešāvara,Pişəvər,Péšávar,bai sha wa,byshawr,pecavar,pes war,pesa''oyara,pesavara,peshawaru,pesyawaleu,pshawr,pyshawr,Πεσαβάρ,Горад Пешавар,Пешавар,Փեշավար,פשאוור,بيشاور,پشاور,پیشاور,پېشاۋار,پېښور,पेशावर,পেশাওয়ার,ਪੇਸ਼ਾਵਰ,பெசாவர்,പെഷവാർ,เปศวาร์,პეშავარი,ペシャーワル,白沙瓦,페샤와르', 34.0080000, 71.5784900, 'PK', '2014-03-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109307, 'Pattoki', 'Pattoki', 'Mandi Pattoki,Pattoki,ptwky,tsyl ptwky,Паттоки,تصیل پتوکی,پتوكى', 31.0166700, 73.8500000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109308, 'Pasrūr', 'Pasrur', 'Pasrur,Pasrūr,Pasur,Pasūr', 32.2628600, 74.6632700, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109309, 'Pasni', 'Pasni', 'PSI,Pansi,Pasni,Пасни', 25.2631600, 63.4680900, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109310, 'Parachinar', 'Parachinar', 'PAJ,Parachinar,Parachiner,Pārachinār,baratshynar,parachnar,Парачинар,باراتشينار,پاراچنار,پاڑاچنار,پاړه چنار', 33.8996800, 70.1001200, 'PK', '2013-11-16', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109311, 'Pāno Āqil', 'Pano Aqil', 'Pano Akil,Pano Aqil,Pāno Āqil', 27.8561900, 69.1111100, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109312, 'Panjgūr', 'Panjgur', 'Chukan,PJG,Panjgur,Panjgūr', 26.9718600, 64.0945900, 'PK', '2017-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109313, 'Pākpattan', 'Pakpattan', 'Pakpattan,Pākpattan', 30.3431400, 73.3894400, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109314, 'Pahārpur', 'Paharpur', '', 32.1038400, 70.9723500, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109315, 'Pad Īdan', 'Pad Idan', '', 26.7747500, 68.3019700, 'PK', '2006-01-27', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109316, 'Pabbi', 'Pabbi', 'Pabbi', 34.0096800, 71.7944500, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109317, 'Ormāra', 'Ormara', 'ORW,Ormara,Ormāra', 25.2088000, 64.6357000, 'PK', '2017-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109318, 'Okāra', 'Okara', 'Okara,Okāra,Окара', 30.8102900, 73.4515500, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109319, 'Nushki', 'Nushki', 'NHS,Nushki', 29.5521800, 66.0228800, 'PK', '2015-12-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109320, 'Nowshera', 'Nowshera', 'Naushahra,Naushera,Nowshehra,Nowshera,nwshhrh,Наушера,نوشهره,نوشہرہ', 34.0158300, 71.9812300, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109321, 'New Mīrpur', 'New Mirpur', 'Mirpur,Mīrpur,New Mirpur,New Mīrpur', 33.1478200, 73.7518700, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109322, 'Nawabshah', 'Nawabshah', 'Nawabshah,Nawābshāh,WNS', 26.2393900, 68.4036900, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109323, 'Naushahro Fīroz', 'Naushahro Firoz', 'Naushahro,Naushahro Firoz,Naushahro Fīroz,Naushahro Piroz', 26.8401000, 68.1226500, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109324, 'Naushahra Virkān', 'Naushahra Virkan', 'Naushahra Virkan,Naushahra Virkhan,Naushahra Virkān,Naushehra Werkan,Naushera Virkhan', 31.9625800, 73.9711700, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109325, 'Naudero', 'Naudero', 'Naudero,Naundero', 27.6668400, 68.3609000, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109326, 'Nasīrābād', 'Nasirabad', '', 27.3813700, 67.9164400, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109327, 'Nārowāl', 'Narowal', 'Narowal,Nārowāl', 32.1019700, 74.8730300, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109328, 'Nārang Mandi', 'Narang Mandi', 'Narang,Narang Mandi,Nārang,Nārang Mandi,Наранг', 31.9037600, 74.5158700, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109329, 'Naukot', 'Naukot', 'Naokot,Naukot,Nawakot', 24.8582200, 69.4015300, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109330, 'Nankāna Sāhib', 'Nankana Sahib', 'Nanakana Sahib,Nankana Municipality,Nankana Sahib,Nankāna Sāhib', 31.4475000, 73.6972200, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109331, 'Nabīsar', 'Nabisar', 'Nabisar,Nabisarpat,Nabīsar', 25.0685400, 69.6418600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109332, 'Muzaffargarh', 'Muzaffargarh', 'Muzafargarkh,Muzafargaro,Muzaffargar,Muzaffargarh,Muzaffargarkh,Muzaffargharh,mu zha fa er ge er xian,muzaffaragarha,mzfr grh  pakstan,Музафаргарх,Музаффаргар,Музаффаргарх,مظفر گره، پاکستان,مظفر گڑھ,मुज़फ़्फ़रगढ़,穆扎法尔格尔县', 30.0725800, 71.1937900, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109333, 'Muzaffarābād', 'Muzaffarabad', 'MFG,Musaffarabad,Musaffarābād,Muzafarabad,Muzaffarabad,Музафарабад', 34.3700200, 73.4708200, 'PK', '2014-03-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109334, 'Mustafābād', 'Mustafabad', '', 30.8922200, 73.4988900, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109335, 'Mūsa Khel Bāzār', 'Musa Khel Bazar', 'Musa Khel Bazar,Musakhel,Mūsa Khel Bāzār', 30.8594400, 69.8220800, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109336, 'Murree', 'Murree', 'Murree,Murri,mry,mu li,مری,穆里', 33.9083600, 73.3903000, 'PK', '2015-01-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109337, 'Murīdke', 'Muridke', 'Muridke,Murīdke', 31.8025800, 74.2577200, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109338, 'Multān', 'Multan', 'MUX,Multan,Multanas,Multān,mu er tan,multan,murutan,Мултан,مُلتان,ムルターン,木爾坦', 30.1967900, 71.4782400, 'PK', '2017-01-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109339, 'Moro', 'Moro', '', 26.6631700, 68.0001600, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109340, 'Mithi', 'Mithi', 'Mithi,Mitti', 24.7370100, 69.7970700, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109341, 'Mitha Tiwāna', 'Mitha Tiwana', 'Mitha Tiwana,Mitha Tiwāna', 32.2454000, 72.1061500, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109342, 'Mīrwāh Gorchani', 'Mirwah Gorchani', 'Mirwah,Mirwah Gorchani,Mīrwāh,Mīrwāh Gorchani', 25.3092800, 69.0521100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109343, 'Mīrpur Sakro', 'Mirpur Sakro', 'Mipur Sakro,Mirpur Sakro,Mirpur Sukro,Mīrpur Sakro', 24.5469200, 67.6279700, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109344, 'Mīrpur Mathelo', 'Mirpur Mathelo', 'Mirpur,Mirpur Mathelo,Mīrpur,Mīrpur Mathelo,Mīrpur Māthelo', 28.0213600, 69.5491400, 'PK', '2016-06-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109345, 'Mirpur Khas', 'Mirpur Khas', 'MPD,Mirpur Khas,Mirpur-Khas,mi er bu er ha si,myr pwr khas,myrpwr khas,myrpwr khas  pakstan,Мирпур Хас,Мирпур-Хас,ميرپور خاص,میر پور خاص,میرپور خاص,میرپور خاص، پاکستان,მირპურქასი,米爾布爾哈斯', 25.5251000, 69.0159000, 'PK', '2013-05-11', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109346, 'Mirpur Bhtoro', 'Mirpur Bhtoro', 'Mirpur Bathoro,Mirpur Batoro,Mirpur Bhtoro,Mīrpur Batoro', 24.7285200, 68.2601000, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109347, 'Mīro Khān', 'Miro Khan', '', 27.7598500, 68.0919500, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109348, 'Mīrān Shāh', 'Miran Shah', 'Miram,Miram Shah,Miram Shah Post,Miram Shāh Post,Miran Shah,Miran Shah Scouts Post,Miran Shāh Scouts Post,Miranshah,Mīram Shāh,Mīrān Shāh', 33.0005900, 70.0711700, 'PK', '2014-11-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109349, 'Mingora', 'Mingora', 'Mingaora,Mingora,Mingāora,migora,ming ge la,ming jiao la,ming-gola,myngwra,myngwrh,Мингаора,Мингора,مينگوره,مینګورہ,مینگورا,مینگوره,مینگورہ,ਮਿੰਗੋਰਾ,明戈拉,明绞拉,밍고라', 34.7795000, 72.3626500, 'PK', '2013-11-25', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109350, 'Minchīanabād', 'Minchianabad', 'Manchinabad,Minchianabad,Minchinabad,Minchinābād,Minchīanabād', 30.1635600, 73.5685800, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109351, 'Miānwāli', 'Mianwali', 'MWD,Mianwali,Miānwāli', 32.5740900, 71.5263900, 'PK', '2017-04-02', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109352, 'Miān Channūn', 'Mian Channun', 'Mian Channu,Mian Channun,Miān Channūn', 30.4400400, 72.3543100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109353, 'Mehrābpur', 'Mehrabpur', 'Mahrabpur,Mehrabpur,Mehrābpur', 28.1077300, 68.0255400, 'PK', '2016-09-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109354, 'Mehar', 'Mehar', '', 27.1806700, 67.8228800, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109355, 'Mātli', 'Matli', '', 25.0429000, 68.6559100, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109356, 'Matiāri', 'Matiari', 'Matari,Matiari,Matiāri', 25.5970900, 68.4467000, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109357, 'Mastung', 'Mastung', 'Mastung', 29.7996600, 66.8455300, 'PK', '2016-10-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109358, 'Mardan', 'Mardan', 'Mardan,Mardanas,Mardān,ma er dan,mrdan,Мардан,مردان,馬爾丹', 34.1979400, 72.0496500, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109359, 'Mānsehra', 'Mansehra', 'Mansehra,Mansekhra,Mānsehra,Мансехра', 34.3302300, 73.1967900, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109360, 'Mankera', 'Mankera', 'Mankera,Mankora', 31.3865600, 71.4406700, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109361, 'Mangla', 'Mangla', '', 31.8930600, 72.3816700, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109362, 'Mandi Bahāuddīn', 'Mandi Bahauddin', 'Bahauddin,Mandi Bahauddin,Mandi Bahāuddīn', 32.5870400, 73.4912300, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109363, 'Mānānwāla', 'Mananwala', '', 31.5841700, 73.6877800, 'PK', '2006-01-27', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109364, 'Māmu Kānjan', 'Mamu Kanjan', 'Mamu Kanjan,Māmu Kānjan', 30.8333300, 72.8000000, 'PK', '2013-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109365, 'Malīr Cantonment', 'Malir Cantonment', 'Malir Cantonment,Malīr Cantonment', 24.9434300, 67.2059100, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109366, 'Malakwāl', 'Malakwal', 'Malakwal,Malakwāl', 32.5544900, 73.2127400, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109367, 'Malakand', 'Malakand', 'Malakand,Malakaud', 34.5656100, 71.9304300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109368, 'Mailsi', 'Mailsi', 'Mailsi', 29.8002800, 72.1758300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109369, 'Madeji', 'Madeji', '', 27.7531400, 68.4516600, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109370, 'Mach', 'Mach', 'Mach', 29.8637100, 67.3297900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109371, 'Loralai', 'Loralai', 'LRG,Loraiar,Loralai', 30.3705100, 68.5979500, 'PK', '2017-04-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109372, 'Lodhrān', 'Lodhran', 'Lodhran,Lodhrān', 29.5405100, 71.6335700, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109373, 'Liliāni', 'Liliani', 'Laliani,Laliāni,Lalliani,Liliani,Liliāni', 32.2065100, 72.9537200, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109374, 'Layyah', 'Layyah', 'Layyah,Leiah', 30.9612800, 70.9390400, 'PK', '2016-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109375, 'Lārkāna', 'Larkana', 'Larkana,Larkane,Larkāna,Lārkāna,Ларкане', 27.5589800, 68.2120400, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109376, 'Landi Kotal', 'Landi Kotal', 'Landi Kotal,Landlandi Kotal', 34.0988000, 71.1410800, 'PK', '2015-02-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109377, 'Lāliān', 'Lalian', 'Lalian,Lāliān', 31.8246200, 72.8011600, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109378, 'Lāla Mūsa', 'Lala Musa', 'Lala Musa,Lalamusa,Lāla Mūsa', 32.7013800, 73.9574600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109379, 'Lakki', 'Lakki', 'Laki-Marwat,Lakki,Lakki Marwat', 32.6072400, 70.9123400, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109380, 'Lakhi', 'Lakhi', '', 27.8488400, 68.6997200, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109381, 'Lahore', 'Lahore', 'Gorad Lakhor,LHE,Lachori,Lahaur,Lahor,Lahora,Lahoras,Lahore,Lahorium,Lakhor,Lohur,Láhaur,Lâhore,Lāhaur,la h xr,la he er,lahaura,laholeu,lahor,lahora,lahori,lahwr,lakur,lwہwr,rahoru,Λαχόρη,Горад Лахор,Лахор,Լահոր,לאהור,لاهور,لاھور,لاھۆر,لاہور,لوہوٗر,لہور,लाहोर,लाहौर,লাহোর,ਲਹੌਰ,લાહોર,லாகூர்,లాహోర్,ಲಾಹೋರ್,ലാഹോർ,ลาฮอร์,ლაჰორი,ラホール,ラーホール,拉合尔,拉合爾,라호르', 31.5580000, 74.3507100, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109382, 'Ladhewāla Warāich', 'Ladhewala Waraich', '', 32.1569200, 74.1156400, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109383, 'Lāchi', 'Lachi', '', 33.3829100, 71.3373300, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109384, 'Kunri', 'Kunri', '', 25.1784700, 69.5691300, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109385, 'Kunjāh', 'Kunjah', '', 32.5298200, 73.9748600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109386, 'Kundiān', 'Kundian', 'Kundian,Kundian Pacca,Kundiān', 32.4577500, 71.4789200, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109387, 'Kulāchi', 'Kulachi', '', 31.9286100, 70.4591700, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109388, 'Kot Sultan', 'Kot Sultan', '', 30.7737000, 70.9312500, 'PK', '2016-01-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109389, 'Kot Samāba', 'Kot Samaba', '', 28.5520700, 70.4683700, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109390, 'Kotri', 'Kotri', 'Koti,Kotri,Котри,کوٹری', 25.3656600, 68.3083100, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109391, 'Kot Rādha Kishan', 'Kot Radha Kishan', 'Kot Radha Kishan,Kot Rādha Kishan', 31.1706800, 74.1012600, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109392, 'Kot Mūmin', 'Kot Mumin', 'Kot Mamin,Kot Mumin,Kot Mūmin,Kot-Moman', 32.1895400, 73.0279700, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109393, 'Kot Malik Barkhurdār', 'Kot Malik Barkhurdar', 'Kot Malik,Kot Malik Barkhurdar,Kot Malik Barkhurdār', 30.2037900, 66.9872300, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109394, 'Kotli Lohārān', 'Kotli Loharan', '', 32.5883000, 74.4932100, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109395, 'Kotli', 'Kotli', 'Kotli', 33.5183600, 73.9022000, 'PK', '2015-11-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109396, 'Kot Ghulām Muhammad', 'Kot Ghulam Muhammad', '', 32.3331100, 74.5469400, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109397, 'Kot Diji', 'Kot Diji', 'Diji,Kot Diji', 27.3427200, 68.7083400, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109398, 'Kot Addu', 'Kot Addu', 'Kot Addu,Kot-Adu', 30.4692000, 70.9671400, 'PK', '2014-03-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109399, 'Kohlu', 'Kohlu', 'Kohlu', 29.8965100, 69.2532400, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109400, 'Kohāt', 'Kohat', 'Kohat,Kohāt,Kokhat,OHT,Кохат', 33.5819600, 71.4492900, 'PK', '2017-04-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109401, 'Khuzdār', 'Khuzdar', 'KDD,Khozdar,Khuzdar,Khuzdār', 27.8119300, 66.6109600, 'PK', '2017-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109402, 'Khushāb', 'Khushab', 'Khushab,Khushah,Khushāb', 32.2966700, 72.3525000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109403, 'Khurriānwāla', 'Khurrianwala', 'Khurianwala,Khurrianwala,Khurriānwāla,Kurrianwala', 31.5005600, 73.2666700, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109404, 'Khewra', 'Khewra', 'Khewra', 32.6491000, 73.0105900, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109405, 'Khāriān', 'Kharian', 'Kharian,Khāriān', 32.8161200, 73.8869700, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109406, 'Khārān', 'Kharan', 'Kharan,Kharan Kalat,Kharon Kalat,Khārān,Khārān Kalāt', 28.5845900, 65.4150100, 'PK', '2016-08-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109407, 'Karak', 'Karak', 'Karak,Kark,Kharak', 33.1163300, 71.0935400, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109408, 'Khānpur', 'Khanpur', 'Khanpur,Khānpur', 28.6473900, 70.6569400, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109409, 'Khānpur', 'Khanpur', 'Khanpoor,Khanpur,Khānpur', 27.8435800, 69.4137300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109410, 'Khāngarh', 'Khangarh', 'Khangarh,Khāngarh', 29.9144600, 71.1606700, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109411, 'Khāngāh Dogrān', 'Khangah Dogran', 'Khanga Dogran,Khangah Dogran,Khangah-Dogra,Khangan Dogran,Khanqah Dogran,Khāngāh Dogrān,Khāngān Dogrān,Khānqāh Dogrān', 31.8316700, 73.6230600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109412, 'Khānewāl', 'Khanewal', 'Khanewal,Khānewāl', 30.3017300, 71.9321200, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109413, 'Khandoyah', 'Khandoyah', 'Khandoa,Khandoyah', 32.7425500, 72.7347800, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109414, 'Khalābat', 'Khalabat', '', 34.0599700, 72.8896300, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109415, 'Khairpur Nathan Shāh', 'Khairpur Nathan Shah', 'Khairpur,Khairpur Nathan Shah,Khairpur Nathan Shāh,Khairpur Nathoshah', 27.0906400, 67.7348900, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109416, 'Khairpur Tāmewah', 'Khairpur Tamewah', 'Khairpur,Khairpur Tamewah,Khairpur Tāmewah', 29.5813900, 72.2380400, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109417, 'Khairpur', 'Khairpur', 'Khairpur,Khairpur Daherki,Khajrpura,Хайрпура', 28.0643700, 69.7036300, 'PK', '2016-06-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109418, 'Khadro', 'Khadro', 'Khadro', 26.1471300, 68.7177700, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109419, 'Keti Bandar', 'Keti Bandar', 'Keti,Keti Bandar,Ketibunder', 24.1442200, 67.4509400, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109420, 'Keshupur', 'Keshupur', 'Keshopur', 32.2600000, 72.5000000, 'PK', '2016-01-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109421, 'Kasur', 'Kasur', 'Kansur,Kansūr,Kasur,Kasūr,Касур', 31.1186600, 74.4502500, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109422, 'Kashmor', 'Kashmor', 'Kashmor,Kashmore', 28.4326000, 69.5836400, 'PK', '2016-06-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109423, 'Karor', 'Karor', 'Haror,Karor,Karor Lal Isa', 31.2274100, 70.9492300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109424, 'Kario Ghanwar', 'Kario Ghanwar', 'Kario,Kario Ghanwar', 24.8081700, 68.6048300, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109425, 'Karaundi', 'Karaundi', 'Karaundi,Karundi', 26.8974500, 68.4068100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109426, 'Karachi', 'Karachi', 'Carachi,Gorad Karachy,KHI,Karaaji,Karaces,Karachi,Karachi - krachy,Karachi - كراچى,Karaci,Karacio,Karacis,Karacsi,Karaczi,Karanchi,Karatschi,Karatsi,Karatsji,Karatxi,Karaçi,Karaĉio,Karači,Karačis,Karačės,Karochi,Karáči,Karáčí,Karâchi,Karāchi,Karāči,Keraci,Keraçî,Kurrachee,Kurrachi,Kəraçi,ka la qi,ka ra ci,kalachi,karaaci,karacci,karachi,karachy,karaci,karatshy,ke la chi,krachy,kratshy,pechs,qrʼzy,Καράτσι,Горад Карачы,Карачи,Карачі,Կարաչի,קאראטשי,קראצי,كاراتشى,كاراچى,كراتشي,کراچی,کراچۍ,کَرٲچی,کەراچی,ڪراچي,ކަރާޗީ,कराची,করাচী,কৰাচী,ਕਰਾਚੀ,કરાચી,କରାଚୀ,கராச்சி,కరాచీ,ಕರಾಚಿ,കറാച്ചി,การาจี,ཀ་ར་ཆི,ကရာချိမြို့,კარაჩი,ከራቺ,カラチ,カラーチー,卡拉奇,喀拉蚩,카라치', 24.8608000, 67.0104000, 'PK', '2017-05-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109427, 'Kanganpur', 'Kanganpur', 'Kanganpur', 30.7646800, 74.1228600, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109428, 'Kandiāro', 'Kandiaro', 'Kandiaro,Kandiāro', 27.0591800, 68.2102200, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109429, 'Kandiāri', 'Kandiari', '', 26.9155000, 68.5219300, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109430, 'Kandhkot', 'Kandhkot', '', 28.2439600, 69.1823500, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109431, 'Kāmra', 'Kamra', 'Kamara,Kamra,Kāmra', 33.7469800, 73.5122900, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109432, 'Kāmoke', 'Kamoke', 'Kamoke,Kamoki,Kāmoke,Kāmoki', 31.9752600, 74.2230400, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109433, 'Chak One Hundred Twenty Nine Left', 'Chak One Hundred Twenty Nine Left', 'Chak One Hundred Twenty Nine Left,Kamir,Kamīr', 30.4291900, 73.0452200, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109434, 'Kamar Mushāni', 'Kamar Mushani', 'Kamar Mushani,Kamar Mushāni', 32.8431800, 71.3619200, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109435, 'Kamālia', 'Kamalia', 'Kamalia,Kamālia', 30.7333300, 72.6500000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109436, 'Kalūr Kot', 'Kalur Kot', 'Kallur Kot Town,Kalur Kot,Kalūr Kot', 32.1551200, 71.2663100, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109437, 'Kallar Kahār', 'Kallar Kahar', 'Kalar Kahar,Kallar Kahar,Kallar Kahār', 32.7799800, 72.6979300, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109438, 'Kāleke Mandi', 'Kaleke Mandi', 'Kaleke Mandi,Kāleke Mandi,Mandi Kaleke', 31.9771700, 73.6025900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109439, 'Kalāt', 'Kalat', 'Kalat,Kalāt,Kelat,Khelat,Калат', 29.0266300, 66.5936100, 'PK', '2016-10-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109440, 'Kālaswāla', 'Kalaswala', 'Kalaswala,Kalāswāla,Kālaswāla', 32.2008100, 74.6485800, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109441, 'Kālābāgh', 'Kalabagh', 'Kalabagh,Kālābāgh', 32.9616400, 71.5463800, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109442, 'Kahuta', 'Kahuta', 'Kahuta,Kahūta,Kakhute,Кахуте', 33.5918300, 73.3873600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109443, 'Kohror Pakka', 'Kohror Pakka', 'Kahror,Kehror Pakka Town,Kharor,Kohror Pakka', 29.6238200, 71.9167300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109444, 'Kāhna Nau', 'Kahna Nau', 'Kahna,Kahna Nau,Khana,Khāna,Kāhna,Kāhna Nau', 31.3670900, 74.3689900, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109445, 'Kadhan', 'Kadhan', '', 24.4804100, 68.9855100, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109446, 'Kabīrwāla', 'Kabirwala', '', 30.4047200, 71.8626900, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109447, 'Johi', 'Johi', '', 26.6920600, 67.6133000, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109448, 'Jīwani', 'Jiwani', 'JIW,Jinwri,Jiunri,Jiwani,Jiyuni,Jīnwri,Jīwani', 25.0485200, 61.7457300, 'PK', '2017-03-31', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109449, 'Chak Jhumra', 'Chak Jhumra', 'Chak Jhumra,Chak Jumra,Jhumra', 31.5680800, 73.1831700, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109450, 'Jhol', 'Jhol', '', 25.9550700, 68.8882100, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109451, 'Jhelum', 'Jhelum', 'Alessandria Bucefala,Dzelam,Dzelamas,Dzhelam,Dźhelam,Dželamas,Jhelam,Jhelum,jehalama,jellum,jhelama sahara,jhlm,jie he lei mu,Џелам,Джелам,جهلم,جہلم,جێھلۆم,झेलम शहर,ਜੇਹਲਮ,傑赫勒姆,젤룸', 32.9344800, 73.7310200, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109452, 'Jhāwāriān', 'Jhawarian', '', 32.3619200, 72.6227500, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109453, 'Dera Allāhyār', 'Dera Allahyar', 'Dera Allahyar,Dera Allāhyār,Jhatpat,Jhatpat Sadar', 28.3735300, 68.3507800, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109454, 'Jhang Sadr', 'Jhang Sadr', 'Jhang Marghiana,Jhang Marghiānā,Jhang Sadar,Jhang Sadr,Jhang-Maghiana,Jhang-Maghiāna,Maghiana,Maghiāna', 31.2698100, 72.3168700, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109455, 'Jauharābād', 'Jauharabad', 'Jauharabad,Jauharābād,Joharabad', 32.2898000, 72.2813000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109456, 'Jatoi Shimāli', 'Jatoi Shimali', 'Jatoi Shimali,Jatoi Shimāli,Jatoi Shumali', 29.5165400, 70.8503200, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109457, 'Jāti', 'Jati', 'Jati,Jāti,Mughal Bhim,Mughalbhin,Mughalbhīn', 24.3549200, 68.2673200, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109458, 'Jarānwāla', 'Jaranwala', 'Jaranwala,Jarānwāla', 31.3333300, 73.4333300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109459, 'Jāndiālā Sher Khān', 'Jandiala Sher Khan', 'Jandiala Sher Khan,Jāndiālā Sher Khān', 31.8209800, 73.9181500, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109460, 'Jand', 'Jand', 'Jand', 33.4298500, 72.0192800, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109461, 'Jāmshoro', 'Jamshoro', 'Jam Shoro,Jams Shoro,Jamsboro,Jamshore,Jamshoro,Jām Shoro,Jāmshoro', 25.4360800, 68.2801700, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109462, 'Jāmpur', 'Jampur', '', 29.6441400, 70.5954400, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109463, 'Jalālpur Pīrwāla', 'Jalalpur Pirwala', 'Jalalpur,Jalalpur Pirwala,Jalālpur Pīrwāla', 29.5051000, 71.2220200, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109464, 'Jalalpur Jattān', 'Jalalpur Jattan', 'Jalalpur,Jalalpur Jattan,Jalalpur Jattān,Jalālpur', 32.6411800, 74.2056100, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109465, 'Jahāniān Shāh', 'Jahanian Shah', '', 31.8054100, 72.2774000, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109466, 'Jacobābād', 'Jacobabad', 'JAG,Jacobabad,Jacobadad,Jacobābād,Jacobādad', 28.2818700, 68.4376100, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109467, 'Islāmkot', 'Islamkot', '', 24.6990400, 70.1798200, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109468, 'Islamabad', 'Islamabad', 'Gorad Islamabad,ISB,Islamabad,Islamabada,Islamabadas,Islamabade,Islamabadi,Islamabado,Islamahbad,Islamampant,Islàmabad,Islámábád,Islāmābād,Islāmābāda,Iszlamabad,Iszlámábád,aslam abad,isalamabada,iseullamabadeu,islamabad,islamabada,islamabadi,islamapat,isuramabado,xislamabad,yi si lan bao,yyslamabad,yyslamyabad,Îslamabad,İslamabad,Ισλαμαμπάντ,Ісламабад,Горад Ісламабад,Исламабад,Իսլամաբադ,איסלאמאבאד,איסלמבאד,إسلام آباد,ئىسلامئاباد,ئیسلاماباد,اسلام آباد,اسلام اباد,اسلام‌آباد,އިސްލާމްއާބާދު,इस्लामाबाद,ইসলামাবাদ,ਇਸਲਾਮਾਬਾਦ,ઇસ્લામાબાદ,ଇସଲାମାବାଦ,இஸ்லாமாபாத்,ಇಸ್ಲಾಮಾಬಾದ್,ഇസ്ലാമബാദ്,อิสลามาบัด,ཨི་སི་ལམ་བོ།,ისლამაბადი,ኢስላማባድ,イスラマバード,伊斯兰堡,伊斯蘭堡,이슬라마바드', 33.7214800, 73.0432900, 'PK', '2013-04-05', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109469, 'Hyderabad', 'Hyderabad', 'Chainterampant,HDD,Haidarabad,Haidarabadas,Hajdarabad,Hajderabado,Haydarabad,Haydarobod,Hiderabad,Hiderábád,Hyderabad,Hyderabad i Pakistan,Hyderâbâd,Hyderābād,Khajdarabad,Khajderabad,aitarapat,hai de la ba,haidarabad,haidarabada,haidarabadi,haidelabadeu,haiderabado,hydr abad,hydrabad,hydrabad  snڌ,Χαϊντεραμπάντ,Хайдарабад,Хајдерабад,היידראבאד,حيدر آباد,حيدرآباد، سنڌ,حیدرآباد,حیدرآباد، سندھ,हैदराबाद,हैदराबाद्,ਹੈਦਰਾਬਾਦ,ஐதராபாத்,ჰაიდარაბადი,ハイデラバード,海得拉巴,하이데라바드', 25.3924200, 68.3736600, 'PK', '2015-04-24', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109470, 'Hujra Shāh Muqim', 'Hujra Shah Muqim', 'Hujra,Hujra Shah Muqim,Hujra Shāh Muqim', 30.7416800, 73.8232700, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109471, 'Hingorja', 'Hingorja', '', 27.2108800, 68.4159800, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109472, 'Hazro City', 'Hazro City', 'Hazro,Hazro City', 33.9099000, 72.4917900, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109473, 'Haveliān', 'Havelian', 'Havelian,Haveliān', 34.0534800, 73.1599300, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109474, 'Haveli Lakha', 'Haveli Lakha', 'Haveli,Haveli Lakha', 30.4509700, 73.6937100, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109475, 'Hāsilpur', 'Hasilpur', 'Hasilpur,Hasipur,Hāsilpur,Hāsipur', 29.6922100, 72.5456600, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109476, 'Hasan Abdāl', 'Hasan Abdal', '', 30.4333300, 72.7000000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109477, 'Haru Zbad', 'Haru Zbad', 'Badruwala Mandi,Badruwāla Mandi,Haroonabad Municipality,Haru Zbad,Harunabad,Hārūnābād', 29.6120600, 73.1380200, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109478, 'Harnoli', 'Harnoli', 'Haranoli,Harnoli', 32.2791700, 71.5538900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109479, 'Harnāi', 'Harnai', 'Harnai,Harnai Bazar,Harnāi', 30.1007700, 67.9382400, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109480, 'Harīpur', 'Haripur', 'Haripur,Harīpur,Kharipur,Харипур', 33.9999700, 72.9340900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109481, 'Hangu', 'Hangu', 'Hangu', 33.5319800, 71.0595000, 'PK', '2015-05-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109482, 'Hāla', 'Hala', 'Hala,Halu,Hāla,Khala,Хала', 25.8145900, 68.4219800, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109483, 'Hāfizābād', 'Hafizabad', 'Hafizabad,Hāfizābād', 32.0678600, 73.6854500, 'PK', '2012-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109484, 'Hadāli', 'Hadali', '', 32.6413200, 74.5690400, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109485, 'Gwadar', 'Gwadar', 'GWD,Gorad Gvadar,Gvadar,Gvadaras,Gwadar,Gwadur,Gwādar,gua da er,guwadaru,gvadara,gwadaleu,gwadr,jwadr,Гвадар,Горад Гвадар,جوادر,گوادر,ग्वादर,グワーダル,瓜达尔,瓜達爾,과다르', 25.1216300, 62.3254100, 'PK', '2013-05-12', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109486, 'Gujrāt', 'Gujrat', 'GRT,Gudzharat,Gujrat,Gujrāt,gjrat,Гуджарат,گجرات', 32.5742000, 74.0754200, 'PK', '2017-04-02', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109487, 'Gujrānwāla', 'Gujranwala', 'Gajranvala,Gujranwala,Gujrānwāla,Гайранвала,گوجرانوالہ', 32.1556700, 74.1870500, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109488, 'Gujar Khān', 'Gujar Khan', 'Gujar Khan,Gujar Khān,Gūjar Khān', 33.2541100, 73.3043300, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109489, 'Gojra', 'Gojra', 'Godzhra,Gojra,gwjra,gwjrh  pakstan,Годжра,Гојра,گوجرا,گوجره، پاکستان,گوجرہ', 31.1492600, 72.6832300, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109490, 'Gilgit', 'Gilgit', 'GIL,Gilghit,Gilgit,glgt,گلگت', 35.9186900, 74.3124500, 'PK', '2013-11-12', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109491, 'Ghotki', 'Ghotki', 'Ghotki,Gotki', 28.0043700, 69.3156900, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109492, 'Ghauspur', 'Ghauspur', 'Ghauspur,Ghouspur', 28.1390600, 69.0830500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109493, 'Ghāro', 'Gharo', 'Garho,Gharo,Ghāro', 24.7418200, 67.5853400, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109494, 'Garh Mahārāja', 'Garh Maharaja', '', 30.8338300, 71.9049100, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109495, 'Garhiyasin', 'Garhiyasin', 'Garhi Yasin,Garhi Yāsīn,Garhiyasin,Gari Yasin,Gharhi Yasin,Gāri Yāsin', 27.9063100, 68.5121000, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109496, 'Garhi Khairo', 'Garhi Khairo', 'Garhi Khairo,Khaira Garhi,Khaira Gārhi', 28.0602900, 67.9803300, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109497, 'Goth Garelo', 'Goth Garelo', 'Garelo,Goth Garelo', 27.4352100, 68.0757200, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109498, 'Gandāvā', 'Gandava', 'Gandava,Gandawah,Gandāvā', 28.6132100, 67.4856400, 'PK', '2016-08-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109499, 'Gambat', 'Gambat', 'Gambat,Gampat,Gumbad', 27.3514500, 68.5205100, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109500, 'Gākuch', 'Gakuch', 'Gakuch,Gākuch', 36.1768300, 73.7638300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109501, 'Gadāni', 'Gadani', 'Gadani,Gadāni', 25.1185300, 66.7298500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109502, 'Fort Abbās', 'Fort Abbas', 'Abbas,Fort Abbas,Fort Abbās,Mandi', 29.1934400, 72.8552500, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109503, 'Fāzilpur', 'Fazilpur', 'Fazalpur,Fazilpur,Fāzilpur', 32.1762900, 75.0658300, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109504, 'Chak Two Hundred Forty-Nine TDA', 'Chak Two Hundred Forty-Nine TDA', 'Chak Two Hundred Forty-Nine TDA,Fatehpur', 31.1795900, 71.2094600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109505, 'Farūka', 'Faruka', 'Farooka,Faruka,Farūka', 31.8864200, 72.4136200, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109506, 'Faqīrwāli', 'Faqirwali', 'Fagirwali,Fagīrwāli,Faqirwala,Faqirwali,Faqīrwāla,Faqīrwāli', 29.4679900, 73.0348900, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109507, 'Faisalābād', 'Faisalabad', 'Faisalabad,Faisalabada,Faisalābād,Faisalābāda,Fajsalabad,Feisalabadas,Fejsalabade,LYP,Lyallpur,Shah Faisalabad,faisarabado,fysl abad,Фейсалабаде,فيصل آباد,فیصل آباد,ファイサラバード,ファイサラーバード', 31.4166700, 73.0833300, 'PK', '2017-03-31', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109508, 'Eminābād', 'Eminabad', 'Eminabad,Eminābād', 32.0423700, 74.2599600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109509, 'Dunyāpur', 'Dunyapur', 'Dunyapur,Dunyāpur', 29.7995000, 71.7195800, 'PK', '2014-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109510, 'Dūnga Būnga', 'Dunga Bunga', 'Dunga Bunga,Dūnga Būnga', 29.7497500, 73.2429400, 'PK', '2016-03-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109511, 'Dullewāla', 'Dullewala', 'Dull-wali,Dullewala,Dullewali,Dullewāla,Dulliwala', 31.8358700, 71.4362500, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109512, 'Duki', 'Duki', '', 30.1530700, 68.5732300, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109513, 'Dokri', 'Dokri', 'Dokri', 27.3742100, 68.0971500, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109514, 'Doāba', 'Doaba', '', 33.4245000, 70.7367600, 'PK', '2015-08-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109515, 'Upper Dir', 'Upper Dir', 'Dir,Dīr,Upper Dir', 35.2074000, 71.8768000, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109516, 'Diplo', 'Diplo', '', 24.4668800, 69.5811400, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109517, 'Dīpālpur', 'Dipalpur', 'Dipalpur,Dīpālpur', 30.6698400, 73.6530600, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109518, 'Dinan Bashnoian Wala', 'Dinan Bashnoian Wala', 'Dinan Bashnoian Wala,Dinan Wala,dynn bshnwyyaں walہ,دینن بشنوئیاں والہ', 29.7658400, 73.2655700, 'PK', '2016-04-15', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109519, 'Dinga', 'Dinga', 'Dinga', 32.6410100, 73.7203900, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109520, 'Dijkot', 'Dijkot', 'Dijkot', 31.2173500, 72.9962100, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109521, 'Digri', 'Digri', 'Digri', 25.1557900, 69.1112900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109522, 'Dhoro Naro', 'Dhoro Naro', 'Dhoro Naro,Dhoro Nāro', 25.5048400, 69.5709000, 'PK', '2016-01-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109523, 'Dhaunkal', 'Dhaunkal', 'Dhaonkal,Dhaunkal', 32.4061300, 74.1370600, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109524, 'Dhanot', 'Dhanot', '', 29.5799100, 71.7521300, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109525, 'Dera Ismāīl Khān', 'Dera Ismail Khan', 'DSK,Dera Ismail Khan,Dera Ismāīl Khān', 31.8312900, 70.9017000, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109526, 'Dera Ghazi Khan', 'Dera Ghazi Khan', 'DEA,Dera Gazi Chanas,Dera Gazi Hano,Dera Gazi Khan,Dera Gazi Ĥano,Dera Ghazi Khan,Dera Ghoz Khan,Dera Ghāzi Khān,Dera-Gazi-Khan,Deri-Ghazi Khan,de la jia qi han,de ra ka si khan,dera gazi khana,Дера Гази Хан,Дера-Гази-Хан,دیره غازی‌خان، پاکستان,ڈیرہ غازی خان,ډېره غازي خان,डेरा ग़ाज़ी ख़ान,เดรากาซีข่าน,德拉加齊汗', 30.0561400, 70.6347700, 'PK', '2014-08-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109527, 'Dera Bugti', 'Dera Bugti', 'Dera Bagti,Dera Bugti', 29.0361900, 69.1584900, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109528, 'Daur', 'Daur', 'Daur', 26.4552800, 68.3183500, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109529, 'Daultāla', 'Daultala', '', 33.1928200, 73.1409900, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109530, 'Daulatpūr', 'Daulatpur', 'Daulatpur,Daulatpūr,Doulatpur', 26.5015800, 67.9707900, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109531, 'Dāūd Khel', 'Daud Khel', 'Daud Khel,Dāūd Khel', 32.8753300, 71.5711800, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109532, 'Daska Kalān', 'Daska Kalan', 'Daska,Daska Kalan,Daska Kalān', 32.3242200, 74.3503900, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109533, 'Darya Khān Marri', 'Darya Khan Marri', 'Darya Khan Mari,Darya Khan Marri,Darya Khān Marri', 26.6776500, 68.2866600, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109534, 'Darya Khān', 'Darya Khan', 'Darva Khan,Darva Khān,Darya Khan,Darya Khan Daggar,Darya Khān', 31.7912300, 71.1039400, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109535, 'Dāro Mehar', 'Daro Mehar', 'Daro,Daro Mehar,Durro,Dāro Mehar', 24.7946300, 68.1805200, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109536, 'Dālbandīn', 'Dalbandin', 'DBA,Dalbandin,Dālbandīn', 28.8884600, 64.4061600, 'PK', '2017-03-31', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109537, 'Dājal', 'Dajal', '', 29.5576700, 70.3761500, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109538, 'Dāira Din Panah', 'Daira Din Panah', 'Daira Din Panah,Daira Din Pannah Mustaqil,Daira Dīn Panāh,Dāira Din Panah,Dāira Dīn Panāh', 30.5705300, 70.9372200, 'PK', '2016-06-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109539, 'Daggar', 'Daggar', 'Dagar,Daggar', 34.5110600, 72.4843800, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109540, 'Dadu', 'Dadu', 'DDU,Dadu,Dādu,dadu,دادُو', 26.7328700, 67.7763100, 'PK', '2013-06-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109541, 'Dādhar', 'Dadhar', 'Dadhar,Dhadar,Dādhar', 29.4748900, 67.6516700, 'PK', '2016-10-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109542, 'Chūniān', 'Chunian', 'Chunian,Chūniān', 30.9662100, 73.9790800, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109543, 'Chūhar Kāna', 'Chuhar Kana', 'Chuchar-kana Mandi,Chuhar Kana,Chuhar Kand,Chūhar Kāna,Chūhar Kānd', 31.7500000, 73.8000000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109544, 'Chhor', 'Chhor', 'Chhor,Chhor Purano,Chor', 25.5126000, 69.7843700, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109545, 'Choa Saidān Shāh', 'Choa Saidan Shah', 'Choa Saidan Shah,Choa Saidān Shāh,Saidan Shah,Saidān Shāh,Saiyidan Shah,Saiyidān Shāh', 32.7196200, 72.9862500, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109546, 'Chitral', 'Chitral', 'CJL,Chetrar,Chitral,Chitrāl,Citral,Czitral,chiteulal,chitoraru,chtral,chytral,chھtrar,ci tra l,citrala,Çitral,Čitral,Читрал,چترال,چھترار,چیترال,चित्राल,চিত্রল,จิตราล,チトラル,치트랄', 35.8462300, 71.7858000, 'PK', '2015-04-24', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109547, 'Chishtiān', 'Chishtian', 'Chishtian,Chishtian Mandi,Chishtiān,Chishtiān Mandi,Chistian', 29.7971300, 72.8577200, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109548, 'Chiniot', 'Chiniot', 'Chaniot,Chiniot,Chinot,chnywt  pakstan,ji ni ao de,Чиниот,چنيوټ,چنیوت، پاکستان,چنیوٹ,吉尼奧德', 31.7200000, 72.9788900, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109549, 'Chilas', 'Chilas', 'CHB,Chilas,chlas,چلاس', 35.4117200, 74.1035200, 'PK', '2013-05-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109550, 'Chīchāwatni', 'Chichawatni', 'Chichawatni,Chīchāwatni', 30.5333300, 72.7000000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109551, 'Cherāt Cantonement', 'Cherat Cantonement', 'Cherat,Cherat Cantonement,Cherāt,Cherāt Cantonement', 33.8234200, 71.8929200, 'PK', '2015-09-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109552, 'Chawinda', 'Chawinda', 'Chawinda', 32.3443400, 74.7050700, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109553, 'Chārsadda', 'Charsadda', 'Charsadda,Chārsadda', 34.1482200, 71.7406000, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109554, 'Chamber', 'Chamber', 'Chakkar,Chambar,Chamber', 25.2936200, 68.8117600, 'PK', '2017-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109555, 'Chaman', 'Chaman', 'Caman,Camanas,Chaman,camana,chaman,chmn,Çaman,Čamanas,Чаман,چمن,चमन,チャマン,차만', 30.9176900, 66.4525900, 'PK', '2016-07-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109556, 'Chakwāl', 'Chakwal', 'Chakwal,Chakwāl', 32.9333800, 72.8585300, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109557, 'Chak Azam Sāhu', 'Chak Azam Sahu', 'Chak Azam Saffo,Chak Azam Saho,Chak Azam Sahu,Chak Azam Sāhu,Chak Āzam Saffo', 30.7520200, 73.0283400, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109558, 'Chak', 'Chak', '', 27.8583800, 68.8337800, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109559, 'Būrewāla', 'Burewala', '', 30.1666700, 72.6500000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109560, 'Bulri', 'Bulri', '', 24.8666700, 68.3333300, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109561, 'Bozdār Wada', 'Bozdar Wada', 'Bozdar,Bozdar Wada,Bozdār Wada', 27.1830000, 68.6358000, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109562, 'Bhopālwāla', 'Bhopalwala', '', 32.4296800, 74.3635000, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109563, 'Bhit Shāh', 'Bhit Shah', 'Bhit Shah,Bhit Shāh', 25.8056500, 68.4914300, 'PK', '2017-06-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109564, 'Bhiria', 'Bhiria', 'Bhiria', 26.9104100, 68.1946600, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109565, 'Bhimbar', 'Bhimbar', 'Bhimbar,Bhimber', 32.9746500, 74.0784600, 'PK', '2016-02-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109566, 'Bhera', 'Bhera', 'Bhera,Bwera', 32.4831800, 72.9097000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109567, 'Bhawāna', 'Bhawana', 'Bawana,Bhawana,Bhawāna,Bhowana', 31.5688400, 72.6491700, 'PK', '2017-03-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109568, 'Bhān', 'Bhan', '', 26.5583100, 67.7213900, 'PK', '2011-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109569, 'Bhalwāl', 'Bhalwal', 'Bhalwal,Bhalwāl', 32.2720400, 72.9042500, 'PK', '2013-04-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109570, 'Bhakkar', 'Bhakkar', 'Bhakkar', 31.6252500, 71.0657400, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109571, 'Bhāi Pheru', 'Bhai Pheru', 'Bhai Pheru,Bhar Pheru,Bhāi Pheru,Mian-ki-Maur,Miān-ki-Maur,Phool Nagar', 31.2000000, 73.9500000, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109572, 'Bhāg', 'Bhag', '', 29.0415000, 67.8239000, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109573, 'Berāni', 'Berani', '', 25.7850100, 68.8068600, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109574, 'Bela', 'Bela', 'Armabel,Armail,Armel,Beila,Bela,Kambakia,Karabel,Las Bela,Бела', 26.2271800, 66.3117800, 'PK', '2016-09-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109575, 'Begowāla', 'Begowala', 'Begawala,Begowala,Begowāla', 32.4381600, 74.2679400, 'PK', '2017-02-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109576, 'Bat Khela', 'Bat Khela', 'Bat Khela,Batkhel', 34.6178000, 71.9724700, 'PK', '2015-07-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109577, 'Battagram', 'Battagram', 'Batagram,Batagrām,Batgram,Batgran,Batgrām,Batgrān,Battagram,Battagram City,Battagrām', 34.6771900, 73.0232900, 'PK', '2016-12-15', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109578, 'Basīrpur', 'Basirpur', '', 30.5775900, 73.8391200, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109579, 'Bārkhān', 'Barkhan', 'Barkhan,Bārkhān,بارکھان', 29.8977300, 69.5255800, 'PK', '2016-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109580, 'Bannu', 'Bannu', 'BNP,Bannu,Banu,ban''nu,bannu,Банну,بنوں,बन्नू,バンヌ,반누', 32.9854100, 70.6027000, 'PK', '2013-05-11', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109581, 'Bāndhi', 'Bandhi', 'Bandhi,Bāndhi', 26.5876100, 68.3021500, 'PK', '2016-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109582, 'Bakhri Ahmad Khan', 'Bakhri Ahmad Khan', '', 30.7358600, 70.8379600, 'PK', '2010-06-30', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109583, 'Bahāwalpur', 'Bahawalpur', 'BHV,Bahawalpur,Bahāwalpur,Bakhavalpura,Бахавалпура', 29.4000000, 71.6833300, 'PK', '2017-04-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109584, 'Bahāwalnagar', 'Bahawalnagar', 'Bahawalnagar,Bahawalpur,Bahawatnagar,Bahawâlpur,Bahāwalnagar,بہاولپور', 29.9983500, 73.2527200, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109585, 'Bāgh', 'Bagh', 'Bagh,Bāgh', 33.9811100, 73.7760800, 'PK', '2012-02-01', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109586, 'Bāgarji', 'Bagarji', 'Bagarji,Bagerji,Bāgarji', 27.7543100, 68.7586600, 'PK', '2016-11-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109587, 'Baffa', 'Baffa', 'Baffa', 34.4377000, 73.2236800, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109588, 'Badin', 'Badin', 'BDN,Badin,bdyn‎,Бадин,بدين‎', 24.6560000, 68.8370000, 'PK', '2017-02-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109589, 'Baddomalhi', 'Baddomalhi', 'Baddomalhi', 31.9904200, 74.6641000, 'PK', '2017-04-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109590, 'Awārān', 'Awaran', 'Awaran,Awārān', 26.4567700, 65.2314400, 'PK', '2016-08-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109591, 'Attock City', 'Attock City', 'Attock City,Campbellpore,Campbellpur', 33.7667100, 72.3597700, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109592, 'Ārifwāla', 'Arifwala', 'Arifwala,Ārifwāla', 30.2905800, 73.0657400, 'PK', '2017-05-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109593, 'Amān Garh', 'Aman Garh', 'Aman Garh,Amangarh,Amān Garh', 34.0058400, 71.9297100, 'PK', '2016-04-10', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109594, 'Alizai', 'Alizai', 'Alizai,Alīzai', 33.5361300, 70.3460700, 'PK', '2015-04-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109595, 'Alīpur', 'Alipur', '', 29.3846400, 70.9115700, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109596, 'Alīābad', 'Aliabad', '', 36.3070300, 74.6154500, 'PK', '2011-07-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109597, 'Akora', 'Akora', 'Akora,Akora Khattak,Akora Khāttak,Акора', 34.0033700, 72.1256100, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109598, 'Ahmadpur East', 'Ahmadpur East', 'Ahmadpur,Ahmadpur East,Ahmedpur East,Ahmedpur East Municipality', 29.1430900, 71.2597600, 'PK', '2012-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109599, 'Abbottābād', 'Abbottabad', 'Abbottabad,Abbottābād,Абботтабад', 34.1463000, 73.2116800, 'PK', '2017-01-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109600, 'Jhang City', 'Jhang City', 'Jhang,Jhang City', 31.3056800, 72.3259400, 'PK', '2017-02-04', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109601, 'Bahāwalnagar', 'Bahawalnagar', 'Bahawalnagar,Bahāwalnagar', 30.5508300, 73.3908300, 'PK', '2012-01-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109602, 'Gulishāh Kach', 'Gulishah Kach', '', 32.6708700, 70.3391700, 'PK', '2014-10-02', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109603, 'Nowshera Cantonment', 'Nowshera Cantonment', '', 33.9982900, 71.9983400, 'PK', '2012-02-28', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109604, 'Alik Ghund', 'Alik Ghund', '', 30.4897600, 67.5217700, 'PK', '2016-11-23', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109605, 'Khadan Khāk', 'Khadan Khak', 'Khadan Khak,Khadan Khāk,Khadar Khak,Khadar Khāk', 30.7523600, 67.7113300, 'PK', '2016-10-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109606, 'Ahmadpur Siāl', 'Ahmadpur Sial', '', 30.6779100, 71.7434400, 'PK', '2017-06-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109607, 'New Bādāh', 'New Badah', '', 27.3416700, 68.0319400, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109608, 'Dandot RS', 'Dandot RS', 'Dandot RS', 32.6416700, 72.9750000, 'PK', '2016-11-28', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109609, 'Dera Murād Jamāli', 'Dera Murad Jamali', 'Dera Murad Jamali,Dera Murād Jamāli,Temple Dera', 28.5465700, 68.2230800, 'PK', '2012-01-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109610, 'Jām Sāhib', 'Jam Sahib', '', 26.2958300, 68.6291700, 'PK', '2006-01-17', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109611, 'Chowki Jamali', 'Chowki Jamali', '', 28.0194400, 67.9208300, 'PK', '2007-11-18', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109612, 'Sethārja Old', 'Setharja Old', '', 27.2127000, 68.4688300, 'PK', '2011-05-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109613, 'Risalpur Cantonment', 'Risalpur Cantonment', 'Risalpur,Risalpur Cantonment,Risālpur', 34.0604800, 71.9927600, 'PK', '2016-04-11', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109614, 'Noorābād', 'Noorabad', 'Noorabad,Nooriabad,Noorābād', 34.2519500, 71.9665600, 'PK', '2012-01-19', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109615, 'Alpūrai', 'Alpurai', '', 34.9205800, 72.6325600, 'PK', '2011-05-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109616, 'Shingli Bala', 'Shingli Bala', 'Bar Shinglai,Shingli Bala,shngly bala,شنگلی بالا', 34.6787200, 72.9849100, 'PK', '2017-04-16', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109617, 'Malakwal City', 'Malakwal City', '', 32.5549200, 73.2122000, 'PK', '2007-04-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109618, 'Mehmand Chak', 'Mehmand Chak', '', 32.7851800, 73.8230600, 'PK', '2009-04-20', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109619, 'Basti Dosa', 'Basti Dosa', '', 30.7876900, 70.8685300, 'PK', '2009-09-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109620, 'Moza Shahwala', 'Moza Shahwala', '', 30.8056300, 70.8491100, 'PK', '2009-09-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109621, 'Khuzdār', 'Khuzdar', 'Khuzdar,Khuzdar Cantonment,Khuzdār,Khuzdār Cantonment', 27.7383900, 66.6433700, 'PK', '2012-01-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109622, 'Eidgāh', 'Eidgah', 'Eidgah,Eidgāh,Idgah,Īdgāh', 35.3471200, 74.8563200, 'PK', '2016-02-07', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109623, 'Dasu', 'Dasu', 'Dasu', 35.2916900, 73.2906000, 'PK', '2012-05-06', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109624, 'Barishāl', 'Barishal', '', 36.3216200, 74.6950200, 'PK', '2016-01-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109625, 'Athmuqam', 'Athmuqam', 'Athmuqam', 34.5717300, 73.8972400, 'PK', '2012-01-21', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109626, 'Nazir Town', 'Nazir Town', '', 33.3061400, 73.4833000, 'PK', '2011-02-08', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109627, 'Amirabad', 'Amirabad', '', 34.1872900, 73.0907800, 'PK', '2012-03-25', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109628, 'Kakad Wari Dir Upper', 'Kakad Wari Dir Upper', '', 34.9979800, 72.0729500, 'PK', '2012-12-03', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109629, 'Hattian Bala', 'Hattian Bala', '', 34.1691000, 73.7432000, 'PK', '2014-05-09', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109630, 'Ashanagro Koto', 'Ashanagro Koto', '', 34.1077300, 72.2451700, 'PK', '2015-11-12', 168);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109631, 'Żyrzyn', 'Zyrzyn', 'Zyrzyn,Zytzyn,Żyrzyn,Żytzyn', 51.4991800, 22.0917000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109632, 'Żyrardów', 'Zyrardow', 'Zhirardov,Zhirarduv,Zirardova,Zyrardow,Zyrarduvas,ri la er du fu,Żyrardów,Žirardova,Žyrarduvas,Жирардов,Жирардув,זירארדוב,日拉爾杜夫', 52.0488000, 20.4459900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109633, 'Żyraków', 'Zyrakow', '', 50.0854500, 21.3962200, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109634, 'Zwoleń', 'Zwolen', 'Zvolen,Zvolen'',Zvolena,Zvoleņa,zbwln,zi wo lun,Зволен,Зволень,Зволењ,זבולן,茲沃倫', 51.3554200, 21.5876800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109635, 'Zwierzyniec', 'Zwierzyniec', 'Zvezhinec,Zvezhinec'',Zvezineca,Zvežiņeca,Zvjezhinec,Zwierzyniec,zfyjynyts,zi wei ri nie ci,Звежинец,Звежинець,Звјежињец,زفيجينيتس,茲維日涅茨', 50.6140000, 22.9751200, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109636, 'Żurowa', 'Zurowa', '', 49.8263600, 21.1689400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109637, 'Żurawiczki', 'Zurawiczki', '', 50.0137000, 22.4994900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109638, 'Żurawica', 'Zurawica', '', 49.8234800, 22.7892500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109639, 'Żołynia', 'Zolynia', '', 50.1620000, 22.3082500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109640, 'Żółkiewka', 'Zolkiewka', 'Zolkiewka,Zolkiewka-Osada,Żółkiewka,Żółkiewka-Osada', 50.9099100, 22.8346500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109641, 'Żoliborz', 'Zoliborz', 'Zalborz,Zalbórz', 52.2689600, 20.9864400, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109642, 'Zmiennica', 'Zmiennica', '', 49.6765200, 21.9659600, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109643, 'Złota', 'Zlota', 'Comuna de Zlota,Comuna de Złota,Gmina Zlota,Gmina Złota,Zlota,Злота,Ґміна Злота', 50.3816000, 20.5936100, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109644, 'Złota', 'Zlota', '', 49.8805900, 20.6932600, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109645, 'Zielonka', 'Zielonka', 'Zel''onka,Zelenka,Zeljonka,Zelonka,Zhel''onka,Zielonka,Zjelonka,jie long ka,Жельонка,Зеленка,Зельонка,Зелёнка,Зјелонка,傑隆卡', 52.3037600, 21.1601800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109646, 'Zgłobień', 'Zglobien', '', 50.0127000, 21.8549000, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109647, 'Żelechów', 'Zelechow', 'Zelechow,Zelechuw,Zelehova,Zhelekhov,Zhelekhuv,re lai hu fu,zlhwb,Żelechów,Żelechůw,Želehova,Желехов,Желехув,זלחוב,熱萊胡夫', 51.8105100, 21.8972100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109648, 'Żelechlinek', 'Zelechlinek', '', 51.7121400, 20.0346000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109649, 'Żegocina', 'Zegocina', 'Rzegocina,Zegocina,Żegocina', 49.8139500, 20.4196400, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109650, 'Zbuczyn', 'Zbuczyn', 'Zbuchinka,Zbuczyn,Збучинка', 52.0897400, 22.4382900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109651, 'Zbójna', 'Zbojna', 'Zbojna,Zbujna,Zbójna,Збуйна', 53.2429300, 21.7881200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109652, 'Zawichost', 'Zawichost', 'Zavihosta,Zavikhost,zha wei huo si te,zwwyhwst,Завихост,זוויחוסט,扎維霍斯特', 50.8074300, 21.8540800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109653, 'Zatory', 'Zatory', 'Zatory,Заторы', 52.5992900, 21.1825800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109654, 'Zarzecze', 'Zarzecze', '', 50.5276700, 22.1952200, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109655, 'Zarzecze', 'Zarzecze', '', 49.9863300, 22.5371600, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109656, 'Zarszyn', 'Zarszyn', '', 49.5817800, 22.0128300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109657, 'Żarnów', 'Zarnow', '', 51.2460700, 20.1747600, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109658, 'Zamość', 'Zamosc', 'Gorad Zamasc'',Zamosc,Zamosc'',Zamosca,Zamoscia,Zamose,Zamoshc,Zamoshch,Zamost''ye,Zamoste,Zamostja,Zamosts,Zamostė,Zamost’ye,Zamość,jamosichi,sa mxchch,zamoshichi,zamostsi,zha mo xi qi,zmwsz,Ζάμοστς,Горад Замасць,Замостя,Замосць,Замошч,Замошћ,Զամոշչ,זמושץ,ซามอชช์,ზამოსცი,ザモシチ,扎莫希奇,자모시치', 50.7231400, 23.2519600, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109659, 'Zamch', 'Zamch', 'Zamch,Zamek', 50.3171300, 23.0278600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109660, 'Zambrów', 'Zambrow', 'Zambrov,Zambrova,Zambrow,Zambruv,Zambruvas,Zambrów,zan bu lu fu,zmbrwb,Замбров,Замбрув,זמברוב,贊布魯夫', 52.9855000, 22.2431900, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109661, 'Załuski', 'Zaluski', '', 52.5115200, 20.5286400, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109662, 'Zaleszany', 'Zaleszany', '', 50.6479900, 21.8906900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109663, 'Zalesie Górne', 'Zalesie Gorne', 'Zalese-Gurne,Zalesie Gorne,Zalesie Górne,Залесе-Гурне', 52.0276800, 21.0365900, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109664, 'Zalesie', 'Zalesie', 'Zalesie', 52.0374300, 23.3636000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109665, 'Zakrzówek', 'Zakrzowek', '', 50.9512400, 22.3813800, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109666, 'Zakrzew', 'Zakrzew', 'Zakrzew,Zakrzow,Zakrzów', 51.4409500, 21.0010500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109667, 'Zakrzew', 'Zakrzew', 'Zakrzew,Zakrzow', 50.8900400, 22.5911500, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109668, 'Zakroczym', 'Zakroczym', 'Zakrochim,Zakrocima,Zakroczym,Zakročima,zha ke luo qi mu,zqrwzym,Закрочим,זקרוצים,扎克羅奇姆', 52.4335100, 20.6120700, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109669, 'Zaklików', 'Zaklikow', 'Zaklikov,Zaklikow,Zaklików,zqlyqwb,Закликов,זקליקוב', 50.7576900, 22.1022600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109670, 'Zakliczyn', 'Zakliczyn', 'Comuna de Zakliczyn,Gmina Zaklichin,Gmina Zakliczyn,Zaklichin,Zakliczyn,Закличин,Ґміна Заклічин', 49.8558900, 20.8093500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109671, 'Zagórzyce', 'Zagorzyce', '', 50.0169000, 21.6751700, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109672, 'Zagórz', 'Zagorz', 'Zagirja,Zagorz,Zagoza,Zagozh,Zagoža,Zaguzh,Zagórz,zgwrd,zha gu ri,Загож,Загуж,Загіря,زگورض,扎古日', 49.5145700, 22.2670600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109673, 'Zagnańsk', 'Zagnansk', 'zagnansk,زاگنانسک', 50.9803700, 20.6631400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109674, 'Żabno', 'Zabno', 'Zabno,Zadno,Zhabno,zabnw,zha bu nuo,Żabno,Żadno,Žabno,Жабно,זאבנו,زابنو,扎布諾', 50.1333400, 20.8861500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109675, 'Zabłudów', 'Zabludow', 'Gorad Zabludau,Zabludiv,Zabludov,Zabludova,Zabludow,Zabluduv,Zabluduvas,Zabłudów,dabwadww,zblwdwb,zha bu wu du fu,Горад Заблудаў,Заблудов,Заблудув,Заблудів,זבלודוב,ضابوادوو,扎布武杜夫', 53.0144200, 23.3383100, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109676, 'Ząbki', 'Zabki', 'Zabki,Zombkai,Zombki,Zompki,Ząbki,zong bu ji,zwbky,Зомбки,Зомпки,زوبکی,宗布基', 52.2927100, 21.1053900, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109677, 'Zabierzów Bocheński', 'Zabierzow Bochenski', 'Zabierzow,Zabierzow Bochenski,Zabierzów,Zabierzów Bochenski', 50.0682100, 20.3189600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109678, 'Żabieniec', 'Zabieniec', '', 52.0585600, 21.0481700, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109679, 'Żabia Wola', 'Zabia Wola', 'Comuna de Zabia Wola,Comuna de Żabia Wola,Gmina Zabia Wola,Gmina Zhabja Volja,Gmina Żabia Wola,Zhabja-Volja,Жабя-Воля,Ґміна Жабя Воля', 52.0316900, 20.6911200, 'PL', '2015-08-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109680, 'Wyszogród', 'Wyszogrod', 'Vishogrod,Vishogrud,Visogroda,Višogroda,Vyshogrud,wei shao ge lu de,wyswgrwd,Вишогрод,Вишогруд,Вышогруд,וישוגרוד,維紹格魯德', 52.3898800, 20.1908100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109681, 'Wyszków', 'Wyszkow', 'Vishkov,Vishkuv,Viskova,Viskuv,Viskuvas,Vişkuv,Viškova,Viškuvas,Vyshkov,Vyshkuv,Wyszkow,Wyszków,wei shen ku fu,wysqwb,Вишков,Вишкув,Вышкув,וישקוב,維什庫夫', 52.5927800, 21.4584000, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109682, 'Wyszki', 'Wyszki', 'Comuna Wyszki,Comuna de Wyszki,Gmina Vishki,Gmina Wyszki,Visku valscius,Viškų valsčius,Vyshki,Вышки,Ґміна Вишкі', 52.8412900, 22.9811900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109683, 'Wysokie Mazowieckie', 'Wysokie Mazowieckie', 'Mazovijos Vysokis,Visoke Mazovecke,Visoke-Mazovec''ke,Visokje Mazovjeckje,Vysoke-Mazovecke,Wysokie Mazowieckie,ma zuo fu she de qu wei suo kai,wyswqh mzwbyyzq,Високе Мазовецке,Високе-Мазовецьке,Високје Мазовјецкје,Высоке-Мазовецке,ויסוקה מזובייצק,馬佐夫舍地區維索凱', 52.9166100, 22.5171200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109684, 'Wysokie', 'Wysokie', '', 50.9109300, 22.6660000, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109685, 'Wysoka Strzyżowska', 'Wysoka Strzyzowska', 'Wysoka,Wysoka Strzyzowska,Wysoka Strzyżowska', 49.8305600, 21.7407400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109686, 'Wysoka Głogowska', 'Wysoka Glogowska', '', 50.1601900, 22.0212400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109687, 'Wysoka', 'Wysoka', '', 50.0447400, 22.2600200, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109688, 'Wyśmierzyce', 'Wysmierzyce', 'Vis''mezhice,Vismezice,Vismežice,Vismjezhice,Vysmezhice,Wysmierzyce,Wyśmierzyce,wei xi mei ri cai,Висмјежице,Висьмежице,Высмежице,維希梅日采', 51.6249400, 20.8139400, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109689, 'Wydminy', 'Wydminy', 'Vydminy,Widminnen,Wydminy,Выдмины', 53.9819400, 22.0323900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109690, 'Wołomin', 'Wolomin', 'Gorad Valomin,Volomin,Volomina,Volominas,Wolomin,Wołomin,bowomin,wo wo ming,wwlwmyn,Воломин,Воломін,Горад Валомін,וולומין,沃沃明,보워민', 52.3400600, 21.2420700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109691, 'Wólka Tanewska', 'Wolka Tanewska', '', 50.5000500, 22.2611300, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109692, 'Wólka Podleśna', 'Wolka Podlesna', 'Wolka,Wolka Podlesna,Wolka pod Lasem,Wólka,Wólka Podleśna,Wólka pod Lasem', 50.1178500, 22.1121300, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109693, 'Wólka Pełkińska', 'Wolka Pelkinska', 'Wola Pelkinska,Wola Pełkińska,Wolka Pelkinska,Wólka Pełkińska', 50.0955300, 22.6234200, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109694, 'Wólka Niedźwiedzka', 'Wolka Niedzwiedzka', 'Wolka Niedzwiecka,Wolka Niedzwiedzka,Wólka Niedzwiecka,Wólka Niedźwiedzka', 50.2422600, 22.1882600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109695, 'Wola Żarczycka', 'Wola Zarczycka', '', 50.2912000, 22.2502300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109696, 'Wola Zabierzowska', 'Wola Zabierzowska', '', 50.0725700, 20.3321700, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109697, 'Wola Uhruska', 'Wola Uhruska', '', 51.3213900, 23.6262700, 'PL', '2010-11-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109698, 'Wola Sernicka', 'Wola Sernicka', 'Wola Sernicka,Wola Syrnicka', 51.4497800, 22.6835100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109699, 'Wola Rębkowska', 'Wola Rebkowska', 'Rembkowska Wola,Wola Rebkowska,Wola Rębkowska', 51.9018100, 21.5581800, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109700, 'Wolanów', 'Wolanow', '', 51.3803000, 20.9770200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109701, 'Wola Jachowa', 'Wola Jachowa', 'Wola Jackowa', 50.8452400, 20.8581400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109702, 'Wola Dębińska', 'Wola Debinska', '', 49.9821400, 20.6877700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109703, 'Wola Batorska', 'Wola Batorska', '', 50.0526200, 20.2661700, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109704, 'Wola', 'Wola', 'Volja,Воля', 52.2401000, 20.9886900, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109705, 'Wojsławice', 'Wojslawice', '', 50.9191600, 23.5460200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109706, 'Wojnicz', 'Wojnicz', 'Vojnich,Wojnicz,wo yi ni qi,Войнич,Војњич,沃伊尼奇', 49.9580000, 20.8378500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109707, 'Wojcieszków', 'Wojcieszkow', '', 51.7692200, 22.3158900, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109708, 'Wojciechowice', 'Wojciechowice', 'Comuna de Wojciechowice,Gmina Vojcekhovice,Gmina Wojciechowice,Vojcekhovice,Wajeie chowice Jasice,Wajeie chówice Jasice,Wojciechowice,Войцеховице,Ґміна Войцеховіце', 50.8422600, 21.5894200, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109709, 'Wojciechów', 'Wojciechow', 'Wojciechow,Wojciechow Lubelski,Wojciechów,Wojciechów Lubelski', 51.2354300, 22.2455100, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109710, 'Wojaszówka', 'Wojaszowka', '', 49.7777700, 21.6707900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109711, 'Wohyń', 'Wohyn', '', 51.7564200, 22.7858200, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109712, 'Wodzisław', 'Wodzislaw', 'Comuna de Wodzislaw,Comuna de Wodzisław,Gmina Vodzislav,Gmina Wodzislaw,Gmina Wodzisław,Vodzislav,Водзислав,Ґміна Водзіслав', 50.5204700, 20.1915000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109713, 'Wodynie', 'Wodynie', '', 52.0404000, 21.9557500, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109714, 'Włodawa', 'Wlodawa', 'Gorad Uladava,Vlodava,Volodava,Wlodawa,Włodawa,fu wo da wa,wlwdbh,Влодава,Володава,Горад Уладава,ולודבה,弗沃達瓦', 51.5500000, 23.5500000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109715, 'Włochy', 'Wlochy', 'Wlochy,Włochy', 52.1794100, 20.9461200, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109716, 'Wizna', 'Wizna', 'Vizna,Wizna,wyznh,Визна,ויזנה', 53.1951800, 22.3824100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109717, 'Wisznice', 'Wisznice', '', 51.7892400, 23.2083600, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109718, 'Wiśniowa', 'Wisniowa', '', 49.8689700, 21.6550800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109719, 'Wiśniowa', 'Wisniowa', '', 49.7878000, 20.1150200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109720, 'Wiśniew', 'Wisniew', '', 52.0726500, 22.2939200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109721, 'Wiślica', 'Wislica', 'Comuna de Wislica,Comuna de Wiślica,Vislica,Vislicja,Wislica,Wiślica,wyslyzh,Вислица,Віслиця,וישליצה', 50.3489100, 20.6743800, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109722, 'Wiskitki', 'Wiskitki', 'Viskitki,Wiskiti,Wiskitki,Вискитки', 52.0883100, 20.3870800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109723, 'Winnica', 'Winnica', 'Vinnica,Winnica,Винница', 52.6430600, 20.9411400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109724, 'Wilków', 'Wilkow', '', 51.2622400, 21.8775600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109725, 'Wilkołaz', 'Wilkolaz', 'Wilkolaz Pierwszy (do 1999),Wilkołaz Pierwszy (do 1999)', 51.0147300, 22.3501400, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109726, 'Wilga', 'Wilga', 'Wilda,Wilga', 51.8521100, 21.3775100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109727, 'Wilczyce', 'Wilczyce', '', 50.7469400, 21.6578300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109728, 'Wilanów', 'Wilanow', 'Viljanuv,Вилянув', 52.1631100, 21.0874800, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109729, 'Wietrzychowice', 'Wietrzychowice', '', 50.1909700, 20.7650200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109730, 'Wierzchosławice', 'Wierzchoslawice', '', 50.0247800, 20.8567700, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109731, 'Wierzbno', 'Wierzbno', '', 52.3100800, 21.8590200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109732, 'Wierzbna', 'Wierzbna', '', 50.0331100, 22.6012800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109733, 'Wierzbica', 'Wierzbica', '', 51.2494000, 21.0825900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109734, 'Wierzawice', 'Wierzawice', '', 50.2362300, 22.4509000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109735, 'Wieniawa', 'Wieniawa', '', 51.3617100, 20.7948900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109736, 'Wielopole Skrzyńskie', 'Wielopole Skrzynskie', 'Wielopole,Wielopole Skrzynskie,Wielopole Skrzyńskie', 49.9456400, 21.6149100, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109737, 'Wielkie Oczy', 'Wielkie Oczy', '', 50.0235700, 23.1640700, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109738, 'Wielka Wieś', 'Wielka Wies', '', 51.0710700, 20.9665500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109739, 'Wielka Wieś', 'Wielka Wies', '', 49.9363100, 20.8230400, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109740, 'Wieliszew', 'Wieliszew', '', 52.4513000, 20.9682700, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109741, 'Wieliczka', 'Wieliczka', 'Velichka,Velicka,Velička,Vjelichka,Wieliczka,biellichika,fyalytshka,vu~ierichika,wei li qi ka,wyylyzqh,Величка,Вјеличка,וייליצקה,فياليتشكا,ヴィエリチカ,維利奇卡,비엘리치카', 49.9873800, 20.0647300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109742, 'Wielbark', 'Wielbark', 'Vel''bark,Wielbark,Willenberg,Вельбарк', 53.3985800, 20.9462900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109743, 'Wieczfnia Kościelna', 'Wieczfnia Koscielna', 'Wieczfnia,Wieczfnia Koscielna,Wieczfnia Kościelna', 53.1953400, 20.4763700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109744, 'Wiązownica', 'Wiazownica', '', 50.0806600, 22.7066800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109745, 'Wesoła', 'Wesola', '', 52.2545100, 21.2240700, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109746, 'Wesoła', 'Wesola', '', 49.7997700, 22.1002900, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109747, 'Werbkowice', 'Werbkowice', '', 50.7537300, 23.7641100, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109748, 'Węgrzce Wielkie', 'Wegrzce Wielkie', 'Wegrzce,Wegrzce Wielkie,Węgrzce,Węgrzce Wielkie', 50.0149100, 20.1108200, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109749, 'Węgrów', 'Wegrow', 'Gorad Vehngrau,Vengaruva,Vengrov,Vengrova,Vengruv,Vengruvas,Wegrow,Wengrover,Wengrow,Węgrów,wen ge lu fu,wngrwb,Венгров,Венгрув,Горад Вэнграў,ונגרוב,文格魯夫', 52.3995400, 22.0163400, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109750, 'Węgorzewo', 'Wegorzewo', 'Angerburg,Ungura,Vengozevo,Vengozhevo,Vengoževo,Wegobork,Wegorzewo,Węgobork,Węgorzewo,wen ge re wo,Венгожево,文戈熱沃', 54.2156700, 21.7372000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109751, 'Węglówka', 'Weglowka', '', 49.7342400, 20.0857500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109752, 'Wawrzeńczyce', 'Wawrzenczyce', '', 50.1101200, 20.3161200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109753, 'Wąwolnica', 'Wawolnica', '', 51.2946700, 22.1468100, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109754, 'Wawer', 'Wawer', '', 52.1965600, 21.1775200, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109755, 'Wąsosz', 'Wasosz', '', 53.5220900, 22.3191500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109756, 'Waśniów', 'Wasniow', '', 50.8991400, 21.2230100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109757, 'Wasilków', 'Wasilkow', 'Vasil''kiv,Vasil''kuv,Vasilkov,Vasilkova,Vasilkuvas,Wasilkow,Wasilków,wa xi er ku fu,wsylqwb,Василков,Василькув,Васильків,וסילקוב,瓦西爾庫夫', 53.1990900, 23.2077600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109758, 'Warsaw', 'Warsaw', 'Barsobia,Varsa,Varsava,Varsavia,Varsavja,Varshava,Varshavae,Varsja,Varsjá,Varso,Varsova,Varsovia,Varsovia - Warszawa,Varsovie,Varsovio,Varssavi,Varsuva,Varsòvia,Varsó,Varsóvia,Varşova,Varšava,Varšuva,Varșovia,Vársá,WAW,Warsaw,Warsawa,Warschau,Warskou,Warszaw,Warszawa,Waršawa,baleusyaba,hua sha,varshava,vorso,warsw,warushawa,wrsh,wrshw,wrsw,wxrsx,Βαρσοβία,Варшавæ,Варшава,Վարշավա,ווארשע,ורשה,װאַרשע,وارسو,ورشو,ۋارشاۋا,ܘܪܣܘ,वॉर्सो,วอร์ซอ,ვარშავა,ዋርሶው,ワルシャワ,华沙,華沙,바르샤바', 52.2297700, 21.0117800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109759, 'Warka', 'Warka', 'Varka,Warka,wa er ka,Варка,ווארקע,וורקא,瓦爾卡', 51.7843000, 21.1909100, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109760, 'Jodłówka-Wałki', 'Jodlowka-Walki', '', 50.0499200, 21.1333200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109761, 'Waksmund', 'Waksmund', '', 49.4820700, 20.0756300, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109762, 'Wadowice Górne', 'Wadowice Gorne', '', 50.2631200, 21.3021500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109763, 'Wąchock', 'Wachock', 'Vonhocka,Vonkhoc''k,Vonkhock,Wachock,Wąchock,weng huo ci ke,wwnhwzq,Вонхоцк,Вонхоцьк,וונחוצק,翁霍茨克', 51.0739100, 21.0124300, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109764, 'Ustrzyki Dolne', 'Ustrzyki Dolne', 'Myasto Ustshiki Dol''ne,Nizhne-Ustriki,Nizhniye Ustriki,Ustriki-Dol''nyye,Ustriki-Dolishni,Ustshiki Dolne,Ustshiki-Dol''ne,Ustsiki Dolne,Ustšiki Dolne,xia wu si qi ji,Устрики-Долішні,Устшики Долне,Устшики-Дольне,אוסציקי דולנה,下烏斯奇基', 49.4304000, 22.5938100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109765, 'Uścimów Stary', 'Uscimow Stary', '', 51.4696200, 22.9551600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109766, 'Uście Gorlickie', 'Uscie Gorlickie', '', 49.5219200, 21.1382100, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109767, 'Urzejowice', 'Urzejowice', '', 50.0118200, 22.4618900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109768, 'Urzędów', 'Urzedow', '', 50.9932300, 22.1426000, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109769, 'Urszulin', 'Urszulin', 'Urszula,Urszulin', 51.3939000, 23.1948000, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109770, 'Ursus', 'Ursus', 'Ursus,Warszawa-Ursus,Урсус', 52.1951700, 20.8841900, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109771, 'Ulhówek', 'Ulhowek', '', 50.4496900, 23.7995600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109772, 'Ułęż', 'Ulez', '', 51.5919500, 22.1074100, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109773, 'Ulanów', 'Ulanow', 'Ulanow,Ulanów', 50.4903100, 22.2636200, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109774, 'Uherce Mineralne', 'Uherce Mineralne', 'Ugerci Mineral''ni,Угерці Мінеральні', 49.4645500, 22.3982900, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109775, 'Tyszowce', 'Tyszowce', 'Tishovce,Tishovice,Tisovce,Tišovce,Typzowce,Tyshovce,Tyszowce,di shao fu cai,tyswbzh,tyswk,Тишовице,Тишовце,Тышовце,טישובצה,تیسوک,蒂紹夫采', 50.6169900, 23.6992700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109776, 'Tyrawa Wołoska', 'Tyrawa Woloska', 'Tyrawa Woloska,Tyrawa Wołoska', 49.5774400, 22.3698800, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109777, 'Tymbark', 'Tymbark', 'Tymbark,tymbark,Тымбарк,تیمبارک', 49.7285900, 20.3253900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109778, 'Tylicz', 'Tylicz', 'Tylich,Tylicz,Тылич', 49.3959800, 21.0236800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109779, 'Tykocin', 'Tykocin', 'Gorad Tykocin,Tikocin,Tikocina,Tikocinas,Tykocin,di ke qin,tykwchyn,tyqtyn,Горад Тыкоцін,Тикоцин,Тикоћин,Тыкоцин,טיקטין,تیکوچین,蒂科欽', 53.2056700, 22.7745700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109780, 'Tyczyn', 'Tyczyn', 'Tichin,Ticina,Tičina,Tychin,di qin,tyzyn,Тичин,Тичињ,Тычин,טיצין,蒂琴', 49.9638400, 22.0339800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109781, 'Turze Pole', 'Turze Pole', '', 49.6632900, 22.0047600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109782, 'Turośń Kościelna', 'Turosn Koscielna', '', 53.0146300, 23.0553200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109783, 'Turobin', 'Turobin', 'twrbyn  astan lwbyn,توربین، استان لوبین,توروبن، صوبہ لوبن', 50.8236700, 22.7427300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109784, 'Tuczna', 'Tuczna', '', 51.8802900, 23.4252000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109785, 'Tuczępy', 'Tuczepy', '', 50.5167600, 20.9918700, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109786, 'Tuchów', 'Tuchow', 'Tuchow,Tuchów,Tuhova,Tukhov,Tukhuv,tu hu fu,twhwb,twkhw,Тухов,Тухув,טוחוב,توخو,圖胡夫', 49.8948500, 21.0540700, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109787, 'Trzydnik Duży', 'Trzydnik Duzy', '', 50.8488700, 22.1335900, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109788, 'Trzemeśnia', 'Trzemesnia', 'Trzemesnia,Trzemeśnia,Trzemiesnia,Trzemieśnia', 49.8275200, 20.0220700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109789, 'Trzebownisko', 'Trzebownisko', '', 50.0782900, 22.0371200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109790, 'Trzebieszów', 'Trzebieszow', '', 51.9900600, 22.5550200, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109791, 'Trzcinica', 'Trzcinica', 'ashchynytza  wyywdshyp pwdkarpakyh,اشچینیتزا، وئیودشیپ پودکارپاکیه,اشچینیکا، صوبہ پودکارپاکی', 49.7430100, 21.4175000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109792, 'Trzciana', 'Trzciana', '', 50.3077100, 21.3372500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109793, 'Trzciana', 'Trzciana', '', 50.0719000, 21.8385000, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109794, 'Trzciana', 'Trzciana', '', 49.8448500, 20.3741500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109795, 'Tryńcza', 'Tryncza', '', 50.1608700, 22.5500800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109796, 'Truskaw', 'Truskaw', 'Truskav,Truskaw,Трускав', 52.3012400, 20.7824400, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109797, 'Troszyn', 'Troszyn', '', 53.0311500, 21.7308300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109798, 'Trojanów', 'Trojanow', '', 51.6922500, 21.8111200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109799, 'Trawniki', 'Trawniki', 'Trawniki', 51.1363300, 22.9981600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109800, 'Trablice', 'Trablice', '', 51.3524900, 21.1287700, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109801, 'Trąbki', 'Trabki', '', 51.9479200, 21.5992900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109802, 'Trąbki', 'Trabki', 'Trabki,Trapki,Trąbki', 49.9622600, 20.1424000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109803, 'Tomaszów Mazowiecki', 'Tomaszow Mazowiecki', 'Mazovijos Tomasuvas,Mazovijos Tomašuvas,Thomasovia,Tomashov Mazovecki,Tomashov Mazovjecki,Tomashuv-Mazovec''kij,Tomashuv-Mazovecki,Tomashuv-Mazoveckij,Tomasova Mazovecka,Tomaszow,Tomaszow Mazowiecki,Tomaszów,Tomaszów Mazowiecki,Tomašova Mazovecka,ma zuo fu she de qu tuo ma shu fu,twmswb mzwbyyzqy,tx ma chuf ma sx weiyt ski,Томашов Мазовецки,Томашов Мазовјецки,Томашув-Мазовецки,Томашув-Мазовецкий,Томашув-Мазовецький,טומשוב מזובייצקי,ตอมาชูฟมาซอเวียตสกี,馬佐夫舍地區托馬舒夫', 51.5313100, 20.0085500, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109804, 'Tomaszów Lubelski', 'Tomaszow Lubelski', 'Liublino Tomasuvas,Liublino Tomašuvas,Tomashev,Tomashiv,Tomashov Ljubelski,Tomashov Lubelski,Tomashuv,Tomashuv-Ljubel''ski,Tomashuv-Ljubel''skij,Tomasova Lubelska,Tomaszow,Tomaszów,Tomašova Lubelska,Tomoshuv Lyubel''ski,lu bu lin de qu tuo ma shu fu,twmswb lwblsqy,Томашов Лубелски,Томашов Любелски,Томашув-Любельски,Томашув-Любельский,Томашів,טאמאשאוו,טומשוב לובלסקי,トマシュフ・ルベルスキ,盧布林地區托馬舒夫', 50.4476700, 23.4161600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109805, 'Tłuszcz', 'Tluszcz', 'Tlushh,Tluszcz,Tłuszcz,Тлущ', 52.4305800, 21.4356100, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109806, 'Tereszpol', 'Tereszpol', 'Tereszpol Zaorenda', 50.5837300, 22.8798000, 'PL', '2013-12-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109807, 'Terespol', 'Terespol', 'Gorad Cjarehspal'',Terespil'',Terespol'',Terespole,Terespolis,tai lei si bo er,teresuporu,Горад Цярэспаль,Тересполь,Тереспіль,テレスポル,泰雷斯波爾', 52.0755000, 23.6161400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109808, 'Teresin', 'Teresin', 'Comuna de Teresin,Gmina Teresin,Teresin,Тересин,Ґміна Тересін', 52.1988700, 20.4167200, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109809, 'Telatyn', 'Telatyn', '', 50.5271200, 23.8395600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109810, 'Tczów', 'Tczow', 'Tczow,Tczow Sredni,Tczów,Tczów Średni', 51.3260000, 21.4467700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109811, 'Tarnowiec', 'Tarnowiec', '', 49.9816400, 20.9865500, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109812, 'Tarnowiec', 'Tarnowiec', '', 49.7310800, 21.5766300, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109813, 'Tarnów', 'Tarnow', 'Gorad Tarnuu,Tarnov,Tarnova,Tarnow,Tarnuv,Tarnuvas,Tarnuw,Tarnów,Tarnůw,ta er nu fu,taleunupeu,tarnwf,tarunufu,trnwb,Горад Тарнуў,Тарнов,Тарнув,טארנע,טרנוב,تارنوف,タルヌフ,塔爾努夫,타르누프', 50.0138100, 20.9869800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109814, 'Tarnogród', 'Tarnogrod', 'Tarnogrod,Tarnogroda,Tarnogrud,Tarnogrudas,Tarnogród,Ternogorod,ta er nuo ge lu de,trnwgrwd,Тарногрод,Тарногруд,Терногород,טרנוגרוד,塔爾諾格魯德', 50.3609000, 22.7417400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109815, 'Tarnobrzeg', 'Tarnobrzeg', 'Gorad Tarnobzhag,Nova Tarnovia,QEP,Tarnobjeg,Tarnobrzeg,Tarnobrzyg,Tarnobzega,Tarnobzegas,Tarnobzheg,Tarnobzhege,Tarnobžega,Tarnobžegas,ta er nuo bu re ge,taleunobeujekeu,tarnwbzk,tarunobujeku,trnwbzg,Горад Тарнобжаг,Тарнобжег,Тарнобжеге,דזשיקאוו,טרנובזג,تارنوبزک,タルノブジェク,塔尔诺布热格,타르노브제크', 50.5730400, 21.6793700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109816, 'Tarnawatka', 'Tarnawatka', '', 50.5315400, 23.3959000, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109817, 'Tarłów', 'Tarlow', 'trlwb,טרלוב', 51.0016000, 21.7147400, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109818, 'Targowisko', 'Targowisko', '', 49.9847300, 20.2934600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109819, 'Targówek', 'Targowek', 'Targuvek,Таргувек', 52.2918500, 21.0484500, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109820, 'Tarczyn', 'Tarczyn', 'Tarchin,Tarcina,Tarčina,ta er qin,trzyn,Тарчин,טרצין,塔爾琴', 51.9819700, 20.8339400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109821, 'Szynwałd', 'Szynwald', '', 49.9676700, 21.1229300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109822, 'Szydłowo', 'Szydlowo', '', 53.0806200, 20.4507100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109823, 'Szydłowiec', 'Szydlowiec', 'Gorad Shydlovec,Shidlovec,Shidlovec'',Shidlovjec,Sidloveca,Sydlovecas,Sydloviec,sydlwbyyz,xi de wo wei ci,Šidloveca,Šydlovecas,Šydloviéc,Горад Шыдловец,Шидловец,Шидловець,Шидловјец,שידלובייץ,希德沃維茨', 51.2282300, 20.8610600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109824, 'Szydłów', 'Szydlow', 'Comuna de Szydlow,Comuna de Szydłów,Gmina Shidluv,Gmina Szydlow,Gmina Szydłów,Shidluv,Szydlow,Szydłów,Шидлув,Ґміна Шидлув', 50.5911400, 21.0068000, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109825, 'Szumowo', 'Szumowo', '', 52.9188400, 22.0844900, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109826, 'Szreńsk', 'Szrensk', 'Shren''sk,Szrensk,Szreńsk,Шреньск', 53.0127700, 20.1200900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109827, 'Szerzyny', 'Szerzyny', '', 49.8091900, 21.2467000, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109828, 'Szepietowo', 'Szepietowo', 'Sepetovas,Sepetovo,Shepetovo,Shepetovo-Stac''ja,Shepjetovo,Szepetowo,Szepietowo,Szepietowo-Stacja,Šepetovas,Šepetovo,Шепетово,Шепетово-Стацья,Шепјетово', 52.8703200, 22.5439200, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109829, 'Szelków', 'Szelkow', 'Stary Szelkow (do 1999),Stary Szelków (do 1999),Szelkow,Szelkow Stary,Szelków,Szelków Stary', 52.8348700, 21.2176900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109830, 'Szczytno', 'Szczytno', 'Ortel''sberg,Ortelsburg,Ortel’sberg,SZY,Scitno,Scytnas,Shchitno,Shhitno,Szczytno,Szczyton,shen qi te nuo,Ščitno,Ščytnas,Шчитно,Щитно,什奇特諾', 53.5625900, 20.9874700, 'PL', '2013-05-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109831, 'Szczurowa', 'Szczurowa', '', 50.1191500, 20.6361000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109832, 'Szczuczyn', 'Szczuczyn', 'Scucina,Scucinas,Shchuchin,Shhuchin,Szczuczyn,Szczuczyn Bialostocki,Szczuczyn Białostocki,shen qiu qin,szwzyn,Ščučina,Ščučinas,Шчучин,Щучин,שצוצין,什丘琴', 53.5633000, 22.2853400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109833, 'Szczucin', 'Szczucin', 'Scucina,Shchuchin,Shchucin,Shhucin,shen qiu qin,szwzyn,Ščucina,Шчучин,Шчућин,Щуцин,שצוצין,什丘欽', 50.3095700, 21.0744400, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109834, 'Szczebrzeszyn', 'Szczebrzeszyn', 'Scebzesina,Shchebzheshin,Shhebreshin,Shhebzheshin,Szczebrzeszyn,shen qie bu re shen,szbzsyn,Ščebžešina,Шчебжешин,Щебжешин,Щебрешин,שצבזשין,什切布熱申', 50.6949900, 22.9795400, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109835, 'Szczawnica', 'Szczawnica', 'Scavnica,Shchavnica,Shhavnica,Shhavnicja,Szczawnica,Szczawnica Wyzna,Szczawnica Wyżna,Szczawnica Zdroj,Szczawnica Zdrój,shen qia fu ni cha,Ščavņica,Шчавница,Шчавњица,Щавница,Щавниця,什恰夫尼察', 49.4243700, 20.4848700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109836, 'Szastarka', 'Szastarka', '', 50.8549400, 22.3346000, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109837, 'Szarów', 'Szarow', '', 49.9950500, 20.2696000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109838, 'Szaflary', 'Szaflary', 'Szaflary', 49.4265500, 20.0271300, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109839, 'Sypniewo', 'Sypniewo', '', 53.0058000, 21.3073000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109840, 'Świlcza', 'Swilcza', '', 50.0717900, 21.8979800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109841, 'Swiętajno', 'Swietajno', '', 54.0015100, 22.3183000, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109842, 'Świętajno', 'Swietajno', 'Schwentainen,Swietajno,Świętajno', 54.0389200, 22.3329700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109843, 'Świętajno', 'Swietajno', 'Altkirchen,Schwentainen,Sventajno,Swietajno,Świętajno,Свентайно', 53.5669200, 21.2154600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109844, 'Świdnik', 'Swidnik', 'Swidnik,Swidnik Duzy,Świdnik,Świdnik Duży', 51.2189800, 22.6962100, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109845, 'Suwałki', 'Suwalki', 'Gorad Suvalki,Suvalkai,Suvalki,Suwalki,Suwalkie,Suwałki,su wa wu ji,subauki,suvu~auki,Горад Сувалкі,Сувалки,סובאלק,スヴァウキ,苏瓦乌基,수바우키', 54.1117500, 22.9308700, 'PL', '2010-10-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109846, 'Susiec', 'Susiec', 'Skwarki,Susiec', 50.4197300, 23.1962600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109847, 'Suraż', 'Suraz', 'Gorad Surazh,Suraz,Suraza,Surazas,Surazh,Suraż,Suraža,Suražas,su la ri,Горад Сураж,Сураж,蘇拉日', 52.9490800, 22.9565300, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109848, 'Supraśl', 'Suprasl', 'Comuna de Suprasl,Comuna de Supraśl,Gmina Suprasl,Gmina Suprasl'',Gmina Supraśl,Suprasl,Suprasl'',Supraslio valscius,Supraslio valsčius,Supraśl,Супрасль,Ґміна Супрасль', 53.2052600, 23.3393400, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109849, 'Sułów', 'Sulow', '', 50.9066100, 22.3606100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109850, 'Sułów', 'Sulow', '', 50.7709900, 22.9559300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109851, 'Sułkowice', 'Sulkowice', '', 51.9231000, 21.0892900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109852, 'Sulejówek', 'Sulejowek', 'Sulejovek,Sulejuvek,Sulejuveka,Сулейовек,Сулеювек,Сулејовек,სულეიუვეკი', 52.2522100, 21.2690200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109853, 'Suchożebry', 'Suchozebry', 'Suchozebry,Suchożebry,Sukhozhebry,Сухожебры', 52.2594800, 22.2528900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109854, 'Suchowola', 'Suchowola', 'Gorad Sukhavolja,Suchovola,Suhovola,Sukhovola,Sukhovolja,su huo wo la,swhwbwlh,Горад Сухаволя,Суховола,Суховоля,סוחובולה,蘇霍沃拉', 53.5775300, 23.1059600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109855, 'Suchedniów', 'Suchedniow', 'Suchedniow,Suchedniów,Suhednova,Suhedņova,Sukhednjuv,Sukhednov,su hai de niu fu,swhdnywb,Сухеднюв,Сухедњов,סוחדניוב,蘇海德紐夫', 51.0477600, 20.8292200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109856, 'Sucha', 'Sucha', 'Sucha,Sucha Szlachecka', 51.6199900, 20.9488700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109857, 'Stupsk', 'Stupsk', 'Stupsk,Ступск', 53.0225800, 20.4368000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109858, 'Stubno', 'Stubno', '', 49.8980600, 22.9560200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109859, 'Strzyżowice', 'Strzyzowice', '', 51.0483000, 22.4401800, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109860, 'Strzyżów', 'Strzyzow', 'Strizhiv,Strzizuw,Strziżůw,Strzyzow,Strzyżów,Stshizhov,Stshizhuv,Stsizova,Stzyzow,Stzyżów,Stšižova,si qi ru fu,stzyzwb,Стрижів,Стшижов,Стшижув,סטזיזוב,斯奇茹夫', 49.8707400, 21.7941300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109861, 'Strzegowo', 'Strzegowo', 'Strzegowo,Strzegowo-Osada,Stshegovo-Osada,Стшегово-Осада', 52.8939400, 20.2854800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109862, 'Stromiec', 'Stromiec', '', 51.6470000, 21.0922900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109863, 'Strawczyn', 'Strawczyn', '', 50.9417700, 20.4213500, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109864, 'Straszydle', 'Straszydle', '', 49.9003800, 21.9812400, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109865, 'Strachówka', 'Strachowka', 'Strachowka,Strachówka,Strakhuvka,Страхувка', 52.4269200, 21.6350000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109866, 'Strachocina', 'Strachocina', 'Strachocina', 49.6081500, 22.0883600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109867, 'Stopnica', 'Stopnica', 'Stopnica,stwpnyzh,סטופניצה', 50.4401800, 20.9378000, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109868, 'Stoczek Łukowski', 'Stoczek Lukowski', 'Stoceka Lukovska,Stochek Lukovski,Stochek-Lukovs''kij,Stochek-Lukovskij,Stoczek,Stoczek Lukovski,Stoczek Lukowski,Stoczek Łukowski,Stočeka Lukovska,stwzq lwqwbsqy,wu ku fu de qu si tuo qie ke,Сточек Луковски,Сточек-Луковский,Сточек-Луковський,סטוצק לוקובסקי,武庫夫地區斯托切克', 51.9613500, 21.9713700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109869, 'Stoczek', 'Stoczek', 'Stochek,Stoczek,Сточек', 52.5433200, 21.9001300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109870, 'Stężyca', 'Stezyca', '', 51.5818700, 21.7708700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109871, 'Sterdyń', 'Sterdyn', 'Sterdyn,Sterdyn'',Sterdyń,Стердынь', 52.5802600, 22.2935800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109872, 'Stawiski', 'Stawiski', 'Stavis''ki,Staviskai,Staviski,Stawiski,si ta wei si ji,stwwysqy,Стависки,Ставіські,סטוויסקי,斯塔維斯基', 53.3798700, 22.1546200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109873, 'Stawiguda', 'Stawiguda', 'Stabigotten,Staviguta,Stawiguda,Ставигута', 53.6572000, 20.4004100, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109874, 'Staszów', 'Staszow', 'Stashev,Stashov,Stashuv,Stasova,Stašova,si ta shu fu,stswb,Сташов,Сташув,סטשוב,斯塔舒夫', 50.5630700, 21.1659300, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109875, 'Stary Zamość', 'Stary Zamosc', '', 50.8200400, 23.1715400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109876, 'Stary Wiśnicz', 'Stary Wisnicz', 'Stary Wisnicz,Stary Wiśnicz,Wisnicz Stary,Wiśnicz Stary', 49.9254800, 20.4864100, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109877, 'Stary Sącz', 'Stary Sacz', 'Gorad Stary Sonch,Oszandec,Stari Sonca,Stari Sonch,Stari Sonča,Starij Sonch,Stary Sacz,Stary Sącz,Staryj Sonch,jiu song qi,Ószandec,Горад Стары Сонч,Стари Сонч,Старий Сонч,Старый Сонч,舊松奇', 49.5636400, 20.6349600, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109878, 'Stare Miasto', 'Stare Miasto', '', 50.2887900, 22.4292800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109879, 'Stare Juchy', 'Stare Juchy', 'Alt Fliessdorf,Alt Jucha,Fliessdorf,Jucha,Stare Juchy,Stare-Jukhy,Старе-Юхы', 53.9219800, 22.1736700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109880, 'Stare Babice', 'Stare Babice', 'Babice Stare,Stare Babice', 52.2602800, 20.8340300, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109881, 'Stara Wieś', 'Stara Wies', '', 49.7150500, 22.0044100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109882, 'Starachowice', 'Starachowice', 'Starachovices,Starachovicės,Starachovitse,Starachowice,Starachowice-Wierzbnik,Starahovice,Starakhovice,si ta la huo wei cai,strhwbyzh,Σταραχοβίτσε,Стараховице,Стараховіце,סטרחוביצה,斯塔拉霍維采', 51.0374000, 21.0712600, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109883, 'Stąporków', 'Staporkow', 'Comuna de Staporkow,Comuna de Stąporków,Gmina Staporkow,Gmina Stomporkuv,Gmina Stąporków,Staporkow,Stomporkuv,Stąporków,Стомпоркув,Ґміна Стомпоркув', 51.1376200, 20.5717300, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109884, 'Stanisławów Pierwszy', 'Stanislawow Pierwszy', '', 52.3748500, 21.0518400, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109885, 'Stanisławów', 'Stanislawow', 'Stanislavuv,Stanislawow,Stanisławów,Станиславув', 52.2893700, 21.5484800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109886, 'Stanisławice', 'Stanislawice', '', 49.9855000, 20.3512300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109887, 'Stalowa Wola', 'Stalowa Wola', 'QXQ,Stal''ova Volja,Staliova Volia,Staljova-Volja,Stalova Vola,Stalowa Wola,Stalowo Wola,si ta luo wa wo la,Сталова Вола,Стальова Воля,Сталёва-Воля,斯塔洛瓦沃拉', 50.5828600, 22.0533400, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109888, 'Srokowo', 'Srokowo', 'Drengfurth,Dryfort,Srokovo,Srokowo,Сроково', 54.2141600, 21.5228200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109889, 'Śródmieście', 'Srodmiescie', 'Seredmistja,Sredmest''e,Srodmiescie,Warszawa-Srodmiescie,Warszawa-Śródmieście,shrudmieshtsie,Śródmieście,Середмістя,Средместье,შრუდმიეშციე', 52.2290400, 21.0164400, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109890, 'Spiczyn', 'Spiczyn', '', 51.3412800, 22.7535400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109891, 'Sosnówka', 'Sosnowka', 'Sosnowka,Sosnówka', 51.7508400, 23.3381400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109892, 'Sosnowica', 'Sosnowica', '', 51.5206500, 23.0921500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109893, 'Sośnica', 'Sosnica', '', 49.9008300, 22.8746900, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109894, 'Sońsk', 'Sonsk', 'Son''sk,Sonsk,Sońsk,Соньск', 52.7816400, 20.6990100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109895, 'Sonina', 'Sonina', '', 50.0608900, 22.2655100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109896, 'Solec-Zdrój', 'Solec-Zdroj', 'Solec,Solec-Zdroj,Solec-Zdrój', 50.3659400, 20.8895600, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109897, 'Solec Nad Wisłą', 'Solec Nad Wisla', '', 51.1363300, 21.7656300, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109898, 'Sokoły', 'Sokoly', 'Sokoly,Sokoły,Соколы', 52.9931400, 22.7005000, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109899, 'Sokołów Podlaski', 'Sokolow Podlaski', 'Gorad Sakolau Padljaski,Palenkes Sokoluvas,Palenkės Sokoluvas,Sokolov Podlaski,Sokolov Podljaski,Sokolova Podlaska,Sokolow,Sokolow Podlaski,Sokoluv-Pidljas''kij,Sokoluv-Podljaski,Sokoluv-Podljaskij,Sokołów,Sokołów Podlaski,bo de la xie de qu suo ke wu fu,swqwlwb pwdlsqy,Горад Саколаў Падляскі,Соколов Подласки,Соколов Подляски,Соколув-Подляски,Соколув-Подляский,Соколув-Підляський,סוקולוב פודלסקי,波德拉謝地區索科武夫', 52.4067700, 22.2530700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109900, 'Sokołów Małopolski', 'Sokolow Malopolski', 'Sokoliv-Malopol''s''kij,Sokolov Malopolski,Sokolova Malopolska,Sokolow,Sokolow Malopolski,Sokoluv Malopolski,Sokoluv-Malopol''ski,Sokołów,Sokołów Małopolski,swqwlwb mʼlwpwlsqy,xiao bo lan de qu suo ke wu fu,Соколов Малополски,Соколув Малополски,Соколув-Малопольски,Соколів-Малопольський,סוקולוב מאלופולסקי,小波蘭地區索科武夫', 50.2290900, 22.1196800, 'PL', '2016-01-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109901, 'Sokolniki', 'Sokolniki', '', 50.6380300, 21.8064900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109902, 'Sokółka', 'Sokolka', 'Gorad Sakulka,Sokola,Sokolka,Sokulka,Sokółka,suo ku wu ka,swqwlqh,Горад Сакулка,Соколка,Сокулка,סוקולקה,索庫烏卡', 53.4071500, 23.5022800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109903, 'Sochocin', 'Sochocin', 'Sochocin,Sokhocin,Сохоцин', 52.6871500, 20.4725900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109904, 'Sochaczew', 'Sochaczew', 'Sochacevas,Sochačevas,Sohaceva,Sohačeva,Sokhachev,sohachefu,sohachepeu,suo ha qi fu,swkzb,Сохачев,סוכצב,ソハチェフ,索哈契夫,소하체프', 52.2294400, 20.2383800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109905, 'Sobolew', 'Sobolew', '', 51.7366000, 21.6634900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109906, 'Sobków', 'Sobkow', 'Sobkow,Sobków,swbqwb,סובקוב', 50.6999900, 20.4506200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109907, 'Sobienie Jeziory', 'Sobienie Jeziory', '', 51.9327300, 21.3033500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109908, 'Śniadowo', 'Sniadowo', 'Sniadowo,Snjadovo,Śniadowo,Снядово', 53.0387400, 21.9907700, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109909, 'Smyków', 'Smykow', '', 51.0444200, 20.4003200, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109910, 'Smęgorzów', 'Smegorzow', '', 50.2284300, 21.0041400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109911, 'Słupno', 'Slupno', '', 52.3840900, 21.1557200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109912, 'Słupiec', 'Slupiec', '', 50.3278700, 21.1937400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109913, 'Słupia', 'Slupia', '', 51.0137000, 20.1406000, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109914, 'Słotowa', 'Slotowa', '', 49.9460300, 21.2942500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109915, 'Słopnice', 'Slopnice', '', 49.6849600, 20.3432500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109916, 'Słomniki', 'Slomniki', 'Slomniki,Slomņiki,Słomniki,Сломники,Сломњики', 50.2401200, 20.0822400, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109917, 'Sławno', 'Slawno', 'Comuna de Slawno,Comuna de Sławno,Gmina Slavno,Gmina Slawno,Gmina Sławno,Slavno,Гміна Славно,Славно', 51.3927300, 20.1404300, 'PL', '2013-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109918, 'Sławatycze', 'Slawatycze', 'Slavatice,Slavatiche,Slavatičė,Slavatyche,Slavatychy,Slawatycze,Slovatichi Nadbuzhanskie,Stavapycze,Sławatycze,slwwtyz''h,Славатыче,Славатычы,Словатичи Надбужанские,סלווטיצ''ה', 51.7633800, 23.5546000, 'PL', '2016-01-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109919, 'Skrzyszów', 'Skrzyszow', '', 49.9937300, 21.0613900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109920, 'Skrzydlna', 'Skrzydlna', '', 49.7534300, 20.1861800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109921, 'Skórzec', 'Skorzec', '', 52.1072700, 22.1305200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109922, 'Skołyszyn', 'Skolyszyn', '', 49.7495500, 21.3366500, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109923, 'Skierniewice', 'Skierniewice', 'Gorad Skernjavicy,Skernevice,Skernevices,Skernevicės,Skernevitsy,Skerņevice,Skieniewice,Skiernievice,Skierniewice,Skjernevice,seukieleuniebiche,si kai er nie wei cai,sqrnbyz,sukyerunyevu~itsu~e,Горад Скернявіцы,Скерневице,Скерневіце,Скјерњевице,סקרנביץ,スキェルニェヴィツェ,斯凱爾涅維采,스키에르니에비체', 51.9548500, 20.1583700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109924, 'Skierbieszów', 'Skierbieszow', 'Skierbieszow,Skierbieszów', 50.8515800, 23.3591700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109925, 'Skarżysko Kościelne', 'Skarzysko Koscielne', '', 51.1382200, 20.9119600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109926, 'Skarżysko-Kamienna', 'Skarzysko-Kamienna', 'Kamenna-Skarzhisko,Kamienna-Skarzhisko,Skarzhis''ko-Kamenna,Skarzhisko-Kamenna,Skarzhisko-Kamjena,Skarzhysko-Kamenna,Skarzisko-Kamenna,Skarzyskas-Kamena,Skarzysko,Skarzysko-Kamienna,Skarżysko-Kamienna,Skaržisko-Kamenna,Skaržyskas-Kamena,si ka ri si ke-ka mian na,sqrzysqw-qmyynh,Скаржиско-Каменна,Скаржиско-Камјена,Скаржисько-Каменна,Скаржыско-Каменна,סקרזיסקו-קמיינה,斯卡日斯科-卡緬納', 51.1131100, 20.8716200, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109927, 'Skaryszew', 'Skaryszew', 'Skariseva,Skarishev,Skariševa,Skaryshev,Skaryszew,si ka lei xie fu,sqrysb,Скаришев,Скарышев,סקרישב,斯卡雷謝夫', 51.3107500, 21.2523300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109928, 'Skalbmierz', 'Skalbmierz', 'Skal''bmezh,Skalbmeza,Skalbmeža,Skalbmierz,Skalbmjezh,si ka er bu mei ri,sqlbmyyz,Скалбмјеж,Скальбмеж,סקלבמייז,斯卡爾布梅日', 50.3199300, 20.3992900, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109929, 'Sitno', 'Sitno', '', 50.7494400, 23.3626000, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109930, 'Osiedle-Nowiny', 'Osiedle-Nowiny', 'Sitkowka,Sitkowka-Nowiny (do 1999),Sitkówka,Sitkówka-Nowiny (do 1999)', 50.8177000, 20.5411700, 'PL', '2012-11-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109931, 'Sietesz', 'Sietesz', '', 49.9862200, 22.3467100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109932, 'Sieradza', 'Sieradza', '', 50.1349900, 20.9294700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109933, 'Sienno', 'Sienno', 'Comuna de Sienno,Gmina Senno,Gmina Sienno,Senno,Сенно,Ґміна Сенно', 51.0877300, 21.4832500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109934, 'Siennica', 'Siennica', 'Comuna de Siennica,Gmina Sennicja,Gmina Siennica,Sennica,Siennica,Сенница,Ґміна Сенниця', 52.0916400, 21.6192100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109935, 'Sieniawa', 'Sieniawa', 'Senava,Senjava,Seņava,Shenjava,Sieniawa,Sjenava,xie ni ya wa,Сенява,Сјењава,Шенява,שינאווא,שיניאווה,谢尼亚瓦', 50.1779000, 22.6095400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109936, 'Sieniawa', 'Sieniawa', '', 49.5650800, 21.9278500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109937, 'Siemień', 'Siemien', '', 51.6288300, 22.7724300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109938, 'Siemiechów', 'Siemiechow', '', 49.8535900, 20.9059500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109939, 'Siemiatycze', 'Siemiatycze', 'Gorad Semjatychy,Semiatice,Semiatičė,Semjatice,Semjatiče,Semjatyche,Semyatichi,Shemjatiche,Siemiatycze,Simjatichi,Sjemjatiche,smyʼtyz,xie mi ya di qie,Горад Семятычы,Семятыче,Сімятичі,Сјемјатиче,Шемятиче,סמיאטיץ,謝米亞蒂切', 52.4271900, 22.8623100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109940, 'Siemiątkowo', 'Siemiatkowo', 'Comuna de Siemiatkowo,Comuna de Siemiątkowo,Gmina Sem''ontkovo,Gmina Siemiatkowo,Gmina Siemiątkowo,Semjontkovo,Siemiatkowo Koziebrodzkie,Siemiątkowo Koziebrodzkie,Семёнтково,Ґміна Семьонтково', 52.8811000, 20.0289300, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109941, 'Siedliska', 'Siedliska', '', 49.9540900, 21.9474200, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109942, 'Siedliska', 'Siedliska', '', 49.8716300, 20.9962500, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109943, 'Siedleczka', 'Siedleczka', '', 49.9606100, 22.3794900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109944, 'Siedlce', 'Siedlce', 'Gorad Sedl''cy,Sedl''ce,Sedl''tse,Sedlce,Sedlcos,Shedulce,Siedlce,Sjedlice,sdlyz,siedeulche,xie de er cai,Горад Седльцы,Седльце,Сједлице,Шедълце,שדליץ,שעדליץ,謝德爾采,시에들체', 52.1677200, 22.2900600, 'PL', '2013-11-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109945, 'Serokomla', 'Serokomla', '', 51.7007000, 22.3323700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109946, 'Serock', 'Serock', 'Seroc''k,Serock,Serocka,Serockas,sai luo ci ke,srwzq,Сероцк,Сероцьк,סרוצק,塞羅茨克', 52.5103600, 21.0691000, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109947, 'Serniki', 'Serniki', 'Serniki,Syrniki', 51.4371600, 22.6585300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109948, 'Sępopol', 'Sepopol', 'Gorad Sempopal'',Schippenbeil,Sempopol'',Sempopole,Senpopol,Sepopol,Szepopel,Szępopel,Sępopol,sen bo bo er,Горад Семпопаль,Семпополь,Сенпопол,森波波爾', 54.2690300, 21.0145300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109949, 'Sękowa', 'Sekowa', '', 49.6221700, 21.1976900, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109950, 'Sejny', 'Sejny', 'Seinai,Sejny,Сейны', 54.1080200, 23.3469800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109951, 'Sędziszów Małopolski', 'Sedziszow Malopolski', 'Sedziszow Malopolski,Sendzhishov Malopolski,Sendzishuv-Malopol''s''kij,Sendzishuv-Malopol''ski,Sendzisova Malopolska,Seziszow,Seņdzišova Malopolska,Sędziszów Małopolski,Sęziszów,xiao bo lan de qu sen ji shu fu,Сенджишов Малополски,Сендзишув-Малопольски,Сендзішув-Малопольський,Сенђишов Малополски,小波蘭地區森濟舒夫', 50.0706900, 21.7006200, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109952, 'Sędziszów', 'Sedziszow', 'Sedziszow,Sendzishuv,Sendzisova,Seņdzišova,Sędziszów,sen ji shu fu,sndzyswb,Сендзишув,Сендзішув,Сенђишов,סנדזישוב,森濟舒夫', 50.5659000, 20.0556300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109953, 'Sawin', 'Sawin', 'Comuna de Sawin,Gmina Savin,Gmina Sawin,Savin,Савин,Ґміна Савін', 51.2744300, 23.4337500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109954, 'Sarnaki', 'Sarnaki', 'Comuna de Sarnaki,Gmina Sarnaki,Sarnaki,Sarnaku valscius,Sarnakų valsčius,Сарнаки,Ґміна Сарнакі', 52.3150400, 22.8904400, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109955, 'Sanok', 'Sanok', 'Sanocum,Sanok,Sanoka,Sanokas,Sjanik,Sunok,Sánók,sa nuo ke,sanokeu,sanoku,Санок,Сянік,Սանոկ,סאנוק,סאניק,სანოკი,サノク,萨诺克,사노크', 49.5557300, 22.2056000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109956, 'Sandomierz', 'Sandomierz', 'Gorad Sandomezh,Sandomer,Sandomeza,Sandomezh,Sandomeža,Sandomieras,Sandomierz,Sandomir,Sandomiria,Sandomjezh,Sandoměř,Sandumjyrz,Sandůmjyrz,sandomiesi,sandomiri,sang duo mei ri,sndwmyyz,Горад Сандомеж,Сандомеж,Сандомир,Сандомјеж,סנדומייז,სანდომირი,桑多梅日,산도미에시', 50.6826500, 21.7489800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109957, 'Samborzec', 'Samborzec', '', 50.6466300, 21.6482200, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109958, 'Sadowne', 'Sadowne', 'Comuna de Sadowne,Gmina Sadovne,Gmina Sadowne,Sadovne,Sadovnes valscius,Sadovnės valsčius,Садовне,Ґміна Садовне', 52.6412400, 21.8456300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109959, 'Sadowie', 'Sadowie', 'Comuna de Sadowie,Gmina Sadove,Gmina Sadowie,Sadove,Садове,Ґміна Садове', 50.8526100, 21.3688400, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109960, 'Sadkowice', 'Sadkowice', 'Comuna de Sadkowice,Gmina Sadkovice,Gmina Sadkowice,Sadkovice,Садковице,Ґміна Садковіце', 51.7251700, 20.5146500, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109961, 'Sabnie', 'Sabnie', 'Comuna de Sabnie,Gmina Sabne,Gmina Sabnie,Sabne,Sabniu valscius,Sabnių valsčius,Сабне,Ґміна Сабне', 52.5009700, 22.3069700, 'PL', '2013-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109962, 'Rzezawa', 'Rzezawa', 'Rzczawa,Rzezawa', 49.9899700, 20.5150800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109963, 'Rzewnie', 'Rzewnie', '', 52.8350800, 21.3368200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109964, 'Rzeszów', 'Rzeszow', 'Gorad Zhehshau,Jesuv,Jeşuv,RZE,Reichshof,Resov,Resovia,Rjashiv,Rzeszow,Rzeszuw,Rzeszów,Rzeszůw,Zesova,Zesuv,Zesuvas,Zheshev,Zheshov,Zheshuv,che chuf,jeshufu,jesyupeu,jyshwf,re shu fu,zhshwf,zswb,Řešov,Žešova,Žešuv,Žešuvas,Горад Жэшаў,Жешов,Жешув,Ряшів,זשוב,ריישע,جيشوف,ژشوف,เชชูฟ,ジェシュフ,热舒夫,제슈프', 50.0413200, 21.9990100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109965, 'Rzepiennik Strzyżewski', 'Rzepiennik Strzyzewski', 'Rzepiennik,Rzepiennik Strzyzewski,Rzepiennik Strzyżewski,Rżepiennik', 49.8054200, 21.0359900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109966, 'Rzepedź', 'Rzepedz', '', 49.3699700, 22.1117400, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109967, 'Rzekuń', 'Rzekun', 'Rzekun,Rzekuń,Zhekun'',Жекунь', 53.0475600, 21.6206900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109968, 'Rzeczyca', 'Rzeczyca', '', 51.9622500, 22.7494200, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109969, 'Rzeczyca', 'Rzeczyca', 'Comuna de Rzeczyca,Gmina Rzeczyca,Gmina Zhechicja,Zhechica,Жечица,Ґміна Жечиця', 51.5982400, 20.2948400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109970, 'Rzeczniów', 'Rzeczniow', '', 51.1280400, 21.4400800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109971, 'Rząśnik', 'Rzasnik', '', 52.7133200, 21.3677200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109972, 'Rytwiany', 'Rytwiany', '', 50.5292000, 21.2063600, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109973, 'Rytro', 'Rytro', '', 49.4890400, 20.6663100, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109974, 'Ryn', 'Ryn', 'Rhein,Rin,Rina,Ryn,Rynas,lei en,Рин,Рын,雷恩', 53.9377000, 21.5464200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109975, 'Rymanów', 'Rymanow', 'Rimaniv,Rimanov,Rimanova,Rymanuv,lei ma nu fu,rymanwf,rymnwb,Риманов,Риманів,Рыманув,רימאנאוו,רימנוב,ریمانوف,雷馬努夫', 49.5764900, 21.8681100, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109976, 'Ryki', 'Ryki', 'Riki,Ryki,lei ji,ryqy,Рики,Рыки,ריקי,雷基', 51.6257400, 21.9327400, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109977, 'Ryglice', 'Ryglice', 'Ryglice', 49.8788700, 21.1374800, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109978, 'Ryczywół', 'Ryczywol', 'Ryczymol,Ryczymół,Ryczywol,Ryczywół', 51.6911800, 21.4219700, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109979, 'Rybno', 'Rybno', 'Rybno,Рыбно', 52.2427800, 20.1030100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109980, 'Rybie', 'Rybie', '', 52.1522900, 20.9365500, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109981, 'Rybczewice', 'Rybczewice', '', 51.0287600, 22.8505300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109982, 'Rutki', 'Rutki', 'Rutki,Рутки', 53.1000000, 22.4333300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109983, 'Rusinów', 'Rusinow', '', 51.4367800, 20.5870100, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109984, 'Rudnik', 'Rudnik', '', 50.8803500, 22.9729300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109985, 'Rudnik nad Sanem', 'Rudnik nad Sanem', 'Rudnik nad Sanem,Rudnik-nad-Sanem,Rudnik-nad-Sjanom,Rudnika pie Sanas,Rudņika pie Sanas,rwdnyq,sang he pan lu de ni ke,Рудник над Санем,Рудник-над-Санем,Рудник-над-Сяном,רודניק,רודניק על נהר סן,桑河畔鲁德尼克', 50.4415200, 22.2485600, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109986, 'Rudna Wielka', 'Rudna Wielka', '', 50.0879900, 21.9475900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109987, 'Rudna Mała', 'Rudna Mala', '', 50.0988900, 21.9602100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109988, 'Rudka', 'Rudka', 'Comuna Rudka,Comuna de Rudka,Gmina Rudka,Rudka,Rudkos valscius,Rudkos valsčius,Рудка,Ґміна Рудка', 52.7243900, 22.7267600, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109989, 'Ruda Maleniecka', 'Ruda Maleniecka', '', 51.1459200, 20.2237700, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109990, 'Ruciane-Nida', 'Ruciane-Nida', 'Nida,Nidy,Nieden,Niedersee,Rucane-NJida,Ruchane-Nida,Ruciane,Ruciany,Rucjane-Nida,Rucjane-Ņida,Rudczanny,Rudczany,lu qia nei ni da,Руцяне-Нида,Ручане-Нида,Рућане-Њида,魯恰內尼達', 53.6416100, 21.5396400, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109991, 'Rozogi', 'Rozogi', 'Friedrichshof,Rozogi,Розоги', 53.4854900, 21.3622300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109992, 'Rozbórz', 'Rozborz', '', 50.0561500, 22.5468600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109993, 'Siennica Różana', 'Siennica Rozana', 'Rozana,Różana,Siennica Rozana,Siennica Różana', 51.0012300, 23.3226000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109994, 'Różan', 'Rozan', 'Rozan,Różan', 52.8875700, 21.3910500, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109995, 'Rossosz', 'Rossosz', '', 51.8583600, 23.1374000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109996, 'Ropczyce', 'Ropczyce', 'Ropchice,Ropcice,Ropczyce,Ropčice,luo pu qi cai,rwpsyz,Ропчице,ראפשיץ,רופשיץ,羅普奇采', 50.0522900, 21.6089100, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109997, 'Ropa', 'Ropa', '', 49.5914600, 21.0443100, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109998, 'Rokitno', 'Rokitno', 'Rokitino,Rokitno,Rokitno Podlaskie,Рокитно', 52.1214200, 23.2951400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(109999, 'Rokietnica', 'Rokietnica', '', 49.8998300, 22.6417100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110000, 'Rogóźno', 'Rogozno', 'Rogozna,Rogozno,Rogożna,Rogóźno', 50.4641700, 23.3904100, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110001, 'Rogóźno', 'Rogozno', '', 50.0736700, 22.3748600, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110002, 'Rogów', 'Rogow', '', 51.2041400, 20.4348300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110003, 'Reszel', 'Reszel', 'Resela,Reshel,Reshel'',Reslius,Reszel,Rešela,Rešlius,Rossel,Rössel,lei xie er,Решел,Решель,雷謝爾', 54.0504200, 21.1458500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110004, 'Repki', 'Repki', 'Repki,Репки', 52.3855500, 22.3911700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110005, 'Rembertów', 'Rembertow', 'Nowy Rembertow,Nowy Rembertów,Rembertuv,rmbrtwb,Рембертув,רמברטוב', 52.2605900, 21.1635500, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110006, 'Rejowiec Fabryczny', 'Rejowiec Fabryczny', 'Rejovec''-Fabrichnij,Rejovec-Fabrychny,Rejovecfabricni,Rejovecfabrični,Rejovjec Fabrichni,Rejowiec Fabryczny,lei yue wei ci fa bu li qi nei,Рейовець-Фабричний,Реёвец-Фабрычны,Рејовјец Фабрични,雷約維茨法布里奇內', 51.1141400, 23.2472400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110007, 'Rejowiec', 'Rejowiec', '', 51.0913400, 23.2819200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110008, 'Regnów', 'Regnow', '', 51.7485000, 20.3871100, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110009, 'Regimin', 'Regimin', 'Regimin,Регимин', 52.9416600, 20.5531900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110010, 'Rawa Mazowiecka', 'Rawa Mazowiecka', 'Rava Mazovecka,Rava Mazovjecka,Rava-Mazovec''ka,Rava-Mazoveckaja,Rawa,Rawa Mazowiecka,ma zuo fu she de qu la wa,rwwh mzwbyyzqh,Рава Мазовецка,Рава Мазовјецка,Рава-Мазовецкая,Рава-Мазовецька,רווה מזובייצקה,馬佐夫舍地區拉瓦', 51.7643700, 20.2549300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110011, 'Raszyn', 'Raszyn', 'Radzyn,Raszyn', 52.1560300, 20.9226000, 'PL', '2017-05-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110012, 'Raniżów', 'Ranizow', '', 50.2587300, 21.9713700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110013, 'Rakszawa', 'Rakszawa', '', 50.1605100, 22.2390700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110014, 'Raków', 'Rakow', 'Rakow,Raków,rqwb,רקוב', 50.6742700, 21.0451700, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110015, 'Rajgród', 'Rajgrod', 'Raigardas,Rajgrod,Rajgroda,Rajgrud,Rajgród,la yi ge lu de,Райгруд,Рајгрод,ראיגרוד,拉伊格魯德', 53.7310200, 22.7051500, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110016, 'Radzyń Podlaski', 'Radzyn Podlaski', 'Gorad Radzyn'' Padljaski,Palenkes Radzinas,Palenkės Radzinas,Radin''-Pidljas''kij,Radzin Podljaski,Radzina Podlaska,Radziņa Podlaska,Radzyn,Radzyn Podlaski,Radzyn''-Podljaskij,Radzyń,Radzyń Podlaski,bo de la xie de qu la ceng,rdzyn pwdlsqy,Горад Радзынь Падляскі,Радзин Подляски,Радзынь-Подляский,Радинь-Підляський,Рађин Подласки,רדזין פודלסקי,波德拉謝地區拉曾', 51.7833300, 22.6166700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110017, 'Radzymin', 'Radzymin', 'Radzimin,Radzimina,Radzymin,la ji ming,Радзимін,Радзымин,Рађимин,ראדזימין,拉濟明', 52.4159200, 21.1841500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110018, 'Radziłów', 'Radzilow', 'Radzilow,Radziluv,Radziluvas,Radziłów,rdzylwb,Радзилув,רדזילוב', 53.4099400, 22.4098800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110019, 'Radziejowice', 'Radziejowice', '', 52.0083400, 20.5477000, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110020, 'Radzanów', 'Radzanow', 'Radzanow,Radzanuv,Radzanów,Радзанув', 52.9423800, 20.0921900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110021, 'Radzanów', 'Radzanow', '', 51.5578600, 20.8639800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110022, 'Radymno', 'Radymno', 'Radimno,Radymno,la di mu nuo,Радимно,Радымно,ראדימנו,拉迪姆诺', 49.9472000, 22.8237500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110023, 'Radoszyce', 'Radoszyce', 'Radoszyce,ראדאשיץ,ראדושיצה', 51.0739200, 20.2583600, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110024, 'Radomyśl Wielki', 'Radomysl Wielki', 'Radomysl Wielki,Radomyśl Wielki', 50.1969300, 21.2769300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110025, 'Radomyśl', 'Radomysl', 'Radomysl,Radomysl na Sanem,Radomysl nad Sanem,Radomyśl,Radomyśl na Sanem,Radomyśl nad Sanem', 50.6810100, 21.9436500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110026, 'Radom', 'Radom', 'Gorad Radam,La-to-me,Là-tô-mê,RDO,Radom,Radoma,Radomas,Radum,Radům,Rantom,la duo mu,ladom,rad xm,radomi,radomu,radwm,Ράντομ,Горад Радам,Радом,Ռադոմ,ראדום,ראדעם,رادوم,ราดอม,რადომი,ラドム,拉多姆,라돔', 51.4025300, 21.1471400, 'PL', '2013-08-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110027, 'Radłów', 'Radlow', '', 50.0841900, 20.8496700, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110028, 'Radgoszcz', 'Radgoszcz', '', 50.2058000, 21.1131500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110029, 'Radecznica', 'Radecznica', '', 50.7515500, 22.8297600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110030, 'Raczki', 'Raczki', 'Rachki,Rackos,Raczki,Račkos,Рачки', 53.9874900, 22.7848700, 'PL', '2015-01-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110031, 'Racławice', 'Raclawice', '', 50.5137000, 22.1655200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110032, 'Raciąż', 'Raciaz', 'Rac''onzh,Rachjonzh,Racjonza,Racjonža,Raconzh,la qiong ri,rzywnz,Рацьонж,Рачёнж,Раћонж,רציונז,拉瓊日', 52.7815200, 20.1177000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110033, 'Rachanie', 'Rachanie', 'Comuna de Rachanie,Gmina Rachanie,Gmina Rakhane,Rakhane,Рахане,Ґміна Рахане', 50.5384200, 23.5468800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110034, 'Pysznica', 'Pysznica', '', 50.5699900, 22.1291300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110035, 'Puszcza Mariańska', 'Puszcza Marianska', 'Comuna de Puszcza Marianska,Comuna de Puszcza Mariańska,Gmina Pushha-Marjans''ka,Gmina Puszcza Marianska,Gmina Puszcza Mariańska,Pushha-Marjan''ska,Puszcza Marianska,Puszcza Mariańska,Puszcza Marjanska,Puszcza Marjańska,Пуща-Маряньска,Ґміна Пуща-Марянська', 51.9790100, 20.3503700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110036, 'Purda', 'Purda', 'Comuna de Purda,Gmina Purda,Gross Purden,Purda,Пурда,Ґміна Пурда', 53.7084400, 20.7068300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110037, 'Puńsk', 'Punsk', 'Pun''sk,Punsk,Punskas,Puńsk,Пуньск', 54.2511400, 23.1812400, 'PL', '2015-01-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110038, 'Pułtusk', 'Pultusk', 'Gorad Pultusk,Pultus''k,Pultusk,Pultuska,Pułtusk,pu wu tu si ke,pwltwsq,Горад Пултуск,Пултуск,Пултуськ,פולטוסק,普烏圖斯克', 52.7025000, 21.0827600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110039, 'Puławy', 'Pulawy', 'Gorad Pulavy,Novaja Aleksandrija,Novo-Aleksandrija,Nowo-Aleksandria,Pulavai,Pulavi,Pulavy,Pulawy,Putawy,Puławy,pu wa wei,puwavu~i,Горад Пулавы,Новая Александрия,Ново-Александрия,Пулави,Пулавы,פולאווי,プワヴィ,普瓦維', 51.4165500, 21.9693900, 'PL', '2017-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110040, 'Puchaczów', 'Puchaczow', 'Puchaczow,Puchaczów,Puhaczow,Puhaczów', 51.3105000, 22.9737000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110041, 'Przytyk', 'Przytyk', 'Przytyk,psytyq,פשיטיק', 51.4656700, 20.9058700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110042, 'Przytoczno', 'Przytoczno', '', 51.6195100, 22.2713500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110043, 'Przysucha', 'Przysucha', 'Pshisukha,Psisuha,Pšisuha,psyshh,pu ri su ha,Пшисуха,פשיסחה,普日蘇哈', 51.3585800, 20.6288900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110044, 'Przyłęk', 'Przylek', '', 51.3085600, 21.7474400, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110045, 'Przybyszówka', 'Przybyszowka', '', 50.0478800, 21.9257900, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110046, 'Przyborów', 'Przyborow', '', 50.0303500, 20.6627900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110047, 'Przeworsk', 'Przeworsk', 'Perevors''k,Prevorsk,Przeworsk,Psevorska,Pshevorsk,Převorsk,Pševorska,pu re wo si ke,Переворськ,Пшеворск,普熱沃斯克', 50.0591200, 22.4940800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110048, 'Przesmyki', 'Przesmyki', '', 52.2681600, 22.5839400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110049, 'Przemyśl', 'Przemysl', 'Peremishl'',Peremishl’,Peremyshl'',Peremyshl’,Peremyslis,Peremyšlis,Premislia,Premysl,Przemysl,Przemyśl,Psemisla,Pshemishul,Pshemisl,Pshemys''l'',Pshemysl'',Pshemys’l’,Přemyšl,Pšemisla,peusyemisil,psmysl,pu re mei xi er,pushemu~ishiru,Перемишль,Перемышль,Пшемисл,Пшемишъл,Пшемысль,פשמישל,פשעמישל,プシェムィシル,普热梅希尔,프셰미실', 49.7849800, 22.7672800, 'PL', '2015-04-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110050, 'Przędzel', 'Przedzel', '', 50.4946500, 22.2192500, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110051, 'Przedmieście Dubieckie', 'Przedmiescie Dubieckie', '', 49.8371000, 22.3717700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110052, 'Przecław', 'Przeclaw', 'Pseclava,Psheclav,Pšeclava,pu re ci wa fu,Пшецлав,普熱茨瓦夫', 50.1933900, 21.4800700, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110053, 'Przasnysz', 'Przasnysz', 'Przasnysz,Psasnisa,Psasnysas,Pshasnish,Pshasnysh,Pšasniša,Pšasnyšas,brzasnysz,pu zha si nei shen,Пшасниш,Пшасныш,برزاسنيسز,普扎斯内什', 53.0190700, 20.8802900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110054, 'Pruszków', 'Pruszkow', 'Prushkov,Prushkuv,Pruskova,Pruskuvas,Pruszkow,Pruszków,Pruškova,Pruškuvas,pu lu si ke fu,purushukufu,Прушков,Прушкув,プルシュクフ,普魯斯科夫', 52.1707200, 20.8121400, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110055, 'Pruchnik', 'Pruchnik', 'Pruchnik,Pruchnik-Miasto', 49.9062000, 22.5155400, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110056, 'Proszowice', 'Proszowice', 'Proshovice,Prosovice,Prošovice,pu luo shao wei cai,Прошовице,Прошовіце,普羅紹維采', 50.1927500, 20.2890900, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110057, 'Prostki', 'Prostki', 'Prostken,Prostki,Простки', 53.6990100, 22.4318300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110058, 'Promna', 'Promna', '', 51.6800600, 20.9591700, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110059, 'Prażmów', 'Prazmow', '', 51.9404000, 20.9547900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110060, 'Pozezdrze', 'Pozezdrze', 'Grossgarten,Possessern,Pozedrze,Pozezdrze,Pozezdzhe,Позездже', 54.1414700, 21.8597000, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110061, 'Potworów', 'Potworow', 'Comuna de Potworow,Comuna de Potworów,Gmina Potvoruv,Gmina Potworow,Gmina Potworów,Potvoruv,Потворув,Ґміна Потворув', 51.5087400, 20.7217600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110062, 'Potok Wielki', 'Potok Wielki', 'Comuna de Potok Wielki,Gmina Potok Wielki,Gmina Potok-Vel''ki,Potok,Potok Wielki,Potok-Vel''ki,Поток-Вельки,Ґміна Поток-Велькі', 50.7915000, 22.2164200, 'PL', '2013-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110063, 'Potok Górny', 'Potok Gorny', '', 50.3847700, 22.5618800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110064, 'Poświętne', 'Poswietne', '', 52.3296700, 21.4213700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110065, 'Poświętne', 'Poswietne', '', 51.5320300, 20.3645300, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110066, 'Poronin', 'Poronin', '', 49.3378100, 20.0029100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110067, 'Poręba Spytkowska', 'Poreba Spytkowska', 'Poreba,Poreba Spytkowska,Poręba,Poręba Spytkowska', 49.9399500, 20.5540500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110068, 'Poręba', 'Poreba', '', 49.7964500, 20.0171800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110069, 'Poraż', 'Poraz', '', 49.4859700, 22.2250000, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110070, 'Porąbka Uszewska', 'Porabka Uszewska', 'Porabka,Porabka Uszewska,Porąbka,Porąbka Uszewska', 49.9426000, 20.6905200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110071, 'Poniatowa', 'Poniatowa', 'Ponatova,Poniatowa,Poniatowo,Ponjatova,Poņatova,bo ni ya tuo wa,Понятова,Поњатова,波尼亞托瓦', 51.1798300, 22.1309300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110072, 'Pomiechówek', 'Pomiechowek', 'Pmiechowek,Pomiechowek,Pomiechówek', 52.4713800, 20.7292300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110073, 'Połomia', 'Polomia', 'Polomia,Polomyja,Połomia,Połomyja', 49.9047500, 21.8919800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110074, 'Policzna', 'Policzna', 'Comuna de Policzna,Gmina Polichna,Gmina Policzna,Polichna,Полична,Ґміна Полічна', 51.4554500, 21.6268400, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110075, 'Połaniec', 'Polaniec', 'Comuna de Polaniec,Comuna de Połaniec,Gmina Polanec'',Gmina Polaniec,Gmina Połaniec,Polanec,Polaniec,Połaniec,Поланец,Ґміна Поланець', 50.4332400, 21.2812000, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110076, 'Polańczyk', 'Polanczyk', 'Polanczyk,Polańczyk', 49.3696900, 22.4211200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110077, 'Pokrzywnica', 'Pokrzywnica', '', 52.6207200, 21.0192500, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110078, 'Pokrówka', 'Pokrowka', '', 51.0947900, 23.4634500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110079, 'Pogórska Wola', 'Pogorska Wola', '', 50.0185500, 21.1579500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110080, 'Podłęże', 'Podleze', '', 50.0145800, 20.1678100, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110081, 'Podkowa Leśna', 'Podkowa Lesna', 'Podkova-Les''na,Podkowa Lesna,Podkowa Leśna,Подкова-Лесьна', 52.1223700, 20.7266500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110082, 'Podegrodzie', 'Podegrodzie', '', 49.5768800, 20.5885500, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110083, 'Podedwórze', 'Podedworze', 'Opole,Podedworze,Podedwórze', 51.6881500, 23.1996100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110084, 'Pniewy', 'Pniewy', '', 51.9146800, 20.7457800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110085, 'Płońsk', 'Plonsk', 'Plon''sk,Plons''k,Plonsk,Plonska,Plonskas,Ploņska,Plunsk,Płońsk,Płůńsk,plwnsq,pu weng si ke,pwnsk,Плонск,Плонськ,Плоньск,Плоњск,פלונסק,پونسک,普翁斯克', 52.6234800, 20.3755200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110086, 'Płoniawy-Bramura', 'Ploniawy-Bramura', '', 52.9778000, 21.0717800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110087, 'Pleśna', 'Plesna', '', 49.9264200, 20.9452600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110088, 'Piwniczna-Zdrój', 'Piwniczna-Zdroj', 'Pivnichna-Zdroj,Pivnichna-Zdruj,Pivnicnazdroja,Pivņičnazdroja,Piwniczna,Piwniczna Zdroj,Piwniczna Zdrój,pi fu ni qi na-ci de lu yi,Пивнична-Здруй,Пивњична-Здрој,Північна-Здруй,皮夫尼奇納-兹德魯伊', 49.4405600, 20.7142300, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110089, 'Piszczac', 'Piszczac', '', 51.9811800, 23.3771900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110090, 'Pisz', 'Pisz', 'Janowa Gora,Johannisburg,Pisa,Pisas,Pish,Pisz,Piša,Pišas,pi shen,Пиш,Піш,皮什', 53.6274400, 21.8125300, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110091, 'Piskorowice', 'Piskorowice', '', 50.2357900, 22.5286700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110092, 'Pionki', 'Pionki', 'P''onki,Pionki,Pionkos,Pjonki,pi weng ji,Пйонкі,Пьонки,Пёнки,Пјонки,皮翁基', 51.4760400, 21.4499500, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110093, 'Pińczów', 'Pinczow', 'Gorad Pin''chau,Pin''chuv,Pinchov,Pinchuv,Pincova,Pincow,Pincuvas,Pinczow,Pinčuvas,Pińczów,Piņčova,ping qiu fu,pynzwb,Горад Піньчаў,Пинчов,Пиньчув,Пињчов,Пінчув,פינטשאוו,פינצוב,平丘夫', 50.5205200, 20.5264900, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110094, 'Pilzno', 'Pilzno', 'Pil''zno,Pilsen,Pilzno,pi er zi nuo,pylznw,Пилзно,Пильзно,Пільзно,פילזנו,皮爾茲諾', 49.9788300, 21.2922800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110095, 'Pilawa', 'Pilawa', 'Pilava,Pilawa,Piljava,pi la wa,Пилава,Пилява,Пілява,皮拉瓦', 51.9594500, 21.5308900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110096, 'Pierzchnica', 'Pierzchnica', '', 50.6975400, 20.7548900, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110097, 'Pieniężno', 'Pieniezno', 'Mehlsack,Melzak,Penenzhno,Penenzno,Peņenžno,Pieniezno,Pieniężno,Pjenenzhno,pei ni en ri nuo,Пененжно,Пјењенжно,佩尼恩日諾', 54.2364900, 20.1283300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110098, 'Piekoszów', 'Piekoszow', '', 50.8803500, 20.4641800, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110099, 'Piecki', 'Piecki', 'Comuna de Piecki,Gmina Pec''kij,Gmina Piecki,Pecki,Peitschendorf,Piecki,Гміна Пецький,Пецки', 53.7575900, 21.3391400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110100, 'Piątnica', 'Piatnica', 'Piatnica Poduchowna,Piontnica,Piątnica Poduchowna', 53.1965700, 22.0959100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110101, 'Piastów', 'Piastow', 'Piastuvas,Pjastov,Pjastova,Pjastuv,pi ya si tu fu,Пястов,Пястув,Пјастов,皮亞斯圖夫', 52.1843500, 20.8395200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110102, 'Piaski', 'Piaski', 'Piaski,Piaski Luterskie,Piaski Wielkie', 51.1389200, 22.8485600, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110103, 'Piaseczno', 'Piaseczno', 'Piasecnas,Piaseczno,Piasečnas,Pjasechno,Pjasecno,Pjasečno,byasytshnw,pi ya sai qi nuo,Пясечно,Пјасечно,פיאסצנו,بياسيتشنو,皮亞塞奇諾', 52.0814000, 21.0239700, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110104, 'Perlejewo', 'Perlejewo', 'Perlejewo,Pertejewo', 52.5667600, 22.5645700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110105, 'Pawłów', 'Pawlow', 'Comuna de Pawlow,Comuna de Pawłów,Gmina Pavluv,Gmina Pawlow,Gmina Pawłów,Pavluv,Павлув,Ґміна Павлув', 50.9621600, 21.1206200, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110106, 'Pawłosiów', 'Pawlosiow', '', 49.9953300, 22.6476300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110107, 'Pawlikowice', 'Pawlikowice', '', 49.9531000, 20.0548600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110108, 'Pasym', 'Pasym', 'Pasim,Pasima,Passenheim,Pasym,pa se mu,Пасим,Пасым,帕瑟姆', 53.6506900, 20.7918800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110109, 'Parysów', 'Parysow', '', 51.9758400, 21.6800600, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110110, 'Parczew', 'Parczew', 'Parceva,Parcevas,Parchev,Parchiv,Parczew,Parčeva,Parčevas,pa er qie fu,przb,Парчев,Парчів,פרצב,帕爾切夫', 51.6402100, 22.9005700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110111, 'Paradyż', 'Paradyz', '', 51.3060400, 20.1137400, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110112, 'Paprotnia', 'Paprotnia', 'Paprotnia,Paprotnja,Папротня', 52.3007100, 22.4675600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110113, 'Paprotnia', 'Paprotnia', 'Paprotnia,Paprotnja,Папротня', 52.2051300, 20.4232000, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110114, 'Pantalowice', 'Pantalowice', 'Pantalowice,Pantatowice', 49.9521000, 22.4356300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110115, 'Padew Narodowa', 'Padew Narodowa', '', 50.4394700, 21.5005900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110116, 'Pacanów', 'Pacanow', 'Pacanov,Пацанов,פצאנוב', 50.4003100, 21.0414800, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110117, 'Ożarów Mazowiecki', 'Ozarow Mazowiecki', 'Ozarova Mazovecka,Ozarow,Ozarow-Franciszkow,Ozharov Mazovecki,Ozharov Mazovjecki,Ozharuv-Mazovec''kij,Ozharuv-Mazovecki,Ozharuv-Mazoveckij,Ożarów,Ożarów-Franciszków,Ožarova Mazovecka,ma zuo fu she de qu ao zha lu fu,Ожаров Мазовецки,Ожаров Мазовјецки,Ожарув-Мазовецки,Ожарув-Мазовецкий,Ожарув-Мазовецький,馬佐夫舍地區奧扎魯夫', 52.2103900, 20.7971600, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110118, 'Ożarów', 'Ozarow', 'Ozarova,Ozharov,Ozharuv,Ožarova,ao zha lu fu,Ожаров,Ожарув,אוזרוב,אזשאראוו,奧扎魯夫', 50.8879800, 21.6665800, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110119, 'Owczarnia', 'Owczarnia', '', 52.1111400, 20.7046800, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110120, 'Otwock', 'Otwock', 'Otvoc''k,Otvock,Otvocka,Otvockas,Otvotsk,Otwock,ao te wo ci ke,Отвоцк,Отвоцьк,אוטבוצק,אטוואצק,奧特沃茨克', 52.1057700, 21.2612900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110121, 'Otrębusy', 'Otrebusy', '', 52.1284300, 20.7607300, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110122, 'Ostrowsko', 'Ostrowsko', '', 49.4761600, 20.1005200, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110123, 'Ostrów Mazowiecka', 'Ostrow Mazowiecka', 'Mazovijos Ostruva,Ostrov Mazovecka,Ostrov Mazovjecka,Ostrov-Mazovetskiy,Ostrova Mazovecka,Ostrow,Ostrow Mazowiecka,Ostrow Mazowiecki,Ostruv-Mazovec''ka,Ostruv-Mazovecka,Ostrów,Ostrów Mazowiecka,Ostrów Mazowiecki,ma zuo fu she de qu ao si te lu fu,Остров Мазовецка,Остров Мазовјецка,Острув-Мазовецка,Острув-Мазовецька,אוסטרוב מזובייצקה,馬佐夫舍地區奧斯特魯夫', 52.8024500, 21.8950700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110124, 'Ostrów Lubelski', 'Ostrow Lubelski', 'Ostrow,Ostrow Lubelski,Ostrow Podlaski,Ostrów,Ostrów Lubelski,Ostrów Podlaski', 51.4941600, 22.8528700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110125, 'Ostrowiec Świętokrzyski', 'Ostrowiec Swietokrzyski', 'Ostrovec Shventokshiski,Ostrovec''-Sventokshis''kij,Ostrovec-Sventokshiskij,Ostrovec-Sventokshizhski,Ostroveca Sventoksiska,Ostroveca Sventokšiska,Ostrovets,Ostrovjec Svjentokshiski,Ostrowiec,Ostrowiec Kielecki,Ostrowiec Swietokrzyski,Ostrowiec nad Kamienna,Ostrowiec nad Kamienną,Ostrowiec Świętokrzyski,Svento Kryziaus Ostrovecas,sheng shi zi de qu ao si te luo wei ci,xx st rx weiytschfeiyn txk chi ski,Švento Kryžiaus Ostrovecas,ʼwstrwbyyz swwyyntwqzysqy,Островец Швентокшиски,Островец-Свентокшижски,Островец-Свентокшиский,Островець-Свентокшиський,Островјец Свјентокшиски,אוסטרובייץ שוויינטוקזיסקי,אסטראווצע,ออสตรอเวียตซ์ชเฟียนตอกชิสกี,聖十字地區奧斯特羅維茨', 50.9293600, 21.3852500, 'PL', '2015-04-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110126, 'Ostrówek', 'Ostrowek', '', 52.5535000, 21.7601400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110127, 'Ostrówek', 'Ostrowek', '', 51.5815000, 22.6122700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110128, 'Ostrów', 'Ostrow', '', 50.0977900, 21.5932000, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110129, 'Ostrów', 'Ostrow', '', 49.9681200, 22.7871000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110130, 'Ostrołęka', 'Ostroleka', 'Gorad Astralehnka,Ostroleka,Ostrolenka,Ostrołęka,ao si te luo wen ka,oseuteulowengka,osutorou~enka,Горад Астралэнка,Остроленка,אוסטרולנקה,オストロウェンカ,奧斯特羅文卡,오스트로웽카', 53.0862100, 21.5756600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110131, 'Osiek Jasielski', 'Osiek Jasielski', '', 49.6378400, 21.4884000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110132, 'Osiek', 'Osiek', 'Comuna de Osiek,Gmina Osek,Gmina Osiek,Osek,Osiek,Osiel,Осек,Ґміна Осек', 50.5199600, 21.4419200, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110133, 'Osieczany', 'Osieczany', 'Osiczany,Osieczany', 49.8425200, 19.9820700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110134, 'Osieck', 'Osieck', '', 51.9665300, 21.4191300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110135, 'Orzysz', 'Orzysz', 'Arys,Ozhish,Ozisa,Ožiša,ao ri shen,Ожиш,奧日什', 53.8096700, 21.9481100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110136, 'Orzechówka', 'Orzechowka', '', 49.7308000, 21.9451900, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110137, 'Orońsko', 'Oronsko', 'Oronsk,Oronske,Oronsko,Orońsk,Orońske,Orońsko', 51.3133900, 20.9906700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110138, 'Orneta', 'Orneta', 'Orneta,Wormditt,ao er nei ta,Орнета,奥尔内塔', 54.1148300, 20.1332800, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110139, 'Orły', 'Orly', '', 49.8710700, 22.8029800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110140, 'Orla', 'Orla', 'Comuna Orla,Comuna de Orla,Gmina Orla,Gmina Orlja,Orla,Orlja,Orlos valscius,Orlos valsčius,Орля,Ґміна Орля', 52.7054600, 23.3321300, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110141, 'Opole Lubelskie', 'Opole Lubelskie', 'Comuna de Opole Lubelskie,Gmina Opole Lubelskie,Gmina Opole-Ljubel''s''ke,Opole,Opole Lubelskie,Opole-Ljubel''ske,Ополе-Любельске,Ґміна Ополе-Любельське', 51.1477500, 21.9689700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110142, 'Opoczno', 'Opoczno', 'Opochno,Opocnas,Opocno,Opoczno,Opočnas,Opočno,ao bo qi nuo,Опочно,אופוצנו,אפאטשנא,奧波奇諾', 51.3756900, 20.2782700, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110143, 'Opinogóra Górna', 'Opinogora Gorna', '', 52.9055400, 20.7178100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110144, 'Opatowiec', 'Opatowiec', 'Comuna de Opatowiec,Gmina Opatovec'',Gmina Opatowiec,Opatovec,Опатовец,Ґміна Опатовець', 50.2431400, 20.7234800, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110145, 'Opatów', 'Opatow', 'Opatov,Opatova,Opatow,Opatuv,Opatów,Uopatuw,Uopatůw,ao pa tu fu,Опатов,Опатув,אפטא,奧帕圖夫', 50.8005800, 21.4253800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110146, 'Olsztynek', 'Olsztynek', 'Gorad Al''shtynek,Hohenstein,Ol''shtinek,Ol''shtynek,Olshtinek,Olstineka,Olstynekas,Olsztynek,Olštineka,Olštynekas,ao er shen di nei ke,Горад Альштынек,Олштинек,Ольштинек,Ольштынек,奧爾什蒂內克', 53.5837400, 20.2847100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110147, 'Olsztyn', 'Olsztyn', 'Allenshteyn,Allenstein,Ol''shtyn,Olsztyn,QYO,Ольштын', 53.7799500, 20.4941600, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110148, 'Olszówka', 'Olszowka', '', 49.6145500, 20.0288500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110149, 'Olszanica', 'Olszanica', '', 49.4774100, 22.4438200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110150, 'Olszana', 'Olszana', 'Olszana,Olszanka', 49.5674800, 20.5212600, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110151, 'Ołpiny', 'Olpiny', 'Olpiny,Ołpiny', 49.8068600, 21.2046400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110152, 'Oleszyce', 'Oleszyce', 'Oleszyce', 50.1675000, 23.0348100, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110153, 'Olesno', 'Olesno', '', 50.2015200, 20.9257800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110154, 'Oleśnica', 'Olesnica', '', 50.4535700, 21.0645700, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110155, 'Olecko', 'Olecko', 'Alecka,Alėcka,Marggrabowa,Margrabowa,Olec''ko,Olecko,Oletzko,Treuburg,Uolecko,ao lai ci ke,Олецко,Олецько,奧萊茨科', 54.0337400, 22.5070400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110156, 'Oksa', 'Oksa', '', 50.7287400, 20.1008600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110157, 'Okocim', 'Okocim', 'Okocim', 49.9489000, 20.6016000, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110158, 'Ojrzeń', 'Ojrzen', '', 52.7657000, 20.5431500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110159, 'Odrzywół', 'Odrzywol', '', 51.5195300, 20.5555900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110160, 'Odrzykoń', 'Odrzykon', '', 49.7405700, 21.7407400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110161, 'Ochotnica Dolna', 'Ochotnica Dolna', 'Ochotnica,Ochotnica Dolna', 49.5268200, 20.3426500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110162, 'Ochota', 'Ochota', 'Okhota,Охота', 52.2209600, 20.9852600, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110163, 'Obsza', 'Obsza', 'Obsza,Zamch-Zamosty Obsza', 50.3152000, 22.9568800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110164, 'Obryte', 'Obryte', 'Obryte,Обрыте', 52.7163300, 21.2494500, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110165, 'Obrazów', 'Obrazow', '', 50.6927600, 21.6504500, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110166, 'Nurzec-Stacja', 'Nurzec-Stacja', 'Nurzec,Nurzec-Stacja,Nuzhech-Stac''ja,Stacja Nurzec,Нужеч-Стацья', 52.4624900, 23.0857100, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110167, 'Nur', 'Nur', 'Nur,Нур', 52.6682600, 22.3220700, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110168, 'Nozdrzec', 'Nozdrzec', '', 49.7732300, 22.1986500, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110169, 'Nowy Żmigród', 'Nowy Zmigrod', 'Novy Zmigrod,Novy Żmigród,Novy-Zhmigrud,Nowy Zmigrod,Nowy Żmigród,Zmigrod Nowy,nwby zmygrwd,Żmigród Nowy,Новы-Жмигруд,נובי זמיגרוד', 49.6035300, 21.5237600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110170, 'Nowy Wiśnicz', 'Nowy Wisnicz', 'Nowy Wisnicz,Nowy Wiśnicz,Wisnicz Nowy,Wiśnicz Nowy', 49.9146500, 20.4610900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110171, 'Nowy Targ', 'Nowy Targ', 'Naujasis Targas,Novi Targ,Novi Targa,Novij Targ,Novy Targ,Novy-Targ,Novyy Targ,Nový Targ,Nowy Targ,novi-tʼargi,xin ta er ge,Нови Тарг,Новий Тарг,Новы-Тарг,נובי טארג,ნოვი-ტარგი,ノヴィ・タルク,新塔爾格', 49.4778300, 20.0322800, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110172, 'Nowy Sącz', 'Nowy Sacz', 'Gorad Novy-Sonch,Naujasis Soncas,Naujasis Sončas,Neu Sandez,Neu-Sandec,Novi Sonca,Novi Sonch,Novi Sonča,Novij Sonch,Novy Sonch,Novy-Sonch,Novyy Sandets,Novyy Sonch,Nowi Soncz,Nowi Sóncz,Nowy Sacz,Nowy Suncz,Nowy Sącz,Nowy Sůncz,Ujszandec,nobisongchi,novi-sonchi,nowy.sontc,nwby swnz,nwwy swnts,xin song qi,Újszandec,Горад Новы-Сонч,Нови Сонч,Новий Сонч,Новы Сонч,Новы-Сонч,נובי סונץ,צאנז,نووی سونتس,ნოვი-სონჩი,ノヴィ・ソンチ,新松奇,노비송치', 49.6217700, 20.6970500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110173, 'Nowy Korczyn', 'Nowy Korczyn', 'Nowy Korczyn,nwby qwrzyn,נובי קורצין', 50.3012400, 20.8075900, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110174, 'Nowy Dwór Mazowiecki', 'Nowy Dwor Mazowiecki', 'Mazovijos Novy Dvuras,Novi Dvor Mazovjecki,Novi Dvora Mazovecka,Novi Dvur Mazovecki,Novij-Dvir-Mazovec''kij,Novy Dvor,Novy-Dvur-Mazovecki,Novy-Dvur-Mazoveckij,Nowy Dwor,Nowy Dwór,ma zuo fu she de qu xin zhuang yuan,nwbydbwr mzwbyyzqy,Нови Двор Мазовјецки,Нови Двур Мазовецки,Новий-Двір-Мазовецький,Новы-Двур-Мазовецки,Новы-Двур-Мазовецкий,נאווידוואר,נובידבור מזובייצקי,馬佐夫舍地區新莊園', 52.4302200, 20.7165200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110175, 'Nowosielce-Gniewosz', 'Nowosielce-Gniewosz', 'Nowosielce,Nowosielce-Gniewosz', 49.5684200, 22.0694700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110176, 'Nowosielce', 'Nowosielce', '', 50.0574700, 22.4105600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110177, 'Nowogród', 'Nowogrod', 'Novogrod,Novogroda,Novogrud,Novogrudas,Nowogrod,Nowogród,nuo wo ge lu de,Новогрод,Новогруд,Новоґруд,諾沃格魯德', 53.2269800, 21.8821000, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110178, 'Nowodwór', 'Nowodwor', '', 51.6390100, 22.1018300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110179, 'Nowe Sioło', 'Nowe Siolo', '', 50.2319400, 23.1588400, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110180, 'Nowe Miasto nad Pilicą', 'Nowe Miasto nad Pilica', 'Nove Mjasto nad Pilicom,Nove Mjasto pie Pilicas,Nove-Mjasto-nad-Piliceju,Nove-Mjasto-nad-Pilicon,Nowe Miasto,Nowe Miasto nad Pilica,Nowe Miasto nad Pilicą,pi li cha he pan xin cheng,Нове Мјасто над Пилицом,Нове-Място-над-Пилицею,Нове-Място-над-Пилицон,נובה מיאסטו על הפיליצה,皮利察河畔新城', 51.6181200, 20.5761900, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110181, 'Nowe Miasto', 'Nowe Miasto', 'Nove-Mjasto,Nowe Miasto,Nowe Miasto K. Plonska,Nowe Miasto K. Płońska,Нове-Място', 52.6569100, 20.6283800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110182, 'Nowe Brzesko', 'Nowe Brzesko', 'Brzesko Nowe,Nowe Brzesko', 50.1322200, 20.3766300, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110183, 'Nowa Słupia', 'Nowa Slupia', 'Nowa Slupia,Nowa Słupia,Slupia Nowa,Słupia Nowa', 50.8643200, 21.0904900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110184, 'Nowa Sarzyna', 'Nowa Sarzyna', 'Nova Sazhina,Nova Sazina,Nova Sažina,Nova-Sazhina,Nowa Sarzyna,Sarzyna,xin sa ri na,Нова Сажина,Нова-Сажина,新薩日納', 50.3208600, 22.3445600, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110185, 'Nowa Dęba', 'Nowa Deba', 'Nova Demba,Nova-Demba,Nowa Deba,Nowa Dęba,xin deng ba,Нова Демба,Нова-Демба,新登巴', 50.4297400, 21.7507800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110186, 'Niwiska', 'Niwiska', '', 50.2249200, 21.6303600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110187, 'Nisko', 'Nisko', 'Nis''ko,Nisko,Njisko,ni si ke,Ņisko,Њиско,Ниско,Нисько,尼斯科', 50.5198700, 22.1396800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110188, 'Nieporęt', 'Nieporet', 'Neporeng,Nieporet,Nieporęt,Непоренг', 52.4315200, 21.0321200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110189, 'Niepołomice', 'Niepolomice', 'Nepolomice,Njepolomice,nie bo wo mi cai,Ņepolomice,Њеполомице,Неполомице,Неполоміце,涅波沃米采', 50.0406600, 20.2225700, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110190, 'Nienadowa', 'Nienadowa', '', 49.8290100, 22.4270400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110191, 'Niemce', 'Niemce', 'Niemce', 51.3615500, 22.6393900, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110192, 'Nielisz', 'Nielisz', '', 50.8006700, 23.0445100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110193, 'Niedźwiedź', 'Niedzwiedz', '', 49.6210000, 20.0779400, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110194, 'Niedźwiada', 'Niedzwiada', 'Niedrzwica,Niedzwiada,Niedźwiada', 51.5440900, 22.6914000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110195, 'Niedźwiada', 'Niedzwiada', '', 49.9893700, 21.5216200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110196, 'Niedzica', 'Niedzica', 'Nedzice,Niedzica,Недзице', 49.4100800, 20.3027300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110197, 'Niedrzwica Duża', 'Niedrzwica Duza', 'Niedrzwica,Niedrzwica Duza,Niedrzwica Duża', 51.1146200, 22.3891100, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110198, 'Niedomice', 'Niedomice', '', 50.1073700, 20.8954800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110199, 'Niechobrz', 'Niechobrz', '', 49.9947200, 21.8782400, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110200, 'Niebylec', 'Niebylec', '', 49.8566900, 21.9034800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110201, 'Nieborów', 'Nieborow', '', 52.0777100, 20.0690200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110202, 'Niebocko', 'Niebocko', 'Niebocka,Niebocko', 49.6777400, 22.1048400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110203, 'Niebieszczany', 'Niebieszczany', '', 49.5034800, 22.1565100, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110204, 'Nidzica', 'Nidzica', 'Neidenburg,Nibork,Nidzhica,Nidzica,Nidzicja,ni ji cha,Ņidzica,Ниджица,Нидзица,Ниђица,Нідзиця,尼濟察', 53.3605200, 20.4274900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110205, 'Nawojowa', 'Nawojowa', 'Nawojowa,Nowajowa', 49.5668600, 20.7392700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110206, 'Nasielsk', 'Nasielsk', 'Comuna de Nasielsk,Gmina Nasel''s''k,Gmina Nasielsk,Nasel''sk,Nasielsk,Насельск,Ґміна Насельськ', 52.5888700, 20.8055300, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110207, 'Naruszewo', 'Naruszewo', 'Narushevo,Naruszewo,Нарушево', 52.5268700, 20.3515700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110208, 'Narol', 'Narol', 'Comuna de Narol,Gmina Naril'',Gmina Narol,Narol,Narol Lipsko,Narol'',Гміна Наріль,Нароль', 50.3492500, 23.3267900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110209, 'Narew', 'Narew', 'Comuna de Narew,Gmina Narev,Gmina Narew,Narev,Narevo valscius,Narevo valsčius,Narew,Нарев,Ґміна Нарев', 52.9141800, 23.5198400, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110210, 'Nałęczów', 'Naleczow', 'Nalenchov,Nalenchuv,Nalencova,Nalencuvas,Nalenčova,Nalenčuvas,na wen qiu fu,Наленчов,Наленчув,納文丘夫', 51.2858100, 22.2153900, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110211, 'Nagłowice', 'Naglowice', 'Naglowice,Nagłowice', 50.6783500, 20.1066100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110212, 'Nadarzyn', 'Nadarzyn', 'Nadarzyn', 52.0943800, 20.8077600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110213, 'Myszyniec', 'Myszyniec', 'Mishinec,Mishinec'',Misineca,Mišiņeca,Myshinec,Myszyniec,mei xi nie ci,Мишинець,Мишињец,Мышинец,梅希涅茨', 53.3805500, 21.3496100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110214, 'Mysiadło', 'Mysiadlo', '', 52.1021600, 21.0185600, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110215, 'Muszyna', 'Muszyna', 'Mushina,Musina,Muszyna,Mušina,mu xi na,mwsynh,Мушина,מושינה,穆希納', 49.3566100, 20.8971800, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110216, 'Mszczonów', 'Mszczonow', 'Msconova,Mshchonov,Mshhonuv,Mstsonoub,Mszczonovia,Mszczonow,Mszczonów,Mščonova,mshtshwnwf,mu shen qiao nu fu,mushichonufu,Μστσόνουβ,Мшчонов,Мщонув,אמשינאוו,אמשינוב,مشتشونوف,ムシチョヌフ,姆什喬努夫', 51.9741500, 20.5208300, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110217, 'Mszana Górna', 'Mszana Gorna', '', 49.6620200, 20.0973400, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110218, 'Mszana Dolna', 'Mszana Dolna', 'Msana Dolna,Mshana Dolna,Mshana-Dol''na,Mszana Dolna,Mšana Dolna,xia mu sha na,Мшана Долна,Мшана-Дольна,משאנה דולנה,下姆沙納', 49.6743200, 20.0799200, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110219, 'Mrozy', 'Mrozy', 'Comuna de Mrozy,Gmina Mrozi,Gmina Mrozy,Kaluska Wola,Kałuska Wola,Mrozy,Wola Kaluska,Wola Kałuska,Мрозы,Ґміна Мрози', 52.1660900, 21.8026300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110220, 'Mrozy', 'Mrozy', '', 52.0197500, 20.3670200, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110221, 'Mrągowo', 'Mragowo', 'Mragovo,Mrongovas,Mrongovo,Sensburg,Zadzbork,mu long ge wo,murongovu~o,Źadzbork,Мрагово,Мронгово,ムロンゴヴォ,姆龍戈沃', 53.8643700, 21.3050700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110222, 'Moszczenica', 'Moszczenica', '', 49.7366800, 21.0923800, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110223, 'Mordy', 'Mordy', 'Mordai,Mordi,Mordy,mo er di,mwrdy,Морди,Морды,מורדי,莫爾迪', 52.2116000, 22.5172500, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110224, 'Morawica', 'Morawica', 'Comuna de Morawica,Gmina Moravicja,Gmina Morawica,Moravica,Моравица,Ґміна Моравиця', 50.7467800, 20.6175600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110225, 'Mońki', 'Monki', 'Gorad Mon''ki,Mon''ki,Monki,Monkos,Mońki,Moņki,meng ji,Горад Монькі,Монки,Моньки,Монькі,Моњки,蒙基', 53.4049600, 22.7979100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110226, 'Mokotów', 'Mokotow', 'Mokotuv,Мокотув', 52.1934000, 21.0348700, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110227, 'Mokobody', 'Mokobody', 'Mokobody,Мокободы', 52.2652300, 22.1118200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110228, 'Mogielnica', 'Mogielnica', 'Mogel''nica,Mogel''nicja,Mogelnica,Mogelņica,Mogjelnica,mo gai er ni cha,mwgyylnyzh,Могельница,Могјелњица,Моґельниця,מאגלניצא,מוגיילניצה,莫蓋爾尼察', 51.6943200, 20.7222700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110229, 'Modliborzyce', 'Modliborzyce', 'Comuna de Modliborzyce,Gmina Modliborzyce,Gmina Modlibozhice,Modlibozhice,Модлибожице,Ґміна Модлібожице', 50.7541600, 22.3294500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110230, 'Mniszków', 'Mniszkow', '', 51.3701700, 20.0391500, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110231, 'Mniów', 'Mniow', '', 51.0122400, 20.4842700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110232, 'Młynarze', 'Mlynarze', '', 52.9541700, 21.4114100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110233, 'Młodzieszyn', 'Mlodzieszyn', 'Mlodzeshin,Mlodzieszyn,Młodzieszyn,Млодзешин', 52.2994500, 20.2001700, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110234, 'Mława', 'Mlawa', 'Mlava,Mlawa,Mława,mu wa wa,Млава,מלאווה,姆瓦瓦', 53.1127800, 20.3841000, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110235, 'Mirzec', 'Mirzec', '', 51.1346600, 21.0571000, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110236, 'Mirów', 'Mirow', '', 51.1972000, 21.0329000, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110237, 'Mirocin', 'Mirocin', '', 50.0423700, 22.5559600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110238, 'Mircze', 'Mircze', '', 50.6516400, 23.8960400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110239, 'Mińsk Mazowiecki', 'Minsk Mazowiecki', 'Gorad Min''sk Mazavecki,Mazovijos Minskas,Min''sk-Mazovecki,Min''sk-Mazoveckij,Mins''k-Mazovec''kij,Minsk,Minsk Mazovecki,Minsk Mazovjecki,Minsk Mazowiecki,Minsk-Mazovetskiy,Minska Mazovecka,Mińsk Mazowiecki,Miņska Mazovecka,Novo-Minsk,ma zuo fu she de qu ming si ke,mynsq mzwbyyzqy,Горад Міньск Мазавецкі,Минск Мазовецки,Миньск-Мазовецки,Миньск-Мазовецкий,Мињск Мазовјецки,Мінськ-Мазовецький,Ново-Минск,מינסק מזובייצקי,馬佐夫舍地區明斯克', 52.1793500, 21.5725100, 'PL', '2017-04-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110240, 'Milejów', 'Milejow', '', 51.2322600, 22.9244300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110241, 'Milejczyce', 'Milejczyce', 'Milejchice,Milejczyce,Милейчице', 52.5196700, 23.1320600, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110242, 'Milanówek', 'Milanowek', 'Milanovek,Milanowek,Milanuveka,Milanówek,Miljanovek,Miljanuvek,mi la nu wei ke,Милановек,Миляновек,Милянувек,Мілянувек,米拉努韋克', 52.1187900, 20.6715500, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110243, 'Milanów', 'Milanow', '', 51.7037400, 22.8883000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110244, 'Miłakowo', 'Milakowo', 'Liebstadt,Milakovo,Milakowo,Miłakowo,Милаково,Мілаково', 54.0092300, 20.0712500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110245, 'Mikołajki', 'Mikolajki', 'Comuna de Mikolajki,Comuna de Mikołajki,Gmina Mikolajki,Gmina Mikołajki,Mikolajki,Mikołajki,Nikolaiken,Гміна Міколайкі,Миколайки', 53.8028800, 21.5701100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110246, 'Miętne', 'Mietne', '', 51.9213500, 21.5745700, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110247, 'Mielec', 'Mielec', 'Melec,Melec'',Meleca,Melecas,Melets,Mielec,Mjelec,mei lai ci,mi xe let s,myylz,Мелец,Мелець,Мјелец,מיילץ,มีเอเลตส์,梅萊茨', 50.2870900, 21.4239000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110248, 'Miejsce Piastowe', 'Miejsce Piastowe', '', 49.6344000, 21.7873500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110249, 'Międzyrzec Podlaski', 'Miedzyrzec Podlaski', 'Gorad Mendzyrehch Padljaski,Mendzijets-Podlyaski,Mendzizeca Podlaska,Mendzizhec Podljaski,Mendzyzhec-Podljaski,Mendzıjets-Podlyaski,Mesericum,Mezhirech''ye,Mezhirech’ye,Mezhirichchja,Meņdzižeca Podlaska,Miedzyrzec,Miedzyrzec Podlaski,Mientzirzets Pontlaski,Międzyrzec,Międzyrzec Podlaski,Mjendzizhec Podlaski,Palenkes Mendzizecas,Palenkės Mendzižecas,Polenkes Miendziziecos,Polėnkės Miendzīžiečos,mian ji re ci,miengjijecheupodeullaseuki,myndsyzhts pwdlasky,mytsyrzyk bwdlasky,myyndzyzz pwdlsqy,Μιεντζίρζετς Ποντλάσκι,Горад Мендзырэч Падляскі,Межиріччя,Мендзижец Подляски,Мендзыжец-Подляски,Мјендзижец Подласки,Подълѣсьскъ Мѧꙃирьць,מיינדזיזץ פודלסקי,ميتسيرزيك بودلاسكي,میندسیژتس پودلاسکی,ミェンヅィジェツ・ポドラスキ,缅济热茨,미엥지제츠포들라스키', 51.9864000, 22.7824800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110250, 'Miedzna', 'Miedzna', 'Medzna,Miedzna,Медзна', 52.4677800, 22.0894700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110251, 'Miedziana Góra', 'Miedziana Gora', '', 50.9368000, 20.5509600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110252, 'Miechów', 'Miechow', 'Mehova,Mekhov,Mekhuv,Mjekhov,mei hu fu,myyhwb,Мехов,Мехув,Мјехов,מייחוב,梅胡夫', 50.3564800, 20.0278800, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110253, 'Michów', 'Michow', 'Michow,Michow Lubartowski,Michów,Michów Lubartowski', 51.5257300, 22.3143500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110254, 'Michałowo', 'Michalowo', 'Michalovas,Michalowo,Michałowo,Mihalovo,Mikhalovo,mi ha wo wo,Михалово,Міхалово,米哈沃沃', 53.0349200, 23.6099600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110255, 'Michałowice', 'Michalowice', 'Michalowice-Osiedle,Michałowice-Osiedle', 52.1743500, 20.8808900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110256, 'Michałów-Reginów', 'Michalow-Reginow', 'Michalow,Michalow-Reginow,Michałów,Michałów-Reginów', 52.4171100, 20.9659500, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110257, 'Michałów', 'Michalow', '', 50.7372700, 23.0229700, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110258, 'Michałów', 'Michalow', '', 50.5470900, 23.6036100, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110259, 'Michałów', 'Michalow', 'Comuna de Michalow,Comuna de Michałów,Gmina Michalow,Gmina Michałów,Gmina Mikhaluv,Mikhaluv,Михалув,Ґміна Міхалув', 50.4954100, 20.4617800, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110260, 'Miastków Kościelny', 'Miastkow Koscielny', '', 51.8840700, 21.8252800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110261, 'Miączyn', 'Miaczyn', '', 50.7382500, 23.5013000, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110262, 'Mełgiew', 'Melgiew', 'Melgiew,Metgiew,Mełgiew', 51.2251900, 22.7841400, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110263, 'Medyka', 'Medyka', 'Medyka', 49.8052600, 22.9222900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110264, 'Mędrzechów', 'Medrzechow', '', 50.2822100, 20.9474900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110265, 'Maszkienice', 'Maszkienice', '', 49.9892000, 20.6865700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110266, 'Masłów', 'Maslow', '', 50.9006500, 20.7232200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110267, 'Markuszów', 'Markuszow', '', 51.3745700, 22.2580400, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110268, 'Markowa', 'Markowa', 'Markowa', 50.0263300, 22.3316000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110269, 'Marki', 'Marki', 'Marki,Markos,ma er ji,maleuki,Марки,Маркі,馬爾基,마르키', 52.3206500, 21.1047400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110270, 'Maniowy', 'Maniowy', '', 49.4597600, 20.2645400, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110271, 'Manasterz', 'Manasterz', 'Manasterz,Monasterz', 49.9352000, 22.3460200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110272, 'Mały Płock', 'Maly Plock', 'Maly Plock,Maly-Plock,Mały Płock,Малы-Плоцк', 53.3038500, 22.0283600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110273, 'Małogoszcz', 'Malogoszcz', 'Malogosca,Malogoshch,Malogoshh,Malogoszcz,Malogošča,Małogoszcz,ma wo ge shen qi,mlwgwsz,Малогошч,Малогощ,מלוגושץ,馬沃戈什奇', 50.8121400, 20.2640700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110274, 'Małkinia Górna', 'Malkinia Gorna', 'Malkinia,Malkinia Gorna,Małkinia,Małkinia Górna', 52.6922000, 22.0283600, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110275, 'Maków Mazowiecki', 'Makow Mazowiecki', 'Makov Mazovecki,Makov Mazovjecki,Makova Mazovecka,Makow,Makow Mazowiecki,Makow nad Orzycem (do 1928),Makuv-Mazovec''kij,Makuv-Mazovecki,Maków,Maków Mazowiecki,Maków nad Orzycem (do 1928),ma zuo fu she de qu ma ku fu,mqwb mzwbyyzqy,Маков Мазовецки,Маков Мазовјецки,Макув-Мазовецки,Макув-Мазовецький,מקוב מזובייצקי,馬佐夫舍地區馬庫夫', 52.8649300, 21.1005300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110276, 'Maków', 'Makow', '', 51.9469600, 20.0521100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110277, 'Majdan Królewski', 'Majdan Krolewski', 'Majdan,Majdan Krolewski,Majdan Królewski', 50.3793500, 21.7461500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110278, 'Maciejowice', 'Maciejowice', '', 51.6922200, 21.5534200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110279, 'Jeziorzany', 'Jeziorzany', 'Jeziorzany,Lysobyki,Przetoczno,Łysobyki', 51.6024500, 22.2766700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110280, 'Łyse', 'Lyse', 'Lyse,Łyse,Лысе', 53.3644300, 21.5648700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110281, 'Łużna', 'Luzna', '', 49.7128800, 21.0463700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110282, 'Lutowiska', 'Lutowiska', 'Liutoviska,Lutowiska,Lyutoviska', 49.2531800, 22.6925200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110283, 'Lutoryż', 'Lutoryz', '', 49.9671200, 21.9124000, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110284, 'Łukowica', 'Lukowica', '', 49.6111000, 20.4828900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110285, 'Łukowa', 'Lukowa', '', 50.3742600, 22.9434900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110286, 'Łukowa', 'Lukowa', '', 50.0930000, 20.9754800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110287, 'Łuków', 'Lukow', 'Lukiv,Lukov,Lukova,Lukow,Lukuv,Lukuvas,lwqwb,ukufu,wu ku fu,Łuków,Луков,Лукув,Луків,לוקוב,ウクフ,武庫夫', 51.9290000, 22.3795600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110288, 'Ludwin', 'Ludwin', 'Comuna de Ludwin,Gmina Ljudvin,Gmina Ludwin,Ljudvin,Людвин,Ґміна Людвін', 51.3460500, 22.9058100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110289, 'Lubycza Królewska', 'Lubycza Krolewska', '', 50.3410200, 23.5194100, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110290, 'Lubomino', 'Lubomino', 'Arnsdorf,Ljubomino,Lubomino,Любомино', 54.0668400, 20.2395600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110291, 'Lubomierz', 'Lubomierz', '', 49.6085400, 20.2021400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110292, 'Lubochnia', 'Lubochnia', '', 51.6079400, 20.0539100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110293, 'Łubnice', 'Lubnice', '', 50.4116400, 21.1501400, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110294, 'Lublin', 'Lublin', 'Gorad Ljublin,LUZ,Lioblens,Lioblėns,Liublinas,Ljublin,Ljublin osh,Ljublin shaary,Loumplin,Lu-pu-lim,Lubblinu,Lublin,Lublina,Lublino,Lublinum,Lueblin,Lyublin,Lû-pu-lìm,Lüblin,lbln,lu bu lin,lub lin,lubeullin,lublina,lublini,lwblyn,ruburin,Ļubļina,Λούμπλιν,Горад Люблін,Лублин,Люблин,Люблин ош,Люблин шаары,Люблін,Լյուբլին,לובלין,لبلن,لوبلين,لوبلین,लुब्लिन,ลูบลิน,ლუბლინი,ルブリン,卢布林,盧布林,루블린', 51.2500000, 22.5666700, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110295, 'Lubenia', 'Lubenia', '', 49.9307800, 21.9266500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110296, 'Lubartów', 'Lubartow', 'Lewartow,Lewartów,Liubartuvas,Ljubartiv,Ljubartov,Ljubartuv,Lubartov,Lubartova,Lubartow,Lubartów,Lyubartov,lu ba er tu fu,lwbrtwb,Лубартов,Любартов,Любартув,Любартів,לוברטוב,盧巴爾圖夫', 51.4602600, 22.6095200, 'PL', '2013-10-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110297, 'Lubaczów', 'Lubaczow', 'Ljubachiv,Ljubachov,Ljubachuv,Lubachov,Lubacova,Lubaczow,Lubaczów,Lubačova,Lyubachev,lu ba qiu fu,Лубачов,Любачов,Любачув,Любачів,לובאצוב,盧巴丘夫', 50.1570000, 23.1233900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110298, 'Łososina Dolna', 'Lososina Dolna', '', 49.7497700, 20.6312900, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110299, 'Łosice', 'Losice', 'Gorad Lasicy,Loshice,Losice,Losicė,lwsyzh,wo xi cai,Łosice,Горад Ласіцы,Лосице,Лосіце,Лошице,לאשיץ,לושיצה,沃西采', 52.2112900, 22.7180100, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110300, 'Łopuszno', 'Lopuszno', '', 50.9486400, 20.2508100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110301, 'Łopuszna', 'Lopuszna', '', 49.4728100, 20.1302100, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110302, 'Łopuszka Wielka', 'Lopuszka Wielka', '', 49.9345400, 22.3930500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110303, 'Łopiennik Górny', 'Lopiennik Gorny', 'Lopiennik Gorny,Lopiennik Lacki,Łopiennik Górny,Łopiennik Lacki', 51.0408000, 23.0183300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110304, 'Łoniów', 'Loniow', '', 50.5644300, 21.5259900, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110305, 'Łomża', 'Lomza', 'Gorad Lomzha,Lomsa,Lomza,Lomzha,Lomža,lwmzh,u~omuja,wo mu zha,womja,wxm cha,Łomża,Горад Ломжа,Ломжа,לומזה,วอมชา,ウォムジャ,沃姆扎,웜자', 53.1780600, 22.0593500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110306, 'Łomianki', 'Lomianki', 'Lomianki,Lomjanki,wo mi an ji,Łomianki,Ломянки,Ломянкі,Ломјанки,沃米安基', 52.3341300, 20.8860200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110307, 'Łomazy', 'Lomazy', 'Lomazai,לומאזי', 51.9043500, 23.1765600, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110308, 'Łochów', 'Lochow', 'Lohova,Lokhov,Lokhuv,wo hu fu,Лохов,Лохув,沃胡夫', 52.5307600, 21.6815800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110309, 'Liw', 'Liw', 'Comuna de Liw,Gmina Liv,Gmina Liw,Liv,Livo valscius,Livo valsčius,Liw,Лив,Ґміна Лів', 52.3751500, 21.9676800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110310, 'Lisia Góra', 'Lisia Gora', '', 50.0803900, 21.0439700, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110311, 'Lipsko', 'Lipsko', 'Lips''ko,Lipsko,li pu si ke,lypsqw,Липско,Ліпсько,ליפסקו,利普斯科', 51.1595400, 21.6493300, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110312, 'Lipsk', 'Lipsk', 'Liepine,Liepinė,Lips''k,Lipsk,Lipska,li pu si ke,Липск,Ліпськ,利普斯克', 53.7331200, 23.4022500, 'PL', '2015-01-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110313, 'Lipowiec Kościelny', 'Lipowiec Koscielny', '', 53.1045900, 20.1763900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110314, 'Lipinki', 'Lipinki', 'Lipinki,Lipniki', 49.6729600, 21.2928800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110315, 'Lipnik', 'Lipnik', '', 50.7297700, 21.4938900, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110316, 'Lipnik', 'Lipnik', '', 49.7890200, 20.0845500, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110317, 'Lipnica Wielka', 'Lipnica Wielka', '', 49.7048900, 20.8684400, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110318, 'Lipnica', 'Lipnica', '', 50.2893900, 21.8881100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110319, 'Nowe Lipiny', 'Nowe Lipiny', '', 52.3578900, 21.2712500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110320, 'Limanowa', 'Limanowa', 'Limanov,Limanova,Limanowa,Limanowo,li ma nuo wa,lymnwbh,Лиманова,Ліманова,לימנובה,利馬諾瓦', 49.7059400, 20.4220400, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110321, 'Lidzbark Warmiński', 'Lidzbark Warminski', 'Heilsberg,Heilsburg,Kheyl''sberg,Licbark,Lidzbark Varminski,Lidzbark Warminski,Lidzbark Warmiński,Lidzbark-Varmin''ski,Lidzbark-Varmin''skij,Lidzbark-Varmins''kij,Lidzbarka Varminska,Lidzbarka Varmiņska,Varmes Lidzbarkas,Varmės Lidzbarkas,wa er mi ya de qu li zi ba ke,Лидзбарк Вармински,Лидзбарк Вармињски,Лидзбарк-Варминьски,Лидзбарк-Варминьский,Лідзбарк-Вармінський,瓦爾米亞地區利茲巴克', 54.1258800, 20.5795400, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110322, 'Leżajsk', 'Lezajsk', 'Lezaiskas,Lezajsk,Lezajska,Lezhajs''k,Lezhajsk,Leżajsk,Ležaiskas,Ležajska,lai zha yi si ke,lyznsq,Лежайск,Лежайськ,Лежајск,ליזנסק,莱扎伊斯克', 50.2625700, 22.4193200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110323, 'Łętownia', 'Letownia', '', 50.3248100, 22.2340100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110324, 'Lesznowola', 'Lesznowola', '', 52.0909500, 20.9347900, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110325, 'Leszno', 'Leszno', 'Leshno,Leszno,Лешно', 52.2579900, 20.5912100, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110326, 'Leśnica', 'Lesnica', '', 49.4009200, 20.0600100, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110327, 'Leśna Podlaska', 'Lesna Podlaska', 'Comuna Lesna Podlaska,Comuna Leśna Podlaska,Comuna de Lesna Podlaska,Comuna de Leśna Podlaska,Gmina Leshna-Podljas''ka,Gmina Lesna Podlaska,Gmina Leśna Podlaska,Les''na-Podljaska,Lesna,Lesna Podlaska,Leśna,Leśna Podlaska,Palenkes Lesnos valscius,Palenkės Lešnos valsčius,Лесьна-Подляска,Ґміна Лешна-Подляська', 52.1331700, 23.0278600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110328, 'Lesko', 'Lesko', 'Lesko,Lis''ko,Lisko,lai si ke,lsqw,Леско,Лісько,לסקו,莱斯科', 49.4701000, 22.3304200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110329, 'Lelkowo', 'Lelkowo', 'Lel''kovo,Lelkowo,Lichtenfeld,Лельково', 54.3245800, 20.2248000, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110330, 'Łęki Górne', 'Leki Gorne', '', 49.9738600, 21.1742600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110331, 'Łęki Dolne', 'Leki Dolne', '', 49.9738600, 21.2473900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110332, 'Łęki', 'Leki', 'Leki,Leki Strzyzowskie,Łęki,Łęki Strzyżowskie', 49.8099600, 21.6602300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110333, 'Legionowo', 'Legionowo', 'Jablonna-Legionowo,Jabłonna-Legionowo,Leg''onovo,Legionovas,Legionovo,Legionowo,Legonovo,lai ji ao nuo wo,Легионово,Легьоново,Леґьоново,萊吉奧諾沃', 52.4014900, 20.9266400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110334, 'Łęczna', 'Leczna', 'Leczna,Lenchna,Lencna,Lenčna,lnznh,wen qi na,wengchina,Łęczna,Ленчна,לנצנה,文奇納,웽치나', 51.3012100, 22.8813500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110335, 'Lecka', 'Lecka', '', 49.8786000, 22.0136800, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110336, 'Łaziska', 'Laziska', '', 51.1422600, 21.8791900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110337, 'Latowicz', 'Latowicz', '', 52.0263600, 21.8082900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110338, 'Laszki', 'Laszki', '', 50.0202000, 22.8999700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110339, 'Łaszczów', 'Laszczow', 'Laszcow,Laszczow,Laszozow,Łaszczów,Łaszców,Łaszozow', 50.5333200, 23.7256200, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110340, 'Laskowa', 'Laskowa', '', 49.7614700, 20.4504500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110341, 'Łaskarzew', 'Laskarzew', 'Laskarzew,Laskazeva,Laskazhev,Laskaževa,lsqzb,wa si ka re fu,Łaskarzew,Ласкажев,לסקזב,瓦斯卡熱夫', 51.7899300, 21.5912200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110342, 'Łapy', 'Lapy', 'Lapi,Lapiai,Lapy,Zieciuki,Zięciuki,wa pei,wapi,Łapy,Лапи,Лапы,ワピ,瓦佩', 52.9911000, 22.8842200, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110343, 'Łapsze Niżne', 'Lapsze Nizne', '', 49.3980700, 20.2434300, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110344, 'Łapczyca', 'Lapczyca', 'Lapczyca,Lapczyce,Łapczyca,Łapczyce', 49.9599400, 20.3844500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110345, 'Łapanów', 'Lapanow', '', 49.8653800, 20.2914900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110346, 'Łańcut', 'Lancut', 'Lan''cut,Lancut,Lancuta,Laņcuta,lnzwt,wan chu te,Łańcut,Ланцут,Ланьцут,Лањцут,לאנצהוט,לנצוט,萬楚特', 50.0687100, 22.2291200, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110347, 'Łajski', 'Lajski', 'Lajsk,Lajski,Łajsk,Łajski', 52.4287300, 20.9494600, 'PL', '2016-05-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110348, 'Łagów', 'Lagow', 'Laguv,lgwb,Лагув,לגוב', 50.7751700, 21.0843100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110349, 'Łączna', 'Laczna', '', 51.0023100, 20.7971200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110350, 'Łącko', 'Lacko', '', 49.5575700, 20.4358600, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110351, 'Łabunie', 'Labunie', '', 50.6551700, 23.3662000, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110352, 'Łabowa', 'Labowa', '', 49.5276600, 20.8549700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110353, 'Kuźnica', 'Kuznica', 'Kuznica,Kuznica Bialost,Кузница', 53.5109400, 23.6495300, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110354, 'Kuryłówka', 'Kurylowka', 'Kurylowka,Kuryłówka', 50.2997600, 22.4660100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110355, 'Kurów', 'Kurow', 'Curov - Kurow,Curovia,Curóv - Kurów,Khu-lu-fu,Khù-lû-fû,Ko-lu-hu,Kourov,Kourovu,Kuriv,Kurou,Kurov,Kurova,Kurow,Kuruv,Kuruv vele,Kuruvas,Kuruvs,Kuruw,Kuròw,Kurów,Kurůw,Kó-lū-hŭ,Vjoska Kurau,khu ruf,ku lu fu,ku lu fu shi,kulupeu,kuraau,kurabha,kureav,kuropha,kurov,kurova,kuruf,kurufa,kurufu,kurupha,kwrwf,kwrwp,qwrwb,qwrwp,qʼryww,rwstay kwrw,Κουρόβ,Κούροβ,Вёска Кураў,Коуровъ,Куров,Курув,Курув веле,Курів,Կուրուվ,קאריוו,קורוב,روستای کورو,كوروف,کوروف,کوروۆ,ܟܘܪܘܦ,ܩܘܪܘܦ,ކުރޫފް,कुरुफ,कुरुफ़,कुरोव्,কুরভ,কুৰৌ,ਕੂਰੋਫ,કુરોવ,குரோவ்,కురోవ్,ಕುರೊವ್,കുറൊവ്,කරෆ,කුරුෆ්,คูรูฟ,ຄູໂຣ,ကူးရိုးရွာ,კუროვი,ኩሩቭ,クルフ,库鲁夫,库鲁夫市,庫魯夫,庫魯夫市,쿠루프,', 51.3894100, 22.1863700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110356, 'Kunów', 'Kunow', 'Kunov,Kunow,Kunuv,Kunów,ku nu fu,qwnwb,Кунов,Кунув,קונוב,庫努夫', 50.9615600, 21.2805800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110357, 'Kuczbork-Osada', 'Kuczbork-Osada', '', 53.0861900, 20.0478200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110358, 'Księżpol', 'Ksiezpol', 'Comuna de Ksiezpol,Comuna de Księżpol,Gmina Ksenzhpol'',Gmina Ksiezpol,Gmina Księżpol,Ksenzhpol'',Ксенжполь,Ґміна Ксенжполь', 50.4232300, 22.7352600, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110359, 'Księżomierz', 'Ksiezomierz', '', 50.9085500, 21.9896500, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110360, 'Krzywda', 'Krzywda', '', 51.7951900, 22.1999400, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110361, 'Krzywcza', 'Krzywcza', '', 49.7989400, 22.5454900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110362, 'Krzynowłoga Mała', 'Krzynowloga Mala', '', 53.1577300, 20.7857900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110363, 'Krzeszów', 'Krzeszow', 'Krzeszow,Krzeszów', 50.4038100, 22.3424100, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110364, 'Krzemienica', 'Krzemienica', '', 50.0621000, 22.1805400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110365, 'Krzeczowice', 'Krzeczowice', '', 49.9892000, 22.4637800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110366, 'Krzeczów', 'Krzeczow', '', 49.9887600, 20.4877900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110367, 'Krynki', 'Krynki', 'Gorad Krynki,Krinkai,Krinki,Krynki,ke lun ji,qrynqy,Горад Крынкі,Кринки,Кринкі,Крынки,קרינקי,克倫基', 53.2644400, 23.7730400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110368, 'Krynice', 'Krynice', '', 50.5876000, 23.3815700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110369, 'Krynica-Zdrój', 'Krynica-Zdroj', 'Krinica-Zdroj,Krinica-Zdruj,Krinicazdroja,Krinicja-Zdruj,Kriņicazdroja,Krynica,Krynica Zdroj,Krynica Zdrój,Krynica-Zdruj,ke lei ni cha-zi de lu yi,qrynyzh zdrwy,Криница-Здруй,Криниця-Здруй,Крињица-Здрој,Крыница-Здруй,קריניצה זדרוי,კრინიცა-ზდრუი,克雷尼察-茲德魯伊', 49.4222500, 20.9594200, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110370, 'Kruklanki', 'Kruklanki', 'Kruglanken,Kruklanki,Krukljanki,Круклянки', 54.0885500, 21.9222700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110371, 'Krosno', 'Krosno', 'Gorad Krosna,Korosno,Krosnas,Krosno,ke luo si nuo,keuloseuno,qrwsnw,Горад Кросна,Коросно,Кросно,קרוסנו,克羅斯諾,크로스노', 49.6886600, 21.7705800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110372, 'Krośnica', 'Krosnica', '', 49.4478700, 20.3395600, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110373, 'Krościenko Wyżne', 'Kroscienko Wyzne', '', 49.6794600, 21.8289800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110374, 'Krempna', 'Krempna', 'Krempna,Krepna,Krępna', 49.5112800, 21.5004200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110375, 'Krasocin', 'Krasocin', '', 50.8887400, 20.1186300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110376, 'Krasnystaw', 'Krasnystaw', 'Gorad Krasnystau,Krasnistav,Krasnistava,Krasnostav,Krasnystav,Krasnystavas,Krasnystaw,ke la si nei si ta fu,qrsnystb,Горад Красныстаў,Краснистав,Красностав,Красныстав,קרסניסטב,克拉斯內斯塔夫', 50.9846400, 23.1742000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110377, 'Krasnosielc', 'Krasnosielc', 'Krasnosel''c,Krasnosielc,Красносельц,קראסנושיילץ', 53.0337800, 21.1573500, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110378, 'Krasnopol', 'Krasnopol', 'Comuna de Krasnopol,Gmina Krasnopol,Gmina Krasnopol'',Krasnapolio valscius,Krasnapolio valsčius,Krasnopol,Krasnopol'',Krasnopolis,Краснополь,Ґміна Краснополь', 54.1161300, 23.2047600, 'PL', '2015-01-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110379, 'Krasnobród', 'Krasnobrod', 'Krasnobrod,Krasnobroda,Krasnobrud,Krasnobród,ke la si nuo bu lu de,Красноброд,Краснобруд,קראסנוברוד,克拉斯諾布魯德', 50.5455100, 23.2130800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110380, 'Kraśnik', 'Krasnik', 'Krashnik,Krasnik,Krasnika,Krasnikas,Krasņika,Kraśnik,ke la xi ni ke,qrsnyq,Красник,Красњик,Крашник,קרשניק,克拉希尼克', 50.9236000, 22.2270600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110381, 'Kraśniczyn', 'Krasniczyn', '', 50.9317100, 23.3492900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110382, 'Krasne', 'Krasne', '', 52.9240100, 20.9673200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110383, 'Krasne', 'Krasne', '', 50.0562600, 22.0863800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110384, 'Krasiczyn', 'Krasiczyn', '', 49.7764400, 22.6525200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110385, 'Kramarzówka', 'Kramarzowka', '', 49.8603400, 22.5013700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110386, 'Kraczkowa', 'Kraczkowa', '', 50.0379600, 22.1680100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110387, 'Kozubszczyzna', 'Kozubszczyzna', '', 51.2232300, 22.4274700, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110388, 'Kozłowo', 'Kozlowo', 'Gross Koslau,Grosskosel,Kozlowo,Kozłowo', 53.3065200, 20.2909800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110389, 'Kozłów', 'Kozlow', '', 50.4839400, 20.0245600, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110390, 'Kozienice', 'Kozienice', 'Kozenicai,Kozenice,Kozenitse,Kozeņice,Kozhenice,Kozienice,Kozjenice,ke jie ni cai,qwzynyzh,Коженице,Козенице,Козеніце,Козјењице,קאזשניץ,קוזיניצה,科傑尼采', 51.5829400, 21.5477900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110391, 'Kowiesy', 'Kowiesy', '', 51.8894200, 20.4192900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110392, 'Kowale Oleckie', 'Kowale Oleckie', 'Kovale-Olecki,Kowahlen,Kowahlen Kreis Treuburg,Kowale,Kowale Oleckie,Reimannswalde,Ковале-Олецки', 54.1635400, 22.4166600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110393, 'Kowala', 'Kowala', 'Kowala-Stepocina (do 1999),Kowala-Stępocina (do 1999)', 51.3250300, 21.0697200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110394, 'Kotuń', 'Kotun', 'Kotun,Kotun'',Kotuń,Котунь', 52.1764300, 22.0681900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110395, 'Koszyce', 'Koszyce', '', 49.9722600, 20.9416600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110396, 'Kostomłoty Pierwsze', 'Kostomloty Pierwsze', 'Kostomloty Pierwsze,Kostomłoty Pierwsze,Zamlynie Kostomloty,Zamłynie Kostomłoty', 50.9232200, 20.5949000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110397, 'Kostomłoty Drugie', 'Kostomloty Drugie', 'Kostomloty,Kostomłoty', 50.9268400, 20.5652900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110398, 'Kosów Lacki', 'Kosow Lacki', 'Kosov Lacki,Kosova Lacka,Kosow,Kosow Lacki,Kossow,Kossów,Kosuv Lackai,Kosuv-Ljac''kij,Kosuv-Ljacki,Kosów,Kosów Lacki,Косов Лацки,Косув-Ляцки,Косув-Ляцький,קוסוב לאצקי', 52.5954100, 22.1470700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110399, 'Kosina', 'Kosina', '', 50.0721300, 22.3290300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110400, 'Korzenna', 'Korzenna', 'Korzenna', 49.6863500, 20.8435500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110401, 'Korytnica', 'Korytnica', 'Korytnica,Корытница', 52.4144100, 21.8494900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110402, 'Kortowo', 'Kortowo', 'Kortau', 53.7573100, 20.4562000, 'PL', '2012-11-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110403, 'Korsze', 'Korsze', 'Korschen,Korse,Korshe,Korsz,Korsze,Korše,ke er xie,Корше,科爾謝', 54.1700200, 21.1391500, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110404, 'Stara Kornica', 'Stara Kornica', 'Kornica Stara,Stara-Kornica,SteraKornica,Стара-Корница', 52.1818300, 22.9375200, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110405, 'Korczyna', 'Korczyna', '', 49.7155500, 21.8094100, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110406, 'Korczew', 'Korczew', 'Korchev,Korczew,Корчев', 52.3532700, 22.6133800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110407, 'Koprzywnica', 'Koprzywnica', 'Koprzywinica,Kopshivnica,Kopshivnicja,Kopsivnica,Kopšivņica,qwpsywwnyzh,Копшивница,Копшивниця,Копшивњица,פאקשיווניץ,קופשיווניצה', 50.5934000, 21.5838000, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110408, 'Konstantynów', 'Konstantynow', 'Konstantynow,Konstantynuv,Konstantynów,Константынув', 52.2074600, 23.0853000, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110409, 'Konstancin-Jeziorna', 'Konstancin-Jeziorna', 'Konstanchin-Jezh''orna,Konstancin-Ez''orna,Konstancin-Ezerna,Konstancin-Ezjorna,Konstancin-Jeziorna,Konstancin-Jezjorna,Konstancina-Jezjorna,Kunstancin-Jezorno,Kůnstanćin-Jeźorno,Skolimow-Konstancin,Skolimów-Konstancin,kang si tan qin-ye jiao er na,Констанцин-Єзьорна,Констанцин-Езерна,Констанцин-Езёрна,Констанчин-Йежьорна,Констанћин-Језјорна,康斯坦欽-耶焦爾納', 52.0938000, 21.1176100, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110410, 'Końskowola', 'Konskowola', 'Kon''skovola,Kon''skovolja,Kon''skovolja vele,Koniskovolia,Kons''kovolja,Konskovol,Konskovola,Konskovole,Konskovolia,Konskovolja,Konskovolya,Konskovolâ,Konskovolė,Konskowola,Końskowola,Koņskovola,Kɔnyskɔvɔla,Vjoska Kan''skavolja,guan shi ge wo na,kaniyaskabhala,kanskavala,keanskeaveala,khxn skx wx la,koinseukobolla,kong si ke wo la,konskobhola,konskovola,ko~insukovu~ora,kwnskwwla,qwnsqwbwlh,Κονσκοβόλα,Вёска Каньскаволя,Конисковолиа,Консковол,Консковоля,Конськоволя,Коньсковола,Коньсковоля,Коньсковоля веле,Кон҄ьсковолꙗ,Коњсковола,Քոնսքօուօլա,קאנסקאוואלע,קונסקובולה,كونسكوولا,کونسکوولا,کونسکووه‌لا,ܩܘܢܣܩܘܒܘܠܐ,ކޮންސްކޮވޯލާ,कॉन्स्कोवोला,कोंस्कोवोला,कोन्स्कोभोला,कोन्स्कोवोला,কনিয়স্কভলা,ਕਞ੍ਸ੍ਕਵਲਾ,કઞ્સ્કવલા,கோன்ஸ்கோவோலா,కొన్‌స్కొవొలా,ಕೊನ್‌ಸ್ಕೊವೊಲಾ,കൊന്സ്കൊവൊല,කෝඤ්ශ්කෝවෝලා,คอนสกอวอลา,ໂກຣິສໂກໂວລາ,კონსკოვოლა,ኮኝስኮቮላ,コィンスコヴォラ,孔斯科沃拉,官士哥窩拿,코인스코볼라,', 51.4092200, 22.0517500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110411, 'Końskie', 'Konskie', 'Comuna de Konskie,Comuna de Końskie,Gmina Kons''ke,Gmina Konskie,Gmina Końskie,Kon''ske,Konsk,Konskie,Końskie,Коньске,Ґміна Конське', 51.1916600, 20.4060700, 'PL', '2010-10-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110412, 'Konieczkowa', 'Konieczkowa', '', 49.8420800, 21.9282000, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110413, 'Kończyce', 'Konczyce', '', 50.4257500, 22.1537600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110414, 'Komorów', 'Komorow', '', 52.1456000, 20.8156600, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110415, 'Komarówka Podlaska', 'Komarowka Podlaska', '', 51.8031500, 22.9439200, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110416, 'Komarów-Osada', 'Komarow-Osada', '', 50.6287800, 23.4937500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110417, 'Komańcza', 'Komancza', 'Koman''cha,Komancha,Команча,Команьча', 49.3392200, 22.0616600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110418, 'Kolno', 'Kolno', 'Kol''no,Kolnas,Kolno,ke er nuo,qwlnh,Колно,Кольно,קולנה,科爾諾', 53.4114800, 21.9290500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110419, 'Kolbuszowa', 'Kolbuszowa', 'Kol''bushova,Kolbushova,Kolbusova,Kolbušova,ke er bu shao wa,qwlbwswbh,Колбушова,Кольбушова,קאלבאסאוו,קולבושובה,科爾布紹瓦', 50.2441000, 21.7761000, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110420, 'Kołbiel', 'Kolbiel', 'Kolbel'',Kolbiel,Kołbiel,Колбель', 52.0643100, 21.4815300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110421, 'Kołaczyce', 'Kolaczyce', 'Kolachice,Kolacice,Kolaczyce,Kolačice,Kołaczyce,Колачице,קולאציצה', 49.8074300, 21.4340700, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110422, 'Kokotów', 'Kokotow', '', 50.0125400, 20.0782900, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110423, 'Kodeń', 'Koden', '', 51.9117100, 23.6030100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110424, 'Kock', 'Kock', 'Koc''k,Kock,Kocka,ke ci ke,kwk,qwzq,Коцк,Коцьк,קוצק,كوك,科茨克', 51.6399700, 22.4439100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110425, 'Kobyłka', 'Kobylka', 'Kobilka,Kobylka,ke bei wu ka,Кобилка,Кобылка,科貝烏卡', 52.3395300, 21.1958900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110426, 'Kobylanka', 'Kobylanka', '', 49.6689100, 21.2229300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110427, 'Knyszyn', 'Knyszyn', 'Gorad Knyshyn,Knishin,Knisina,Knisinas,Knišina,Knišinas,Knyshin,Knyszyn,ke nei shen,qnysyn,Горад Кнышын,Книшин,Кнышин,קנישין,克內申', 53.3140600, 22.9196300, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110428, 'Klwów', 'Klwow', '', 51.5344800, 20.6364400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110429, 'Kluszkowce', 'Kluszkowce', '', 49.4510000, 20.3017900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110430, 'Kłoczew', 'Kloczew', '', 51.7213400, 21.9649300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110431, 'Klimontów', 'Klimontow', '', 50.6558800, 21.4558700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110432, 'Klimontów', 'Klimontow', '', 50.2284300, 20.3199000, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110433, 'Kleszczele', 'Kleszczele', 'Klescele,Kleshchele,Kleshcheli,Klesheli,Kleshhele,Kleszczele,Kleščele,Kleščelė,Klishheli,ke lai shen qie lai,qlszlh,Клешчеле,Клещеле,Кліщелі,קלשצלה,克萊什切萊', 52.5731400, 23.3253900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110434, 'Klembów', 'Klembow', 'Klembow,Klembow Koscielny,Klembów,Klembów Kościelny', 52.4065000, 21.3317600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110435, 'Kłaj', 'Klaj', '', 49.9924600, 20.2990400, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110436, 'Kije', 'Kije', 'Baljaght Kije,Comuna de Kije,Gmina Kie,Gmina Kije,Kije,Кийе,Ґміна Кіє', 50.6072100, 20.5712100, 'PL', '2010-10-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110437, 'Kiełpin', 'Kielpin', '', 52.3579600, 20.8621400, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110438, 'Kielce', 'Kielce', 'Gorad Kel''cy,Kel''ce,Kel''tsy,Kelcai,Kelce,Khai-ngi-chhai,Khái-ngì-chhái,Kielce,Kjelce,QKI,kai er cai,kielche,kyerutsu~e,kylch,kylsy,kylts,qyylzh,Горад Кельцы,Келце,Кельце,Кјелце,Кјељце,קיילצה,קעלץ,كيلسي,کیئلتسہ,کیلتس,کیلچ,კელცე,キェルツェ,凯尔采,키엘체', 50.8703300, 20.6275200, 'PL', '2016-03-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110439, 'Kielanówka', 'Kielanowka', '', 50.0261600, 21.9290500, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110440, 'Kętrzyn', 'Ketrzyn', 'Kentshin,Kentsina,Kentsynas,Kentšina,Kentšynas,Ketrzyn,Ketzyn,Kętrzyn,Rastembork,Rastenburg,ken qin,kengteusin,kentoshin,kntshyn,kyntshn,Кентшин,کنتشین,کینتشن,ケントシン,肯琴,켕트신', 54.0767600, 21.3752700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110441, 'Kępie Żaleszańskie', 'Kepie Zaleszanskie', 'Kepie,Kepie Zaleszanskie,Kępie,Kępie Żaleszańskie', 50.6398300, 21.8813300, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110442, 'Kazimierz Dolny', 'Kazimierz Dolny', 'Kazimezdolni,Kazimezh-Dol''ni,Kazimezh-Dol''ny,Kazimeždolni,Kazimierz,Kazimierz Dolny,Kazimjezh Dolni,ka qi mi ri duo er ni,qzymyyz dwlny,Казимеж-Дольны,Казимјеж Долни,Казімеж-Дольни,קזימייז דולני,卡齊米日多爾尼', 51.3191100, 21.9550200, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110443, 'Kazimierza Wielka', 'Kazimierza Wielka', 'Kazhimezha Velka,Kazimeza Velka,Kazimezha-Vel''ka,Kazimezha-Velika,Kazimeža Velka,Kazimierza Wielka,Kazimjezha Vjelka,qzymyyzh wyylqh,Кажимежа Велка,Казимежа-Велька,Казимјежа Вјелка,Казімежа-Велика,קזימייזה ויילקה', 50.2656400, 20.4935800, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110444, 'Kazanów', 'Kazanow', '', 51.2759300, 21.4673700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110445, 'Kawęczyn Nowy', 'Kaweczyn Nowy', 'Kaweczyn,Kaweczyn Nowy,Kawęczyn,Kawęczyn Nowy,Nowy Kaweczyn,Nowy Kawęczyn', 51.8859700, 20.2470300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110446, 'Kasina Wielka', 'Kasina Wielka', 'Kasina Wielka,Kosina Wielka', 49.7296900, 20.1355400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110447, 'Karniewo', 'Karniewo', 'Karnevo,Karniewo,Карнево', 52.8370000, 20.9888600, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110448, 'Karczmiska', 'Karczmiska', '', 51.2295200, 21.9815800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110449, 'Karczew', 'Karczew', 'Karceva,Karchev,Karčeva,ka er qie fu,Карчев,קארצב,卡爾切夫', 52.0765500, 21.2496200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110450, 'Kaniów', 'Kaniow', '', 50.9857700, 20.6639100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110451, 'Kańczuga', 'Kanczuga', 'Kan''chuga,Kanchuga,Kancuga,Kanczuga,Kańczuga,Kaņčuga,kan qiu jia,qnzwgh,Канчуга,Каньчуга,Кањчуга,קנצוגה,坎丘加', 49.9834600, 22.4116800, 'PL', '2017-07-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110452, 'Kampinos', 'Kampinos', 'Kampinos,Кампинос', 52.2683700, 20.4630700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110453, 'Kamionka Wielka', 'Kamionka Wielka', '', 49.5684800, 20.8236400, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110454, 'Kamionka', 'Kamionka', '', 51.4716500, 22.4627500, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110455, 'Kamienica', 'Kamienica', '', 49.5753300, 20.3450500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110456, 'Kamień', 'Kamien', '', 50.3406400, 22.1353900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110457, 'Kałuszyn', 'Kaluszyn', 'Kalushin,Kalusina,Kaluszyn,Kalušina,Kałuszyn,ka wu shen,Калушин,קאלושין,卡武申', 52.2066900, 21.8083800, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110458, 'Kadzidło', 'Kadzidlo', 'Kadzidlo,Kadzidło,Кадзидло', 53.2343500, 21.4645400, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110459, 'Kabaty', 'Kabaty', 'Kabaty', 52.1301200, 21.0814800, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110460, 'Józefów', 'Jozefow', '', 52.1944600, 20.6959200, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110461, 'Józefów', 'Jozefow', 'Jozefov,Juzefova,Juzefuv,yue se fu wu,ywzpwb,Јозефов,Юзефув,יוזפוב,約瑟夫烏', 52.1370700, 21.2358900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110462, 'Józefów nad Wisłą', 'Jozefow nad Wisla', 'Comuna de Jozefow nad Wisla,Comuna de Józefów nad Wisłą,Gmina Jozefow nad Wisla,Gmina Juzefuv-nad-Visloju,Gmina Józefów nad Wisłą,Juzefuv-nad-Vislon,Юзефув-над-Вислон,Ґміна Юзефув-над-Віслою', 51.0418300, 21.8301800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110463, 'Józefów', 'Jozefow', 'Jozefov,Jozefow,Juzefova,Juzefuv,Józefów,yue se fu wu,ywzpwb,Јозефов,Юзефув,יוזפוב,約瑟夫烏', 50.4811900, 23.0540400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110464, 'Józefosław', 'Jozefoslaw', '', 52.1005000, 21.0462900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110465, 'Jonkowo', 'Jonkowo', 'Jonkendorf,Jonkovo,Jonkowo,Йонково', 53.8281700, 20.3105400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110466, 'Joniec', 'Joniec', '', 52.6012800, 20.5817700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110467, 'Jodłówka', 'Jodlowka', '', 49.9929500, 20.5482100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110468, 'Jodłówka', 'Jodlowka', '', 49.8943000, 22.4665300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110469, 'Jodłowa', 'Jodlowa', '', 49.8722900, 21.2789700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110470, 'Jeżowe', 'Jezowe', '', 50.3748600, 22.1274900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110471, 'Jeziorany', 'Jeziorany', 'Ez''orani,Ezerany,Ezjorany,Jeziorany,Jezjorani,Seeburg,ye jiao la nei,Єзьорани,Језјорани,Езераны,Езёраны,耶焦拉內', 53.9757800, 20.7463900, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110472, 'Jedwabno', 'Jedwabno', 'Edvabno,Gedwangen,Jedwabno,Едвабно', 53.5299000, 20.7265700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110473, 'Jedwabne', 'Jedwabne', 'Edvabne,Jedvabnas,Jedvabne,Jedwabne,ydwwbnh,ye de wa bu nei,Єдвабне,Једвабне,Едвабне,Йедвабне,ידוובנה,יעדוואבנע,耶德瓦布內', 53.2855400, 22.3035300, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110474, 'Jędrzejów', 'Jedrzejow', 'Comuna de Jedrzejow,Comuna de Jędrzejów,Endzhejuv,Gmina Endzhejuv,Gmina Jedrzejow,Gmina Jędrzejów,Yendzheyev,Гміна Єнджеюв,Енджеюв', 50.6394500, 20.3045400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110475, 'Jednorożec', 'Jednorozec', 'Ednorozhec,Jednorozec,Jednorożec,Еднорожец', 53.1411600, 21.0516100, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110476, 'Jedlnia-Letnisko', 'Jedlnia-Letnisko', '', 51.4307400, 21.3353600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110477, 'Jedlińsk', 'Jedlinsk', 'Comuna de Jedlinsk,Comuna de Jedlińsk,Edlin''sk,Gmina Edlins''k,Gmina Jedlinsk,Gmina Jedlińsk,Jedlinsk,Jedlińsk,Гміна Єдлінськ,Едлиньск', 51.5140000, 21.1157700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110478, 'Jedlicze', 'Jedlicze', 'Edliche,Jedlice,Jedliche,Jedlicze,Jedliče,ye de li qie,Єдліче,Једличе,Едличе,Йедличе,耶德利切', 49.7174900, 21.6488600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110479, 'Jawornik Polski', 'Jawornik Polski', '', 49.8908200, 22.2886800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110480, 'Jawornik', 'Jawornik', '', 49.8464000, 21.8940400, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110481, 'Jastrzębia', 'Jastrzebia', '', 51.4974200, 21.2370900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110482, 'Jastrzębia', 'Jastrzebia', '', 49.7973300, 20.8808900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110483, 'Jastrząb', 'Jastrzab', '', 51.2472500, 20.9475800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110484, 'Jastków', 'Jastkow', '', 51.3041100, 22.4354600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110485, 'Jasło', 'Jaslo', 'Gorad Jasla,Jaslas,Jaslo,Jasto,Jasło,Yaslo,ya si wo,ysww,Јасло,Горад Ясла,Ясло,יאסלו,یسوو,亚斯沃', 49.7450600, 21.4725200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110486, 'Jaśliska', 'Jasliska', 'Jaslis''ka,jaslaska,Яслиська,יאשליסק,جاسلاسکا', 49.4422900, 21.8079500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110487, 'Jasionów', 'Jasionow', '', 49.6584100, 21.9767800, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110488, 'Jasieniec', 'Jasieniec', '', 51.8210400, 20.9409900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110489, 'Jasienica Rosielna', 'Jasienica Rosielna', 'Jasienica,Jasienica Rosielna', 49.7514400, 21.9417600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110490, 'Jasienica', 'Jasienica', '', 52.4141500, 21.4115000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110491, 'Jasień', 'Jasien', '', 49.9698800, 20.5719000, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110492, 'Jarosław', 'Jaroslaw', 'Jaroslau,Jaroslav,Jaroslava,Jaroslavas,Jaroslaw,Jarosław,Yaroslav,jarwswaw,ya luo si wa fu,yrwslb,Јарослав,Ярослав,ירוסלב,جاروسواو,雅罗斯瓦夫', 50.0162300, 22.6777600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110493, 'Jarocin', 'Jarocin', 'Jarocin,Jarotin,jrwkn  pwdkrpkkyy swbہ,Яротин,Яроцин,جروکن، پودکرپککئی صوبہ', 50.5645900, 22.3212100, 'PL', '2016-01-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110494, 'Jarczów', 'Jarczow', '', 50.4243800, 23.5857600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110495, 'Janów Podlaski', 'Janow Podlaski', 'Janow Podlaski,Januv-Podljaski,Janów Podlaski,Янув-Подляски', 52.1939800, 23.2121800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110496, 'Janów Lubelski', 'Janow Lubelski', 'Janiv-Ljubel''s''kij,Janov Ljubelski,Janov Lubelski,Janova Lubelska,Janow,Janow Lubelski,Januv-Ljubel''skij,Janów,Janów Lubelski,jnww lblsky,lu bu lin de qu ya nu fu,Јанов Лубелски,Янов Любелски,Янув-Любельский,Янів-Любельський,جنوو لبلسکی,盧布林地區亞努夫', 50.7069500, 22.4103900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110497, 'Janowiec', 'Janowiec', 'Janowiec,Janowiec nad Wista,Janowiec nad Wistą', 51.3235900, 21.8894000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110498, 'Janowice', 'Janowice', '', 49.8915400, 20.8608100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110499, 'Janów', 'Janow', 'Janow,Januv,Januvas,Janów,Янув,יאנוב,جنوو، پودلسکئی صوبہ', 53.4674700, 23.2305200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110500, 'Jakubowice Murowane', 'Jakubowice Murowane', '', 51.2699200, 22.6341500, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110501, 'Jakubów', 'Jakubow', '', 52.2196500, 21.6803200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110502, 'Jagiełła', 'Jagiella', 'Jagiela,Jagiella,Jagieła,Jagiełła', 50.0946000, 22.5726100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110503, 'Jadowniki Mokre', 'Jadowniki Mokre', '', 50.1654600, 20.7284500, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110504, 'Jadowniki', 'Jadowniki', 'جدوونیکی، لیسسر پولینڈ صوبہ', 49.9588400, 20.6443400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110505, 'Jadów', 'Jadow', 'Jadow,Jaduv,Jadów,Ядув', 52.4784900, 21.6319900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110506, 'Jabłonna Lacka', 'Jablonna Lacka', '', 52.4766400, 22.4422800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110507, 'Jabłonna', 'Jablonna', '', 52.3788500, 20.9174500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110508, 'Jabłonna', 'Jablonna', 'Jablonna Pierwsza (do 1999),Jabłonna Pierwsza (do 1999)', 51.0887500, 22.5936400, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110509, 'Jabłonka', 'Jablonka', '', 49.6941700, 22.1156500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110510, 'Jabłonica Polska', 'Jablonica Polska', '', 49.6978400, 21.8996100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110511, 'Jabłoń', 'Jablon', '', 51.7250100, 23.0874300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110512, 'Izbica', 'Izbica', 'Izbica,איזביצה,איזשביצע', 50.8872800, 23.1524800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110513, 'Iwonicz-Zdrój', 'Iwonicz-Zdroj', 'Ivonich-Zdroj,Ivonich-Zdruj,Ivoniczdroja,Ivoņičzdroja,Iwonicz Zdroj,Iwonicz Zdrój,yi wo ni qi-zi de lu yi,Івонич-Здруй,Ивонич-Здруй,Ивоњич-Здрој,伊沃尼奇-茲德魯伊', 49.5631900, 21.7899200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110514, 'Iwkowa', 'Iwkowa', '', 49.8171600, 20.5901800, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110515, 'Iwierzyce', 'Iwierzyce', '', 50.0295800, 21.7539600, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110516, 'Iwaniska', 'Iwaniska', 'איווניסקה', 50.7314600, 21.2806000, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110517, 'Inowłódz', 'Inowlodz', '', 51.5271700, 20.2230000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110518, 'Imielno', 'Imielno', '', 50.5856900, 20.4481300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110519, 'Iłża', 'Ilza', 'Ilza,Ilzha,Ilža,Iłża,yi wu zha,ʼylzh,Ілжа,Илжа,אילזה,伊烏扎', 51.1631300, 21.2397900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110520, 'Iłów', 'Ilow', 'אילוב', 52.3395300, 20.0273000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110521, 'Hyżne', 'Hyzne', 'Hyzne,Hyżne', 49.9176900, 22.1813100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110522, 'Husów', 'Husow', 'Husow,Hussow,Hussów,Husów', 49.9797100, 22.2864500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110523, 'Humniska', 'Humniska', '', 49.6750700, 22.0536800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110524, 'Hrubieszów', 'Hrubieszow', 'Gorad Grubeshau,Grubeshev,Grubeshiv,Grubeshov,Grubeshuv,Hrubesova,Hrubešova,Hrubieszow,Hrubieszów,Khrubeshov,Khrubeshuv,Khrubjeshov,he lu bie shu fu,hrwbyyswb,Горад Грубешаў,Грубешів,Хрубешов,Хрубешув,Хрубјешов,הרוביישוב,赫魯別舒夫', 50.8050200, 23.8925100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110525, 'Horyniec-Zdrój', 'Horyniec-Zdroj', 'Horyniec,Horyniec Zdroj,Horyniec Zdrój', 50.1915200, 23.3627700, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110526, 'Horodło', 'Horodlo', 'Horodlo,Horodło', 50.8945900, 24.0372300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110527, 'Hornówek', 'Hornowek', '', 52.2863800, 20.8079300, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110528, 'Harasiuki', 'Harasiuki', 'Harasinki,Harasiuki', 50.4751500, 22.4728800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110529, 'Hańsk', 'Hansk', '', 51.4128600, 23.3994200, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110530, 'Handzlówka', 'Handzlowka', '', 49.9952700, 22.2231100, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110531, 'Halinów', 'Halinow', 'Halinova,Khalinov,Khalinuv,ha li nu fu,Халинов,Халинув,Халінув,哈利努夫', 52.2288000, 21.3551000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110532, 'Hajnówka', 'Hajnowka', 'Gajnivka,Gorad Gajnauka,Hainuvka,Hajnowka,Hajnuvka,Hajnówka,Khajnovka,Khajnuvka,ha yi nu fu ka,Гайнівка,Горад Гайнаўка,Хайновка,Хайнувка,Хајновка,哈伊努夫卡', 52.7432800, 23.5812200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110533, 'Haczów', 'Haczow', 'hachyf,هاچیف', 49.6615200, 21.8979000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110534, 'Gzy', 'Gzy', '', 52.7404500, 20.9437200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110535, 'Gwoźnica Górna', 'Gwoznica Gorna', '', 49.8279100, 21.9977200, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110536, 'Guzów', 'Guzow', 'Guzow,Guzuv,Guzów,Гузув', 52.1162600, 20.3367200, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110537, 'Grzybowa Góra', 'Grzybowa Gora', '', 51.1332600, 20.9617400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110538, 'Grzęska', 'Grzeska', '', 50.0830300, 22.4539900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110539, 'Grybów', 'Grybow', 'Gribiv,Gribov,Gribova,Grybow,Grybuv,Grybów,ge lei bu fu,grybwb,Грибов,Грибів,Грыбув,גריבאוו,גריבוב,格雷布夫', 49.6243900, 20.9479700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110540, 'Gruszów Wielki', 'Gruszow Wielki', 'Gruszow,Gruszow Wielki,Gruszów,Gruszów Wielki', 50.1916300, 21.0314400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110541, 'Grudusk', 'Grudusk', 'Grudusk,Грудуск', 53.0584500, 20.6249400, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110542, 'Grudki', 'Grudki', 'Grodek,Grudek,Grudki,Gródek,Грудек', 53.0948800, 23.6684800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110543, 'Gromnik', 'Gromnik', '', 49.8384300, 20.9612300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110544, 'Grójec', 'Grojec', 'Grojec,Gruec,Gruec'',Grujeca,Grójec,ge lu ye ci,grwyyz,Гройец,Гројец,Груец,Груєць,גרוייץ,גריצע,格魯耶茨', 51.8625200, 20.8675700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110545, 'Grodzisko Górne', 'Grodzisko Gorne', 'Grodzisko Gorne,Grodzisko Górne', 50.1869000, 22.4378600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110546, 'Grodzisko Dolne', 'Grodzisko Dolne', '', 50.1623800, 22.4629200, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110547, 'Grodzisk Mazowiecki', 'Grodzisk Mazowiecki', 'Grodzhisk Mazovecki,Grodzis''k-Mazovec''kij,Grodzisk,Grodzisk Mazowiecki,Grodzisk-Mazovecki,Grodzisk-Mazoveckij,Grodzisk-Mazovetskiy,Grodziska Mazovecka,Mazovijos Grodziskas,grwdzysq mzwbyyzqy,ma zuo fu she de qu ge luo ji si ke,Гроджиск Мазовецки,Гродзиск-Мазовецки,Гродзиск-Мазовецкий,Гродзиськ-Мазовецький,Грођиск Мазовјецки,גרודזיסק מזובייצקי,馬佐夫舍地區格羅濟斯克', 52.1038700, 20.6337000, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110548, 'Grębów', 'Grebow', '', 50.5653600, 21.8740400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110549, 'Gręboszów', 'Greboszow', '', 50.2450100, 20.7766900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110550, 'Grębków', 'Grebkow', 'Grebkow,Grembkuv,Grębków,Грембкув', 52.2693100, 21.9097400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110551, 'Granica', 'Granica', '', 52.1335900, 20.8031300, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110552, 'Grajewo', 'Grajewo', 'Gorad Graeva,Graevo,Grajevas,Grajevo,Grajewo,ge la ye wo,gryybw,Горад Граева,Граево,Грайево,Граєво,Грајево,גרייבו,格拉耶沃', 53.6472800, 22.4553700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110553, 'Grabownica Starzeńska', 'Grabownica Starzenska', 'Grabownica,Grabownica Starzenska,Grabownica Starzeńska', 49.6589600, 22.0775400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110554, 'Grabowiec', 'Grabowiec', 'Grabowez,Grabowiec', 50.8209000, 23.5505700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110555, 'Gózd', 'Gozd', 'Goza,Gozd,Gózd', 51.3783200, 21.3791400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110556, 'Goworowo', 'Goworowo', 'Govorovo,Goworowo,Говорово', 52.9008300, 21.5557800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110557, 'Gowarczów', 'Gowarczow', '', 51.2784500, 20.4383500, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110558, 'Goszczyn', 'Goszczyn', '', 51.7318700, 20.8515400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110559, 'Gościeradów', 'Goscieradow', 'Goscieradow Ukazowy (do 1999),Gościeradów Ukazowy (do 1999)', 50.8685900, 22.0053600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110560, 'Gorzyce', 'Gorzyce', '', 50.6672000, 21.8401300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110561, 'Gorzyce', 'Gorzyce', 'Gorgyce,Gorzyce', 50.1284100, 22.5792600, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110562, 'Górzno', 'Gorzno', '', 51.8468100, 21.7093300, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110563, 'Gorzków', 'Gorzkow', 'Gorzkow,Gorzków,Kolonia Gorzkow,Kolonia Gorzków', 50.9477800, 23.0126700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110564, 'Górowo Iławeckie', 'Gorowo Ilaweckie', 'Gorovo Ilaveckje,Gorowo,Gorowo Ilaweckie,Gurovo Ilavecke,Gurovo-Ilavec''ke,Gurovo-Ilavecke,Górowo,Górowo Iławeckie,Landsberg,Landsberg Ost Preussen,gu luo wo yi wa wei ci kai,Горово Илавецкје,Гурово-Ілавецьке,Гурово-Илавецке,古羅沃伊瓦韋茨凱', 54.2855900, 20.4888600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110565, 'Górno', 'Gorno', '', 50.8477400, 20.8250100, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110566, 'Górno', 'Gorno', '', 50.2824300, 22.1450000, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110567, 'Gorliczyna', 'Gorliczyna', '', 50.0921700, 22.4876400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110568, 'Gorlice', 'Gorlice', 'Gorlice,Gorlices,Gorlici,Gorlicės,ge er li cai,gwrlyzh,Горлице,Горлиці,גורליצה,戈爾利采', 49.6556300, 21.1603500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110569, 'Górki', 'Gorki', '', 49.6438500, 22.0430400, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110570, 'Góra Kalwaria', 'Gora Kalwaria', 'Ger,Gora Kalvarija,Gora Kalwarja,Guer,Gura Kalvarja,Gura-Kal''var''ya,Gura-Kal''varija,Góra Kalwarja,gu la ka er wa li ya,Гора Калвария,Гора Калварија,Гура-Кальвария,Ґура-Кальварія,גורה קלוואריה,גער,古拉卡爾瓦里亞', 51.9765300, 21.2153700, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110571, 'Goraj', 'Goraj', 'Goraj,Goraj Lubelski', 50.7218400, 22.6665100, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110572, 'Goniadz', 'Goniadz', 'Gonendz,Goniadz,Гонендз', 53.4895300, 22.7357800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110573, 'Gołymin-Ośrodek', 'Golymin-Osrodek', 'Golymin-Os''rodek,Golymin-Osrodek,Gołymin-Ośrodek,Голымин-Осьродек', 52.8080000, 20.8732500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110574, 'Gołdap', 'Goldap', 'Geldape,Geldapė,Goldap,Goldapa,Gołdap,ge wu da pu,Голдап,גולדאפ,戈乌达普', 54.3063100, 22.3036200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110575, 'Golcowa', 'Golcowa', '', 49.7716200, 22.0250100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110576, 'Godziszów', 'Godziszow', '', 50.7488900, 22.4979400, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110577, 'Godzianów', 'Godzianow', '', 51.8969400, 20.0358900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110578, 'Gnojno', 'Gnojno', 'Comuna de Gnojno,Gmina Gnojno,Gnojno,Гнойно,Ґміна Ґнойно', 50.6026300, 20.8491300, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110579, 'Gnojnik', 'Gnojnik', '', 49.8939700, 20.6086300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110580, 'Głuchów', 'Gluchow', '', 51.7794700, 20.0766600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110581, 'Głuchów', 'Gluchow', '', 50.0817100, 22.2713500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110582, 'Głogów Małopolski', 'Glogow Malopolski', 'Glogov Malopolski,Glogova Malopolska,Glogow,Glogow Malopolski,Gloguv-Malopol''s''kij,Gloguv-Malopol''skij,Głogów,Głogów Małopolski,glwgwb mlwpwlsqy,xiao bo lan de qu ge wo gu fu,Глогов Малополски,Глогув-Малопольский,Глогув-Малопольський,גלוגוב מלופולסקי,小波蘭地區格沃古夫', 50.1512200, 21.9628700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110583, 'Glinojeck', 'Glinojeck', 'Glinoec''k,Glinoeck,Glinojeck,Glinojecka,Glinojek,ge li nuo ye ci ke,Глиноецк,Глинојецк,Гліноєцьк,格利諾耶茨克', 52.8198300, 20.2919800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110584, 'Giżycko', 'Gizycko', 'Gizhic''ko,Gizhicko,Gizicko,Gizycko,Giżycko,Gižicko,Lec,Lecius,Lettsen,Lotzen,Luczany,Lutsany,Lëttsen,Lötzen,Lėcius,gijicheuko,gijitsuko,ji ri ci ke,Łuczany,Гижицко,Гіжицько,ギジツコ,吉日茨科,기지츠코', 54.0381100, 21.7644100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110585, 'Gietrzwałd', 'Gietrzwald', 'Dietrichswalde,Gietrzwald,Gietrzwałd', 53.7461700, 20.2374200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110586, 'Gierzwałd', 'Gierzwald', 'Geierswalde,Geirswalde,Gierzwald,Gierzwałd,Gietrzwalde,Gietrzwałde', 53.5412800, 20.0886700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110587, 'Gierłoż', 'Gierloz', 'Gierloz,Gierłoż,Gorlitz,Görlitz', 54.0813400, 21.4955100, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110588, 'Gielniów', 'Gielniow', '', 51.4007600, 20.4812600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110589, 'Giedlarowa', 'Giedlarowa', '', 50.2268900, 22.4059300, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110590, 'Gdów', 'Gdow', '', 49.9081800, 20.1987900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110591, 'Gąsocin', 'Gasocin', 'Gasocin,Gonsocin,Gąsocin,Гонсоцин', 52.7375400, 20.7118000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110592, 'Garwolin', 'Garwolin', 'Garvolin,Garvolina,Garwolin,jia er wo lin,Гарволин,Гарволін,加爾沃林', 51.8974700, 21.6146600, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110593, 'Garbów', 'Garbow', '', 51.3551700, 22.3293700, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110594, 'Garbatka-Letnisko', 'Garbatka-Letnisko', '', 51.4832000, 21.6107900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110595, 'Gać', 'Gac', '', 50.0269300, 22.3589800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110596, 'Frysztak', 'Frysztak', 'Frysztak', 49.8416400, 21.6094200, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110597, 'Frydman', 'Frydman', '', 49.4492700, 20.2296100, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110598, 'Fredropol', 'Fredropol', '', 49.6957800, 22.7462500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110599, 'Frampol', 'Frampol', 'Frampol,Frampol'',Frampole,fu lan bo er,Фрампол,Фрамполь,弗蘭波爾', 50.6715900, 22.6706100, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110600, 'Firlej', 'Firlej', 'Firlej', 51.5588200, 22.5084100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110601, 'Filipów', 'Filipow', 'Filipow,Filipuv,Filipów,Pilypavas,Филипув', 54.1803700, 22.6207600, 'PL', '2015-01-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110602, 'Fałków', 'Falkow', '', 51.1360600, 20.1061000, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110603, 'Fajsławice', 'Fajslawice', '', 51.0959200, 22.9632300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110604, 'Ełk', 'Elk', 'Ehlk,Elk,Elka,Ełk,Lik,Lukas,Lyck,ai wu ke,euku,xelk,Елк,Элк,אלק,เอลก์,エウク,埃烏克', 53.8282400, 22.3646900, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110605, 'Dzwola', 'Dzwola', '', 50.6965700, 22.5672900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110606, 'Dźwierzuty', 'Dzwierzuty', 'Dzwierzuty,Dźwierzuty,Mensguth,Mensguth Dorf', 53.7049400, 20.9603700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110607, 'Dzików Stary', 'Dzikow Stary', 'Dzikow,Dzikow Stary,Dzików,Dzików Stary,Stary Dzikow,Stary Dzików', 50.2469900, 22.9298400, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110608, 'Dzikowiec', 'Dzikowiec', 'Dzikowiec,Dzikowiec Stary', 50.2728800, 21.8436500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110609, 'Dziewin', 'Dziewin', '', 50.0755400, 20.4549100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110610, 'Dzierzkowice', 'Dzierzkowice', '', 50.9601900, 22.0663900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110611, 'Dzierzgowo', 'Dzierzgowo', 'Comuna de Dzierzgowo,Dzezhgovo,Gmina Dzezhgovo,Gmina Dzierzgowo,Дзежгово,Ґміна Дзежґово', 53.1527900, 20.6632200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110612, 'Dzierzążnia', 'Dzierzaznia', 'Dzierzazna,Dzierzaznia,Dzierząźna,Dzierzążnia', 52.6281100, 20.2336400, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110613, 'Dziekanów Leśny', 'Dziekanow Lesny', 'Dziekanow Lesny,Dziekanow Niemiecki,Dziekanów Leśny,Dziekanów Niemiecki', 52.3524300, 20.8512400, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110614, 'Działoszyce', 'Dzialoszyce', 'Dzialoszyce,Działoszyce,Dzjaloshice,Dzjalosice,Dzjalošice,gu wo xi cai,Ђалошице,Дзялошице,דזיאלושיצה,賈沃希采', 50.3653400, 20.3522600, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110615, 'Działdowo', 'Dzialdowo', 'Dzhjaldovo,Dzialdovas,Dzialdowo,Działdowo,Dzjaldovo,Soldau,cea dx wx,gu wu duo wo,Ђалдово,Джялдово,Дзялдово,เจาดอวอ,賈烏多沃', 53.2395800, 20.1700400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110616, 'Dziadkowice', 'Dziadkowice', 'Dziadkowice,Dzjadkovice,Дзядковице', 52.5638000, 22.9168900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110617, 'Dywity', 'Dywity', 'Diwitten,Dyvity,Dywity,Дывиты', 53.8375900, 20.4781700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110618, 'Dynów', 'Dynow', 'Diniv,Dinov,Dinova,Dynow,Dynuv,Dynów,di nu fu,dynwb,Динов,Динів,Дынув,דינאוו,דינוב,迪努夫', 49.8150600, 22.2338800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110619, 'Dydnia', 'Dydnia', '', 49.6864000, 22.1719600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110620, 'Dwikozy', 'Dwikozy', 'Dwikozy', 50.7361300, 21.7886400, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110621, 'Dukla', 'Dukla', 'Dukla,Duklja,du ke la,dwqlh,Дукла,Дукля,דוקלה,杜克拉', 49.5555400, 21.6831700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110622, 'Duczki', 'Duczki', 'Duczki,Duszki', 52.3627100, 21.2904700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110623, 'Dubienka', 'Dubienka', '', 51.0486200, 23.8925200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110624, 'Dubiecko', 'Dubiecko', 'Dubiecko,dubetsk', 49.8260800, 22.3911700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110625, 'Drzewica', 'Drzewica', 'Drzewica,Dzevica,Dzhevica,Dzhevicja,Dževica,de re wei cha,dzwwyzh,Джевица,Джевиця,דזוויצה,德熱維察', 51.4508500, 20.4770100, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110626, 'Drohiczyn', 'Drohiczyn', 'Drohiczyn,Drohiczyn nad Bugiem,Drokhichin,Дрохичин', 52.4001100, 22.6585300, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110627, 'Drelów', 'Drelow', '', 51.9121900, 22.8716500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110628, 'Dorohusk', 'Dorohusk', '', 51.1547500, 23.8032500, 'PL', '2010-11-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110629, 'Domaszowice', 'Domaszowice', '', 50.8748800, 20.6828800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110630, 'Domaradz', 'Domaradz', '', 49.7867500, 21.9457100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110631, 'Domanice', 'Domanice', '', 52.0373900, 22.1764200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110632, 'Dołhobyczów', 'Dolhobyczow', '', 50.5859100, 24.0359400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110633, 'Dobrzyniewo Duże', 'Dobrzyniewo Duze', 'Dobrzyniewo Duze,Dobrzyniewo Duże,Dobrzyniewo Wielkie', 53.2002200, 23.0112900, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110634, 'Dobre Miasto', 'Dobre Miasto', 'Dobre Miasto,Dobre Misto,Dobre Mjasto,Dobre-Mjasto,Guttstadt,duo bu lei cheng,Добре Місто,Добре Мјасто,Добре-Място,多布雷城', 53.9866800, 20.3974900, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110635, 'Dobre', 'Dobre', 'Dobre,Добре', 52.3209700, 21.6788100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110636, 'Dobra', 'Dobra', 'Dobra,Dobra Podlopien,Dobra Podłopień', 49.7179300, 20.2534700, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110637, 'Dobczyce', 'Dobczyce', 'Dobchice,Dobcice,Dobczyce,Dobčice,Dopchice,duo bu qi cai,dwbzyzh,Добчице,Допчице,דובציצה,多布奇采', 49.8810900, 20.0893600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110638, 'Długosiodło', 'Dlugosiodlo', 'Dlugosedlo,Dlugosiodlo,Długosiodło,Длугоседло', 52.7599800, 21.5918300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110639, 'Długie', 'Dlugie', '', 49.5786600, 22.0433800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110640, 'Dębowiec', 'Debowiec', '', 49.6837400, 21.4606800, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110641, 'Dębowa Kłoda', 'Debowa Kloda', '', 51.5944600, 23.0064000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110642, 'Dębów', 'Debow', '', 50.0449000, 22.4361400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110643, 'Dębno', 'Debno', 'Debno,Dembno,Dębno', 50.1981100, 22.5183700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110644, 'Dębno', 'Debno', '', 49.9670100, 20.7197900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110645, 'Dęblin', 'Deblin', 'Demblin,Demblina,deng bu lin,dmblyn,Демблин,Демблін,דמבלין,登布林', 51.5591200, 21.8482900, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110646, 'Dębica', 'Debica', 'Debica,Debitsa,Dembica,Dembicja,Dembits,Dembitsa,Dembitz,Dembiza,Dębica,deng bi cha,dmbyzh,Дембица,Дембиця,דמביצה,登比察', 50.0514600, 21.4114100, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110647, 'Dębe Wielkie', 'Debe Wielkie', '', 52.1996100, 21.4433400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110648, 'Daleszyce', 'Daleszyce', 'Daleshice,Dalesice,Dalešice,da lai xi cai,Далешице,達萊希采', 50.8022900, 20.8079100, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110649, 'Dąbrówno', 'Dabrowno', 'Dabrowno,Dombruvno,Dąbrówno,Gilgenberg,Gilgenburg,Vjoska Dambruuna,Вёска Дамбруўна,Домбрувно', 53.4340800, 20.0352900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110650, 'Dąbrówka', 'Dabrowka', '', 52.4838800, 21.2979400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110651, 'Dąbrowa Tarnowska', 'Dabrowa Tarnowska', 'Dabrowa,Dabrowa Tarnowska,Dambrova,Dombrova,Dombrova Tarnovska,Dombrova-Tarnovs''ka,Dombrova-Tarnovska,Dombrowa Tarnowska,Dąbrowa,Dąbrowa Tarnowska,dwmbrwbh trnwbsqh,ta er nu fu de dong bu luo wa,Домброва Тарновска,Домброва-Тарновска,Домброва-Тарновська,דומברובה טרנובסקה,ドンブロヴァ・タルノフスカ,塔爾努夫的棟布羅瓦', 50.1746200, 20.9863300, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110652, 'Dąbrowa Białostocka', 'Dabrowa Bialostocka', 'Dabrowa,Dabrowa Bialostocka,Dabrowa Grodzienska-Wies,Dambrava,Dombrova Bjalostocka,Dombrova-Bilostoc''ka,Dombrova-Bjalostocka,Dąbrowa,Dąbrowa Białostocka,Dąbrowa Grodzieńska-Wieś,Gorad Dambrova-Belastockaja,bi ya wei si tuo ke de dong bu luo wa,Горад Дамброва-Беластоцкая,Домброва Бјалостоцка,Домброва-Бялостоцка,Домброва-Білостоцька,דומברובה ביאלוסטוצקה,比亞韋斯托克的棟布羅瓦', 53.6536400, 23.3479200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110653, 'Czyżew', 'Czyzew', 'Chizhev,Chizhev-Osada,Cizevo valscius,Comuna de Czyzew-Osada,Comuna de Czyżew-Osada,Czyzew-Osada,Czyzewo,Czyżew-Osada,Czyżewo,Gmina Chizhev,Gmina Czyzew,Gmina Czyzew-Osada,Gmina Czyżew,Gmina Czyżew-Osada,Čiževo valsčius,Чижев,Чижев-Осада,Ґміна Чижев', 52.7976800, 22.3123700, 'PL', '2017-06-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110654, 'Czudec', 'Czudec', '', 49.9448700, 21.8413400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110655, 'Czerwonka', 'Czerwonka', 'Chervonka,Czerwonka,Rothfliess,Червонка', 53.9162700, 20.8968500, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110656, 'Czerwonka', 'Czerwonka', 'Czerwonka Wloscianska (do 1999),Czerwonka Włościańska (do 1999)', 52.8925400, 21.2149400, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110657, 'Czerwińsk Nad Wisłą', 'Czerwinsk Nad Wisla', 'Czerwinsk,Czerwinsk Nad Wisla,Czerwińsk,Czerwińsk Nad Wisłą', 52.3982800, 20.3096000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110658, 'Czerwin', 'Czerwin', '', 52.9490500, 21.7584200, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110659, 'Czerniewice', 'Czerniewice', 'Czerniewice', 51.6541900, 20.1555300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110660, 'Czernice Borowe', 'Czernice Borowe', 'Chernice-Borove,Czernice Borowe,Чернице-Борове', 53.0319700, 20.7194400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110661, 'Czermin', 'Czermin', 'Czermin,Kolonia Czermin', 50.3391100, 21.3335600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110662, 'Czeremcha', 'Czeremcha', '', 52.5166700, 23.3500000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110663, 'Czemierniki', 'Czemierniki', '', 51.6729800, 22.6388700, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110664, 'Czchów', 'Czchow', 'Chechiav,Chekhoiv,Chkhov,Chkhuv,Chova,Czchow,Czchów,qi hu fu,tsykwb,Čhova,Чхов,Чхув,טשיכוב,奇胡夫', 49.8372600, 20.6805600, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110665, 'Czaszyn', 'Czaszyn', 'Czaszyn', 49.4485400, 22.2165000, 'PL', '2014-04-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110666, 'Czarnocin', 'Czarnocin', 'Charnocin,Gmina Charnocin,Gmina Czarnocin,Чарноцин,Ґміна Чарноцин', 50.3408000, 20.5162000, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110667, 'Czarnochowice', 'Czarnochowice', '', 50.0047100, 20.0679000, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110668, 'Czarnia', 'Czarnia', '', 53.3561400, 21.1952000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110669, 'Czarna Góra', 'Czarna Gora', '', 49.3766200, 20.1304700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110670, 'Czarna Białostocka', 'Czarna Bialostocka', 'Carna Bialostocka,Carna Bjalostocka,Charna Bjalostocka,Charna-Belostocka,Charna-Bilostoc''ka,Charna-Bjalostocka,Czarna Bialostocka,Czarna Białostocka,hei bi ya wo si tuo ci ka,Čarna Bialostocka,Čarna Bjalostocka,Чарна Бјалостоцка,Чарна-Белостоцка,Чарна-Бялостоцка,Чарна-Білостоцька,黑比亞沃斯托茨卡', 53.3050900, 23.2814600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110671, 'Czarna', 'Czarna', '', 50.1097900, 22.1816500, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110672, 'Czarna', 'Czarna', '', 50.0671700, 21.2561400, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110673, 'Czarna', 'Czarna', 'Czarna Gorna (do 1999),Czarna Górna (do 1999)', 49.3311600, 22.6589600, 'PL', '2010-11-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110674, 'Cyców', 'Cycow', 'Cycow,Cyców,Wiszniewice', 51.2992800, 23.1412400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110675, 'Cmolas', 'Cmolas', '', 50.2952600, 21.7441700, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110676, 'Ćmielów', 'Cmielow', 'Chmeljuv,Cmeljuv,Cmelova,Cmielow,Cmjelov,qi mei lu fu,zmyylwb,Ćmielów,Ћмјелов,Цмелюв,Чмелюв,צמיילוב,奇梅盧夫', 50.8902800, 21.5142600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110677, 'Cisna', 'Cisna', 'Tisna,Тісна', 49.2132800, 22.3279500, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110678, 'Ciężkowice', 'Ciezkowice', 'Censhkovice,Cenzhkovice,Cenzkovice,Cenžkovice,Chenzhkovice,Chenzhkovitze,Ciezkowice,Ciężkowice,Hardenberg,Tzezhkovitz,qian ri ke wei cai,Ћеншковице,Ценжковіце,Ченжковице,錢日科維采', 49.7857500, 20.9732400, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110679, 'Cieszanów', 'Cieszanow', 'Cesanova,Ceshanov,Ceshanuv,Cešanova,Cheshanov,Cieszanow,Cieszanów,Cishaniv,Tishaniv,Tseshenov,qie sha nu fu,Ћешанов,Цешанув,Цішанів,Чешанов,ציעשינאוו,切沙努夫', 50.2456400, 23.1316300, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110680, 'Ciepielów', 'Ciepielow', 'Ciepielow,Ciepielów', 51.2483800, 21.5747500, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110681, 'Cielądz', 'Cieladz', '', 51.7157600, 20.3442800, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110682, 'Ciechanowiec', 'Ciechanowiec', 'Cechanoveco valscius,Cechanoveco valsčius,Cekhanovec,Comuna de Ciechanowiec,Gmina Cekhanovec'',Gmina Ciechanowiec,Цехановец,Ґміна Цехановець', 52.6782800, 22.4981500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110683, 'Ciechanów', 'Ciechanow', 'Cechanuvas,Cehanova,Cekhanuv,Chekhanov,Ciechanow,Ciechanów,Tsekhanov,chiehanupeu,qie ha nu fu,tsykhanww,zhʼnwb,Цеханув,Чеханов,צחאנוב,تسیخانوو,切哈努夫,치에하누프', 52.8814100, 20.6199600, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110684, 'Chynów', 'Chynow', 'Comuna de Chynow,Comuna de Chynów,Gmina Chynow,Gmina Chynów,Gmina Khinuv,Khynuv,Хынув,Ґміна Хинув', 51.9042500, 21.0820800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110685, 'Chwałowice', 'Chwalowice', '', 50.7666500, 21.8868300, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110686, 'Chrzanów', 'Chrzanow', 'Chrzanow,Chrzanow Ordynacki,Chrzanów,Chrzanów Ordynacki', 50.7725600, 22.6035100, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110687, 'Chorzele', 'Chorzele', 'Chorzele,Hozele,Hožele,Khozhele,huo re lai,hwzlh,Хожеле,חוזלה,霍熱萊', 53.2607500, 20.8972800, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110688, 'Choroszcz', 'Choroszcz', 'Choroscas,Choroszcz,Choroščas,Horosca,Horošča,Khoroshch,Khoroshh,huo luo shen qi,Хорошч,Хорощ,霍羅什奇', 53.1433200, 22.9888900, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110689, 'Chorkówka', 'Chorkowka', '', 49.6466800, 21.6715600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110690, 'Chodel', 'Chodel', '', 51.1117700, 22.1326900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110691, 'Chmielnik', 'Chmielnik', 'Hmelnika,Hmelņika,Khmel''nik,Khmjelnik,he mei er ni ke,hmyylnyq,Хмельник,Хмјелњик,חמיילניק,赫梅爾尼克', 50.6144000, 20.7520600, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110692, 'Chmielnik', 'Chmielnik', '', 49.9738600, 22.1453500, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110693, 'Chlewiska', 'Chlewiska', '', 51.2437600, 20.7687100, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110694, 'Chełmiec', 'Chelmiec', 'Chelmiec,Chelmiec Polski,Chełmiec,Chełmiec Polski,Comuna de Chelmiec,Comuna de Chełmiec,Gmina Chelmiec,Gmina Chełmiec,Gmina Khelmec'',Khelmec,Хелмец,Ґміна Хелмець', 49.6305100, 20.6642500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110695, 'Chełm', 'Chelm', 'Chelm,Chelmas,Chełm,Gorad Khehlm,Helma,Khelm,Kholm,hai wu mu,he-um,heumu,hlm,Горад Хэлм,Хелм,Холм,חלם,ヘウム,海乌姆,헤움', 51.1431200, 23.4716000, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110696, 'Chęciny', 'Checiny', 'Hencini,Khencini,Khenciny,heng qi nei,hntsyn,Хенцини,Хенцины,Хенћини,חנטשין,כענטשין,亨齊內', 50.8002100, 20.4622900, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110697, 'Ceranów', 'Ceranow', 'Ceranow,Ceranuv,Ceranów,Церанув', 52.6308200, 22.2282600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110698, 'Celestynów', 'Celestynow', 'Celestynow,Celestynuv,Celestynów,Letnisko Celestynow,Letnisko Celestynów,Целестынув', 52.0609300, 21.3910700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110699, 'Cegłów', 'Ceglow', 'Ceglow,Cegluv,Cegłów,Цеглув', 52.1478200, 21.7373900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110700, 'Bystra', 'Bystra', '', 49.6623500, 21.0862800, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110701, 'Bychawa', 'Bychawa', 'Bihava,Bikhava,Bychawa,Bykhava,bei ha wa,Бихава,Быхава,ביחאווה,貝哈瓦', 51.0160800, 22.5329600, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110702, 'Busko-Zdrój', 'Busko-Zdroj', 'Bus''ko-Zdruj,Busk,Busko,Busko Zdroj,Busko Zdrój,Busko-Zdroj,Busko-Zdruj,Busko-Zdrój,Buskozdroja,bu si ke zi de lu yi,bwsqw-zdrwy,Буско-Здрој,Буско-Здруй,Бусько-Здруй,בוסקו-זדרוי,布斯科茲德魯伊', 50.4707800, 20.7188400, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110703, 'Bulkowo', 'Bulkowo', 'Bul''kovo,Bulkowo,Бульково', 52.5408700, 20.1188900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110704, 'Bukowsko', 'Bukowsko', 'Bukivs''ko,bwqwbsqw,Буківсько,בוקאווסק,בוקובסקו', 49.4803900, 22.0632900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110705, 'Bukowina Tatrzańska', 'Bukowina Tatrzanska', 'Bukowina,Tatranska Bukovina,Tatranská Bukovina', 49.3430200, 20.1080700, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110706, 'Brzyska', 'Brzyska', 'Brzyska,Brzyski', 49.8222600, 21.3900400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110707, 'Brzozów', 'Brzozow', 'Bereziv,Berezov,Breziv,Brozovia,Brzozow,Brzozów,Bz''ozuv,Bzhozov,Bzhozuv,Bzozova,Bžozova,Prozzow,brzwzww,bu ruo zu fu,bzwzwb,Березів,Бжозов,Бжозув,בזוזוב,ברעזשוב,برزوزوو,布若祖夫', 49.6950100, 22.0192600, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110708, 'Brzóza Stadnicka', 'Brzoza Stadnicka', '', 50.1996500, 22.2823300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110709, 'Brzóza Królewska', 'Brzoza Krolewska', 'Brzoza Krolewska,Brzóza Królewska', 50.2390800, 22.3255900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110710, 'Brzostek', 'Brzostek', 'Brzhostik,Bzhostek,Bzosteka,Bžosteka,bu ruo si tai ke,bzwstq,Бжостек,בזוסטק,برزوسٹیک,布若斯泰克', 49.8795400, 21.4110200, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110711, 'Brzeźnica', 'Brzeznica', '', 50.1006500, 21.4802500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110712, 'Brzeźnica', 'Brzeznica', '', 49.9576300, 20.4913900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110713, 'Brzeziny', 'Brzeziny', 'Brzeiny,Brzeziny', 50.7727300, 20.5731900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110714, 'Brzesko', 'Brzesko', 'Briegel,Brigel,Brzesko', 49.9691100, 20.6060600, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110715, 'Brzączowice', 'Brzaczowice', '', 49.8747800, 20.0370900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110716, 'Brwinów', 'Brwinow', 'Brvinuv,Brwinow,Brwinów,Comuna de Brwinow,Comuna de Brwinów,Gmina Brvinuv,Gmina Brwinow,Gmina Brwinów,Брвинув,Ґміна Брвінув', 52.1426900, 20.7169700, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110717, 'Brok', 'Brok', 'Brok,Broka,Gorad Brok,brwq,bu luo ke,Брок,Горад Брок,ברוק,布羅克', 52.6994800, 21.8570400, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110718, 'Brody', 'Brody', '', 51.0246600, 21.2214700, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110719, 'Brochów', 'Brochow', 'Brokhuv,Comuna de Brochow,Comuna de Brochów,Gmina Brochow,Gmina Brochów,Gmina Brokhuv,Брохув,Ґміна Брохув', 52.3195000, 20.2625700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110720, 'Brańszczyk', 'Branszczyk', 'Braniszczyki,Branszczyk,Branszezki,Brańszczyk', 52.6293100, 21.5874500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110721, 'Brańsk', 'Bransk', 'Bran''sk,Brans''k,Bransk,Branska,Branskas,Brańsk,Braņska,Bryansk,bu lan si ke,Бранськ,Браньск,Брањск,בראנסק,布蘭斯克', 52.7444000, 22.8377400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110722, 'Borzęcin', 'Borzecin', '', 50.0654000, 20.7110300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110723, 'Borzechów', 'Borzechow', '', 51.0925800, 22.2841400, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110724, 'Borowie', 'Borowie', '', 51.9490800, 21.7658000, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110725, 'Borowa', 'Borowa', '', 50.3854800, 21.3515000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110726, 'Borkowice', 'Borkowice', '', 51.3202500, 20.6833900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110727, 'Borki', 'Borki', '', 51.7216100, 22.5212900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110728, 'Borek', 'Borek', '', 50.0177800, 20.5308700, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110729, 'Bolimów', 'Bolimow', 'Bolimow,Bolimuv,Bolimów,Болимув', 52.0767100, 20.1635200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110730, 'Bojanów', 'Bojanow', 'Boyanuv', 50.4253100, 21.9511100, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110731, 'Boguty-Pianki', 'Boguty-Pianki', 'Boguty,Boguty-Pianki,Boguty-Pjanki,Богуты-Пянки', 52.7168000, 22.4154600, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110732, 'Boguchwała', 'Boguchwala', 'Boguchwala,Boguchwała', 49.9847300, 21.9452800, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110733, 'Bogoria', 'Bogoria', 'Bogoria,Bogorja,Bogoryja,Borgoria,Comuna de Bogoria,Gmina Bogoria,Gmina Bogorija,Богоря,Ґміна Боґорія', 50.6517500, 21.2600000, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110734, 'Bodzentyn', 'Bodzentyn', 'Bodzentin,Bodzentina,Bodzentyn,bo ceng teng,bwdzntyn,Бодзентин,Бодзентын,בודזנטין,博曾滕', 50.9411500, 20.9571900, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110735, 'Bodzechów', 'Bodzechow', '', 50.9071500, 21.4371500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110736, 'Bodzanów', 'Bodzanow', 'Bodzanow,Bodzanuv,Bodzanów,Comuna de Bodzanow,Comuna de Bodzanów,Gmina Bodzanow,Gmina Bodzanuv,Gmina Bodzanów,Бодзанув,Ґміна Бодзанув', 52.4999200, 20.0294500, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110737, 'Boćki', 'Bocki', 'Boc''ki,Bocki,Bocku valscius,Boćki,Bočkų valsčius,Comuna Bocki,Comuna Boćki,Comuna de Bocki,Comuna de Boćki,Gmina Boc''ki,Gmina Bocki,Gmina Boćki,Voc''ki,Боцьки,Воцьки,Ґміна Боцькі', 52.6515500, 23.0448500, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110738, 'Bochnia', 'Bochnia', 'Bochna,Bochnia,Bochńa,Bohna,Bohņa,Bokhnja,Bokhnya,bo he ni ya,bofunya,bwknyh,Бохня,Бохња,בוכניה,ボフニャ,博赫尼亞', 49.9690500, 20.4302800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110739, 'Bobrowniki', 'Bobrowniki', 'Bobrovniki,Bobrowniki,Бобровники', 52.0644200, 20.0194900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110740, 'Bobowa', 'Bobowa', 'Bobov,Bobova,Bobowa,bo bo wa,bwbwbh,Бобова,באבאוו,בובובה,博博瓦', 49.7086600, 20.9476700, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110741, 'Stara Błotnica', 'Stara Blotnica', '', 51.5467600, 20.9747900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110742, 'Błonie', 'Blonie', 'Blone,Blonie,Bloņe,Błonie,blwnyh,bu wo nie,Блоне,Блоње,בלוניה,布沃涅', 52.1984900, 20.6170900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110743, 'Bliżyn', 'Blizyn', 'Blizin,Blizyn,Bliżyn', 51.1077800, 20.7593500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110744, 'Blizne', 'Blizne', '', 49.7533200, 21.9735100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110745, 'Błędów', 'Bledow', '', 51.7776700, 20.6979800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110746, 'Błażowa', 'Blazowa', 'Blazhova,Blazova,Blazowa,Blažova,Blezov,Bluzhov,Błażowa,bu wa ruo wa,Блажова,בלאזובה,בלאזשאוו,布瓦若瓦', 49.8852100, 22.1003700, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110747, 'Bisztynek', 'Bisztynek', 'Bischofstein,Bischsteen,Bishtinek,Bishtynek,Bistineka,Bisztynek,Bištineka,bi shen di nei ke,Биштинек,Биштынек,Біштинек,比什蒂內克', 54.0863300, 20.9019200, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110748, 'Biszcza', 'Biszcza', '', 50.4014600, 22.6506300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110749, 'Biskupiec', 'Biskupiec', 'Bischofsburg,Biskupec,Biskupec'',Biskupeca,Biskupiec,Biskupjec,bi si ku pei ci,Бискупец,Бискупјец,Біскупець,比斯庫佩茨', 53.8646700, 20.9569200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110750, 'Biskupice Radłowskie', 'Biskupice Radlowskie', '', 50.1206900, 20.8594300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110751, 'Bircza', 'Bircza', 'Berch,Bircha,Bircza,Birtch', 49.6917300, 22.4785400, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110752, 'Binarowa', 'Binarowa', '', 49.7562100, 21.2281600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110753, 'Biłgoraj', 'Bilgoraj', 'Bilgora,Bilgoraia,Bilgoraj,Bilgoraja,Bilgorajus,Bilgoray,Biłgora,Biłgoraj,Gorad Bilgoraj,bi wu ge la yi,bylgwryy,Билгорай,Билгорај,Білґорай,Горад Білгорай,בילגוריי,比烏戈拉伊', 50.5411400, 22.7220400, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110754, 'Bieniewice', 'Bieniewice', '', 52.1826800, 20.5630600, 'PL', '2010-11-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110755, 'Bielsk Podlaski', 'Bielsk Podlaski', 'Bel''sk-Podljaski,Belsk Podljaski,Belska Podlaska,Bielsk,Bielsk Podlaski,Bielskas,Bil''s''k-Pidljas''kij,Bjelsk Podlaski,Gorad Bel''sk-Padljashski,Podlaski,bo de la xie de qu bie er si ke,Белск Подляски,Бельск-Подляски,Більськ-Підляський,Бјелск Подласки,Горад Бельск-Падляшскі,波德拉謝地區別爾斯克', 52.7651200, 23.1864700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110756, 'Bieliny', 'Bieliny', 'Bieliny Kapitulne (do 1999)', 50.8494700, 20.9414900, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110757, 'Bieliny', 'Bieliny', '', 50.4423700, 22.3048200, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110758, 'Bielany', 'Bielany', '', 52.3417400, 22.2492900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110759, 'Bielany', 'Bielany', '', 52.2924200, 20.9353100, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110760, 'Biecz', 'Biecz', 'Beca,Bech,Beča,Biecz,Bjech,Bjecz,bie qi,byyz,Беч,Бјеч,בייץ,別奇', 49.7359600, 21.2630100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110761, 'Białystok', 'Bialystok', 'Balstoge,Balstogė,Belostok,Belostoko,Bialistok,Bialystok,Białystok,Bilostok,Bjalistok,Bjalistoka,Bjalistoko,Bjelostock,Bjolystok,Bjołystok,Byelostok,Gorad Belastok,QYY,bi ya wei si tuo ke,biawiseutokeu,byalystwk,byau~isutoku,byawystwk,Μπιάλιστοκ,Белосток,Бялисток,Білосток,Бјалисток,Горад Беласток,ביאליסטאק,ביאליסטוק,بیالیستوک,بیاویستوک,ბელოსტოკი,ビャウィストク,比亚韦斯托克,비아위스토크', 53.1333300, 23.1643300, 'PL', '2015-06-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110762, 'Biały Dunajec', 'Bialy Dunajec', '', 49.3738000, 20.0089800, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110763, 'Białowieża', 'Bialowieza', 'Belovez,Belovezha,Bialovieza,Bialovieža,Bialowieza,Białowieża,Bilovezha,Bělověž,Vjoska Belavezha,Беловежа,Біловежа,Вёска Белавежа', 52.7000000, 23.8666700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110764, 'Białołeka', 'Bialoleka', '', 52.3212700, 20.9720400, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110765, 'Białobrzegi', 'Bialobrzegi', '', 52.4419900, 21.0525500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110766, 'Białobrzegi', 'Bialobrzegi', 'Bialobrzegi,Białobrzegi,Bilobzhegi,Bjalobzegi,Bjalobzhegi,Bjalobžegi,bi ya wo bu re ji,Бялобжеги,Білобжегі,Бјалобжеги,ביאלובזגי,比亞沃布熱吉', 51.6469500, 20.9504100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110767, 'Białobrzegi', 'Bialobrzegi', '', 50.1025200, 22.3190700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110768, 'Białka Tatrzańska', 'Bialka Tatrzanska', '', 49.3897500, 20.1050700, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110769, 'Biała Rawska', 'Biala Rawska', 'Biala,Biala Ravska,Biala Rawska,Biała,Biała Rawska,Bila-Ravs''ka,Bjala Ravska,Bjala-Ravska,bi ya wa la fu si ka,Бяла-Равска,Біла-Равська,Бјала Равска,ביאלה ראווסקה,比亞瓦拉夫斯卡', 51.8077900, 20.4725900, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110770, 'Biała Podlaska', 'Biala Podlaska', 'Alba,BXP,Biala Podlaska,Biała Podlaska,Bila Pidljas''ka,Bjala Podlaska,Bjala Podljaska,Bjala-Podljaska,Gorad Bjala-Padljaska,Palenkes Biala,Palenkės Biala,bi ya wa-bo de la si ka,biawapodeullaseuka,Бяла Подляска,Бяла-Подляска,Біла Підляська,Бјала Подласка,Горад Бяла-Падляска,ביאלא פודולסק,ביאלע,比亞瓦-波德拉斯卡,비아와포들라스카', 52.0323800, 23.1165200, 'PL', '2017-01-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110771, 'Biała Piska', 'Biala Piska', 'Biala,Biala Piska,Bialla,Biała,Biała Piska,Bila Piska,Bjala Piska,Bjala-Piska,Gehlenburg,bi ya wa pi si ka,Бяла-Писка,Біла Піска,Бјала Писка,比亞瓦皮斯卡', 53.6119100, 22.0632100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110772, 'Białaczów', 'Bialaczow', '', 51.2981500, 20.2972400, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110773, 'Besko', 'Besko', 'Bos''ko,Босько', 49.5875700, 21.9529200, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110774, 'Bemowo', 'Bemowo', 'Bemovo,Бемово', 52.2546000, 20.9084400, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110775, 'Bełżyce', 'Belzyce', 'Belzhice,Belzice,Belzyce,Belžice,Bełżyce,bei wu ri cai,blzyzh,Белжице,בלזיצה,貝烏日采', 51.1741500, 22.2802700, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110776, 'Belsk Duży', 'Belsk Duzy', 'Belsk,Belsk Duzy,Belsk Duży', 51.8256100, 20.8084700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110777, 'Bejsce', 'Bejsce', '', 50.2390300, 20.5983400, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110778, 'Batorz', 'Batorz', '', 50.8505000, 22.4931300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110779, 'Bartoszyce', 'Bartoszyce', 'Barstynas,Bartenstein,Bartoshice,Bartosice,Bartoszyce,Bartošice,Barštynas,ba er tuo xi cai,Бартошице,巴爾托希采', 54.2535400, 20.8081900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110780, 'Barczewo', 'Barczewo', 'Barcevo,Barchevo,Barczewo,Barčevo,Wartenbork,Wartenburg,ba er qie wo,Барчево,巴爾切沃', 53.8305500, 20.6911200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110781, 'Barciany', 'Barciany', 'Barciany,Barcjany,Barten,Bartenai,Bartėnai,Барцяны', 54.2199300, 21.3534700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110782, 'Baranów Sandomierski', 'Baranow Sandomierski', 'Baranow,Baranow Sandomierski,Baranów,Baranów Sandomierski', 50.4991200, 21.5420400, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110783, 'Baranowo', 'Baranowo', 'Baranovo,Baranowo,Бараново', 53.1755400, 21.2980300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110784, 'Baranów', 'Baranow', '', 51.5578600, 22.1362500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110785, 'Baniocha', 'Baniocha', '', 52.0165300, 21.1398400, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110786, 'Banie Mazurskie', 'Banie Mazurskie', 'Bane-Mazurske,Bani Mazurs''ki,Banie,Banie Mazurskie,Benkaimis,Benkheim,Бане-Мазурске,Бані Мазурські', 54.2466200, 22.0361700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110787, 'Bałtów', 'Baltow', '', 51.0184500, 21.5438500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110788, 'Baligród', 'Baligrod', '', 49.3309000, 22.2856600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110789, 'Baćkowice', 'Backowice', '', 50.7919400, 21.2321100, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110790, 'Baboszewo', 'Baboszewo', 'Baboshevo,Baboszewo,Бабошево', 52.6807000, 20.2552700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110791, 'Babica', 'Babica', '', 49.9347600, 21.8703500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110792, 'Augustów', 'Augustow', 'Augustavas,Augustov,Augustow,Augustów,Avgustov,Августов,Аугустов', 53.8432100, 22.9797900, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110793, 'Annopol', 'Annopol', 'Annopol,Annopol'',Annopole,Anopol,Rachow-Annopol,Rachów-Annopol,an nuo bo er,Аннопол,Аннополь,Анопол,אנופול,安諾波爾', 50.8855100, 21.8567800, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110794, 'Aleksandrów', 'Aleksandrow', '', 50.4663000, 22.8922500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110795, 'Albigowa', 'Albigowa', 'Albigowa', 50.0142500, 22.2241400, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110796, 'Adamówka', 'Adamowka', '', 50.2585700, 22.6959500, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110797, 'Adamów', 'Adamow', 'Adamuv,Comuna de Adamow,Comuna de Adamów,Gmina Adamau,Gmina Adamow,Gmina Adamuv,Gmina Adamów,Адамув,Гміна Адамаў,Гміна Адамув', 51.7433500, 22.2641400, 'PL', '2010-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110798, 'Abramów', 'Abramow', 'Abramow,Abramów', 51.4564700, 22.3152100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110799, 'Żywiec', 'Zywiec', 'Saybusch,Zhivec,Zhivec'',Zhivjec,Ziveca,Zwyiec,Zyvecas,Zywiec,jibiecheu,jivu~ietsu,ri wei ci,Żywiec,Živeca,Žyvecas,Живец,Живець,Живјец,ジヴィエツ,日維茨,지비에츠', 49.6852900, 19.1924300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110800, 'Żychlin', 'Zychlin', 'Zhikhlin,Zihlina,Zychlin,ri he lin,zyklyn,Żychlin,Žihlina,Жихлин,Жихлін,זיכלין,日赫林', 52.2440400, 19.6261300, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110801, 'Zwierzyń', 'Zwierzyn', '', 52.8321200, 15.5676300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110802, 'Żuromin', 'Zuromin', 'Zhuromin,Zuramin,Zuromin,Zuromina,ru luo ming,zwrwmyn,Żuromin,Žuromina,Журомин,Журомін,זורומין,茹羅明', 53.0661100, 19.9089400, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110803, 'Żukowo', 'Zukowo', 'Zukowo,Żukowo', 54.3422000, 18.3647600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110804, 'Zubrzyca Górna', 'Zubrzyca Gorna', 'Felsozubrica,Felsőzubrica,Zubrzyca  Gorna,Zubrzyca  Górna,Zubrzyca Gorna,Zubrzyca Górna', 49.5617400, 19.6497300, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110805, 'Zubrzyca Dolna', 'Zubrzyca Dolna', '', 49.5268800, 19.6734200, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110806, 'Żory', 'Zory', 'Gorad Zhory,Sohrau,Zhori,Zhory,Zori,Zoros,Zory,ch xrux,joli,joru~i,ruo lei,Żory,Žori,Žoros,Žory,Горад Жоры,Жори,Жоры,ชอรือ,ジョルィ,若雷,조리', 50.0452300, 18.7006200, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110807, 'Żórawina', 'Zorawina', 'Rothbach,Rothsurben,Rothsürben,Zorawin,Zorawina,Zurawin,Zurawina,Żurawina,Żórawin,Żórawina', 50.9808000, 17.0367100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110808, 'Żnin', 'Znin', 'Zhnin,Znina,Zninas,ri ning,Žninas,Žņina,Жнин,Жнін,Жњин,日寧', 52.8495800, 17.7199200, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110809, 'Żmigród', 'Zmigrod', 'Trachenberg,Zhmigrod,Zhmigrud,Zmigrod,Zmigroda,ri mi ge lu de,Żmigród,Žmigroda,Жмигрод,Жмигруд,Жміґруд,日米格魯德', 51.4667200, 16.9056400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110810, 'Złoty Stok', 'Zloty Stok', 'Reichenstein,Rowne,Równe,Zloti Stok,Zloti Stoka,Zloty Stok,Zloty-Stok,Złoty Stok,zi wo di si tuo ke,Злоти Сток,Злоты-Сток,茲沃蒂斯托克', 50.4447200, 16.8758600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110811, 'Złotów', 'Zlotow', 'Flatow i. Westpr.,Gorad Zlotau,Zlotov,Zlotova,Zlotovia,Zlotowo,Zlotuv,Złotowò,zi wo tu fu,Горад Злотаў,Злотов,Злотув,茲沃圖夫', 53.3634600, 17.0408200, 'PL', '2016-04-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110812, 'Złotoryja', 'Zlotoryja', 'Aurimontium,Goldberg,Goldberg in Schlesien,Slotoryja,Słotoryja,Zlota Gora,Zlotorija,Zlotoryja,Złota Góra,Złotoryja,zi wo tuo lei ya,Злотория,Злоторија,Злоторыя,茲沃托雷亞', 51.1263700, 15.9197900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110813, 'Złotniki Kujawskie', 'Zlotniki Kujawskie', 'Zlotniki Kujawskie,Zlotniki-Kujavske,Złotniki Kujawskie,Злотники-Куявске', 52.8994300, 18.1456400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110814, 'Złotniki', 'Zlotniki', '', 52.4940700, 16.8449600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110815, 'Złoczew', 'Zloczew', 'Zloceva,Zlochev,Zloczew,Zločeva,Złoczew,zi wo qie fu,zlwzb,Злочев,זלוצב,茲沃切夫', 51.4171900, 18.6036300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110816, 'Złocieniec', 'Zlocieniec', 'Falkenburg,Gorad Zlacenec,Walczemborg,Walczembórg,Zlocenec,Zlocenec'',Zloceneca,Zloceņeca,Zlocieniec,Złocieniec,zi wo qie nie ci,Горад Злаценец,Злоценец,Злоценець,Злоћењец,茲沃切涅茨', 53.5328600, 16.0113200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110817, 'Zławieś Wielka', 'Zlawies Wielka', 'Comuna de Zlawies Wielka,Comuna de Zławieś Wielka,Gmina Zlaves''-Vel''ka,Gmina Zlawies Wielka,Gmina Zławieś Wielka,Zlaves''-Vel''ka,Злавесь-Велька,Ґміна Злавесь-Велька', 53.0956200, 18.3289700, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110818, 'Zielonki', 'Zielonki', 'Zielonki', 50.1209100, 19.9215600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110819, 'Zielona Góra', 'Zielona Gora', 'Gorad Zjaljona-Gura,Gruentberg,Grunberg,Grünberg,IEG,Prasia Elysiorum,Zelena Gura,Zeliona Gura,Zeljona-Gura,Zeloena Gur,Zelona Gura,Zelono Gora,Zelonô Góra,Zelöna Gur,Zhel''ona Gora,Zielona Gora,Zielona Gura,Zielona Góra,Zielona Nkora,Zjelona Gora,jiellonagula,jlwna ghwra,lu shan cheng,zhlwna gwra,zhylwna gwra,zylwna gwra,Ζιελόνα Γκόρα,Горад Зялёна-Гура,Жельона Гора,Зелена Гура,Зелёна-Гура,Зјелона Гора,Զիելոնա Գուրա,جلونا غورا,زیلونا گورا,ژلونا گورا,ژیلونا گورا,แชลอนากูรา,ジェロナ・グラ,綠山城,지엘로나구라', 51.9354800, 15.5064300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110820, 'Ziębice', 'Ziebice', 'Muensterberg,Münsterberg,Zembice,Zembise,Zhembice,Ziebice,Ziembice,Ziębice,Zjembice,jin bi cai,Жембице,Зембице,Зембіце,Зјембице,津比采', 50.6012200, 17.0406500, 'PL', '2017-07-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110821, 'Zgorzelec', 'Zgorzelec', 'Gorlitz,Görlitz,Zgorzelec,Zgorzelice,Zgozeleca,Zgozelecas,Zgozhelec,Zgozhelec'',Zgoželeca,Zgoželecas,jeugojellecheu,zgwzlz,zi ge re lai ci,zugojeretsu,Згожелец,Зґожелець,זגוזלץ,ズゴジェレツ,茲戈熱萊茨,즈고젤레츠', 51.1494200, 15.0083500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110822, 'Zgierz', 'Zgierz', 'Gorad Zgezh,Zgeza,Zgezas,Zgezh,Zgeža,Zgežas,Zgierz,Zgjezh,Znkies,ci gai ri,jeugiesi,sex keiyr ch,zgyyz,zugyeshi,Ζγκιες,Горад Згеж,Згеж,Згјеж,זגייז,เซอเกียร์ช,ズギェシ,兹盖日,즈기에시', 51.8556100, 19.4062300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110823, 'Żerniki Wrocławskie', 'Zerniki Wroclawskie', '', 51.0330800, 17.0566200, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110824, 'Żernica', 'Zernica', '', 50.2477000, 18.6154700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110825, 'Żerków', 'Zerkow', 'Gorad Zhehrkau,Zerkova,Zerkow,Zherkov,Zherkuv,re er ku fu,Żerków,Žerkova,Горад Жэркаў,Жерков,Жеркув,熱爾庫夫', 52.0687700, 17.5634900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110826, 'Zembrzyce', 'Zembrzyce', 'Zambrzyce', 49.7751700, 19.6012000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110827, 'Zelów', 'Zelow', 'Zeljuv,Zelova,Zelow,Zelów,ze lu fu,Зелюв,澤盧夫', 51.4645200, 19.2197200, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110828, 'Żelistrzewo', 'Zelistrzewo', '', 54.6777000, 18.4173800, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110829, 'Żelazków', 'Zelazkow', '', 51.8541800, 18.1743000, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110830, 'Zebrzydowice', 'Zebrzydowice', '', 50.1000000, 18.5000000, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110831, 'Zebrzydowice', 'Zebrzydowice', '', 49.8903200, 19.6729100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110832, 'Zebrzydowice', 'Zebrzydowice', 'Zebrzydowice', 49.8779300, 18.6112700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110833, 'Zębowice', 'Zebowice', 'Fohrendorf,Föhrendorf,Zebowice,Zembowitz,Zębowice', 50.7629000, 18.3443400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110834, 'Zdzieszowice', 'Zdzieszowice', 'Deschowitz,Odertal,Zagieszowice,Zdzeshovice,Zdzesovice,Zdzešovice,Zdzheshovice,Zdzieszowice,Zdzyszowicy,zi jie shao wei cai,Źdźyszowicy,Зджешовице,Здзешовице,Здзешовіце,Зђешовице,茲傑紹維采', 50.4248200, 18.1234900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110835, 'Zduny', 'Zduny', 'Zduni,Zduny,zi du nei,Здуни,Здуны,茲杜內', 51.6458000, 17.3769400, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110836, 'Zduńska Wola', 'Zdunska Wola', 'Zdun''skaja-Volja,Zduns''ka Volja,Zdunska Vola,Zdunska Volia,Zdunska Volja,Zdunska Wola,Zduńska Wola,Zduņska Vola,zdwnsqh wwlh,zi dui si ka wo la,Здунска Воля,Здунська Воля,Здуньская-Воля,Здуњска Вола,זדונסקה וולה,茲敦斯卡沃拉', 51.5991500, 18.9397400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110837, 'Zbytków', 'Zbytkow', 'Zbytkow,Zbytków', 49.9228800, 18.7269700, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110838, 'Zbrosławice', 'Zbroslawice', '', 50.4161200, 18.7544300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110839, 'Zbójno', 'Zbojno', 'Comuna Zbojno,Comuna Zbójno,Comuna de Zbojno,Comuna de Zbójno,Gmina Zbojno,Gmina Zbujno,Gmina Zbójno,Zbojno,Zbujno,Zbójno,Збуйно,Ґміна Збуйно', 53.0084800, 19.1575000, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110840, 'Zblewo', 'Zblewo', 'Hoch Stublau,Hoch Stüblau,Zblevo,Zblewo,Зблево', 53.9336600, 18.3226200, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110841, 'Zbąszynek', 'Zbaszynek', 'Neu Bentschen,Zbaszynek,Zbonshinek,Zbonsineka,Zbonšineka,Zbąszynek,ci bang xi nei ke,Збоншинек,兹邦希内克', 52.2431500, 15.8165400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110842, 'Zbąszyń', 'Zbaszyn', 'Zbaszyn,Zbonshin,Zbonshin'',Zbonsina,Zbonšiņa,Zbąszyń,zi bang shen,Збоншинь,Збоншињ,茲邦申', 52.2509000, 15.9252000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110843, 'Zawoja', 'Zawoja', 'Zawoja', 49.6439600, 19.5422700, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110844, 'Zawiercie', 'Zawiercie', 'Zaverce,Zaverche,Zavercis,Zavertse,Zaviercis,Zavjerce,Zawiercie,zha wei er qie,zwwyyrzh,Заверце,Заверче,Завјерће,זוויירצה,扎维尔切', 50.4876600, 19.4167900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110845, 'Zawidz', 'Zawidz', 'Zawidz Koscielny,Zawidz Kościelny', 52.8274500, 19.8736700, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110846, 'Zawidów', 'Zawidow', 'Seidenberg,Zavidov,Zavidova,Zaviduv,Zawidow,Zawidów,zha wei du fu,Завидов,Завидув,Завідув,扎維杜夫', 51.0254600, 15.0621300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110847, 'Zawadzkie', 'Zawadzkie', 'Andreashutte,Andreashutte Oberschlesien,Andreashütte,Andreashütte Oberschlesien,Zavadskje,Zavadz''ke,Zavadzke,Zawadzki,Zawadzki Oberschlesien,Zawadzkie,zha wa zi kai,Завадзке,Завадзьке,Завадскје,扎瓦茲凱', 50.6050300, 18.4846700, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110848, 'Zator', 'Zator', 'Zator', 49.9960400, 19.4379900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110849, 'Zarzecze', 'Zarzecze', '', 50.3671500, 19.6959100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110850, 'Zarzecze', 'Zarzecze', '', 49.7193200, 19.1752600, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110851, 'Żary', 'Zary', 'Sorau,Sorau in Nieder Lausitz,Soraw,Zara,Zarai,Zari,Zarow,Zary,Zhara,Zhari,Zhary,Zoraw,Zóraw,zha lei,Żary,Žarai,Žari,Žarow,Жара,Жари,Жары,扎雷', 51.6420500, 15.1372700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110852, 'Żarów', 'Zarow', 'Saarau,Saaru,Zarova,Zarow,Zarrow,Zharov,Zharuv,zha lu fu,Żarów,Žarova,Жаров,Жарув,扎魯夫', 50.9411600, 16.4946600, 'PL', '2016-08-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110853, 'Żarki', 'Zarki', 'Zarki,Zharki,zha ji,zrqy,Žarki,Жарки,זרקי,札基', 50.6251800, 19.3635700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110854, 'Żarki', 'Zarki', '', 50.0825900, 19.3519900, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110855, 'Zapolice', 'Zapolice', '', 51.5431900, 18.8833500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110856, 'Zaniemyśl', 'Zaniemysl', '', 52.1556100, 17.1622800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110857, 'Zamarski', 'Zamarski', 'Zamarski', 49.7825400, 18.6697200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110858, 'Zalewo', 'Zalewo', 'Saalfeld,Zalevo,Zalewo,zha lai wo,Залево,扎萊沃', 53.8453400, 19.6051900, 'PL', '2011-10-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110859, 'Zalas', 'Zalas', '', 50.0803300, 19.6213200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110860, 'Zakrzów', 'Zakrzow', '', 49.8255800, 19.6497300, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110861, 'Zakrzewo', 'Zakrzewo', '', 53.4118600, 17.1547200, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110862, 'Zakopane', 'Zakopane', 'Gorad Zakapaneh,QAZ,Zakopane,Zakopané,Zakopanė,jakopane,zakopane,zha ke pa nei,zkwbn,zkwpana,Горад Закапанэ,Закопане,זאקופנה,زكوبن,زکوپانا,ზაკოპანე,ザコパネ,扎科帕內,자코파네', 49.2989900, 19.9488500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110863, 'Zagrodno', 'Zagrodno', 'Zagrodno', 51.1913400, 15.8653300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110864, 'Zagórze', 'Zagorze', '', 50.0944900, 19.4035700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110865, 'Zagórów', 'Zagorow', 'Zagorov,Zagorow,Zagurova,Zaguruv,Zagórów,zgwrwb,zgwrww,zha gu lu fu,Загоров,Загурув,זגורוב,زگوروو,扎古魯夫', 52.1683500, 17.8956100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110866, 'Zagórnik', 'Zagornik', '', 49.8371000, 19.3786800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110867, 'Żagań', 'Zagan', 'Jagan'',Jaganʻ,Jaqan,Sagan,Saganum,Zagan,Zagana,Zaganis,Zahan,Zahań,Zaháň,Zankan,Zegan,Zegań,Zhagan,Zhagan'',jagan,jagana,sa gen,zagan,zagana,zajan,Żagań,Žaganis,Žagaņa,Ζάγκαν,Жаган,Жагань,Жагањ,Жаґань,زاجان,زاگان,ज़ागान,जागान,ジャガン,薩根', 51.6175900, 15.3148600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110868, 'Zadzim', 'Zadzim', 'zajym,زاجیم', 51.7766600, 18.8492800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110869, 'Zabrzeg', 'Zabrzeg', 'Zabrzeg', 49.9161900, 18.9429200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110870, 'Zabrze', 'Zabrze', 'Gorad Zabzheh,Hindenburg,Zabje,Zaborze,Zabrze,Zabzas,Zabze,Zabzhe,Zabžas,Zabže,Zobrze,jabeuje,sab che,zabjh,zabuje,zabzhh,zha bu re,zʼbzh,Горад Забжэ,Забже,Զաբժե,זאבזה,زابجه,زابژه,زبرزے,ซาบเช,ザブジェ,扎布热,자브제', 50.3249200, 18.7857600, 'PL', '2013-11-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110871, 'Zaborze', 'Zaborze', '', 50.0217500, 19.2406700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110872, 'Zaborze', 'Zaborze', 'Zaborze', 49.8727900, 18.8037000, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110873, 'Zabór', 'Zabor', 'Fursteneich,Fürsteneich,Saabor,Zabor,Zabór', 51.9519400, 15.7167600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110874, 'Żabnica', 'Zabnica', 'زابنیکا، سیلسیان صوبہ', 49.5813900, 19.1562100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110875, 'Zabłocie', 'Zablocie', '', 49.9028200, 18.7814700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110876, 'Ząbkowice Śląskie', 'Zabkowice Slaskie', 'Frankenstein,Frankenstein in Schlesien,Zabkowice,Zabkowice Slaskie,Zabkowice Szlascze,Zombkovice Shl''onske,Zombkovice Slonske,Zombkovice-Shl''ons''ke,Zombkovice-Sljonske,Zompkovice Slonskje,Ząbkowice Szląsczé,Ząbkowice Śląskie,xi long si ke de qu zong bu ke wei cai,Зомбковице Шльонске,Зомбковице-Слёнске,Зомбковіце-Шльонське,Зомпковице Слонскје,زوبکووکے سلوسکے,希隆斯克地區宗布科維采', 50.5896900, 16.8123900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110877, 'Zabierzów', 'Zabierzow', 'Comuna de Zabierzow,Comuna de Zabierzów,Gmina Zabezhuv,Gmina Zabierzow,Gmina Zabierzów,Zabezhuv,Zabierzow,Zabierzów,Забежув,Ґміна Забежув', 50.1142500, 19.7978800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110878, 'Wysoka', 'Wysoka', 'Visoka,Vysoka,Wesoko,Wissek,Wysoka,Wësokô,wei suo ka,Висока,Высока,維索卡', 53.1809100, 17.0835300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110879, 'Wysoka', 'Wysoka', '', 50.4298900, 19.3536800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110880, 'Wysoka', 'Wysoka', '', 49.9071300, 19.6035600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110881, 'Wyrzysk', 'Wyrzysk', 'Vizhis''k,Vizhisk,Viziska,Viziskas,Vižiska,Vižiskas,Vyzhisk,Werzesko,Wirsitz,Wryzysk,Wërzëskò,wei ri si ke,Вижиск,Вижиськ,Выжиск,維日斯克', 53.1530000, 17.2680200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110882, 'Wyry', 'Wyry', '', 50.1329600, 18.9005200, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110883, 'Wymiarki', 'Wymiarki', '', 51.5110900, 15.0820800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110884, 'Wschowa', 'Wschowa', 'Fraustadt,Vshova,Vskhova,Vuskhova,Wschowa,fu si huo wa,Всхова,Въсхова,弗斯霍瓦', 51.8070500, 16.3166300, 'PL', '2017-07-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110885, 'Września', 'Wrzesnia', 'Gorad Uzhehsnja,Vzesn,Vzesna,Vzesnia,Vzhes''nja,Vzhes''nya,Vzheshnja,Vzhesna,Vzhesnja,Vzhes’nya,Vžesn,Vžesnia,Vžesņa,Wreschen,Wrzesnia,Września,fu re xi ni ya,Вжесня,Вжесьня,Вжесња,Вжешня,Горад Ужэсня,弗熱希尼亞', 52.3251200, 17.5651900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110886, 'Wrząsowice', 'Wrzasowice', '', 49.9586200, 19.9465400, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110887, 'Wronki', 'Wronki', 'Vronki,Vronkos,fu long ji,wrwnky,Вронки,Вронкі,ورونکی,弗龍基', 52.7105100, 16.3804400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110888, 'Wrocław', 'Wroclaw', 'Brassel,Breslau,Breslavia,Breslavl'',Breslavl’,Gorad Vroclau,Vratislav,Vratislavia,Vroclav,Vroclava,Vroclavas,Vroclavo,Vroklave,Vroslav,Vrotslav,WRO,Wroclaw,Wroclow,Wrocław,Wrocłow,Wroklaw,Wroslaw,Wrosław,Wrócław,beulocheuwapeu,frwtswaf,fu luo ci wa fu,viratscahp,vrotsavapha,vrotslavi,vurotsuwafu,w rxtswaf,wrwslaw,wrwtswaf,wrwzlb,Βρότσλαβ,Вроцлав,Горад Вроцлаў,ברעסלוי,ורוצלב,فروتسواف,وروتسواف,وروسلاو,ڤرۆتسواف,व्रोत्सवाफ,விராத்ஸ்சாஃப்,วรอตสวัฟ,ვროცლავი,ヴロツワフ,弗罗茨瓦夫,브로츠와프', 51.1000000, 17.0333300, 'PL', '2016-03-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110889, 'Wróblew', 'Wroblew', '', 51.6121500, 18.6148700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110890, 'Wręczyca Wielka', 'Wreczyca Wielka', 'Wreczyca,Wreczyca Wielka,Wręczyca,Wręczyca Wielka', 50.8458900, 18.9208600, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110891, 'Wożniki', 'Wozniki', '', 50.5893400, 19.0599100, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110892, 'Woźniki', 'Wozniki', '', 49.9377400, 19.4907800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110893, 'Wolsztyn', 'Wolsztyn', 'Gorad Vol''shtyn,Vol''shtin,Vol''shtyn,Volshhin,Volshtin,Volstina,Volština,Wolsztyn,wo er shen teng,Волштин,Волщин,Вольштин,Вольштын,Горад Вольштын,وولشٹائین,沃尔什滕', 52.1155200, 16.1171200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110894, 'Wołowice', 'Wolowice', '', 49.9887600, 19.7263000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110895, 'Wołów', 'Wolow', 'Volov,Volova,Voluv,Wohlau,Wolow,Wołów,wo wu fu,Волов,Волув,沃武夫', 51.3365600, 16.6442900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110896, 'Wolin', 'Wolin', 'Gorad Volin,Volin,Volina,Wolen,Wolin,Wollin,Wòlëń,wo lin,Волин,Волін,Горад Волін,沃林', 53.8421400, 14.6146500, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110897, 'Wołczyn', 'Wolczyn', 'Konstadt,Volchin,Volcina,Volčina,Wolczyn,Wołczyn,wo wu qin,Волчин,沃烏琴', 51.0184500, 18.0499400, 'PL', '2015-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110898, 'Wolbrom', 'Wolbrom', 'Vol''brom,Volbrom,Volbroma,Wolbrom,wo er bu luo mu,wwlbrwm,Волбром,Вольбром,וולברום,沃爾布羅姆', 50.3795700, 19.7583100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110899, 'Wolbórz', 'Wolborz', 'Vol''buzh,Volboza,Volbozh,Volboža,wo er bo ri,Волбож,Вольбуж,沃爾博日', 51.5019600, 19.8304900, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110900, 'Wola Radziszowska', 'Wola Radziszowska', '', 49.9055800, 19.7882700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110901, 'Wola Krzysztoporska', 'Wola Krzysztoporska', '', 51.3441800, 19.5809000, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110902, 'Wola Filipowska', 'Wola Filipowska', '', 50.1343300, 19.5801300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110903, 'Wola', 'Wola', '', 50.0174500, 19.1233300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110904, 'Wojkowice', 'Wojkowice', 'Vojkovice,Wojkowice,Wojkowice Komorne,Wojkowice-Korne,vu~oikovu~itsu~e,wo yi ke wei cai,Войковице,Войковіце,Војковице,ヴォイコヴィツェ,沃伊科維采', 50.3650900, 19.0365200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110905, 'Wojcieszów', 'Wojcieszow', 'Kauffung,Vojceshov,Vojceshuv,Vojcesova,Vojcešova,Wojcieszow,Wojcieszów,wo yi qie shu fu,Войцешув,Војћешов,沃伊切舒夫', 50.9519400, 15.9218500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110906, 'Wodzisław Śląski', 'Wodzislaw Slaski', 'Silezijos Vodzislavas,Vodzhislav Shl''onski,Vodzislav-Shl''ons''kij,Vodzislav-Shljonski,Vodzislav-Sljonski,Vodzislava Slonska,Wladzisluw,Wodislaw-Slaski,Wodisław-Śląski,Wodzislaw,Wodzislaw Slaski,Wodzisław,Wodzisław Śląski,Władźisłůw,wwdzyslʼb slzyh,xi long si ke de qu wo ji si wa fu,Воджислав Шльонски,Водзислав-Слёнски,Водзислав-Шлёнски,Водзіслав-Шльонський,Вођислав Слонски,וודזיסלאב שלזיה,希隆斯克地區沃濟斯瓦夫', 50.0037700, 18.4720500, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110907, 'Wodzierady', 'Wodzierady', '', 51.7182600, 19.1512300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110908, 'Włoszczowa', 'Wloszczowa', 'Vloscova,Vloshchova,Vloshhova,Vloščova,Wloszczowo,Włoszczowo,fu wo shen qiao wa,wlwszwbh,Влошчова,Влощова,ולושצובה,弗沃什喬瓦', 50.8525600, 19.9659300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110909, 'Włoszakowice', 'Wloszakowice', '', 51.9275400, 16.3645600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110910, 'Włosienica', 'Wlosienica', '', 50.0182200, 19.3167100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110911, 'Włodowice', 'Wlodowice', '', 50.5556000, 19.4515500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110912, 'Włocławek', 'Wloclawek', 'Gorad Ulaclavak,Leslau,Vloclavek,Vloclaveka,Vloclavekas,Wloclawek,Włocławek,beuwocheuwabekeu,fu wo ci wa wei ke,fwtswafk,vuu~otsuwavu~eku,w wxts wa wek,Влоцлавек,Горад Улацлавак,ולוצלאווק,فوتسوافك,ووتس‌واوک,ววอตซวาเวก,ヴウォツワヴェク,弗沃茨瓦韦克,브워츠와베크', 52.6481700, 19.0678000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110913, 'Wleń', 'Wlen', 'Laehn,Lahn,Lähn,Wlen,Wleń', 51.0163500, 15.6747400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110914, 'Władysławowo', 'Wladyslawowo', 'Vladislavovo,Vladyslavovo,Wiolgo Wies,Wiôlgô Wies,Wladyslawowo,Władysławowo,fu wa di si wa wo wo,wwadyswawwww,Владиславово,Владыславово,ووادیسواوووو,弗瓦迪斯瓦沃沃', 54.7908600, 18.4009000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110915, 'Władysławów', 'Wladyslawow', 'Comuna de Wladyslawow,Comuna de Władysławów,Gmina Vladislavuv,Gmina Wladyslawow,Gmina Władysławów,Vladyslavuv,Владыславув,Ґміна Владиславув', 52.1031300, 18.4762600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110916, 'Witonia', 'Witonia', 'Vitonja,Witonia,Витоня', 52.1465500, 19.3004900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110917, 'Witnica', 'Witnica', 'Vietz,Vietz Ostbahnhof,Vitnica,Vitnicja,Vitņica,Wicno,Witnica,wei te ni cha,Витница,Витњица,Вітниця,維特尼察', 52.6731800, 14.8976500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110918, 'Witkowo', 'Witkowo', 'Gorad Vitkova,Vitkovo,wei te ke wo,Витково,Вітково,Горад Віткова,維特科沃', 52.4396400, 17.7726400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110919, 'Witkowice', 'Witkowice', '', 49.9074600, 19.2796300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110920, 'Witaszyce', 'Witaszyce', '', 51.9415100, 17.5618200, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110921, 'Witanowice', 'Witanowice', '', 49.9179600, 19.5257900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110922, 'Wisła', 'Wisla', 'Wisla,Wisła', 49.6562900, 18.8591000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110923, 'Wińsko', 'Winsko', 'Winiec,Winsko,Winzig,Wińsko', 51.4703200, 16.6139000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110924, 'Wilkowice', 'Wilkowice', '', 51.8851300, 16.5341700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110925, 'Wilkowice', 'Wilkowice', '', 49.7628200, 19.0897300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110926, 'Wilków', 'Wilkow', '', 51.1015800, 17.6628400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110927, 'Wilków', 'Wilkow', 'Wilkow,Wilków', 51.0921200, 15.9282400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110928, 'Wilczyn', 'Wilczyn', 'Wilczyn', 52.4881600, 18.1612600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110929, 'Wilczogóra', 'Wilczogora', '', 52.4734800, 18.1674400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110930, 'Wilcza', 'Wilcza', 'Wilcza,Wilcza Dolna', 50.1889900, 18.5966800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110931, 'Wilamowice', 'Wilamowice', 'Vilaemovice,Vilamovice,Viljamovice,Vilämovice,Wilamowicy,wei la mo wei cai,Виламовице,Вилямовице,Вілямовіце,維拉莫維采', 49.9170100, 19.1523700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110932, 'Wijewo', 'Wijewo', '', 51.9162700, 16.1855200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110933, 'Wieszowa', 'Wieszowa', '', 50.3844400, 18.7592400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110934, 'Wierzchucino', 'Wierzchucino', '', 54.7879700, 18.0030700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110935, 'Wierzchowo', 'Wierzchowo', 'Virchow,Wierzchowo', 53.4601300, 16.0996100, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110936, 'Wierzchosławice', 'Wierzchoslawice', '', 52.8692300, 18.3560900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110937, 'Wierzchlas', 'Wierzchlas', '', 51.2045700, 18.6654300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110938, 'Wierzbno', 'Wierzbno', '', 50.9367400, 17.1796100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110939, 'Wierzbinek', 'Wierzbinek', '', 52.4402600, 18.5108500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110940, 'Wieruszów', 'Wieruszow', 'Verushov,Verushuv,Verusova,Verušova,Vjerushov,Wieruszow,Wieruszów,wei lu shu fu,wyyrwswb,Верушов,Верушув,Вјерушов,ויירושוב,維魯舒夫', 51.2948800, 18.1554700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110941, 'Wieprz', 'Wieprz', '', 49.8909300, 19.3568800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110942, 'Wieprz', 'Wieprz', '', 49.6474600, 19.1800700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110943, 'Wieluń', 'Wielun', 'Gorad Veljun'',Veliunis,Veljun,Veljun'',Veluna,Veluņa,Velyun'',Vieloun,Vielun,Vjelun,Weilun,Wielun,Wieluń,biellun,vu~ieruni,wei long,wylwn,wyylwn,Βιέλουν,Велюн,Велюнь,Вјелуњ,Горад Велюнь,ויילון,ویلون,ヴィエルニ,维隆,비엘룬', 51.2209700, 18.5696400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110944, 'Wielowieś', 'Wielowies', 'Langendorf,Wielowies,Wielowieś', 50.5096600, 18.6160800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110945, 'Wielka Wieś', 'Wielka Wies', '', 50.1569400, 19.8436300, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110946, 'Wielka Nieszawka', 'Wielka Nieszawka', '', 52.9961900, 18.5097300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110947, 'Wielichowo', 'Wielichowo', 'Velihovo,Velikhovo,Vjelikhovo,Wielichowo,wei li huo wo,Велихово,Веліхово,Вјелихово,維利霍沃', 52.1157300, 16.3518000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110948, 'Wielgie', 'Wielgie', '', 52.7407600, 19.2635000, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110949, 'Wieleń', 'Wielen', 'Filehne,Velen'',Velena,Veleņa,Vielene,Vielenė,Vjelen,Wielen,Wieleń,Wieléń,wei lun,Велень,Вјелењ,维伦', 52.8946100, 16.1713600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110950, 'Większyce', 'Wiekszyce', '', 50.3365900, 18.1022100, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110951, 'Więcbork', 'Wiecbork', 'Vandsburg,Vencbork,Vencborka,Vjencbork,Wiacborg,Wiebork,Wiecbork,Wiãcbórg,Więcbork,wen ci bao,Венцборк,Вјенцборк,溫茨堡', 53.3538400, 17.4906400, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110952, 'Widuchowa', 'Widuchowa', 'Fiddichow,Widuchowo', 53.1269300, 14.3907400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110953, 'Widawa', 'Widawa', 'Comuna de Widawa,Gmina Vidava,Gmina Widawa,Vidava,Видава,Ґміна Відава', 51.4385500, 18.9442100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110954, 'Wiązów', 'Wiazow', 'V''onzov,Vjonzhov,Vjonzova,Vjonzuv,Wansen,Wiazow,Wiezow,Wiezów,Wiązów,wei weng zu fu,Вйонзув,Вьонзов,Вёнзув,Вјонжов,維翁祖夫', 50.8139900, 17.2021400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110955, 'Wejherowo', 'Wejherowo', 'Neustadt,Veiherovas,Vejgerovo,Vejherovo,Vejkherovo,Veykherovo,Weiherowo,Wejherowo,Wejrowo,Wejrowò,vu~eiherovu~o,wei yi hai luo wo,Вейгерово,Вейхерово,Вејхерово,ヴェイヘロヴォ,韋伊海羅沃', 54.6056800, 18.2355900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110956, 'Węgry', 'Wegry', '', 50.7431900, 18.0174100, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110957, 'Węgorzyno', 'Wegorzyno', 'Gorad Vehngazhyna,Vengojino,Vengozhino,Vengozino,Vengožino,Veñgojıno,Wagorzeno,Wangerin,Wãgòrzëno,wen ge ri nuo,Венгожино,Горад Вэнгажына,文戈日諾', 53.5410100, 15.5596400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110958, 'Węgliniec', 'Wegliniec', 'Kalawsk,Kaławsk,Kohlfurt,Venglinec,Venglinec'',Venglineca,Vengliņeca,Wegliniec,Węgliniec,wen ge li nie ci,Венглинец,Венглињец,Венґлінець,文格利涅茨', 51.2875300, 15.2289400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110959, 'Węgierska Górka', 'Wegierska Gorka', '', 49.6077600, 19.1163800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110960, 'Wąsosz', 'Wasosz', 'Herrnstadt,Vonsosa,Vonsosh,Vonsoša,Wasosz,Wąsosz,weng suo shen,Вонсош,翁索什', 51.5622400, 16.6905900, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110961, 'Wartkowice', 'Wartkowice', '', 51.9762600, 19.0018000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110962, 'Warta', 'Warta', '', 51.7104900, 18.6248300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110963, 'Warnice', 'Warnice', 'Warnice,Warnitz', 53.2537600, 14.9940200, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110964, 'Warlubie', 'Warlubie', 'Varljube,Warlubie,Варлюбе', 53.5875100, 18.6344400, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110965, 'Wapno', 'Wapno', 'Wapno,Wapno Nowe', 52.9080400, 17.4750400, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110966, 'Wąpielsk', 'Wapielsk', '', 53.1376100, 19.2779200, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110967, 'Walim', 'Walim', 'Walim,Wuestewaltersdorf,Wustelwaltersdorf,Wusterwaltersdorf,Wüstelwaltersdorf,Wüsterwaltersdorf,Wüstewaltersdorf', 50.6974900, 16.4448200, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110968, 'Walichnowy', 'Walichnowy', '', 51.2957900, 18.3807300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110969, 'Wałcz', 'Walcz', 'Deutsch Krone,Gorad Valch,Valca,Valcas,Valch,Valča,Valčas,Walcz,Wałcz,Wolcz,Wôłcz,wa wu qi,Валч,Горад Валч,瓦烏奇', 53.2778700, 16.4712200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110970, 'Walce', 'Walce', '', 50.3732200, 18.0042700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110971, 'Wałbrzych', 'Walbrzych', 'Gorad Valbzhykh,Valbzhikh,Valbziha,Valbzychas,Valbžiha,Valbžychas,Walbrzych,Waldenburg,Waldenburg in Schlesien,Wałbrzych,baubeujiheu,vu~aubujifu,wa lb cik,wa wu bu ri he,wawb jykh,wawb zhykh,wlbzyk,Валбжих,Горад Валбжых,ולבזיך,واوب جيخ,واوب ژیخ,วาลบ์จิก,ヴァウブジフ,瓦烏布日赫,바우브지흐', 50.7714100, 16.2843200, 'PL', '2017-05-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110972, 'Wągrowiec', 'Wagrowiec', 'Eichenbruck,Eichenbrück,Vongrovec,Vongrovec'',Vongroveca,Vongrovecas,Vongrovjec,Wagrowiec,Wągrowiec,weng ge luo wei ci,Вонгровец,Вонгровець,Вонгровјец,翁格羅維茨', 52.8084200, 17.1996100, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110973, 'Waganiec', 'Waganiec', '', 52.8012000, 18.8758900, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110974, 'Wadowice', 'Wadowice', 'Bantobitse,Gorad Vadavicy,Vadovice,Wadowice,badobiche,vu~adovu~itsu~e,wa duo wei cai,wdwbyzh,Βαντοβίτσε,Вадовице,Вадовіце,Горад Вадавіцы,ודוביצה,ヴァドヴィツェ,瓦多維采,바도비체', 49.8833500, 19.4929200, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110975, 'Wąbrzeźno', 'Wabrzezno', 'Briesen,Vombzezno,Vombzhez''no,Vombzhezhno,Vombzhezno,Vombžezno,Wabrzezno,Wąbrzeźno,Wąbrzézno,vu~onbujejino,weng bu re yi nuo,Вомбжежно,Вомбжезно,Вомбжезьно,ヴォンブジェジノ,翁布熱伊諾', 53.2798900, 18.9477300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110976, 'Ustronie Morskie', 'Ustronie Morskie', 'Henkenhagen,Ustronie Morskie,Ustronie Polana', 54.2151700, 15.7556800, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110977, 'Ustroń', 'Ustron', 'Ustron,Ustron'',Ustrona,Ustroń,Ustroņa,Ustroň,Ustrune,Ustrůńe,wu si te long,Устрон,Устронь,Устроњ,烏斯特龍', 49.7215300, 18.8019800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110978, 'Ustka', 'Ustka', 'Stolpmunde,Stolpmünde,Usko,Ustka,useuteuka,usutoka,wu si te ka,Ùskô,Устка,ウストカ,乌斯特卡,우스트카', 54.5804800, 16.8619400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110979, 'Unisław', 'Unislaw', 'Unislav,Unislaw,Unisław,Унислав', 53.2124100, 18.3862200, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110980, 'Uniejów', 'Uniejow', 'Unejov,Unejova,Unejuv,Uniejow,Uniejów,Uņejova,wu nie you fu,Ùniejów,Унеюв,Уњејов,אונייוב,烏涅尤夫', 51.9742800, 18.7930800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110981, 'Ujsoły', 'Ujsoly', '', 49.4829000, 19.1380100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110982, 'Ujście', 'Ujscie', 'Ujs''ce,Ujsce,Ujscie,Ujshce,Ujście,Usce,wu yi xi qie,Ùscé,Уйсце,Уйсьце,Ујшће,烏伊希切', 53.0533900, 16.7320100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110983, 'Ujazd', 'Ujazd', '', 51.5978100, 19.9222500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110984, 'Ujazd', 'Ujazd', 'Bischofstal,Ujazd,Ujazda,Ujest,Ujest Oberschlesien,wu ya zi de,Уязд,Ујазд,אוייזד,烏亞茲德', 50.3893800, 18.3492900, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110985, 'Udanin', 'Udanin', 'Udanin', 51.0374000, 16.4546900, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110986, 'Uciechów', 'Uciechow', '', 50.7548700, 16.6817500, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110987, 'Tyniec Mały', 'Tyniec Maly', 'Tyniec Maly,Tyniec Mały', 51.0194800, 16.9199800, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110988, 'Tychy', 'Tychy', 'Tichau,Tihi,Tikhi,Tychos,Tychy,Tykhy,Tıhı,di hei,thi khi,tihi,tixa,tyshy,Тихи,Тыхы,تیشی,ทิคี,ティヒ,蒂黑,티히', 50.1371700, 18.9664100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110989, 'Tychowo', 'Tychowo', 'Gross Tychow,Techowo,Tihovo,Tikhovo,Tychowo,Tëchòwò,di huo wo,Тихово,蒂霍沃', 53.9277400, 16.2577100, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110990, 'Tworóg', 'Tworog', 'Horneck,Tworog,Tworóg', 50.5310000, 18.7157200, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110991, 'Tworków', 'Tworkow', '', 50.0055900, 18.2357600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110992, 'Twardogóra', 'Twardogora', 'Festenberg,Tvardogora,Tvardogura,Twarda Gora,Twarda Góra,Twardogora,Twardogóra,te wa er duo gu la,Твардогора,Твардогура,Твардоґура,特瓦爾多古拉', 51.3648700, 17.4687800, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110993, 'Twardawa', 'Twardawa', '', 50.3434900, 17.9909700, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110994, 'Tuszyn', 'Tuszyn', 'Tushin,Tusina,Tuszyn,Tušina,tu shen,twchyn,Тушин,توچین,圖申', 51.6094900, 19.5300900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110995, 'Turza Śląska', 'Turza Slaska', 'Turza,Turza Slaska,Turza Śląska', 49.9723100, 18.4378100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110996, 'Turek', 'Turek', 'Turek,Турек', 52.0154800, 18.5005500, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110997, 'Tuplice', 'Tuplice', 'Klein Teuplitz,Teuplitz,Tuplice', 51.6763900, 14.8291400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110998, 'Tułowice', 'Tulowice', 'Tillowitz,Tulowice,Tułowice', 50.5957700, 17.6532300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(110999, 'Tuliszków', 'Tuliszkow', 'Comuna de Tuliszkow,Comuna de Tuliszków,Gmina Tulishkuv,Gmina Tuliszkow,Gmina Tuliszków,Tulishkuv,Tuliszkow,Tuliszków,Тулишкув,Ґміна Тулішкув', 52.0765800, 18.2954900, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111000, 'Tuczno', 'Tuczno', 'Teczno,Tuchno,Tucno,Tuetz,Tučno,Tëczno,Tütz,tu qi nuo,Тучно,圖奇諾', 53.1937400, 16.1536800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111001, 'Tuchomie', 'Tuchomie', 'Goss Tuchen,Gross Tuchen,Tuchomie,Tuchonie', 54.1152200, 17.3363400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111002, 'Tuchola', 'Tuchola', 'Techolo,Tuchola,Tuhola,Tukhola,Tukholja,Tëchòlô,tu huo la,twkhla,Тухола,Тухоля,توخلا,圖霍拉', 53.5879200, 17.8590500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111003, 'Trzemeszno', 'Trzemeszno', 'Trzemeszno,Tsemesno,Tshemeshno,Tšemešno,chmsnw,qie mei shen nuo,Тшемешно,چمسنو,切梅什諾', 52.5613900, 17.8231100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111004, 'Trzebunia', 'Trzebunia', 'Trzebunia,Trzebunie', 49.7914600, 19.8471500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111005, 'Trzebnica', 'Trzebnica', 'Trebnitz,Trzebnica,Tsebnica,Tshebnica,Tshebnicja,Tšebņica,chbnyka,qie bu ni cha,Тшебница,Тшебниця,Тшебњица,چبنیکا,切布尼察', 51.3107600, 17.0633100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111006, 'Trzebinia', 'Trzebinia', 'Trzebinia,Tsebina,Tshebina,Tshebinja,Tšebiņa,chbynya,qie bi ni ya,toshebinya,trzbynya,tsbynyh,Тшебиня,Тшебиња,Тшебіня,טשביניה,ترزبينيا,چبینیا,トシェビニャ,切比尼亞', 50.1593100, 19.4696600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111007, 'Trzebinia', 'Trzebinia', '', 49.6502400, 19.2226400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111008, 'Trzebielino', 'Trzebielino', 'Treblin,Trzebielino,chbylynw,چبیلینو', 54.1999600, 17.0872600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111009, 'Trzebiel', 'Trzebiel', 'Triebel,Trjebule,Trzebiel,chbyl,چبیل', 51.6349600, 14.8160900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111010, 'Trzebiechów', 'Trzebiechow', '', 52.0211300, 15.7362000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111011, 'Trzebiatów', 'Trzebiatow', 'Gorad Tshehbjatau,Preptow,Treptow,Treptow Rega,Treptow an de Rega,Treptow an der Rega,Trzebiatow,Trzebiatowo,Trzebiatów,Trzébiatowò,Tsebiatuvas,Tsebjatova,Tsebyatuv,Tshebjatov,Tshebjatuv,Tšebiatuvas,Tšebjatova,chbyatw,qie bi ya tu fu,toshebyato~ufu,Горад Тшэбятаў,Тшебятув,Тшебјатов,Տշեբյատուվ,چبیاتو,トシェビャトゥフ,切比亞圖夫', 54.0614700, 15.2647500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111012, 'Trzcińsko Zdrój', 'Trzcinsko Zdroj', 'Bad Schonfliess,Bad Schönfliess,Schonfliess,Schönfliess,Zdroj Schonfliess,Zdrój Schönfliess', 52.9648700, 14.6066700, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111013, 'Trzcinica', 'Trzcinica', '', 51.1670700, 18.0045300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111014, 'Trzciel', 'Trzciel', 'Neu Tirschtiegel,Tirschtiegel,Trzciel,Tscela,Tshcel,Tshcel'',Tšcela,ashchyl,chchyl,qi qie er,Тшцель,Тшћел,اشچیل,چچیل,奇切爾', 52.3650400, 15.8730600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111015, 'Trzcianka', 'Trzcianka', 'Kreisstadt Schonlanke,Kreisstadt Schönlanke,Schonlanke,Schönlanke,Trzcianka,Trzconka,Trzcónka,Tscjanka,Tshcanka,Tshchanka,Tshchjanka,Tshcjanka,Tšcjanka,ashchyanka,chchanka,qi qiang ka,Тшцянка,Тшчанка,Тшчянка,Тшћанка,اشچیانکا,چچانکا,奇強卡', 53.0406300, 16.4562900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111016, 'Truskolasy', 'Truskolasy', '', 50.8669200, 18.8270500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111017, 'Trąbki Wielkie', 'Trabki Wielkie', 'Gross Trampken,Trabki Wielkie,Trąbki Wielkie,trwmpky wylkyh,ترومپکی ویلکیه', 54.1706200, 18.5400300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111018, 'Toszek', 'Toszek', 'Toczek,Toseka,Toshek,Tost,Toszek,Tošeka,tuo xie ke,twsq,Тошек,טושק,托謝克', 50.4544200, 18.5220900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111019, 'Torzym', 'Torzym', 'Sternberg,Sternberg Neumark,Torun Lubuski,Toruń Lubuski,Tozhim,Tozima,Tožima,tuo ri mu,twrzym,Тожим,تورزيم,托日姆', 52.3133100, 15.0824300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111020, 'Toruń', 'Torun', 'Gorad Torun'',Thorn,Thorunium,Torn,Toroun,Torun,Torun'',Toruna,Torune,Toruni,Torunj,Torunė,Toruń,Toruņa,Toruň,Torń,Torůń,thx run,tolun,torun,trwny,tuo lun,twrwn,twryny,Τόρουν,Горад Торунь,Торун,Торунь,Торуњ,טורון,ترونی,تورون,تورینی,تۆرون,ทอรูน,ტორუნი,トルン,托伦,토룬', 53.0137500, 18.5981400, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111021, 'Toporzysko', 'Toporzysko', '', 49.6249500, 19.8022600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111022, 'Topólka', 'Topolka', 'Topolka,Topul''ka,Topólka,Топулька', 52.5032700, 18.7124600, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111023, 'Tomice', 'Tomice', '', 49.8977300, 19.4835700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111024, 'Tolkmicko', 'Tolkmicko', 'Tol''kmic''ko,Tol''kmicko,Tolkemit,Tolkmicko,tuo er ke mi ci ke,Толкмицко,Толькмицко,Толькмицько,托爾克米茨科', 54.3203800, 19.5269500, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111025, 'Tokarnia', 'Tokarnia', '', 49.7272000, 19.8716100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111026, 'Tłuchowo', 'Tluchowo', '', 52.7471500, 19.4656300, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111027, 'Tenczynek', 'Tenczynek', 'Tenczynek,Tенцынеҟ', 50.1198600, 19.6130800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111028, 'Tczew', 'Tczew', 'Derszewo,Dirschau,Dërszewò,Tceva,Tcevas,Tchev,Tczew,Tčeva,Tčevas,Тчев', 54.0924200, 18.7778700, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111029, 'Tarnowskie Góry', 'Tarnowskie Gory', 'Tarnovs''ki Guri,Tarnovske Gori,Tarnovske Gurai,Tarnovske Guri,Tarnovske-Gury,Tarnovskje Gori,Tarnowitz,Tarnowske Gury,Tarnowske Gůry,Tarnowskie Gory,Tarnowskie Góry,ta er nuo fu si kai gu lei,taleunopeuseukieguli,Тарновске Гори,Тарновске-Гуры,Тарновскје Гори,Тарновські Гури,タルノフスキェ・グルィ,塔爾諾夫斯凱古雷,타르노프스키에구리', 50.4454800, 18.8614700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111030, 'Tarnów Opolski', 'Tarnow Opolski', 'Tarnau,Tarnow,Tarnow Opolski,Tarnów,Tarnów Opolski', 50.5763100, 18.0836700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111031, 'Tarnowo Podgórne', 'Tarnowo Podgorne', '', 52.4664200, 16.6632600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111032, 'Tarnówka', 'Tarnowka', 'Tarnowka,Tarnowke,Tarnówka', 53.3417400, 16.8527300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111033, 'Targanice', 'Targanice', 'Targanica', 49.8057500, 19.3244400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111034, 'Szydłowo', 'Szydlowo', '', 53.1621200, 16.6117100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111035, 'Szubin', 'Szubin', 'Comuna de Szubin,Gmina Shubin,Gmina Szubin,Schubin,Shubin,Szubin,Шубин,Ґміна Шубін', 53.0096700, 17.7400000, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111036, 'Sztum', 'Sztum', 'Shhum,Shtum,Stuhm,Stuma,Stumas,Sztem,Sztum,Sztëm,ch tum,shen tu mu,Štuma,Štumas,Штум,Щум,ชตุม,什圖姆', 53.9207700, 19.0307200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111037, 'Szprotawa', 'Szprotawa', 'Shprotava,Sprotava,Sprotawa,Sprottau,Szprotawa,shen pu luo ta wa,Šprotava,Шпротава,什普羅塔瓦', 51.5656300, 15.5366400, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111038, 'Szlichtyngowa', 'Szlichtyngowa', 'Schlichtingsheim,Shlikhtingova,Shlikhtyngova,Slihtingova,Szlichtyngowa,shen li he teng ge wa,Šlihtingova,Шлихтингова,Шлихтынгова,Шліхтинґова,什利赫滕戈瓦', 51.7122200, 16.2442700, 'PL', '2015-09-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111039, 'Szlachta', 'Szlachta', '', 53.7682700, 18.1136700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111040, 'Szklarska Poręba', 'Szklarska Poreba', 'Schreiberhau,Schreibhau,Shklarska Poremba,Shkljars''ka Poremba,Shkljarska Poremba,Shkljarska-Poremba,Sklarska Poremba,Szklarska Porbe,Szklarska Poreba,Szklarska Poręba,ashklarska prmba,shen ke la er si ka-bo lun ba,Šklarska Poremba,Шкларска Поремба,Шклярска Поремба,Шклярска-Поремба,Шклярська Поремба,اشکلارسکا پرمبا,什克拉爾斯卡-波倫巴', 50.8256700, 15.5227400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111041, 'Szemud', 'Szemud', 'Shemud,Szemold,Szemud,Szëmôłd,Шемуд', 54.4870900, 18.2228000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111042, 'Szczytna', 'Szczytna', 'Scitna,Shchitna,Shhitna,Zhitna,Ščitna,Житна,Шчитна,Щитна', 50.4134300, 16.4474300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111043, 'Szczyrk', 'Szczyrk', 'Scirka,Shchirk,Shhirk,Szczyrk,shen qie er ke,Ščirka,Шчирк,Щирк,什切爾克', 49.7172400, 19.0318300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111044, 'Szczutowo', 'Szczutowo', 'Szczutowo,Szszutowo', 52.9404700, 19.5743800, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111045, 'Szczerców', 'Szczercow', 'Szczercow,Szczerców,szrzwb,שצרצוב', 51.3331900, 19.1097700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111046, 'Szczepanów', 'Szczepanow', '', 51.1979600, 16.6106400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111047, 'Szczekociny', 'Szczekociny', 'Gorad Shchehkaciny,Scekocini,Shchekochini,Shchekocini,Shhekocini,Shhekociny,Szczekociny,shen qie ke qi nei,syuchekochini,szqwzyny,Ščekocini,Горад Шчэкаціны,Шчекочини,Шчекоћини,Щекоцини,Щекоцины,שצקוציני,什切科齊內,슈체코치니', 50.6266900, 19.8250000, 'PL', '2011-06-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111048, 'Szczecinek', 'Szczecinek', 'Gorad Shchacinak,Neustettin,Neustettiu,Scecineka,Scecinekas,Shchechinek,Shchecinek,Shhecinek,Szczecenko,Szczecinek,Szczecënkò,shen qie qi nei ke,Ščecineka,Ščecinekas,Горад Шчацінак,Шчечинек,Шчећинек,Щецинек,什切齊內克', 53.7079100, 16.6993700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111049, 'Szczecin', 'Szczecin', 'Estetino,Estettin,Gorad Shchehcin,SZZ,Scecin,Scecina,Scecinas,Scetsin,Shchechin,Shchecin,Shchekin,Shchetsin,Shchétsin,Shhechin,Shhecin,Stetin,Stettin,Stettino,Stettinum,Stsetsin,Szczecin,Szczetno,Szczëtno,Sztetin,shchchyn,shchetsini,shen qie qing,shshychn,shttyn,shuchechin,stecina,syuchechin,sz''z''yn,Şçetsin,Şçeçin,Štetín,Štětín,Šćećin,Ščecin,Ščecina,Ščecinas,Στσέτσιν,Горад Шчэцін,Шчечин,Шчећин,Шчеќин,Шчэцін,Щецин,Щечин,שטעטין,שצ''צ''ין,شتتين,ششیچن,شچچین,श्टेचिन,შჩეცინი,シュチェチン,什切青,슈체친', 53.4289400, 14.5530200, 'PL', '2012-01-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111050, 'Szczawno-Zdrój', 'Szczawno-Zdroj', 'Bad Salzbrunn,Ober Salzbrunn,Scavnozdroja,Shchavno-Zdroj,Shhavno-Zdruj,Solice Zdroj,Solice-Zdruj,Solice-Zdrůj,Szczawno Zdroj,Szczawno Zdrój,Szczawno-Zdroj,Szczawno-Zdrój,shchawnw-zdrwyy,Ščavnozdroja,Шчавно-Здрој,Щавно-Здруй,شچاونو-زدروئی', 50.8035200, 16.2565500, 'PL', '2010-11-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111051, 'Szczaniec', 'Szczaniec', '', 52.2687400, 15.6817000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111052, 'Szamotuły', 'Szamotuly', 'Gorad Shamatuly,Samotuli,Samter,Shamotuli,Shamotuly,Szamotuly,Szamotuły,sha mo tu wei,shamoto~uu~i,Šamotuli,Горад Шаматулы,Шамотули,Шамотулы,シャモトゥウィ,沙莫圖維', 52.6120100, 16.5779400, 'PL', '2015-04-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111053, 'Szamocin', 'Szamocin', 'Samotschin,Szamocin', 53.0279500, 17.1265300, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111054, 'Szadek', 'Szadek', 'Sadeka,Shadek,Szadek,sha dai ke,Šadeka,Шадек,שאדיק,שאדק,沙代克', 51.6917400, 18.9754900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111055, 'Syrynia', 'Syrynia', '', 50.0200400, 18.3459700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111056, 'Sypniewo', 'Sypniewo', 'Sypniewo,Zippnow', 53.4682300, 16.6058300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111057, 'Sypniewo', 'Sypniewo', '', 53.3698100, 17.3269000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111058, 'Syców', 'Sycow', 'Gross Wartenberg,Sicov,Sicova,Sicuv,Sycow,Sycuv,Sycuw,Syców,Sycůw,se chu fu,Сицов,Сицув,Сыцув,瑟楚夫', 51.3081400, 17.7197900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111059, 'Świnoujście', 'Swinoujscie', 'Gorad Svinaujs''ce,Sbinooustsie,Shvinoujshche,Svinouiscis,Svinoujs''ce,Svinoujsce,Svinoujshce,Svinousti,Svinouyscie,Svinoústí,Swienemuenn,Swienemünn,Swina,Swinemude,Swinemunde,Swinemüde,Swinemünde,Swinioujscie,Swinmunde,Swinmutha,Swinoujsce,Swinoujscie,Swīnmūþa,ashwynwawyshchh,chfi nx xu xichche,shifinouishiche,sibinou-isichie,svinujsi,swwynwz''y,xi wei nuo wu yi xi qie,Świnoujście,Świnoujśće,Σβινόουστσιε,Горад Свінауйсьце,Свиноуйсьце,Свиноујшће,Свіноуйсьце,Швиноуйшче,סווינוצ''י,اشوینواویشچه,स्विनूज्सी,ชฟีนออูอีชเช,シフィノウイシチェ,希維諾烏伊希切,시비노우이시치에', 53.9105300, 14.2471200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111060, 'Świnna', 'Swinna', '', 49.6580200, 19.2540600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111061, 'Świnice Warckie', 'Swinice Warckie', 'Svinice-Varcke,Swinice,Swinice Warckie,Świnice,Świnice Warckie,Свинице-Варцке', 52.0407200, 18.9178600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111062, 'Świętochłowice', 'Swietochlowice', 'Sbietochlobitse,Schweintochlitz,Schwientochlowitz,Shventokhlovice,Sventochlovices,Sventochlovicės,Sventohlovice,Sventokhlovice,Svintohuvitso,Svjentokhlovice,Svjetohlovice,Swietochlowice,Swjyntochlowicy,ashfyntwkhwwytsh,shfyntwkhwfytsh,shifientofuu~ovu~itsu~e,sibiengtoheuwobiche,swwyyntwhlwbyzh,xi wei tuo he luo wei cai,Świętochłowice,Śwjyntochlowicy,Ŝvintohuvitso,Σβιετοχλόβιτσε,Свентохловице,Свентохловіце,Свјентохловице,Швентохловице,שוויינטוחלוביצה,اشفینتوخوویتسه,شفينتوخوفيتسه,シフィエントフウォヴィツェ,希维托赫洛维采,시비엥토흐워비체', 50.2963600, 18.9172600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111063, 'Święta Katarzyna', 'Swieta Katarzyna', 'Kattern,Swieta Katarzyna,Świeta Katarzyna', 51.0259600, 17.1146400, 'PL', '2013-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111064, 'Świerzno', 'Swierzno', 'Schwirsen,Swierzno,Świerzno', 53.9649700, 14.9654400, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111065, 'Świerzawa', 'Swierzawa', 'Schoenau am Katzbach,Schönau am Katzbach,Shvezhava,Svezava,Svezhava,Svežava,Svjezhava,Swierzawa,Szunaw,Świerzawa,Свежава,Свјежава,Швежава', 51.0137500, 15.8951600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111066, 'Świerklany Górne', 'Swierklany Gorne', '', 50.0276500, 18.5905000, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111067, 'Świerklany Dolne', 'Swierklany Dolne', '', 50.0182700, 18.5770200, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111068, 'Świerklaniec', 'Swierklaniec', 'Swierklaniec,Świerklaniec', 50.4423700, 18.9373400, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111069, 'Świerczów', 'Swierczow', 'Schwirz,Swierczow,Świerczów', 50.9601600, 17.7588000, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111070, 'Świeradów-Zdrój', 'Swieradow-Zdroj', 'Bad Flinsberg,Flinsberg Zdroj,Flinsberg Zdrój,Shveraduv-Zdruj,Sveradovzdroja,Sveraduv-Zdruj,Svjeradov-Zdroj,Swieradow-Zdroj,Swieradow-Zdroj/Bad Flinsberg,Swieradow-zdroj,xi wei la du fu-zi de lu yi,Świeradów-Zdrój,Świeradów-zdrój,Сверадув-Здруй,Свјерадов-Здрој,Шверадув-Здруй,希維拉杜夫-茲德魯伊', 50.9092000, 15.3430900, 'PL', '2016-02-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111071, 'Świekatowo', 'Swiekatowo', '', 53.4186400, 18.0973100, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111072, 'Świedziebnia', 'Swiedziebnia', '', 53.1520700, 19.5546300, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111073, 'Świebodzin', 'Swiebodzin', 'Comuna de Swiebodzin,Comuna de Świebodzin,Gmina Svebodzin,Gmina Swiebodzin,Gmina Świebodzin,Schweibus,Schwiebus,Svebodzin,Свебодзин,Ґміна Свебодзін', 52.2475100, 15.5335500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111074, 'Świecie nad Osą', 'Swiecie nad Osa', '', 53.4440000, 19.1017100, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111075, 'Święciechowa', 'Swieciechowa', 'Schwetzkau,Swieciechowa,Święciechowa', 51.8550300, 16.4980500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111076, 'Świecie', 'Swiecie', 'Comuna de Swiecie,Comuna de Świecie,Gmina Svece,Gmina Swiecie,Gmina Świecie,Schwetz,Svece,Swiecie,Świecie,Свеце,Ґміна Свеце', 53.4095300, 18.4474200, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111077, 'Świebodzice', 'Swiebodzice', 'Freiburg,Freiburg in Schlesien,Frybork,Shvebodzhice,Svebodzice,Svebodzices,Svebodzicės,Swiebodzice,swwyybwdzyzh,xi wei bo ji cai,Świebodzice,Свебодзице,Свебодзіце,Свјебођице,Швебоджице,שווייבודזיצה,希維博濟采', 50.8597500, 16.3282000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111078, 'Świdwin', 'Swidwin', 'Gorad Svidvin,Schivelbein,Shvidvin,Skwilbeno,Skwilbëno,Svidvin,Svidvina,Svidvinas,Swibowina,Swidwin,xi wei de wen,Świdwin,Горад Свідвін,Свидвин,Свідвин,Швидвин,希維德溫', 53.7746400, 15.7767100, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111079, 'Świdnica', 'Swidnica', 'Schweinitz,Swidnica,Świdnica', 51.8883600, 15.3901300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111080, 'Świdnica', 'Swidnica', 'Schweidnitz,Schweidnitz-Schlesian,Schweinitz,Shvidnica,Svidnica,Svidnice,Svidnicja,Svidņica,Svídnice,Swidnica,swwydnyzh,xi wei de ni cha,Świdnica,Свидница,Свидњица,Свідниця,Швидница,שווידניצה,希维德尼察', 50.8437800, 16.4885900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111081, 'Świątniki Górne', 'Swiatniki Gorne', 'Shv''ontniki Gorne,Sv''ontniki-Gurne,Svjontniki Gorne,Svjontniki Gurni,Svjontniki-Gurne,Svjontņiki Gurni,Swiatniki Gorne,Świątniki Górne,Свьонтники-Ґурне,Свёнтники-Гурне,Свјонтњики Горне,Швьонтники Горне', 49.9342900, 19.9536400, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111082, 'Swarzędz', 'Swarzedz', 'Gorad Svazhehndz,Svazendza,Svazendzas,Svazhendz,Svažendza,Svažendzas,Swarzedz,Swarzędz,si wa ren ci,Горад Сважэндз,Сважендз,斯瓦任兹', 52.4128900, 17.0850300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111083, 'Suszec', 'Suszec', '', 50.0295800, 18.7916000, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111084, 'Susz', 'Susz', 'Rosenberg,Rosenburg,Sesz,Susa,Susas,Sush,Susz,Suša,Sušas,Sësz,swsh,Суш,سوش', 53.7174300, 19.3364500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111085, 'Sułów', 'Sulow', 'Sulau,Sulejewo,Sulow,Sułów', 51.4996600, 17.1681100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111086, 'Sułoszowa', 'Suloszowa', '', 50.2678900, 19.7328200, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111087, 'Sulmierzyce', 'Sulmierzyce', 'Sul''mezhice,Sulmezice,Sulmežice,Sulmierzyce,Sulmjezhice,Сулмјежице,Сульмежице', 51.6059400, 17.5305300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111088, 'Sulmierzyce', 'Sulmierzyce', '', 51.1845600, 19.1959500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111089, 'Sułkowice', 'Sulkowice', 'Sulkovice,Sulkowice,Sułkowice,Сулковице,Сулковіце', 49.8405300, 19.8009700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111090, 'Sułkowice', 'Sulkowice', '', 49.8193200, 19.3598800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111091, 'Borne Sulinowo', 'Borne Sulinowo', 'Borne Sulinovas,Borne Sulinovo,Borne Sulinowo,Borne-Sulinovo,Lepa,Linde,Linde bei Krangen,Lindee,Lëpa,Sulinowo,bo er nei su li nuo wo,Борне Сулиново,Борне-Сулиново,Борне-Суліново,博爾內蘇利諾沃', 53.5766100, 16.5339500, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111092, 'Sulików', 'Sulikow', 'Schonberg,Schonberg in der Oberlausitz,Schonberg ober Lausitz,Schönberg,Schönberg in der Oberlausitz,Schönberg ober Lausitz,Sulikow,Sulików', 51.0762400, 15.0679200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111093, 'Sulejów', 'Sulejow', 'Sulejov,Sulejova,Sulejow,Sulejuv,Sulejów,Сулеюв,Сулејов', 51.3543600, 19.8853800, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111094, 'Sulęczyno', 'Suleczyno', 'Seleczeno,Sëlëczëno', 54.2330200, 17.7733000, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111095, 'Sulęcin', 'Sulecin', 'Cielecin,Comuna de Sulecin,Comuna de Sulęcin,Gmina Sulecin,Gmina Sulencin,Gmina Sulęcin,Sulencin,Zielenzig,Суленцин,Ґміна Суленцин', 52.4442900, 15.1167600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111096, 'Sulechów', 'Sulechow', 'Cylichow,Cylichów,Gorad Sulekhau,Sulechow,Sulechuvas,Sulechów,Sulehova,Sulekhov,Sulekhuv,Zullichau,Züllichau,su lai hu fu,surefufu,Горад Сулехаў,Сулехов,Сулехув,スレフフ,苏莱胡夫', 52.0836200, 15.6251300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111097, 'Suchy Las', 'Suchy Las', '', 52.4730800, 16.8774500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111098, 'Suchy Dąb', 'Suchy Dab', 'Suchy Dab,Suchy Dąb,Zugdam', 54.2080900, 18.7673100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111099, 'Suchań', 'Suchan', 'Sechan,Suhana,Suhaņa,Sukhan,Sukhan'',Sëchąń,Zachan,Сухань,Сухањ', 53.2800300, 15.3254100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111100, 'Sucha Beskidzka', 'Sucha Beskidzka', 'Sucha,Suha Beskidzka,Sukha Beskidska,Sukha Beskidzka,Sukha-Beskidz''ka,Sukha-Beskidzka,bei si ji de de qu su ha,swcha bskytska,swtsha bskytska,Суха Бескидзка,Суха Бескидска,Суха-Бескидзка,Суха-Бескидзька,سوتشا بسكيتسكا,سوچا بسکیتسکا,貝斯基德地區蘇哈', 49.7418800, 19.5942900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111101, 'Subkowy', 'Subkowy', 'Subkovy,Subkowy,Субковы', 54.0022700, 18.7692800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111102, 'Studzionka', 'Studzionka', 'Studzionka', 49.9623200, 18.7728000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111103, 'Studzienice', 'Studzienice', 'Comuna Studzienice,Comuna de Studzienice,Gmina Stedzence,Gmina Studzenice,Gmina Studzienice,Gmina Stëdzéńce,Studzenice,Studzienice,Студзенице,Ґміна Студзеніце', 54.0926200, 17.5758100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111104, 'Strzyżowice', 'Strzyzowice', '', 50.3872500, 19.0803800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111105, 'Strzelno', 'Strzelno', 'Strzelno', 54.7856400, 18.3251500, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111106, 'Strzelno', 'Strzelno', 'Strelno,Strzelno,Stselno,Stshel''no,Stshelno,Stšelno,si qie er nuo,Стшелно,Стшельно,斯切爾諾', 52.6278900, 18.1724600, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111107, 'Strzelin', 'Strzelin', 'Comuna de Strzelin,Gmina Strzelin,Gmina Stshelin,Strehlen,Strzelin,Stshelin,Стшелин,Ґміна Стшелін', 50.7815700, 17.0647700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111108, 'Strzeleczki', 'Strzeleczki', '', 50.4621500, 17.8566500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111109, 'Strzelce Wielkie', 'Strzelce Wielkie', 'Strzelce Wielki,Strzelce Wielkie', 51.1394000, 19.1453900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111110, 'Strzelce Opolskie', 'Strzelce Opolskie', 'Gross Strehlitz,Gross Strohlitz,Groß Strehlitz,Opoles Stselces,Opolės Stšelcės,Strehlitz,Strzelce,Strzelce Opolskie,Stselce Opolske,Stshel''ce-Opol''s''ki,Stshel''ce-Opol''ske,Stshelce Opolske,Stshelce Opolskje,Stšelce Opolske,Uopolske Strzelce,si qie er cai ao bo lai si ji,Стшелце Ополске,Стшелце Ополскје,Стшельце-Опольске,Стшельце-Опольські,ซตแชลต์แซออปอลสกีแย,斯切爾采奧波萊斯基', 50.5107000, 18.3005600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111111, 'Strzelce Krajeńskie', 'Strzelce Krajenskie', 'Friedeberg,Friedeberg in Neumark,Strzelce,Strzelce Krainskie,Strzelce Kraińskie,Strzelce Krajenskie,Strzelce Krajeńskie,Strzelcé,Stselce Krajenske,Stshel''ce-Kraen''ske,Stshel''ce-Kraens''ke,Stshelce Krajenske,Stshelce Krajenskje,Stšelce Krajeņske,si qie er cai-ke la yan si kai,Стшелце Крайенске,Стшелце Крајењскје,Стшельце-Краеньске,Стшельце-Краєнське,斯切爾采-克拉延斯凱', 52.8772600, 15.5297800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111112, 'Strzelce', 'Strzelce', '', 52.3147800, 19.4070100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111113, 'Strzegom', 'Strzegom', 'Striegau,Strzegom,Strzyglow,Strzygłow,Stsegoma,Stshegom,Stšegoma,si qie ge mu,Стшегом,Стшеґом,斯切戈姆', 50.9626400, 16.3500600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111114, 'Strzebiń', 'Strzebin', '', 50.6164700, 18.8979400, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111115, 'Strzałkowo', 'Strzalkowo', '', 52.3070100, 17.8181100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111116, 'Stryszów', 'Stryszow', '', 49.8256900, 19.6176300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111117, 'Stryszawa', 'Stryszawa', '', 49.7132700, 19.5218500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111118, 'Stryków', 'Strykow', 'Strikov,Strikova,Strikuv,Strykow,Strykuv,Stryków,si te lei ku fu,stryqwb,Стриков,Стрикув,Стрыкув,סטריקוב,斯特雷庫夫', 51.9022400, 19.6053600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111119, 'Strumień', 'Strumien', 'Strumien,Strumień', 49.9210300, 18.7663700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111120, 'Stróża', 'Stroza', '', 49.7962800, 19.9237900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111121, 'Stronie Śląskie', 'Stronie Slaskie', 'Seitenberg,Seitenberg Grafschaft Glatz,Strone Slonske,Strone-Shl''ons''ki,Strone-Sljonske,Stronie Slaskie,Stronie Śląskie,Stroņe Slonske,si tuo ni la si qi,Строне-Слёнске,Строне-Шльонські,Строње Слонске,斯托尼拉斯奇', 50.2955400, 16.8739700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111122, 'Stronie', 'Stronie', '', 49.8305600, 19.6749700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111123, 'Straszyn', 'Straszyn', 'Straschin,Straszyn', 54.2721400, 18.5811400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111124, 'Stoszowice', 'Stoszowice', 'Stoszowice', 50.5998600, 16.7389600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111125, 'Stężyca', 'Stezyca', 'Gmina Stazeca,Gmina Stenzhicja,Gmina Stezyca,Gmina Stãżëca,Gmina Stężyca,Stenzhica,Stezyca,Stezyca Krolewska,Stężyca,Stężyca Królewska,Стенжица,Ґміна Стенжиця', 54.2059300, 17.9556900, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111126, 'Stęszew', 'Steszew', 'Stenseva,Stenshev,Stenševa,Steszew,Stęszew,si teng xie fu,Стеншев,斯滕謝夫', 52.2837000, 16.7008500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111127, 'Stepnica', 'Stepnica', 'Gross Stepenitz,Stepenitz,Stepnica,Stepnitz,Stobnica,Stopnica,Степњица', 53.6518700, 14.6255500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111128, 'Stegna', 'Stegna', 'Steegen,Stegna,Стегна', 54.3268400, 19.1125200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111129, 'Stawiszyn', 'Stawiszyn', 'Stavishin,Stavisina,Stavišina,Stawiszyn,si ta wei shen,Ставишин,Ставішин,斯塔維申', 51.9178600, 18.1117100, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111130, 'Stary Targ', 'Stary Targ', 'Altmark,Stary Targ,Stary-Targ,Стары-Тарг', 53.9233500, 19.1700300, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111131, 'Staroźreby', 'Starozreby', 'Staroz''reby,Starozreby,Staroźreby,Старозьребы', 52.6326500, 19.9855000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111132, 'Starowa Góra', 'Starowa Gora', '', 51.6913400, 19.4837400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111133, 'Starokrzepice', 'Starokrzepice', '', 50.9485900, 18.6534100, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111134, 'Starogard Gdański', 'Starogard Gdanski', 'Gdansko Starogardas,Starogard,Starogard Gdanski,Starogard Gdański,Starogard-Gdan''ski,Starogard-Gdan''skij,Starogard-Gdans''kij,Starogarda,Starogarda Gdanska,Starogarda Gdaņska,astarwgard gdansky,ge dan si ke jiu cheng,Старогард Гдански,Старогард Гдањски,Старогард-Гданьски,Старогард-Гданьский,Старогард-Ґданський,استاروگارد گدانسکی,スタロガルド・グダニスキ,格但斯克舊城', 53.9639600, 18.5263800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111135, 'Stargard', 'Stargard', 'Gorad Stargard,Stargard,Stargard Shchechinski,Stargard Szczecinski,Stargard Szczeciński,Stargard-Shhecins''kij,Stargarda,Stargardas,Stargardia,Starnkarnt,Starogrod,Storgard,Stôrgard,Szczecinski Stargard,Szczećiński Stargard,astargart ashchchynsky,s tar kard chche ching ski,seutaleugaleuteusyuchechinseuki,shen qie qing jiu cheng,starghard ztsysynsky,sutarugaruto,Στάργκαρντ,Горад Старгард,Старгард,Старгард Шчечински,Старгард-Щецинський,استارگارت اشچچینسکی,ستارغارد زتسيسينسكي,สตาร์การ์ดชเชชีงสกี,スタルガルト,什切青旧城,스타르가르트슈체친스키', 53.3367200, 15.0499000, 'PL', '2017-05-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111136, 'Stare Pole', 'Stare Pole', 'Altfelde,Stare Pole,Stare-Pole,Старе-Поле', 54.0566700, 19.2087400, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111137, 'Stare Miasto', 'Stare Miasto', '', 52.1797200, 18.2149900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111138, 'Stare Kurowo', 'Stare Kurowo', '', 52.8566900, 15.6774900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111139, 'Stare Czarnowo', 'Stare Czarnowo', 'Neumark', 53.2786100, 14.7790600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111140, 'Stare Bogaczowice', 'Stare Bogaczowice', 'Stare Bogaczowice', 50.8475200, 16.1930800, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111141, 'Starcza', 'Starcza', '', 50.6642100, 19.0418000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111142, 'Stara Kiszewa', 'Stara Kiszewa', 'Kiszewa Stara,Stara Kiszewa,Staro Cziszewa,Starô Cziszewa', 53.9900600, 18.1695800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111143, 'Stara Kamienica', 'Stara Kamienica', 'Stara Kamienica,Stara Kamienice', 50.9160200, 15.5728600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111144, 'Stara Dąbrowa', 'Stara Dabrowa', 'Alt Damerow,Stara Dabrowa,Stara Dąbrowa', 53.4219100, 15.1440500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111145, 'Stanowice', 'Stanowice', '', 50.9310600, 16.3742600, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111146, 'Stanowice', 'Stanowice', '', 50.1303700, 18.6708400, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111147, 'Stanisław Górny', 'Stanislaw Gorny', 'Stanislaw Gorny,Stanistaw Gony,Stanisław Górny', 49.9115500, 19.6293100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111148, 'Stanisław Dolny', 'Stanislaw Dolny', '', 49.9047000, 19.6533400, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111149, 'Środa Wielkopolska', 'Sroda Wielkopolska', 'Didziosios Lenkijos Sroda,Didžiosios Lenkijos Sroda,Gorad S''roda-Vel''kapol''ska,S''roda-Vel''kopol''ska,S''roda-Velikopol''s''ka,Schroda,Shroda Velkopolska,Sroda,Sroda Velkopolska,Sroda Vjelkopolska,Sroda Wielkopolska,da bo lan de qu xi luo da,Środa,Środa Wielkopolska,Горад Сьрода-Велькапольска,Срода Вјелкополска,Сьрода-Великопольська,Сьрода-Велькопольска,Шрода Велкополска,大波蘭地區希羅達', 52.2284300, 17.2761700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111150, 'Środa Śląska', 'Sroda Slaska', 'Neumarkt,Neumarkt in Schlesieu,Noviforum,S''roda-Shl''ons''ka,S''roda-Sljonska,Shroda Shl''onska,Sroda,Sroda Slaska,Sroda Slonska,xi long si ke de qu xi luo da,Środa Śląska,Срода Слонска,Сьрода-Слёнска,Сьрода-Шльонська,Шрода Шльонска,希隆斯克地區希羅達', 51.1640600, 16.5950800, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111151, 'Śrem', 'Srem', 'Comuna de Srem,Comuna de Śrem,Gmina S''rem,Gmina Srem,Gmina Śrem,S''rem,Srem,Śrem,Срем,Сьрем,Ґміна Сьрем', 52.0886800, 17.0150800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111152, 'Spytkowice', 'Spytkowice', 'Spytkewice,Spytkowice', 49.9967100, 19.5110300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111153, 'Spytkowice', 'Spytkowice', '', 49.5774400, 19.8334100, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111154, 'Sosnówka', 'Sosnowka', '', 50.8183000, 15.7231500, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111155, 'Sosnowiec', 'Sosnowiec', 'Sosnovec,Sosnoveca,Sosnovecas,Sosnovice,Sosnowez,Sosnowiec,Sossnowitz,Сосновец', 50.2868200, 19.1038500, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111156, 'Sosnowice', 'Sosnowice', '', 49.9399500, 19.7151400, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111157, 'Sośno', 'Sosno', '', 53.3892200, 17.6871300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111158, 'Sośnie', 'Sosnie', 'Sosnie,Sosnie Na Gorach,Sośnie,Sośnie Na Górach', 51.4731500, 17.6338300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111159, 'Sośnicowice', 'Sosnicowice', 'Kiefernstadtel,Kiefernstädtel,Kieferstadtel,Kieferstädtel,Sosnicowice,Sośnicowice', 50.2721400, 18.5298200, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111160, 'Sopotnia Wielka', 'Sopotnia Wielka', '', 49.5685300, 19.2828900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111161, 'Sopot', 'Sopot', 'Gorad Sopat,Sopot,Sopota,Sopotas,Sopoty,Sopòt,Zoppot,sopoteu,sopoto,suo bo te,swbwt,swpwt,Горад Сопат,Сопот,سوبوت,سوپوت,ソポト,索波特,소포트', 54.4418000, 18.5600300, 'PL', '2011-12-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111162, 'Sompolno', 'Sompolno', 'Comuna de Sompolno,Deutscheneck,Gmina Sompol''no,Gmina Sompolno,Sompol''no,Sompolno,Сомпольно,Ґміна Сомпольно', 52.3883200, 18.5028200, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111163, 'Somonino', 'Somonino', 'Somonino,Somònino,Сомонино', 54.2755500, 18.1988500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111164, 'Solec Kujawski', 'Solec Kujawski', 'Schulitz,Solec Kujavski,Solec Kujawski,Solec Kujawski…,Solec''-Kujavs''kij,Solec-Kujavski,Soleca Kujavska,ku ya wei de qu suo lai ci,Солец Куявски,Солец Кујавски,Солец-Куявски,Солець-Куявський,庫亞維地區索萊茨', 53.0837100, 18.2257200, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111165, 'Szczerbice', 'Szczerbice', '', 50.0941600, 18.4489600, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111166, 'Sól', 'Sol', '', 49.4876400, 19.0417100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111167, 'Sokolniki', 'Sokolniki', 'Comuna de Sokolniki,Gmina Sokol''niki,Gmina Sokolniki,Sokol''niki,Сокольники,Ґміна Сокольники', 51.3073800, 18.3327500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111168, 'Sobótka', 'Sobotka', 'Sobotka,Sobutka,Sobótka,Zobten,Zobten am Berge,suo bu te ka,Соботка,Собутка,索布特卡', 50.8999200, 16.7444100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111169, 'Smolec', 'Smolec', 'Schmolz,Smolec,Smolice', 51.0732200, 16.8822100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111170, 'Smołdzino', 'Smoldzino', 'Schmolsin', 54.6631800, 17.2136900, 'PL', '2015-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111171, 'Śmiłowo', 'Smilowo', '', 53.1364700, 16.9207500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111172, 'Śmigiel', 'Smigiel', 'Smigel,Smigel'',Smigela,Smigiel,xi mi gai er,Śmigiel,Смигел,Смигель,Смігель,希米蓋爾', 52.0133900, 16.5270400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111173, 'Smętowo Graniczne', 'Smetowo Graniczne', '', 53.7463800, 18.6858600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111174, 'Słupsk', 'Slupsk', 'Gorad Slupsk,Slups''k,Slupsk,Slupska,Slupskas,Stolp,Stolp in Pommern,Stolpe,Stolpsk,Stôłpsk,Słupsk,seuubseukeu,si wu pu si ke,suupusuku,swwbsk,swwpsk,Горад Слупск,Слупск,Слупськ,سووبسك,سووپسک,スウプスク,斯武普斯克,스웁스크', 54.4640500, 17.0287200, 'PL', '2016-10-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111175, 'Słupno', 'Slupno', 'Slupno,Słupno,Слупно', 52.5058800, 19.8373600, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111176, 'Słupia', 'Slupia', '', 51.8551800, 19.9699700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111177, 'Słupia pod Kępnem', 'Slupia pod Kepnem', '', 51.2392400, 18.0425500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111178, 'Słupia', 'Slupia', '', 50.6007300, 19.9743500, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111179, 'Słupca', 'Slupca', 'Slupca,Słupca,si wu pu cha,Слупца,斯武普察', 52.2873300, 17.8719200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111180, 'Słubice', 'Slubice', 'Gmina Slubice,Gmina Słubice,Slubice,Słubice,Слубице,Ґміна Слубіце', 52.3694200, 19.9388100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111181, 'Słubice', 'Slubice', 'Damm-Vorstadt,Slubice,Slubices,Slubicės,Słubice,Zliwice,Zliwitz,seuubiche,si wu bi cai,slubitse,slwbyzh,Слубице,Слубіце,סלוביצה,სლუბიცე,斯武比采,스우비체', 52.3508800, 14.5606500, 'PL', '2015-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111182, 'Słońsk', 'Slonsk', 'Sonnenburg', 52.5634500, 14.8052600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111183, 'Śliwice', 'Sliwice', 'Comuna de Sliwice,Comuna de Śliwice,Gmina Slivice,Gmina Sliwice,Gmina Śliwice,Slivice,Sliwice,Śliwice,Сливице,Ґміна Слівіце', 53.7087500, 18.1737000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111184, 'Ślesin', 'Slesin', '', 53.1651400, 17.7025800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111185, 'Ślesin', 'Slesin', 'Slesin,Slesina,xi lai xin,Ślesin,Слесин,Слесін,שלעשין,希萊辛', 52.3703900, 18.3064400, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111186, 'Ślemień', 'Slemien', 'Slemien,Ślemień', 49.7182600, 19.3673500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111187, 'Sławoborze', 'Slawoborze', 'Slawoborze,Stolzenberg,Sławoborze', 53.8899200, 15.7066700, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111188, 'Sławno', 'Slawno', 'Gorad Slauna,Schlawe,Slavno,Slawno,Slowno,Sławno,Słôwno,si wa fu nuo,Горад Слаўна,Славно,斯瓦夫諾', 54.3627600, 16.6788800, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111189, 'Sławków', 'Slawkow', 'Slavkov,Slavkova,Slavkuv,Slawkuw,Sławkůw,si wa fu ku fu,slwwqwb,suwafukufu,Славков,Славкув,סלווקוב,スワフクフ,斯瓦夫庫夫', 50.2994300, 19.3896700, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111190, 'Sławięcice', 'Slawiecice', 'Ehrenforst,Slawecice,Slawensitz,Slawiecice,Sławięcice,Sławęcice', 50.3720700, 18.3217600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111191, 'Sława', 'Slawa', 'Schlawa,Schlawa Schlesien,Schlesiersee,Slava,Slawa,Sława,si wa wa,Слава,斯瓦瓦', 51.8762300, 16.0720500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111192, 'Skwierzyna', 'Skwierzyna', 'Schwerin,Skvezhina,Skvezina,Skvežina,Skvjezhina,Skwierzyna,si ke wei ri na,Сквежина,Сквјежина,斯克維日納', 52.5991400, 15.5065200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111193, 'Skulsk', 'Skulsk', 'Skul''sk,Skuls,Skulsk,Скульск', 52.4820000, 18.3311200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111194, 'Skrzyszów', 'Skrzyszow', 'Skrzyszow,Skrzyszów', 49.9487300, 18.4887900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111195, 'Skrwilno', 'Skrwilno', 'Skrvil''no,Skrwilno,Скрвильно', 53.0160700, 19.6236400, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111196, 'Skoroszyce', 'Skoroszyce', 'Friedewalde,Koppendorf Kolonia,Kubinow,Skoroszyce', 50.5964800, 17.3824300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111197, 'Skorogoszcz', 'Skorogoszcz', 'Schurgast,Skorogoszcz,Szurgoszcz', 50.7591600, 17.6819800, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111198, 'Skórcz', 'Skorcz', 'Skorca,Skorch,Skorcz,Skorča,Skurch,Skurcz,Skórcz,Skůrcz,si ku er qi,Скорч,Скурч,斯庫爾奇', 53.7943600, 18.5256100, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111199, 'Skomlin', 'Skomlin', '', 51.1708900, 18.3869900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111200, 'Skomielna Czarna', 'Skomielna Czarna', 'Skomielna,Skomielna Czarna', 49.7270900, 19.8363300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111201, 'Skoki', 'Skoki', 'Gorad Skoki,Schokken,Skoki,si ke ji,Горад Скокі,Скоки,Скокі,斯科基', 52.6722200, 17.1610700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111202, 'Skoczów', 'Skoczow', 'Skochov,Skochuv,Skocov,Skocova,Skoczow,Skoczów,Skočov,Skočova,si ke qiu fu,Скочов,Скочув,斯科丘夫', 49.8008900, 18.7877000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111203, 'Skępe', 'Skepe', 'Skempe,Skenpe,Skepe,Skępe,si ken pei,Скемпе,Скенпе,斯肯佩', 52.8679800, 19.3560400, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111204, 'Skawinki', 'Skawinki', '', 49.8228100, 19.7125600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111205, 'Skawina', 'Skawina', 'Skavina,Skawina,si ka wei na,Скавина,Скавіна,斯卡維納', 49.9752400, 19.8286900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111206, 'Skawica', 'Skawica', '', 49.6771800, 19.6232100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111207, 'Skarszewy', 'Skarszewy', 'Skarsevi,Skarshevi,Skarshevy,Skarszewe,Skarszewy,Skarszewë,Skarševi,si ka er xie wei,Скаршеви,Скаршевы,斯卡爾謝維', 54.0691100, 18.4441600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111208, 'Skąpe', 'Skape', 'Skampe,Skape,Skąpe', 52.1529200, 15.4584500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111209, 'Skalmierzyce', 'Skalmierzyce', 'Skalmierzyce,Skalmierzyce Stare', 51.7009700, 17.9633300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111210, 'Skała', 'Skala', 'Skala,Skała,si ka wa,Скала,斯卡瓦', 50.2305200, 19.8536300, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111211, 'Siewierz', 'Siewierz', 'Seveza,Sevezh,Seveža,Shevezh,Siewierz,Sjevjezh,xie wei ri,Севеж,Сјевјеж,Шевеж,謝維日', 50.4665700, 19.2302800, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111212, 'Sierpc', 'Sierpc', 'Serpc,Serpc'',Serpca,Serpts,Sherpc,Sierpc,Sjerpc,srpz,xie er pu ci,Серпц,Серпць,Сјерпц,Шерпц,שרפץ,謝爾普茨', 52.8568000, 19.6691300, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111213, 'Sieroszewice', 'Sieroszewice', '', 51.6334700, 17.9720000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111214, 'Sierakowice', 'Sierakowice', 'Gmina Serakovice,Gmina Sierakowice,Gmina Srokojce,Gmina Srôkòjce,Serakovice,Сераковице,Ґміна Сераковіце', 54.3461000, 17.8925200, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111215, 'Sieraków', 'Sierakow', 'Gorad Sjarakau,Serakova,Serakuv,Sierakow,Sieraków,Sjerakov,xie la ku fu,Горад Сяракаў,Серакув,Сјераков,謝拉庫夫', 52.6513400, 16.0804700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111216, 'Sieraków Śląski', 'Sierakow Slaski', 'Breitenmarkt,Schierokau,Sierakow,Sieraków', 50.8029000, 18.5754800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111217, 'Sieradz', 'Sieradz', 'Seradz,Seradza,Seradzas,Sheradz,Sieradz,Sieratz,Sjeradz,shyradz,xie la zi,Σίερατζ,Серадз,Сјерадз,Шерадз,שייראדז,شیرادز,謝拉茲', 51.5958400, 18.7302300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111218, 'Siepraw', 'Siepraw', '', 49.9143700, 19.9586400, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111219, 'Sieniawa Żarska', 'Sieniawa Zarska', 'Schonwalde,Schönwalde,Sieniawa Zarska,Sieniawa Żarska', 51.6400700, 15.0604500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111220, 'Sieniawa', 'Sieniawa', 'Schoenow,Schönow', 52.3634400, 15.3776800, 'PL', '2014-05-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111221, 'Sieniawa', 'Sieniawa', '', 49.5394700, 19.9301400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111222, 'Siemkowice', 'Siemkowice', '', 51.2019400, 18.8988000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111223, 'Siemianowice Śląskie', 'Siemianowice Slaskie', 'Semjanovice Slonske,Semjanovice-Shl''ons''ki,Semjanovice-Sljonske,Shemjanovice Silezko,Siemianowice,Siemianowice Slaskie,Siemianowice Śląskie,Siemianowitz,Silezijos Semianovicai,Symjanowicy,siemianobichesillongseukie,xi long si ke de qu xie mi ya nuo wei cai,Śymjanowicy,Семяновице-Слёнске,Семяновіце-Шльонські,Шемяновице Силезко,シェミャノヴィツェ・シロンスキェ,希隆斯克地區謝米亞諾維采,시에미아노비체실롱스키에', 50.3273800, 19.0290100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111224, 'Siekierczyn', 'Siekierczyn', 'Geibsdorf', 51.1221700, 15.1937500, 'PL', '2015-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111225, 'Siedlisko', 'Siedlisko', 'Carolath,Karolat,Siedlisko', 51.7686400, 15.8139600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111226, 'Siedlec', 'Siedlec', '', 52.1378100, 16.0027900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111227, 'Siechnice', 'Siechnice', 'Kraftborn,Siechnice,Tschechnitz', 51.0338400, 17.1474300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111228, 'Sidzina', 'Sidzina', '', 50.5737500, 17.4490400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111229, 'Sidzina', 'Sidzina', '', 49.9873200, 19.8749500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111230, 'Sidzina', 'Sidzina', 'Sidzina', 49.5914600, 19.7111900, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111231, 'Sicienko', 'Sicienko', 'Comuna Sicienko,Comuna de Sicienko,Gmina Sicenko,Gmina Sicienko,Sicenko,Wilhelmsort,Сиценко,Ґміна Сіценко', 53.2038700, 17.8005100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111232, 'Sianów', 'Sianow', 'Sanowo,Sanowò,Sianow,Sianów,Sjanov,Sjanova,Sjanuv,Zanow,xia nu fu,Сянув,Сјанов,夏努夫', 54.2264600, 16.2912700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111233, 'Sępólno Krajeńskie', 'Sepolno Krajenskie', 'Cembelburg,Krainskie,Kraińskie,Sapolno,Sempolno Krajenske,Sempul''no-Kraen''ske,Sempul''no-Kraens''ke,Sempulno Krajenske,Sempulno Krajeņske,Senpolno Krajenskje,Sepolno,Sepolno Krainskie,Sepolno Krajenskie,Sãpólno,Sępolno,Sępólno Kraińskie,Sępólno Krajeńskie,Zempelburg,sen pu er nuo-ke la yan si kai,Семполно Крайенске,Семпульно-Краеньске,Семпульно-Краєнське,Сенполно Крајењскје,森普爾諾-克拉延斯凱', 53.4519800, 17.5316900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111234, 'Sędziejowice', 'Sedziejowice', 'Comuna de Sedziejowice,Comuna de Sędziejowice,Gmina Sedziejowice,Gmina Sendzejovice,Gmina Sędziejowice,Sendzejovice,Сендзеёвице,Ґміна Сендзейовіце', 51.5067700, 19.0276300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111235, 'Secemin', 'Secemin', '', 50.7667600, 19.8359900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111236, 'Ścinawa', 'Scinawa', 'S''cinava,Scinava,Scinawa,Shcinava,Steinau,Steinau an der Oder,xi qi na wa,Ścinawa,Сьцинава,Шцинава,Шћинава,希齊納瓦', 51.4162600, 16.4251000, 'PL', '2013-10-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111237, 'Sarnów', 'Sarnow', '', 50.3738000, 19.1506100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111238, 'Sąspów', 'Saspow', '', 50.2288700, 19.7700700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111239, 'Santok', 'Santok', 'Santok,Zantoch', 52.7378500, 15.4102100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111240, 'Sanniki', 'Sanniki', 'Sanniki,Санники', 52.3304600, 19.8676600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111241, 'Sanka', 'Sanka', '', 50.0687100, 19.6459600, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111242, 'Sadlinki', 'Sadlinki', 'Sadlinki,Sedlinen,Садлинки', 53.6653900, 18.8680700, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111243, 'Sadki', 'Sadki', 'Sadke,Sadki,Schlossberg  Kr. Wirsitz,Schloßberg  Kr. Wirsitz', 53.1603600, 17.4491200, 'PL', '2017-05-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111244, 'Sączów', 'Saczow', '', 50.4352000, 19.0303800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111245, 'Rzyki', 'Rzyki', '', 49.8112900, 19.3961900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111246, 'Rzozów', 'Rzozow', '', 49.9539800, 19.7966800, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111247, 'Rzgów Pierwszy', 'Rzgow Pierwszy', '', 52.1513400, 18.0497600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111248, 'Rzeszotary', 'Rzeszotary', '', 49.9462500, 19.9728000, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111249, 'Rzepin', 'Rzepin', 'Reppen,Rypin Lubuski,Rzepin,Zepina,Zhepin,jepin,re ping,Žepina,Жепин,Жепін,ジェピン,熱平', 52.3464000, 14.8322700, 'PL', '2015-08-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111250, 'Rzeczenica', 'Rzeczenica', 'Rzeczenica,Stegers', 53.7579000, 17.1075200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111251, 'Rząska', 'Rzaska', '', 50.0971300, 19.8450900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111252, 'Rypin', 'Rypin', 'Ripin,Ripina,Rypin,lei ping,rypyn,Рипин,Рипін,Рыпин,ריפין,雷平', 53.0660300, 19.4094100, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111253, 'Rymań', 'Ryman', 'Roman,Ryman,Rymań', 53.9439100, 15.5286600, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111254, 'Ryjewo', 'Ryjewo', 'Rehhof,Ryjewo', 53.8446300, 18.9607700, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111255, 'Rydzyna', 'Rydzyna', 'Ridzina,Rydzyna,lei ji na,Ридзина,Рыдзына,雷濟納', 51.7865100, 16.6676100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111256, 'Rydułtowy', 'Rydultowy', 'Ridultovi,Rydultovai,Rydultovy,Rydultowy,Rydułtowy,Rydůłtowy,lei du wu tuo wei,Ридултови,Рыдултовы,雷杜烏托維', 50.0585700, 18.4170300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111257, 'Ryczywół', 'Ryczywol', 'Comuna de Ryczywol,Comuna de Ryczywół,Gmina Richivul,Gmina Ryczywol,Gmina Ryczywół,Rychivul,Рычивул,Ґміна Ричивул', 52.8132400, 16.8311400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111258, 'Ryczów', 'Ryczow', '', 49.9810300, 19.5501700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111259, 'Rychwał', 'Rychwal', 'Rihvala,Rikhval,Rychwal,Rychwał,Rykhval,lei he wa wu,Рихвал,Рыхвал,雷赫瓦烏', 52.0714900, 18.1651000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111260, 'Rychtal', 'Rychtal', '', 51.1453300, 17.8513200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111261, 'Rycerka Górna', 'Rycerka Gorna', '', 49.4443600, 19.0159600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111262, 'Rycerka Dolna', 'Rycerka Dolna', '', 49.4780500, 19.0616200, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111263, 'Rybno', 'Rybno', 'Comuna de Rybno,Gmina Ribno,Gmina Rybno,Komunumo Rybno,Rybno,Гміна Рибно,Рыбно', 53.3834800, 19.9322900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111264, 'Rybnik', 'Rybnik', 'Gorad Rybnik,Ribnik,Ribnika,Ribņika,Rimpnik,Rybnik,Rybnikas,Rybńik,lei bu ni ke,libeunikeu,rbnyk,ribuniku,rybnyk,Ρίμπνικ,Горад Рыбнік,Рибник,Рибњик,Рыбник,ربنیک,ريبنيك,リブニク,雷布尼克,리브니크', 50.0971300, 18.5417900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111265, 'Rybarzowice', 'Rybarzowice', '', 49.7295600, 19.1016200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111266, 'Rusocice', 'Rusocice', '', 49.9960400, 19.6064800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111267, 'Rusiec', 'Rusiec', 'Comuna Rusiec,Comuna de Rusiec,Gmina Rusec'',Gmina Rusiec,Rusec,Русец,Ґміна Русець', 51.3244400, 18.9850600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111268, 'Rumia', 'Rumia', 'Remio,Rumia,Rumija,Rumja,Rëmiô,lu mi ya,Румија,Румя,Румія,魯米亞', 54.5709200, 18.3880200, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111269, 'Rudziniec', 'Rudziniec', 'Rudgershagen,Rudziniec,Rudzinitz', 50.3532400, 18.4091400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111270, 'Rudziczka', 'Rudziczka', '', 50.0360800, 18.7622500, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111271, 'Rudy', 'Rudy', 'Gross Rauden,Rauden,Ruda,Rudy', 50.1900300, 18.4533400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111272, 'Rudniki', 'Rudniki', '', 50.8785100, 19.2461600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111273, 'Rudniki', 'Rudniki', '', 50.5213400, 19.4313000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111274, 'Rudnik', 'Rudnik', 'Herrenkirch,Rudnik', 50.1272900, 18.1859800, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111275, 'Rudnik', 'Rudnik', '', 49.8524300, 19.8474000, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111276, 'Rudna', 'Rudna', '', 51.5098100, 16.2636300, 'PL', '2012-08-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111277, 'Rudawa', 'Rudawa', 'Rudava,Rydava,Рyдaвa,Рудава', 50.1215100, 19.7123900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111278, 'Ruda Śląska', 'Ruda Slaska', 'Ruda,Ruda O.S.,Ruda Silezka,Ruda Slaska,Ruda Slonska,Ruda Śląska,Ruda-Shl''ons''ka,Ruda-Slenska,Ruda-Sljonskaja,Silezijos Ruda,Slunsko Ruda,lu da xi long si ka,ludasillongseuka,ru das lxn ska,rwda shlwska,Ślůnsko Ruda,Руда Силезка,Руда-Сленска,Руда-Слёнская,Руда-Шльонська,رودا شلوسکا,รูดาซลอนสกา,ルダ・シロンスカ,鲁达希隆斯卡,루다실롱스카', 50.2584000, 18.8563200, 'PL', '2016-08-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111279, 'Rozwadza', 'Rozwadza', '', 50.4349300, 18.0998000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111280, 'Rozprza', 'Rozprza', '', 51.3026600, 19.6457000, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111281, 'Rozdrażew', 'Rozdrazew', '', 51.7821800, 17.5049100, 'PL', '2010-10-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111282, 'Rościszewo', 'Rosciszewo', 'Ros''cishevo,Rosciszewo,Rościszewo,Росьцишево', 52.9033100, 19.7741900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111283, 'Rokitno Szlacheckie', 'Rokitno Szlacheckie', '', 50.4319500, 19.4329300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111284, 'Rokietnica', 'Rokietnica', '', 52.5124500, 16.7457000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111285, 'Rokiciny', 'Rokiciny', 'Kolonia Rokiciny,Rokiciny', 51.6507800, 19.8019100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111286, 'Rokiciny', 'Rokiciny', '', 49.5724300, 19.9230200, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111287, 'Rogóźno', 'Rogozno', 'Rogozno,Roguz''no,Rogóźno,Рогузьно', 53.5358700, 18.9285900, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111288, 'Rogoźno', 'Rogozno', 'Rogasen,Rogoz''no,Rogozno,Rogozno Wielkopolskie,Rogoźno,Roguz''no,Rogóźno Wielkopolskie,luo ge yi nuo,Рогозно,Рогозьно,Рогузьно,羅戈伊諾', 52.7522600, 16.9904900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111289, 'Rogoźnik', 'Rogoznik', '', 50.3910600, 19.0377600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111290, 'Rogowo', 'Rogowo', '', 52.9771200, 19.3848600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111291, 'Rogowo', 'Rogowo', '', 52.7244900, 17.6511700, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111292, 'Rogów', 'Rogow', '', 51.8175800, 19.8865400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111293, 'Rogów', 'Rogow', 'Rogow,Rogów', 49.9909700, 18.3507700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111294, 'Rogalinek', 'Rogalinek', '', 52.2494500, 16.8998900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111295, 'Roczyny', 'Roczyny', '', 49.8537000, 19.3156800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111296, 'Rewal', 'Rewal', 'Reval'',Rewahl,Реваль', 54.0812000, 15.0147100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111297, 'Resko', 'Resko', 'Gorad Rehska,Rega,Regenwalde,Res''ko,Resko,Réga,lei si ke,Горад Рэска,Реско,Ресько,雷斯科', 53.7730700, 15.4060700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111298, 'Reńska Wieś', 'Renska Wies', '', 50.3158700, 18.1260700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111299, 'Rekowo Dolne', 'Rekowo Dolne', '', 54.6313300, 18.3627900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111300, 'Regulice', 'Regulice', '', 50.0831400, 19.5278500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111301, 'Rędziny', 'Redziny', '', 50.8592200, 19.2162000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111302, 'Reda', 'Reda', 'Reda,Réda,lei da,Реда,雷達', 54.6052800, 18.3471700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111303, 'Ręczno', 'Reczno', '', 51.1902600, 19.8537500, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111304, 'Recz', 'Recz', 'Reca,Rech,Reetz,Rezecz,Reča,lei qi,Реч,雷奇', 53.2598900, 15.5471300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111305, 'Rawicz', 'Rawicz', 'Gorad Ravich,Ravica,Ravich,Ravicius,Raviča,Ravičius,Rawicz,Rawitsch,la wei qi,Горад Равіч,Равич,ראביץ,拉維奇', 51.6094600, 16.8585200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111306, 'Ratowice', 'Ratowice', 'Ralowice,Ratowice,Rattwitz', 51.0330800, 17.2720500, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111307, 'Raszowa', 'Raszowa', '', 50.3977900, 18.1772200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111308, 'Raszków', 'Raszkow', 'Gorad Rashkau,Rashkov,Rashkuv,Raskova,Raszkow,Raszków,Raškova,la shen ku fu,Горад Рашкаў,Рашков,Рашкув,拉什庫夫', 51.7182800, 17.7257100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111309, 'Raszczyce', 'Raszczyce', '', 50.1219000, 18.2996200, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111310, 'Rakoniewice', 'Rakoniewice', 'Rakonevice,Rakoniewice,Rakoņevice,la ke nie wei cai,Раконевице,Раконевіце,Ракоњевице,ریکوٹز,拉科涅維采', 52.1390600, 16.2734600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111311, 'Rajsko', 'Rajsko', '', 50.0119300, 19.1929400, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111312, 'Rajcza', 'Rajcza', '', 49.5092700, 19.1127800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111313, 'Radzyń Chełmiński', 'Radzyn Chelminski', 'Radzin''-Khelmins''kij,Radzina Helminska,Radziņa Helmiņska,Radzyn,Radzyn Chelminski,Radzyn''-Khelmin''ski,Radzyń,Radzyń Chełmiński,Rodzeno,Rôdzëno,Радзинь-Хелмінський,Радзынь-Хелминьски,Рађин Хелмињски', 53.3850900, 18.9372500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111314, 'Radziszów', 'Radziszow', '', 49.9353100, 19.8152200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111315, 'Radzionków', 'Radzionkow', 'Radz''onkuv,Radzh''onkov,Radzionkow,Radzionkuvas,Radzionków,Radzjonkova,Radzjonkuv,Radzunkuw,Radźůnkůw,la ji weng ke fu,Раджьонков,Радзьонкув,Радзёнкув,Рађонков,拉濟翁科夫', 50.4002600, 18.9023200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111316, 'Radziejów', 'Radziejow', 'Radzejova,Radzejuv,Radzhejov,Radziejow,Radziejów,la jie you fu,Раджейов,Радзеюв,拉傑尤夫', 52.6248100, 18.5277100, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111317, 'Radziechowy', 'Radziechowy', 'Radzechovai,Radzekhovi,Radzekhovy,Radziechowy,Ragekhovi,Радзехови,Радзеховы,Раѓехови', 49.6465100, 19.1311500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111318, 'Radzanowo', 'Radzanowo', 'Comuna de Radzanowo,Gmina Radzanovo,Gmina Radzanowo,Radzanovo,Radzanowo,Радзаново,Ґміна Радзаново', 52.5730600, 19.8910900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111319, 'Radowo Małe', 'Radowo Male', '', 53.6657500, 15.4478900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111320, 'Radostowice', 'Radostowice', '', 50.0031100, 18.8810300, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111321, 'Radomsko', 'Radomsko', 'Novoradomsk,Nowo Radomsko,Radoms''ko,Radomskas,Radomsko,Radumsko,Radůmsko,la duo mu si ke,ladomseuko,radomusuko,Радомско,Радомсько,ראדאמסק,ראדומסק,ラドムスコ,拉多姆斯科,라돔스코', 51.0671300, 19.4447700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111322, 'Radomin', 'Radomin', 'Radomin,Радомин', 53.0867000, 19.1941500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111323, 'Radocza', 'Radocza', '', 49.9177400, 19.4749800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111324, 'Radlin', 'Radlin', 'Radlin', 50.0502000, 18.4762600, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111325, 'Radków', 'Radkow', 'Hradek,Radkov,Radkova,Radkow,Radkuv,Radkuvas,Radków,Wunschelburg,Wünschelburg,la de ku fu,Радков,Радкув,拉德庫夫', 50.5042600, 16.4006100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111326, 'Rączna', 'Raczna', '', 50.0098400, 19.7678400, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111327, 'Racławice Śląskie', 'Raclawice Slaskie', 'Deutsch Rasselwitz,Raclawice,Raclawice Slaskie,Racławice,Racławice Śląskie', 50.3120400, 17.7752800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111328, 'Racławice', 'Raclawice', '', 50.1934400, 19.6768600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111329, 'Racibórz', 'Raciborz', 'Gorad Racibuzh,Racebuzos,Rachibozh,Raciborz,Raciboza,Racibozh,Raciboža,Raciburz,Racibuzas,Racibuzh,Racibužas,Racibórz,Racėbužos,Rakibozh,Rasibuj,Ratibor,Ratiboria,Ratiboř,Ratihor,Ratsibuj,Ratsimporz,Raćibůrz,la qi bu ri,lachibusi,ra chi burch,rachibushu,rasiborj,rasybwrz,rtybwr,Ρατσίμπορζ,Горад Рацібуж,Ратибор,Рацибуж,Рачибож,Раћибож,Раќибож,ראטיבאר,רטיבור,راسيبورز,راسیبورز,रसिबोर्ज्,ราชีบุร์ช,ラチブシュ,拉齐布日,라치부시', 50.0919500, 18.2192800, 'PL', '2015-10-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111330, 'Raciążek', 'Raciazek', '', 52.8565000, 18.8133400, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111331, 'Rabka-Zdrój', 'Rabka-Zdroj', 'Rabka,Rabka Zdroj,Rabka Zdrój,Rabka-Zdruj,Rabkazdroja,Rapka-Zdroj,la bu ka-zi de lu yi,Рабка-Здруй,Рапка-Здрој,ראבקה זדרוי,拉布卡-茲德魯伊', 49.6088900, 19.9665400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111332, 'Rąbino', 'Rabino', '', 53.8663000, 15.9448500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111333, 'Raba Wyżna', 'Raba Wyzna', 'Raba Wyzna,Raba Wyżna', 49.5668100, 19.8796700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111334, 'Pyzdry', 'Pyzdry', 'Pizdri,Pyzdry,pei zi de lei,Пиздри,Пыздры,佩茲德雷', 52.1705600, 17.6900500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111335, 'Pyskowice', 'Pyskowice', 'Peiskretscham,Pieskretscham,Piskovice,Pyskovice,Pyskowice,Pyskowicy,pei si ke wei cai,Писковице,Писковіце,Пысковице,佩斯科維采', 50.4000000, 18.6333300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111336, 'Pyrzyce', 'Pyrzyce', 'Gorad Pyzhycy,Perzeca,Pizhice,Pizice,Pižice,Pyritz,Pyzhice,Përzëca,pei ri cai,Горад Пыжыцы,Пижице,Пыжице,ปือชึตแซ,佩日采', 53.1462000, 14.8925700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111337, 'Puszczykowo', 'Puszczykowo', 'Puscikovo,Pushchikovo,Pushhikovo,Puszczykowo,Puščikovo,pu shen qi ke wo,Пушчиково,Пущиково,普什奇科沃', 52.2857000, 16.8492500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111338, 'Puńców', 'Puncow', '', 49.7184200, 18.6615700, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111339, 'Puck', 'Puck', 'Puck,Putzig,Pùck,Пуцк', 54.7179000, 18.4084100, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111340, 'Pszów', 'Pszow', 'Pschow,Pshov,Pshuv,Psova,Pszow,Pszuw,Pszów,Pszůw,Pšova,pu shu fu,Пшов,Пшув,普舒夫', 50.0399400, 18.3947200, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111341, 'Pszczyna', 'Pszczyna', 'Pless,Pscina,Pscyna,Pshchina,Pshhina,Pszczyn,Pszczyna,Pščina,Pščyna,pu shen qi na,Пшчина,Пщина,普什奇納', 49.9803700, 18.9538200, 'PL', '2012-01-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111342, 'Pszczółki', 'Pszczolki', 'Hohenstein,Pszczolki,Pszczółki', 54.1730400, 18.6978700, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111343, 'Pszczew', 'Pszczew', 'Betsche,Betsche-Stadt,Pszczew', 52.4772400, 15.7816000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111344, 'Psary', 'Psary', 'Psary', 51.1871200, 17.0317300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111345, 'Psary', 'Psary', '', 50.6147000, 18.9699100, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111346, 'Psary', 'Psary', '', 50.3796400, 19.1154800, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111347, 'Psary', 'Psary', '', 50.1724200, 19.5295300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111348, 'Przywidz', 'Przywidz', 'Comuna de Przywid,Gmina Przewidz,Gmina Przywidz,Gmina Przëwidz,Gmina Pshividz,Mariensee,Przywidz,Pshividz,Пшивидз,Ґміна Пшивідз', 54.1952400, 18.3211600, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111349, 'Przytoczna', 'Przytoczna', '', 52.5775500, 15.6787800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111350, 'Przytkowice', 'Przytkowice', '', 49.9178500, 19.6857000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111351, 'Przyszowice', 'Przyszowice', 'Przyszowice', 50.2484100, 18.7459400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111352, 'Przystajń', 'Przystajn', '', 50.8849500, 18.6916900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111353, 'Przyrów', 'Przyrow', '', 50.8005100, 19.5279400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111354, 'Przykona', 'Przykona', '', 51.9817100, 18.6124700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111355, 'Przygodzice', 'Przygodzice', '', 51.5919500, 17.8241200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111356, 'Przyborów', 'Przyborow', '', 51.7999100, 15.7689000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111357, 'Przyborów', 'Przyborow', '', 49.6215000, 19.3870100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111358, 'Przybiernów', 'Przybiernow', 'Pribbernow', 53.7578000, 14.7852900, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111359, 'Przodkowo', 'Przodkowo', 'Przedkowo,Przedkòwò', 54.3799100, 18.2876000, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111360, 'Przewóz', 'Przewoz', 'Pribuz,Priebus,Przewoz,Przewóz,Přibuz', 51.4805300, 14.9518800, 'PL', '2017-04-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111361, 'Przeworno', 'Przeworno', 'Prieborn,Przeworno', 50.6862900, 17.1658800, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111362, 'Przemków', 'Przemkow', 'Primkenau,Prymka,Przemkow,Przemkowo,Przemków,Psemkova,Pshemkov,Pshemkuv,Pšemkova,pu re mu ku fu,Пшемков,Пшемкув,普熱姆庫夫', 51.5253000, 15.7944100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111363, 'Przemęt', 'Przemet', '', 52.0080800, 16.3011400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111364, 'Przelewice', 'Przelewice', 'Prillwitz,Przelewice,Pyrzyckie', 53.1041300, 15.0762500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111365, 'Przeginia', 'Przeginia', '', 50.2383100, 19.6885300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111366, 'Przedecz', 'Przedecz', 'Przedecz,Psedeca,Psedecas,Pshedech,Pšedeča,Pšedečas,pu re dai qi,Пшедеч,普熱代奇', 52.3344000, 18.8991500, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111367, 'Przedbórz', 'Przedborz', 'Comuna de Przedbor,Comuna de Przedbór,Gmina Przedborz,Gmina Przedbórz,Gmina Pshedbuzh,Przedborz,Przedbórz,Pshedbuzh,Пшедбуж,Ґміна Пшедбуж', 51.0878900, 19.8738400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111368, 'Przecław', 'Przeclaw', '', 53.3744700, 14.4725100, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111369, 'Przeciszów', 'Przeciszow', '', 50.0064700, 19.3757600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111370, 'Przecieszyn', 'Przecieszyn', '', 49.9783800, 19.1704600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111371, 'Przechlewo', 'Przechlewo', 'Prechlau,Przechlewo,Przechlewò', 53.7984700, 17.2520500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111372, 'Pruszcz', 'Pruszcz', 'Comuna de Pruszc,Gmina Prushh,Gmina Pruszcz,Prushh,Pruszcz,Pruszcz Pomorski,Прущ,Ґміна Прущ', 53.3302100, 18.1989400, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111373, 'Pruszcz Gdański', 'Pruszcz Gdanski', 'Gdansko Pruscas,Gdansko Pruščas,Praust,Prusca Gdanska,Prushch Gdanski,Prushh-Gdan''skij,Prushh-Gdans''kij,Pruszcz,Pruszcz Gdanski,Pruszcz Gdański,Prušča Gdaņska,ge dan si ke pu lu shen qi,Прушч Гдански,Прушч Гдањски,Прущ-Гданьский,Прущ-Ґданський,格但斯克普魯什奇', 54.2621700, 18.6362500, 'PL', '2015-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111374, 'Prusice', 'Prusice', 'Prausnitz,Prusice,pu lu xi cai,Прусице,Прусіце,普魯西采', 51.3711600, 16.9602500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111375, 'Prudnik', 'Prudnik', 'Neustadt,Neustadt in Oberschlesien,Prudnik,Prudnika,Prudnikas,Prudník,Prudńik,Prudņika,prud yik,pu lu de ni ke,Прудник,Прудњик,ปรูดญิก,პრუდნიკი,普魯德尼克', 50.3212400, 17.5746100, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111376, 'Pruchna', 'Pruchna', 'Pruchna', 49.8652700, 18.6819100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111377, 'Prószków', 'Proszkow', 'Proshkov,Proskau,Proskow,Proszkow,Prushkuv,Pruskova,Pruszkuw,Pruškova,Prószków,Průszkůw,pu lu shen ku fu,Прошков,Прушкув,普魯什庫夫', 50.5767000, 17.8714300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111378, 'Prochowice', 'Prochowice', 'Parchwitz,Prochowice,Prohovice,Prokhovice,pu luo huo wei cai,Проховице,Проховіце,普羅霍維采', 51.2730700, 16.3653200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111379, 'Praszka', 'Praszka', 'Prashka,Praska,Praszka,Praška,pu la shen ka,Прашка,פראשקה,普拉什卡', 51.0537500, 18.4531700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111380, 'Prabuty', 'Prabuty', 'Prabutai,Prabute,Prabuti,Prabuty,Prabùtë,Riesenburg,pu la bu di,Прабути,Прабуты,普拉布蒂', 53.7550000, 19.2054700, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111381, 'Poznań', 'Poznan', 'Gorad Poznan'',POZ,Po-tsu-nam,Posen,Posnania,Poznan,Poznan'',Poznan'' osh,Poznana,Poznane,Poznanj,Poznano,Poznany,Poznanė,Poznań,Poznańy,Poznaņa,Poznaň,Poznon,Pòznóń,Pô-tsṳ-nàm,Pоznan,bo zi nan,bwznan,phx snan,pocunan,pojeunan,pojhnana,pozunan,pwyzn,pwznan,pwznn,Πόζναν,Горад Познань,Познан,Познань,Познань ош,Познањ,Պոզնան,פוזנן,פויזן,بوزنان,پوزنان,پۆزنان,पोझ्नान,போசுனான்,พอซนาน,ཕྰོ་ཟོ་ནན།,პოზნანი,ポズナン,波茲南,포즈난', 52.4069200, 16.9299300, 'PL', '2014-01-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111382, 'Powidz', 'Powidz', '', 52.4136200, 17.9192600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111383, 'Potok Złoty', 'Potok Zloty', 'Zloty Potok,Złoty Potok', 50.7067600, 19.4309100, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111384, 'Potęgowo', 'Potegowo', 'Comuna Potegowo,Comuna Potęgowo,Comuna de Potegowo,Comuna de Potęgowo,Gmina Potagowo,Gmina Potegowo,Gmina Potengovo,Gmina Potęgowo,Gmina Pòtãgòwò,Potengovo,Потенгово,Ґміна Потенґово', 54.4828500, 17.4862000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111385, 'Poręba Wielka', 'Poreba Wielka', 'Poreba,Poreba Wielka,Poręba,Poręba Wielka', 50.0111600, 19.2837500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111386, 'Cynków', 'Cynkow', 'Poreba,Poreba-Cynkow,Poręba,Poręba-Cynków', 50.5620300, 19.1195600, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111387, 'Poręba', 'Poreba', 'Poreba,Poremba,Porenba,Poręba,bo lun ba,Поремба,Поренба,波倫巴', 50.4883100, 19.3390300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111388, 'Poraj', 'Poraj', '', 50.6779700, 19.2150900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111389, 'Porąbka', 'Porabka', '', 49.8171600, 19.2183500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111390, 'Popów', 'Popow', '', 51.0402900, 18.9311700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111391, 'Popielów', 'Popielow', 'Klink,Kolonie Poppelau,Popielow,Popielów,Poppelau,Poppelau Kolonie', 50.8263200, 17.7437800, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111392, 'Ponikiew', 'Ponikiew', '', 49.8331100, 19.4657100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111393, 'Poniec', 'Poniec', 'Gorad Ponec,Ponec,Ponec'',Poneca,Poniec,Poņeca,bo nie ci,Горад Понец,Понец,Понець,Поњец,波涅茨', 51.7634300, 16.8086700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111394, 'Polska Cerekiew', 'Polska Cerekiew', 'Cerkiew Polska,Comuna de Polska Cerekiew,Gmina Pol''s''ka Cerekev,Gmina Polska Cerekiew,Gross Neukirch,Pol''ska-Cerekev,Polnisch Neukirch,Polska Cerekiew,Польска-Церекев,Ґміна Польська Церекев', 50.2282700, 18.1267500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111395, 'Połomia', 'Polomia', '', 49.9918500, 18.5510200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111396, 'Polkowice', 'Polkowice', 'Bolkowice,Heerwegen,Pol''kovice,Polkovice,Polkovices,Polkovicės,Polkowice,Polkowicy,Polkwitz,Polkwitz Kreis Glogau,bo er ke wei cai,pwlqwbyzh,Полковице,Польковице,Польковіце,פולקוביצה,波爾科維采', 51.5039100, 16.0726100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111397, 'Police', 'Police', 'Poleca,Police,Police i Polen,Policija,Politz,Pòlëca,Pölitz,bo li cai,polliche,Полице,Полиция,Поліце,波利采,폴리체', 53.5521400, 14.5718200, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111398, 'Połczyn-Zdrój', 'Polczyn-Zdroj', 'Bad Polzin,Polchin-Zdroj,Polchin-Zdruj,Polcinzdroja,Polczeno,Polczyn-Zdroj,Polzin,Polčinzdroja,Połczyn-Zdrój,Pôłczëno,bo wu qin-zi de lu yi,Полчин-Здрој,Полчин-Здруй,波烏琴-茲德魯伊', 53.7642400, 16.0957400, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111399, 'Polanów', 'Polanow', 'Polanov,Polanova,Polanow,Polanowo,Polanów,Poljanuv,Pollnow,Pòlanowò,bo la nu fu,Поланов,Полянув,波拉努夫', 54.1193000, 16.6851200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111400, 'Polanka Wielka', 'Polanka Wielka', '', 49.9850100, 19.3261500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111401, 'Polanica-Zdrój', 'Polanica-Zdroj', 'Altheide,Altheide Bad,Bad Altheide,Polanica Zdroj,Polanica Zdrój,Polanica-Zdroj,Polanica-Zdrój,Polanicazdroja,Polaņicazdroja,Poljanica-Zdruj,Poljanicja-Zdruj,blnytsa zdry,bo lan ni ka-zi de lu yi,Полањица-Здрој,Поляница-Здруй,Поляниця-Здруй,بلنيتسا زدري,波蘭尼卡-茲德魯伊', 50.4037300, 16.5127100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111402, 'Połajewo', 'Polajewo', '', 52.7992300, 16.7334700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111403, 'Pokój', 'Pokoj', 'Carlsruhe,Pokoj,Pokój', 50.9026500, 17.8375100, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111404, 'Pogwizdów', 'Pogwizdow', 'Pogwizdow,Pogwizdów', 49.8038200, 18.6010600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111405, 'Pogrzebień', 'Pogrzebien', '', 50.0672200, 18.2987600, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111406, 'Pogorzyce', 'Pogorzyce', '', 50.1018600, 19.4222800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111407, 'Pogorzela', 'Pogorzela', 'Pogorzela,Pogozela,Pogozhela,Pogozhelja,Pogožela,bo ge re la,Погожела,Погожеля,波戈熱拉', 51.8222000, 17.2301700, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111408, 'Pogórze', 'Pogorze', '', 54.5644000, 18.4820900, 'PL', '2012-12-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111409, 'Podwilk', 'Podwilk', 'Podvilk,Podwilk', 49.5476000, 19.7387400, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111410, 'Podgórzyn', 'Podgorzyn', 'Giersdorf,Podgorzyn,Podgórzyn', 50.8326100, 15.6816100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111411, 'Poddębice', 'Poddebice', 'Comuna de Poddebice,Comuna de Poddębice,Gmina Poddebice,Gmina Poddembice,Gmina Poddębice,Poddebice,Poddembice,Poddębice,Поддембице,Ґміна Поддембіце', 51.8934400, 18.9573000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111412, 'Pobierowo', 'Pobierowo', 'Poberow', 54.0610000, 14.9328200, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111413, 'Pobiedziska', 'Pobiedziska', 'Pobedzis''ka,Pobedziska,Pobiedziska,Pudewitz,bo bie ji si ka,bociniec,Победзиска,Победзіська,Побјеђиска,波別濟斯卡', 52.4775300, 17.2876700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111414, 'Pniewy', 'Pniewy', 'Pinne,Pnevai,Pnevi,Pnevy,Pniewy,Pņevi,pu nie wei,Пневи,Пневы,Пњеви,普涅維', 52.5094300, 16.2566800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111415, 'Płużnica', 'Pluznica', '', 53.2967200, 18.7769200, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111416, 'Płoty', 'Ploty', 'Gorad Ploty,Plate,Plathe,Plota,Ploti,Ploty,Płota,Płoty,pu wo di,Горад Плоты,Плоти,Плоты,Պլոտի,普沃蒂', 53.8018200, 15.2667000, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111417, 'Płock', 'Plock', 'Gorad Plock,Ploc''k,Plock,Plocka,Plockas,Plotsk,Płock,bwtsk,peuwocheukeu,plwzq,pu wo ci ke,puu~otsuku,pwtsk,Горад Плоцк,Плоцк,Плоцьк,Պլոցկ,פלאצק,פלוצק,بوتسك,پوتسک,プウォツク,普沃茨克,프워츠크', 52.5468200, 19.7063800, 'PL', '2013-07-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111418, 'Plewiska', 'Plewiska', '', 52.3670600, 16.8098500, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111419, 'Pleszew', 'Pleszew', 'Gorad Pleshau,Pleseva,Pleshev,Pleševa,pu lai xie fu,Горад Плешаў,Плешев,普萊謝夫', 51.8963600, 17.7854900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111420, 'Płaza', 'Plaza', '', 50.0998800, 19.4645100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111421, 'Pławno', 'Plawno', '', 50.9777200, 19.4552400, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111422, 'Pisarzowice', 'Pisarzowice', 'Mittel Schreibersdorf,Schreibersdorf', 51.1447900, 15.2305700, 'PL', '2013-11-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111423, 'Pisarzowice', 'Pisarzowice', '', 49.8836300, 19.1456500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111424, 'Piotrków Trybunalski', 'Piotrkow Trybunalski', 'Gorad Pjotrkau-Trybunal''ski,P''oturkov Tribunalski,Petrakavas,Petrikau,Petrokov,Piotrkow,Piotrkow Trybunalski,Piotrków,Piotrków Trybunalski,Pjotrkov Tribunalski,Pjotrkova Tribunalska,Pjotrkuv-Tribunal''s''kij,Pjotrkuv-Trybunal''ski,Pjotrkuv-Trybunal''skij,bi de ku fu te lei bu na er si ji,pi yxtr kuft rux bunal ski,pioteuleukupeuteulibunalseuki,pywtrqwb trybwnlsqy,Горад Пётркаў-Трыбунальскі,Пйотркув-Трибунальський,Пьотърков Трибуналски,Пётркув-Трыбунальски,Пётркув-Трыбунальский,Пјотрков Трибуналски,פיוטרקוב טריבונלסקי,פיעטרקאוו,ปียอตร์กุฟตรือบูนัลสกี,ピョートルクフ・トルィブナルスキ,彼得庫夫特雷布納爾斯基,피오트르쿠프트리부날스키', 51.4054700, 19.7032100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111425, 'Piotrków Kujawski', 'Piotrkow Kujawski', 'Piotrkow,Piotrkow Kujawski,Piotrków,Piotrków Kujawski,Pjotrkov Kujavski,Pjotrkova Kujavska,Pjotrkuv-Kujavs''kij,Pjotrkuv-Kujavskij,ku ya wei de qu bi de ku fu,Пйотркув-Куявський,Пётркув-Куявский,Пјотрков Кујавски,פיוטרקוב קויאבסקי,庫亞維地區彼得庫夫', 52.5511100, 18.4990500, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111426, 'Pilica', 'Pilica', 'Pilica', 50.4679900, 19.6572900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111427, 'Pilchowice', 'Pilchowice', 'Bilchengrund,Pilchowice,Pilchowitz', 50.2166800, 18.5613200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111428, 'Piława Górna', 'Pilawa Gorna', 'Pilava Gorna,Pilava Gurna,Pilava-Gurna,Pilawa Gorna,Piława Górna,shang pi wa wa,Пилава Горна,Пилава-Гурна,Пілава-Ґурна,上皮瓦瓦', 50.6835700, 16.7435900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111429, 'Piła', 'Pila', 'Gorad Pila,Piela,Pila,Pily,Piéła,Piła,Schneidemuhl,Schneidemühl,pi wa,piwa,Горад Піла,Пила,Пилы,Піла,ピワ,皮瓦,피와', 53.1514500, 16.7378200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111430, 'Pietrzykowice', 'Pietrzykowice', '', 49.6963400, 19.1599000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111431, 'Pietrowice Wielkie', 'Pietrowice Wielkie', '', 50.0845200, 18.0914800, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111432, 'Pieszyce', 'Pieszyce', 'Peshice,Pesice,Peterswaldau,Pešice,Pieszyce,Pjeshice,pei xi cai,Пешице,Пјешице,ปีแยชึตแซ,佩希采', 50.7128700, 16.5823200, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111433, 'Pierściec', 'Piersciec', 'Piersciec,Pierściec', 49.8333900, 18.8140900, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111434, 'Pieńsk', 'Piensk', 'Pen''sk,Pens''k,Penska,Penzig,Peņska,Piensk,Pieńsk,Pjensk,Pjeńsk,pian si ke,Пенськ,Пеньск,Пјењск,片斯克', 51.2490000, 15.0468500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111435, 'Pielgrzymowice', 'Pielgrzymowice', '', 49.9054700, 18.6488600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111436, 'Piekielnik', 'Piekielnik', 'Pekelnik,Piekielek,Piekielnik', 49.4768800, 19.7681000, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111437, 'Piekary Śląskie', 'Piekary Slaskie', 'Gorad Pjakary Sljonske,Pekarai,Pekari Shl''onske,Pekari Slonski,Pekari-Shl''ons''ki,Pekary-Shljonske,Pekary-Sljonske,Piekary Slaskie,Piekary Wielkie,Piekary Śląskie,Pjekari Slonskje,Pjekary,piekalisillongseukie,xi long si ke de qu pei ka lei,Горад Пякары Слёнске,Пекари Шльонске,Пекари-Шльонські,Пекары-Слёнске,Пекары-Шлёнске,Пјекари Слонскје,ピェカルィ・シロンスキェ,希隆斯克地區佩卡雷,피에카리실롱스키에', 50.3801700, 18.9265300, 'PL', '2016-05-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111438, 'Piekary', 'Piekary', '', 50.0249500, 19.7961600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111439, 'Piechowice', 'Piechowice', 'Pehovice,Pekhovice,Petersdorf,Piechowice,Pjekhovice,pei huo wei cai,Пеховице,Пеховіце,Пјеховице,佩霍維采', 50.8496300, 15.5988700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111440, 'Piątek', 'Piatek', 'Comuna de Piatek,Comuna de Piątek,Gmina Piatek,Gmina Piątek,Gmina Pjontek,Pjontek,Пёнтек,Ґміна Пйонтек', 52.0689000, 19.4797000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111441, 'Piaski', 'Piaski', 'Comuna de Piaski,Gmina Piaski,Gmina Pjaski,Pjaski,Пяски,Ґміна Пяскі', 51.8849700, 17.0729300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111442, 'Piasek', 'Piasek', '', 50.0105500, 18.9480700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111443, 'Pewel Wielka', 'Pewel Wielka', '', 49.6745700, 19.3748200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111444, 'Pewel Ślemieńska', 'Pewel Slemienska', '', 49.6896800, 19.3343100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111445, 'Perzów', 'Perzow', '', 51.2762500, 17.8097000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111446, 'Pępowo', 'Pepowo', '', 51.7656900, 17.1266100, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111447, 'Pelplin', 'Pelplin', 'Pel''plin,Pelpin,Pelplin,Pelplina,Пельплин,Пельплін', 53.9283400, 18.6977000, 'PL', '2017-07-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111448, 'Pełczyce', 'Pelczyce', 'Bernstein,Berszten,Bersztén,Pelchice,Pelcice,Pelczyce,Pelčice,Pełczyce,pei wu qi cai,Пелчице,แปวต์ชึตแซ,佩烏奇采', 53.0435400, 15.3044700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111449, 'Pęczniew', 'Peczniew', '', 51.8038400, 18.7231100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111450, 'Pecna', 'Pecna', 'Pecna', 52.1833300, 16.8000000, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111451, 'Pcim', 'Pcim', '', 49.7516600, 19.9710800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111452, 'Pawonków', 'Pawonkow', '', 50.6949900, 18.5814900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111453, 'Pawłowiczki', 'Pawlowiczki', 'Comuna de Pawlowiczki,Comuna de Pawłowiczki,Gmina Pavlovichki,Gmina Pawlowiczki,Gmina Pawłowiczki,Pavlovichki,Павловички,Ґміна Павловічкі', 50.2466000, 18.0486500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111454, 'Pawłowice', 'Pawlowice', '', 49.9612700, 18.7177800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111455, 'Pątnów', 'Patnow', '', 51.1440300, 18.6165900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111456, 'Paszowice', 'Paszowice', '', 51.0107800, 16.1527300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111457, 'Pasłęk', 'Paslek', 'Paslek,Paslenk,Paslenka,Paslenkas,Pasłęk,Preussen Holland,Preussisch Holad,Preussisch Holland,pa si wen ke,Пасленк,帕斯文克', 54.0616000, 19.6593200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111458, 'Parzęczew', 'Parzeczew', 'Comuna de Parzeczew,Comuna de Parzęczew,Gmina Parzeczew,Gmina Parzęczew,Gmina Pazhenchev,Pazhenchev,Паженчев,Ґміна Паженчев', 51.9485500, 19.2060800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111459, 'Parchowo', 'Parchowo', 'Parchowo,Parchòwò', 54.2065800, 17.6681600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111460, 'Panki', 'Panki', '', 50.8833300, 18.7516000, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111461, 'Paniówki', 'Paniowki', '', 50.2313900, 18.7810400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111462, 'Pamiątkowo', 'Pamiatkowo', '', 52.5533400, 16.6809400, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111463, 'Palcza', 'Palcza', '', 49.8045400, 19.7438900, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111464, 'Pakosławice', 'Pakoslawice', '', 50.5447400, 17.3657800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111465, 'Pakosław', 'Pakoslaw', '', 51.6143800, 17.0579300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111466, 'Pakość', 'Pakosc', 'Pakosc,Pakosc'',Pakosca,Pakoshc,Pakość,pa ke xi qi,Пакосць,Пакошћ,帕科希奇', 52.8017800, 18.0853000, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111467, 'Pajęczno', 'Pajeczno', 'Paenchno,Pajeczno,Pajenchno,Pajencno,Pajenčno,Pajęczno,pa yan qi nuo,Паенчно,Пайенчно,Паєнчно,Пајенчно,פאיינצנו,帕延奇諾', 51.1444900, 18.9961200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111468, 'Paczków', 'Paczkow', 'Pachkov,Pachkuv,Packova,Paczkow,Paczków,Patschkau,Pačkova,pa qi ku fu,Пачков,Пачкув,帕奇庫夫', 50.4639500, 17.0065800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111469, 'Pacyna', 'Pacyna', 'Pacina,Pacyna,Пацина', 52.3028100, 19.7098200, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111470, 'Pabianice', 'Pabianice', 'Pab''janice,Pab''janicy,Pab''yanitsy,Pabianice,Pabianices,Pabianicės,Pabjanice,Pabjaņice,Pab’yanitsy,pa bi ya ni cai,Паб''яніцы,Пабьянице,Пабянице,Пабяніце,Пабјањице,פביאניצה,帕比亞尼采', 51.6644600, 19.3547300, 'PL', '2014-05-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111471, 'Ozorków', 'Ozorkow', 'Ozorkov,Ozorkova,Ozorkow,Ozorkuv,Ozorkuvas,Ozorków,ao zuo er ku fu,Озорков,Озоркув,אוזורקוב,奧佐爾庫夫', 51.9633600, 19.2913900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111472, 'Ozimek', 'Ozimek', 'Malapane,Malapane Oberschlesien,Ozhimek,Ozimek,Ozimeka,ao ji mei ke,Ожимек,Озимек,Озімек,奧濟梅克', 50.6794400, 18.2137000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111473, 'Ożarowice', 'Ozarowice', 'Ozarowice,Ozgrowice,Ożarowice,Ożgrowice', 50.4618200, 19.0431700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111474, 'Ożarów', 'Ozarow', '', 51.1448900, 18.5111000, 'PL', '2010-09-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111475, 'Otyń', 'Otyn', 'Deutsch Wartenberg,Otyn,Otyń', 51.8476600, 15.7110500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111476, 'Otmuchów', 'Otmuchow', 'Odmuchow,Otmuchow,Otmuchów,Otmuhova,Otmukhov,Otmukhuv,Ottmachau,ao te mu hu fu,Отмухов,Отмухув,奧特穆胡夫', 50.4662700, 17.1734800, 'PL', '2017-07-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111477, 'Oświęcim', 'Oswiecim', 'Auschwitz,Osvecimia,Osvencim,Osvencima,Osvencimas,Osviencim,Osvienčim,Osvietsim,Oswiecim,Oświęcim,ao si wei xin,oshifienchimu,osibiengchim,osphincima,Οσβιέτσιμ,Освенцим,Освиенцим,אושוויינצ''ים,אשפעצין,ओश्फिन्चिम,オシフィエンチム,奥斯威辛,오시비엥침', 50.0343700, 19.2103700, 'PL', '2012-11-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111478, 'Ostrzeszów', 'Ostrzeszow', 'Gorad Astshehshau,Ostrzeszow,Ostrzeszów,Ostsesova,Ostsheshov,Ostsheshuv,Ostšešova,ao si qie shu fu,Горад Астшэшаў,Остшешов,Остшешув,奧斯切舒夫', 51.4264000, 17.9335500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111479, 'Ostrowy', 'Ostrowy', '', 52.3044400, 19.1656500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111480, 'Ostrowy nad Okszą', 'Ostrowy nad Oksza', '', 50.9779900, 19.0535500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111481, 'Ostrów Wielkopolski', 'Ostrow Wielkopolski', 'Didziosios Lenkijos Ostruvas,Didžiosios Lenkijos Ostruvas,Gorad Ostrau-Vel''kapol''ski,Ostrov,Ostrov Velkopolski,Ostrov Vjelkopolski,Ostrova Velkopolska,Ostrovia,Ostrovo,Ostrow,Ostrow Wielkopolski,Ostruv-Vel''kopol''ski,Ostruv-Vel''kopol''skij,Ostruv-Velikopol''s''kij,Ostrów,Ostrów Wielkopolski,QDG,Wjelgopolski Uostruw,Wjelgopolski Uostrůw,awstrw wlkwbwlysky,da bo lan de qu ao si te lu fu,Горад Остраў-Велькапольскі,Остров Велкополски,Остров Вјелкополски,Острув-Великопольський,Острув-Велькопольски,Острув-Велькопольский,اوسترو ولكوبوليسكي,大波蘭地區奧斯特魯夫', 51.6550100, 17.8068600, 'PL', '2013-03-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111482, 'Ostrowite', 'Ostrowite', 'Ostrovite,Ostrowite,Островите', 53.0691700, 19.2933700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111483, 'Ostrowite', 'Ostrowite', '', 52.3819900, 18.0447000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111484, 'Ostroszowice', 'Ostroszowice', 'Ostroszowice,Weigelsdorf,Wyganow', 50.6457600, 16.6396500, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111485, 'Ostroróg', 'Ostrorog', 'Ostrorog,Ostroroga,Ostrorug,Ostroróg,ao si te luo lu ge,Остророг,Остроруг,奧斯特羅魯格', 52.6265000, 16.4498800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111486, 'Ostróda', 'Ostroda', 'Osterode,Ostroda,Ostruda,Ostróda,ao si te lu da,astrwda,osutoruda,Острода,Оструда,אוסטרודה,استرودا,オストルダ,奧斯特魯達', 53.6967100, 19.9648600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111487, 'Ostrężnica', 'Ostreznica', '', 50.1926200, 19.5707700, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111488, 'Ostaszewo', 'Ostaszewo', 'Ostashevo,Ostaszewo,Schoneberg,Schöneberg,Осташево', 54.2125600, 18.9514200, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111489, 'Ośno Lubuskie', 'Osno Lubuskie', 'Drossen,Os''no-Ljubuske,Oshno-Ljubus''ke,Osno,Osno Lubelskje,Osno Lubuske,Ośno,Осно Лубелскје,Осьно-Любуске,Ошно-Любуське', 52.4536000, 14.8754900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111490, 'Osjaków', 'Osjakow', 'Comuna de Osjakow,Comuna de Osjaków,Gmina Os''jakuv,Gmina Osjakow,Gmina Osjaków,Os''jakuv,Осьякув,Ґміна Осьякув', 51.2894600, 18.7915100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111491, 'Osina', 'Osina', '', 53.6047300, 15.0123000, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111492, 'Osielsko', 'Osielsko', '', 53.1850500, 18.0841800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111493, 'Osielec', 'Osielec', '', 49.6807900, 19.7824300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111494, 'Osiek nad Notecią', 'Osiek nad Notecia', '', 53.1203000, 17.2910200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111495, 'Osiek Mały', 'Osiek Maly', 'Comuna de Osiek Maly,Comuna de Osiek Mały,Gmina Osek-Mali,Gmina Osiek Maly,Gmina Osiek Mały,Osek-Maly,Осек-Малы,Ґміна Осек-Мали', 52.2763000, 18.6023400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111496, 'Osiek', 'Osiek', 'Gmina Osek,Gmina Osiek,Osek,Osiek,Осек,Ґміна Осек', 53.7222600, 18.4905100, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111497, 'Osiek', 'Osiek', 'Osiek,Osiek-nad-Wisla,Osiek-nad-Wisła', 52.9262900, 18.8076500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111498, 'Osiek', 'Osiek', 'Ossig', 51.3671700, 16.2338000, 'PL', '2015-08-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111499, 'Osiek', 'Osiek', '', 50.2435300, 19.6004700, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111500, 'Osiek', 'Osiek', '', 49.9506700, 19.2644400, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111501, 'Osieczna', 'Osieczna', 'Osechna,Osecna,Osečna,Osieczna,Osjechna,ao xie qi na,Осечна,Осјечна,奧謝奇納', 51.9042000, 16.6786200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111502, 'Osięciny', 'Osieciny', 'Comuna Osieciny,Comuna Osięciny,Comuna de Osieciny,Comuna de Osięciny,Gmina Osencini,Gmina Osieciny,Gmina Osięciny,Osenciny,Osieciny,Osięciny,Осенцины,Ґміна Осенцини', 52.6292600, 18.7220800, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111503, 'Osie', 'Osie', '', 53.5991800, 18.3437300, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111504, 'Orzesze', 'Orzesze', 'Orzesze,Ozese,Ozheshe,Ožeše,Uorzesze,Ожеше', 50.1559500, 18.7792300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111505, 'Orzech', 'Orzech', '', 50.4274400, 18.9227500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111506, 'Ornontowice', 'Ornontowice', 'Ornontowice,Ornontowitz', 50.1937700, 18.7543500, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111507, 'Orle', 'Orle', 'Worle', 54.6402200, 18.1705700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111508, 'Orchowo', 'Orchowo', '', 52.5093800, 18.0157800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111509, 'Oporów', 'Oporow', '', 52.2644800, 19.5641600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111510, 'Opole', 'Opole', 'Gorad Apole,Opole,Opoli,Opolí,Opolė,Oppein,Oppeln,Uopole,abwlwsky,ao bo lai,awpwl,awpwlh,opolle,opore,xx pxle,Òpòle,Горад Аполе,Ополе,אופולה,أبولوسكي,اوپول,اوپوله,ออปอเล,オポーレ,奥波莱,오폴레', 50.6721100, 17.9253300, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111511, 'Opatówek', 'Opatowek', 'Opatowek,Opatówek', 51.7398900, 18.2165300, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111512, 'Opatów', 'Opatow', '', 51.2146300, 18.1461500, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111513, 'Opatów', 'Opatow', '', 50.9556700, 18.8194100, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111514, 'Opalenica', 'Opalenica', 'Opalenica,Opalenicja,Opaleņica,ao pa lai ni cha,Опаленица,Опалениця,Опалењица,奧帕萊尼察', 52.3088700, 16.4127800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111515, 'Olza', 'Olza', '', 49.9539300, 18.3391000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111516, 'Olszyna', 'Olszyna', 'Olszyna', 51.0671000, 15.3722800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111517, 'Olsztyn', 'Olsztyn', '', 50.7518500, 19.2673700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111518, 'Olszówka', 'Olszowka', '', 52.1903000, 18.8625800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111519, 'Olszanka', 'Olszanka', '', 50.7951400, 17.4789000, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111520, 'Olszanica', 'Olszanica', '', 51.2067200, 15.8004000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111521, 'Olkusz', 'Olkusz', 'Ol''kush,Olkusa,Olkusas,Olkush,Olkuša,Olkušas,ao er ku shen,Олкуш,Олькуш,אולקוש,עלקוש,奧爾庫什', 50.2813000, 19.5650300, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111522, 'Olesno', 'Olesno', 'Olesno,Rosenberg,Uoleszno,ao lai si nuo,Олесно,ออแลสนอ,奧萊斯諾', 50.8769800, 18.4209400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111523, 'Oleśnica', 'Olesnica', 'Oels,Oles''nicja,Oleshnica,Olesnica,Olesnice,Olesņica,Oleśnica,Olešnice,Ols,ao lai xi ni cha,Öls,Олесница,Олесьниця,Олесњица,Олешница,אולשניצה,奧萊希尼察', 51.2133800, 17.3898600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111524, 'Oława', 'Olawa', 'Ohiau,Ohlau,Olava,Olawa,Oława,ao wa wa,Олава,אולאווה,奧瓦瓦', 50.9466000, 17.2926000, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111525, 'Kołaczkowo', 'Kolaczkowo', '', 52.2173900, 17.6241300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111526, 'Okonek', 'Okonek', 'Comuna de Okonek,Gmina Okonek,Okonek,Ratzebuhr,Ratzenbuhr,Оконек,Ґміна Оконек', 53.5361800, 16.8515800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111527, 'Ogrodzieniec', 'Ogrodzieniec', 'Ogrodzenec,Ogrodzenec'',Ogrodzeneca,Ogrodzhenec,Ogrodzieniec,ao ge luo jie nie ci,Огродженец,Огродзенец,Огродзенець,Огрођењец,奧格羅傑涅茨', 50.4517700, 19.5198700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111528, 'Odolanów', 'Odolanow', 'Adelnau,Odolanov,Odolanova,Odoljanuv,ao duo la nu fu,Одоланов,Одолянув,奧多拉努夫', 51.5741900, 17.6743400, 'PL', '2015-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111529, 'Ochojno', 'Ochojno', '', 49.9525500, 19.9745200, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111530, 'Ochla', 'Ochla', '', 51.8790300, 15.4713200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111531, 'Ochaby', 'Ochaby', 'Ochaby', 49.8425200, 18.7689400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111532, 'Obrzycko', 'Obrzycko', 'Obrzycko,Obzhic''ko,Obzhicko,Obzicko,Obžicko,ao bu ri ci ke,Обжицко,Обжицько,奧布日茨科', 52.7033800, 16.5280700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111533, 'Obrowo', 'Obrowo', 'Obrovo,Obrowo,Оброво', 52.9714900, 18.8786300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111534, 'Oborniki Śląskie', 'Oborniki Slaskie', 'Obernigk,Oborniki Slaskie,Oborniki Slonski,Oborniki Slonskje,Oborniki Śląskie,Oborniki-Shl''ons''ki,Oborniki-Sljonske,Oborņiki Slonski,xi long si ke de qu ao bo er ni ji,Оборники-Слёнске,Оборники-Шльонські,Оборњики Слонскје,希隆斯克地區奧博爾尼基', 51.3013700, 16.9146500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111535, 'Oborniki', 'Oborniki', 'Obornik,Oborniki,Oborņiki,ao bo er ni ji,Оборники,Оборњики,奧博爾尼基', 52.6473900, 16.8140600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111536, 'Nysa', 'Nysa', 'Neisse,Neisse-Neuland,Neisze,Niesse,Nisa,Nysa,Nysa i Polen,ni si,nisa,nux sa,nysa,Ниса,Ныса,نيسا,นือซา,ニサ,尼斯,니사', 50.4737900, 17.3343700, 'PL', '2017-05-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111537, 'Nowy Tomyśl', 'Nowy Tomysl', 'Gorad Novy-Tomysl'',Novi Tomishul,Novi Tomisl,Novi Tomisla,Novij Tomishl'',Novy-Tomysl'',Nowy Tomysl,Nowy Tomyśl,xin tuo mei xi er,Горад Новы-Томысль,Нови Томисл,Нови Томишъл,Новий Томишль,Новы-Томысль,新托梅希爾', 52.3195000, 16.1284400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111538, 'Nowy Staw', 'Nowy Staw', 'Neuteich,Nitech,Nitëch,Novi Stav,Novi Stava,Novij Stav,Novy-Stav,Nowy Staw,Nytych,xin si ta fu,Нови Став,Новий Став,Новы-Став,新斯塔夫', 54.1360900, 19.0090900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111539, 'Nowy Dwór Gdański', 'Nowy Dwor Gdanski', 'Novi Dvor Gdanski,Novi Dvora Gdanska,Novi Dvora Gdaņska,Novi Dvur Gdanski,Novij Dvur-Gdans''kij,Novy-Dvur-Gdan''skij,Nowi Dwor,Nowi Dwór,Nowy Dwn Gdanski,Nowy Dwor,Nowy Dwor Gdanski,Nowy Dwór,Nowy Dwór Gdański,Tiegenhof,ge dan si ke xin zhuang yuan,Нови Двор Гдањски,Нови Двур Гдански,Новий Двур-Ґданський,Новы-Двур-Гданьский,格但斯克新莊園', 54.2130500, 19.1177100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111540, 'Nowy Duninów', 'Nowy Duninow', 'Duninow Nowy,Duninow Nw,Duninów Nowy,Duninów Nw,Novy-Duninuv,Nowy Duninow,Nowy Duninów,Новы-Дунинув', 52.5827100, 19.4799600, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111541, 'Nowogrodziec', 'Nowogrodziec', 'Naumburg am Queis,Naumburgum ad Quisum,Novogrodzec,Novogrodzec'',Novogrodzeca,Nowogrodziec,nuo wo ge luo jie ci,Новогродзец,Новогрођец,Новоґродзець,諾沃格羅傑茨', 51.1954300, 15.3985400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111542, 'Nowogródek Pomorski', 'Nowogrodek Pomorski', 'Neuenburg,Nowogrodek Pomorski,Nowogródek Pomorski', 52.9114900, 15.0294700, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111543, 'Nowogród Bobrzański', 'Nowogrod Bobrzanski', 'Comuna de Nowogrod Bobrzanski,Comuna de Nowogród Bobrzański,Gmina Novogrud-Bobzhans''kij,Gmina Nowogrod Bobrzanski,Gmina Nowogród Bobrzański,Naumburg,Naumburg Bober,Naumburg am Bober,Novogrud-Bobzhan''skij,Nowogrod Bobrzanski,Nowogród Bobrzański,Nowy Zamek,Новогруд-Бобжаньский,Ґміна Новоґруд-Бобжанський', 51.7985600, 15.2352000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111544, 'Nowogard', 'Nowogard', 'Gorad Navogard,Naugard,Novogard,Novogarda,Nowogard,Nowògard,nuo wo jia de,Горад Навогард,Новогард,諾沃加德', 53.6743700, 15.1163000, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111545, 'Nowe Warpno', 'Nowe Warpno', 'Neuwarp,Nove Varpno,Nove-Varpno,Nowo Worpino,Nowô Wôrpinô,xin wa er pu nuo,Нове Варпно,Нове-Варпно,新瓦爾普諾', 53.7225600, 14.2896100, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111546, 'Nowe Skalmierzyce', 'Nowe Skalmierzyce', 'Nove Skal''mezhice,Nove Skalmezice,Nove Skalmežice,Nove Skalmjezhice,Nove-Skal''mezhice,Nowe Skalmierzyce,Skalmierzyce,Skalmierzyce Nowe,xin si ka er mei ri cai,Нове Скалмјежице,Нове Скальмежице,Нове-Скальмежице,新斯卡爾梅日采', 51.7103800, 17.9933700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111547, 'Nowe Miasto nad Wartą', 'Nowe Miasto nad Warta', 'Nowe Miasto,Nowe Miasto nad Warta,Nowe Miasto nad Wartą', 52.0900700, 17.4111400, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111548, 'Nowe Miasto Lubawskie', 'Nowe Miasto Lubawskie', 'Nove Mjasto Ljubavske,Nove Mjasto Lubavske,Nove Mjasto Lubavskje,Nove-Mjasto,Nove-Mjasto-Ljubavs''ke,Nove-Mjasto-Ljubavske,Nowe Miasto Lubawskie,Nowe-Miasto,lu ba wa xin cheng,Нове Място Любавске,Нове Мјасто Лубавскје,Нове-Място,Нове-Място-Любавске,Нове-Място-Любавське,נובה מיאסטו,盧巴瓦新城', 53.4207900, 19.5951500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111549, 'Nowe Miasteczko', 'Nowe Miasteczko', 'Neustaedtel,Neustädtel,Nowe Miasteczko', 51.6909700, 15.7317400, 'PL', '2015-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111550, 'Nowe', 'Nowe', 'Nove,Nowe,Nowé,nuo wei,Нове,諾韋', 53.6490600, 18.7271600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111551, 'Nowa Wieś Wielka', 'Nowa Wies Wielka', '', 52.9715900, 18.0903600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111552, 'Nowa Wieś Lęborska', 'Nowa Wies Leborska', 'Nowo Wies,Nowô Wies', 54.5587800, 17.7275600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111553, 'Nowa Wieś', 'Nowa Wies', '', 49.9074600, 19.2164600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111554, 'Nowa Sól', 'Nowa Sol', 'Neusalz,Nova Sol,Nova Sola,Nova Sul'',Nova Sule,Nova Sulė,Nova-Sul'',Nowa Sol,Nowa Sól,xin su er,Нова Сол,Нова Суль,Нова-Суль,新蘇爾', 51.8033300, 15.7170200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111555, 'Nowa Ruda', 'Nowa Ruda', 'Naujoji Ruda,Neurode,Nova Ruda,Nova-Ruda,Nowa Ruda,Nowo Ruda,Nowy Ruda,nobaluda,nwbh rwdh,xin lu da,Нова Руда,Нова-Руда,נובה רודה,新魯達,노바루다', 50.5800800, 16.5016400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111556, 'Nowa Góra', 'Nowa Gora', '', 50.1730500, 19.5912000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111557, 'Nieszawa', 'Nieszawa', 'Nesava,Neshava,Nieszawa,Njeshava,nie sha wa,Ņešava,Њешава,Нешава,涅沙瓦', 52.8345200, 18.8992100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111558, 'Niemodlin', 'Niemodlin', 'Falkenberg,Falkenberg in Ober Schlesien,Nemodlin,Nemodlina,Niemodlin,Njemodlin,Nymodlin,nie mo de lin,Ńymodlin,Ņemodlina,Њемодлин,Немодлин,Немодлін,涅莫德林', 50.6420000, 17.6193200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111559, 'Niemcza', 'Niemcza', 'Nemca,Nemcha,Niemcz,Niemcza,Nimptsch,Njemcha,nie mu qia,Ņemča,Њемча,Немча,涅姆恰', 50.7200700, 16.8357300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111560, 'Niegowonice', 'Niegowonice', 'Niegowinice,Niegowonice', 50.3890900, 19.4226300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111561, 'Niedobczyce', 'Niedobczyce', '', 50.0654000, 18.4953100, 'PL', '2010-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111562, 'Niechanowo', 'Niechanowo', '', 52.4652700, 17.6781200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111563, 'Nidek', 'Nidek', '', 49.9049200, 19.3246100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111564, 'Nekla', 'Nekla', 'Gorad Neklja,Nekla,Neklja,Горад Некля,Некла,Некля', 52.3649600, 17.4132900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111565, 'Nędza', 'Nedza', 'Buchenau,Klein Nensa,Nedza,Nendza,Nensa,Nędza', 50.1611200, 18.3110300, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111566, 'Naprawa', 'Naprawa', '', 49.6465700, 19.8791600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111567, 'Namysłów', 'Namyslow', 'Namislov,Namislova,Namisluv,Namslau,Namyslow,Namysluv,Namysluvas,Namysłów,na mei si wu fu,Намислов,Намислув,Намыслув,納梅斯武夫', 51.0759200, 17.7228400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111568, 'Nakło nad Notecią', 'Naklo nad Notecia', 'Nakel,Naklo,Naklo nad Notech''on,Naklo nad Notecia,Naklo nad Notecom,Naklo pie Notecas,Naklo-nad-Notecem,Naklo-nad-Notecjon,Nakło,Nakło nad Notecią,nuo tai qi he pan na ke wo,Накло над Нотечьон,Накло над Нотећом,Накло-над-Нотецем,Накло-над-Нотецён,諾泰奇河畔納克沃', 53.1421400, 17.6018100, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111569, 'Nakło', 'Naklo', 'Nakel,Naklo,Nakło', 50.5797500, 18.1181700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111570, 'Nakło', 'Naklo', '', 50.4369000, 18.9105600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111571, 'Myszków', 'Myszkow', 'Mishkov,Mishkuv,Miskova,Miškova,Myshkov,Myshkuv,Myskuvas,Myszkow,Myszkow Nowy,Myszkuw,Myszków,Myszków Nowy,Myszkůw,Myškuvas,mei shen ku fu,mu~ishukufu,Мишков,Мишкув,Мышков,Мышкув,ムィシュクフ,梅什库夫', 50.5752000, 19.3246100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111572, 'Mysłowice', 'Myslowice', 'Gorad Myslavicy,Mislovice,Myslovice,Myslovices,Myslovicės,Myslowice,Myslowicy,Mysłowice,mei si wo wei cai,miseuwobiche,mu~isuu~ovu~itsu~e,Горад Мыславіцы,Мисловице,Мисловіце,Мысловице,ムィスウォヴィツェ,梅斯沃維采,미스워비체', 50.2074500, 19.1666800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111573, 'Myślibórz', 'Mysliborz', 'Gorad Myslibuzh,Mishlibozh,Misliboza,Mislibozh,Misliboža,Mislibuzh,Myslibuzas,Myslibuzh,Myslibužas,Soldin,Zoldzeno,mei xi li bu ri,Żôłdzëno,Горад Мыслібуж,Мислибож,Мислібуж,Мишлибож,Мыслибуж,梅希利布日', 52.9238200, 14.8678500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111574, 'Myślenice', 'Myslenice', 'Mishlenice,Mislenice,Misleņice,Myslenice,Myślenice,mei xi lai ni cai,Мисленіце,Мислењице,Мишленице,Мысленице,梅希萊尼采', 49.8338300, 19.9383000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111575, 'Mysłakowice', 'Myslakowice', 'Myslakowice,Mysłakowice,Zillerthal-Erdmannsdorf', 50.8412300, 15.7789400, 'PL', '2016-02-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111576, 'Myślachowice', 'Myslachowice', '', 50.1851400, 19.4811600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111577, 'Mykanów', 'Mykanow', '', 50.9236000, 19.2005000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111578, 'Murowana Goślina', 'Murowana Goslina', 'Murovana Goslina,Murovana-Goslina,Murowana Goslina,Murowana Goślina,mu luo wa na-ge xi li na,Мурована Гослина,Мурована Ґосліна,Мурована-Гослина,穆羅瓦納-戈希利納', 52.5746300, 17.0093300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111579, 'Murów', 'Murow', 'Hermannsthal,Hermannsthal Oberschlesien,Murow,Murów', 50.8630700, 17.9455700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111580, 'Murcki', 'Murcki', 'Emanuelssegen,Murcki', 50.2003600, 19.0435100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111581, 'Mszana', 'Mszana', 'Mszana', 49.9693900, 18.5279300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111582, 'Mstów', 'Mstow', '', 50.8296900, 19.2854700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111583, 'Mrzeżyno', 'Mrzezyno', 'Deep,Ost Deep,Treptower Deep', 54.1438400, 15.2914200, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111584, 'Mrzezino', 'Mrzezino', 'Mrzezino,Mzhezino,Мжезино', 54.6537800, 18.4302500, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111585, 'Mrozów', 'Mrozow', 'Mrozow,Mrozów', 51.1881700, 16.7883100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111586, 'Mrocza', 'Mrocza', 'Immenheim,Mroca,Mrocha,Mrocza,Mrotschen,Mroča,mu luo qia,Мроча,姆羅恰', 53.2431300, 17.6040500, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111587, 'Moszczenica', 'Moszczenica', 'Gmina Moshhenicja,Gmina Moszczenica,Moshhenica,Мощеница,Ґміна Мощениця', 51.5029700, 19.7198600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111588, 'Moszczanka', 'Moszczanka', '', 50.3002000, 17.4910900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111589, 'Mosty', 'Mosty', '', 54.6119500, 18.4963400, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111590, 'Mosty', 'Mosty', '', 53.5479600, 14.9563400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111591, 'Mosina', 'Mosina', 'Gorad Masina,Mosina,mo xi na,mwshyna,Горад Масіна,Мосина,Мосіна,موشینا,莫西納', 52.2454300, 16.8470900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111592, 'Moryń', 'Moryn', 'Mohrin,Morin,Morin'',Morina,Moriņa,Moryn'',Morzeno,Mòrzëno,mo lun,Моринь,Морињ,Морынь,莫倫', 52.8576900, 14.3929700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111593, 'Morąg', 'Morag', 'Gorad Morang,Mohrungen,Morag,Mordong,Morong,Moronga,Morongas,Morąg,mo long ge,Горад Моранг,Мордонг,Моронг,莫龍格', 53.9171100, 19.9260200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111594, 'Mokrsko', 'Mokrsko', '', 51.1789700, 18.4887900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111595, 'Mogilno', 'Mogilno', 'Mogil''no,Mogilno,mo ji er nuo,Могилно,Могильно,Моґільно,莫吉爾諾', 52.6580600, 17.9557800, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111596, 'Mogilany', 'Mogilany', '', 49.9389000, 19.8897200, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111597, 'Modlniczka', 'Modlniczka', 'Modliczka,Modlniczki', 50.1173900, 19.8553000, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111598, 'Modlnica', 'Modlnica', '', 50.1295800, 19.8646100, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111599, 'Mochowo', 'Mochowo', '', 52.7657000, 19.5559200, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111600, 'Mników', 'Mnikow', '', 50.0604400, 19.7259500, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111601, 'Mnich', 'Mnich', 'Mnich', 49.8894400, 18.8072200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111602, 'Młynary', 'Mlynary', 'Mlinari,Mlynary,Muhlhausen,Mühlhausen,Młynary,mu wei na lei,Млинари,Млынары,姆維納雷', 54.1869000, 19.7214900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111603, 'Mirsk', 'Mirsk', 'Friedeberg,Friedeberg am Queis,Mirs''k,Mirsk,Mirska,mi er si ke,Мирск,Мірськ,米爾斯克', 50.9705400, 15.3856700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111604, 'Mirosławiec', 'Miroslawiec', 'Fredladk,Frydlad,Frédlądk,Maerkisch Friedland,Miroslavec,Miroslavec'',Miroslaveca,Miroslavjec,Miroslawice,Mirosławice,Märkisch Friedland,mi luo si wa wei ci,Мирославец,Мирославець,Мирославјец,מירוסלאבייץ,米羅斯瓦維茨', 53.3407100, 16.0879300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111605, 'Milówka', 'Milowka', '', 49.5554000, 19.0907200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111606, 'Miłosław', 'Miloslaw', 'Gorad Miloslau,Miloslav,Miloslava,Miloslaw,Miłosław,mi wo si wa fu,Горад Мілослаў,Милослав,Мілослав,米沃斯瓦夫', 52.2031800, 17.4895500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111607, 'Miłoradz', 'Miloradz', 'Mielenz,Miloradz,Miłoradz', 54.0139200, 18.9184600, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111608, 'Miłomłyn', 'Milomlyn', 'Liebemuhl,Liebemühl,Milomlin,Milomlina,Milomlyn,Miłomłyn,mi wo mu wen,Миломлин,Миломлын,Міломлин,米沃姆溫', 53.7644900, 19.8380000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111609, 'Miłkowice', 'Milkowice', 'Arnsdorf,Milkowice,Miłkowice', 51.2560100, 16.0723100, 'PL', '2015-09-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111610, 'Milicz', 'Milicz', 'Gorad Milich,Milica,Milich,Milicz,Militsch,Miliča,mi li qi,Горад Міліч,Милич,Мілич,米利奇', 51.5277000, 17.2713700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111611, 'Mikstat', 'Mikstat', 'Gorad Mikstat,Mikstat,Mikstata,mi ke si ta te,Горад Мікстат,Микстат,Мікстат,米克斯塔特', 51.5323600, 17.9737800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111612, 'Mikołów', 'Mikolow', 'Miklos,Miklós,Mikolov,Mikolova,Mikolow,Mikoluv,Mikoluvas,Mikoluw,Mikołów,Mikołůw,Mikulas,Mikuláš,Nicolaas,Nicolai,Nikolai,Nikolaus,mi ke wu fu,mikoufu,Миколов,Миколув,Міколув,ミコウフ,米科武夫', 50.1710300, 18.9041000, 'PL', '2015-11-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111613, 'Mikołajki Pomorskie', 'Mikolajki Pomorskie', 'Mikolajki,Mikolajki Pomorskie,Mikolajki-Pomorske,Mikołajki,Mikołajki Pomorskie,Niklaskirchen,Nikolaiken,Миколайки-Поморске', 53.8513100, 19.1657400, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111614, 'Mieszkowice', 'Mieszkowice', 'Barwalde,Barwalde in Neumark,Berwold,Berwôłd,Bärwalde,Bärwalde in Neumark,Meshkovice,Meskovice,Meškovice,Mjeshkovice,mei shen ke wei cai,Мешковице,Мешковіце,Мјешковице,梅什科維采', 52.7873000, 14.4934600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111615, 'Mieścisko', 'Miescisko', '', 52.7435700, 17.3321300, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111616, 'Mierzęcice', 'Mierzecice', '', 50.4450400, 19.1293400, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111617, 'Mieroszów', 'Mieroszow', 'Friedland,Friedland in Schlesien,Fyrlad,Meroshuv,Merosova,Merošova,Mieroszow,Mieroszów,Mjeroshov,mei luo shu fu,Мерошув,Мјерошов,梅羅舒夫', 50.6658900, 16.1888300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111618, 'Mielno', 'Mielno', 'Grossmollen,Grossmollen uber Koslin,Grossmöllen,Grossmöllen über Köslin,Mel''no,Mielno Koszalinskie,Mielno Koszalińskie,Мельно', 54.2608600, 16.0621000, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111619, 'Mieleszyn', 'Mieleszyn', '', 52.6686800, 17.4977900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111620, 'Miękinia', 'Miekinia', 'Comuna de Miekinia,Comuna de Miękinia,Gmina Menkinja,Gmina Miekinia,Gmina Miękinia,Menkinja,Miekinia,Miękinia,Менкиня,Ґміна Мєнкіня', 51.1884400, 16.7359500, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111621, 'Miękinia', 'Miekinia', 'Miekina,Miekinia,Miękina,Miękinia', 50.1555700, 19.6087100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111622, 'Miejska Górka', 'Miejska Gorka', 'Mejs''ka Gurka,Mejska Gurka,Mejska-Gurka,Miejska Gorka,Miejska Górka,Mjejska Gorka,mei yi si ka gu er ka,Мейска-Гурка,Мейська Гурка,Мјејска Горка,梅伊斯卡古爾卡', 51.6557300, 16.9582600, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111623, 'Międzyzdroje', 'Miedzyzdroje', 'Mendzizdroe,Mendzizdroje,Mendzyzdroe,Meņdzizdroje,Misdroy,Mizezdroje,Mizëzdroje,Mjendzizdroje,Mysdroje,mian ji zi de luo ye,Мендзыздрое,Мєндзиздроє,Мјендзиздроје,緬濟茲德羅耶', 53.9292100, 14.4509700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111624, 'Międzyrzecz', 'Miedzyrzecz', 'Gorad Mendzyrehch,Mendzizeca,Mendzizhech,Mendzižeča,Mendzyzecas,Mendzyzhech,Mendzyžečas,Mesdirtz,Meseritz,Miedzyrzecz,Międzyrzecz,Mjendzizhech,mian ji re qi,Горад Мендзырэч,Мендзижеч,Мендзыжеч,Мјендзижеч,緬濟熱奇', 52.4446100, 15.5780100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111625, 'Międzylesie', 'Miedzylesie', 'Miedzylesie,Mittwalde,Międzylesie', 52.1448700, 15.3828300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111626, 'Międzylesie', 'Miedzylesie', 'Mendzilese,Mendzylese,Mezilesi,Mezilesí,Mittelwalde,Mjendzilesje,mian ji lai xie,Мендзылесе,Мєндзилесе,Мјендзилесје,緬濟萊謝', 50.1477800, 16.6671200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111627, 'Międzychód', 'Miedzychod', 'Birnbaum,Mendzihoda,Mendzikhod,Mendzikhud,Mendzykhud,Miedzychod,Międzychód,Mjendzikhod,mian ji hu de,myendzu~ifuto,Мендзиход,Мендзихуд,Мендзыхуд,Мјендзиход,ミェンヅィフト,緬濟胡德', 52.5988200, 15.8969600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111628, 'Międzybrodzie Bialskie', 'Miedzybrodzie Bialskie', 'Miedzybrodzie,Międzybrodzie', 49.7874700, 19.1974100, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111629, 'Międzybórz', 'Miedzyborz', 'Mendziboza,Mendziboža,Mendzibuzh,Mendzybuzh,Miedzyborz,Międzybórz,Mjendzibozh,Neumittelwalde,mian ji bu ri,Мендзыбуж,Мєндзибуж,Мјендзибож,緬濟布日', 51.3962600, 17.6661000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111630, 'Miedzno', 'Miedzno', '', 50.9699400, 18.9811100, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111631, 'Miedźna', 'Miedzna', 'Miedzna,Miedźna', 49.9822500, 19.0488300, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111632, 'Miedzichowo', 'Miedzichowo', '', 52.3758100, 15.9587600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111633, 'Miechów Charsznica', 'Miechow Charsznica', '', 50.3959900, 19.9503100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111634, 'Michałowice', 'Michalowice', '', 50.1589800, 19.9804400, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111635, 'Miastko', 'Miastko', 'Miastko,Miastkò,Miasztko,Miásztkó,Mjastko,Rummelsburg,Rummelsburg in Pommern,mi ya si te ke,Мястко,米亞斯特科', 54.0028300, 16.9826300, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111636, 'Miasteczko Śląskie', 'Miasteczko Slaskie', 'Miasteczko,Miasteczko Slaskie,Miasteczko Śląskie,Mjastechko Shl''onske,Mjastechko Slonskje,Mjastechko-Shl''ons''ke,Mjastechko-Sljonske,Mjastecko Slonske,Mjastečko Slonske,Мястечко Шльонске,Мястечко-Слёнске,Мястечко-Шльонське,Мјастечко Слонскје', 50.5026200, 18.9394900, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111637, 'Miasteczko Krajeńskie', 'Miasteczko Krajenskie', 'Friedheim,Miasteczko,Miasteczko Krainskie,Miasteczko Kraińskie', 53.0978400, 17.0047800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111638, 'Mętków', 'Metkow', '', 50.0525100, 19.3752500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111639, 'Mazańcowice', 'Mazancowice', 'Mazancowice,Mazańcowice', 49.8580200, 18.9770800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111640, 'Maszewo Duże', 'Maszewo Duze', '', 52.5802600, 19.6290500, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111641, 'Maszewo', 'Maszewo', 'Masevo,Mashevo,Massow,Maszewo,Maszewò,Maševo,ma xie wo,Машево,馬謝沃', 53.4961500, 15.0616600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111642, 'Maszewo', 'Maszewo', 'Maszewo,Messow', 52.0689600, 14.9055300, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111643, 'Markłowice', 'Marklowice', 'Marklowice,Markłowice', 50.0169500, 18.5209800, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111644, 'Marianowo', 'Marianowo', '', 53.3828700, 15.2664500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111645, 'Margonin', 'Margonin', 'Margonin,Margonina,Margoņina,ma er ge ning,Маргонин,Маргонін,Маргоњин,馬爾戈寧', 52.9733500, 17.0946400, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111646, 'Marciszów', 'Marciszow', '', 50.8447000, 16.0211600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111647, 'Małomice', 'Malomice', 'Mallmitz,Malmitz,Malomice,Małomice,ma wo mi cai,Маломице,Маломіце,馬沃米采', 51.5559700, 15.4500400, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111648, 'Malec', 'Malec', '', 49.9210600, 19.2453000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111649, 'Małdyty', 'Maldyty', 'Maldeuten,Maldyty,Małdyty,Малдыты', 53.9198100, 19.7439800, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111650, 'Malczyce', 'Malczyce', 'Malczyce,Maloszyn,Maltsch,Małoszyn', 51.2203800, 16.4936500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111651, 'Malbork', 'Malbork', 'Mal''bork,Malbork,Malborka,Malborkas,Marienburg,Мальборк', 54.0359100, 19.0266000, 'PL', '2017-07-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111652, 'Malanów', 'Malanow', '', 51.9535800, 18.3912800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111653, 'Maków Podhalański', 'Makow Podhalanski', 'Makiv-Pidkhaljans''kij,Makov Podkhaljanski,Makov Potkhalanski,Makova Podhalanska,Makova Podhalaņska,Makow,Makow Podhalanski,Makuv-Podkhaljan''skij,Maków,Maków Podhalański,Маков Подхалянски,Маков Потхалањски,Макув-Подхаляньский,Маків-Підхалянський', 49.7300800, 19.6771100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111654, 'Łyszkowice', 'Lyszkowice', '', 51.9855100, 19.9065400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111655, 'Łysomice', 'Lysomice', '', 53.0862900, 18.6200200, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111656, 'Lyski', 'Lyski', '', 50.1199200, 18.3914600, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111657, 'Lwówek Śląski', 'Lwowek Slaski', 'Comuna de Lwowek Slaski,Comuna de Lwówek Śląski,Gmina L''vuvek-Shl''ons''kij,Gmina Lwowek Slaski,Gmina Lwówek Śląski,Komunumo Lwowek Slaski,Komunumo Lwówek Śląski,L''vuvek-Sljonski,Lowenberg,Lowenberg in Schlesien,Lwowek Slaski,Lwówek Śląski,Löwenberg,Löwenberg in Schlesien,Львувек-Слёнски,Ґміна Львувек-Шльонський', 51.1107400, 15.5858200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111658, 'Lwówek', 'Lwowek', 'Comuna de Lwowek,Comuna de Lwówek,Gmina L''vuvek,Gmina Lwowek,Gmina Lwówek,L''vuvek,Lwowek,Lwówek,Neustadt bei Pinne,Львувек,Ґміна Львувек', 52.4479800, 16.1810600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111659, 'Luzino', 'Luzino', 'Lezeno,Ljuzino,Luzino,Lëzëno,Люзино', 54.5660400, 18.1090700, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111660, 'Lututów', 'Lututow', 'Comuna de Lututow,Comuna de Lututów,Gmina Ljututuv,Gmina Lututow,Gmina Lututów,Ljututuv,Лютутув,Ґміна Лютутув', 51.3703300, 18.4348000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111661, 'Lutomiersk', 'Lutomiersk', 'Comuna de Lutomiersk,Gmina Ljutomers''k,Gmina Lutomiersk,Ljutomersk,Лютомерск,Ґміна Лютомерськ', 51.7537600, 19.2109700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111662, 'Lutocin', 'Lutocin', '', 52.9815200, 19.7665500, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111663, 'Luszowice', 'Luszowice', '', 50.1741500, 19.4042600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111664, 'Ludźmierz', 'Ludzmierz', 'Ludzimierz,Ludzmierz,Ludźmierz', 49.4665600, 19.9825000, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111665, 'Ludwikowice Kłodzkie', 'Ludwikowice Klodzkie', 'Ludwigsdorf,Ludwikow,Ludwikowice Klodzkie,Ludwikowice Kłodzkie,Ludwikowo', 50.6246400, 16.4605200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111666, 'Lubsza', 'Lubsza', '', 50.9159100, 17.5217300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111667, 'Lubsko', 'Lubsko', 'Ljubs''ko,Ljubsko,Lubsko,Lupsko,Sommerfeld,Zemr,Zemsz,lu bu si ke,lubseuko,Žemŕ,Лупско,Любско,Любсько,盧布斯科,룹스코', 51.7846700, 14.9719600, 'PL', '2013-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111668, 'Lubrza', 'Lubrza', 'Liebenau,Liebenau bei Schwiebus,Lubna,Lubrza', 52.3041800, 15.4431700, 'PL', '2014-05-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111669, 'Lubrza', 'Lubrza', '', 50.3363100, 17.6263600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111670, 'Lubraniec', 'Lubraniec', 'Ljubranec,Ljubranec'',Lubranec,Lubraneca,Lubranecas,Lubraniec,Lubraņeca,Лубрањец,Любранец,Любранець', 52.5417800, 18.8325400, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111671, 'Łubowo', 'Lubowo', '', 53.5863400, 16.3917700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111672, 'Łubowo', 'Lubowo', '', 52.5116800, 17.4533300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111673, 'Lubowidz', 'Lubowidz', 'Ljubovidz,Lubowidz,Любовидз', 53.1186500, 19.8459400, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111674, 'Luboń', 'Lubon', 'Liubonis,Ljubon,Ljubon'',Lubon,Lubona,Luboń,Luboņa,Luboň,lu bang,Лубоњ,Любон,Любонь,盧邦', 52.3470500, 16.8926700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111675, 'Lubomierz', 'Lubomierz', 'Liebenthal,Ljubomezh,Lubomeza,Lubomeža,Lubomierz,Lubomjezh,Лубомјеж,Любомеж,ลูบอมีแยช', 51.0127800, 15.5096900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111676, 'Lubomia', 'Lubomia', 'Lubomia', 50.0397200, 18.3082000, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111677, 'Lubniewice', 'Lubniewice', 'Konigswalde,Königswalde,Ljubnevice,Lubnevice,Lubniewica,Lubniewice,Lubņevice,lu bu nie wei cai,Лубњевице,Любневице,Любневіце,盧布涅維采', 52.5163800, 15.2500500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111678, 'Łubnice', 'Lubnice', '', 51.1640600, 18.2906900, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111679, 'Łubniany', 'Lubniany', 'Comuna de Lubniany,Comuna de Łubniany,Gmina Lubniany,Gmina Lubnjani,Gmina Łubniany,Lubniany,Lubnjany,Lugendorf,Lugnian,Lugniany,Łubniany,Ługniany,Лубняны,Ґміна Лубняни', 50.7859700, 18.0011000, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111680, 'Lubliniec', 'Lubliniec', 'Liublinecas,Ljublinec,Ljublinec'',Lublinec,Lublineca,Lublinek,Lubliniec,Lublinitz,Lubliņeca,Lublynec,Lublyńec,lu bu li nie ci,ruburinyetsu,Лублињец,Люблинец,Люблінець,ルブリニェツ,盧布利涅茨', 50.6689700, 18.6844000, 'PL', '2015-11-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111681, 'Lublewo Gdańskie', 'Lublewo Gdanskie', 'Ljublevo,Loblau,Lublewo,Lublewo Gdanskie,Lublewo Gdańskie,Löblau,Люблево', 54.2845700, 18.5038900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111682, 'Lubiszyn', 'Lubiszyn', 'Lubiszyn,Ludwigsruh', 52.7807500, 14.9479300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111683, 'Lubin', 'Lubin', 'Gorad Ljubin,Liubinas,Ljubin,Luben,Lubin,Lubina,Luebin,Lüben,Lübin,lu bin,lubin,lwbyn,lyubina,rubin,Горад Любін,Лубин,Любин,Любін,לובין,ल्युबिन,ルビン,盧賓,루빈', 51.4008900, 16.2014900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111684, 'Lubiewo', 'Lubiewo', '', 53.4654200, 18.0299400, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111685, 'Lubień Kujawski', 'Lubien Kujawski', 'Lubien,Lubien Kujawski,Lubień,Lubień Kujawski', 52.4057400, 19.1644000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111686, 'Lubień', 'Lubien', '', 49.7192100, 19.9784700, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111687, 'Lubichowo', 'Lubichowo', '', 53.8513600, 18.3990100, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111688, 'Łubianka', 'Lubianka', 'Lubianka,Lubjanka,Łubianka,Лубянка', 53.1386400, 18.4811500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111689, 'Lubawka', 'Lubawka', 'Liebau,Liebau in Schlesien,Ljubavka,Lubavka,Lubawka,lu ba fu ka,Лубавка,Любавка,盧巴夫卡', 50.7045600, 16.0002600, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111690, 'Lubawa', 'Lubawa', 'Liubava,Ljubava,Lubava,lu ba wa,Лубава,Любава,盧巴瓦', 53.5042800, 19.7496600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111691, 'Lubasz', 'Lubasz', '', 52.8521300, 16.5234400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111692, 'Lubanie', 'Lubanie', 'Ljubane,Lubanie,Любане', 52.7468900, 18.9194000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111693, 'Lubań', 'Luban', 'Gorad Ljuban'',Lauba Lusatorum,Lauban,Liubanis,Ljuban,Ljuban'',Luban,Lubana,Lubań,Lubaņa,lu ban,lwbn,Горад Любань,Лубањ,Любан,Любань,לובן,盧班', 51.1201400, 15.2876800, 'PL', '2015-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111694, 'Łowicz', 'Lowicz', 'Lovica,Lovich,Lovicius,Lovitium,Loviča,Lovičius,Lowicz,Lowitsch,lwbyz,u~ovu~ichi,wo wei qi,wobichi,Łowicz,Лович,לוביץ,ウォヴィチ,沃維奇,워비치', 52.1071400, 19.9452500, 'PL', '2013-07-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111695, 'Łosiów', 'Losiow', '', 50.7909600, 17.5659400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111696, 'Łódź', 'Lodz', 'Gorad Lodz'',Litzmannstadt,Lo-tsu,Lodz,Lodz'',Lodz'' osh,Lodza,Lodze,Lodzia,Lodzo,Lodzė,Lodž,Log,Loj,Lotz,Luc,Ludz,Luz,Lò-tsṳ,lodzi,luo ci,luo zi,lwdz,uchi,utchi,vutsa,wuch,wwch,wwdj,Łódź,Łůdź,Λοτζ,Горад Лодзь,Лодз,Лодзь,Лодзь ош,Лођ,Лоѓ,Луӟ,Լոձ,לאדזש,לודז,لودز,وودج,ووچ,वूत्श,วูช,ლოძი,ウッチ,罗兹,羅茲,우치', 51.7500000, 19.4666700, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111697, 'Łodygowice', 'Lodygowice', '', 49.7299200, 19.1393900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111698, 'Łobżenica', 'Lobzenica', 'Lobsens,Lobzenica,Lobzhenica,Lobzhenicja,Lobžeņica,wo bu re ni cha,Łobzenica,Łobżenica,Лобженица,Лобжениця,Лобжењица,沃布熱尼察', 53.2624400, 17.2557400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111699, 'Łobodno', 'Lobodno', '', 50.9307900, 18.9909000, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111700, 'Łobez', 'Lobez', 'Gorad Lobaz,Laabs,Labes,Lobesia,Lobez,Lobez osh,Lobeza,Lobezas,Lompez,Luobezos,lwbs,lwbyz,wo bei zi,wobeseu,Łobéz,Λόμπεζ,Горад Лобаз,Лобез,Лобез ош,لوبس,لوبيز,ዎበስ,沃貝茲,워베스', 53.6391800, 15.6212900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111701, 'Lniano', 'Lniano', '', 53.5280100, 18.2126700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111702, 'Liszki', 'Liszki', '', 50.0388400, 19.7683500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111703, 'Lisków', 'Liskow', '', 51.8331300, 18.3978900, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111704, 'Lisewo Malborskie', 'Lisewo Malborskie', 'Liessau,Lisevo,Lisewo,Лисево', 54.0966500, 18.8292800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111705, 'Lisewo', 'Lisewo', 'Lisevo,Lisewo,Лисево', 53.2958000, 18.6871400, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111706, 'Lipusz', 'Lipusz', 'Lepusz,Lëpùsz', 54.0980600, 17.7845500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111707, 'Lipowa', 'Lipowa', '', 49.6757400, 19.0939800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111708, 'Lipno', 'Lipno', 'Lipno,Липно', 52.8443600, 19.1785200, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111709, 'Lipno', 'Lipno', 'Gmina Lipno,Lipno,Липно,Ґміна Ліпно', 51.9172200, 16.5670800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111710, 'Lipnica Wielka', 'Lipnica Wielka', 'Alsolipnica,Alsólipnica,Dolna Lipnica,Dolná Lipnica,Lipnica Wielka,Nizna Lipnica,Nižná Lipnica', 49.4740400, 19.6388300, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111711, 'Lipnica Mała', 'Lipnica Mala', 'Felsolipnica,Felsőlipnica,Lipnica Mala,Lipnica Mała', 49.5150700, 19.6349700, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111712, 'Lipnica', 'Lipnica', 'Lepince,Lëpińce', 53.9962300, 17.4070200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111713, 'Lipka', 'Lipka', 'Linde,Linde in Westpreussen,Lipka', 53.4960100, 17.2508500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111714, 'Lipinki Łużyckie', 'Lipinki Luzyckie', '', 51.6395400, 14.9987400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111715, 'Lipie', 'Lipie', '', 51.0125700, 18.7965800, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111716, 'Lipiany', 'Lipiany', 'Lepienie,Lipjani,Lipjany,Lippehne,Lëpienié,li pi ya nei,Липяны,Липјани,Ліпяни,利皮亞內', 53.0033600, 14.9691900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111717, 'Lipce Reymontowskie', 'Lipce Reymontowskie', 'Lipce,Lipce Stara Wies,Lipce Stara Wieś', 51.8986300, 19.9417300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111718, 'Liniewo', 'Liniewo', '', 54.0766100, 18.2267500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111719, 'Linia', 'Linia', '', 54.4514300, 17.9345400, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111720, 'Ligota', 'Ligota', 'Ligota', 49.8985600, 18.9509000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111721, 'Lidzbark', 'Lidzbark', 'Lautenburg,Lidzbark,Lidzbark Welski,Lidzbark-Wies,Lidzbark-Wieś,Lidzbarka,li zi ba ke,Лидзбарк,Лідзбарк,利茲巴克', 53.2628300, 19.8266300, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111722, 'Licheń Stary', 'Lichen Stary', 'Lichen Stari,Lichen Stary,Licheń Stary,Личен Стари', 52.3122600, 18.3551500, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111723, 'Libiąż', 'Libiaz', 'Gorad Libjonzh,Lib''onzh,Libiaz,Libiąż,Libjonza,Libjonzh,Libjonža,li bi weng ri,Горад Лібёнж,Либьонж,Либёнж,Либјонж,Лібйонж,利比翁日', 50.1039600, 19.3156800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111724, 'Libertów', 'Libertow', '', 49.9724200, 19.8946100, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111725, 'Lgota Wielka', 'Lgota Wielka', '', 51.1490400, 19.3273500, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111726, 'Łęczyce', 'Leczyce', 'Comuna de Leczyce,Comuna de Łęczyce,Gmina Laczece,Gmina Leczyce,Gmina Lenchice,Gmina Łãczëce,Gmina Łęczyce,Lenchice,Ленчице,Ґміна Ленчице', 54.5940500, 17.8593100, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111727, 'Lewin Kłodzki', 'Lewin Klodzki', 'Hummelstadt,Lewin', 50.4055900, 16.2910100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111728, 'Lewin Brzeski', 'Lewin Brzeski', 'Levin Bzheski,Levin-Bzhes''kij,Levin-Bzheski,Levin-Bzheskij,Levina Bzeska,Levina Bžeska,Lewin,Lewin Brzeski,Loewen  Glatzer Neisse,Luoien,Löwen  Glatzer Neiße,Левин Бжески,Левин-Бжески,Левин-Бжеский,Левін-Бжеський', 50.7487000, 17.6168800, 'PL', '2017-07-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111729, 'Leszno', 'Leszno', 'Gorad Leshna,Leshno,Lesnas,Lesno,Leszno,Lešnas,Lešno,Lissa,lai shen nuo,lesyuno,lsnw,reshuno,Горад Лешна,Лешно,ליסא,לשנו,レシュノ,莱什诺,레슈노', 51.8403400, 16.5749400, 'PL', '2010-10-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111730, 'Leśnica', 'Lesnica', 'Bergstadt,Leschnitz,Leschnitz Oberschlesien,Lesnica,Leśnica', 50.4308300, 18.1868400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111731, 'Leśna', 'Lesna', 'Les''na,Leshna,Lesna,Leśna,Lěsna,Marklissa,Marklissa-Schlesian,lai xi na,Лесна,Лесьна,Лешна,萊希納', 51.0243100, 15.2641300, 'PL', '2015-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111732, 'Leśna', 'Lesna', '', 49.6704100, 19.1276300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111733, 'Leńcze', 'Lencze', 'Lencze,Lencze Gorne,Leńcze,Leńcze Górne', 49.8989500, 19.7353900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111734, 'Lelów', 'Lelow', 'Lelow,Lelów,llwb,ללוב', 50.6833500, 19.6256200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111735, 'Łęknica', 'Leknica', 'Leknica,Leknice,Lenknica,Lenknicja,Lenkņica,Lucknitz,Lugknitz,Lugnice,Wjeska,wen ke ni cha,Ługnice,Łęknica,Łęknice,Ленкница,Ленкниця,Ленкњица,文克尼察', 51.5414800, 14.7358400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111736, 'Łęki Szlacheckie', 'Leki Szlacheckie', '', 51.1877400, 19.7979600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111737, 'Łękawica', 'Lekawica', '', 49.7220900, 19.2649600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111738, 'Łęka Opatowska', 'Leka Opatowska', '', 51.2123100, 18.1071000, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111739, 'Łęgowo', 'Legowo', 'Langenau,Legowo,Łęgowo', 54.2264100, 18.6427700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111740, 'Legnickie Pole', 'Legnickie Pole', 'Legnickie Pole,Wahlstatt', 51.1441900, 16.2420800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111741, 'Legnica', 'Legnica', 'Gorad Ljagnica,Legnica,Legnicja,Legņica,Lehnice,Liegnitz,Lignica,Lignitium,Ligńica,lai ge ni cha,legeunicha,lghnytsa,lgnytsa,lgnyzh,regunitsu~a,Горад Лягніца,Легница,Легниця,Легњица,Լեգնիցա,לגניצה,لغنيتسا,لگنیتسا,レグニツァ,萊格尼察,레그니차', 51.2100600, 16.1619000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111742, 'Lędziny', 'Ledziny', 'Ledziny,Lendzhini,Lendzini,Lendziny,Leņdzini,Lyndziny,Lyńdźiny,Lędziny,lun ji nei,renjini,Ленджини,Лендзины,Лендзіни,Ленђини,レンジニ,倫濟內', 50.1426400, 19.1314900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111743, 'Łęczyca', 'Leczyca', 'Leczyca,Lenchica,Lenchicja,Lencica,Lenčica,lnzyzh,u~enchitsu~a,wen qi cha,Łęczyca,Ленчица,Ленчиця,לנציצה,ウェンチツァ,文奇察', 52.0595900, 19.1997200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111744, 'Lębork', 'Lebork', 'Laborg,Lauenburg,Lauenburg in Pommern,Lebork,Lembork,Lemborka,Lemborkas,Lãbórg,Lębork,lun bao,renboruku,Лемборк,แลมบอร์ก,レンボルク,倫堡', 54.5392100, 17.7501200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111745, 'Łeba', 'Leba', 'Leba,wei ba,Леба,韋巴', 54.7609900, 17.5554700, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111746, 'Łazy', 'Lazy', 'Lazi,Lazy,wa ji,waji,Łazy,Лази,Лазы,ワジ,瓦濟', 50.4276900, 19.3946500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111747, 'Łazy', 'Lazy', 'Lazi,Lazy,wa ji,waji,Лази,Лазы,ワジ,瓦濟', 50.3500000, 19.4166700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111748, 'Łaziska Górne', 'Laziska Gorne', 'Aukstutiniai Laziskai,Aukštutiniai Laziskai,Gurne Laziska,Gůrne Łaźiska,Lagissa,Lazhiska Gorne,Lazis''ka-Gurne,Laziska Gorne,Laziska Gurne,Laziska-Gurne,Laziskagorna,Oberlasisk,Oberlazisk,shang wa ji si ka,Łaziska Górne,Лажиска Горне,Лазиска Горне,Лазиска-Гурне,Лазиська-Гурне,上瓦濟斯卡', 50.1495200, 18.8421500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111749, 'Łaziska', 'Laziska', 'Laziska,Łaziska', 49.9357000, 18.4470700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111750, 'Łask', 'Lask', 'Las''k,Lask,Laska,wa si ke,Łask,Ласк,Ласьк,לאסק,瓦斯克', 51.5905600, 19.1327800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111751, 'Łasin', 'Lasin', 'Lasin,Lasina,Lazin,Loseno,wa xin,Łasin,Łazin,Łôsëno,Ласин,Ласін,瓦辛', 53.5179400, 19.0883200, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111752, 'Lasek', 'Lasek', '', 49.5088300, 19.9807800, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111753, 'Łanięta', 'Lanieta', 'Comuna de Lanieta,Comuna de Łanięta,Gmina Lanenta,Gmina Lanieta,Gmina Łanięta,Lanenta,Lanieta,Łanięta,Ланента,Ґміна Ланента', 52.3620300, 19.2803200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111754, 'Lanckorona', 'Lanckorona', 'lankwrwna,لانکورونا', 49.8449600, 19.7157800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111755, 'Łambinowice', 'Lambinowice', 'Lambinowice,Lamsdorf,Łambinowice', 50.5386900, 17.5609600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111756, 'Laliki', 'Laliki', '', 49.5344600, 19.0054900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111757, 'Łąka Prudnicka', 'Laka Prudnicka', '', 50.3106100, 17.5280900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111758, 'Łagów', 'Lagow', 'Lagow,Łagów', 52.3342900, 15.2976900, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111759, 'Łagów', 'Lagow', 'Lagow,Łagów', 51.1583500, 15.0437200, 'PL', '2010-10-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111760, 'Łagiewniki', 'Lagiewniki', 'Heidersdorf,Lagiewniki,Łagiewniki', 50.7908800, 16.8445700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111761, 'Lądek-Zdrój', 'Ladek-Zdroj', 'Bad Landeck,Bad Landeck in Schlesien,L''ondek-Zdruj,Ladek Zdroj,Landeck,Landeck in Schlesien,Ljondek-Zdruj,Londek-Zdroj,Londekzdroja,Lądek Zdrój,long dai ke-zi de lu yi,Ладек Здрой,Лондек-Здрој,Льондек-Здруй,Лёндек-Здруй,隆代克-茲德魯伊', 50.3437100, 16.8794600, 'PL', '2010-09-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111762, 'Lądek', 'Ladek', '', 52.2092900, 17.9299400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111763, 'Łączany', 'Laczany', '', 49.9840700, 19.5786700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111764, 'Łąck', 'Lack', '', 52.4662100, 19.6113700, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111765, 'Lachowice', 'Lachowice', '', 49.7155500, 19.4745500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111766, 'Łabiszyn', 'Labiszyn', 'Labishin,Labisina,Labiszyn,Labišina,wa bi shen,Łabiszyn,Лабишин,Лабішин,瓦比申', 52.9521000, 17.9197100, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111767, 'Kwilcz', 'Kwilcz', '', 52.5550600, 16.0856200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111768, 'Kwidzyn', 'Kwidzyn', 'Kvidzin,Kvidzina,Kvidzyn,Kvidzynas,Kwidzeno,Kwidzyn,Kwidzëno,Marienwerder,k fid sun,ke wei ceng,Квидзин,Квидзын,Квідзин,กฟิดซึน,克维曾', 53.7249500, 18.9311400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111769, 'Kwaczała', 'Kwaczala', '', 50.0640800, 19.4921500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111770, 'Kuźnia Raciborska', 'Kuznia Raciborska', 'Kuzhnja Rachiborska,Kuzna Raciborska,Kuznia Raciborska,Kuznica Raciborska,Kuznja-Racibors''ka,Kuznja-Raciborskaja,Kuzņa Raciborska,Kuźnia Raciborska,Kuźnica Raciborska,Ratiborhammer,Кужня Рачиборска,Кузня-Рациборская,Кузня-Рациборська,Кузња Раћиборска', 50.2005800, 18.3114600, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111771, 'Kutno', 'Kutno', 'Kutnas,Kutno,ku te na,qwtnw,Кутно,קוטנו,库特娜', 52.2306400, 19.3640900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111772, 'Kuślin', 'Kuslin', '', 52.3638600, 16.3153800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111773, 'Kurzętnik', 'Kurzetnik', '', 53.3985800, 19.5785800, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111774, 'Kup', 'Kup', 'Kup,Kupp,Kupy', 50.8065900, 17.8835100, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111775, 'Kunice Żarskie', 'Kunice Zarskie', '', 51.5994400, 15.1649500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111776, 'Kunice', 'Kunice', '', 51.2223100, 16.2480900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111777, 'Kuków', 'Kukow', '', 49.7325200, 19.4848500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111778, 'Kudowa-Zdrój', 'Kudowa-Zdroj', 'Bad Kudowa,Cudowa,Kudova Zdroj,Kudova-Zdruj,Kudovazdroja,Kudowa,Kudowa-Zdroj,Kudowa-Zdruj,Kudowa-Zdrój,Kudowa-Zdrůj,ku duo wa-zi de lu yi,Кудова Здрој,Кудова-Здруй,庫多瓦-茲德魯伊', 50.4429700, 16.2439700, 'PL', '2013-07-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111779, 'Książ Wielkopolski', 'Ksiaz Wielkopolski', 'Comuna de Ksiaz Wielkopolski,Comuna de Książ Wielkopolski,Gmina Ks''onzh-Vel''kopol''s''kij,Gmina Ksiaz Wielkopolski,Gmina Książ Wielkopolski,Ksiaz,Ksiaz Wielkopolski,Książ,Książ Wielkopolski,Ksjonzh-Vel''kopol''skij,Ксёнж-Велькопольский,Ґміна Ксьонж-Велькопольський', 52.0616700, 17.2395200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111780, 'Książki', 'Ksiazki', '', 53.3298000, 19.0702900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111781, 'Książenice', 'Ksiazenice', '', 50.1552400, 18.5992500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111782, 'Ksawerów', 'Ksawerow', '', 51.6828800, 19.4028000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111783, 'Krzyżowice', 'Krzyzowice', '', 49.9852800, 18.6728100, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111784, 'Krzyżowa', 'Krzyzowa', '', 49.5923500, 19.3446900, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111785, 'Krzyżanowice', 'Krzyzanowice', 'Kreuzenort,Krzyzanowice,Krzyżanowice', 49.9824700, 18.2684600, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111786, 'Krzyżanów', 'Krzyzanow', '', 52.1840900, 19.4561900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111787, 'Krzyż Wielkopolski', 'Krzyz Wielkopolski', 'Kreuz,Krziz,Krziż,Krzyz,Krzyż,Kshizh Vjelkopolski,Kshizh-Vel''kopol''skij,Kshizh-Velikopol''s''kij,Ksiza Velkopolska,Kšiža Velkopolska,Кшиж Вјелкополски,Кшиж-Великопольський,Кшиж-Велькопольский', 52.8809700, 16.0111600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111788, 'Krzywiń', 'Krzywin', 'Krzywin,Krzywiń,Kshivin,Kshivin'',Ksivina,Kšiviņa,ke ri wen,Кшивинь,Кшивињ,Кшивінь,克日溫', 51.9629600, 16.8198500, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111789, 'Krzywaczka', 'Krzywaczka', '', 49.8935300, 19.8322100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111790, 'Krzyszkowice', 'Krzyszkowice', '', 49.8834600, 19.9228500, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111791, 'Krzymów', 'Krzymow', '', 52.1896000, 18.4311000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111792, 'Krzykosy', 'Krzykosy', '', 52.1104100, 17.3741100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111793, 'Krzeszyce', 'Krzeszyce', 'Kriescht,Krzeszyce', 52.5832900, 15.0070700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111794, 'Krzeszowice', 'Krzeszowice', 'Krzeszowice,Ksesovice,Ksheshovice,Kzheshovice,Kšešovice,Kšešovicė,ke re shao wei cai,kshshwwytsh,Кжешовице,Кшешовице,Кшешовіце,کششوویتسه,克熱紹維采', 50.1424800, 19.6322300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111795, 'Krzeszów', 'Krzeszow', 'Gruessau,Grüssau,Krzeszow,Krzeszów,Ksheshuv,Кшешув', 50.7343400, 16.0699100, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111796, 'Krzeszów', 'Krzeszow', '', 49.7591500, 19.4891500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111797, 'Krzepice', 'Krzepice', 'Ksepice,Kshepice,Kšepice,ke re pi cai,qspyzh,Кшепице,Кшепіце,קשפיצה,克熱皮采', 50.9705900, 18.7288600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111798, 'Krzemieniewo', 'Krzemieniewo', '', 51.8590500, 16.8335400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111799, 'Krzęcin', 'Krzecin', '', 53.0816000, 15.4900800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111800, 'Krzęcin', 'Krzecin', '', 49.9431600, 19.7415700, 'PL', '2010-11-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111801, 'Krzczonów', 'Krzczonow', '', 49.7381300, 19.9182100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111802, 'Krzanowice', 'Krzanowice', 'Kranowitz,Kranstadt,Kranstodt,Kranstädt,Kranstödt,Krzanowice,Krzonowice,Ksanovice,Kshanovice,Kšanovice,ke zha nuo wei cai,Кшановице,Кшановіце,克扎諾維采', 50.0182200, 18.1225100, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111803, 'Kryspinów', 'Kryspinow', '', 50.0438000, 19.7982200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111804, 'Kryry', 'Kryry', '', 50.0166700, 18.8056800, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111805, 'Krynica Morska', 'Krynica Morska', 'Krinica Morska,Krinicja-Mors''ka,Kriņica Morska,Krynica Morska,Krynica-Morska,Kryniza Morska,Leso Gora - Lepa,ke li ni cha mo er si ka,Łësô Góra - Lëpa,Криниця-Морська,Крињица Морска,Крыница-Морска,克里尼查謨爾斯卡', 54.3805100, 19.4441300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111806, 'Kruszwica', 'Kruszwica', 'Krushvica,Krushvicja,Krusvica,Kruszwica,Krušvica,ke lu shen wei cha,Крушвица,Крушвиця,克魯什維察', 52.6756200, 18.3313100, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111807, 'Krupski Młyn', 'Krupski Mlyn', 'Borowian Kolonie,Kruppamuhle,Kruppamühle,Krupski Mlyn,Krupski Młyn', 50.5733700, 18.6225100, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111808, 'Krotoszyn', 'Krotoszyn', 'Gorad Kratoshyn,Krotoshin,Krotosina,Krotosynas,Krotoszyn,Krotošina,Krotošynas,ke luo tuo shen,Горад Кратошын,Кротошин,克羅托申', 51.6986800, 17.4373800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111809, 'Krosno Odrzańskie', 'Krosno Odrzanskie', 'Crossen,Krosno,Krosno Odrzanskie,Krosno Odrzańskie,Krosno Odzanske,Krosno Odzhanske,Krosno Odzhanskje,Krosno Odžaņske,Krosno-Odzhan''ske,Krosno-Odzhans''ke,ao de he pan ke luo si nuo,Кросно Оджанске,Кросно Оджањскје,Кросно-Оджанське,Кросно-Оджаньске,奧得河畔克羅斯諾', 52.0549200, 15.0988200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111810, 'Krosno', 'Krosno', '', 52.2235700, 16.8325100, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111811, 'Krośniewice', 'Krosniewice', 'Krosnevice,Krosniewice,Krosņevice,Krośniewice,ke luo xi nie wei cai,qrwsnyywwyzh,Кросневице,Кросневіце,Кросњевице,קרושנייוויצה,克羅希涅維采', 52.2559200, 19.1703700, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111812, 'Krośnice', 'Krosnice', 'Comuna de Krosnice,Comuna de Krośnice,Gmina Kroshnice,Gmina Krosnice,Gmina Krośnice,Kraschnitz,Krosnice,Krośnice,Municipio de Krosnice,Municipio de Krośnice,Кроснице,Ґміна Крошніце', 51.4764100, 17.3591700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111813, 'Krokowa', 'Krokowa', 'Krokova,Krokowa,Krokowo,Krokòwa,Крокова', 54.7792100, 18.1616000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111814, 'Kroczyce', 'Kroczyce', '', 50.5617600, 19.5700000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111815, 'Krobia', 'Krobia', 'Krobia,Krobija,Krobja,ke luo bi ya,Кробя,Кробія,Кробја,克羅比亞', 51.7740500, 16.9823700, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111816, 'Kraszewice', 'Kraszewice', '', 51.5186800, 18.2199700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111817, 'Krapkowice', 'Krapkowice', 'Chrapkowice,Krapkovice,Krapkovices,Krapkovicės,Krapkowice,Krappitz,ke la pu ke wei cai,Крапковице,Крапковіце,กรัปกอวิตแซ,克拉普科維采', 50.4751500, 17.9653900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111818, 'Kramsk', 'Kramsk', 'Kramsk,Крамск', 52.2646900, 18.4240700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111819, 'Kraków', 'Krakow', 'Carcovia,Cracau,Cracaû,Cracovia,Cracovie,Cracow,Cracòvia,Cracóvia,Gorad Krakau,KRK,Kraka,Krakau,Krakiv,Krakko,Krakkó,Krakobia,Krakov,Krakova,Krakovi,Krakovia,Krakovija,Krakovja,Krakovo,Krakow,Krakowo,Krakuw,Kraká,Krakòwò,Krakóvia,Kraków,Krakůw,Krakоv,Krokuva,ke la ke fu,keulakupeu,kraku f,krakupha,krakwf,kurakufu,qrqwb,Κρακοβία,Горад Кракаў,Краков,Краковия,Краків,Կրակով,קראקע,קרקוב,كراكوف,کراکوف,क्राकूफ,กรากุฟ,ကရားကော့မြို့,კრაკოვი,クラクフ,克拉科夫,크라쿠프', 50.0614300, 19.9365800, 'PL', '2016-02-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111820, 'Krajenka', 'Krajenka', 'Kraenka,Krajenka,Krojanke,ke la yan ka,Краенка,Краєнка,Крајенка,克拉延卡', 53.2975900, 16.9907900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111821, 'Kozy', 'Kozy', 'Kozy,Kozy Wielkie', 49.8475600, 19.1489100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111822, 'Kożuchów', 'Kozuchow', 'Freystadt,Kozhukhov,Kozhukhuv,Kozuchow,Kozuhova,Kożuchów,Kožuhova,ke ru hu fu,Кожухов,Кожухув,科茹胡夫', 51.7455800, 15.5949200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111823, 'Koźminek', 'Kozminek', '', 51.7987400, 18.3389300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111824, 'Koźmin Wielkopolski', 'Kozmin Wielkopolski', 'Koschmin,Koz''min-Velikopol''s''kij,Kozmin Vjelkopolski,Kozmin-Vel''kopol''ski,Kozmina Velkopolska,Козмин Вјелкополски,Козмин-Велькопольски,Козьмін-Великопольський', 51.8271200, 17.4539100, 'PL', '2013-10-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111825, 'Koźle', 'Kozle', 'Cosel,Kosel,Kossel,Kössel', 50.3356000, 18.1433200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111826, 'Kozielice', 'Kozielice', '', 53.1067900, 14.8223700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111827, 'Koziegłowy', 'Kozieglowy', 'Kozeglovi,Kozeglovy,Kozheglovi,Kozieglowy,Koziegłowy,Kozjeglovi,ke jie ge wo wei,Кожеглови,Козегловы,Козеґлови,Козјеглови,科傑格沃維', 50.6003500, 19.1629900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111828, 'Kowary', 'Kowary', 'Kovari,Kovary,Kowary,Krzyzatka,Krzyżatka,Schmiedeberg,Schmiedeberg in Schlesien,ke wa lei,Ковари,Ковары,科瓦雷', 50.7931300, 15.8355900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111829, 'Kowalewo Pomorskie', 'Kowalewo Pomorskie', 'Kovalevo Pomorske,Kovalevo Pomorskje,Kovalevo-Pomors''ke,Kovalevo-Pomorske,Kowalewo,Kowalewo Pomorskie,Kowolewo,Kòwôlewò,bo mo rui de qu ke wa lai wo,Ковалево Поморскје,Ковалево-Поморске,Ковалево-Поморське,波莫瑞地區科瓦萊沃', 53.1543200, 18.8986800, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111830, 'Kowale', 'Kowale', 'Kowale,Kowall,Schmiede', 54.3097600, 18.5614900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111831, 'Kowal', 'Kowal', 'Dəmirçi,Koval,Koval'',Kovala,Kowal,hdadt,ke wa er,Ковал,Коваль,קובאל,حدادة,科瓦爾', 52.5301900, 19.1476700, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111832, 'Kotlin', 'Kotlin', '', 51.9191300, 17.6482500, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111833, 'Kotla', 'Kotla', 'Kotla,Kuttlau', 51.7454200, 16.0357500, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111834, 'Koszarawa', 'Koszarawa', 'Koszarawa,Koszarowa', 49.6446200, 19.4008300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111835, 'Koszalin', 'Koszalin', 'Gorad Kashalin,Kezlin,Koeslin,Kosalina,Kosalinas,Koshalin,Koslin,Koszaleno,Koszalin,Košalina,Košalinas,Kòszalëno,Köslin,OSZ,Scurgum,ke sha lin,kosharin,kosyallin,kshalyn,kx chalin,Горад Кашалін,Кошалин,Кошалін,كشالين,کشالین,กอชาลิน,コシャリン,科沙林,코샬린', 54.1943800, 16.1722200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111836, 'Kostrzyn nad Odrą', 'Kostrzyn nad Odra', 'Cuestrin,Cüstrin,Kistrzyn,Koscerzeno,Kostrin,Kostrzyn ce Odro,Kostrzyn nad Odra,Kostrzyn nad Odrą,Kostrzyn ĉe Odro,Kostshin na Odri,Kostshin nad Odrom,Kostshin-nad-Odroju,Kostshin-nad-Odron,Kostsina pie Odras,Kostsynas prie Odros,Kostšina pie Odras,Kostšynas prie Odros,Kuestrin,Kòscérzëno,Küstrin,ao de he pan ke si qin,Костшин на Одри,Костшин над Одром,Костшин-над-Одрон,Костшин-над-Одрою,コストシン・ナド・オドロン,奥得河畔科斯琴', 52.5871300, 14.6495300, 'PL', '2015-11-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111837, 'Kostrzyn', 'Kostrzyn', 'Kostrzyn,Kostrzyń,Kostshin,Kostsina,Kostšina,ke si qin,Костшин,科斯琴', 52.3984700, 17.2281100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111838, 'Koszęcin', 'Koszecin', 'Comuna de Koszecin,Comuna de Koszęcin,Gmina Koshencin,Gmina Koszecin,Gmina Koszęcin,Koshencin,Kosiecin,Kosięcin,Koszecin,Koszęcin,Кошенцин,Ґміна Кошенцин', 50.6341100, 18.8413000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111839, 'Kościerzyna', 'Koscierzyna', 'Kos''cezhina,Koscerzna,Koscezina,Koscezyna,Koscežina,Koscežyna,Koscierzyna,Koshcezhina,Koshchezhina,Kościerzyna,Kòscérzna,ke xi qie ri na,Косьцежина,Кошчежина,Кошћежина,科希切日納', 54.1222600, 17.9811900, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111840, 'Kościelisko', 'Koscielisko', 'Koscielsko', 49.2907300, 19.8892900, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111841, 'Kościelec', 'Koscielec', 'Comuna de Koscielec,Comuna de Kościelec,Gmina Kos''celec'',Gmina Koscielec,Gmina Kościelec,Kos''celec,Koscelec,Koscielec,Kościelec,Municipio de Koscielec,Municipio de Kościelec,Косцелец,Косьцелец,Ґміна Косьцелець', 52.1742500, 18.5706700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111842, 'Kościelec', 'Koscielec', '', 50.8971300, 19.2156000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111843, 'Kościan', 'Koscian', 'Gorad Koscjan,Kos''cjan,Kos''tsyan,Koscan,Koscian,Koscianas,Koscjan,Koscjana,Koshcan,Koshchjan,Kosten,Kos’tsyan,Kościan,Kòscan,ke xi qiang,Горад Косцян,Косцян,Косьцян,Кошчян,Кошћан,科希強', 52.0882900, 16.6486600, 'PL', '2016-11-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111844, 'Kosakowo', 'Kosakowo', '', 54.5892700, 18.4848400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111845, 'Koronowo', 'Koronowo', 'Crone,Koronovo,Koronowo,Krone,Kòrónowò,ke luo nuo wo,Короново,科羅諾沃', 53.3137000, 17.9369800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111846, 'Kornowac', 'Kornowac', '', 50.0717900, 18.3284600, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111847, 'Kórnik', 'Kornik', 'Burgshtedt,Kornik,Kurnik,Kurnika,Kurņika,ku er ni ke,Бургштедт,Корњик,Курник,庫爾尼克', 52.2477200, 17.0894900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111848, 'Korfantów', 'Korfantow', 'Friedland,Friedland in Oberschlesien,Korfantov,Korfantova,Korfantow,Korfantuv,Korfantów,ke er fan tu fu,Корфантов,Корфантув,科爾凡圖夫', 50.4889400, 17.5989800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111849, 'Korbielów', 'Korbielow', '', 49.5682000, 19.3500100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111850, 'Konstantynów Łódzki', 'Konstantynow Lodzki', 'Konstantinov Lodski,Konstantinov Lodzki,Konstantinova Ludzka,Konstantinuv-Lodz''kij,Konstantynow,Konstantynow Lodzki,Konstantynuv-Lodzinskij,Konstantynów,Konstantynów Łódzki,Lodzes Konstantynuvas,Lodzės Konstantynuvas,luo zi sheng kang si tan ding nu fu,qwnstntynwb lwdzqy,Константинов Лодзки,Константинов Лодски,Константинув-Лодзький,Константынув-Лодзинский,קונסטנטינוב לודזקי,羅茲省康斯坦丁努夫', 51.7477600, 19.3256400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111851, 'Konotop', 'Konotop', 'Konotop,Kontapp,Kontopp', 51.9315700, 15.9039100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111852, 'Konopiska', 'Konopiska', '', 50.7269500, 19.0078100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111853, 'Konin', 'Konin', 'Gorad Konin,Konin,Konina,Koninas,Koņina,ke ning,konin,kwnyn,qwnyn,Горад Конін,Конин,Конін,קונין,كونين,科寧,코닌', 52.2233800, 18.2512100, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111854, 'Koniecpol', 'Koniecpol', 'Konecpol,Konecpol'',Konecpole,Koniecpol,Koņecpole,ke nie ci bo er,qwnyyzpwl,Конецпол,Конецполь,Коњецпол,קונייצפול,科涅茨波尔', 50.7746800, 19.6889600, 'PL', '2011-06-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111855, 'Koniaków', 'Koniakow', 'Koniakow,Koniaków', 49.5506600, 18.9491000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111856, 'Kończyce Wielkie', 'Konczyce Wielkie', 'Konczyce Wielkie,Kończyce Wielkie,Velke Kuncice,Velké Kunčice', 49.8351000, 18.6447400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111857, 'Kończyce Małe', 'Konczyce Male', 'Konczyce Male,Kończyce Małe', 49.8582400, 18.6296400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111858, 'Konary', 'Konary', '', 51.6569000, 17.0418500, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111859, 'Komprachcice', 'Komprachcice', 'Comprachtschutz,Comprachtschütz,Gumpersdorf,Gumpertsdorf,Komprachcice,Komprachciec,Lomprachciec', 50.6367800, 17.8263500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111860, 'Komorniki', 'Komorniki', '', 52.3387000, 16.8106300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111861, 'Koluszki', 'Koluszki', 'Koljushki,Kolushki,Koluski,Koluszki,Koluški,ke lu shen ji,qwlwsqy,Колушки,Колюшки,Колюшкі,קולושקי,科卢什基', 51.7387200, 19.8199400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111862, 'Kolsko', 'Kolsko', 'Kolsko,Kolzig', 51.9614600, 15.9598700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111863, 'Kolonowskie', 'Kolonowskie', 'Colonnowska,Kol''onovs''ke,Kol''onovske,Koljonovske,Kolonovske,Kolonovskje,Kolonowskie,ke luo nuo fu si kai,Колоновскје,Кольоновске,Кольоновське,Колёновске,科洛諾夫斯凱', 50.6533800, 18.3849300, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111864, 'Kołobrzeg', 'Kolobrzeg', 'Gorad Kalabzhehg,Kolbarg,Kolberg,Kolbrzeg,Kolobreh,Kolobrzeg,Kolobrzyg,Kolobzeg,Kolobzega,Kolobzegas,Kolobzheg,Kolobřeh,Kolobžega,Kolobžegas,Kołobrzeg,Kołobrzyg,Kòlbrzég,ke wo bu re ge,kowobeujekeu,kwwbjk,kwwbzhk,Горад Калабжэг,Колобжег,Կոլոբժեգ,كووبجك,کووبژک,กอวอบแชก,科沃布热格,코워브제크', 54.1756500, 15.5834200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111865, 'Koło', 'Kolo', 'Gorad Kola,Kolas,Kolo,Koło,Warthbrucken,Warthbrücken,ke wo,kou~o,Горад Кола,Коло,コウォ,科沃', 52.2002400, 18.6386500, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111866, 'Koleczkowo', 'Koleczkowo', '', 54.4862900, 18.3437300, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111867, 'Kołczygłowy', 'Kolczyglowy', 'Alt Kolziglow,Kolciglowy,Kolczeglowe,Kolczyglowy,Kołcigłowy,Kołczygłowy,Kòłczëgłowë', 54.2389500, 17.2315400, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111868, 'Kolbudy', 'Kolbudy', 'Kahlbude,Kalbudy,Kolbudy', 54.2698900, 18.4663900, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111869, 'Kołbaskowo', 'Kolbaskowo', 'Colbitzow,Kolbaskowo,Kolbitzow,Kołbaskowo', 53.3364100, 14.4383500, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111870, 'Koczała', 'Koczala', 'Flotenstein,Flötenstein,Koczala,Koczała,Kòczała', 53.9044900, 17.0652900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111871, 'Kochanowice', 'Kochanowice', 'Kochanowice,Kochanowicz,Kochanowicze,Kochanowitz', 50.7054800, 18.7491100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111872, 'Kobylnica', 'Kobylnica', '', 54.4397500, 16.9978200, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111873, 'Kobylnica', 'Kobylnica', '', 52.4459700, 17.0764400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111874, 'Kobylin', 'Kobylin', 'Gorad Kabylin,Kobilin,Kobilina,Kobylin,ke bei lin,Горад Кабылін,Кобилин,Кобилін,Кобылин,科貝林', 51.7164500, 17.2268200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111875, 'Kobylanka', 'Kobylanka', 'Kublank,Kublanka', 53.3449200, 14.8714300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111876, 'Kobyla Góra', 'Kobyla Gora', '', 51.3792300, 17.8381100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111877, 'Kobiór', 'Kobior', '', 50.0608900, 18.9346800, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111878, 'Kobierzyce', 'Kobierzyce', 'Koberwitz,Kobierzyce,Rosslingen,Rösslingen', 50.9705400, 16.9350800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111879, 'Kobiernice', 'Kobiernice', '', 49.8549700, 19.2164600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111880, 'Knurów', 'Knurow', 'Knurov,Knurova,Knurow,Knuruv,Knuruvas,Knuruw,Knurów,Knurůw,ke nu lu fu,kunurufu,Кнуров,Кнурув,クヌルフ,克努魯夫', 50.2197100, 18.6506700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111881, 'Kluki', 'Kluki', '', 51.3418700, 19.2393800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111882, 'Klucze', 'Klucze', '', 50.3356500, 19.5623600, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111883, 'Kluczbork', 'Kluczbork', 'Klauczbork,Kliucborkas,Kliučborkas,Kljuchbork,Klucborka,Kluchbork,Kluczborek,Kluczbork,Kluozborek,Klučborka,Kreuzburg,ke lu qi bao,kludch bxrk,Клучборк,Ключборк,กลุดช์บอร์ก,克盧奇堡', 50.9728100, 18.2181600, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111884, 'Klonowa', 'Klonowa', '', 51.4192800, 18.4181500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111885, 'Kłomnice', 'Klomnice', '', 50.9216500, 19.3567900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111886, 'Kłodzko', 'Klodzko', 'Glatz,Kladsko,Kladzko,Klodsko,Klodz''ko,Klodzkas,Klodzko,Kładzko,Kłodzko,ke wo zi ke,qlwdzqw,Клодзко,Клодзько,Клодско,קלודצקו,克沃茲科', 50.4348800, 16.6614500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111887, 'Kłodawa', 'Klodawa', 'Kladow,Klodawa,Kłodawa', 52.7859500, 15.2145200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111888, 'Kłodawa', 'Klodawa', 'Klodava,Klodawa,Kłodawa,ke wo da wa,Клодава,קלודאווה,克沃達瓦', 52.2544700, 18.9135200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111889, 'Kłobuck', 'Klobuck', 'Klobuc''k,Klobuck,Klobucka,Klobuckas,Klobucko,Kłobuck,ke wo bu ci ke,kuu~obutsuku,qlwbwzq,Клобуцк,Клобуцьк,קלובוצק,クウォブツク,克沃布茨克', 50.9008100, 18.9367400, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111890, 'Klikuszowa', 'Klikuszowa', '', 49.5193000, 19.9849000, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111891, 'Kleszczów', 'Kleszczow', '', 51.2235500, 19.3041800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111892, 'Kleszczewo', 'Kleszczewo', '', 52.3337700, 17.1716300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111893, 'Klenica', 'Klenica', '', 51.9921700, 15.7839200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111894, 'Kleczew', 'Kleczew', 'Kleceva,Klechev,Kleczew,Klečeva,ke lai qie fu,qlzb,Клечев,קלצב,克萊切夫', 52.3705700, 18.1771400, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111895, 'Klecza Dolna', 'Klecza Dolna', '', 49.8829100, 19.5376400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111896, 'Kłecko', 'Klecko', 'Gorad Klecka,Klec''ko,Klecko,Kłecko,ke wei ci ke,Горад Клецка,Клецко,Клецько,克韋茨科', 52.6318100, 17.4307500, 'PL', '2010-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111897, 'Kiszkowo', 'Kiszkowo', 'Comuna de Kiszkowo,Gmina Kishkovo,Gmina Kiszkowo,Kishkovo,Kiszkowo,Кишково,Ґміна Кішково', 52.5887100, 17.2663000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111898, 'Kisielice', 'Kisielice', 'Cziselece,Cziselëce,Freystadt,Kiselice,Kisielice,ji xie li cai,Киселице,Кіселіце,基謝利采', 53.6085500, 19.2635000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111899, 'Kikół', 'Kikol', 'Kikol,Kikul,Kikół,Кикул', 52.9099400, 19.1201600, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111900, 'Kietrz', 'Kietrz', 'Katscher,Ketr,Ketsh,Ketř,Kietrz,Kjetsh,kai qi,Кетш,Кјетш,凱奇', 50.0804200, 18.0043200, 'PL', '2015-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111901, 'Kiernozia', 'Kiernozia', 'Kernozja,Kiernozia,Кернозя', 52.2685800, 19.8709200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111902, 'Kiełczów', 'Kielczow', 'Kielczow,Kiełczów', 51.1399900, 17.1779800, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111903, 'Kęty', 'Kety', 'Kentai,Kenti,Kenty,Kety,Kęty,ken di,Кенти,Кенты,肯蒂', 49.8821400, 19.2233300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111904, 'Kęsowo', 'Kesowo', '', 53.5587200, 17.7158000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111905, 'Kępno', 'Kepno', 'Gorad Kehmpna,Kempen in Posen,Kempnas,Kempno,Kepno,Kępno,ken pu nuo,kenpuno,Горад Кэмпна,Кемпно,ケンプノ,肯普諾', 51.2784000, 17.9890800, 'PL', '2015-02-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111906, 'Kępice', 'Kepice', 'Hamer,Hammermuehle,Hammermühle,Hąmer,Kempice,Kepice,Kępice,ken pi cai,Кемпице,Кемпіце,肯皮采', 54.2411100, 16.8896800, 'PL', '2017-03-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111907, 'Kędzierzyn-Koźle', 'Kedzierzyn-Kozle', 'Heydebreck,Kandrzin,Kandrzin Pogorzelletz,Kandrzin-Kozle,Kandrzin-Koźle,Kedzierzyn,Kedzierzyn-Kozle,Kendzezhin-Koz''le,Kendzezhin-Kozle,Kendzezina-Kozle,Kendzezynas-Kozle,Kendzežynas-Kozlė,Kendzhezhin-Kozhle,Keņdzežina-Kozle,Kędzierzyn,Kędzierzyn-Koźle,ken jie ren ke zi lai,Кенджежин-Кожле,Кендзежин-Козле,Кендзежин-Козьле,Кенђежин Козле,แกนแจชึน-กอชแล,肯傑任科茲萊', 50.3498400, 18.2260600, 'PL', '2015-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111908, 'Kcynia', 'Kcynia', 'Kcina,Kcinja,Kciņa,Kcynia,Kcynja,ke qi ni ya,Кциня,Кциња,Кцыня,克齊尼亞', 52.9919200, 17.4883000, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111909, 'Kaźmierz', 'Kazmierz', '', 52.5130900, 16.5840300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111910, 'Kazimierz Biskupi', 'Kazimierz Biskupi', 'Kazimezh Biskupi,Kazimierz Biskupi,Казимеж Бискупи', 52.3110000, 18.1658100, 'PL', '2010-09-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111911, 'Kawęczyn', 'Kaweczyn', 'Comuna de Kaweczyn,Comuna de Kawęczyn,Gmina Kavenchin,Gmina Kaweczyn,Gmina Kawęczyn,Kavenchin,Кавенчин,Ґміна Кавенчин', 51.9092300, 18.5310200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111912, 'Kąty Wrocławskie', 'Katy Wroclawskie', 'Kanth,Katy,Katy Wroclawskie,Konti Vroclavske,Konti Vroclavskje,Konti-Vroclavs''ki,Konty-Vroclavske,Kąty Wrocławskie,fu luo ci wa fu de kong di,Конти Вроцлавскје,Конти-Вроцлавські,Конты-Вроцлавске,弗羅茨瓦夫的孔蒂', 51.0309800, 16.7676700, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111913, 'Katowice', 'Katowice', 'Catowice,Gorad Katavicy,KTW,Katobitse,Katovica,Katovicai,Katovice,Katovice osh,Katovicum,Katovits,Katovitse,Katovîts,Katowice,Katowicy,Katowihi,Kattowitz,Kha-thok-vi-chu,Khà-thok-vì-chṳ,Stalinogorod,Stalinograd,Stalinogrod,Stalinogród,ka tuo wei ci,ka tuo wei zhi,ka tuo wei zi,katobiche,katovis''sa,katovitsa,katovitses,katovu~itsu~e,katwfytsh,katwwch,katwwyts,ketovis,kha to wit se,kha to wits,kyatobhisa,mstkhdm:mhmd alqyrwany,qtwbyz,tcadrkatovitse,Κάτοβιτσε,Κατοβίτσε,Κατοβιτσε,Горад Катавіцы,Катовица,Катовице,Катовице ош,Катовіце,Կատովիցե,קאטאוויץ,קטוביץ,كاتوفيتسه,مستخدم:محمد القيرواني,کاتووچ,کاتوویتس,ކެޓޮވިސް,कातोवित्सा,क्याटोभिस,ಕತೋವೀಸ್ಸ,คะโตวิตซ,คาโตวีตเซ,კატოვიცე,ካቶቪጸ,カトヴィツェ,卡托維治,卡托维兹,카토비체', 50.2584100, 19.0275400, 'PL', '2015-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111914, 'Kaszów', 'Kaszow', '', 50.0388400, 19.7193400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111915, 'Kartuzy', 'Kartuzy', 'Kartuzai,Kartuze,Kartuzi,Kartuzy,Kartuzë,Kartūzai,ka er tu ji,Картузи,Картузы,卡爾圖濟', 54.3342400, 18.1973500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111916, 'Karsin', 'Karsin', '', 53.9076800, 17.9209300, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111917, 'Karpacz', 'Karpacz', 'Karpaca,Karpach,Karpacz,Karpača,Krummhubel,Krummhübel,ka er pa qi,Карпач,卡爾帕奇', 50.7766900, 15.7559400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111918, 'Karnice', 'Karnice', 'Gryfickie,Karnice,Karnitz', 54.0300100, 15.0549600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111919, 'Karlino', 'Karlino', 'Chorzeleno,Chòrzelëno,Karlin,Karlino,Korlin,Körlin,ka er li nuo,Карлино,Карліно,卡爾利諾', 54.0351500, 15.8773900, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111920, 'Kargowa', 'Kargowa', 'Karge,Kargova,Kargowa,Unruhstadt,ka er ge wa,Каргова,Карґова,卡爾戈瓦', 52.0714000, 15.8613800, 'PL', '2015-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111921, 'Kaniów', 'Kaniow', '', 49.9431600, 19.0509800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111922, 'Kamyk', 'Kamyk', '', 50.9017900, 19.0287500, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111923, 'Kamieńsk', 'Kamiensk', 'Kamen''sk,Kamens''k,Kamenska,Kameņska,Kamiensk,Kamieńsk,Kamjensk,ka mian si ke,Каменськ,Каменьск,Камјењск,קאמיינסק,卡緬斯克', 51.2024200, 19.4966100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111924, 'Kamień Pomorski', 'Kamien Pomorski', 'Cammin,Cammin in Pommern,Kamen Pomorski,Kamen''-Pomorskij,Kamena Pomorska,Kameņa Pomorska,Kamien,Kamin''-Pomors''kij,Kamiéń,Kamjen Pomorski,Kammin,bo mo rui de qu ka mian,kamienpomoleuseuki,Камен Поморски,Камень-Поморский,Камінь-Поморський,Камјењ Поморски,波莫瑞地區卡緬,카미엔포모르스키', 53.9684900, 14.7726200, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111925, 'Kamiennik', 'Kamiennik', 'Kamiennik,Kamnig,Steinhaus', 50.5703200, 17.1497900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111926, 'Kamienna Góra', 'Kamienna Gora', 'Kamena Gura,Kamenna Gora,Kamenna Gura,Kamenna-Gura,Kamienna Gora,Kamienna Góra,Kamjena Gora,Landeshut,ka mian na gu la,Каменна Гора,Каменна Ґура,Каменна-Гура,Камјена Гора,קאמיינה גורה,卡缅纳古拉', 50.7831400, 16.0303700, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111927, 'Kamień Krajeński', 'Kamien Krajenski', 'Kamen''-Kraen''skij,Kamen''-Kraens''kij,Kamena Krajenska,Kameņa Krajeņska,Kamien,Kamien Krajenski,Kamień,Kamień Krajeński,Kamiéń,Kamjen Krajenski,Камень-Краеньский,Камень-Краєнський,Камјењ Крајењски', 53.5335200, 17.5201900, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111928, 'Kamieniec Ząbkowicki', 'Kamieniec Zabkowicki', 'Camenz,Kamenz,Kamieniec', 50.5254100, 16.8792100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111929, 'Kamieniec Wrocławski', 'Kamieniec Wroclawski', '', 51.0718200, 17.1819300, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111930, 'Kamieniec', 'Kamieniec', 'Kamieniec,Kamieniec Poznanskie,Kamieniec Poznańskie', 52.1661400, 16.4616400, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111931, 'Kamienica Polska', 'Kamienica Polska', '', 50.6709000, 19.1226500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111932, 'Kamienica', 'Kamienica', '', 50.4500700, 16.9539600, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111933, 'Kamień', 'Kamien', '', 50.0121500, 19.5853600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111934, 'Kamesznica', 'Kamesznica', '', 49.5646900, 19.0212000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111935, 'Kalwaria Zebrzydowska', 'Kalwaria Zebrzydowska', 'Kal''varija Zebzhidovska,Kal''varija-Zebzhidovs''ka,Kal''varija-Zebzhidovska,Kalarija Zebrzydowska,Kalvarija Zebrzydowska,Kalvarija Zebzhidovska,Kalvarija Zebzydovska,Kalvarija Zebžydovska,Kalvarja Zebzidovska,Kalvarja Zebžidovska,Kalwaria,Kalwaria Zebrzydowska,Kalwarja,Kalwarja Zebrydowska,ka er wa li ya-ze bu ri duo fu si ka,Калвария Зебжидовска,Калварија Зебжидовска,Кальвария Зебжидовска,Кальвария-Зебжидовска,Кальварія-Зебжидовська,קלוואריה זבזידובסקה,კალვარია-ზაბჟიდოვსკა,カルヴァリア・ゼブジトフスカ,卡爾瓦里亞-澤布日多夫斯卡', 49.8675900, 19.6772000, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111936, 'Kalisz Pomorski', 'Kalisz Pomorski', 'Callies,Comuna de Kalisz Pomorski,Gmina Kalish-Pomors''kij,Gmina Kalisz Pomorski,Kalish-Pomorskij,Kalisz Pomorski,Kallies,Калиш-Поморский,Ґміна Каліш-Поморський', 53.2990800, 15.9063100, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111937, 'Kalisz', 'Kalisz', 'Gorad Kalish,Kalis,Kalisa,Kalisas,Kalisch,Kalish,Kalisz,Kališa,Kališas,ka li shen,kallisi,kalysh,karishu,Горад Каліш,Калиш,Каліш,Կալիշ,קאליש,كاليش,کالیش,カリシュ,卡利什,칼리시', 51.7610900, 18.0910200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111938, 'Kaliska', 'Kaliska', 'Kaliska,Калиска', 53.9053500, 18.2188500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111939, 'Kalety', 'Kalety', 'Kaleti,Kalety,ka lai di,Калети,Калеты,卡萊蒂', 50.5627000, 18.8926000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111940, 'Kalej', 'Kalej', '', 50.8366200, 18.9842900, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111941, 'Kaczyce', 'Kaczyce', 'Kaczyce,Kaczyce Gorne,Kaczyce Górne', 49.8275200, 18.5916100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111942, 'Kaczory', 'Kaczory', '', 53.1034800, 16.8816900, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111943, 'Wielki Kack', 'Wielki Kack', 'Kack,Kack Wielki,Wielki Kack', 54.4675400, 18.4881000, 'PL', '2012-12-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111944, 'Jutrosin', 'Jutrosin', 'Jutrosin,Jutrosina,you te luo xin,Јутросин,Ютросин,尤特羅辛', 51.6500900, 17.1695700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111945, 'Juszczyna', 'Juszczyna', '', 49.6298400, 19.2203200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111946, 'Juszczyn', 'Juszczyn', '', 49.6929000, 19.6912800, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111947, 'Jugów', 'Jugow', '', 50.6275800, 16.5181200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111948, 'Jordanów Śląski', 'Jordanow Slaski', 'Jordanow,Jordanow Slaski,Jordansmuhl,Jordansmühl,Jordanów,Jordanów Śląski', 50.8642100, 16.8687300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111949, 'Jordanów', 'Jordanow', 'Jordanov,Jordanova,Jordanuv,yue er da nu fu,Јорданов,Йорданов,Йорданув,約爾達努夫', 49.6493500, 19.8298100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111950, 'Jeżów Sudecki', 'Jezow Sudecki', 'Grunau,Jezow,Jezow Sudecki,Jeżów,Jeżów Sudecki', 50.9350700, 15.7430600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111951, 'Jeżów', 'Jezow', '', 51.8137600, 19.9687700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111952, 'Jeziora Wielkie', 'Jeziora Wielkie', '', 52.5304300, 18.2680300, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111953, 'Jeżewo', 'Jezewo', 'Comuna de Jezewo,Comuna de Jeżewo,Ezhevo,Gmina Ezhevo,Gmina Jezewo,Gmina Jeżewo,Гміна Єжево,Ежево', 53.5106100, 18.4943700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111954, 'Jerzmanowice', 'Jerzmanowice', '', 50.2126700, 19.7467200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111955, 'Jenin', 'Jenin', 'Gennin,Jenin', 52.6964700, 15.0979600, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111956, 'Jemielno', 'Jemielno', 'Comuna de Jemielno,Emel''no,Gmina Emel''no,Gmina Jemielno,Емельно,Ґміна Ємельно', 51.5243400, 16.5432600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111957, 'Jemielnica', 'Jemielnica', '', 50.5457300, 18.3780700, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111958, 'Jeleśnia', 'Jelesnia', '', 49.6424600, 19.3270100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111959, 'Jelenia Góra', 'Jelenia Gora', 'Hirschberg,Hirschberg im Riesengebirge,Hirschberg in Schlesien,Jelena Gura,Jelenia Gora,Jelenia Góra,Jelenja Gura,Jeleņa Gura,yelleniagula,Йеленя Гура,옐레니아구라', 50.8997300, 15.7289900, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111960, 'Jelcz', 'Jelcz', 'Jelcz,Jelczc,Jelez,Jeltsch,Zaklady Samochodowe Jelcz SA,Zakłady Samochodowe Jelcz SA,i~eruchi she,イェルチ社', 51.0210200, 17.3209500, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111961, 'Jejkowice', 'Jejkowice', '', 50.1081400, 18.4676700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111962, 'Jedlina-Zdrój', 'Jedlina-Zdroj', 'Bad Charlottenbrunn,Bad Charlottenbrunn in Schlesien,Charlottenbrunn,Charlottenbrunn-Zdroj,Charlottenbrunn-Zdrój,Edlina-Zdruj,Jedlina Zdroj,Jedlina Zdrój,Jedlina-Zdroj,Jedlina-Zdrój,Jedlinazdroja,ye de li na-zi de lu yi,Єдліна-Здруй,Једлина-Здрој,Едлина-Здруй,耶德利納-茲德魯伊', 50.7200500, 16.3464500, 'PL', '2016-07-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111963, 'Jaworzynka', 'Jaworzynka', 'Jaworzynka', 49.5401900, 18.8699600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111964, 'Jaworzyna Śląska', 'Jaworzyna Slaska', 'Javozhina Shl''onska,Javozhina Slonska,Javozhina-Shl''ons''ka,Javozhina-Sljonska,Javozina Slonska,Javožina Slonska,Jaworzyna Slaska,Jaworzyna Śląska,Koenigszelt,Königszelt,xi long si ke de qu ya wo ri na,Јавожиња Слонска,Явожина Шльонска,Явожина-Слёнска,Явожина-Шльонська,希隆斯克地區亞沃日納', 50.9134000, 16.4324100, 'PL', '2016-07-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111965, 'Jaworzno', 'Jaworzno', 'Gorad Javozhna,Javozhno,Javoznas,Javozno,Javožnas,Javožno,Jaworzno,Jaworzyna,ya wo ri nuo,yabojuno,yafwrjnw,yavu~ojuno,yawwzhnw,Горад Явожна,Явожно,يافورجنو,یاووژنو,ヤヴォジュノ,亚沃日诺,야보주노', 50.2052800, 19.2749800, 'PL', '2017-01-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111966, 'Jaworze', 'Jaworze', '', 49.7935100, 18.9479000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111967, 'Jawornik', 'Jawornik', '', 49.8558000, 19.8931500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111968, 'Jawor', 'Jawor', 'Jauer,Javor,Javora,Javoras,Jawor,ya wo er,Јавор,Явор,יאבור,亚沃尔', 51.0513200, 16.1934700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111969, 'Jastrzębie Zdrój', 'Jastrzebie Zdroj', 'Jastrzebie Zdroj,Jastrzebie-Zdroj,Jastrzębie Zdrój,Jastrzębie-Zdrój,Jastsembe Zdroja,Jastšembe Zdroja', 49.9554200, 18.5747900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111970, 'Jastrzębia Góra', 'Jastrzebia Gora', '', 54.8313500, 18.3130100, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111971, 'Jastrząb', 'Jastrzab', '', 50.6701900, 19.1817000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111972, 'Jastrowie', 'Jastrowie', 'Jastrove,Jastrovje,Jastrovė,Jastrow,Jastrowie,Jastrowié,ya si te luo wei,Јастровје,Ястрове,جسترووئے,亞斯特羅維', 53.4204800, 16.8175600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111973, 'Jastarnia', 'Jastarnia', 'Gemeen Heisternest,Heisternest,Jastaania,Jastarna,Jastarnia,Jastarnio,Jastarniô,Jastarnja,Jastarņa,ya si ta er ni ya,Јастарња,Ястарня,جسترنیہ,亞斯塔爾尼亞', 54.6960600, 18.6787300, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111974, 'Jasienica', 'Jasienica', '', 49.8228100, 19.8419100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111975, 'Jasienica', 'Jasienica', 'Jasienica,جسینیکا، سیلسیان صوبہ', 49.8131200, 18.9215500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111976, 'Jasień', 'Jasien', 'Gassen,Jasien,Jasień', 51.7514200, 15.0141900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111977, 'Jaroszowice', 'Jaroszowice', '', 49.8626700, 19.5196200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111978, 'Jarocin', 'Jarocin', 'Gorad Jarocin,Jarochin,Jarocin,Jarocina,Jarocinas,jrwkn,ya luo qin,Јароћин,Горад Яроцін,Яроцин,Ярочин,جروکن,亚罗钦', 51.9726600, 17.5025600, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111979, 'Jaraczewo', 'Jaraczewo', 'Jaraczew,Jaraczewo', 51.9685400, 17.2970700, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111980, 'Januszkowice', 'Januszkowice', '', 50.3918900, 18.1368000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111981, 'Janowiec Wielkopolski', 'Janowiec Wielkopolski', 'Janovec''-Vel''kopol''s''kij,Janovec-Vel''kopol''skij,Janoveca Velkopolska,Janovjec Vjelkopolski,Janowiec,da bo lan de qu ya nuo wei ci,jnwwyk wylkwpwlsky,Јановјец Вјелкополски,Яновец-Велькопольский,Яновець-Велькопольський,جنوویک ویلکوپولسکی,大波蘭地區亞諾維茨', 52.7558300, 17.4898100, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111982, 'Janowice Wielkie', 'Janowice Wielkie', 'Janowice Wielkie,جنووکے ویلکئی', 50.8756900, 15.9232200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111983, 'Janowice', 'Janowice', '', 49.8849600, 19.0937600, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111984, 'Janków Przygodzki', 'Jankow Przygodzki', '', 51.5980800, 17.7882400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111985, 'Jankowice Rybnickie', 'Jankowice Rybnickie', '', 50.0447900, 18.5470700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111986, 'Jankowice', 'Jankowice', '', 50.0009000, 18.9890100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111987, 'Janikowo', 'Janikowo', 'Janikovo,Janikowo,Яниково', 52.7532800, 18.1132800, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111988, 'Jabłonowo Pomorskie', 'Jablonowo Pomorskie', 'Jablonovo Pomorske,Jablonovo Pomorskje,Jablonovo-Pomors''ke,Jablonovo-Pomorske,Jablonowo,Jablonowo Pomorskie,Jabłonowo,Jabłonowo Pomorskie,Jabłónowò,bo mo rui de qu ya bu wo nuo wo,Јаблоново Поморскје,Яблоново-Поморске,Яблоново-Поморське,جبوؤںووو پومورسکئی,波莫瑞地區亞布沃諾沃', 53.3913700, 19.1550900, 'PL', '2010-10-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111989, 'Jabłonna', 'Jablonna', '', 52.2059800, 16.2074100, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111990, 'Jabłonka', 'Jablonka', 'Jablonka,Jabłonka', 49.4796800, 19.6937000, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111991, 'Izdebnik', 'Izdebnik', '', 49.8721800, 19.7680100, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111992, 'Izbicko', 'Izbicko', 'Izbicko,Stubendorf', 50.5716300, 18.1558500, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111993, 'Izbica Kujawska', 'Izbica Kujawska', 'Izbica,Izbica Kujavska,Izbica Kujawska,Izbica-Kujavska,Izbicja-Kujavs''ka,Kujavijos Izbica,Ізбиця-Куявська,Избица Кујавска,Избица-Куявска,איזביצה קויאווסקה', 52.4207300, 18.7627000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111994, 'Istebna', 'Istebna', 'Istebna,Istebno,Istempna,Ιστέμπνα', 49.5631900, 18.9056700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111995, 'Inwałd', 'Inwald', '', 49.8635500, 19.3927600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111996, 'Ińsko', 'Insko', 'In''sko,Ins''ko,Insko,Iņsko,Nierbarg,Norenberg,Nörenberg,yin si ke,Інсько,Иньско,Ињско,因斯科', 53.4361300, 15.5502000, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111997, 'Inowrocław', 'Inowroclaw', 'Gorad Inauroclau,Hohensalza,Inovroclav,Inovroclava,Inovroclavas,Inovrotslav,Inowraclaw,Inowracław,Inowroclaw,Inowrocław,Irownoclaw,inovurotsuwafu,xi nxw rxtswaf,yi nuo fu luo ci wa fu,Іновроцлав,Горад Інаўроцлаў,Иновроцлав,อีนอวรอตสวัฟ,イノヴロツワフ,伊诺弗罗茨瓦夫', 52.7988600, 18.2638700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111998, 'Imielin', 'Imielin', 'Imelin,Imelina,Imielin,Imjelin,imyerin,yi mei lin,Імелін,Имелин,Имјелин,イミェリン,伊梅林', 50.1453400, 19.1859900, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(111999, 'Iłowa', 'Ilowa', 'Halbau,Ilova,Ilowa,Iłowa,Jilwa,Jiłwa,Stadt Halbau,xi wx wa,yi wo wa,Ілова,Илова,อีวอวา,伊沃瓦', 51.5006000, 15.1998000, 'PL', '2017-04-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112000, 'Iława', 'Ilawa', 'Deutsch Eylau,Ilava,Ilawa,Iława,Ylava,iwavu~a,yi wa wa,Ілава,Илава,イワヴァ,伊瓦瓦', 53.5960100, 19.5684900, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112001, 'Huta Stara B', 'Huta Stara B', '', 50.7379200, 19.1329500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112002, 'Herby', 'Herby', '', 50.7531800, 18.8875600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112003, 'Henryków', 'Henrykow', 'Heinrichau,Henrykow,Henryków', 50.6532700, 17.0102700, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112004, 'Hel', 'Hel', 'Gel'',Hel,Hela,Helas,Hél,Khel,Khel'',he er,heru,Гель,Хел,Хель,ヘル,赫爾', 54.6081400, 18.8013000, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112005, 'Hażlach', 'Hazlach', 'Hazlach,Hażlach', 49.8071400, 18.6517800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112006, 'Harbutowice', 'Harbutowice', 'Harbutowice', 49.8123500, 19.7804500, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112007, 'Gubin', 'Gubin', 'Gorad Gubin,Guben,Gubin,Gubina,Gubinas,gu bin,Горад Губін,Губин,Ґубін,古賓', 51.9495600, 14.7283700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112008, 'Grzmiąca', 'Grzmiaca', 'Gramenz,Grzmiaca,Grzmiąca', 53.8373400, 16.4351200, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112009, 'Grzegorzew', 'Grzegorzew', '', 52.2017700, 18.7340900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112010, 'Grzechynia', 'Grzechynia', '', 49.7136000, 19.6456100, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112011, 'Gryfów Śląski', 'Gryfow Slaski', 'Greiffenberg,Greiffenberg in Schlesien,Greiffeńberg,Grifov Shl''onski,Grifov Slonski,Grifova Slonska,Grifuv-Shl''ons''kij,Gryfow Slaski,Gryfuv-Sljonskij,Gryfów Śląski,xi long si ke de qu ge lei fu fu,Грифов Слонски,Грифов Шльонски,Грыфув-Слёнский,Ґрифув-Шльонський,希隆斯克地區格雷富夫', 51.0308100, 15.4201700, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112012, 'Gryfino', 'Gryfino', 'Gorad Gryfina,Greifenhagen,Grifino,Gripenhagen,Gripiewo,Gripiewò,Gryfinas,Gryfino,ge lei fei nuo,Горад Грыфіна,Грифино,Грифіно,Грыфино,格雷菲諾', 53.2524300, 14.4883100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112013, 'Gryfice', 'Gryfice', 'Gorad Gryficy,Greifenberg,Greifenberg in Pommern,Grifice,Gripiewo Gora,Gripiewô Góra,Gryfice,Gryficė,ge lei fei cai,Горад Грыфіцы,Грифице,Грифіце,Грыфице,Գրիֆիցե,格雷菲采', 53.9165000, 15.2002700, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112014, 'Gruta', 'Gruta', 'Gruta,Грута', 53.4531500, 18.9570000, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112015, 'Grudziądz', 'Grudziadz', 'Gorad Grudzjondz,Graudenz,Gredzadz,Grudz''ondz,Grudzendz,Grudzh''ondz,Grudziadz,Grudziondzas,Grudziądz,Grudzjondz,Grudzjondza,Grudzundz,Grudzëndz,Grudźůndz,Grëdządz,ge lu qiong zi,geulujiongcheu,ghrwjwnts,grwjwnts,gurujontsu,kru cxn ts,Горад Грудзёндз,Груджьондз,Грудзендз,Грудзьондз,Грудзёндз,Груђондз,غروجونتس,گروجونتس,กรูจอนตส์,グルジョンツ,格魯瓊茲,그루지옹츠', 53.4841100, 18.7536600, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112016, 'Gronowo Górne', 'Gronowo Gorne', 'Gronowo,Grunau,Grunau Hohe,Grünau Höhe,Hohe,Höhe', 54.1386300, 19.4598800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112017, 'Gronowo Elbląskie', 'Gronowo Elblaskie', 'Gronowo,Gronowo Elblaskie,Gronowo Elbląskie,Grunau', 54.0858800, 19.3059800, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112018, 'Gromadka', 'Gromadka', 'Greulich,Gromadka', 51.3606300, 15.7645200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112019, 'Grojec', 'Grojec', 'Grojec', 50.0897500, 19.5570400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112020, 'Grojec', 'Grojec', '', 49.9814700, 19.2379200, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112021, 'Grodzisk Wielkopolski', 'Grodzisk Wielkopolski', 'Didziosios Lenkijos Grodziskas,Didžiosios Lenkijos Grodziskas,Gratz,Grodzhisk Velkopolski,Grodzis''k-Velikopol''s''kij,Grodzisk,Grodzisk Wielkopolski,Grodzisk-Vel''kopol''skij,Grodziska Velkopolska,Grätz,da bo lan de qu ge luo ji si ke,Гроджиск Велкополски,Гродзиск-Велькопольский,Гродзиськ-Великопольський,Грођиск Вјелкополски,大波蘭地區格羅濟斯克', 52.2276200, 16.3653400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112022, 'Grodziec', 'Grodziec', 'Grodzec,Grodziec,Гродзец', 52.0385500, 18.0597200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112023, 'Grodków', 'Grodkow', 'Grodkov,Grodkova,Grodkow,Grodkuv,Grodków,Grotkow,Grottkau,ge luo de ku fu,Гродков,Гродкув,Ґродкув,格羅德庫夫', 50.6983600, 17.3844900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112024, 'Grębocice', 'Grebocice', 'Grebocice,Grębocice', 51.5990900, 16.1674100, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112025, 'Granowo', 'Granowo', '', 52.2224400, 16.5285900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112026, 'Grabowo Kościerskie', 'Grabowo Koscierskie', 'Grabowo,Grabowo Koscierskie', 54.1681600, 18.1469200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112027, 'Grabów nad Prosną', 'Grabow nad Prosna', 'Comuna de Grabow nad Prosna,Comuna de Grabów nad Prosną,Gmina Grabow nad Prosna,Gmina Grabuv-nad-Prosnoju,Gmina Grabów nad Prosną,Grabow nad Prosna,Grabuv-nad-Prosnon,Grabów nad Prosną,Грабув-над-Проснон,Ґміна Ґрабув-над-Просною', 51.5059600, 18.1192900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112028, 'Grabów', 'Grabow', 'Grabow,Grabuv,Grabów,Грабув', 52.1271700, 19.0025700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112029, 'Grabica', 'Grabica', 'Comuna de Grabica,Gmina Grabica,Gmina Grabicja,Grabica,Грабица,Ґміна Ґрабиця', 51.4798900, 19.5313700, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112030, 'Gozdowo', 'Gozdowo', 'Gozdovo,Gozdowo,Гоздово', 52.7245500, 19.6850100, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112031, 'Gozdnica', 'Gozdnica', 'Freiwaldau,Gozdnica,Gozdnicja,Gozdņica,ge zi de ni cha,Гоздница,Гоздниця,Гоздњица,戈茲德尼察', 51.4363000, 15.0985600, 'PL', '2017-06-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112032, 'Goszczanów', 'Goszczanow', '', 51.7916300, 18.5057000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112033, 'Gostynin', 'Gostynin', 'Gostinin,Gostinina,Gostiņina,Gostyn,Gostynin,ge si di ning,gwstynyn,Гостинин,Гостинін,Гостињин,Гостынин,גוסטינין,戈斯蒂寧', 52.4293800, 19.4619400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112034, 'Gostyń', 'Gostyn', 'Gostin,Gostin'',Gostina,Gostingen,Gostiņa,Gostyn,Gostyn'',Gostynis,Gostyń,ge si teng,Гостин,Гостинь,Гостињ,Гостын,Гостынь,戈斯滕', 51.8824700, 17.0122500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112035, 'Gostyń', 'Gostyn', '', 50.1052800, 18.8824100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112036, 'Gostycyn', 'Gostycyn', 'Gostycyn,Gostyczyn', 53.4901400, 17.8097800, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112037, 'Gościno', 'Goscino', 'Gos''cino,Gosceno,Goscino,Goshchino,Goshcino,Gościno,Gross,Gross Jestin,Gòscëno,ge xi qi nuo,Госьцино,Гошчино,Гошћино,戈希齊諾', 54.0512300, 15.6525600, 'PL', '2011-01-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112038, 'Gościcino', 'Goscicino', 'Goscicino,Gościcino,Госцицино', 54.6045900, 18.1549100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112039, 'Gorzyczki', 'Gorzyczki', 'Gorzyczki', 49.9491200, 18.4033000, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112040, 'Gorzyce Wielkie', 'Gorzyce Wielkie', '', 51.6372500, 17.7295300, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112041, 'Gorzyce', 'Gorzyce', 'Gorzyce', 49.9594500, 18.3988400, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112042, 'Górzyca', 'Gorzyca', 'Goritz,Göritz', 52.4944700, 14.6550300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112043, 'Gorzów Wielkopolski', 'Gorzow Wielkopolski', 'Gorad Gozhau Vel''kapol''ski,Gorzow Wielkopolski,Gorzuw Wjelgopolski,Gorzów Wielkopolski,Gorzůw Wjelgopolski,Gozhov Velkopolski,Gozhov Vjelkopolski,Gozhuv-Vel''kopol''s''kij,Gozhuv-Vel''kopol''ski,Gozhuv-Vel''kopol''skij,Gozova Velkopolska,Gozuv-Velkopolski,Gozuvas,Gožova Velkopolska,Gožuv-Velkopolski,Gožuvas,Ladzbarg,Landsberg,Landsberg an der Warthe,Landsbergum,Lãdzbarg,Thai Po-lan Thi-khi Ko-yi-fu,Thai Pô-làn Thi-khî Kô-yî-fû,da bo lan de qu ge ru fu,ghwrjwf wylkwbwlsky,gojupeubielkopolseuki,gwrzhwf wylkwpwlsky,gwrzhww wyylwpwlsky,gwzwb wyylqwpwlsqy,kxr sufwei yl khx pxl ski,Гожов Велкополски,Гожов Вјелкополски,Гожув-Велькопольски,Гожув-Велькопольский,Горад Гожаў Велькапольскі,Ґожув-Велькопольський,Գորժուվ-Վելկապոլսկացի,גוזוב ויילקופולסקי,غورجوف ويلكوبولسكي,گورژوف ویلکوپولسکی,گورژوو ویئلوپولسکی,กอร์ซูฟเวียลคอปอลสกี,ゴジュフ・ヴィエルコポルスキ,大波蘭地區戈茹夫,고주프비엘코폴스키', 52.7367900, 15.2287800, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112044, 'Gorzów Śląski', 'Gorzow Slaski', 'Gorzow,Gorzow Slaski,Gorzów,Gorzów Śląski,Gozhov Shl''onski,Gozhov Slaski,Gozhuv-Shl''ons''kij,Gozhuv-Sljonskij,Gozova Slonska,Gožova Slonska,Landsberg,xi long si ke de qu ge ru fu,Гожов Сласки,Гожов Шльонски,Гожув-Слёнский,Гожув-Шльонський,希隆斯克地區戈茹夫', 51.0287100, 18.4230400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112045, 'Górzno', 'Gorzno', 'Gorzno,Gozhno,Guzhno,Guzno,Gužno,Górzno,gu ri nuo,Гожно,Гужно,Ґужно,古日諾', 53.1977900, 19.6431700, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112046, 'Gorzkowice', 'Gorzkowice', 'Gorzkowice', 51.2153300, 19.5962600, 'PL', '2010-10-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112047, 'Górki Wielkie', 'Gorki Wielkie', 'Gorki Wielkie,Górki Wielkie', 49.7797100, 18.8311700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112048, 'Gorenice', 'Gorenice', '', 50.2080000, 19.6203800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112049, 'Górażdże', 'Gorazdze', 'Goradze,Gorazdze,Górażdże,Waldenstein,Waldstein', 50.5290300, 18.0100300, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112050, 'Góra Świętej Małgorzaty', 'Gora Swietej Malgorzaty', 'Gora Malgorzaty,Gora Swiety Malgorzaty,Góra Małgorzaty,Góra Święty Małgorzaty', 52.0571300, 19.3199700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112051, 'Góra', 'Gora', 'Gora,Guhrau,Gura,Góra,Gůra,gu la,ku ra,Гора,Гура,Ґура,กูรา,古拉', 51.6663800, 16.5349400, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112052, 'Góra', 'Gora', '', 49.9797100, 19.1047100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112053, 'Gomunice', 'Gomunice', '', 51.1689000, 19.4933500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112054, 'Gołuchów', 'Goluchow', 'Comuna de Goluchow,Comuna de Gołuchów,Gmina Goluchow,Gmina Golukhuv,Gmina Gołuchów,Golukhuv,Гміна Голухув,Голухув', 51.8503600, 17.9314000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112055, 'Golub-Dobrzyń', 'Golub-Dobrzyn', 'Goljub-Dobzhin,Goljub-Dobzhin'',Golub,Golub-Dobrzyn,Golub-Dobrzyń,Golub-Dobzhin,Goluba-Dobzina,Goluba-Dobžiņa,ge lu bu-duo bu ren,gwlwb-dwbzyn,Голуб-Добжињ,Голюб-Добжин,Голюб-Добжинь,Ґолюб-Добжинь,גולוב-דובזין,戈盧布-多布任', 53.1108700, 19.0538100, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112056, 'Gołkowice', 'Golkowice', 'Golkowice,Gołkowice', 49.9141800, 18.5141900, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112057, 'Golina', 'Golina', 'Golina,ge li na,gwlynh,Голина,Голіна,גולינה,戈利納', 52.2431500, 18.0926800, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112058, 'Golina', 'Golina', '', 51.9148900, 17.4826800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112059, 'Goleszów', 'Goleszow', 'Goleszow,Goleszów,Holesov,Holešov', 49.7358000, 18.7367500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112060, 'Goleniów', 'Goleniow', 'Golen''ov,Goleniow,Goleniuvas,Goleniów,Golenjuv,Golenov,Golenova,Goleņova,Gollnow,Golonog,Gorad Galeneu,Gòłonóg,SZZ,ge lai niu fu,gorenyufu,Голеньов,Голенюв,Голењов,Горад Галенеў,ゴレニュフ,戈萊紐夫', 53.5639200, 14.8285400, 'PL', '2013-03-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112061, 'Golczewo', 'Golczewo', 'Gjul''cov,Gol''chevo,Golcevo,Golchevo,Goleszewo,Golčevo,Gulzow,Gòlëszewò,Gülzow,ge er qie fu,Голчево,Гольчево,Гюльцов,戈爾切夫', 53.8242600, 14.9784700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112677, 'Shūkat aş Şūfī', 'Shukat as Sufi', 'Shawkat as Sufi,Shawkat aş Şūfī,Shoket es Sufi,Shukat as Sufi,Shūkat aş Şūfī,shwkt alswfy,شوكة الصوفي', 31.2599700, 34.2826000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112678, 'Rafaḩ', 'Rafah', 'Er Rafa,Rafa,Rafaa,Rafah,Rafakh,Rafaḩ,Rafia,Rafiah,Rafīah,Raphia,Rifah,Ràfia,la fa shi,rfh,rpyh,Рафа,Рафах,רפיח,رفح,拉法市', 31.2870000, 34.2595200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112679, 'An Nuşayrāt', 'An Nusayrat', 'An Nusayrat,An Nuşayrāt,Nusayrat,Nuseira,Nuseirat,Nuşayrāt,Nuṣeirā,alnsyrat,النصيرات', 31.4486100, 34.3925000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112680, 'Khuzā‘ah', 'Khuza`ah', 'Kh Ikhza`a,Kh Ikhza‘a,Khirbat Ikhza`a,Khirbat Ikhza`ah,Khirbat Ikhzā‘a,Khirbat Ikhzā‘ah,Khuza`ah,Khuzā‘ah,خزاعة', 31.3067500, 34.3611000, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112681, 'Khān Yūnis', 'Khan Yunis', 'Hanut Yona,Hanūt Yōnā,Jan Yunis,Jan Yunís,Khan Younes,Khan Younis,Khan Yumus,Khan Yunis,Khan Yunus,Khan-Junis,Khān Yūnis,Khān Yūnus,Yunas,Yunus,khan ywns,Хан-Юнис,خان يونس', 31.3401800, 34.3062700, 'PS', '2011-05-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112682, 'Jabālyā', 'Jabalya', 'Dzhabalija,Jabalia,Jabaliya,Jabalya,Jabāliyā,Jabālyā,jbalya,Джабалия,جباليا', 31.5272000, 34.4834700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112683, 'Gaza', 'Gaza', 'Azzah,Dakbayan sa Gaza,GZA,Gaesa,Gasa,Gaz,Gaza,Gaza City,Gaza by,Gaza-urbo,Gazae,Gazze,Ghazah,Ghazza,Ghazzah,Ghazze,Ghazzi,Ghuzze,Gàsa,Gáza,Qəzza,Xeze,`Azza,`Azzā,gaja,gaja sahara,gaja siti,gajha,gaza,gaza sahira,ghzh,ghzt,jia sa,jia sha,jia sha cheng,kaca,Γάζα,Газa,Газæ,Газа,Газзә,Ղազա,עזה,غزة,غزه,غزہ,غەززە,ग़ज़ा,गाजा शहर,गाझा,গাজা সিটি,ਗ਼ਜ਼ਾ ਸ਼ਹਿਰ,காசா,ガザ,加沙,加沙城,加薩,가자', 31.5000000, 34.4666700, 'PS', '2009-07-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112457, 'Adamstown', 'Adamstown', 'Adams Town,Adamstaun,Adamstaunas,Adamstauno,Adamstaŭno,Adamstown,Antamstaoun,adamusutaun,admztawn,admztwn  pytkrn ayslnd,aedeomseutaun,atamstavun,ya dang si dui,Άνταμσταουν,Адамстаун,Адамстаўн,אדמסטאון,آدمزتاون,ادمزتون، پیتکرن ایسلند,ایڈمز ٹاؤن، جزائر پٹکیرن,ॲडम्सटाउन,ஆடம்ஸ்டவுன்,แอดัมส์ทาวน์,ადამსტაუნი,アダムスタウン,亚当斯敦,애덤스타운', -25.0659700, -130.1014700, 'PN', '2010-07-21', 176);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112062, 'Gołańcz', 'Golancz', 'Golan''ch,Golanca,Golanch,Golancz,Golanča,Gołańcz,ge wan qi,Голаньч,Голањч,戈萬奇', 52.9432600, 17.2999500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112063, 'Gogolin', 'Gogolin', 'Gogolin,ge ge lin,kx kx lin,Гоголин,Гоголін,กอกอลิน,戈戈林', 50.4922200, 18.0199400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112064, 'Godziszka', 'Godziszka', '', 49.7128800, 19.0758700, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112065, 'Godów', 'Godow', 'Godow,Godów', 49.9248100, 18.4783000, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112066, 'Goczałkowice Zdrój', 'Goczalkowice Zdroj', 'Goczalkowice,Goczalkowice Zdroj,Goczałkowice,Goczałkowice Zdrój', 49.9445400, 18.9692700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112067, 'Gniezno', 'Gniezno', 'Gnesen,Gnesna,Gnezno,Gnieznas,Gniezno,Gorad Gnezna,Gņezno,Hnezdno,Hnězdno,ge nie ci nuo,geuniejeuno,gnezno,gnyyznw,gunyezuno,gynyzna,k neiy snx,Гнезно,Горад Гнезна,Гњезно,גנייזנו,گینیزنا,กเนียซนอ,გნეზნო,グニェズノ,格涅兹诺,그니에즈노', 52.5348100, 17.5825900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112068, 'Gnieżdżewo', 'Gniezdzewo', '', 54.7474100, 18.3794400, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112069, 'Gniewkowo', 'Gniewkowo', 'Gnevkovo,Gniekowo,Gniewkowo,Gņevkovo,ge nie fu ke wo,Гневково,Гњевково,格涅夫科沃', 52.8946100, 18.4078500, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112070, 'Gniewino', 'Gniewino', 'Gnevino,Gniewino,Gniéwino,Nknievino,Γκνιεβίνο,Гневино,Гневіно', 54.7170900, 18.0166300, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112071, 'Gniew', 'Gniew', 'Gmew,Gméw,Gnev,Gneva,Gņeva,ge nie fu,Гнев,Гњев,格涅夫', 53.8360200, 18.8231000, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112072, 'Gniechowice', 'Gniechowice', 'Altenrode,Gnichwitz,Gniechowice', 50.9880400, 16.8336300, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112073, 'Gniazdów', 'Gniazdow', '', 50.5962100, 19.1113200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112074, 'Głuszyca Górna', 'Gluszyca Gorna', 'Gluszyca Gorna,Głuszyca Górna,Ober Wustegiersdorf,Ober Wüstegiersdorf', 50.6660600, 16.3758500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112075, 'Głuszyca', 'Gluszyca', 'Glushica,Glushicja,Glusica,Gluszyca,Glušica,Głuszyca,Nieder Wustegiersdorf,Nieder Wüstegiersdorf,Wustegiersdorf,Wüstegiersdorf,ge wu xi cha,Глушица,Ґлушиця,格武希察', 50.6874300, 16.3717300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112076, 'Głuchołazy', 'Glucholazy', 'Glucholazy,Gluholazi,Glukholazi,Glukholazy,Gucholazy,Głuchołazy,Gůchołazy,Hlucholazy,Ziegenhals,ge wu huo wa ji,Глухолази,Глухолазы,Ґлухолази,格武霍瓦濟', 50.3150500, 17.3835500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112077, 'Głubczyce', 'Glubczyce', 'Ghipczyce,Glubchice,Glubcice,Glubczyce,Glubčice,Głubczyce,Hlubcice,Hlubčice,Leobschuetz,Leobschutz,Leobschütz,ge wu bu qi cai,Глубчице,Ґлубчице,格武布奇采', 50.2008600, 17.8285800, 'PL', '2015-10-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112078, 'Głowno', 'Glowno', 'Glovno,Glowd,Glowno,Głowno,ge wo fu nuo,glwbnw,Гловно,גלובנו,格沃夫諾', 51.9646300, 19.7156500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112079, 'Główczyce', 'Glowczyce', 'Comuna Glowczyce,Comuna Główczyce,Comuna de Glowczyce,Comuna de Główczyce,Glowczyce,Glowitz,Gluvchice,Gmina Glowczece,Gmina Glowczyce,Gmina Gluvchice,Gmina Główczyce,Gmina Główczëce,Główczyce,Глувчице,Ґміна Ґлувчице', 54.6193500, 17.3723000, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112080, 'Głogówek', 'Glogowek', 'Glogovek,Glogowek,Gloguvek,Gloguveka,Głogówek,Oberglogau,ge wo gu wei ke,Глоговек,Глогувек,格沃古韋克', 50.3535500, 17.8640500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112081, 'Głogów', 'Glogow', 'Glogau,Glogov,Glogova,Glogovia,Glogow,Gloguv,Gloguvas,Gloguw,Głogów,Głogůw,Hlohov,Hlohow,Hłohow,ge wo gu fu,geuwogupeu,glwgwb,guu~ogufu,k wx kuf,Глогов,Глогув,Ґлоґув,גלוגוב,กวอกูฟ,グウォグフ,格沃古夫,그워구프', 51.6636100, 16.0845000, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112082, 'Głogoczów', 'Glogoczow', '', 49.8945200, 19.8741000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112083, 'Gliwice', 'Gliwice', 'Gleiwitz,Glivice,Glivices,Glivicės,Glivitse,Gliwice,Gliwice-Sosnowiec,Glywicy,Gorad Glivicy,QLC,ge li wei cai,geullibiche,ghlyfytsh,glivisa,glybyzh,glywytsh,gurivu~itsu~e,Гливице,Глівіце,Горад Глівіцы,Гљивице,Գլիվիցե,גליביצה,غليفيتسه,گلیویتسه,گلیویتسہ,ग्लिविस,グリヴィツェ,格利维采,글리비체', 50.2976100, 18.6765800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112084, 'Gizałki', 'Gizalki', '', 52.0426700, 17.7693600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112085, 'Gilowice', 'Gilowice', '', 49.9950500, 19.0961300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112086, 'Gilowice', 'Gilowice', '', 49.7127700, 19.3104500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112087, 'Gierałtowice', 'Gieraltowice', '', 50.2248600, 18.7338400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112088, 'Gierałtowice', 'Gieraltowice', '', 49.9442600, 19.3907000, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112089, 'Cielmice', 'Cielmice', 'Cielmice,Gielmice', 50.0882600, 19.0189600, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112090, 'Giebułtów', 'Giebultow', '', 50.1455600, 19.8785600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112091, 'Gidle', 'Gidle', '', 50.9619900, 19.4718100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112092, 'Gdynia', 'Gdynia', 'Civitas Gdinensis,Gdina,Gdingen,Gdinio,Gdiniô,Gdinja,Gdinya,Gdiņa,Gdyna,Gdyne,Gdynia,Gdynja,Gdynė,Gdyně,Gdyńa,Gdyňa,Gorad Gdynja,Gotenhafen,Gothenhafen,Kak-ten-ni-a,Kak-tên-nì-â,Nkntinia,QYD,gdinia,gdnya,gdynyh,ge ding ni ya,geudinia,ghdynya,gudinya,Γκντίνια,Гдиня,Гдиња,Гдыня,Горад Гдыня,Գդինյա,גדיניה,غدينيا,گدنیا,გდინია,グディニャ,格丁尼亚,그디니아', 54.5188900, 18.5318800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112093, 'Gdańsk', 'Gdansk', 'Danceke,Dancigo,Dantsic,Danzica,Danzig,Dànzica,GDN,Gdan''sk,Gdanjsk,Gdans''k,Gdansk,Gdanska,Gdanskas,Gdańsk,Gdaņska,Gdaňsk,Gdunsk,Gduńsk,Gedanum,Gorad Gdan''sk,Gothiscandza,Gudan''sku,Gydanysg,Nkntansk,Qdansk,gadanska,gdansk,gdnsq,ge dan si ke,geudanseukeu,ghdansk,gudanisuku,katansk,kday sk,Γκντανσκ,Гданск,Гданськ,Гданьск,Гдањск,Горад Гданьск,Гъданьскъ,Գդանսկ,גדנסק,דאנציג,غدانسك,گدانسک,गदान्स्क,கதான்ஸ்க்,กดัญสก์,გდანსკი,グダニスク,格但斯克,그단스크', 54.3520500, 18.6463700, 'PL', '2016-08-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112094, 'Gaworzyce', 'Gaworzyce', 'Gaworzyce', 51.6277300, 15.8819800, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112095, 'Gaszowice', 'Gaszowice', '', 50.1085800, 18.4304200, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112096, 'Gąsawa', 'Gasawa', 'Gasawa,Gąsawa', 52.7675700, 17.7557900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112097, 'Gardeja', 'Gardeja', 'Gardeja,Garnsee,Гардея', 53.6112500, 18.9468700, 'PL', '2010-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112098, 'Gardawice', 'Gardawice', '', 50.1166700, 18.8000000, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112099, 'Garcz', 'Garcz', '', 54.3476000, 18.1016900, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112100, 'Gałków Mały', 'Galkow Maly', '', 51.7255400, 19.7135900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112101, 'Galewice', 'Galewice', '', 51.3447100, 18.2575600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112102, 'Gąbin', 'Gabin', 'Gabin,Gombin,Gombina,Gąbin,gong bin,gwmbyn,Гомбин,Гомбін,גומבין,貢賓', 52.3984900, 19.7350900, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112103, 'Frydrychowice', 'Frydrychowice', '', 49.9048100, 19.4193600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112104, 'Frydek', 'Frydek', '', 49.9962600, 19.0727800, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112105, 'Frombork', 'Frombork', 'Frauenburg,Frauenburgum,Frombork,Fromborka,fu long bao,Фромборк,弗龙堡', 54.3576600, 19.6802900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112106, 'Fordon', 'Fordon', '', 53.1482100, 18.1703600, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112107, 'Filipowice', 'Filipowice', '', 50.1557300, 19.5657900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112108, 'Fabianki', 'Fabianki', 'Fabianki,Fabjanki', 52.7192900, 19.1094300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112109, 'Elbląg', 'Elblag', 'Ehl''blong,El''bleng,El''blong,Elbing,Elbinga,Elbingas,Elbl''ong,Elblag,Elblong,Elblonga,Elbląg,Elwing,El’blëng,Gorad Ehl''bljong,Ilfingburg,ZBG,ai er bu long ge,alblng,alblngh,elbeullongkeu,eruburonku,xe lb lxng k,Горад Эльблёнг,Елблаг,Елбльонг,Ельблонг,Эльблонг,אלבלונג,البلنغ,البلنگ,เอลบลองก์,エルブロンク,埃爾布隆格,엘블롱크', 54.1522000, 19.4088400, 'PL', '2015-09-05', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112110, 'Dziećmorowice', 'Dziecmorowice', '', 50.7694700, 16.3521200, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112111, 'Dziwnów', 'Dziwnow', 'Dzivnova,Dzivnuv,Dzywnowo,Dzywnowò,Ost Dievenow,ji fu nu fu,Ђивнов,Дзивнув,Дзівнув,濟夫努夫', 54.0281900, 14.7669100, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112112, 'Dzierżoniów', 'Dzierzoniow', 'Dzerzhonjuv,Dzerzoniuvas,Dzerzonova,Dzeržoniuvas,Dzeržoņova,Dzherzhon''ov,Dzierzoniow,Dzierżoniów,Reichenbach,Reichenbach im Eulengebirge,Reichenbach in Schlesien,Rychbach,dzrzwnywb,jie er ruo niu fu,Ђержоњов,Джержоньов,Дзержонюв,דזרזוניוב,傑爾若紐夫', 50.7282000, 16.6514100, 'PL', '2016-09-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112113, 'Dzierzgoń', 'Dzierzgon', 'Christburg,Dzerzgon,Dzezgona,Dzezhgon'',Dzežgoņa,Dzierzgon,Dzierzgoń,Dzërzgóń,jie ri gong,Ђежгоњ,Дзежгонь,Дзежґонь,傑日貢', 53.9219600, 19.3470500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112114, 'Dziergowice', 'Dziergowice', 'Dziergowice,Dziergowitz,Oderwalde', 50.2424800, 18.2860600, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112115, 'Dziemiany', 'Dziemiany', 'Dzemione,Dzemiónë,Dziemiany', 54.0063600, 17.7675500, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112116, 'Dzięgielów', 'Dziegielow', 'Dziegielow,Dzięgielów', 49.7225900, 18.7049100, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112117, 'Działoszyn', 'Dzialoszyn', 'Dzialoszyn,Działoszyn,Dzjaloshin,Dzjalosina,Dzjalošina,gu wo shen,Ђалошин,Дзялошин,דזיאלושין,賈沃申', 51.1169900, 18.8652400, 'PL', '2011-06-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112118, 'Dziadowa Kłoda', 'Dziadowa Kloda', 'Dziadowa Kloda,Dziadowa Kłoda,Kunzendorf', 51.2354300, 17.7091900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112119, 'Dygowo', 'Dygowo', 'Degow', 54.1303100, 15.7199300, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112120, 'Duszniki-Zdrój', 'Duszniki-Zdroj', 'Bad Reinerz,Dushniki-Zdroj,Dushniki-Zdruj,Dusnikizdroja,Duszniki,Duszniki Zdroj,Duszniki Zdrój,Duszniki-Zdruj,Duszńiki-Zdrůj,Dušņikizdroja,Reinerz,du shen ni ji-zi de lu yi,Душники-Здруй,Душњики-Здрој,杜什尼基-茲德魯伊', 50.4032700, 16.3909100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112121, 'Duszniki', 'Duszniki', 'Comuna de Duszniki,Dushniki,Gmina Dushniki,Gmina Duszniki,Душники,Ґміна Душники', 52.4469100, 16.4060200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112122, 'Drzycim', 'Drzycim', '', 53.5052000, 18.3094000, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112123, 'Drużbice', 'Druzbice', '', 51.4636900, 19.3940400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112124, 'Drogomyśl', 'Drogomysl', 'Drogomysl,Drogomyśl', 49.8696400, 18.7572700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112125, 'Drobin', 'Drobin', 'Drobin,Drobina,de luo bin,drwbyn,Дробин,Дробін,דרובין,得羅賓', 52.7377500, 19.9892800, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112126, 'Drezdenko', 'Drezdenko', 'Derzen,Drebenko,Drezdenkas,Drezdenko,Driesen,Drizenko,Dërżéń,de lei ci deng ke,Дрезденко,Դրիզենկո,德雷兹登科', 52.8383100, 15.8307900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112127, 'Drawsko Pomorskie', 'Drawsko Pomorskie', 'Dramburg,Dravs''ko-Pomors''ke,Dravsko Pomorske,Dravsko Pomorskje,Dravsko-Pomorske,Drawsko,Drawsko Pomorskie,Drowa,Drôwa,Gorad Drauska Pamorske,bo mo rui de qu de la fu si ke,Горад Драўска Паморске,Дравско Поморске,Дравско Поморскје,Дравско-Поморске,Дравсько-Поморське,波莫瑞地區德拉夫斯科', 53.5305600, 15.8096700, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112128, 'Drawsko', 'Drawsko', 'Dratzig,Drawsko,Drawsko Kreuz,Vratzig', 52.8542100, 16.0312500, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112129, 'Drawno', 'Drawno', 'Dravno,Drawno,Neuwedell,Nowi Wedel,de la fu nuo,Дравно,德拉夫諾', 53.2198600, 15.7594600, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112130, 'Doruchów', 'Doruchow', '', 51.4171900, 18.0769700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112131, 'Dopiewo', 'Dopiewo', '', 52.3572600, 16.6756200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112132, 'Dominowo', 'Dominowo', '', 52.2915800, 17.3575400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112133, 'Domaszowice', 'Domaszowice', 'Domaszowice,Noldau', 51.0429000, 17.8887500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112134, 'Domaniewice', 'Domaniewice', '', 52.0062300, 19.8029400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112135, 'Dolsk', 'Dolsk', 'Dol''s''k,Dol''sk,Dolsk,Dolska,Dolskas,Gorad Dol''sk,duo er si ke,Горад Дольск,Долск,Дольск,Дольськ,多爾斯克', 51.9818000, 17.0627300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112136, 'Dolice', 'Dolice', 'Dolice,Dolitz,Dölitz', 53.1908100, 15.2026700, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112137, 'Dobrzyń nad Wisłą', 'Dobrzyn nad Wisla', 'Dobrzyn,Dobrzyn nad Wisla,Dobrzyń,Dobrzyń nad Wisłą,Dobzhin nad Vislom,Dobzhin''-nad-Visloju,Dobzhin''-nad-Vislon,Dobzina pie Vislas,Dobžiņa pie Vislas,wei si wa he pan duo bu ren,Добжин над Вислом,Добжинь-над-Вислон,Добжинь-над-Віслою,דובזין על נהר ויסלה,維斯瓦河畔多布任', 52.6381400, 19.3187500, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112138, 'Dobrzyca', 'Dobrzyca', 'Dobzhica,Добжица', 51.8666300, 17.6033600, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112139, 'Dobrzeń Wielki', 'Dobrzen Wielki', 'Dobern,Dobrze,Dobrzen Wielki,Dobrzeń Wielki,Döbern,Gross Dobern,Gross Döbern,Wielki Dobrzen,Wielki Dobrzeń', 50.7684400, 17.8465200, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112140, 'Dobrzany', 'Dobrzany', 'Dobzani,Dobzhani,Dobzhany,Dobžani,Jacobshagen,Jakobshagen,Jakubowo,Jakùbòwò,duo bu zha nei,Добжани,Добжаны,多布扎內', 53.3591400, 15.4288600, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112141, 'Dobroszyce', 'Dobroszyce', 'Dobroszyce,Douroszyce,Juliusburg', 51.2677600, 17.3420500, 'PL', '2015-09-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112142, 'Dobroń', 'Dobron', '', 51.6388500, 19.2453900, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112143, 'Dobrodzień', 'Dobrodzien', 'Dobrodzen'',Dobrodzhen,Dobrodzien,Dobrodzień,Gogolina,Guttentag,duo bu luo jin,Доброджен,Добродзень,Доброђењ,多布羅津', 50.7287400, 18.4450100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112144, 'Dobre', 'Dobre', '', 52.6839800, 18.5776200, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112145, 'Dobra', 'Dobra', 'Daber,Dobra,Dobra Nowogardzka,Dobro,Dobrô,Gorad Dobra,duo bu la,Горад Добра,Добра,多布拉', 53.5862500, 15.3097700, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112146, 'Dobra', 'Dobra', 'Daber,Dobra,Szczecinska,Szczecińska', 53.4883500, 14.3861700, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112147, 'Dobra', 'Dobra', 'Dobra,Gorad Dobra,duo bu la,dwbrh,Горад Добра,Добра,דוברה,多布拉', 51.9166400, 18.6155600, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112148, 'Dobieszowice', 'Dobieszowice', '', 50.3969700, 19.0130400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112149, 'Dobiegniew', 'Dobiegniew', 'Dobegnev,Dobegneva,Dobegņeva,Dobiegniew,Dobiegniewo,Dobiegniewò,Dobiehiewo,Dobjegnev,Woldenberg,Woldenberg Neumark,duo bie ge nie fu,Добегнев,Добеґнев,Добјегњев,多别格涅夫', 52.9694700, 15.7536200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112150, 'Dmosin', 'Dmosin', '', 51.9243700, 19.7593400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112151, 'Dłutów', 'Dlutow', '', 51.5593600, 19.3919800, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112152, 'Długołęka', 'Dlugoleka', '', 51.1790200, 17.1913700, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112153, 'Długomiłowice', 'Dlugomilowice', 'Dlugomilowice,Długomiłowice,Krzanowitz,Langenlieben,Langlieben', 50.2829800, 18.1487300, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112154, 'Deszczno', 'Deszczno', 'Dechsel,Deszczno', 52.6698800, 15.3197500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112155, 'Debrzno', 'Debrzno', 'Debrzno,Debzhno,Debzno,Debžno,Fredlad,Frédląd,Preussisch Friedland,dai bu ri nuo,Дебжно,代布日諾', 53.5381700, 17.2364300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112156, 'Dębowiec', 'Debowiec', 'Debowiec,Dębowiec', 49.8140600, 18.7206200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112157, 'Dębowa Łąka', 'Debowa Laka', '', 53.2554100, 19.0959500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112158, 'Dębno', 'Debno', 'Dembno,Gorad Dehmbna,Neudamm,Nowe Dabe,Nowé Dãbé,deng bu nuo,Горад Дэмбна,Дембно,登布諾', 52.7390100, 14.6980000, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112159, 'Dębnica Kaszubska', 'Debnica Kaszubska', 'Dabnica Kaszebsko,Debnica Kaszubska,Dãbnica Kaszëbskô,Dębnica Kaszubska,Rathsdamnitz', 54.3783100, 17.1611600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112160, 'Daszyna', 'Daszyna', '', 52.1550300, 19.1815300, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112161, 'Daszewice', 'Daszewice', '', 52.3000200, 16.9572300, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112162, 'Darłowo', 'Darlowo', 'Darlovo,Darlowo,Darłowo,Derlowo,Dyrlow,Dyrłów,Dërłowò,Gorad Darlova,Ruegenwoold,Rugenwalde,Rügenwalde,Rügenwoold,da er wo wo,Горад Дарлова,Дарлово,達爾沃沃', 54.4209500, 16.4107000, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112163, 'Damnica', 'Damnica', '', 54.5002500, 17.2715400, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112164, 'Damasławek', 'Damaslawek', '', 52.8397900, 17.5006200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112165, 'Dalików', 'Dalikow', '', 51.8847600, 19.1190400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112166, 'Dalachów', 'Dalachow', 'Dalachow,Dalachów', 51.0773200, 18.5784000, 'PL', '2011-06-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112167, 'Dąbrowice', 'Dabrowice', 'Dabrowice,Dabrowice Lipiny,Dombrovice,Dąbrowice,Dąbrowice Lipiny,Домбровице', 52.3114200, 19.0843700, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112168, 'Dąbrowa Zielona', 'Dabrowa Zielona', '', 50.8439400, 19.5565200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112169, 'Dąbrowa Górnicza', 'Dabrowa Gornicza', 'Dabrowa Gornicza,Dombrova Gurnica,Dombrova Gurnicha,Dombrova Gurniča,Dombrova Gurņiča,Dombrova-Gurnicha,Dombrowa,Dumbrowa,Dąbrowa Górnicza,Důmbrowa,dong bu luo wa gu er ni qia,dongbeulobaguleunicha,dwmbrwbh,dwmbrwwh gwrnycha,Домброва Гурнича,Домброва-Гурнича,דומברובה,دومبرووه گورنیچا,ドンブロヴァ・グルニチャ,栋布罗瓦古尔尼恰,동브로바구르니차', 50.3181800, 19.2374000, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112170, 'Dąbrowa Chełmińska', 'Dabrowa Chelminska', 'Dabrowa Chelminska,Dabrowka Chelminska,Dąbrowa Chełmińska,Dąbrowka Chełmińska', 53.1751800, 18.3053700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112171, 'Dąbrowa', 'Dabrowa', '', 52.7466800, 17.9434200, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112172, 'Dąbrowa', 'Dabrowa', 'Dabrowa,Dambrau,Deutsch Damno,Dąbrowa', 50.6835200, 17.7495700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112173, 'Dąbie', 'Dabie', 'Dabie,Dombe,Dąbie,Gmina Dabie,Gmina Dombe,Gmina Dąbie,Домбе,Ґміна Домбе', 52.0866800, 18.8225000, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112174, 'Dąbie', 'Dabie', '', 52.0105600, 15.1522100, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112175, 'Czyżowice', 'Czyzowice', '', 49.9849000, 18.4043300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112176, 'Czułów', 'Czulow', '', 50.0595600, 19.7010600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112177, 'Człuchów', 'Czluchow', 'Chlukhov,Chlukhuv,Cluhova,Czluchow,Czluchowo,Człuchòwò,Człuchów,Schlochau,qi wu hu fu,Čluhova,Члухов,Члухув,奇武胡夫', 53.6672200, 17.3588300, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112178, 'Człopa', 'Czlopa', 'Chlopa,Clopa,Czlopa,Człopa,Schloppe,qi wo pa,Člopa,Члопа,奇沃帕', 53.0885600, 16.1209800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112179, 'Częstochowa', 'Czestochowa', 'CZW,Censtakava,Censtochova,Censtohova,Censtokhova,Chenstochov,Chenstokhov,Chenstokhova,Czenstochau,Czestochowa,Czynstochowy,Częstochowa,Gorad Chanstakhova,Khim-su-thok-khok-nga,Khìm-sṳ̂-thok-khok-ngá,Tschenstochau,chen s to kho wa,chengseutohoba,chensutohovu~a,chstwhwwa,qin si tuo huo wa,tshystwkhwfa,znstwhwbh,Çenstohova,Čenstakava,Čenstochová,Čenstohova,Горад Чанстахова,Ченстохова,Ӵенстохова,Չեստոխովա,צנסטוחובה,تشيستوخوفا,چستوهووا,เชนสโตโควา,チェンストホヴァ,琴斯托霍瓦,쳉스토호바', 50.7964600, 19.1240900, 'PL', '2017-01-29', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112180, 'Czerwonak', 'Czerwonak', 'Czerwonak', 52.4645900, 16.9816900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112181, 'Czerwionka-Leszczyny', 'Czerwionka-Leszczyny', 'Cervionka-Lescynos,Cervjonka-Lescini,Cherv''onka-Leshchini,Chervjonka-Leshchini,Chervjonka-Leshhini,Chervjonka-Leshhiny,Czerwionka,Czyrwjunka-Leszczyny,Czyrwjůnka-Leszczyny,Leszczyny,Červionka-Leščynos,Červjonka-Leščini,Червйонка-Лещини,Червьонка-Лешчини,Червёнка-Лещины,Червјонка-Лешчини', 50.1500700, 18.6776200, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112182, 'Czerwieńsk', 'Czerwiensk', 'Cervenska,Cherven''sk,Chervens''k,Chervjensk,Czerwinsk,Czerwińsk,Rothenburg,Rothenburg an der Oder,Rozborg,qie er wei yan si ke,Červeņska,Червенськ,Червеньск,Червјењск,切爾維延斯克', 52.0128900, 15.4231700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112183, 'Czersk', 'Czersk', 'Cerska,Chers''k,Chersk,Czersk,Czersk Pomorski,Czersko,Czérskò,qie er si ke,Čerska,Черск,Черськ,切爾斯克', 53.7958900, 17.9764700, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112184, 'Czernikowo', 'Czernikowo', 'Chernikovo,Czernikowo,Черниково', 52.9468800, 18.9380300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112185, 'Czerniewice', 'Czerniewice', '', 52.5115700, 19.0869400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112186, 'Czerniejewo', 'Czerniejewo', 'Cernejevo,Cherneevo,Chernejevo,Czerniejewo,qie er nie ye wo,Čerņejevo,Чернеево,Чернеєво,Черњејево,切爾涅耶沃', 52.4264000, 17.4892500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112187, 'Czernichów', 'Czernichow', 'Czernichow,Czernichów', 49.9892000, 19.6811500, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112188, 'Czernichów', 'Czernichow', '', 49.7544300, 19.2094700, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112189, 'Czernica', 'Czernica', 'Czernica,Grossbruck,Grossbrück,Tschirne', 51.0460900, 17.2451000, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112190, 'Czernica', 'Czernica', '', 50.0839100, 18.4006800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112191, 'Czermin', 'Czermin', 'Chermin,Gmina Chermin,Gmina Czermin,Чермин,Ґміна Чермін', 51.9500800, 17.7495700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112192, 'Czempiń', 'Czempin', 'Cempina,Chempin,Chempin'',Chempin’,Czempin,Czempiń,qin ping,Čempiņa,Чемпинь,Чемпињ,Чемпінь,琴平', 52.1440400, 16.7640800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112193, 'Czeladź', 'Czeladz', 'Czeladz,Czeladz Piaski,Czeladź', 50.3154200, 19.0782400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112194, 'Czechowice-Dziedzice', 'Czechowice-Dziedzice', 'Cechovices-Dzedzices,Cehovice-Dzedzice,Chekhovice-Dzedzice,Chekhovice-Dzhedzhice,Czchowice,Czechowice,Czechowice-Dziedzice,Czechowice-Dzydzice,Czechowice-Dźydźice,Dziedzice,Dzieozice,Zabracze,qie huo wei cai-jie ji cai,Čechovicės-Dzedzicės,Čehovice-Dzedzice,Чеховице-Ђеђице,Чеховице-Джеджице,Чеховице-Дзедзице,Чеховіце-Дзедзіце,切霍維采-傑濟采', 49.9134200, 19.0047900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112195, 'Czastary', 'Czastary', '', 51.2586900, 18.3195300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112196, 'Czarny Dunajec', 'Czarny Dunajec', 'Charni Dunayets,Cierny Dunajec,Dunayets,Tzarna Dunayetz,Čierny Dunajec', 49.4366300, 19.8516100, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112197, 'Czarny Bór', 'Czarny Bor', 'Czarny Bor,Czarny Bór,Schwarzwaldau', 50.7708300, 16.1305000, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112198, 'Czarnożyły', 'Czarnozyly', '', 51.2853300, 18.5610600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112199, 'Czarnowąsy', 'Czarnowasy', 'Charnovonsi,Czarnowanz,Czarnowasy,Czarnowąsy,Klosterbruck,Klosterbrück,Чарновонси', 50.7285800, 17.8981900, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112200, 'Czarnocin', 'Czarnocin', 'Czarnocin Podduchowny,Czarnocin Poduchowny', 51.5914200, 19.6815800, 'PL', '2010-10-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112201, 'Czarnków', 'Czarnkow', 'Carnkova,Charnkov,Charnkuv,Czarnkow,Czarnków,Czornkowo,Czôrnkòwò,Gorad Charnkau,qia en ku fu,Čarnkova,Горад Чарнкаў,Чарнков,Чарнкув,恰恩庫夫', 52.9021400, 16.5641300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112202, 'Czarne', 'Czarne', 'Carne,Charne,Czarne,Czorne,Czôrné,Hammerstein,qia er nei,Čarne,Чарне,恰尔内', 53.6842000, 16.9383400, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112203, 'Czarna Woda', 'Czarna Woda', 'Charna-Voda,Czarna Woda,Чарна-Вода', 53.8445800, 18.1000600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112204, 'Czarków', 'Czarkow', '', 50.0183300, 18.9067800, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112205, 'Czapury', 'Czapury', '', 52.3171900, 16.9126800, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112206, 'Czaplinek', 'Czaplinek', 'Caplineka,Chaplinek,Czaplinek,Czoplenko,Czôplënkò,Tempelburg,qia pu li nei ke,Čaplineka,Чаплинек,Чаплінек,恰普利內克', 53.5577500, 16.2333300, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112207, 'Czaniec', 'Czaniec', '', 49.8507100, 19.2535400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112208, 'Czajków', 'Czajkow', '', 51.4919700, 18.3272600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112209, 'Cybinka', 'Cybinka', 'Cibinka,Cybinka,Ziebingen,qi bin ka,Цибинка,Цибінка,Цыбинка,齊賓卡', 52.1944600, 14.7956700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112210, 'Cisownica', 'Cisownica', 'Cisownica', 49.7227600, 18.7620700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112211, 'Cisiec', 'Cisiec', '', 49.5921300, 19.1054000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112212, 'Cisek', 'Cisek', 'Cisek,Comuna de Cisek,Czissek,Friedenau,Friedenau Oberschlesien,Gmina Cisek,Цисек,Ґміна Цисек', 50.2823200, 18.1998800, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112213, 'Cieszyn', 'Cieszyn', 'Ceshin,Cesina,Cesynas,Ceszyn,Cešina,Cešynas,Cheshin,Cieszyn,Gorad Ceshyn,Teschen,Tesin,Tesino,Tessinum,Teŝino,Tešín,Těšín,cheshin,chiesin,qie shen,z''syn,zsyn,Ćeszyn,Ћешин,Горад Цешын,Цешин,Чешин,צ''שין,צשין,チェシン,切申,치에신', 49.7513300, 18.6321300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112214, 'Cieszków', 'Cieszkow', 'Cieszkow,Cieszków,Frejno,Freyhan', 51.6310400, 17.3572600, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112215, 'Ciepłowody', 'Cieplowody', 'Cieplowody,Ciepłowody,Lauenbrunn,Tepliwoda', 50.6747700, 16.9087100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112216, 'Cieplice Śląskie Zdrój', 'Cieplice Slaskie Zdroj', 'Bad Warmbrunn,Cieplice Slaskie Zdroj,Cieplice Slaskie-Zdroj,Cieplice Śląskie Zdrój,Cieplice Śląskie-Zdrój,Teplice,Warmbrunn,Теплице', 50.8654500, 15.6836700, 'PL', '2013-11-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112217, 'Cięcina', 'Ciecina', '', 49.6022000, 19.1410200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112218, 'Ciechów', 'Ciechow', 'Ciechow,Ciechów', 51.1321800, 16.5677300, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112219, 'Ciechocinek', 'Ciechocinek', 'Cehocineka,Cekhocinek,Ciechocinek,qie huo qi nei ke,zhwzynq,Ћехоћинек,Цехоцинек,צחוצינק,切霍齊內克', 52.8790800, 18.7950500, 'PL', '2014-06-26', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112220, 'Ciechocin', 'Ciechocin', 'Cekhocin,Ciechocin,Цехоцин', 53.0558100, 18.9263500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112221, 'Ciasna', 'Ciasna', '', 50.7542700, 18.6083500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112222, 'Chyżne', 'Chyzne', 'Chizsne,Chyzne,Chyżne', 49.4267200, 19.6695600, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112223, 'Chybie', 'Chybie', 'Chybie', 49.9024900, 18.8275600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112224, 'Chwaszczyno', 'Chwaszczyno', '', 54.4437900, 18.4187500, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112225, 'Chrzypsko Wielkie', 'Chrzypsko Wielkie', '', 52.6281700, 16.2285200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112226, 'Chrząstowice', 'Chrzastowice', '', 50.6662200, 18.0729400, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112227, 'Chrzanów', 'Chrzanow', 'Chrzanov,Chrzanovia,Chrzanow,Chrzanów,Chsanuvas,Chšanuvas,Hsanova,Hšanova,Keshanov,Khshanov,Khshanuv,Krenau,Kreshanov,Kshonev,Xsanov,Xşanov,fushanufu,he zha nu fu,heusyanupeu,krznw,zanwf,Χρζάνοβ,Хшанов,Хшанув,כשאנוב,קשאנאוו,زانوف,كرزنو,フシャヌフ,赫扎努夫,흐샤누프', 50.1354600, 19.4020300, 'PL', '2012-10-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112228, 'Chruszczobród', 'Chruszczobrod', '', 50.4147000, 19.3271800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112229, 'Chrostkowo', 'Chrostkowo', '', 52.9437800, 19.2532800, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112230, 'Chrościna', 'Chroscina', '', 50.6657800, 17.8175900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112231, 'Chróścice', 'Chroscice', '', 50.7807600, 17.8122700, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112232, 'Choszczno', 'Choszczno', 'Arnswalde,Chosczno,Choszczno,Chòsczno,Gorad Khoshchna,Hoscno,Hoščno,Khoshchno,Khoshhno,huo shen qi nuo,Горад Хошчна,Хошчно,Хощно,霍什奇诺', 53.1690500, 15.4205400, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112233, 'Chorzów', 'Chorzow', 'Cherzow,Cherzów,Chorzow,Chorzuw,Chorzów,Chorzůw,Chozuvas,Chožuvas,Gorad Khozhau,Hozova,Hožova,Khozhov,Khozhuv,Konigshutte,Krolewska Huta,Królewska Huta,Königshütte,Xozuv,hojufu,hojupeu,huo ru fu,khwjwf,khwzhwf,Горад Хожаў,Хожов,Хожув,Խոժուվ,خوجوف,خوژوف,ホジュフ,霍茹夫,호주프', 50.3058200, 18.9742000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112234, 'Choroń', 'Choron', '', 50.6817800, 19.2605800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112235, 'Chmielowice', 'Chmielowice', '', 50.6495700, 17.8666900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112236, 'Chojnów', 'Chojnow', 'Chojnow,Chojnuw,Chojnów,Chojnůw,Hainovia,Haynau,Hojnova,Khojnov,Khojnuv,huo yi nu fu,khwynwf,Хойнув,Хојнов,خوینوف,霍伊努夫', 51.2737300, 15.9366100, 'PL', '2015-09-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112237, 'Chojnice', 'Chojnice', 'Choinices,Choinicės,Chojnice,Chonice,Chònice,Hojnice,Hojņice,Khojnice,Khoynitsy,Konitz,hoinitsu~e,huo yi ni cai,Хойнице,Хойніце,Хојњице,ホイニツェ,霍伊尼采', 53.6955400, 17.5570100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112238, 'Chojna', 'Chojna', 'Czinsbarg,Czińsbarg,Hojna,Khojna,Konigsberg,Konigsberg in Neumark,Königsberg,Königsberg in Neumark,Neumark,huo yi na,Хойна,Хојна,霍伊納', 52.9638900, 14.4279700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112239, 'Chodzież', 'Chodziez', 'Chodziez,Chodzież,Gorad Khodzezh,Hodzeza,Hodzeža,Khodzezh,Khodzhezh,Kolmar,hojeshu,huo jie ri,Горад Ходзеж,Ходжеж,Ходзеж,Хођеж,ホジェシュ,霍傑日', 52.9950500, 16.9198000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112240, 'Chodów', 'Chodow', 'Comuna de Chodow,Comuna de Chodów,Gmina Chodow,Gmina Chodów,Gmina Khoduv,Khoduv,Ходув,Ґміна Ходув', 52.2496100, 19.0121800, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112241, 'Chodecz', 'Chodecz', 'Chodecz,Hodeca,Hodeča,Khodech,huo dai qi,hwdz,Ходеч,חודץ,霍代奇', 52.4051300, 19.0275900, 'PL', '2014-06-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112242, 'Chocznia', 'Chocznia', '', 49.8741700, 19.4543800, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112243, 'Choczewo', 'Choczewo', '', 54.7399300, 17.8917500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112244, 'Chocz', 'Chocz', '', 51.9764200, 17.8699500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112245, 'Chociwel', 'Chociwel', 'Freienwalde in Pommern,Friwold,Friwôłd,Hocivela,Khocivel,Khocivel'',huo qi wei er,Хоцивель,Хоћивел,霍齊韋爾', 53.4669600, 15.3334200, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112246, 'Chocianów', 'Chocianow', 'Chocianow,Chocianów,Hocjanova,Kaczanow,Kaczanów,Khocanov,Khocjanuv,Kotzenau,huo qia nu fu,Хоцянув,Хоћанов,霍恰努夫', 51.4186700, 15.9017200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112247, 'Choceń', 'Chocen', '', 52.4861800, 19.0133900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112248, 'Chmielno', 'Chmielno', 'Comuna de Chmielno,Gmina Chmielno,Gmina Khmel''no,Khmel''no,Хмельно,Ґміна Хмельно', 54.3254300, 18.0986000, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112249, 'Chłapowo', 'Chlapowo', '', 54.8036500, 18.3735200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112250, 'Chełmża', 'Chelmza', 'Chelmza,Chełmża,Cholmzo,Chôłmżô,Helmza,Helmža,Khelmzha,hai wu mu zha,Хелмжа,海烏姆扎', 53.1846300, 18.6046600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112251, 'Chełm Śląski', 'Chelm Slaski', '', 50.1082500, 19.1955200, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112252, 'Chełmno', 'Chelmno', 'Campo di sterminio di Chelmno,Campo di sterminio di Chełmno,Chelmno,Chelmno nad Wisla,Chełmno,Chełmno nad Wisłą,Cholmno,Chôłmno,Ekstermejo Chelmno,Ekstermejo Chełmno,Gorad Khehlmna,Helmno,Khelmno,Kulm,Kulmas,hai wu mu nuo,heumuno,hlmnw,Горад Хэлмна,Хелмно,חלמנו,ヘウムノ,海烏姆諾', 53.3485500, 18.4251000, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112253, 'Chełmek', 'Chelmek', 'Chelmek,Chełmek,Helmeka,Khelmek,hai wu mei ke,Хелмек,海烏梅克', 50.1016300, 19.2480100, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112254, 'Chąśno', 'Chasno', 'Chasno Drugie (do 1999),Chąśno Drugie (do 1999)', 52.1953500, 19.9425900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112255, 'Chałupki', 'Chalupki', 'Chalupki,Chalutki,Chałupki,Ruderswald', 49.9255900, 18.3173000, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112256, 'Cewice', 'Cewice', 'Cewice,Zewitz', 54.4355100, 17.7348500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112257, 'Cerkwica', 'Cerkwica', 'Zirkwitz', 54.0077700, 15.1090300, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112258, 'Cekcyn', 'Cekcyn', 'Cekcyn,Цекцын', 53.5729400, 18.0112300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112259, 'Cedynia', 'Cedynia', 'Cedina,Cedinja,Cediņa,Cedynja,Cedzenio,Cedzëniô,Zehden,cai di ni ya,Цединя,Цедиња,Цедыня,采迪尼亞', 52.8793100, 14.2024900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112260, 'Cedry Wielkie', 'Cedry Wielkie', 'Cedry Wielkie,Gross Zunder,Gross Zünder', 54.2470700, 18.8456700, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112261, 'Bytów', 'Bytow', 'Betowo,Bitiv,Bitov,Bitova,Butow,Bytow,Bytowe,Bytuv,Bytów,Bëtowò,Bütow,bei tu fu,Битов,Битів,Бытув,貝圖夫', 54.1705700, 17.4918700, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112262, 'Bytoń', 'Byton', '', 52.5575700, 18.5952200, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112263, 'Bytom Odrzański', 'Bytom Odrzanski', 'Beuthen,Beuthen an Oder,Beuthen an der Oder,Bialobrzezie,Białobrzezie,Bitom Odzhanski,Bitom-Odzhans''kij,Bitoma Odzanska,Bitoma Odžaņska,Bytom Odrzanski,Bytom Odrzański,Bytom-Odzhan''skij,ao de he pan bi tuo mu,Битом Оджањски,Битом-Оджанський,Бытом-Оджаньский,奧得河畔比托姆', 51.7306200, 15.8236200, 'PL', '2015-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112264, 'Bytom', 'Bytom', 'Beuthen,Bithomia,Bitom,Bitoma,Bytom,Bytomas,Bytun,Bytůń,Bıtom,Gorad Bytam,bi tuo mu,bitom,bitomu,bytwm,Битом,Бытом,Горад Бытaм,ביטום,بیتوم,ビトム,比托姆,비톰', 50.3480200, 18.9328200, 'PL', '2015-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112265, 'Bytnica', 'Bytnica', 'Beutnitz,Bytnica', 52.1506600, 15.1694600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112266, 'Bystrzyca Kłodzka', 'Bystrzyca Klodzka', 'Bistrica Klodska,Bistshica Klodzka,Bistshicja-Klodz''ka,Bistsica Klodzka,Bistšica Klodzka,Bystrzyca,Bystrzyca Klodzka,Bystrzyca Kłodzka,Bystshica-Klodzka,Habelschwerdt,bei si qi cha ke wo zi ka,Бистрица Клодска,Бистшица Клодзка,Бистшиця-Клодзька,Быстшица-Клодзка,貝斯奇察克沃茲卡', 50.3017900, 16.6423100, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112267, 'Bystrzyca', 'Bystrzyca', 'Bystrzyca,Peisterwitz', 50.9604800, 17.3970200, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112268, 'Bystra', 'Bystra', 'Bystra,Bystra Krakowska,Bystra Slaska,Bystra kolo Bialej,Bystra koło Białej,Bystra Śląska,Быстра', 49.7604200, 19.0597300, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112269, 'Bystra', 'Bystra', '', 49.6479600, 19.7799400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112270, 'Bydgoszcz', 'Bydgoszcz', 'BZG,Bedgoszcza,Bidgosc,Bidgosca,Bidgoshch,Bidgoshh,Bidgošč,Bidgošča,Bidqos,Bintnkos,Brombarg,Bromberch,Bromberg,Bydgoscius,Bydgoshh,Bydgostia,Bydgoszcz,Bydgoščius,Bydhost,Bydhošť,Bëdgòszcza,Bıdgoşç,Bıdqoş,Gorad Bydgashch,bi de ge shen,bideugosyuchi,bidgoshchi,bu~idogoshuchu,bydghwshtsh,bydgwshch,bydgwsz,Μπιντγκός,Бидгошч,Бидгощ,Быдгощ,Горад Быдгашч,בידגאש,בידגושץ,بيدغوشتش,بیدگوشچ,ბიდგოშჩი,ブィドゴシュチュ,比得哥什,비드고슈치', 53.1235000, 18.0076200, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112271, 'Byczyna', 'Byczyna', 'Bichina,Bicina,Bičina,Bychina,Byczyna,Pitschen,bayszyna,bei qi na,Бичина,Бычина,بائسزینا,貝奇納', 51.1138700, 18.2141300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112272, 'Burzenin', 'Burzenin', 'bwznyn,בוזנין', 51.4607700, 18.8323300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112273, 'Bulowice', 'Bulowice', '', 49.8765000, 19.2887300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112274, 'Bukowno', 'Bukowno', 'Bukovno,bu ke fu nuo,Буковно,布科夫諾', 50.2647400, 19.4596200, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112275, 'Bukowiec', 'Bukowiec', 'Bukovec,Bukowiec,Буковец', 53.4338300, 18.2404800, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112276, 'Buk', 'Buk', 'Buk,Buka,Gorad Buk,bu ke,Бук,Горад Бук,布克', 52.3553200, 16.5195800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112277, 'Bujaków', 'Bujakow', '', 49.8518200, 19.1943200, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112278, 'Budzyń', 'Budzyn', '', 52.8895400, 16.9881200, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112279, 'Budzów', 'Budzow', 'Budzow,Budzów', 50.5933700, 16.7103800, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112280, 'Budzów', 'Budzow', '', 49.7762200, 19.6727400, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112281, 'Budziszewice', 'Budziszewice', '', 51.6673900, 19.9358100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112282, 'Buczkowice', 'Buczkowice', '', 49.7285800, 19.0690800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112283, 'Buczek', 'Buczek', '', 51.5022800, 19.1641900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112284, 'Brzuze', 'Brzuze', '', 53.0545800, 19.2619500, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112285, 'Brzozie', 'Brzozie', '', 53.3255400, 19.6048500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112286, 'Brzeźnio', 'Brzeznio', 'Brzeznio,Brzezno,Brzeźnio,Brzeźno,برزےزنو', 51.4940000, 18.6223400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112287, 'Brzeźnica', 'Brzeznica', '', 49.9649700, 19.6195200, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112288, 'Brzeziny Śląskie', 'Brzeziny Slaskie', 'Brzeziny,Brzeziny Slaskie,Brzeziny Śląskie', 50.3543900, 18.9812900, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112289, 'Brzeziny', 'Brzeziny', 'Brzeziny,Bzezini,Bzhezhini,Bzhezini,Bzheziny,Bžezini,beusyejini,bu zha xi ni,bzzyny,Бжежини,Бжезини,Бжезины,Бжезіни,בזזיני,برززننے,布札希尼,브셰지니', 51.8002300, 19.7514400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112290, 'Brzezinka', 'Brzezinka', '', 50.0423700, 19.1902000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112291, 'Brzeszcze', 'Brzeszcze', 'Bresha,Brzeszcze,Bzesce,Bzheshche,Bzheshhe,Bžešče,Gorad Bzhehshchy,bu re shen qie,Бжешче,Бжеще,Горад Бжэшчы,برزسزکزے,布熱什切', 49.9820300, 19.1515700, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112292, 'Brześć Kujawski', 'Brzesc Kujawski', 'Brzesc Kujawski,Brześć Kujawski,Bzesca Kujavska,Bzhesc''-Kujavs''kij,Bzhesc''-Kujavskij,Bzheshc Kujavski,Bžesca Kujavska,Kujavijos Brestas,ku ya wei de qu bu re xi qi,Бжесць-Куявский,Бжесць-Куявський,Бжешћ Кујавски,בזשץ קויאבסקי,برزےسچ کجوسکی,庫亞維地區布熱希奇', 52.6053200, 18.9017300, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112293, 'Brzeg Dolny', 'Brzeg Dolny', 'Brzeg Dolny,Bzegdolni,Bzheg Dolni,Bzheg-Dol''nij,Bzheg-Dol''ny,Bžegdolni,Dyhernfurth,xia bu re ge,Бжег Долни,Бжег-Дольний,Бжег-Дольны,برزگ ڈولنے,ブジェク・ドルヌィ,下布熱格', 51.2729900, 16.7081500, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112294, 'Brzeg', 'Brzeg', 'Brieg,Brzeg,Bzega,Bzegas,Bzheg,Bžega,Bžegas,Gorad Bzhehg,brzg,bu re ge,bujeku,Бжег,Бжеґ,Горад Бжэг,برزگ,บแชก,ブジェク,布熱格', 50.8607900, 17.4674000, 'PL', '2015-09-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112295, 'Brusy', 'Brusy', 'Bruse,Brusi,Brusy,Brusë,bu lu se,Бруси,Брусы,布魯瑟', 53.8844600, 17.7178600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112296, 'Brudzew', 'Brudzew', 'Brudzev,Brudzew,Брудзев', 52.0994900, 18.6043200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112297, 'Brudzeń Duży', 'Brudzen Duzy', 'Brudzen,Brudzen Duzy,Brudzen Wielki,Brudzeń,Brudzeń Duży,Brudzeń Wielki', 52.6688400, 19.5039900, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112298, 'Bronów', 'Bronow', 'Bronow,Bronów', 49.8778200, 18.9210300, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112299, 'Brojce', 'Brojce', '', 53.9570500, 15.3597500, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112300, 'Brójce', 'Brojce', 'Bratz,Bratz Stadt,Brojce,Brätz,Brätz Stadt,Brójce', 52.3174500, 15.6741400, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112301, 'Brójce', 'Brojce', '', 51.6643600, 19.6480200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112302, 'Brody', 'Brody', 'Pforten,Pförten', 51.7904600, 14.7733500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112303, 'Brody', 'Brody', '', 49.8674200, 19.6974600, 'PL', '2010-10-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112304, 'Brodnica', 'Brodnica', 'Brodnica,Brodnicja,Brodņica,bu luo de ni cha,Бродница,Бродниця,Бродњица,布罗德尼察', 53.2596700, 19.3965300, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112305, 'Brodnica', 'Brodnica', 'Brodnica,Brodnitz,Comuna de Brodnica,Gmina Brodnica,Gmina Brodnicja,Бродница,Ґміна Бродниця', 52.1412300, 16.8909600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112306, 'Brodła', 'Brodla', '', 50.0433100, 19.5887900, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112307, 'Brenno', 'Brenno', '', 51.9225700, 16.2148800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112308, 'Brenna', 'Brenna', '', 49.7257600, 18.9024900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112309, 'Brdów', 'Brdow', 'Brduv,Brduvas,Брдув', 52.3539000, 18.7298000, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112310, 'Brąszewice', 'Braszewice', '', 51.4990200, 18.4498200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112311, 'Braniewo', 'Braniewo', 'Branevas,Branevo,Braniewo,Braunsberg  Ostpreussen,Braunsberg  Ostpreußen,Braņevo,Brunsbarg,Brunsberga,Gorad Braneva,bu la nie wo,Бранево,Брањево,Горад Бранева,布拉涅沃', 54.3797100, 19.8195900, 'PL', '2016-08-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112312, 'Branice', 'Branice', 'Branice,Branitz', 50.0510800, 17.7939900, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112313, 'Bralin', 'Bralin', '', 51.2858100, 17.9032500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112314, 'Bozkow', 'Bozkow', '', 50.5131500, 16.5752800, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112315, 'Borzytuchom', 'Borzytuchom', '', 54.2002100, 17.3680100, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112316, 'Borzęta', 'Borzeta', '', 49.8622800, 19.9792400, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112317, 'Borucin', 'Borucin', '', 50.0076300, 18.1574800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112318, 'Borowno', 'Borowno', '', 50.9324700, 19.2738000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112319, 'Boronów', 'Boronow', 'Boronow,Boronów', 50.6746000, 18.9067800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112320, 'Borek Wielkopolski', 'Borek Wielkopolski', 'Borek,Borek Wielkopolski', 51.9167400, 17.2413300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112321, 'Boniewo', 'Boniewo', '', 52.4653200, 18.8911600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112322, 'Bolszewo', 'Bolszewo', '', 54.6180100, 18.1758500, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112323, 'Bolków', 'Bolkow', 'Bol''kuv,Bolkenhain,Bolkow,Bolków,Comuna de Bolkow,Comuna de Bolków,Gmina Bol''kuv,Gmina Bolkow,Gmina Bolków,Болькув,Ґміна Болькув', 50.9220300, 16.1011100, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112324, 'Boleszkowice', 'Boleszkowice', 'Furstenfelde,Fürstenfelde', 52.7249300, 14.5690100, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112325, 'Bolesławiec', 'Boleslawiec', 'Boleslavec,Boleslavjec,Boleslawice,Boleslawiec,Bolesławiec,Bunzlau,buntsurau,Болеславец,Болеславјец,ブンツラウ', 51.2641800, 15.5697000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112326, 'Bolesławiec', 'Boleslawiec', '', 51.1986600, 18.1914700, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112327, 'Bolesław', 'Boleslaw', '', 50.2972900, 19.4807300, 'PL', '2010-10-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112328, 'Bolęcin', 'Bolecin', '', 50.1175000, 19.4811600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112329, 'Bolechowice', 'Bolechowice', '', 50.1483100, 19.7927300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112330, 'Bojszowy Nowe', 'Bojszowy Nowe', 'Bojszowy Nowe,Nowe Bojszowy', 50.0528400, 19.0501200, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112331, 'Bojszowy', 'Bojszowy', '', 50.0578000, 19.1014500, 'PL', '2010-09-20', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112332, 'Bojanowo Stare', 'Bojanowo Stare', '', 51.9930200, 16.5836900, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112333, 'Bojanowo', 'Bojanowo', 'Bojanovo,Bojanowo,bo ya nuo wo,Бояново,Бојаново,博亞諾沃', 51.7074900, 16.7482700, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112334, 'Bojano', 'Bojano', 'Bojan,Bojano', 54.4712300, 18.3840800, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112335, 'Bojadła', 'Bojadla', 'Bojadla,Bojadła,Boyadel', 51.9532100, 15.8103600, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112336, 'Boguszów-Gorce', 'Boguszow-Gorce', 'Bogushov-Gorce,Bogushuv-Gorce,Bogusova-Gorce,Boguszow,Boguszow-Gorce,Boguszów,Boguszów-Gorce,Bogušova-Gorce,Gottesberg,bo gu shu fu-ge er cai,bogushufu=gorutsu~e,Богушов-Горце,Богушув-Горце,Боґушув-Ґорце,ボグシュフ＝ゴルツェ,博古舒夫-戈爾采', 50.7551400, 16.2049400, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112337, 'Bogdaniec', 'Bogdaniec', 'Bogdaniec,Duehringshof,Dühringshof', 52.6889700, 15.0712700, 'PL', '2015-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112338, 'Bogatynia', 'Bogatynia', 'Bogatina,Bogatinja,Bogatiņa,Bogatynia,Bogatynja,Reichenau,bo jia di ni ya,Богатиня,Богатиња,Богатыня,博加蒂尼亞', 50.9074700, 14.9563400, 'PL', '2015-09-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112339, 'Bobrowo', 'Bobrowo', 'Bobrovo,Comuna Bobrowo,Comuna de Bobrowo,Gmina Bobrovo,Gmina Bobrowo,Боброво,Ґміна Боброво', 53.2854900, 19.2705300, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112340, 'Bobrowniki', 'Bobrowniki', 'Bobrovniki,Bobrowniki,Бобровники', 52.7808600, 18.9602600, 'PL', '2010-09-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112341, 'Bobrowniki', 'Bobrowniki', 'Bobrowniki,Bobrowniki Slaskie,Bobrowniki Śląskie,Borowniki', 50.3798500, 18.9866100, 'PL', '2010-09-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112342, 'Bobrowice', 'Bobrowice', 'Bobersberg,Bobrowice,Bobrowiec', 51.9485000, 15.0905800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112343, 'Bobowo', 'Bobowo', 'Bobovo,Bobowo,Бобово', 53.8837800, 18.5568100, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112344, 'Bobolice', 'Bobolice', 'Bablitz,Bobolece,Bobolice,Bóbòlëce,bo bo li cai,Боболице,Боболіце,博博利采', 53.9550800, 16.5889300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112345, 'Blizanów', 'Blizanow', '', 51.9037200, 18.0100300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112346, 'Bledzew', 'Bledzew', 'Bledzew,Bledzewo,Blesen,Blesen Stadt', 52.5171100, 15.4138200, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112347, 'Błaszki', 'Blaszki', 'Blashki,Blaszki,Błaszki,Comuna de Blaszki,Comuna de Błaszki,Gmina Blashki,Gmina Blaszki,Gmina Błaszki,Блашки,Ґміна Блашкі', 51.6516300, 18.4347200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112348, 'Blachownia', 'Blachownia', 'Blachownia', 50.7801500, 18.9638900, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112349, 'Bieżuń', 'Biezun', 'Bezhun'',Bezuna,Bežuņa,Biezun,Bieżuń,Bjezhun,bie rong,byyzwn,Бежунь,Бјежуњ,בייזון,別容', 52.9610700, 19.8897600, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112350, 'Bierzwnik', 'Bierzwnik', '', 53.0356700, 15.6650000, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112351, 'Bierutów', 'Bierutow', 'Beirut,Bernstadt,Bernstadt in Schlesien,Berutov,Berutova,Berutuv,Bierutow,Bierutów,Bjerutov,bie lu tu fu,Берутов,Берутув,Бјерутов,別魯圖夫', 51.1244300, 17.5460700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112352, 'Bieruń', 'Bierun', 'Berun,Berun'',Beruna,Beruņa,Beruň,Bierun,Bierun Stary,Bieruń,Bieruń Stary,Bjerun,Bjeruń,bie lun,byeruni,Берун,Берунь,Бјеруњ,ビェルニ,別倫', 50.0900000, 19.0929100, 'PL', '2014-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112353, 'Bierdzany', 'Bierdzany', '', 50.8185200, 18.1580800, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112354, 'Bierawa', 'Bierawa', 'Bierawa,Birawa,Reigerfeld,Reigersfeld', 50.2811100, 18.2417700, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112355, 'Bieńkówka', 'Bienkowka', '', 49.7760000, 19.7717900, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112356, 'Bielsko-Biala', 'Bielsko-Biala', 'Bel''s''ko-Bjala,Bel''sko-Bjala,Belsko-Biala,Belsko-Bjala,Biala,Biala Krakowska,Biała,Biała Krakowska,Bielsko-Biala,Bielsko-Biała,Bilsko-Bela,Bjelsko-Bjala,Bjylsko-Bjolo,Bjylsko-Bjoło,Byala,Bílsko-Bělá,bie er si ke-bi ya wa,bielseukobiawa,byerusuko=byawa,bylskw byawa,Белско-Бяла,Бельско-Бяла,Бельсько-Бяла,Бјелско-Бјала,ביילסקו-ביאלה,بیلسکو بیاوا,ビェルスコ＝ビャワ,别尔斯科-比亚瓦,비엘스코비아와', 49.8224500, 19.0468600, 'PL', '2014-05-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112357, 'Bielsk', 'Bielsk', '', 52.6718000, 19.8050000, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112358, 'Bielice', 'Bielice', 'Beelitz,Beelitz in Pommern,Belice,Bielice,Comuna de Bielice,Gmina Belice,Gmina Bielice,Белице,Ґміна Беліце', 53.2002200, 14.7276000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112359, 'Bielawy', 'Bielawy', '', 52.0753900, 19.6555700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112360, 'Bielawa', 'Bielawa', 'Belava,Beliava,Beljava,Bielawa,Bjelava,Bjelawa,Langenbielau,bie la wa,byylbh,Белява,Бјелава,ביילבה,別拉瓦', 50.6907500, 16.6230000, 'PL', '2015-03-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112361, 'Bielany Wrocławskie', 'Bielany Wroclawskie', 'Bielany Wroclawskie,Bielany Wrocławskie', 51.0361000, 16.9677000, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112362, 'Biały Bór', 'Bialy Bor', 'Baldenburg,Bialy Bor,Biały Bór,Bilij Bir,Biolo,Biôłô,Bjali Bor,Bjali Bora,Bjaly-Bur,bi ya wei bu er,Бялы-Бур,Білий Бір,Бјали Бор,比亞維布爾', 53.8967000, 16.8354300, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112363, 'Białośliwie', 'Bialosliwie', '', 53.1046100, 17.1253300, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112364, 'Białogard', 'Bialogard', 'Belgard,Bialogard,Bialogardas,Bialogrod,Białogard,Białogrod,Bilogard,Biologarda,Biôłogarda,Bjalogard,Bjalogarda,Gorad Bjalogard,bi ya wo jia de,Бялогард,Білоґард,Бјалогард,Горад Бялогард,比亞沃加德', 54.0069600, 15.9875100, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112365, 'Białe Błota', 'Biale Blota', '', 53.0951600, 17.9162100, 'PL', '2010-09-13', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112366, 'Biała', 'Biala', 'Biala,Biala Prudnicka,Biała,Biała Prudnicka,Bila,Bjala,Zulz,Zülz,bi ya wa pu lu de ni ci ka,Бяла,Біла,Бјала,ビャワ・プルドニツカ,比亞瓦普魯德尼茨卡', 50.3858700, 17.6603500, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112367, 'Białka', 'Bialka', '', 49.6930600, 19.6703300, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112368, 'Bestwinka', 'Bestwinka', '', 49.9327200, 19.0669400, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112369, 'Bestwina', 'Bestwina', '', 49.8971200, 19.0577600, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112370, 'Bełsznica', 'Belsznica', '', 49.9781100, 18.3631300, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112371, 'Bełk', 'Belk', '', 50.1304800, 18.7166700, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112372, 'Bełchatów', 'Belchatow', 'Belchatow,Belchatuvas,Belhatova,Belkhatov,Belkhatuv,Bełchatów,be-uhatupeu,bei wu ha tu fu,beuhato~ufu,blhtwb,Белхатов,Белхатув,בלחטוב,ベウハトゥフ,貝烏哈圖夫,베우하투프', 51.3688300, 19.3567100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112373, 'Będzin', 'Bedzin', 'Bedzin,Bendzhin,Bendzin,Bendzina,Bendzinas,Beņdzina,Będzin,ben jin,bengjin,bndyn,Бенджин,Бендзин,Бенђин,בנדין,בענדין,แบนจิน,本津,벵진', 50.3260700, 19.1256500, 'PL', '2010-10-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112374, 'Bedlno', 'Bedlno', 'Bedl''no,Bedlno,Бедльно', 52.2082900, 19.5759200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112375, 'Będków', 'Bedkow', '', 51.5876300, 19.7495600, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112376, 'Bęczarka', 'Beczarka', '', 49.8779300, 19.8672300, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112377, 'Bębło', 'Beblo', '', 50.1805300, 19.7874100, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112378, 'Bażanowice', 'Bazanowice', 'Bazanowice,Bażanowice', 49.7379100, 18.7034500, 'PL', '2010-09-08', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112379, 'Barwice', 'Barwice', 'Barvice,Barwalde,Barwice,Berwald,Borwica,Bärwalde,Bôrwica,ba er wei cai,Барвице,Барвіце,巴爾維采', 53.7449000, 16.3553000, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112380, 'Barwałd Średni', 'Barwald Sredni', '', 49.8663200, 19.5936000, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112381, 'Barwałd Górny', 'Barwald Gorny', '', 49.8621100, 19.6174600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112382, 'Baruchowo', 'Baruchowo', '', 52.4941200, 19.2649600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112383, 'Barlinek', 'Barlinek', 'Barlinek,Barlineka,Berlenko,Berlinchen,Berlinek,Berlënkò,Gorad Barlinak,ba er li nei ke,Барлинек,Барлінек,Горад Барлінак,巴爾利內克', 52.9946400, 15.2186400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112384, 'Bardo', 'Bardo', 'Bardo,Bardo Slaskie,Bardo Śląskie,Bardo-Przylek,Bardo-Przylęk,Byrdo,Wartha,Wartha Frankenberg,ba er duo,Бардо,巴爾多', 50.5058900, 16.7398600, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112385, 'Barcin', 'Barcin', 'Barcin,Barcina,Barçın,ba er qin,Барцин,Барћин,巴爾欽', 52.8660700, 17.9462500, 'PL', '2010-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112386, 'Baranów', 'Baranow', '', 51.2634200, 18.0047000, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112387, 'Banino', 'Banino', '', 54.3921500, 18.4062200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112388, 'Banie', 'Banie', 'Bahn,Bane,Comuna de Banie,Gmina Bane,Gmina Banie,Бане,Гмина Бане,Ґміна Бане', 53.1003100, 14.6622800, 'PL', '2011-07-31', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112389, 'Balin', 'Balin', '', 50.1679900, 19.3834000, 'PL', '2014-07-03', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112390, 'Balice', 'Balice', '', 50.0879900, 19.7946200, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112391, 'Bąków', 'Bakow', 'Bakow,Bąków', 49.8934200, 18.7149500, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112392, 'Bachowice', 'Bachowice', '', 49.9581200, 19.4936900, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112393, 'Baborów', 'Baborow', 'Baborov,Baborova,Baborow,Baboruv,Baboruw,Baborów,Baborůw,Bauerwitz,ba bo lu fu,Баборов,Баборув,巴博魯夫', 50.1576000, 17.9851300, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112394, 'Babimost', 'Babimost', 'Babimost,Babimosta,Bomst,IEG,ba bi mo si te,Бабимост,Бабімост,巴比莫斯特', 52.1648800, 15.8276900, 'PL', '2013-04-02', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112395, 'Babice', 'Babice', '', 50.0688200, 19.4490600, 'PL', '2010-10-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112396, 'Babice', 'Babice', '', 50.0556500, 19.1995500, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112397, 'Babiak', 'Babiak', 'Babjak,Comuna de Babiak,Gmina Babiak,Gmina Babjak,Бабяк,Гміна Бабяк,Ґміна Бабяк', 52.3453000, 18.6666300, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112398, 'Andrychów', 'Andrychow', 'Andrichovia,Andrihova,Andrikhov,Andrikhuv,Andrychow,Andrychuvas,Andrychuw,Andrychów,Andrychůw,Andrykhuv,Андрихов,Андрихув,Андрыхув,אנדריכוב', 49.8549700, 19.3383400, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112399, 'Andrespol', 'Andrespol', '', 51.7278300, 19.6417500, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112400, 'Alwernia', 'Alwernia', 'Al''vernja,Alverna,Alvernja,Alverņa,Alwernia,a er wei ni ya,alwrnya,Алверня,Алверња,Альверня,الورنیا,阿爾韋尼亞', 50.0605600, 19.5395300, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112401, 'Aleksandrów Łódzki', 'Aleksandrow Lodzki', 'Aleksandrov Lodzki,Aleksandrova Ludzka,Aleksandrow,Aleksandrow Lodzki,Aleksandruv-Lodz''kij,Aleksandruv-Lodzinskij,Aleksandrów,Aleksandrów Łódzki,Lodzes Aleksandruvas,Lodzės Aleksandruvas,alksandra lwdzky,luo zi de qu ya li shan de lu fu,Александров Лодзки,Александров Лођски,Александрув-Лодзинский,Александрув-Лодзький,אלכסנדר לודז,אלעקסאנדער,الکساندرا لودزکی,羅茲地區亞歷山德魯夫', 51.8196500, 19.3038400, 'PL', '2010-10-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112402, 'Aleksandrów Kujawski', 'Aleksandrow Kujawski', 'Aleksandrov Kujavski,Aleksandrova Kujavska,Aleksandrow,Aleksandrow Kujawski,Aleksandruv Kujavskij,Aleksandruv-Kujavs''kij,Aleksandruv-Kujavski,Aleksandruv-Kujavskij,Aleksandrów,Aleksandrów Kujawski,alksandra kwjawsky,ku ya wei de qu ya li shan de lu fu,Александров Куявски,Александров Кујавски,Александрув Куявский,Александрув-Куявски,Александрув-Куявский,Александрув-Куявський,אלכסנדרוב קויאבסקי,الکساندرا کوجاوسکی,庫亞維地區亞歷山德魯夫', 52.8765900, 18.6934500, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112403, 'Aleksandrów', 'Aleksandrow', 'Aleksandruv,Comuna de Aleksandrow,Comuna de Aleksandrów,Gmina Aleksandrow,Gmina Aleksandruv,Gmina Aleksandrów,Gmina Aljaksandrau,Александрув,Гміна Аляксандраў,Ґміна Александрув', 51.2712600, 19.9900500, 'PL', '2013-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112404, 'Ursynów', 'Ursynow', 'Ursinuv,Ursynov,Урсинув,Урсынов', 52.1505100, 21.0504100, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112405, 'Praga Północ', 'Praga Polnoc', '', 52.2544300, 21.0347200, 'PL', '2012-11-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112406, 'Praga Południe', 'Praga Poludnie', '', 52.2442400, 21.0854500, 'PL', '2012-11-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112407, 'Krościenko nad Dunajcem', 'Kroscienko nad Dunajcem', '', 49.4408100, 20.4262400, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112408, 'Grzybowo', 'Grzybowo', '', 54.1589200, 15.4855700, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112409, 'Rzgów', 'Rzgow', 'Rzgow,Rzgów,Zgova,Zhgov,Zhguv,zgwb,Žgova,Жгов,Жгув,זגוב', 51.6634500, 19.4918100, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112410, 'Jelcz Laskowice', 'Jelcz Laskowice', '', 51.0213400, 17.3164900, 'PL', '2010-09-12', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112411, 'Brody-Parcele', 'Brody-Parcele', '', 52.4779700, 20.7497400, 'PL', '2010-09-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112412, 'Sztutowo', 'Sztutowo', 'Shtutovo,Stutovas,Sztutowo,Sztutowò,Štutovas,Штутово', 54.3267900, 19.1792100, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112413, 'Żarki-Letnisko', 'Zarki-Letnisko', '', 50.6229500, 19.2750800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112414, 'Ostrówek', 'Ostrowek', '', 52.3893800, 21.3673800, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112415, 'Pogórze', 'Pogorze', '', 49.7996100, 18.8432700, 'PL', '2010-09-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112416, 'Podebłocie', 'Podeblocie', '', 51.6402300, 21.7442000, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112417, 'Sulbiny Górne', 'Sulbiny Gorne', '', 51.8732100, 21.6317400, 'PL', '2010-09-07', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112418, 'Biskupiec', 'Biskupiec', '', 53.5005600, 19.3505600, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112419, 'Ruda-Huta', 'Ruda-Huta', '', 51.2366600, 23.5948600, 'PL', '2010-10-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112420, 'Iłowo -Osada', 'Ilowo -Osada', '', 53.1680800, 20.2929500, 'PL', '2010-09-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112421, 'Koszyce Wielkie', 'Koszyce Wielkie', '', 49.9807600, 20.9455200, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112422, 'Radwanice', 'Radwanice', '', 51.5708300, 15.9480300, 'PL', '2010-09-10', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112423, 'Rutki-Kossaki', 'Rutki-Kossaki', '', 53.0893200, 22.4401100, 'PL', '2010-09-11', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112424, 'Zalesie', 'Zalesie', '', 50.0122600, 22.5326200, 'PL', '2016-06-01', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112425, 'Bartniczka', 'Bartniczka', '', 53.2477600, 19.6043300, 'PL', '2010-09-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112426, 'Lubicz Dolny', 'Lubicz Dolny', '', 53.0315100, 18.7455900, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112427, 'Lubicz Górny', 'Lubicz Gorny', '', 53.0268600, 18.7710000, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112428, 'Tomaszkowice', 'Tomaszkowice', '', 49.9791800, 20.0996600, 'PL', '2010-09-16', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112429, 'Chotcza', 'Chotcza', '', 51.2404300, 21.7766200, 'PL', '2010-09-17', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112430, 'Biała', 'Biala', '', 52.6052400, 19.6495600, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112431, 'Mała Wieś', 'Mala Wies', 'Comuna de Mala Wies,Comuna de Mała Wieś,Gmina Mala Ves'',Gmina Mala Wies,Gmina Mała Wieś,Mala-Ves'',Мала-Весь,Ґміна Мала Весь', 52.4577900, 20.1022300, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112432, 'Baranowo', 'Baranowo', '', 52.4352500, 16.7863100, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112433, 'Wiśniewo', 'Wisniewo', '', 53.0647400, 20.3480500, 'PL', '2010-09-18', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112434, 'Izabelin', 'Izabelin', '', 52.2999200, 20.8172900, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112435, 'Świercze', 'Swiercze', '', 52.6705500, 20.7639000, 'PL', '2010-09-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112436, 'Łętownia', 'Letownia', '', 49.6974500, 19.8710900, 'PL', '2010-09-22', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112437, 'Broniszewice', 'Broniszewice', '', 51.9669600, 17.8164800, 'PL', '2010-09-23', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112438, 'Czarna Dąbrówka', 'Czarna Dabrowka', 'Czorno Dabrowka,Czôrnô Dąbrówka', 54.3563100, 17.5645600, 'PL', '2010-09-24', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112439, 'Skarbimierz Osiedle', 'Skarbimierz Osiedle', '', 50.8458400, 17.4186500, 'PL', '2010-09-25', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112440, 'Wilczyce', 'Wilczyce', '', 51.1294400, 17.1547200, 'PL', '2010-09-27', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112441, 'Krzczonów', 'Krzczonow', '', 51.0072700, 22.7109700, 'PL', '2010-10-09', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112442, 'Bełżec', 'Belzec', '', 50.3845300, 23.4383900, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112443, 'Godziszów Pierwszy', 'Godziszow Pierwszy', '', 50.7575300, 22.4838600, 'PL', '2010-10-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112444, 'Rokiciny-Kolonia', 'Rokiciny-Kolonia', '', 51.6646800, 19.7831200, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112445, 'Nowe Ostrowy', 'Nowe Ostrowy', '', 52.3031800, 19.1921700, 'PL', '2010-10-15', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112446, 'Kocierzew Południowy', 'Kocierzew Poludniowy', 'Comuna de Kocierzew Poludniowy,Comuna de Kocierzew Południowy,Gmina Kocezhev-Poludn''ovi,Gmina Kocierzew Poludniowy,Gmina Kocierzew Południowy,Kocezhev-Poludnjovy,Коцежев-Полуднёвы,Ґміна Коцежев-Полудньови', 52.2172800, 20.0181200, 'PL', '2013-07-14', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112447, 'Zdziechowice Drugie', 'Zdziechowice Drugie', '', 50.7847800, 22.1099900, 'PL', '2010-10-19', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112448, 'Chróścina', 'Chroscina', 'Falkenau', 50.6230600, 17.3686100, 'PL', '2013-10-30', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112449, 'Mirków', 'Mirkow', '', 51.1610500, 17.1702600, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112450, 'Radwanice', 'Radwanice', '', 51.0541300, 17.1093200, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112451, 'Rotmanka', 'Rotmanka', '', 54.2742500, 18.6038000, 'PL', '2010-10-21', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112452, 'Nowe Grocholice', 'Nowe Grocholice', '', 52.1592400, 20.9111000, 'PL', '2010-10-28', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112453, 'Babice', 'Babice', '', 52.2503700, 20.8505100, 'PL', '2013-09-04', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112454, 'Sulęcin', 'Sulecin', '', 52.4599300, 15.1217400, 'PL', '2017-07-06', 177);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112458, 'Aceitunas', 'Aceitunas', '', 18.4432800, -67.0649000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112459, 'Adjuntas', 'Adjuntas', 'Adjuntas,Adjuntas Pueblo', 18.1627400, -66.7221200, 'PR', '2015-07-25', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112460, 'Aguada', 'Aguada', 'Aguada,Agvada,a gua da,aguraada,agwada  pwyrtw rykw,Агвада,Агуада,اگوادا، پوئرتو ریکو,اگوادا، پورٹو ریکو,আগুৱাডা,阿瓜達', 18.3793900, -67.1882400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112461, 'Aguadilla', 'Aguadilla', 'Aguadil''ja,Aguadilla,Agvadila,BQN,Guadilla,Guadiya,a gua di ya,aguraadila,agwadyla  pwyrtw rykw,Агвадиља,Агуадилья,Агуаділья,اگوادیلا، پورٹو ریکو,اگوادیلا، پویرتو ریکو,আগুৱাডিলা,阿瓜迪亚', 18.4274500, -67.1540700, 'PR', '2017-06-29', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112462, 'Aguas Buenas', 'Aguas Buenas', '', 18.2569000, -66.1029400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112463, 'Aguas Claras', 'Aguas Claras', 'Parcelas Aguas Claras', 18.2527300, -65.6535000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112464, 'Aguilita', 'Aguilita', '', 18.0233000, -66.5346200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112465, 'Aibonito', 'Aibonito', 'Jatibonicu', 18.1399600, -66.2660000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112466, 'Añasco', 'Anasco', 'An''jasko,Anasco,Anasko,a ni ya si ke,annasako,Аньяско,Ањаско,আন্নাসকো,阿尼亞斯科', 18.2827300, -67.1396200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112467, 'Animas', 'Animas', '', 18.4455000, -66.6349000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112468, 'Antón Ruiz', 'Anton Ruiz', 'Anton Ruiz', 18.1852400, -65.8085000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112469, 'Arecibo', 'Arecibo', 'ARE,Arecivo,Arezibo,Ariezibo,Arrec2 bo,El Arecibo,La Ribera del A recibo,La Villa del Capitan Correa', 18.4724500, -66.7157300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112470, 'Arroyo', 'Arroyo', '', 17.9658000, -66.0612800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112471, 'Bairoa', 'Bairoa', '', 18.2591200, -66.0404400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112472, 'Bajadero', 'Bajadero', '', 18.4266100, -66.6832300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112473, 'Bajandas', 'Bajandas', '', 18.1577400, -65.7815500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112474, 'Barahona', 'Barahona', '', 18.3513400, -66.4454500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112475, 'Barceloneta', 'Barceloneta', 'Barrgeloneta', 18.4505000, -66.5385100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112476, 'Barranquitas', 'Barranquitas', 'Barankitas,Barrankitas,ba lan ji ta si,barankuyitasa,Баранкитас,Барранкітас,بارانکیتاس، پورٹو ریکو,বারাংকুয়িতাস,巴蘭基塔斯', 18.1866200, -66.3062800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112477, 'Bartolo', 'Bartolo', '', 18.3613400, -65.8385000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112478, 'Bayamón', 'Bayamon', 'Bajamon,Bajamonas,Bayamon,Bayamón,ba a meng,bayamana,bayamon,bayamwn,Баямон,Бајамон,بايامون,বায়ামন,バヤモン,巴阿蒙,바야몬', 18.3985600, -66.1557200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112479, 'Bayamon', 'Bayamon', '', 18.1777400, -66.1132200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112480, 'Benitez', 'Benitez', '', 18.2735700, -65.8790500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112481, 'Boquerón', 'Boqueron', 'Boqueron', 18.0269100, -67.1690700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112482, 'Boqueron', 'Boqueron', '', 18.2074600, -65.8485000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112483, 'Brenas', 'Brenas', '', 18.4671700, -66.3410000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112484, 'Buena Vista', 'Buena Vista', '', 17.9963500, -66.0518300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112485, 'Bufalo', 'Bufalo', '', 18.4182800, -66.5732300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112486, 'Caban', 'Caban', '', 18.4432800, -67.1360100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112487, 'Cabo Rojo', 'Cabo Rojo', 'El Pueblo,Kabo Rokho,Kabo-Rokho,ka wo luo huo,kabo rojo,Кабо Рохо,Кабо-Рохо,কাবো রোজো,卡沃羅霍', 18.0866300, -67.1457300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112488, 'Cacao', 'Cacao', '', 18.4366100, -66.9371200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112489, 'Caguas', 'Caguas', 'Kaguas,Kaguasas,Kagvas,ka gua si,kaguasu,kaguraasa,Кагвас,Кагуас,קגואס,کاگواس، پورٹو ریکو,কাগুৱাস,カグアス,卡瓜斯', 18.2341200, -66.0485000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112490, 'Campanilla', 'Campanilla', '', 18.4213400, -66.2368300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112491, 'Campo Rico', 'Campo Rico', '', 18.3371700, -65.8979400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112492, 'Camuy', 'Camuy', 'Kamuj,ka mu yi,kamuya,Камуй,Камуј,কামুয়,卡穆伊', 18.4838300, -66.8449000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112493, 'Candelaria', 'Candelaria', '', 18.4041100, -66.2087800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112494, 'Candelaria Arenas', 'Candelaria Arenas', '', 18.4171700, -66.2173900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112495, 'Candelero Arriba', 'Candelero Arriba', '', 18.1019100, -65.8368300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112496, 'Canovanas', 'Canovanas', 'Canovanas,Canóvanas', 18.3751000, -65.8993400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112497, 'Capitanejo', 'Capitanejo', '', 18.0145400, -66.5337200, 'PR', '2015-08-06', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112498, 'Carolina', 'Carolina', 'San Fernando de la Carolina', 18.3807800, -65.9573900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112499, 'Carrizales', 'Carrizales', '', 18.4818900, -66.7899000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112500, 'Cataño', 'Catano', 'Catano,Cataño', 18.4413400, -66.1182200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112501, 'Cayey', 'Cayey', 'Cayey de Muesas', 18.1119100, -66.1660000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112502, 'Cayuco', 'Cayuco', '', 18.2910600, -66.7393400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112503, 'Ceiba', 'Ceiba', 'Ceiba,NRR,Seiba,Sejba,sai wa,se''iba,Сеиба,Сейба,سئیبا، پورٹو ریکو,সেইবা,塞瓦', 18.2641200, -65.6485000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112504, 'Ceiba', 'Ceiba', '', 18.4463400, -66.3507300, 'PR', '2006-01-22', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112505, 'Celada', 'Celada', '', 18.2716200, -65.9660000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112506, 'Central Aguirre', 'Central Aguirre', 'Aguirre,Central Aguirre,Central Aguirre Comunidad', 17.9535800, -66.2229400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112507, 'Ciales', 'Ciales', 'Siales,Sijales,siyalesa,xi ya lai si,Сијалес,Сіалес,سیالیس، پورٹو ریکو,সিয়ালেস,錫亞萊斯', 18.3360600, -66.4687800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112508, 'Cidra', 'Cidra', '', 18.1757900, -66.1612800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112509, 'Coamo', 'Coamo', 'Koamo,San Blas de Cuam o,San Blas de Illescas,ke a mo,koyamo,Коамо,کوامو، پورٹو ریکو,কোয়ামো,科阿莫', 18.0799600, -66.3579500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112510, 'Coco', 'Coco', '', 18.0071900, -66.2593300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112511, 'Comerío', 'Comerio', 'Comerio', 18.2180100, -66.2260000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112512, 'Comunas', 'Comunas', '', 18.0871900, -65.8437700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112513, 'Coquí', 'Coqui', 'Coqui', 17.9741300, -66.2271100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112514, 'Corazón', 'Corazon', 'Corazon', 17.9927400, -66.0848900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112515, 'Corcovado', 'Corcovado', '', 18.4585600, -66.7762900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112516, 'Corozal', 'Corozal', '', 18.3410600, -66.3168400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112517, 'Coto Laurel', 'Coto Laurel', '', 18.0496900, -66.5512800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112518, 'Coto Norte', 'Coto Norte', '', 18.4307800, -66.4398900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112519, 'Culebra', 'Culebra', 'CPX,Da Town,Dewey,El Pueblo,Playa Sardina,Puebla', 18.3030100, -65.3009900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112520, 'Daguao', 'Daguao', '', 18.2263500, -65.6832200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112521, 'Dorado', 'Dorado', 'DDP,Dorado,dorado,duo la duo,Дорадо,دورادو، پورٹو ریکو,ডোরাডো,多拉多', 18.4588300, -66.2676700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112522, 'Duque', 'Duque', '', 18.2366900, -65.7417200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112523, 'El Mangó', 'El Mango', 'El Mango', 18.2341200, -65.8796100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112524, 'El Negro', 'El Negro', '', 18.0374700, -65.8512700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112525, 'El Ojo', 'El Ojo', '', 18.0038500, -66.3915600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112526, 'Emajagua', 'Emajagua', '', 18.0005200, -65.8826600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112527, 'Esperanza', 'Esperanza', '', 18.0971900, -65.4707100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112528, 'Espino', 'Espino', '', 18.2763400, -67.1193500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112529, 'Estancias de Florida', 'Estancias de Florida', '', 18.3666200, -66.5696200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112530, 'Fajardo', 'Fajardo', 'FAJ,Fakhardo,Faxardo,Fayjardo,fa ha duo,phajardo,Фахардо,فاجارڈو، پویرٹو ریکو,ফাজার্ডো,法哈多', 18.3257900, -65.6523800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112531, 'Florida', 'Florida', '', 18.3624500, -66.5612800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112532, 'Franquez', 'Franquez', '', 18.3402300, -66.4276700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112533, 'Fuig', 'Fuig', '', 17.9877400, -66.9160100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112534, 'G. L. Garcia', 'G. L. Garcia', '', 18.1274600, -66.1040500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112535, 'Galateo', 'Galateo', '', 18.3624500, -66.2587800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112536, 'Garrochales', 'Garrochales', '', 18.4535600, -66.5662800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112537, 'Guánica', 'Guanica', 'Guanica,Gvanika,gua ni ka,guraanika,Гваника,Гваніка,گوانیکا، پورٹو ریکو,গুৱানিকা,瓜尼卡', 17.9716300, -66.9079500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112538, 'Guayabal', 'Guayabal', '', 18.0813500, -66.5012800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112539, 'Guayama', 'Guayama', 'City of Witches,Guajama,Gvajama,gua ya ma,guraayama,Гваяма,Гвајама,Гуаяма,گوایاما، پورٹو ریکو,গুৱায়ামা,瓜亞馬', 17.9841300, -66.1137800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112540, 'Guayanilla', 'Guayanilla', 'Guadanilh a,Guadanillo,Guadianella', 18.0191300, -66.7918400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112541, 'Guaynabo', 'Guaynabo', '', 18.3574500, -66.1110000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112542, 'Gurabo', 'Gurabo', 'Gurabo,gu la wo,gurabo,Гурабо,گورابو، پورٹو ریکو,গুরাবো,古拉沃', 18.2544000, -65.9729400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112543, 'H. Rivera Colon', 'H. Rivera Colon', '', 18.3477300, -66.2737800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112544, 'Hatillo', 'Hatillo', 'Atil''jo,Atilo,Hatillo del Corazon,a ti yue,hatillo,Атиљо,Атільйо,اتیلو، پورٹو ریکو,হাতিল্লো,阿提約', 18.4863300, -66.8254500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112545, 'Hato Candal', 'Hato Candal', '', 18.3743900, -65.7871100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112546, 'Hormigueros', 'Hormigueros', 'Ormigeros,ao er mi ge luo si,hormiguraerosa,Ормигерос,Ормігерос,اورمیگیروس، پورٹو ریکو,হোর্মিগুৱেরোস,奧爾米格羅斯', 18.1396800, -67.1274000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112547, 'Imbery', 'Imbery', '', 18.4368900, -66.5523900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112548, 'Indios', 'Indios', '', 17.9941300, -66.8193400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112549, 'Ingenio', 'Ingenio', '', 18.4421700, -66.2260000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112550, 'Humacao', 'Humacao', 'HUC,Umakao,humaka''o,wu ma kao,Умакао,اوماکاو، پورٹو ریکو,হুমাকাও,烏馬考', 18.1496800, -65.8273800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112551, 'Isabel Segunda', 'Isabel Segunda', 'El Pueblo,Isabell II,Vieques', 18.1491300, -65.4426600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112552, 'Isabela', 'Isabela', '', 18.5007800, -67.0243500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112553, 'Jagual', 'Jagual', '', 18.1616300, -65.9954400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112554, 'Jauca', 'Jauca', 'Jaucas', 17.9691300, -66.3657200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112555, 'Jayuya', 'Jayuya', 'Jayua', 18.2185700, -66.5915600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112556, 'Jobos', 'Jobos', '', 17.9552400, -66.1654400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112557, 'Juana Díaz', 'Juana Diaz', 'Juana Diaz,Khuana Dijaz,Khuana-Dias,hu an na di ya si,juyana diyaja,Хуана Дијаз,Хуана-Діас,خوانا دیاز، پورٹو ریکو,জুয়ানা ডিয়াজ,胡安娜迪亞斯', 18.0524600, -66.5065600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112558, 'Juncal', 'Juncal', '', 18.3138400, -66.9190700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112559, 'Juncos', 'Juncos', '', 18.2274600, -65.9210000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112560, 'La Alianza', 'La Alianza', '', 18.3974500, -66.6024000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112561, 'La Dolores', 'La Dolores', 'Colonia Dolores', 18.3755000, -65.8557200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112562, 'La Fermina', 'La Fermina', '', 18.1755100, -65.8535000, 'PR', '2007-02-16', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112563, 'La Luisa', 'La Luisa', '', 18.4488400, -66.5098900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112564, 'La Parguera', 'La Parguera', '', 17.9749700, -67.0465700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112565, 'La Playa', 'La Playa', '', 18.2874500, -67.1868500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112566, 'La Plena', 'La Plena', '', 18.0466300, -66.2046100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112567, 'Lajas', 'Lajas', 'Lakhas,la ha si,lajasa,Лахас,لاخاس، پورٹو ریکو,লাজাস,拉哈斯', 18.0499600, -67.0593400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112568, 'Lamboglia', 'Lamboglia', '', 17.9813600, -65.9857200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112569, 'Lares', 'Lares', 'Lares,Santuario de la Patna,la lei si,laresa,Ларес,لاریس، پورٹو ریکو,লারেস,拉雷斯', 18.2946700, -66.8771200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112570, 'Las Marias', 'Las Marias', 'Comunidad Marias', 18.2932800, -67.1462900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112571, 'Las Marías', 'Las Marias', 'Las Marias,Las Marijas,Las-Marias,la si ma li ya si,lasa mariyasa,Лас Маријас,Лас-Маріас,লাস মারিয়াস,拉斯瑪麗亞斯', 18.2519000, -66.9921200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112572, 'Las Ochenta', 'Las Ochenta', '', 17.9846900, -66.3179500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112573, 'Las Ollas', 'Las Ollas', '', 18.0330200, -66.4243400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112574, 'Las Piedras', 'Las Piedras', 'Ribera de las Piedras', 18.1830100, -65.8662700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112575, 'Levittown', 'Levittown', '', 18.4499500, -66.1815600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112576, 'Liborio Negron Torres', 'Liborio Negron Torres', '', 18.0430200, -66.9424000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112577, 'Lluveras', 'Lluveras', '', 18.0383000, -66.9046200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112578, 'Loíza', 'Loiza', 'Loisa,Loiza,lo''ija,luo yi sa,Лоиза,Лоїса,لویسا، پورٹو ریکو,লোইজা,洛伊薩', 18.4313400, -65.8801600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112579, 'Los Llanos', 'Los Llanos', '', 18.0552400, -66.4057300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112580, 'Luis Llorens Torres', 'Luis Llorens Torres', '', 18.0569100, -66.5268400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112581, 'Luis M. Cintron', 'Luis M. Cintron', '', 18.2996800, -65.6384900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112582, 'Luquillo', 'Luquillo', 'Laquilo,Loquillo', 18.3724500, -65.7165500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112583, 'Luyando', 'Luyando', '', 18.3643900, -67.1574000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112584, 'Magas Arriba', 'Magas Arriba', '', 18.0174600, -66.7690600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112585, 'Manatí', 'Manati', 'Manati', 18.4274500, -66.4921200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112586, 'Maria Antonia', 'Maria Antonia', '', 17.9783000, -66.8893400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112587, 'Mariano Colón', 'Mariano Colon', 'Mariano Colon', 18.0233000, -66.3323900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112588, 'Maricao', 'Maricao', 'Marikao,ma li kao,marika''o,Марикао,Марікао,ماریکاو، پورٹو ریکو,মারিকাও,馬里考', 18.1807900, -66.9799000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112589, 'Martorell', 'Martorell', '', 18.0760700, -65.8982200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112590, 'Maunabo', 'Maunabo', '', 18.0071900, -65.8993300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112591, 'Miranda', 'Miranda', '', 18.3866200, -66.3837800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112592, 'Moca', 'Moca', 'Moka,The Literary City,mo ka,moka,Мока,موکا، پورٹو ریکو,মোকা,莫卡', 18.3946700, -67.1132400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112593, 'Monserrate', 'Monserrate', '', 18.4366100, -66.3596100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112594, 'Monte Grande', 'Monte Grande', '', 18.0874600, -67.1074000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112595, 'Mora', 'Mora', '', 18.4630000, -67.0326800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112596, 'Morovis', 'Morovis', '', 18.3257800, -66.4065600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112597, 'Mucarabones', 'Mucarabones', '', 18.3907800, -66.2160000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112598, 'Mayagüez', 'Mayagueez', 'MAZ,Magiagoues,Majaguehs,Majagues,Majaguesas,Majagvez,Mayagueez,Mayaguez,Mayagüez,ma ya gui si,mayaguesu,mayaguraeja,mayagvejha,mayagweseu,Μαγιαγουές,Маягуес,Маягуэс,Мајагвез,מאיאגואס,مایاگویس، پورٹو ریکو,मायाग्वेझ,মায়াগুৱেজ,マヤグエス,馬亞圭斯,마야궤스', 18.2010700, -67.1396200, 'PR', '2016-10-25', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112599, 'Naguabo', 'Naguabo', 'Naguabo,Nagueabo,Nagvabo,Nagüabo,Santiago,na gua wo,Нагвабо,Нагуабо,ناگوابو، پورٹو ریکو,納瓜沃', 18.2116200, -65.7348800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112600, 'Naranjito', 'Naranjito', 'Narankhito,na lan xi tuo,naranajito,Наранхито,Наранхіто,نارانخیتو، پورٹو ریکو,নারানজিতো,納蘭希托', 18.3007900, -66.2448900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112601, 'Olimpo', 'Olimpo', 'Hacienda Olimpo', 18.0019100, -66.1082200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112602, 'Orocovis', 'Orocovis', 'Barros', 18.2269000, -66.3910000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112603, 'Pájaros', 'Pajaros', 'Pajaros', 18.3685600, -66.2168300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112604, 'Palmarejo', 'Palmarejo', '', 18.0680200, -66.3254500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112605, 'Palmarejo', 'Palmarejo', '', 18.0402400, -67.0768500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112606, 'Palmas', 'Palmas', '', 17.9871900, -66.0254400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112607, 'Palmer', 'Palmer', '', 18.3705100, -65.7740500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112608, 'Palo Seco', 'Palo Seco', '', 18.0074700, -65.9368300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112609, 'Palomas', 'Palomas', '', 18.2324600, -66.2562800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112610, 'Palomas', 'Palomas', '', 18.0135800, -66.8732300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112611, 'Parcelas La Milagrosa', 'Parcelas La Milagrosa', '', 18.1707900, -66.1882200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112612, 'Parcelas Nuevas', 'Parcelas Nuevas', '', 18.1402400, -66.1723900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112613, 'Parcelas Peñuelas', 'Parcelas Penuelas', 'Parcelas Penuelas', 17.9988500, -66.3412800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112614, 'Pastos', 'Pastos', '', 18.1177400, -66.2587800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112615, 'Patillas', 'Patillas', 'Patil''jas,Patilas,pa di ya si,patillasa,Патиљас,Патільяс,پاتیلاس، پورٹو ریکو,পাটিল্লাস,帕蒂亞斯', 18.0063500, -66.0157200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112616, 'Peña Pobre', 'Pena Pobre', 'Pena Pobre', 18.2155100, -65.8221100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112617, 'Peñuelas', 'Penuelas', 'Penuelas', 18.0563500, -66.7215600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112618, 'Piedra Gorda', 'Piedra Gorda', '', 18.4341100, -66.8876800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112619, 'Playa Fortuna', 'Playa Fortuna', '', 18.3796700, -65.7451600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112620, 'Playita', 'Playita', '', 18.0446900, -65.9073800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112621, 'Playita Cortada', 'Playita Cortada', '', 17.9849700, -66.4390600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112622, 'Pole Ojea', 'Pole Ojea', '', 17.9749600, -67.1851800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112623, 'Ponce', 'Ponce', 'La Ciudad Senorial,La Ciudad de las Quenepas,La Perla del Sur,PSE,Ponce,Ponce Senorial,Ponse,Ponsė,Porto 4 e Ponce,The Pearl of the 54 uth,pang sai,ponse,Понсе,ポンセ,龐塞,폰세', 18.0110800, -66.6140600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112624, 'Potala Pastillo', 'Potala Pastillo', '', 17.9913500, -66.4965600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112625, 'Pueblito del Rio', 'Pueblito del Rio', '', 18.2280100, -65.8629400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112626, 'Puerto Real', 'Puerto Real', '', 18.0749600, -67.1871200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112627, 'Punta Santiago', 'Punta Santiago', '', 18.1663500, -65.7482200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112628, 'Quebrada', 'Quebrada', '', 18.3566200, -66.8321200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112629, 'Quebradillas', 'Quebradillas', 'Kebradil''jas,Kebradilas,ke bu la di ya si,Кебрадиљас,Кебрадільяс,کیبرادیلاس، پورٹو ریکو,克布拉迪亞斯', 18.4738300, -66.9385100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112630, 'Rafael Capo', 'Rafael Capo', '', 18.4071700, -66.7821200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112631, 'Rafael Gonzalez', 'Rafael Gonzalez', '', 18.4274500, -66.7868400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112632, 'Rafael Hernandez', 'Rafael Hernandez', '', 18.4713300, -67.0790700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112633, 'Ramos', 'Ramos', '', 18.3396700, -65.7126600, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112634, 'Rincón', 'Rincon', 'Rincon,Rinon,Santa Rosa de Rincon', 18.3402300, -67.2499000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112635, 'Río Blanco', 'Rio Blanco', 'Rio Blanco', 18.2182900, -65.7885000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112636, 'Río Cañas Abajo', 'Rio Canas Abajo', 'Rio Canas Abajo', 18.0383000, -66.4676700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112637, 'Río Grande', 'Rio Grande', 'Rio Grande,Rio-Grande,li ao ge lan de,ri''o grande,Рио Гранде,Ріо-Гранде,ریو گرینڈے، پورٹو ریکو,রিও গ্রান্ডে,里奧格蘭德', 18.3802300, -65.8312700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112638, 'Río Lajas', 'Rio Lajas', 'Rio Lajas', 18.3946700, -66.2676700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112639, 'Rosa Sanchez', 'Rosa Sanchez', '', 18.0616300, -65.9135000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112640, 'Sabana', 'Sabana', '', 18.4607800, -66.3585000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112641, 'Sabana Eneas', 'Sabana Eneas', '', 18.0860700, -67.0810100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112642, 'Sabana Grande', 'Sabana Grande', 'Sabana Grande,Sabana-Grande,da sa wa na,sabana grande,Сабана Гранде,Сабана-Гранде,سبانہ گراندے، پورٹو ریکو,সাবানা গ্রান্ডে,大薩瓦納', 18.0777400, -66.9604500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112643, 'Sabana Hoyos', 'Sabana Hoyos', '', 18.4338400, -66.6137800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112644, 'Sabana Seca', 'Sabana Seca', 'Sabana Seco', 18.4268900, -66.1846100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112645, 'Salinas', 'Salinas', 'Porto de las Salinas', 17.9774700, -66.2979500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112646, 'San Antonio', 'San Antonio', '', 18.4921700, -67.0985100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112647, 'San Antonio', 'San Antonio', '', 18.4488400, -66.3026700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112648, 'San Antonio', 'San Antonio', '', 18.4516100, -66.9496200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112649, 'San Germán', 'San German', 'Ciudad de la s Lomas,La Villa San German,Nueva Villa de Salamanca,San 7 ermani,San German,San Jermani,San Kherman,San-Kherman,sheng he er man,Сан Херман,Сан-Херман,سان خیرمان، پورٹو ریکو,聖赫爾曼', 18.0816300, -67.0449000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112650, 'San Isidro', 'San Isidro', '', 18.3921700, -65.8854400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112651, 'San José', 'San Jose', 'San Jose', 18.3982800, -66.2557200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112652, 'San Juan', 'San Juan', 'Caparra,Ciudad de Puerto Rico,Gorad San-Khuan,Portorico,Prico,Puerto Rico,SJU,Saint Iuan,Saint John de Porto Rico,Sainte Jean de Porto-rico,San Chouan,San Chuanas,San Huan,San Ian de Porto Rico,San Ioanni,San Jean de Portorico,San Juan,San Juan Batista de Puerto Rico,San Juan Bautistade de Puerto Rico,San Juan de Puerto Rico,San Khuan,San Xoan,San Xoán,San Xuan,San-Juano,San-Khuan,Sanhuana,The City of Saint John,Ville de Porto-Rico,Ville de Sainte Jean de Porto Rico,can van,saenhwan,san hwn,san khwan,san-khuani,sana hu''ana,sana huraana,sanfuan,sanhuan,sheng hu an,Σαν Χουάν,Горад Сан-Хуан,Сан Хуан,Сан-Хуан,Սան Խուան,סן חואן,سان خوآن,سان خوان,सान हुआन,সান হুৱান,ਸਾਨ ਹੁਆਨ,சான் வான்,ซานฮวน,სან-ხუანი,サンフアン,圣胡安,산후안,샌환', 18.4663300, -66.1057200, 'PR', '2017-06-22', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112653, 'San Lorenzo', 'San Lorenzo', 'San Miguel de Hato Grande', 18.1894000, -65.9610000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112654, 'San Sebastián', 'San Sebastian', 'San Sebastian', 18.3366200, -66.9901800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112655, 'Santa Barbara', 'Santa Barbara', '', 18.3935600, -65.9187800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112656, 'Santa Clara', 'Santa Clara', '', 18.2185700, -66.1287800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112657, 'Santa Isabel', 'Santa Isabel', '', 17.9660800, -66.4048900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112658, 'Santo Domingo', 'Santo Domingo', '', 18.0633000, -66.7524000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112659, 'Stella', 'Stella', '', 18.3218900, -67.2468500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112660, 'Suárez', 'Suarez', 'Suarez', 18.4302200, -65.8535000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112661, 'Sumidero', 'Sumidero', '', 18.2185700, -66.1287800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112662, 'Tallaboa', 'Tallaboa', '', 17.9949700, -66.7162900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112663, 'Tallaboa Alta', 'Tallaboa Alta', '', 18.0510700, -66.7001700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112664, 'Tierras Nuevas Poniente', 'Tierras Nuevas Poniente', '', 18.4618900, -66.4885000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112665, 'Toa Alta', 'Toa Alta', 'Toa Alta,Toa-Al''ta,shang tuo a,taraa alata,Тоа Алта,Тоа-Альта,توا التا، پورٹو ریکو,টৱা আলটা,上托阿', 18.3882800, -66.2482200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112666, 'Toa Baja', 'Toa Baja', '', 18.4438400, -66.2596100, 'PR', '2013-06-29', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112667, 'Trujillo Alto', 'Trujillo Alto', 'Trukhil''jo-Al''to,Trukhilo Alto,shang te lu xi e,teuluhiyoalto,trwzhylw altw  pwrtwrykw,Трухиљо Алто,Трухільйо-Альто,تروخیلو التو، پورٹو ریکو,تروژیلو آلتو، پورتوریکو,上特魯希略,트루히요알토', 18.3546700, -66.0073900, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112668, 'Utuado', 'Utuado', 'Utuado,uturaada,wu tu a duo,Утуадо,اوتوادو، پورٹو ریکو,উটুৱাদা,烏圖阿多', 18.2655100, -66.7004500, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112669, 'Vázquez', 'Vazquez', 'Vazquez', 18.0658000, -66.2385000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112670, 'Vega Alta', 'Vega Alta', 'Vega Alta,Vega-Al''ta,bhega alata,shang wei jia,wga alta  pwrtwrykw,Вега Алта,Вега-Альта,بیگا التا، پورٹو ریکو,وگا آلتا، پورتوریکو,ভেগা আলটা,上維加', 18.4121700, -66.3312800, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112671, 'Vega Baja', 'Vega Baja', 'Vega Bakha,Vega-Bakha,bhega baja,wga baja  pwrtwrykw,xia wei jia,Вега Баха,Вега-Баха,بیگا باخا، پورٹو ریکو,وگا باجا، پورتوریکو,ভেগা বাজা,下維加', 18.4443900, -66.3876700, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112672, 'Vieques', 'Vieques', '', 18.4249500, -65.8329400, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112673, 'Villalba', 'Villalba', '', 18.1271800, -66.4921200, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112674, 'Yabucoa', 'Yabucoa', '', 18.0505200, -65.8793300, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112675, 'Yauco', 'Yauco', 'Coayuco,Jauko,ya''uko,yao ke,Јауко,Яуко,یاوکو، پورٹو ریکو,য়াউকো,堯科', 18.0349600, -66.8499000, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112676, 'Yaurel', 'Yaurel', '', 18.0269100, -66.0571100, 'PR', '2015-08-03', 179);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112455, 'Saint-Pierre', 'Saint-Pierre', 'FSP,Saint Pierre,Saint-Pierre,St Pierre,saengpieleu,생피에르', 46.7791400, -56.1773000, 'PM', '2013-12-22', 190);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112456, 'Miquelon', 'Miquelon', 'MQC,Miquelon', 47.0975000, -56.3813900, 'PM', '2017-01-10', 190);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112684, 'Dayr al Balaḩ', 'Dayr al Balah', 'Belar,Dayr al Balah,Dayr al Balaḩ,Deir el-Balah,Der el Bela,Dier El Balah,dyr alblh,دير البلح', 31.4178300, 34.3503300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112685, 'Bayt Lāhyā', 'Bayt Lahya', 'Bayt Lahiya,Bayt Lahiyah,Bayt Lahya,Bayt Lāhiya,Bayt Lāhiyah,Bayt Lāhyā,Beit Lahia,Beit Lahiya,Beit Lahya,Beit Lāhiya,byt lahya,بيت لاهيا', 31.5464000, 34.4951400, 'PS', '2014-07-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112686, 'Bayt Ḩānūn', 'Bayt Hanun', 'Bayt Hanun,Bayt Ḩanūn,Bayt Ḩānūn,Beit Hanoon,Beit Hanoum,Beit Hanoun,Beit Hanun,byt hanwn,byt hnwn,بيت حانون,بيت حنون', 31.5353000, 34.5357900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112687, 'Banī Suhaylā', 'Bani Suhayla', 'Bani Suhayl,Bani Suhayla,Bani Suhaylah,Bani Suheila,Banī Suhayl,Banī Suhaylah,Banī Suhaylā,bny shyla,بني سهيلا', 31.3433700, 34.3233700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112688, 'Al Fukhkhārī', 'Al Fukhkhari', 'Al Fakhkhari,Al Fakhkhārī,Al Fukhkhari,Al Fukhkhārī,El Fukhkhari,alfkhary,الفخاري', 31.2927800, 34.3306100, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112689, 'Al Burayj', 'Al Burayj', 'Al Buraij,Al Burayj,Al-Bureij,Bureij,El Bureij,albryj,البريج', 31.4394400, 34.4030600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112690, '‘Abasān al Kabīrah', '`Abasan al Kabirah', 'Abasan,Abasan Kabera,Abasan al Kabir,Abasan al-Kabera,Abasan alkabir,Abasan el-Kabir,Abasân el-Kabîr,Abasān,Abasān al Kabīr,`Abasan al Kabirah,عبسان الكبيرة,‘Abasān al Kabīrah', 31.3191300, 34.3400500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112691, 'Zubūbah', 'Zububah', 'Zububa,Zububah,Zubūbah,Zubūbā,zbwbh,زبوبه', 32.5434600, 35.2227400, 'PS', '2013-05-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112692, 'Zaytā', 'Zayta', 'Zayta,Zaytā,Zeita,Zeitā,zyta,زيتا', 32.3856000, 35.0512200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112693, 'Zaytā Jammā‘īn', 'Zayta Jamma`in', 'Zayta,Zayta Jamma`in,Zaytā,Zaytā Jammā‘īn,Zeita,زيتا جماعين', 32.1369800, 35.1859500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112694, 'Zawātā', 'Zawata', 'Zawata,Zawātā,zwata,زواتا', 32.2461100, 35.2265000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112695, 'Za‘tarah', 'Za`tarah', 'Za `Tara,Za ‘Tara,Za`tarah,Za‘tarah,زعترة', 31.6736100, 35.2566200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112696, 'Yuta', 'Yuta', 'Jatta,Yatta,Yattah,Yaţţah,Yaţţā,Yaṭṭa,Yuta,yta,يطا', 31.4459000, 35.0944300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112697, 'Yatmā', 'Yatma', 'Yatma,Yatmā,ytma,يتما', 32.1088900, 35.2690900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112698, 'Yāsūf', 'Yasuf', 'Yasouf,Yasuf,Yāsūf,yaswf,ياسوف', 32.1084100, 35.2378400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112699, 'Yāşīd', 'Yasid', 'Yasid,Yāşīd,yasyd,ياصيد', 32.2968800, 35.2775700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112700, 'Ya‘bad', 'Ya`bad', 'Ya`bad,Ya`bud,Ya‘bad,Ya‘bud,يعبد', 32.4456600, 35.1682200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112701, 'Wādī Fūkīn', 'Wadi Fukin', 'Wadi Fukin,Wādī Fūkīn,wady fwkyn,وادي فوكين', 31.7070100, 35.1036600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112702, '‘Ūrīf', '`Urif', '`Urif,عوريف,‘Ūrīf', 32.1594900, 35.2222800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112703, 'Ūdalah', 'Udalah', 'Audala,Odala,Udalah,`Awdallah,`Udala,awdla,Ūdalah,أودلا,‘Awdallah,‘Udala', 32.1536300, 35.2764600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112704, 'Turmus‘ayyā', 'Turmus`ayya', 'Turmas `Aya,Turmas ‘Aya,Turmosa''ayya,Turmus `Aiya,Turmus `Ayya,Turmus `Ayyah,Turmus ‘Aiyā,Turmus ‘Ayyah,Turmus ‘Ayyā,Turmus`ayya,Turmus‘ayyā,ترمسعيا', 32.0353800, 35.2856400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112705, 'Ţūlkarm', 'Tulkarm', 'Keram,Toelkarem,Tul Kerem,Tul''karm,Tulkarem,Tulkarm,Tūl Kerem,twl krm,twlkrm,Ţūlkarm,Тулькарм,טול כרם,طولكرم', 32.3103700, 35.0286300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112706, 'Ţūbās', 'Tubas', 'Tubas,twbas,Ţūbās,طوباس', 32.3209100, 35.3698900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112707, 'Tayāsīr', 'Tayasir', 'Tayaseer,Tayasir,Tayāsīr,tyasyr,تياسير', 32.3404200, 35.3960400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112708, 'Tarqūmyā', 'Tarqumya', 'Tarqumia,Tarqumiya,Tarqumiyah,Tarqumya,Tarqumye,Tarqūmiya,Tarqūmiyah,Tarqūmye,Tarqūmyā,Terkumie,Turqumiya,trqwmya,ترقوميا', 31.5755100, 35.0122300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112709, 'Ţammūn', 'Tammun', 'Tammun,tmwn,Ţammūn,طمون', 32.2834700, 35.3836700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112710, 'Ţallūzah', 'Talluzah', 'Talluza,Talluzah,tlwzt,Ţallūzah,Ţallūzā,طلوزة', 32.2705600, 35.2949600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112711, 'Till', 'Till', 'Tall,Tell,Til,Till,Tīl,tl,تل', 32.2006800, 35.2129300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112712, 'Talfīt', 'Talfit', 'Talfit,Talfīt,Tilfit,Tilfīt,tlfyt,تلفيت', 32.0866400, 35.2909400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112713, 'Taffūḩ', 'Taffuh', 'Taffouh,Taffuh,Taffūḩ,Tapuah,tfwh,تفوح', 31.5385500, 35.0496600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112714, 'Şūrīf', 'Surif', 'Surif,swryf,Şūrīf,صوريف', 31.6507800, 35.0643900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112715, 'Surdā', 'Surda', 'Surda,Surdah,Surdā,srda,صردا', 31.9370900, 35.2032100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112716, 'Sīrīs', 'Siris', 'Siris,Sīrīs,syrys,سيريس', 32.3282800, 35.2913400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112717, 'Sinjil', 'Sinjil', 'Saint Gilles,Sindjil,Sinjel,Sinjil,snjl,سنجل', 32.0333400, 35.2654500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112718, 'Silwād', 'Silwad', 'Silwad,Silwād,slwad,سلواد', 31.9762500, 35.2613000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112719, 'Sīlat az̧ Z̧ahr', 'Silat az Zahr', 'Saylat ad Dahr,Saylat aḑ Ḑahr,Silat adh Dhahr,Silat az Zahr,Silat edh Dhahr,Silet edh Dhahr,Sīlat adh Dhahr,Sīlat az̧ Z̧ahr,Sīlet edh Dhahr,sylt alzhr,سيلة الظهر', 32.3193400, 35.1841800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112720, 'Sīlat al Ḩārithīyah', 'Silat al Harithiyah', 'Silat al Harithiya,Silat al Harithiyah,Silat el Harithiya,Sīlat al Ḩārithīyah,Sīlat el Ḥārithīya,sylt alharthyt,سيلة الحارثية', 32.5084700, 35.2275200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112721, 'Sa‘īr', 'Sa`ir', 'Sa`ir,Sa‘īr,Si`ir,Si‘īr,سعير', 31.5785500, 35.1401700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112722, 'Shuqbā', 'Shuqba', 'Shiqbah,Shuqba,Shuqbah,Shuqbā,shqba,شقبا', 31.9869500, 35.0401200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112723, 'Shūfah', 'Shufah', 'Shawfah,Shufa,Shufah,Shūfa,Shūfah,shwft,شوفة', 32.2755100, 35.0813500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112724, 'Şaydā', 'Sayda', 'Khirbat Saydah,Khirbat Şaydāh,Sayda,Seida,syda,Şaydā,صيدا', 32.3848900, 35.1185600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112725, 'Şarţah', 'Sartah', 'Sarta,Sartah,srtt,Şarţah,صرطة', 32.1044700, 35.0919800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112726, 'Şarrah', 'Sarrah', 'Sarra,Sarrah,srt,Şarrah,صرة,Ṣarra', 32.2097000, 35.1914700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112727, 'Şānūr', 'Sanur', 'Sanur,sanwr,Şānūr,صانور', 32.3560800, 35.2453700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112728, 'Sannīryā', 'Sannirya', 'Samiriyyah,Sanirah,Sanireh,Sanniriya,Sanniriyah,Sannirya,Sannīriya,Sannīrya,Sannīryā,Sannīrīyah,Sanīrah,Sanīreh,snyrya,سنيريا', 32.1287700, 35.0465200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112729, 'Sālim', 'Salim', 'Salem,Salim,Sālem,Sālim,salm,سالم', 32.2096200, 35.3303400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112730, 'Salfīt', 'Salfit', 'Salfit,Salfīt,slfyt,سلفيت', 32.0837100, 35.1807900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112731, 'Şaffā', 'Saffa', 'Saffa,sfa,Şaffā,صفا', 31.9056300, 35.0609400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112732, 'Sabasţīyah', 'Sabastiyah', 'Sabastiya,Sabastiyah,Sabasţīyah,Sabatiyah,Sabaţīyah,Sebaste,Sebastia,Sebastiya,Sebastye,Sebustie,Sebustiye,Sevaste,Sevastē,Shomron,sbstyt,سبسطية', 32.2756200, 35.1987300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112733, 'Rummanah', 'Rummanah', 'Rummana,Rummanah,Rummāna,rmnt,رمنة', 32.5245100, 35.2048000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112734, 'Rūjayb', 'Rujayb', 'Oujeeb,Rujayb,Rujeib,Rūjayb,rwjyb,روجيب', 32.1906100, 35.2933200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112735, 'Rās Karkar', 'Ras Karkar', 'Ra''s Karkar,Ras Karkar,Ra’s Karkar,Rās Karkar,ras krkr,راس كركر', 31.9424000, 35.1077300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112736, 'Rantīs', 'Rantis', 'Rantis,Rantīs,rntys,رنتيس', 32.0279700, 35.0187900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112737, 'Rammūn', 'Rammun', 'Rammun,Rammūn,Rimmon,rmwn,رمون', 31.9334200, 35.2982100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112738, 'Rāmīn', 'Ramin', 'Ramin,Rāmīn,ramyn,رامين', 32.2852000, 35.1495100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112739, 'Ramallah', 'Ramallah', 'Rahm Alla,Ram Allah,Ramala,Ramalaho,Ramall,Ramalla,Ramallae,Ramallag'',Ramallah,Ramallakh,Ramalláh,Ramal·lah,Ramella,Rámalláh,Rām Allāh,Rāmalla,ZDM,la mu an la,lamalla,ram allh,ramarra,ramla,rxma llxh,Ραμάλα,Рамала,Рамаллæ,Рамалла,Рамаллагь,Рамаллах,РамаллахӀ,Рамаллаһ,Ռամալլահ,ראמאללא,רמאללה,رام الله,رام‌الله,رملہ,ڕامەڵا,ரம்லா,รอมัลลอฮ์,ラマッラー,拉姆安拉,라말라', 31.8996400, 35.2042200, 'PS', '2013-11-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112740, 'Rāfāt', 'Rafat', '', 32.0780600, 35.0441700, 'PS', '2006-01-17', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112741, 'Rāfāt', 'Rafat', 'Rafat,Rāfāt,rafat,رافات', 31.8709600, 35.1918200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112742, 'Rābā', 'Raba', 'Raba,Rābā,raba,رابا', 32.3867900, 35.3829800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112743, 'Quşrah', 'Qusrah', 'Kusrah,Qusra,Qusrah,Quşrah,Quṣra,qsrt,قصرة', 32.0854300, 35.3300500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112744, 'Qūşīn', 'Qusin', 'Qusein,Qusin,Qūşīn,Qūṣein,qwsyn,قوصين', 32.2382900, 35.1829700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112745, 'Qīrah', 'Qirah', 'Kireh,Qira,Qirah,Qire,Qīra,Qīrah,qyrt,قيرة', 32.1221400, 35.1717300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112746, 'Qibyah', 'Qibyah', 'Kibbia,Qibya,Qibyah,Qibye,Qibyā,qbyh,قبيه', 31.9773400, 35.0098400, 'PS', '2013-05-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112747, 'Qaţanah', 'Qatanah', 'Katanneh,Qatana,Qatanah,Qatanna,Qatannah,Qatanne,Qaţanah,Qaţannah,qtnh,قطنه', 31.8336600, 35.1189400, 'PS', '2013-05-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112748, 'Qaryūt', 'Qaryut', 'Kuriyut,Qaryut,Qaryūt,qrywt,قريوت', 32.0700400, 35.2943200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112749, 'Qarāwat Banī Zayd', 'Qarawat Bani Zayd', 'Qarawat Bani Zayd,Qarawat Bani Zeid,Qarāwat Banī Zayd,Quarawat Bani Zeid,Quarāwat Banī Zeid,qrawt bny zyd,قراوة بني زيد', 32.0547000, 35.1290800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112750, 'Qarāwat Banī Ḩasan', 'Qarawat Bani Hasan', 'Qarawat Bani Hasan,Qarāwat Banī Ḩasan,qrawt bny hsan,قراوة بني حسان', 32.1256800, 35.1006100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112751, 'Qalqīlyah', 'Qalqilyah', 'Kal Kiliya,Kal''kilija,Kalkilieh,Kfar Saba,Qalkilya,Qalqiliya,Qalqilyah,Qalqilye,Qalqīliya,Qalqīlyah,Qalqīlye,qlqylyh,qlqylyt,Калькилия,קלקיליה,قلقيلية', 32.1896600, 34.9706300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112752, 'Qalandiyā', 'Qalandiya', 'Kalendieh,Kulundia,Qalandiya,Qalandiyah,Qalandiyā,Qalandye,Qalandīyah,qlndya,قلنديا', 31.8628900, 35.2081500, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112753, 'Qaffīn', 'Qaffin', 'Kuffin,Qaffin,Qaffīn,Quffin,Quffīn,fqyn,فقين', 32.4327400, 35.0826600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112754, 'Qabāţīyah', 'Qabatiyah', 'Kubatie,Kubatiya,Qabatiya,Qabatiyah,Qabatye,Qabātiya,Qabātye,Qabāţīyah,qbatyt,قباطية', 32.4103500, 35.2808700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112755, 'Qabalān', 'Qabalan', 'Kubalan,Qabalan,Qabalān,qblan,قبلان', 32.1018200, 35.2893800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112756, 'Nūbā', 'Nuba', 'Nuba,Nūbā,nwba,نوبا', 31.6090000, 35.0345500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112757, 'Ni‘līn', 'Ni`lin', 'Ni`lin,Ni‘līn,نعلين', 31.9474600, 35.0203100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112758, 'Nazlat ‘Īsá', 'Nazlat `Isa', 'Nazlat `Isa,Nazlat ‘Īsá,نزلة عيسى', 32.4156200, 35.0588800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112759, 'Naḩḩālīn', 'Nahhalin', 'Nahhalin,Naḩḩālīn,nhalyn,نحالين', 31.6855900, 35.1208100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112760, 'Nablus', 'Nablus', 'Flavia Neapolis,Nablus,Nablusas,Nablusz,Nabulus,Namplous,Naplouse,Naplusa,Napouse,Neapolis,Náblus,Náblusz,Nāblus,Schechem,Shechem,Shekhem,Sichem,Sihhem,Siquem,Sychem,Sykhem,ZDF,na bu lu si,nabeulluseu,nabls,nablws,naburusu,skm,Ναμπλούς,Наблус,שכם,نابلس,نابلوس,ナーブルス,納布盧斯,나블루스', 32.2211100, 35.2544400, 'PS', '2010-01-29', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112761, 'Mikhmās', 'Mikhmas', 'Mikhmas,Mikhmās,Mukhmas,Mukhmās,mkhmas,مخماس', 31.8721000, 35.2759600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112762, 'Mislīyah', 'Misliyah', 'Misilya,Misilyah,Misliya,Misliyah,Mislīyah,mslyt,مسلية', 32.3861300, 35.2878000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112763, 'Mirkah', 'Mirkah', 'Mirka,Mirkah,mrkt,مركة', 32.3958300, 35.2380700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112764, 'Banī Zayd ash Shārqīyah', 'Bani Zayd ash Sharqiyah', 'Bani Zayd ash Sharqiyah,Banī Zayd ash Shārqīyah,Mazari` an Nubani,Mazari` en Nubani,Mazāri‘ an Nūbānī,Mazāri‘ en Nūbānī,bny zyd alshrqyt,بني زيد الشرقية,مزارع النوباني', 32.0493500, 35.1659300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112765, 'Maythalūn', 'Maythalun', 'Maysalun,Maysalūn,Maythalun,Maythalūn,Meithalun,Meithalūn,mythlwn,ميثلون', 32.3479800, 35.2744600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112766, 'Masḩah', 'Mashah', 'Mas-ha,Mas-ḥa,Masha,Mashah,Masḩah,msht,مسحة', 32.1082800, 35.0509600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112767, 'Mardā', 'Marda', 'Marda,Mardah,Mardā,mrda,مردا', 32.1138100, 35.1953600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112768, 'Majdal Banī Fāḑil', 'Majdal Bani Fadil', 'Majdal Bani Fadil,Majdal Bani Fadl,Majdal Banī Fāḑil,mjdl bny fadl,مجدل بني فاضل', 32.0835700, 35.3637800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112769, 'Mādamā', 'Madama', 'Madama,Mādamā,madma,مادما', 32.1858800, 35.2311400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112770, 'Al Lubban ash Sharqīyah', 'Al Lubban ash Sharqiyah', 'Al Lubban ash Sharqiyah,Al Lubban ash Sharqīyah,Lubban Sharqiya,Lubban esh Sharqiya,allbn alshrqyt,اللبن الشرقية', 32.0701100, 35.2403000, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112771, 'Kufayrit', 'Kufayrit', 'Kufayrat,Kufayrit,Kufayrāt,Kufeirat,Kufeirit,Kufeirāt,kfyrt,كفيرت', 32.4438000, 35.2018400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112772, 'Kifil Ḩāris', 'Kifil Haris', 'Kafr Haris,Kafr Ḩaris,Kefel Hares,Kiel Harith,Kiel Ḥārith,Kifil Haris,Kifil Ḩāris,Kifl Hareth,Kifl Harith,Kifl Ḩārith,kfl hars,كفل حارس', 32.1182700, 35.1571900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112773, 'Ar Ramāḑīn', 'Ar Ramadin', 'Ar Ramadin,Ar Ramāḑīn,Khirbat Mudayminah,Khirbat Mudeimina,Khirbat Umm Dayminah,alrmadyn,الرماضين', 31.3795200, 34.9124600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112774, 'Qalqas', 'Qalqas', 'Khirbat Qalqas,Khirbat Qilqis,Qalqas,qlqs,قلقس', 31.4921200, 35.0953500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112775, 'Imrīsh', 'Imrish', 'Imrish,Imrīsh,Khirbat Muraysh,Khirbat Mureish,amrysh,إمريش', 31.4689500, 35.0081900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112776, 'Marāḩ Rabbāḩ', 'Marah Rabbah', 'Khirbat Marah Rabbah,Khirbat Marāḩ Rabbāḩ,Marah Rabbah,Marāḩ Rabbāḩ,mrah rbah,مراح رباح', 31.6340600, 35.1868800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112777, 'Dayr al ‘Asal al Fawqā', 'Dayr al `Asal al Fawqa', 'Dayr al `Asal al Fawqa,Dayr al ‘Asal al Fawqā,Khirbat Dayr `Asal al Fawqa,Khirbat Dayr al `Asal al Fawqa,Khirbat Dayr al ‘Asal al Fawqā,Khirbat Dayr ‘Asal al Fawqā,Khirbat Deir `Asal el Fauqa,Khirbat Deir ‘Asal el Fauqa,دير العسل الفوقا', 31.4683200, 34.9383200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112778, 'Bayt Ta‘mar', 'Bayt Ta`mar', 'Bayt Ta`mar,Bayt Ta‘mar,Khirbat Bayt Ta`mir,Khirbat Bayt Ta‘mīr,Khirbat Beit Ta`mir,Khirbat Beit Ta‘mir,بيت تعمر', 31.6792700, 35.2398600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112779, 'Bayt Ḩasan', 'Bayt Hasan', 'Bayt Hasan,Bayt Ḩasan,Khirbat Bayt Hasan,Khirbat Bayt Ḩasan,Khirbat Beit Hasan,byt hsn,بيت حسن', 32.2376000, 35.4040700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112780, 'Bayt ‘Awwā', 'Bayt `Awwa', 'Bayt `Awwa,Bayt ‘Awwā,Khirbat Bayt `Awwa'',Khirbat Bayt ‘Awwā’,Khirbat Beit `Awwa,Khirbat Beit ‘Awwa,بيت عوا', 31.5091100, 34.9493800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112781, 'Jannātah', 'Jannatah', 'Bayt Faluh,Bayt Falūḩ,Jannatah,Jannātah,Khirbat Badd Falluh,Khirbat Badd Fallūḩ,Khirbat Badd Faluh,Khirbat Badd Falūh,byt flwh,jnatt,بيت فلوح,جناتة', 31.6695900, 35.2196100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112782, 'Ash Shaykh Sa‘d', 'Ash Shaykh Sa`d', 'Ash Shaykh Sa`d,Ash Shaykh Sa‘d,Khirbat ash Shaykh Sa`ad,Khirbat ash Shaykh Sa`d,Khirbat ash Shaykh Sa‘ad,Khirbat ash Shaykh Sa‘d,Khirbat ash Sheikh Sa`d,Khirbat ash Sheikh Sa‘d,Khirbat esh Sheikh Sa`ad,Khirbat esh Sheikh Sa‘ad,الشيخ سعد', 31.7372100, 35.2574200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112783, 'An Naşşārīyah', 'An Nassariyah', 'An Nassariyah,An Naşşārīyah,Khirbat al Mirsas,Khirbat al Mirşās,Khirbat al Murassas,Khirbat al Muraşşaş,Khirbat el Mirsas,Khirbat el Mirṣāṣ,Khirbat el Murassas,alnsaryt,النصارية', 32.2364700, 35.3871100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112784, 'Kharbathā al Mişbāḩ', 'Kharbatha al Misbah', 'Kharbatha al Misbah,Kharbathā al Mişbāḩ,Khirbat al Misbah,Khirbat al Mişbāḩ,Khirbat el Misbah,Khirbat el Miṣbāḥ,khrbtha almsbah,خربثا المصباح', 31.8854600, 35.0718500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112785, 'Al Majd', 'Al Majd', 'Al Majd,Khirbat al Majd,Khirbat el Majd,almjd,المجد', 31.4809500, 34.9506300, 'PS', '2017-01-05', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112786, 'Karmah', 'Karmah', 'Karmah,Khirbat Karma,Khirbat Karmah,Khirbat al Karmah,Khirbat el Karma,krmt,كرمة', 31.4518500, 35.0271400, 'PS', '2017-01-05', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112787, 'Al Burj', 'Al Burj', 'Al Burj,Burj Beirah,Burj el Baiyara,Burj el Baiyāra,Khirbat al Burj,Khirbat el Burj,albrj,البرج', 31.4360900, 34.9169700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112788, 'Shuyūkh al ‘Arrūb', 'Shuyukh al `Arrub', 'Khirbat `Arrub,Khirbat al `Arrub,Khirbat al ‘Arrūb,Khirbat ‘Arrūb,Shuyukh al `Arrub,Shuyūkh al ‘Arrūb,شيوخ العروب', 31.6173500, 35.1436600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112789, 'Khirbat Abū Falāḩ', 'Khirbat Abu Falah', 'Al Jardah,Khirbat Abu Falah,Khirbat Abū Falāḩ,Khirbet Abu Falah,Khirbet Abū Falāh,khrbt abw flah,خربة أبو فلاح', 32.0167800, 35.3013500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112790, 'Kharbathā Banī Ḩārith', 'Kharbatha Bani Harith', 'Kharbata,Kharbatha Bani Harith,Kharbathā Banī Ḩārith,Kharbatā,Khirbata,Khirbatā,khrbtha bny harth,خربثا بني حارث', 31.9450800, 35.0719400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112791, 'Khārās', 'Kharas', 'Kharas,Khārās,kharas,خاراس', 31.6148000, 35.0417400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112792, 'Khallat al Mayyah', 'Khallat al Mayyah', 'Khallat al Mayyah,Khirbat Khallat al Mayyah,Khirbat Khallat al Meiya,Khirbat al Mayyah,Khirbat el Maiya,khlt almyt,خلة المية', 31.4422200, 35.1428600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112793, 'Kūbar', 'Kubar', 'Kaubar,Kawbar,Kubar,Kūbar,kwbr,كوبر', 31.9872200, 35.1578800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112794, 'Kafr Zībād', 'Kafr Zibad', 'Kafr Zibad,Kafr Zībād,Khirbat Zibad,Khirbat Zibād,kfr zybad,كفر زيباد', 32.2258300, 35.0717900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112795, 'Kafr Thulth', 'Kafr Thulth', 'Kafr Thulth,kfr thlth,كفر ثلث', 32.1533000, 35.0469800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112796, 'Kafr Şūr', 'Kafr Sur', 'Kafr Sur,Kafr Şūr,kfr swr,كفر صور', 32.2436600, 35.0639400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112797, 'Kafr Rā‘ī', 'Kafr Ra`i', 'Kafr Ra`i,Kafr Rā‘ī,Kufr Ra`i,Kufr Rā‘i,Raay,كفر راعي', 32.3739800, 35.1545100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112798, 'Kafr Qūd', 'Kafr Qud', 'Kafr Qud,Kafr Qūd,kfr qwd,كفر قود', 32.4566100, 35.2264900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112799, 'Kafr Qallīl', 'Kafr Qallil', 'Kafr Qalil,Kafr Qallil,Kafr Qallīl,Kafr Qalīl,Kufor Qallil,kfr qlyl,كفر قليل', 32.1935100, 35.2828400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112800, 'Kafr Qaddūm', 'Kafr Qaddum', 'Allen More,Alon Moreh,Alon-Morah,Elon Moreh,Kaddum,Kadoum,Kafr Kaddum,Kafr Kaddūm,Kafr Qaddum,Kafr Qaddūm,Kufr Qaddum,Kufr Qaddūm,Qaddum,Qadum,Qidma,Qidmā,kfr qdwm,كفر قدوم', 32.2216200, 35.1447100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112801, 'Kafr Mālik', 'Kafr Malik', 'Kafr Malik,Kafr Mālik,kfr malk,كفر مالك', 31.9884000, 35.3093200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112802, 'Kafr Jammāl', 'Kafr Jammal', 'Kafr Jammal,Kafr Jammāl,kfr jmal,كفر جمال', 32.2255100, 35.0433700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112803, 'Kafr Dān', 'Kafr Dan', 'Kafr Dan,Kafr Dān,kfr dan,كفر دان', 32.4785200, 35.2542500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112804, 'Kafr ‘Ayn', 'Kafr `Ayn', 'Kafr `Ayn,Kafr `Ein,Kafr ‘Ayn,Kafr ‘Ein,كفر عين', 32.0475800, 35.1203800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112805, 'Kafr al Labad', 'Kafr al Labad', 'Kafr al Labad,Kafr el Labad,kfr allbd,كفر اللبد', 32.2996700, 35.1095500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112806, 'Kafr ad Dīk', 'Kafr ad Dik', 'Kafr ad Dik,Kafr ad Dīk,Kafr ed Dik,Kafr ed Dīk,kfr aldyk,كفر الديك', 32.0671000, 35.0828700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112807, 'Kafr ‘Abbūsh', 'Kafr `Abbush', 'Kafr `Abbush,Kafr ‘Abbūsh,كفر عبوش', 32.2235300, 35.0850400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112808, 'Jūrīsh', 'Jurish', 'Jurish,Jūrīsh,jwrysh,جوريش', 32.1018800, 35.3218800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112809, 'Jūrat ash Sham‘ah', 'Jurat ash Sham`ah', 'Jaurat esh Sham`a,Jaurat esh Sham‘a,Jurat ash Sham`ah,Jurat esh Shama,Jūrat ash Sham‘ah,Khirbat ash Sham`a,Khirbat ash Sham`ah,Khirbat ash Sham‘a,Khirbat ash Sham‘ah,Khirbat esh Shama,جورة الشمعة', 31.6505100, 35.1700100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112810, 'Al Judayyidah', 'Al Judayyidah', 'Al Judayyidah,El Judeiyida,Judaydah,Judeida,aljdydt,الجديدة', 32.3354100, 35.3010700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112811, 'Jīt', 'Jit', 'Jit,Jitt,Jīt,Jītt,Qaryat Jit,Qaryat Jīt,jyt,جيت', 32.2143100, 35.1708100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112812, 'Jifnā', 'Jifna', 'Jifna,Jifnā,jfna,جفنا', 31.9619200, 35.2133800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112813, 'Jayyūs', 'Jayyus', 'Jaiyus,Jaiyūs,Jayyus,Jayyūs,jyws,جيوس', 32.2012500, 35.0341600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112814, 'Janīn', 'Janin', 'Djenin,Dschenin,Dzhenin,Engannim,Janin,Janīn,Jenin,Jenine,Jinin,Jénine,`Ein Gannim,gnyn,jnyn,Дженин,גנין,جنين,‘Ein Gannīm', 32.4594300, 35.3008600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112815, 'Jammā‘īn', 'Jamma`in', 'Djemmain,Jamma`in,Jammā‘īn,Jemma`in,Jemmā‘īn,جماعين', 32.1316400, 35.2040300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112816, 'Jalqamūs', 'Jalqamus', 'Jalqamus,Jalqamūs,jlqmws,جلقموس', 32.4246400, 35.3642100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112817, 'Jalbūn', 'Jalbun', 'Djelbon,Gilbo`a,Gilbo‘a,Jalbun,Jalbūn,jlbwn,جلبون', 32.4595700, 35.4151600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112818, 'Al Jalamah', 'Al Jalamah', 'Al Jalamah,Jalama,Jalamah,aljlmt,الجلمة', 32.5082100, 35.3131700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112819, 'Jaba‘', 'Jaba`', 'Geva`,Geva‘,Jaba`,Jaba‘,Jeba,جبع', 32.3240900, 35.2213300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112820, 'Jaba‘', 'Jaba`', 'Al Jaba`,Al Jaba‘,Jaba`,Jaba‘,جبع', 31.8572700, 35.2586800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112821, 'Immātīn', 'Immatin', 'Immatin,Immātīn,Um et Tin,Um et Tīn,Umm at Tin,Umm at Tīn,amatyn,إماتين', 32.1916400, 35.1583600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112822, '‘Illār', '`Illar', '`Illar,علار,‘Illār', 32.3702400, 35.1070800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112823, 'Iktābah', 'Iktabah', 'Iktaba,Iktabah,Iktābah,aktabt,إكتابة', 32.3266000, 35.0526200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112824, 'Idhnā', 'Idhna', 'Idhna,Idhnā,Idna,Idnah,Idnā,adhna,إذنا', 31.5587400, 34.9743600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112825, 'Ḩuwwārah', 'Huwwarah', 'Huwarah,Huwwara,Huwwarah,Huwwāra,hwart,حوارة,Ḩuwwārah,Ḩūwārah', 32.1522400, 35.2567300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112826, 'Ḩūsān', 'Husan', 'Husan,hwsan,حوسان,Ḩūsān', 31.7093100, 35.1347500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112827, 'Ḩizmā', 'Hizma', 'Hizma,Hizmah,hzma,حزما,Ḩizmah,Ḩizmā', 31.8333700, 35.2631500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112828, 'Ḩāris', 'Haris', 'Haris,hars,حارس,Ḩāris', 32.1142400, 35.1419200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112829, 'Ḩalḩūl', 'Halhul', 'Halhul,hlhwl,حلحول,Ḩalḩūl', 31.5802900, 35.1017800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112830, 'Ḩajjah', 'Hajjah', 'Hajja,Hajjah,Qaryat Hajja,Qaryat Hajjah,Qaryat Ḩajjah,hjt,حجة,Ḥajja,Ḩajjah', 32.2042700, 35.1307700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112831, 'Ḩablah', 'Hablah', 'Habla,Hablah,hblt,حبلة,Ḩablah', 32.1652300, 34.9774800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112832, 'Far‘ūn', 'Far`un', 'Far`un,Far‘un,Far‘ūn,Fir`awn,Fir‘awn,فرعون', 32.2861300, 35.0232600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112833, 'Farkhah', 'Farkhah', 'Farkha,Farkhah,frkht,فرخة', 32.0687800, 35.1528600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112834, 'Faqqū‘ah', 'Faqqu`ah', 'Faqqu`a,Faqqu`ah,Faqqū‘a,Faqqū‘ah,فقوعة', 32.4899800, 35.4016300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112835, 'Faḩmah', 'Fahmah', 'Fahma,Fahmah,Faḥma,Faḩmah,fhmt,فحمة', 32.3829100, 35.1791200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112836, 'Dūrā al Qar‘', 'Dura al Qar`', 'Dura al Qar`,Dura el Qar`,Dūrā al Qar‘,Dūrā el Qar‘,دورا قرع', 31.9586300, 35.2271400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112837, 'Dūrā', 'Dura', 'Dura,Durah,Dury,Dūrah,Dūrā,dwra,Дуры,دورا', 31.5077700, 35.0292900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112838, 'Domea', 'Domea', 'Doma,Domea,Duma,Dumah,Dōma,Dūmah,Dūmā,dwma,دوما', 32.0563200, 35.3670500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112839, 'Dhannābah', 'Dhannabah', 'Dannaba,Dannabah,Dannāba,Dannābah,Dhannabah,Dhannābah', 32.3134100, 35.0414400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112840, 'Dayr Sharaf', 'Dayr Sharaf', 'Dayr Sharaf,Deir Sharaf,dyr shrf,دير شرف', 32.2532600, 35.1889300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112841, 'Dayr Qiddīs', 'Dayr Qiddis', 'Dayr Qaddis,Dayr Qaddīs,Dayr Qiddis,Dayr Qiddīs,Deir Qaddis,dyr qdys,دير قديس', 31.9486200, 35.0443700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112842, 'Dayr Jarīr', 'Dayr Jarir', 'Dayr Jarir,Dayr Jarīr,Deir Jarir,Deir Jarīr,dyr jryr,دير جرير', 31.9663600, 35.2926100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112843, 'Dayr Istiyā', 'Dayr Istiya', 'Dayr Istiya,Dayr Istiyā,Dayr Istya,Dayr Istyā,Deir Istiya,Deir Istiyā,Deir Istya,dyr astya,دير إستيا', 32.1309600, 35.1396300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112844, 'Dayr Ibzī‘', 'Dayr Ibzi`', 'Dayr Ibzi`,Dayr Ibzī‘,Deir Ibzi`,Deir Ibzī‘,دير إبزيع', 31.9172700, 35.1210500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112845, 'Dayr Dibwān', 'Dayr Dibwan', 'Dayr Dibwan,Dayr Dibwān,Deir Dibwan,Deir Dibwān,Dier Dibwan,dyr dbwan,دير دبوان', 31.9111200, 35.2666100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112846, 'Dayr Ballūţ', 'Dayr Ballut', 'Dair Balut,Dayr Ballut,Dayr Ballūţ,Deir Ballut,Deir Balluṭ,dyr blwt,دير بلوط', 32.0655100, 35.0245100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112847, 'Dayr as Sūdān', 'Dayr as Sudan', 'Dayr as Sudan,Dayr as Sūdān,Deir as Sudan,Deir es Sudan,Deir es Sūdān,dyr alswdan,دير السودان', 32.0321300, 35.1484500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112848, 'Dayr al Ḩaţab', 'Dayr al Hatab', 'Dayr al Hatab,Dayr al Ḩaţab,Deir al Hatab,Deir el Hatab,dyr alhtb,دير الحطب', 32.2173400, 35.3212700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112849, 'Dayr al Ghuşūn', 'Dayr al Ghusun', 'Dayr al Ghusn,Dayr al Ghusun,Dayr al Ghuşn,Dayr al Ghuşūn,Dayr al-Ghuson,Dayr al-Ghusoun,Deir Al Ghusoon,Deir al Ghusan,Deir al Ghusun,Deir el Ghusun,Deir el Ghuṣūn,dyr alghswn,دير الغصون', 32.3524400, 35.0768900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112850, 'Dayr Abū Mash‘al', 'Dayr Abu Mash`al', 'Dayr Abu Mash`al,Dayr Abū Mash‘al,Deir Abu Mash`al,Deir Abu Mash‘al,دير أبو مشعل', 31.9988100, 35.0684400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112851, 'Dayr Abū Ḑa‘īf', 'Dayr Abu Da`if', 'Dayr Abu Da`if,Dayr Abū Ḑa‘īf,Deir Abu Da`if,Deir Abū Ḍa‘īf,دير أبو ضعيف', 32.4560100, 35.3616400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112852, 'Brūqīn', 'Bruqin', 'Bruqin,Brūqīn,Burgin,Burgīn,Burqayn,Burqin,Burqīn,brwqyn,بروقين', 32.0721600, 35.0994300, 'PS', '2013-03-27', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112853, 'Birqīn', 'Birqin', 'Birqin,Birqīn,Burqin,Burqīn,brqyn,برقين', 32.4546100, 35.2607600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112854, 'Burqah', 'Burqah', 'Burqa,Burqah,Burqā,brqt,برقة', 32.3017700, 35.1926300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112855, 'Burqah', 'Burqah', 'Burqa,Burqah,Burqā,brqt,برقة', 31.8968200, 35.2543000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112856, 'Būrīn', 'Burin', 'Burin,Būrīn,bwryn,بورين', 32.1845200, 35.2501500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112857, 'Budrus', 'Budrus', 'Bodros,Budrus,bdrs,بدرس', 31.9668700, 34.9942500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112858, 'Bīr Zayt', 'Bir Zayt', 'Az Zayt,Bi''r az Zayt,Bir Zayt,Bir Zeit,Bir Ziet,Birzeit,Bi’r az Zayt,Bīr Zayt,Bīr Zeit,byr zyt,بير زيت', 31.9695900, 35.1940800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112859, 'Bīr Nabālā', 'Bir Nabala', 'Bi''r Nabala,Bir Nabala,Bi’r Nabālā,Bīr Nabālā,byr nbala,بير نبالا', 31.8508000, 35.2036000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112860, 'Bil‘īn', 'Bil`in', 'Bil`in,Bil‘īn,بلعين', 31.9283500, 35.0720400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112861, 'Biddū', 'Biddu', 'Beddo,Biddu,Biddū,Bidu,bdw,بدو', 31.8347800, 35.1494700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112862, 'Bidyā', 'Bidya', 'Bedia,Biddiya,Biddiyā,Biddya,Biddyā,Bidia,Bidieh,Bidiye,Bidya,Bidyā,Biryah,bdya,بديا', 32.1146000, 35.0802800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112863, 'Bazzāryah', 'Bazzaryah', 'Bazariya,Bazariyah,Bazzariya,Bazzariyah,Bazzaryah,Bazzāriya,Bazzāryah,Bazzārīyah,Bazāriya,Bazārīyah,bzaryh,بزاريه', 32.3079800, 35.1659300, 'PS', '2013-05-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112864, 'Bayt Wazan', 'Bayt Wazan', 'Bayt Wazan,Beit Wazan,byt wzn,بيت وزن', 32.2310500, 35.2157600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112865, 'Bayt ‘Ūr at Taḩtā', 'Bayt `Ur at Tahta', 'Bayt `Ur,Bayt `Ur at Tahta,Bayt ‘Ūr,Bayt ‘Ūr at Taḩtā,Beit `Ur at Tahta,Beit `Ur et Tahta,Beit ‘Ur at Tahta,Beit ‘Ūr et Tahtā,بيت عور التحتا', 31.8960900, 35.0817800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112866, 'Baytūnyā', 'Baytunya', 'Baytunya,Baytūnyā,Beitunia,Beituniya,Beituniyā,Beitunya,Beitūnya,Betounia,Betunia,Bituniya,Bītuniyā,bytwnya,بيتونيا', 31.8966000, 35.1704800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112867, 'Bayt Imrīn', 'Bayt Imrin', 'Bayt Imrin,Bayt Imrīn,Bayt Umrin,Bayt Umrīn,Beit Umrin,Beit Umrīn,byt amryn,بيت إمرين', 32.2930100, 35.2161000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112868, 'Bayt Sūrīk', 'Bayt Surik', 'Bayt Surik,Bayt Sūrīk,Beit Surik,Beit Sūrīk,byt swryk,بيت سوريك', 31.8242400, 35.1493600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112869, 'Bayt Sīrā', 'Bayt Sira', 'Bayt Sira,Bayt Sīrā,Beit Sira,Beit Sīrā,byt syra,بيت سيرا', 31.8878000, 35.0462300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112870, 'Bayt Sāḩūr', 'Bayt Sahur', 'Bayt Sahur,Bayt Sāḩūr,Beit Sahur,Beit Saḥūr,Bettsahour,Haql ar Ru`ah,Haql ar Ru`at,Haql er Ru`at,byt sahwr,بيت ساحور,حقل الرعاة,Ḥaql er Ru‘āt,Ḩaql ar Ru‘āh,Ḩaql ar Ru‘āt', 31.7009500, 35.2263100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112871, 'Bayt Qād', 'Bayt Qad', 'Bayt Qad,Bayt Qād,Beit Qad,Beit Qād,byt qad,بيت قاد', 32.4696800, 35.3562600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112872, 'Bayt Liqyā', 'Bayt Liqya', 'Bayt Liqya,Bayt Liqyā,Beit Liqya,Beit Liqyā,Biet Liqia,Likia,byt lqya,بيت لقيا', 31.8695800, 35.0654000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112873, 'Bayt Līd', 'Bayt Lid', 'Bayt Lid,Bayt Līd,Beit Leed,Beit Lid,Beit Līd,byt lyd,بيت ليد', 32.2608900, 35.1316900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112874, 'Bethlehem', 'Bethlehem', 'Bayt Lahm,Bayt Laḩm,Beit Lahm,Beit Lehem,Beitheal,Belem,Belen,Belen de Juda,Belém,Belén,Belén de Judá,Bet-Lehem,Bet-Leĥem,Bethleem,Bethleem Efrata,Bethlehem,Bethléem,Betlehem,Betlejem,Betlem,Betlemme,Betleyem,Bètleyèm,Vifleem,bedeullehem,beit-lahmi,betsurehemu,bo li heng,byt lhm,Βηθλεέμ,Вифлеем,Віфлеєм,בית לחם,بيت لحم,ბეით-ლაჰმი,ベツレヘム,伯利恆,베들레헴', 31.7048700, 35.2037600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112875, 'Bayt Kāḩil', 'Bayt Kahil', 'Bayt Kahil,Bayt Kāḩil,Beit Kahil,Beit Kāḥil,byt kahl,بيت كاحل', 31.5701100, 35.0650200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112876, 'Bayt Jālā', 'Bayt Jala', 'Bayt Jala,Bayt Jālā,Beit Jala,Beit Jālā,byt jala,بيت جالا', 31.7154500, 35.1878800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112877, 'Bayt ‘Anān', 'Bayt `Anan', 'Bayt `Anan,Bayt `Inan,Bayt ‘Anān,Bayt ‘Inān,Beit I`nan,Beit I‘nān,بيت عنان', 31.8506900, 35.1124800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112878, 'Baytīn', 'Baytin', 'Baytin,Baytīn,Beitin,Beitīn,Bethel,Bitayn,bytyn,بيتين', 31.9267400, 35.2409800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112879, 'Bayt Ūmmar', 'Bayt Ummar', 'Bayt Immar,Bayt Ummar,Bayt `Umar,Bayt Ūmmar,Bayt ‘Umar,Beit Immar,Beit Ummar,byt awmr,بيت أومر', 31.6232900, 35.1044600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112880, 'Al Ittiḩād', 'Al Ittihad', 'Al Ittihad,Al Ittiḩād,Baytillu,Baytillū,Beitillu,alathad,bytllw,الاتحاد,بيتللو', 31.9755200, 35.1159500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112881, 'Bayt Iksā', 'Bayt Iksa', 'Bayt Iksa,Bayt Iksā,Beit Iksa,Beit Ixxa,byt aksa,بيت إكسا', 31.8173200, 35.1793400, 'PS', '2012-12-12', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112882, 'Bayt Ībā', 'Bayt Iba', 'Bayt Iba,Bayt Ībā,Beit Iba,Beit Ība,byt ayba,بيت إيبا', 32.2371900, 35.2097700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112883, 'Bayt Fūrīk', 'Bayt Furik', 'Bayt Furik,Bayt Fūrīk,Bayt Nurik,Bayt Nūrīk,Beit Furik,Beit Fūrīk,byt fwryk,بيت فوريك', 32.1768900, 35.3354100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112884, 'Bayt Fajjār', 'Bayt Fajjar', 'Bayt Fajjar,Bayt Fajjār,Beit Fajjar,Beit Fajjār,byt fjar,بيت فجار', 31.6244300, 35.1545700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112885, 'Bayt Duqqū', 'Bayt Duqqu', 'Bayt Duqqu,Bayt Duqqū,Beit Duqqu,byt dqw,بيت دقو', 31.8591100, 35.1312400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112886, 'Bayt Dajan', 'Bayt Dajan', 'Bayt Dajan,Beit Dajan,byt djn,بيت دجن', 32.1930300, 35.3712700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112887, 'Bayt Ūlā', 'Bayt Ula', 'Bayt Aula,Bayt Awla,Bayt Awlā,Bayt Ula,Bayt Ūlā,Beit Aula,Beit Aulā,Beit Ula,Beitula,byt awla,بيت أولا', 31.5961800, 35.0296000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112888, 'Baytā al Fawqā', 'Bayta al Fawqa', 'Bayta al Fawqa,Baytā al Fawqā,Beita al Fauqa,Beita el Fauqa', 32.1426000, 35.2877400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112889, 'Battīr', 'Battir', 'Battir,Battīr,Betar,btyr,بتير', 31.7194500, 35.1410300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112890, 'Barţa‘ah ash Sharqīyah', 'Barta`ah ash Sharqiyah', 'Barta`ah ash Sharqiyah,Barţa‘ah ash Sharqīyah,Khirbat Barta`a,Khirbat Barta`ah,Khirbat Barţa‘ah,Khirbat Barṭa‘a,برطعة الشرقية', 32.4730400, 35.0936000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112891, 'Bardalah', 'Bardalah', 'Bardala,Bardalah,brdlt,بردلة', 32.3863200, 35.4808400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112892, 'Bāqah ash Sharqīyah', 'Baqah ash Sharqiyah', 'Baqa ash Sharqiya,Baqa esh Sharqiya,Baqah ash Sharqiyah,Baqat ash Sharqiyah,Bāqa esh Sharqiya,Bāqah ash Sharqīyah,Bāqat ash Sharqīyah,baqt alshrqyt,باقة الشرقية', 32.4103200, 35.0705400, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112893, 'Bāqat al Ḩaţab', 'Baqat al Hatab', 'Baka,Baqa,Baqah,Baqat al Hatab,Bāqa,Bāqah,Bāqat al Ḩaţab,baqt alhtb,باقة الحطب', 32.2043400, 35.1143300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112894, 'Banī Na‘īm', 'Bani Na`im', 'Bani Na`im,Banī Na‘īm,بني نعيم', 31.5159100, 35.1641600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112895, 'Balāţah', 'Balatah', 'Balata,Balatah,Balāta,Balāţah', 32.2120700, 35.2856100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112896, 'Bal‘ā', 'Bal`a', 'Bal`a,Bal`ah,Bal‘ah,Bal‘ā,بلعا', 32.3339200, 35.1116000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112897, '‘Azzūn', '`Azzun', '`Azzun,عزون,‘Azzūn', 32.1749600, 35.0575200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112898, 'Az Zāwiyah', 'Az Zawiyah', 'Az Zawiyah,Az Zāwiyah,Ez Zawiya,Ez Zawye,Ez Zāwiya,Ez Zāwye,Zawiya,Zawiyah,Zāwiya,Zāwiyah,alzawyt,الزاوية', 32.0962700, 35.0398200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112899, 'Az̧ Z̧āhirīyah', 'Az Zahiriyah', 'Ad Dahiriyah,Adh Dhahiriya,Az Zahiriyah,Az̧ Z̧āhirīyah,Aḑ Ḑāhirīyah,Debir,Devir,Devīr,Dhahiriya,Dhāhirīya,Ed Dhaherie,Edh Dhahiriya,Edh Dhahriye,Edh Dhairiya,Edh Dhāhrīye,Edh Dhāiriya,El Dahaheriya,Eḍh Ḍhāhiriya,alzahryt,الظاهرية', 31.4096700, 34.9732900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112900, 'Az Zabābidah', 'Az Zababidah', 'Az Zababida,Az Zababidah,Az Zababide,Az Zabābidah,Ez Zababida,Ez Zabābida,Zababida,Zabābida,alzbabdt,الزبابدة', 32.3866500, 35.3241100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112901, '‘Azmūţ', '`Azmut', '`Azmut,عزموط,‘Azmūţ', 32.2229700, 35.3098900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112902, '‘Ayn Yabrūd', '`Ayn Yabrud', 'Yabrud,Yabrūd,`Ain Yabrud,`Ayn Yabrud,`Ein Yabrud,عين يبرود,‘Ain Yabrūd,‘Ayn Yabrūd,‘Ein Yabrūd', 31.9491800, 35.2512200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112903, '‘Ayn ‘Arīk', '`Ayn `Arik', '`Ain `Arik,`Ayn `Arik,`Ein `Arik,عين عريك,‘Ain ‘Arīk,‘Ayn ‘Arīk,‘Ein ‘Arīk', 31.9061300, 35.1425400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112904, '‘Aynabūs', '`Aynabus', '`Aynabus,`Einabus,عينبوس,‘Aynabūs,‘Einabūs', 32.1470600, 35.2451300, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112905, 'Usarin', 'Usarin', 'Ausarin,Auṣarīn,Aw Sarin,Aw Şarīn,Osarin,Osarīn,Usarin,awsryn,Ūşarīn,أوصرين', 32.1249900, 35.3099900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112906, '‘Awartā', '`Awarta', '`Awarta,عورتا,‘Awartā', 32.1610800, 35.2838800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112907, 'Aţ Ţīrah', 'At Tirah', 'At Tira,At Tirah,Aţ Ţīrah,Et Tira,Et Tīra,Khirbat et Tira,Khirbat eṭ Ṭira,Tira,Tireh,altyrt,الطيرة', 31.8702200, 35.1268200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112908, '‘Attīl', '`Attil', '`Attil,عتيل,‘Attīl', 32.3693500, 35.0718900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112909, 'Aţ Ţaybah', 'At Taybah', 'At Taybah,At Tayyibah,Aţ Ţaybah,Aţ Ţayyibah,Et Taiyiba,Khirbat at Tayyibah,Khirbat aţ Ţayyibah,Khirbet at Taiyiba,altybt,الطيبة', 32.5149400, 35.1857400, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112910, 'Aţ Ţaybah', 'At Taybah', 'At Taiyiba,At Taybah,At Tayyiba,At Tayyibah,Aţ Ţaybah,Aţ Ţayyibah,Aţ Ţayyibā,El Taiyiba,El Ṭaiyibā,Et Taiyiba,Et Taiyibe,Et Tayyibeh,Ophrah,Taiyiba,Taiyibi,`Ofra,altybt,الطيبة,Ṭaiyiba,‘Ofrā', 31.9538800, 35.2998000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112911, '‘Aţārah', '`Atarah', 'Ain `Atara,Ain ‘Atāra,`Atarah,`Attara,`Attarah,عطارة,‘Attāra,‘Aţārah,‘Aţţārah', 32.0005800, 35.2046600, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112912, 'As Sāwiyah', 'As Sawiyah', 'As Sawiya,As Sawiyah,As Sāwiyah,Es Sawiya,Es Sāwiya,alsawyt,الساوية', 32.0853700, 35.2578200, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112913, 'As Samū‘', 'As Samu`', 'Al-Samou'',Al-Samou’,As Samu`,As Samū‘,As-Samu,Es Samu`,Es Samū‘,Eshtemoa`,Eshtemoa‘,Samu''a,al-Samu'',السموع', 31.3967100, 35.0661100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112914, '‘Aşīrah ash Shamālīyah', '`Asirah ash Shamaliyah', 'As Sira ash Shamaliyah,Asira ash Shamaliya,Aş Şīrā ash Shamālīyah,`Asira,`Asira esh Shamaliya,`Asira esh Shamaliye,`Asirah ash Shamaliyah,عصيرة الشمالية,‘Asira,‘Asīra esh Shamālīye,‘Aşīrah ash Shamālīyah,‘Aṣīra esh Shamālīya', 32.2512400, 35.2671600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112915, '‘Aşīrah al Qiblīyah', '`Asirah al Qibliyah', 'Hatserot,Hatsērōt,Kiblie,Kibliyeh,`Asira al Qibliya,`Asira el Qibliya,`Asira el Qibliye,`Asirah al Qibliyah,عصيرة القبلية,‘Asīra al Qiblīya,‘Asīra el Qiblīya,‘Asīra el Qiblīye,‘Aşīrah al Qiblīyah', 32.1784200, 35.2156900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112916, 'Ash Shuyūkh', 'Ash Shuyukh', 'Ash Shuyukh,Ash Shuyūkh,Esh Shuyukh,Esh Shuyūkh,Shuyukh,Shūyūkh,alshywkh,الشيوخ', 31.5700400, 35.1560600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112917, 'Ash Shuhadā’', 'Ash Shuhada''', 'Ash Shuhada'',Ash Shuhadā’,Esh Shuhada,Esh Shuhadā,الشهداء', 32.4294900, 35.2711200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112918, 'Arţās', 'Artas', 'Artas,Artasium,Arţās,Ertas,artas,أرطاس', 31.6893900, 35.1868100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112919, 'Ar Rīḩīyah', 'Ar Rihiyah', 'Ar Rihiya,Ar Rihiyah,Ar Rīḩīyah,Barta''a,Barta’a,Er Rihiya,Er Rīhīya,Rihiya,Rīhīya,alryhyt,الريحية', 31.4695000, 35.0778100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112920, '‘Arrānah', '`Arranah', '`Arrana,`Arranah,عرانة,‘Arrāna,‘Arrānah', 32.4972000, 35.3227100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112921, 'Ar Rām wa Ḑāḩiyat al Barīd', 'Ar Ram wa Dahiyat al Barid', 'Ar Ram,Ar Ram wa Dahiyat al Barid,Ar Rām,Ar Rām wa Ḑāḩiyat al Barīd,Er Ram,Er Rām,Ram,Rām,alram wdahyt albryd,الرام وضاحية البريد', 31.8494500, 35.2342000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112922, '‘Arrābah', '`Arrabah', 'Arabeh,`Arava,`Arraba,`Arrabah,`Arrabe,عرابة,‘Arrāba,‘Arrābah,‘Arrābe,‘Arāvā', 32.4051700, 35.2018900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112923, 'Jericho', 'Jericho', 'Ariha,Arīḩā,Cherico,Chericó,Eriha,Erihon,Erīha,Gerico,Gorad Ierykhon,Iericho,Ierihon,Ierikhon,Ireacho,Ireachó,Jeeriko,Jerichas,Jericho,Jerico,Jericó,Jeriho,Jerihon,Jerika,Jerikhon,Jeriko,Jerikó,Jeriĥo,Jerycho,Jéricho,Jērika,Xerico,Xericó,Yeriho,Yerikho,Yeriko,Yerīhō,Yirihu,Yirīḩū,aryha,erikko,eriko,ierikoni,jie li ke,yeliko,yryhw,Ιεριχώ,Єрихон,Јерихон,Горад Іерыхон,Иерихон,Йерихон,יריחו,أريحا,اریحا,ܐܝܪܝܚܘ,எரிக்கோ,იერიქონი,ኢያሪኮ,エリコ,杰里科,예리코,', 31.8666700, 35.4500000, 'PS', '2007-07-16', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112924, 'Al ‘Araqa', 'Al `Araqa', 'Al `Araqa,Al ‘Araqa,Arrakah,El `Araqa,El ‘Araqa,`Araqa,`Araqah,`Arraqa,العرقة,‘Araqa,‘Araqah,‘Arrāqa', 32.4705700, 35.2002700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112925, '‘Aqrabā', '`Aqraba', '`Aqraba,`Aqrabe,عقربا,‘Aqraba,‘Aqrabe,‘Aqrabā', 32.1249500, 35.3454700, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112926, '‘Anzah', '`Anzah', '`Anza,`Anzah,عنزة,‘Anza,‘Anzah', 32.3591600, 35.2201100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112927, 'An Nuway‘imah', 'An Nuway`imah', 'An Nuway`imah,An Nuway‘imah,Nu''eima,Nu`aymah,Nu‘aymah,Nu’eima,`Ain Nuwi`ima,`Ayn Nuwi`imah,النويعمة,‘Ain Nuwi‘ima,‘Ayn Nuwi‘imah', 31.8921200, 35.4354900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112928, 'An Nazlah ash Sharqīyah', 'An Nazlah ash Sharqiyah', 'An Nazla ash Sharqiya,An Nazlah ash Sharqiyah,An Nazlah ash Sharqīyah,An Nazlat ash Sharqiyah,An Nazlat ash Sharqīyah,En Nazla ash Sharqiya,En Nazla esh Sharqiya,alnzlt alshrqyt,النزلة الشرقية', 32.4107200, 35.1091600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112929, 'An Nāqūrah', 'An Naqurah', 'An Maqurah,An Māqūrah,An Naqura,An Naqurah,An Nāqūrah,En Naqura,En Nāqūra,Naqura,Naqūra,alnaqwrt,الناقورة', 32.2650600, 35.2013500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112930, 'An Nabī Ilyās', 'An Nabi Ilyas', 'An Nabi Ilyas,An Nabī Ilyās,En Nabi Elyas,En Nabi Ilyas,En Nabī Elyās,En Nabī Ilyās,alnby alyas,النبي إلياس', 32.1848200, 35.0176000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112931, '‘Anīn', '`Anin', '`Anin,عنين,‘Anīn', 32.5025900, 35.1666800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112932, '‘Anātā', '`Anata', '`Anata,`Anatot,عناتا,‘Anātā,‘Anātōt', 31.8092400, 35.2590200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112933, '‘Anabtā', '`Anabta', '`Anabta,`Anabtah,`Anebta,عنبتا,‘Anabtah,‘Anabtā,‘Anebta', 32.3079200, 35.1169300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112934, 'Al Yāmūn', 'Al Yamun', 'Al Yamoun,Al Yamun,Al Yāmūn,Alyamoun,El Yamun,El Yāmūn,Yamun,Yāmūn,alyamwn,اليامون', 32.4856300, 35.2301100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112935, 'Al Qubaybah', 'Al Qubaybah', 'Al Qubaybah,Al Qubeiba,El Qubeiba,Qubeiba,alqbybt,القبيبة', 31.8388600, 35.1367800, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112936, 'Al Mughayyir', 'Al Mughayyir', 'Al Mughaiyir,Al Mughayyir,El Mughaiyir,Mughaiyir,almghyr,المغير', 32.4222800, 35.3847600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112937, 'Al Mughayyir', 'Al Mughayyir', 'Al Mughaiyir,Al Mughayir,Al Mughayyir,El Mughaiyir,El Mugheir,Mughaiyir,almghyr,المغير', 32.0192000, 35.3478300, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112938, 'Al Midyah', 'Al Midyah', 'Al Midya,Al Midyah,El Midya,Midya,Midyah,Midyā,almdyt,المدية', 31.9359200, 35.0050000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112939, 'Al Mazra‘ah ash Sharqīyah', 'Al Mazra`ah ash Sharqiyah', 'Al Mazra`ah ash Sharqiyah,Al Mazra‘ah ash Sharqīyah,El Maza''a esh Sharqiya,El Mazara`a esh Sharqiya,El Mazara‘a esh Sharqiya,El Maza’a esh Sharqīya,Mazra`a Bani Murra,Mazra`a ash Sharqiya,Mazra‘a Banī Murra,Mazra‘a ash Sharqiya,المزرعة الشرقية', 32.0001800, 35.2815200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112940, 'Az Zaytūnīyah', 'Az Zaytuniyah', 'Al Mazra`ah al Qibliyah,Al Mazra`at al Qibliyah,Al Mazra‘ah al Qiblīyah,Al Mazra‘at al Qiblīyah,Az Zaytuniyah,Az Zaytūnīyah,El Mazra`a al Qibliya,El Mazra`a el Qibliya,El Mazra‘a al Qibliya,El Mazra‘a el Qibliya,Mazra`a al Qibliya,Mazra`at Bani Harith,Mazra‘a al Qibliya,Mazra‘at Bani Hārith,alzytwnyt,الزيتونية,المزرعة القبلية', 31.9540300, 35.1624000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112941, 'Al Lubban al Gharbī', 'Al Lubban al Gharbi', 'Al Lubban,Al Lubban al Gharbi,Al Lubban al Gharbī,El Lubban,Lubban,Lubban Rantis,Lubban Rantīs,allbn alghrby,اللبن الغربي', 32.0350400, 35.0392800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112942, 'Al Khaḑir', 'Al Khadir', 'Al Khadir,Al Khadr,Al Khaḑir,Al Khidr,Al Khiḑr,El Khader,El Khadr,Khadr,Khaḍr,alkhdr,الخضر', 31.6940500, 35.1668500, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112943, 'Hebron', 'Hebron', 'Al Khalil,Al Khalīl,Al-Khalil,Chevrona,El Halil,El Khalil,El Khulil,Gorad Kheuron,Habrun,Hebrom,Hebron,Hebronas,Hebroni,Hebrón,Hevron,Hevrōn,Hébron,Khalil'',Khalil-el-Rahman,Khebron,Khevron,alkhlyl,epiron,hbrwn,hebarana,hebeulon,hebrona,heburon,hi brxn,xi bo lun,Əl Xəlil,Χεβρώνα,Горад Хеўрон,Халиль,Хеброн,Хеврон,Әл-Халил,חברון,الخليل,الخلیل,हेब्रॉन,হেবরন,எபிரோன்,ฮีบรอน,ኬብሮን,Ḩabrūn,ヘブロン,希伯仑,헤브론', 31.5293500, 35.0938000, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112944, 'Al Judayrah', 'Al Judayrah', 'Al Judayrah,Judayrah,Judeira,Judira,Judirah,Judīra,Judīrah,aljdyrt,الجديرة', 31.8558700, 35.1970600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112945, 'Al Jīb', 'Al Jib', 'Al Jib,Al Jīb,El Jib,El Jīb,Jib,Jīb,aljyb,الجيب', 31.8520300, 35.1845100, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112946, 'Al Jāniyah', 'Al Janiyah', 'Al Janiya,Al Janiyah,Al Jāniyah,El Janiya,El Jāniya,Janiyah,Jāniyah,aljanyt,الجانية', 31.9384800, 35.1214200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112947, 'Al Hāshimīyah', 'Al Hashimiyah', 'Al Barid,Al Bārid,Al Hashimiyah,Al Hāshimīyah,El Barid,El Bārid,El Hashimiya,El Hāshimiya,alhashmyt,الهاشمية', 32.4639200, 35.2193800, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112948, 'Al Faşāyil', 'Al Fasayil', 'Al Fasa''il,Al Fasayil,Al Faşāyil,Al Faşā’il,El Fasayil,El Faṣāyil,Paza''el,Paza’el,alfsayl,الفصايل', 32.0250900, 35.4435100, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112949, 'Al Fandaqūmīyah', 'Al Fandaqumiyah', 'Al Fandaqumiya,Al Fandaqumiyah,Al Fandaqūmīyah,El Fandaqumiya,El Fandaqumiye,El Fandaqūmiya,El Fandaqūmīye,Fandaqumiya,Fandaqumiye,Fandaqūmīya,Fandaqūmīye,Fendakumie,Fendakumiyeh,Pentakomia,Pundaqa,alftdqwmyt,الفتدقومية', 32.3206000, 35.2032900, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112950, 'Al Bīrah', 'Al Birah', 'Al Bira,Al Birah,Al Bīrah,Al''-Bira,Be-erot,Be-eroth,Be-ērot,Be-ēroth,Bira,Birah,Bire,Bīra,Bīrah,Bīre,El Bira,El Bīra,albyrt,Аль-Бира,البيرة', 31.9100100, 35.2164500, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112951, 'Al ‘Ayzarīyah', 'Al `Ayzariyah', 'Aizaria,Al `Ayzariyah,Al `Eizariya,Al ‘Ayzarīyah,Al ‘Eizariya,Bethany,El `Eizariye,El ‘Eizarīye,`Eizariya,العيزرية,‘Eizarīya', 31.7707800, 35.2691700, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112952, 'Al ‘Awjā', 'Al `Awja', 'Al `Auja,Al `Awja,Al `Awja'',Al ‘Auja,Al ‘Awjā,Al ‘Awjā’,El ''Auja,El ’Aujā,`Auja el Fauqa,العوجا,‘Aujā el Fauqā', 31.9506900, 35.4675600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112953, 'Al ‘Aţţārah', 'Al `Attarah', 'Al `Attara,Al `Attarah,Al ‘Attara,Al ‘Aţţārah,El `Attara,El ‘Aţţāra,`Attara,العطارة,‘Aṭṭāra', 32.3257100, 35.1637300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112954, '‘Ajjūl', '`Ajjul', '`Ajjul,عجول,‘Ajjūl', 32.0223200, 35.1796900, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112955, '‘Ajjah', '`Ajjah', '`Ajja,`Ajjah,عجة,‘Ajja,‘Ajjah', 32.3607400, 35.1959000, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112956, '‘Ibwayn', '`Ibwayn', '`Abwayn,`Abwein,`Ibwayn,`Ibwein,عبوين,‘Abwayn,‘Abwein,‘Ibwayn,‘Ibwein', 32.0314400, 35.1999200, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112957, 'Abū Qashsh', 'Abu Qashsh', 'Abu Qash,Abu Qashsh,Abū Qash,Abū Qashsh,abw qsh,أبو قش', 31.9488300, 35.1842600, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112958, 'Abū Dīs', 'Abu Dis', 'Abu Dis,Abū Dīs,abw dys,أبو ديس', 31.7621500, 35.2616600, 'PS', '2012-02-28', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112959, '‘Ābūd', '`Abud', '`Abud,عابود,‘Ābūd', 32.0163700, 35.0683300, 'PS', '2012-01-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112960, 'Old City', 'Old City', 'alqds alqdymt,القدس القديمة', 31.7766700, 35.2341700, 'PS', '2016-02-22', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112961, 'An Naşr', 'An Nasr', 'Al Bayk,Al Bayuk,Al Bayūk,An Nasr,An Naşr,albywk,alnsr,البيوك,النصر', 31.2813700, 34.3025300, 'PS', '2015-09-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112962, '‘Abasān al Jadīdah', '`Abasan al Jadidah', '`Abasan al Jadida,`Abasan al Jadidah,`Abasan as Saghirah,عبسان الجديدة,عبسان الصغيرة,‘Abasan al Jadida,‘Abasān al Jadīdah,‘Abasān aş Şaghīrah', 31.3415800, 34.3459200, 'PS', '2012-01-20', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112963, 'Al Qarārah', 'Al Qararah', 'Al Qarara,Al Qararah,Al Qarārah,alqrart,القرارة', 31.3738900, 34.3408500, 'PS', '2013-10-30', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112964, 'Umm an Naşr', 'Umm an Nasr', 'Al Qaryah al Badawiyah al Maslakh,Umm an Nasr,Umm an Naşr,alqryt albdwyt almslkh,am alnsr,أم النصر,القرية البدوية المسلخ', 31.5608500, 34.5186300, 'PS', '2012-01-20', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112965, 'Juḩr ad Dīk', 'Juhr ad Dik', 'Juhor ad Dik,Juhr ad Dik,Juḩr ad Dīk,jhr aldyk,جحر الديك', 31.4557100, 34.4371900, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112966, 'Az Zuwāydah', 'Az Zuwaydah', 'Alzwaydt,Ar Ruwaydah,Az Zuwaydah,Az Zuwāydah,alzwaydt,الزوايدة', 31.4395400, 34.3805300, 'PS', '2013-11-08', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112967, 'Al Muşaddar', 'Al Musaddar', 'Al Musaddar,Al Muşaddar,almsdr,المصدر', 31.4105200, 34.3780200, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112968, 'Wādī as Salqā', 'Wadi as Salqa', 'Wadi as Salga,Wadi as Salqa,Wādī as Salgā,Wādī as Salqā,wady alslqa,وادي السلقا', 31.4004800, 34.3375400, 'PS', '2015-09-18', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112969, 'Al Mughrāqah', 'Al Mughraqah', 'Abu Mudayin,Abū Mudayin,Al Mughraqah,Al Mughrāqah,abw mdyn,almghraqh,ابو مدين,المغراقه', 31.4658700, 34.4120800, 'PS', '2012-02-02', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112970, 'East Jerusalem', 'East Jerusalem', 'Aust-Jerusalem,Baitulmuqaddis Timur,Dogu Kudues,Doğu Kudüs,Ekialdeko Jerusalem,GJong Jerusalem,Gerusalemme Est,Ida-Jeruusalemm,Istochen Erusalim,Istocni Jerusalem,Istocni Jeruzalem,Istočni Jerusalem,Istočni Jeruzalem,Iztochen Jerusalim,Jerusalem East,Jerusalem Est,Jerusalem Oriental,Jerusalem-Est,Jerusalen Este,Jerusalèm Èst,Jerusalém Oriental,Jerusalén Este,Jérusalem-Est,OEstra Jerusalem,Oost-Jeruzalem,Orienta Jerusalemo,Ost-Jerusalem,Ostjerusalem,Skhidnij Erusalim,Urselime Rocvetisi,Urşelimê Rocvetışi,Uskhodni Ierusalim,Vostochnyj Ierusalim,Vychodni Jeruzalem,Východní Jeruzalém,Wschodnia Jerozolima,Yerusalem Timur,Yerusalem Wetan,Yerusalem Wétan,Yerusalemu ya Mashariki,Yerushalayim Oryentala,alqds alshrqyt,dong ye lu sa leng,dong-yelusallem,dongerusaremu,kilakku erucalem,mshrqy yrwshlm,mzrh yrwslym,qds shrqy,ye ru sa lem tawan xxk,Östra Jerusalem,Øst-Jerusalem,Østjerusalem,Đông Jerusalem,Şərqi Qüds,Восточный Иерусалим,Източен Йерусалим,Источен Ерусалим,Малхбален Къудс-ГӀала,Східний Єрусалим,Усходні Іерусалім,מזרח ירושלים,القدس الشرقية,قدس شرقی,مشرقی یروشلم,கிழக்கு எருசலேம்,കിഴക്കൻ ജറൂസലേം,เยรูซาเลมตะวันออก,东耶路撒冷,東エルサレム,동예루살렘', 31.7833600, 35.2338800, 'PS', '2016-02-22', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112971, 'Karney Shomron', 'Karney Shomron', '', 32.1714000, 35.0976700, 'PS', '2010-09-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112972, 'al-Kum', 'al-Kum', 'Alkoum', 31.5312300, 34.9606400, 'PS', '2016-12-10', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112973, 'Azun Atme', 'Azun Atme', '''Azzun ''Atma,Azoon Atmah,Azoon Atmeh', 32.1216700, 35.0203600, 'PS', '2012-12-12', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112974, 'Jinşāfūţ', 'Jinsafut', 'Jinsafut,Jinşāfūţ,jnsafwt,جنصافوط', 32.1791600, 35.1303800, 'PS', '2012-12-12', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112975, 'Banī Zayd', 'Bani Zayd', 'Bani Zayd,Banī Zayd,bny zyd,بني زيد', 32.0392400, 35.1031600, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112976, 'Az Za‘ayyim', 'Az Za`ayyim', 'Az Za`ayyim,Az Za‘ayyim,الزعيم', 31.7885200, 35.2651100, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112977, 'Al ‘Ubaydīyah', 'Al `Ubaydiyah', 'Al `Ubaydiyah,Al ‘Ubaydīyah,العبيدية', 31.7169700, 35.2900700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112978, 'Khallat an Nu‘mān', 'Khallat an Nu`man', 'Khallat an Nu`man,Khallat an Nu‘mān,خلة النعمان', 31.7174900, 35.2422700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112979, 'Khallat Ḩamāmah', 'Khallat Hamamah', 'Khallat Hamamah,Khallat Ḩamāmah,khlt hmamt,خلة حمامة', 31.7216000, 35.1924300, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112980, 'Ad Dawḩah', 'Ad Dawhah', 'Ad Dawhah,Ad Dawḩah,aldwht,الدوحة', 31.6994800, 35.1804700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112981, 'Wādī Raḩḩāl', 'Wadi Rahhal', 'Wadi Rahhal,Wādī Raḩḩāl,wady rhal,وادي رحال', 31.6651600, 35.1672700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112982, '‘Arab ar Rashāydah', '`Arab ar Rashaydah', '`Arab ar Rashaydah,عرب الرشايدة,‘Arab ar Rashāydah', 31.5711200, 35.2322700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112983, 'Bayt ‘Īnūn', 'Bayt `Inun', 'Bayt `Inun,Bayt ‘Īnūn,Khirbat Bayt `Anun,Khirbat Bayt `Aynun,Khirbat Bayt ‘Aynūn,Khirbat Bayt ‘Ānūn,Khirbat Beit `Anun,Khirbat Beit ‘Anun,بيت عينون', 31.5587000, 35.1244000, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112984, 'Bayt Maqdum', 'Bayt Maqdum', 'Bayt Maqdum,Bayt Maqdūm,Khirbat Bayt Maqdum,Khirbat Bayt Maqdūm,Khirbat Beit Maqdum,byt mqdwm,بيت مقدوم', 31.5353700, 34.9719200, 'PS', '2016-12-10', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112985, 'Al Buq‘ah', 'Al Buq`ah', 'Al Buq`ah,Al Buq‘ah,البقعة', 31.5419900, 35.1427900, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112986, 'Khallat ad Dār', 'Khallat ad Dar', 'Khallat ad Dar,Khallat ad Dār,khlt aldar,خلة الدار', 31.4973700, 35.1136200, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112987, 'Dayr Sāmit', 'Dayr Samit', 'Dayr Samit,Dayr Sāmit,Khirbat Dayr Samit,Khirbat Dayr Şāmit,Khirbat Deir Samit,dyr samt,دير سامت', 31.5205700, 34.9744200, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112988, 'Al Ḩīlah', 'Al Hilah', 'Al Hilah,Al Ḩīlah,alhylt,الحيلة', 31.4745400, 35.1074200, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112989, 'Aş Şūrrah', 'As Surrah', 'As Surrah,Aş Şūrrah,alswrt,الصورة', 31.4709700, 34.9989700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112990, 'Bayt ‘Amrah', 'Bayt `Amrah', 'Bayt `Amrah,Bayt ‘Amrah,Khirbat Bayt Imran,Khirbat Bayt Imrān,Khirbat Bayt `Amrah,Khirbat Bayt ‘Amrah,Khirbat Beit `Amra,Khirbat Beit `Imra,Khirbat Beit ‘Amra,Khirbat Beit ‘Imra,بيت عمرة', 31.4502000, 35.0495200, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112991, 'Rābūd', 'Rabud', 'Rabud,Rābūd,rabwd,رابود', 31.4390900, 35.0162000, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112992, 'Al Karmil', 'Al Karmil', 'Al Karmil,Kirbat al Karmil,alkrml,الكرمل', 31.4230100, 35.1327800, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112993, 'Khallat Şāliḩ', 'Khallat Salih', 'Khallat Salih,Khallat Şāliḩ,khlt salh,خلة صالح', 31.4201300, 35.1151600, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112994, 'Bīr al Bāshā', 'Bir al Basha', 'Bir al Basha,Bīr al Bāshā,byr albasha,بير الباشا', 32.4202200, 35.2301300, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112995, 'Al Bādhān', 'Al Badhan', 'Al Badhan,Al Bādhān,albadhan,الباذان', 32.2585700, 35.3324700, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112996, '‘Ayn al Bayḑā', '`Ayn al Bayda', '`Ayn al Bayda,عين البيضا,‘Ayn al Bayḑā', 32.3805100, 35.5083800, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112997, 'Az Zubaydāt', 'Az Zubaydat', 'Az Zubaydat,Az Zubaydāt,alzbydat,الزبيدات', 32.1733000, 35.5300500, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112998, 'Al Jiftlik', 'Al Jiftlik', 'Al Jiftlik,aljftlk,الجفتلك', 32.1407000, 35.4873800, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(112999, 'Khursā', 'Khursa', 'Khirbat Kharsa'',Khirbat Kharsā’,Khirbat Khursa,Khirbat Khursah,Khursa,Khursā,khrsa,خرسا', 31.4823200, 35.0174200, 'PS', '2012-01-21', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113000, 'Givat Zeev', 'Givat Zeev', 'גבעת זאב', 31.8614500, 35.1686100, 'PS', '2016-09-13', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113001, 'Oranit', 'Oranit', 'אורנית', 32.1316500, 34.9909400, 'PS', '2016-09-13', 170);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113002, 'Vila Viçosa', 'Vila Vicosa', 'Vila Vicosa,Vila Viçosa', 38.7777000, -7.4179300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113003, 'Vila Real de Santo António', 'Vila Real de Santo Antonio', 'Bila Real nte Santo Antonio,Vila Real de San Antonio,Vila Real de San António,Vila Real de Santo Antonio,Vila Real de Santo António,Βίλα Ρεάλ ντε Σάντο Αντόνιο', 37.1950000, -7.4176600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113004, 'Vila Nova de Milfontes', 'Vila Nova de Milfontes', 'Vila Nova de Milfontes', 37.7237700, -8.7827800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113005, 'Vila Nova da Barquinha', 'Vila Nova da Barquinha', 'Barquinha,Vila Nova da Barquinha', 39.4500000, -8.4333300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113006, 'Vila Franca de Xira', 'Vila Franca de Xira', 'Vila Franca de Xira', 38.9552500, -8.9896600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113007, 'Vila Flor', 'Vila Flor', '', 41.3090400, -7.1537800, 'PT', '2016-06-22', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113008, 'Vila do Bispo', 'Vila do Bispo', 'Vila do Bispo,Villa do Bispo', 37.0831700, -8.9114400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113009, 'Vila de Rei', 'Vila de Rei', 'Vila de Rei,Vila do Rei', 39.6760400, -8.1457700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113010, 'Vila de Porto Santo', 'Vila de Porto Santo', 'Porta Santa,Porto Santo,Pôrta Santa,Vila de Porto Santo', 33.0601800, -16.3341000, 'PT', '2013-03-27', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113011, 'Vieira de Leiria', 'Vieira de Leiria', 'Vieira,Vieira de Leiria', 39.8694500, -8.9323800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113012, 'Vidigueira', 'Vidigueira', 'Vidigueira', 38.2099500, -7.8005000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113013, 'Viana do Alentejo', 'Viana do Alentejo', 'Viana do Alentejo', 38.3345800, -8.0044000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113014, 'Vialonga', 'Vialonga', '', 38.8709400, -9.0682300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113015, 'Ventosa', 'Ventosa', 'Ventosa', 39.1269600, -9.0842300, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113016, 'Vendas Novas', 'Vendas Novas', 'Vendas Novas', 38.6770600, -8.4579200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113017, 'Venda do Pinheiro', 'Venda do Pinheiro', '', 38.9236500, -9.2317800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113018, 'Vale da Amoreira', 'Vale da Amoreira', '', 39.0696900, -7.6984900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113019, 'Urra', 'Urra', '', 39.2283000, -7.3985600, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113020, 'Unhos', 'Unhos', '', 38.8258900, -9.1223100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113021, 'Turquel', 'Turquel', 'Turquel', 39.4641100, -8.9774300, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113022, 'Tramagal', 'Tramagal', 'Tramagal', 39.4500000, -8.2500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113023, 'Trafaria', 'Trafaria', 'Trafaria', 38.6722200, -9.2326800, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113024, 'Torres Vedras', 'Torres Vedras', 'Lapangan Terbang Santa Cruz,Tores Vedrasas,Torres Vedras,Torresh,Torresh-Vedrash,Torrish-Vedrash,Turres Veteres,tuo lei si wei de la shen,twrs wdras,Торреш,Торреш-Ведраш,Торриш-Ведраш,تورس ودراس,ტორეშ-ვედრაში,托雷斯韋德拉什', 39.0910900, -9.2586000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113025, 'Torres Novas', 'Torres Novas', 'Torres Novas', 39.4811400, -8.5394900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113026, 'Tomar', 'Tomar', 'Tomar,Томар', 39.6019900, -8.4092400, 'PT', '2016-06-22', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113027, 'Terrugem', 'Terrugem', '', 38.7064700, -9.2869300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113028, 'Tavira', 'Tavira', 'Tabira,Tavira,Tavira Municipality,ta wei la,tavu~ira,tawyra,Ταβίρα,Тавира,Тавіра,تاویرا,ტავირა,タヴィラ,塔維拉', 37.1273400, -7.6486100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113029, 'Souto da Carpalhosa', 'Souto da Carpalhosa', 'Souto,Souto da Carpalhosa', 39.8456900, -8.8233200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113030, 'Sobreda', 'Sobreda', 'Sobreda', 38.6496100, -9.1897700, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113031, 'Sobralinho', 'Sobralinho', '', 38.9170300, -9.0265600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113032, 'Sobral de Monte Agraço', 'Sobral de Monte Agraco', 'Sobral,Sobral de Monte Agraco,Sobral de Monte Agraço', 39.0195800, -9.1508100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113033, 'Sintra', 'Sintra', 'Cintra,Sintra,shintora,Σίντρα,Синтра,シントラ', 38.8009700, -9.3782600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113034, 'Sines', 'Sines', 'SIE,Sines,Sines Municipality,Sinesh,Sinish,sayns  prtghal,shinesu,sinesi,xi ni shen,Синес,Синиш,Сінеш,ساینس، پرتغال,სინესი,シーネス,锡尼什', 37.9562200, -8.8697900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113035, 'Silves', 'Silves', 'Cilpes,Shilb,Silves', 37.1892100, -8.4382200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113036, 'Silveira', 'Silveira', '', 39.1112000, -9.3643000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113037, 'Sesimbra', 'Sesimbra', 'Cezimbra,Sesimbra,Сесимбра', 38.4445100, -9.1014900, 'PT', '2015-02-20', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113038, 'Setúbal', 'Setubal', 'Caetobriga,Gorad Setubal,Setoumpal,Setubal,Setubala,Setubalis,Setúbal,sai tu ba er,seto~ubaru,setubal,stwbal,stwbl,sux tu bal,sytwbal,Σετούμπαλ,Горад Сетубал,Сетубал,סטובל,ستوبال,سيتوبال,سیتوبال,ซือตูบัล,სეტუბალი,ሴቱባል,セトゥーバル,塞图巴尔,세투발', 38.5244000, -8.8882000, 'PT', '2012-09-18', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113039, 'Sertã', 'Serta', 'Serta,Sertã', 39.8084600, -8.0988300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113040, 'Serpa', 'Serpa', 'Serpa,Серпа', 37.9458100, -7.5975400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113041, 'Seixal', 'Seixal', 'Seixal', 38.6400800, -9.1014100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113042, 'São Vicente', 'Sao Vicente', 'San-Visente,San-Visenti,Sao Vicente,São Vicente,sheng wei sen te,Сан-Висенте,Сан-Висенти,Сан-Вісенте,聖維森特', 32.7967300, -17.0432300, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113043, 'São Teotónio', 'Sao Teotonio', 'San Teotonio,San Teotónio,Sao Teotonio,Sao Theotonio,São Teotónio,São Theotonio', 37.5128200, -8.7070800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113044, 'São Pedro da Cadeira', 'Sao Pedro da Cadeira', '', 39.0698300, -9.3717400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113045, 'São Martinho do Porto', 'Sao Martinho do Porto', 'Sao Martinho,Sao Martinho de Porto,Sao Martinho do Porto,São Martinho,São Martinho de Porto,São Martinho do Porto', 39.5144400, -9.1311100, 'PT', '2016-03-26', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113046, 'São Julião', 'Sao Juliao', '', 39.3226800, -7.3110600, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113047, 'São João dos Montes', 'Sao Joao dos Montes', '', 38.9394400, -9.0189200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113048, 'São João da Talha', 'Sao Joao da Talha', '', 38.8218300, -9.0907900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113049, 'São João das Lampas', 'Sao Joao das Lampas', '', 38.8737600, -9.3984200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113050, 'São Domingos de Rana', 'Sao Domingos de Rana', 'Domingos De Rana,Sao Domingos,Sao Domingos de Rana,São Domingos,São Domingos de Rana', 38.7012300, -9.3276000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113051, 'São Brás de Alportel', 'Sao Bras de Alportel', 'Alportel,San-Brash-de-Alportel,San-Brash-di-Alportel,Sao Bras de Alportel,Sao Braz,Sao Braz d''Alportel,Sao Braz de Aportel,São Braz,São Braz de Aportel,São Braz d’Alportel,São Brás de Alportel,sheng bu la shen di a er bo te er,Сан-Браш-де-Алпортел,Сан-Браш-ди-Алпортел,聖布拉什迪阿爾波特爾', 37.1531000, -7.8875100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113052, 'São Bartolomeu de Messines', 'Sao Bartolomeu de Messines', 'Messines,Sao Bartolomeo de Messines,Sao Bartolomeu de Messines,São Bartolomeo de Messines,São Bartolomeu de Messines', 37.2602400, -8.2867000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113053, 'Santo António da Charneca', 'Santo Antonio da Charneca', '', 38.6256100, -9.0304300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113054, 'Santo Antão do Tojal', 'Santo Antao do Tojal', 'Santo Antao,Santo Antao de Tojal,Santo Antao do Tojal,Santo Antão,Santo Antão de Tojal,Santo Antão do Tojal', 38.8515100, -9.1397500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113055, 'Santo André', 'Santo Andre', '', 39.0553200, -8.2441400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113056, 'Santo André', 'Santo Andre', '', 38.0544500, -8.7521100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113057, 'Santiago do Cacém', 'Santiago do Cacem', 'Santiago do Cacem,Santiago do Cacém,Sao Tiago de Cacem,Sao Tiago do Cacem,São Tiago de Caçem,São Tiago do Cacém', 38.0169300, -8.6947500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113058, 'Santarém', 'Santarem', 'Santarem,Santaren,Santarém,Scalabis,Σανταρέμ,Сантарен', 39.2333300, -8.6833300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113059, 'Santana', 'Santana', 'Santana,Сантана', 32.8000000, -16.8833300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113060, 'Santa Iria da Azóia', 'Santa Iria da Azoia', 'Santa Iria,Santa Iria da Azoia,Santa Iria da Azóia,Santa Iria de Azoia', 38.8462900, -9.0874800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113061, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa Krouz,Santa-Krush,Santa-Kruzh,santa krwz  madyra,santakeuluseu,sheng ke lu si,Σάντα Κρουζ,Санта-Круж,Санта-Круш,سانتا کروز، مادیرا,სანტა-კრუში,聖克魯斯,산타크루스', 32.6833300, -16.8000000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113062, 'Santa Catarina da Serra', 'Santa Catarina da Serra', 'Santa Catarina,Santa Catarina da Serra,Santa Catharina,Santa Catharina da Serra', 39.6796000, -8.6867900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113063, 'Santa Bárbara de Nexe', 'Santa Barbara de Nexe', 'Santa Barbara de Nexe,Santa Bárbara de Nexe', 37.1061900, -7.9664800, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113064, 'Samora Correia', 'Samora Correia', '', 38.9370900, -8.8717800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113065, 'Salvaterra de Magos', 'Salvaterra de Magos', 'Salvaterra de Magos', 39.0278800, -8.7935000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113066, 'Sagres', 'Sagres', 'Sagres,Sagresh,Сагреш', 37.0086400, -8.9431100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113067, 'Sacavém', 'Sacavem', 'Sacaben,Sacabis,Sacabén,Sakavain,Sakavem,Sakaven,Sakaven'',Sakavena,Sakavenas,sa ka wen,sakavu~en,sakawm,shqban,Σακαβέμ,Сакавен,Сакавень,ساکاوم,شقبان,საკავენი,サカヴェン,萨卡文', 38.7920200, -9.1080100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113068, 'Rio Maior', 'Rio Maior', 'Rio Maior', 39.3373200, -8.9390600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113069, 'Rio de Mouro', 'Rio de Mouro', 'Rio de Mouro', 38.7745700, -9.3276000, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113070, 'Ribeira Brava', 'Ribeira Brava', 'Ribeira Brava,Ribeira Mpraba,Ριβέιρα Μπράβα', 32.6500000, -17.0666700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113071, 'Riachos', 'Riachos', '', 39.4447200, -8.5142000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113072, 'Reguengos de Monsaraz', 'Reguengos de Monsaraz', 'Reguengos,Reguengos de Monsaraz', 38.4252900, -7.5349400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113073, 'Reguengo', 'Reguengo', '', 39.2980100, -7.3923400, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113074, 'Redondo', 'Redondo', 'Redondo', 38.6487200, -7.5470800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113075, 'Ramada', 'Ramada', 'Ramada', 38.8023500, -9.1921600, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113076, 'Quinta do Anjo', 'Quinta do Anjo', 'Quinta da Anjo,Quinta do Anjo', 38.5675300, -8.9422800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113077, 'Queluz', 'Queluz', 'Kelush,Queluz,Келуш', 38.7565700, -9.2545100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113078, 'Quejas', 'Quejas', 'Queijas,Quejas', 38.7223600, -9.2659300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113079, 'Quarteira', 'Quarteira', 'Quarteira', 37.0694600, -8.1006400, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113080, 'Proença-a-Nova', 'Proenca-a-Nova', 'Proenca-a-Nova,Proença-a-Nova', 39.7522000, -7.9239000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113081, 'Pragal', 'Pragal', 'Pragal', 38.6745900, -9.1698100, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113082, 'Póvoa e Meadas', 'Povoa e Meadas', 'Nossa Senhora da Graca de Povoa e Meadas,Nossa Senhora da Graça de Póvoa e Meadas', 39.5104600, -7.5176500, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113083, 'Póvoa de Santo Adrião', 'Povoa de Santo Adriao', '', 38.8000000, -9.1666700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113084, 'Póvoa de Santa Iria', 'Povoa de Santa Iria', 'Povoa,Povoa Santa Iria,Povoa de Martinho,Povoa de Santa Iria,Povoa do Tojal,Povua-de-Santa-Irija,Póvoa,Póvoa Santa Iria,Póvoa de Santa Iria,Póvoa do Tojal,Повуа-де-Санта-Ирия', 38.8610100, -9.0645300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113085, 'Porto Salvo', 'Porto Salvo', 'Porto Salvo', 38.7174500, -9.2983300, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113086, 'Porto Moniz', 'Porto Moniz', 'Porto Moniz,Porto do Moniz,Portu-Monish,Pôrto do Moniz,Порту-Мониш', 32.8500000, -17.1666700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113087, 'Porto de Mós', 'Porto de Mos', 'Porto de Mos,Porto de Mós', 39.6019100, -8.8183900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113088, 'Porto Covo', 'Porto Covo', 'Portu-Kovu,Порту-Кову', 37.8525600, -8.7901800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113089, 'Portimão', 'Portimao', 'PRM,Portimao,Portimão,Vila Nova de Portimao,Vila Nova de Portimão,Портимао', 37.1385600, -8.5377500, 'PT', '2016-10-22', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113090, 'Portel', 'Portel', 'Portel,Porteles Joao Baptista,Porteles João Baptista', 38.3069700, -7.7024400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113091, 'Portalegre', 'Portalegre', 'Portalegre,Порталегре', 39.2937900, -7.4312200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113092, 'Pontinha', 'Pontinha', 'Pontinha', 38.7677100, -9.1993500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113093, 'Pontével', 'Pontevel', '', 39.1494500, -8.8388000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113094, 'Ponte de Sôr', 'Ponte de Sor', 'Ponte de Sor,Ponte de Sôr', 39.2496400, -8.0100900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113095, 'Ponta do Sol', 'Ponta do Sol', 'Ponta do Sol,Ponta nto Sol,Πόντα ντο Σολ', 32.6666700, -17.1000000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113096, 'Pombal', 'Pombal', 'Pombal,Помбал', 39.9167400, -8.6284700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113097, 'Poceirão', 'Poceirao', '', 38.8309500, -8.7936500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113098, 'Pinhal Novo', 'Pinhal Novo', 'Pinhal Novo', 38.6310600, -8.9137600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113099, 'Piedade', 'Piedade', 'Cova da Piedade,Piedade', 38.6666700, -9.1500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113100, 'Pero Pinheiro', 'Pero Pinheiro', '', 38.8578300, -9.3235200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113101, 'Peniche', 'Peniche', 'Peniche', 39.3558000, -9.3811200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113102, 'Pedrógão Grande', 'Pedrogao Grande', 'Pedrogao,Pedrogao Grande,Pedrogao-o-Grande,Pedrogão,Pedrógão Grande,Pedrógão-o-Grande', 39.9183500, -8.1459000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113103, 'Pataias', 'Pataias', '', 39.6697800, -8.9958000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113104, 'Parede', 'Parede', 'Parede', 38.6928200, -9.3541200, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113105, 'Palmela', 'Palmela', 'Palmela', 38.5690200, -8.9012600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113106, 'Paço de Arcos', 'Paco de Arcos', 'Paco d''Arcos,Paço d''Arcos', 38.6956900, -9.2914300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113107, 'Ourique', 'Ourique', 'Ourique', 37.6539000, -8.2256900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113108, 'Ourém', 'Ourem', 'Ourem,Ourém', 39.6416700, -8.5919000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113109, 'Olival do Basto', 'Olival do Basto', '', 38.7907900, -9.1662100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113110, 'Olhão', 'Olhao', '', 37.0286000, -7.8411000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113111, 'Oleiros', 'Oleiros', 'Oleiros', 39.9189300, -7.9137000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113112, 'Oeiras', 'Oeiras', 'Oeiras', 38.6910500, -9.3108500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113113, 'Odivelas', 'Odivelas', 'Odivelas,awdywlas,اودیولاس', 38.7926900, -9.1838000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113114, 'Odemira', 'Odemira', '', 37.5979800, -8.6397200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113115, 'Óbidos', 'Obidos', 'Obidos,Obidush,Óbidos,Обидуш', 39.3605500, -9.1567000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113116, 'Nossa Senhora do Monte', 'Nossa Senhora do Monte', 'Monte,Nossa Senhora do Monte,Монте', 32.6666700, -16.9000000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113117, 'Nisa', 'Nisa', 'Nisa,Niza', 39.5149900, -7.6490800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113118, 'Nazaré', 'Nazare', 'Nazare,Nazaré,nazare,Ναζαρέ,Назаре,ナザレ', 39.6028900, -9.0683600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113119, 'Mourão', 'Mourao', 'Mourao,Mourão', 38.3835600, -7.3418900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113120, 'Moura', 'Moura', 'Mora,Moura,mo la,mora,Мора,Моура,მორა,莫拉', 38.1401000, -7.4485600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113121, 'Moscavide', 'Moscavide', '', 38.7792900, -9.1022200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113122, 'Mora', 'Mora', 'Mora', 38.9435100, -8.1643400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113123, 'Montijo', 'Montijo', 'Montijo,Montikho,Монтихо', 38.7067500, -8.9738800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113124, 'Monte Redondo', 'Monte Redondo', '', 39.8993000, -8.8317100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113125, 'Montemor-o-Novo', 'Montemor-o-Novo', 'Montemor-o-Novo', 38.6481200, -8.2145500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113126, 'Monte Gordo', 'Monte Gordo', 'Monte Gorde,Monte Gordo', 37.1819200, -7.4522500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113127, 'Monte Estoril', 'Monte Estoril', '', 38.7027900, -9.4160600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113128, 'Monsanto', 'Monsanto', 'Monsanto,Монсанто', 39.4620300, -8.7118000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113129, 'Monchique', 'Monchique', 'Monchique', 37.3177500, -8.5552900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113130, 'Moncarapacho', 'Moncarapacho', 'Moncarapacho', 37.0886300, -7.7872200, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113131, 'Moita', 'Moita', 'Moita', 38.6507800, -8.9903800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113132, 'Milharado', 'Milharado', '', 38.9473200, -9.1991400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113133, 'Mértola', 'Mertola', 'Mertola,Mértola,martlt,mei er tu la,merutora,Мертола,مارتلة,メルトラ,梅爾圖拉', 37.6430400, -7.6611000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113134, 'Marvão', 'Marvao', 'Marvan,Марван', 39.3937700, -7.3766300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113135, 'Marinhais', 'Marinhais', 'Marinhais', 39.0473000, -8.7023600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113136, 'Marinha Grande', 'Marinha Grande', 'Marinha Grande', 39.7476900, -8.9322800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113137, 'Malveira', 'Malveira', '', 38.9321300, -9.2577900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113138, 'Mafra', 'Mafra', 'Mafra', 38.9379300, -9.3275600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113139, 'Machico', 'Machico', 'Machico', 32.7000000, -16.7666700, 'PT', '2012-11-27', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113140, 'Maceira', 'Maceira', '', 39.6885300, -8.8942300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113141, 'Mação', 'Macao', 'Macao,Mação', 39.5557300, -7.9942100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113142, 'Luz', 'Luz', '', 37.0921600, -7.7043300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113143, 'Lourinhã', 'Lourinha', 'Lourinha,Lourinhã', 39.2333300, -9.3166700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113144, 'Louriçal', 'Lourical', 'Lourical,Louriçal', 40.0039000, -8.7373600, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113145, 'Loures', 'Loures', 'Loures,Loyres,Λόυρες', 38.8309100, -9.1684500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113146, 'Loulé', 'Loule', 'Lola,Loule,Loulé,Лола', 37.1377200, -8.0196800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113147, 'Lisbon', 'Lisbon', 'Felicitas Julia,Felicitas Julia Olissipo,LIS,Liospoin,Liospóin,Lisabon,Lisabona,Lisboa,Lisbon,Lisbona,Lisbonne,Lisbono,Lisbonum,Lissabon,Lisszabon,Lizboa,Lizbon,Lizbona,Olisipo,Olissipo,li si ben,lisaboni,lisbana,lisbxn,liseubon,lshbwnt,lysabwn,lysbwn,risubon,Λισαβώνα,Лисабон,Лиссабон,Лісабон,Լիսբոնա,ליסבון,لشبونة,لىسابون,لیسبون,ܠܫܒܘܢܐ,लिस्बन,ลิสบอน,ლისაბონი,ሊዝቦን,リスボン,里斯本,리스본', 38.7166700, -9.1333300, 'PT', '2015-03-08', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113148, 'Linda-a-Velha', 'Linda-a-Velha', 'Linda a Velha,Linda-a-Velha', 38.7144600, -9.2422000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113149, 'Leiria', 'Leiria', 'Leiria,Lejrija,QLR,Vieira de Leiria,lyyryh,Λεϊρία,Лейрия,לייריה', 39.7436200, -8.8070500, 'PT', '2017-04-02', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113150, 'Laranjeiro', 'Laranjeiro', '', 37.0683100, -7.7937000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113151, 'Lagos', 'Lagos', 'Lacobriga', 37.1020200, -8.6742200, 'PT', '2012-10-25', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113152, 'Lagoa', 'Lagoa', 'Lagoa', 37.1353500, -8.4531900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113153, 'Idanha-a-Nova', 'Idanha-a-Nova', 'Idan''ja-a-Nova,Idanha-a-Nova,xin yi da ni ya,Іданья-а-Нова,Иданья-а-Нова,新伊達尼亞', 39.9231600, -7.2408200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113154, 'Guia', 'Guia', 'Guia', 37.1295900, -8.2996300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113155, 'Grândola', 'Grandola', 'Grandola,Grândola,ge lan du la,Грандола,格蘭杜拉', 38.1771800, -8.5667500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113156, 'Golegã', 'Golega', 'Golega,Golegã', 39.4047400, -8.4862500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113157, 'Gavião', 'Gaviao', '', 39.4644300, -7.9344900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113158, 'Funchal', 'Funchal', 'FNC,Funchal,Funsala,Funsalis,Funshal,Funšala,Funšalis,Gorad Funshal,Phountsal,feng sha er,fnchal  prtgal,fung chal,funsharu,fwnchal,fwnshal,phunkala,punshali,punsyal,pwnsl,Φουντσάλ,Горад Фуншал,Фуншал,פונשל,فنچال ،پرتگال,فونشال,فونچال,फुंकल,ฟุงชาล,ფუნშალი,フンシャル,丰沙尔,푼샬', 32.6656800, -16.9254700, 'PT', '2016-12-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113159, 'Fronteira', 'Fronteira', 'Fronteira', 39.0562900, -7.6486800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113160, 'Fortios', 'Fortios', '', 39.3249400, -7.5005700, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113161, 'Figueiró dos Vinhos', 'Figueiro dos Vinhos', 'Figueiro dos Vinhos,Figueiró dos Vinhos', 39.9041300, -8.2751100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113162, 'Ferreiras', 'Ferreiras', 'Ferreiras', 37.1292600, -8.2375900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113163, 'Ferreira do Zêzere', 'Ferreira do Zezere', 'Ferreira do Zezere,Ferreira do Zêzere', 39.6940600, -8.2921300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113164, 'Ferreira do Alentejo', 'Ferreira do Alentejo', 'Ferreira do Alentejo,Ferrejra-du-Alentezhu,fei lei la du a lian te ru,Феррейра-ду-Алентежу,費雷拉杜阿連特茹', 38.0500000, -8.0333300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113165, 'Fazendas de Almeirim', 'Fazendas de Almeirim', 'Fazendas de Almeirim', 39.1755300, -8.5692700, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113166, 'Fátima', 'Fatima', 'Fatima,Fatimae,Fàtima,Fátima,Phatima,fatima,fatmt,fatyma,hua de ma,patima,phatima,phattima,Φάτιμα,Фатимæ,Фатима,Фатіма,فاتیما,فاطمة,فاطیما,ফাটিমা,ഫാത്തിമ,ファティマ,花地瑪,파티마', 39.6207100, -8.6523700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113167, 'Faro', 'Faro', 'FAO,Faro,Faru,Фару', 37.0193700, -7.9322300, 'PT', '2013-11-15', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113168, 'Famões', 'Famoes', '', 38.7880400, -9.2103300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113169, 'Fajã da Ovelha', 'Faja da Ovelha', 'Faia da Ovelha,Faja da Ovelha,Fajã da Ovelha,Fazhan-da-Ovel''ja,Фажан-да-Овелья', 32.7745700, -17.2341200, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113170, 'Évora', 'Evora', 'Aebura,Ebora,Ehvora,Elbora,Erbora,Evora,Yabura/Yabora/Yabra,Ébora,Évora,Эвора', 38.5666700, -7.9000000, 'PT', '2015-04-05', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113171, 'Estremoz', 'Estremoz', 'Estremoz', 38.8443200, -7.5858500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113172, 'Estreito da Calheta', 'Estreito da Calheta', 'Ehshtrejtu-da-Kal''eta,Эштрейту-да-Кальета', 32.7370400, -17.1867400, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113173, 'Estoril', 'Estoril', 'Ehshtoril,Eshhoril,Eshturil,Estoril,Estorilis,Estoris,Estorís,Estroil,astwryl,eseutolil,esutoriru,Εστορίλ,Есторил,Ештуріл,Ещорил,Эшторил,إستوريل,エストリル,에스토릴', 38.7057100, -9.3977300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113174, 'Estômbar', 'Estombar', '', 37.1462900, -8.4850500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113175, 'Ericeira', 'Ericeira', '', 38.9627500, -9.4156300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113176, 'Entroncamento', 'Entroncamento', 'Entrocamento,Entroncamento', 39.4666700, -8.4666700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113177, 'Elvas', 'Elvas', 'Elvas', 38.8815000, -7.1628200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113178, 'Curral das Freiras', 'Curral das Freiras', 'Curral das Freiras,Kurral-dash-Frejrash,Куррал-даш-Фрейраш', 32.7202900, -16.9699300, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113179, 'Cuba', 'Cuba', 'Cuba', 38.1654400, -7.8924000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113180, 'Costa de Caparica', 'Costa de Caparica', '', 38.6445800, -9.2355600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113181, 'Coruche', 'Coruche', 'Coruche', 38.9595500, -8.5252400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113182, 'Corroios', 'Corroios', 'Corroios', 38.6450200, -9.1484300, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113183, 'Constância', 'Constancia', '', 39.4666700, -8.3333300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113184, 'Colares', 'Colares', 'Colares', 38.7992100, -9.4469100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113185, 'Charneca', 'Charneca', 'Charneca,Charneca de Caparica,Sharneka,Шарнека', 38.6205900, -9.1914900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113186, 'Cercal', 'Cercal', 'Cercal,Cercal do Alentejo', 37.8060100, -8.6715300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113187, 'Castro Verde', 'Castro Verde', 'Castro Verde,Castro Verde Municipality,Kashtru-Verdi,Каштру-Верди,Каштру-Верді', 37.6982800, -8.0858100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113188, 'Castro Marim', 'Castro Marim', '', 37.2206800, -7.4435000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113189, 'Castelo de Vide', 'Castelo de Vide', 'Castello de Vide,Kashtelu-de-Vide,Каштелу-де-Виде', 39.4162400, -7.4568000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113190, 'Castelo Branco', 'Castelo Branco', 'Castelo Branco,Kashtelu-Branku,Каштелу-Бранку', 39.8221900, -7.4908700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113191, 'Castanheira do Ribatejo', 'Castanheira do Ribatejo', 'Castanheira,Castanheira do Ribatejo', 38.9929800, -8.9734600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113192, 'Castanheira de Pêra', 'Castanheira de Pera', 'Castanheira,Castanheira de Pera,Castanheira de Pêra', 40.0071700, -8.2104800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113193, 'Cascais', 'Cascais', 'CAT,Cascaes,Cascais,Kashkajsh,Kaskais,Kaskaisas,Kaškaišas,ka si kai shen,kasukaisu,Κασκάις,Каскаис,Кашкайш,カスカイス,卡斯凯什', 38.6968100, -9.4214700, 'PT', '2017-07-03', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113194, 'Carvoeiro', 'Carvoeiro', 'Carvoeiro,Karvoejro,Карвоейро', 37.0905100, -8.4538100, 'PT', '2012-01-08', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113195, 'Cartaxo', 'Cartaxo', 'Cartaxo', 39.1602200, -8.7874100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113196, 'Carregado', 'Carregado', 'Carregado', 39.0236200, -8.9769200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113197, 'Carnaxide', 'Carnaxide', 'Carnaxide,Karnashide,Карнашиде', 38.7270600, -9.2467100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113198, 'Carcavelos', 'Carcavelos', 'Carcavelos', 38.6910500, -9.3221500, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113199, 'Caranguejeira', 'Caranguejeira', 'Caranguejeira', 39.7461900, -8.7074000, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113200, 'Caparica', 'Caparica', 'Caparica', 38.6666700, -9.2000000, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113201, 'Caniço', 'Canico', 'Canico,Caniço', 32.6333300, -16.8500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113202, 'Caniçal', 'Canical', 'Canical,Caniçal,Kanisal,Канисал,Канісал', 32.7383400, -16.7383600, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113203, 'Caneças', 'Canecas', 'Canecas,Caneças', 38.8132100, -9.2267900, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113204, 'Campo Maior', 'Campo Maior', 'Campo Maior', 39.0177400, -7.0649700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113205, 'Campanário', 'Campanario', 'Campanario,Campanário', 32.6657800, -17.0357600, 'PT', '2011-10-21', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113206, 'Camarate', 'Camarate', 'Camarate,Camrate,Kamarate,Камарате', 38.8035800, -9.1280900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113207, 'Câmara de Lobos', 'Camara de Lobos', 'Camara de Lobos,Câmara de Lobos,Kamara nte Lompos,Kamara-de-Lobos,Kamara-de-Lobush,Kamara-di-Lobush,ka ma la-de luo bu shen,kamara dlwbws,kamara dy lwbws,Καμάρα ντε Λόμπος,Камара-де-Лобос,Камара-де-Лобуш,Камара-ди-Лобуш,كامارا دي لوبوس,کامارا دلوبوس,კამარა-დი-ლობუში,卡馬拉-德洛布什', 32.6333300, -16.9666700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113208, 'Camacha', 'Camacha', '', 33.0866500, -16.3425300, 'PT', '2014-10-15', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113209, 'Camacha', 'Camacha', 'Camacha,Kamasha,Камаша', 32.6791900, -16.8446200, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113210, 'Calheta', 'Calheta', 'Calheta,Kal''eta,ka lie ta,kallyeta,qlyyth,Кальета,Кальєта,קלייטה,卡列塔,칼례타', 32.7166700, -17.1833300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113211, 'Caldas da Rainha', 'Caldas da Rainha', 'Caldad da Rainha,Caldas da Rainha,Kaldas da Raina,Kaldash-da-Rain''ja,kaldas daraynya,Калдас да Раиња,Калдаш-да-Раинья,کالداس داراینیا,კალდაშ-და-რაინია,カルダス・ダ・ライーニャ', 39.4032600, -9.1383900, 'PT', '2016-08-31', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113212, 'Cadaval', 'Cadaval', 'Cadaval', 39.2429800, -9.1032700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113213, 'Cacilhas', 'Cacilhas', 'Cacilhas', 38.6877300, -9.1466300, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113214, 'Cacém', 'Cacem', 'Cacem,Cacém', 38.7669800, -9.2979300, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113215, 'Bucelas', 'Bucelas', 'Bucelas,Bucellas', 38.9019300, -9.1188500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113216, 'Borba', 'Borba', 'Borba,Borda,Борба', 38.8055300, -7.4546500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113217, 'Bombarral', 'Bombarral', 'Bombarral,Rombarral', 39.2672300, -9.1579500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113218, 'Boliqueime', 'Boliqueime', 'Boliqueime', 37.1371800, -8.1582000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113219, 'Bobadela', 'Bobadela', '', 38.8077400, -9.0992500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113220, 'Benedita', 'Benedita', 'Benedita,Benedito', 39.4247000, -8.9699600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113221, 'Benavente', 'Benavente', 'Benavente', 38.9791900, -8.8075900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113222, 'Belas', 'Belas', '', 38.7772100, -9.2607800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113223, 'Beja', 'Beja', 'BYJ,Beja,Conistorgis', 38.0150600, -7.8632300, 'PT', '2013-08-05', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113224, 'Batalha', 'Batalha', 'Batalha,Mpatalia,Μπατάλια', 39.6602500, -8.8247500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113225, 'Barreiro', 'Barreiro', 'Barreiro,Barrejru,ba lei lu,Баррейру,巴雷鲁', 38.6631400, -9.0724000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113226, 'Barrancos', 'Barrancos', 'Barrancos', 38.1344600, -6.9760400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113227, 'Barcarena', 'Barcarena', '', 38.7324500, -9.2800000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113228, 'Azambuja', 'Azambuja', 'Azambuja,Azambuzha,a zan bu ya,Азамбужа,阿贊布雅', 39.0702900, -8.8682200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113229, 'Avis', 'Avis', 'Avis,Aviz', 39.0539100, -7.8915600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113230, 'Aveiras de Cima', 'Aveiras de Cima', 'Aveiras de Cima', 39.1379600, -8.8993200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113231, 'Atouguia da Baleia', 'Atouguia da Baleia', 'Atouguia,Atouguia da Baleia', 39.3381400, -9.3263000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113232, 'Arruda dos Vinhos', 'Arruda dos Vinhos', 'Arruda,Arruda dos Vinhos', 38.9841100, -9.0774600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113233, 'Arronches', 'Arronches', 'Arronches', 39.1224200, -7.2861900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113234, 'Arrentela', 'Arrentela', 'Arrentela,Arrentella,Аррентела', 38.6166700, -9.1000000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113594, 'Koror', 'Koror', 'Goreor,Goror,Koreor,Koror,Koror City,Koror town,Koror village,Kororu,Korōru,ROR', 7.3397800, 134.4732600, 'PW', '2014-08-20', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113595, 'Ulimang', 'Ulimang', 'A Ulimang,Galap,Uliman', 7.6241600, 134.6420800, 'PW', '2013-08-31', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113596, 'Melekeok Village', 'Melekeok Village', 'Artingall,Athermal,Athernal,Coaengal,Malligoyoke,Marukiyoku,Melekeiok,Melekejok,Melekiok,Melekyok,Meligeok,Mgadernal,Molegojok,Molegoyok,Ngadernal', 7.4956700, 134.6367100, 'PW', '2013-08-14', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113597, 'Ngereklmadel', 'Ngereklmadel', 'Madarabae,Madarabaye,Ngedbang', 7.4882600, 134.4856200, 'PW', '2011-03-26', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113598, 'Imeong Hamlet', 'Imeong Hamlet', 'A Imeungs,Aimeong,Aimion,Imeiong,Imeong', 7.5313400, 134.5271300, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113599, 'Ngchesar Hamlet', 'Ngchesar Hamlet', 'Alakasoho,Arakaso,Enchesar,Engkasar,Enkasar,Enkassar,Galaus,Ngesar,Nggesar,Nggessar,Ngurutoi', 7.4693200, 134.6099100, 'PW', '2013-08-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113600, 'Ngerkeai', 'Ngerkeai', 'Karaeru,Ngaragoluuk,Ngaregeluj,Ngerecheluk,Ngermechau,Ngiwal,Ogiwal,Ogiwaru', 7.5545600, 134.6361200, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113601, 'Mengellang', 'Mengellang', 'Kayungur,Ngeiungel,Ononguru', 7.6957000, 134.6305400, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113602, 'Angaur State', 'Angaur State', 'Ngeaur', 6.9060100, 134.1299700, 'PW', '2013-08-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113603, 'Melekeok', 'Melekeok', 'Melekeok,Melekeok - Palau State Capital', 7.5004300, 134.6235500, 'PW', '2015-02-25', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113604, 'Tobi Village', 'Tobi Village', 'Hatohobei', 3.0048800, 131.1216800, 'PW', '2013-07-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113605, 'Sonsorol Village', 'Sonsorol Village', 'Dongosaro,Sonsorol', 5.3260800, 132.2194300, 'PW', '2013-08-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113606, 'Kayangel', 'Kayangel', '', 8.0822800, 134.7172500, 'PW', '2011-03-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113607, 'Kloulklubed', 'Kloulklubed', '', 7.0419200, 134.2556100, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113608, 'Ngetkib', 'Ngetkib', '', 7.3645100, 134.5148400, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113609, 'Ngchemiangel', 'Ngchemiangel', '', 7.4461300, 134.4767800, 'PW', '2013-08-10', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113610, 'Ngardmau', 'Ngardmau', '', 7.6098600, 134.5744000, 'PW', '2013-08-05', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113611, 'Koror Town', 'Koror Town', 'Little Tokyo', 7.3425700, 134.4788800, 'PW', '2011-04-02', 169);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113612, 'Yuty', 'Yuty', 'Yuty', -26.6000000, -56.2500000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113613, 'Ypacarai', 'Ypacarai', 'Ipacarai,Ypacarai,Ypacaray', -25.4077700, -57.2888900, 'PY', '2015-06-13', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113614, 'Yhú', 'Yhu', '', -25.0500000, -55.9166700, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113615, 'Ygatimí', 'Ygatimi', 'Igatimi,Igatimí,Terecany,Terecañy,Ygatimi,Ygatimí', -24.0833300, -55.5000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113616, 'Yegros', 'Yegros', 'Yegros', -26.4500000, -56.4000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113617, 'Ybycuí', 'Ybycui', 'Ibycuy,Ybycui,Ybycul,Ybycuí', -26.0166700, -57.0500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113618, 'Yataity del Norte', 'Yataity del Norte', '', -24.8333300, -56.3500000, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113619, 'Yaguarón', 'Yaguaron', 'Yaguaron,Yaguarón,Yaquaron', -25.6000000, -57.3000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113620, 'Villarrica', 'Villarrica', 'Gorad Vil''jaryka,Vil''jarrika,Viljarika,Villa Rica,Villarrica,Villarrica del Espiritu Santo,Villarrica del Espíritu Santo,Villarrika,bi ya li ka,biyalika,wyaryka,Вильяррика,Вільярріка,Горад Вільярыка,ویاریکا,ویاریکا، پیراگوئے,ვილიარიკა,比亚里卡,비야리카', -25.7494600, -56.4351800, 'PY', '2015-06-14', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113621, 'Villa Hayes', 'Villa Hayes', 'New Bordeaux,Nueva Burdeos,Remanzo,Villa Hayes,Villa Occidental', -25.0930600, -57.5236100, 'PY', '2013-08-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113622, 'Villa Florida', 'Villa Florida', 'Florida,Villa Florida', -26.3833300, -57.1500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113623, 'Villa Elisa', 'Villa Elisa', 'Colonia Eliza,Villa Elisa', -25.3676000, -57.5927400, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113624, 'Unión', 'Union', 'Union,Unión', -24.8000000, -56.5500000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113625, 'Trinidad', 'Trinidad', 'Trinidad', -27.1166700, -55.7833300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113626, 'Tobatí', 'Tobati', 'Tobati,Tobaty,Tobatí', -25.2500000, -57.0666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113627, 'Tacuatí', 'Tacuati', 'Tacuati,Tacuaty,Tacuatí', -23.4500000, -56.5833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113628, 'Sapucaí', 'Sapucai', 'Sapucai,Sapucay,Sapucaí', -25.6666700, -56.9166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113629, 'Santiago', 'Santiago', 'Santiago,Santiago De Las Misiones', -27.1431000, -56.7680300, 'PY', '2015-06-13', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113630, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa,Santa Rosa de la Misiones', -26.8666700, -56.8500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113631, 'Santa Rita', 'Santa Rita', '', -25.7833300, -55.0666700, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113632, 'Santa María', 'Santa Maria', 'Santa Maria,Santa María', -26.7833300, -56.9333300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113633, 'Santa Elena', 'Santa Elena', 'Santa Elena', -25.4000000, -56.8000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113634, 'San Pedro de Ycuamandiyú', 'San Pedro de Ycuamandiyu', 'San Pedro,San Pedro de Ycuamandiyu,San Pedro de Ycuamandiyú', -24.0853400, -57.0874500, 'PY', '2014-07-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113635, 'San Pedro del Paraná', 'San Pedro del Parana', '', -26.8333300, -56.2000000, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113636, 'San Patricio', 'San Patricio', 'San Patricio', -26.9666700, -56.8166700, 'PY', '2012-05-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113637, 'San Miguel', 'San Miguel', '', -26.5000000, -57.0500000, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113638, 'San Lorenzo', 'San Lorenzo', 'San Lorensas,San Lorenso,San Lorenzo,San Lorenzo del Campo Grande,San-Lorenso,san lwrynzw,san-lorenso,sheng luo lun suo,sn lwrnzw  paragwyh,Сан Лорензо,Сан-Лоренсо,سان لورينزو,سن لورنزو، پاراگوئه,სან-ლორენსო,聖洛倫索', -25.3396800, -57.5087900, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113639, 'San Juan Nepomuceno', 'San Juan Nepomuceno', 'San Juan Nepomuceno', -26.1000000, -55.9666700, 'PY', '2012-02-28', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113640, 'San Juan del Paraná', 'San Juan del Parana', 'San Juan del Parana,San Juan del Paraná', -27.3000000, -55.9666700, 'PY', '2013-04-04', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113641, 'San Juan Bautista', 'San Juan Bautista', 'San Juan Bautista', -26.6694400, -57.1458300, 'PY', '2013-08-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113642, 'San José', 'San Jose', 'San Jose,San Jose de los Arroyos,San José,San José de los Arroyos', -25.5333300, -56.7333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113643, 'San Joaquín', 'San Joaquin', '', -24.9500000, -56.1166700, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113644, 'San Isidro de Curuguaty', 'San Isidro de Curuguaty', 'Curuguaty,San Isidro de Curuguaty,Villa Curuguaty', -24.5166700, -55.7000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113645, 'San Cosme y Damián', 'San Cosme y Damian', 'San Cosme,San Cosme y Damian,San Cosme y Damián', -27.3166700, -56.3500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113646, 'San Bernardino', 'San Bernardino', 'San Bernardino', -25.3106700, -57.2962800, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113647, 'San Antonio', 'San Antonio', 'San Antonio', -25.4212600, -57.5472500, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113648, 'San Alberto', 'San Alberto', 'San Alberto', -24.9666700, -54.9000000, 'PY', '2012-05-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113649, 'Salto del Guairá', 'Salto del Guaira', 'Sal''to-del''-Guajra,Salto del Guaira,Salto del Guairá,Salto del Gvaira,Saltos de Guaira,Saltos de Guairá,sa er tuo de er gua,saltodelgwaila,saltw dyl gwayra,Сальто-дель-Гуайра,Сальто-дель-Ґуайра,سالتو دیل گوایرا,სალტო-დელ-გუაირა,薩爾托德爾瓜,살토델과이라', -24.0625000, -54.3069400, 'PY', '2012-04-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113650, 'Repatriación', 'Repatriacion', 'Repatriacion,Repatriación', -25.5333300, -55.9500000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113651, 'Quiindy', 'Quiindy', 'Quiindy,Quyyndy', -25.9666700, -57.2666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113652, 'Puerto Rosario', 'Puerto Rosario', 'Puerto Rosario,Puerto Villa del Rosario', -24.4500000, -57.0833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113653, 'Puerto Mayor Otaño', 'Puerto Mayor Otano', '', -26.4000000, -54.7000000, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113654, 'Presidente Franco', 'Presidente Franco', 'Presidente Franco,Puerto Presidente Franco', -25.5333300, -54.6166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113655, 'Piribebuy', 'Piribebuy', 'Piribebuy', -25.4833300, -57.0500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113656, 'Pirayú', 'Pirayu', 'Pirayu,Pirayú', -25.4833300, -57.2333300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113657, 'Pirapo', 'Pirapo', 'Pirapo,Puerto Pirapo,Puerto Pirapó', -26.8500000, -55.5333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113658, 'Pilar', 'Pilar', 'PIL,Pilar,Pilaras,bylar,pi la er,pillaleu,pylar,Пилар,Пілар,بيلار,پیلار,پیلار، پیراگوئے,პილარი,皮拉爾,필라르', -26.8687900, -58.2934600, 'PY', '2013-06-29', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113659, 'Pedro Juan Caballero', 'Pedro Juan Caballero', 'PJC,Pedro Chuan Kabaljeras,Pedro Huan Kabaljero,Pedro Juan Caballero,Pedro Khuan Kabalero,Pedro-Khuan-Kabal''ero,pdrw khwan kabalrw,pedeulohuankabayelo,pei de luo hu an ka wa lie luo,Педро Хуан Кабалеро,Педро-Хуан-Кабальеро,Педро-Хуан-Кабальєро,פדרו חואן קבאיירו,پدرو خوآن کابالرو,پیدرو خوان کابالیرو، پیراگوئے,პედრო-ხუან-კაბალიერო,ペドロ・フアン・カバリェロ市,佩德罗胡安卡瓦列罗,페드로후안카바예로', -22.5472200, -55.7333300, 'PY', '2014-08-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113660, 'Paraguarí', 'Paraguari', 'Paraguari,Paraguarí,Paragvari,ba la gua li,palagwali,paragwary,Парагуари,Параґуарі,پاراگواری,პარაგუარი,巴拉瓜里,파라과리', -25.6208300, -57.1472200, 'PY', '2012-04-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113661, 'Obligado', 'Obligado', 'Colonia Doctor Pastor Obligado,Obligado', -27.0333300, -55.6333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113662, 'Nueva Italia', 'Nueva Italia', 'Colonia Nueva Italia,Nueva Italia', -25.6166700, -57.5000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113663, 'Nueva Germania', 'Nueva Germania', 'Colonia Nueva Germania,Nueva Germania', -23.9000000, -56.5666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113664, 'Nemby', 'Nemby', 'Nemby,San Lorenzo de la Frontera', -25.3949000, -57.5357400, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113665, 'Natalio', 'Natalio', 'Natalio', -26.7166700, -55.0833300, 'PY', '2012-05-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113666, 'Natalicio Talavera', 'Natalicio Talavera', 'Colonia Natalicio Talavera,Natalicio Talavera,Natalico Talavera', -25.6333300, -56.3000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113667, 'Naranjal', 'Naranjal', 'Naranjal', -25.9666700, -55.1833300, 'PY', '2012-05-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113668, 'Nanawa', 'Nanawa', 'Nanawa', -25.2666700, -57.6666700, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113669, 'Mbuyapey', 'Mbuyapey', 'Mbuyapey', -26.2000000, -56.7500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113670, 'Mbutuy', 'Mbutuy', 'Mbutuy', -24.9666700, -56.3000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113671, 'Mbocayaty', 'Mbocayaty', 'Mbocayaty', -25.7193800, -56.4217900, 'PY', '2015-06-14', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113672, 'Los Cedrales', 'Los Cedrales', 'Los Cedrales', -25.6500000, -54.7000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113673, 'Limpio', 'Limpio', 'Limpio', -25.1661100, -57.4856200, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113674, 'Lima', 'Lima', 'Lima', -23.9000000, -56.3333300, 'PY', '2013-05-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113675, 'Las Palomas', 'Las Palomas', '', -24.0833300, -54.5166700, 'PY', '2006-01-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113676, 'Lambaré', 'Lambare', 'Lambare,Lambaré,Lambarė,lambale,lambare,lambarh,lambary,lan ba lei,ranbare,Ламбаре,لامباره,لامباری,ლამბარე,ランバレ,蘭巴雷,람바레', -25.3468200, -57.6064700, 'PY', '2012-01-24', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113677, 'La Colmena', 'La Colmena', 'Colonia La Colmena,La Colmena', -25.8833300, -56.8166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113678, 'Jesús', 'Jesus', '', -27.0500000, -55.7833300, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113679, 'Iturbe', 'Iturbe', 'Iturbe', -26.0500000, -56.4833300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113680, 'Itauguá', 'Itaugua', 'Itaugua,Itauguá,Itaugva,Ytaygua,aytaywgwa,yi tao gua,Итаугуа,ایتائوگوآ,იტაუგუა,伊陶瓜', -25.3833300, -57.3333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113681, 'Itaquyry', 'Itaquyry', 'Itaquyry,Ytaquyry', -24.9333300, -55.2166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113682, 'Itapé', 'Itape', 'Itape,Itapé', -25.8500000, -56.6166700, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113683, 'Itacurubí del Rosario', 'Itacurubi del Rosario', 'Itacurabi,Itacurubi del Rosario,Itacurubí del Rosario', -24.5000000, -56.6833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113684, 'Itacurubí de la Cordillera', 'Itacurubi de la Cordillera', 'Itacurubi,Itacurubi de la Cordillera,Itacurubí de la Cordillera', -25.4500000, -56.8500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113685, 'Itá', 'Ita', 'Ita,Itá', -25.5005400, -57.3671700, 'PY', '2015-06-13', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113686, 'Isla Pucú', 'Isla Pucu', 'Isla Pucu,Isla Pucú', -25.3000000, -56.9000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113687, 'Independencia', 'Independencia', 'Colonia Independencia,Independencia', -25.6910000, -56.2678100, 'PY', '2015-06-14', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113688, 'Hohenau', 'Hohenau', 'Colonia Hohenau,Hohenau', -27.0833300, -55.7500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113689, 'Guayaybi', 'Guayaybi', '', -24.5333300, -56.4333300, 'PY', '2006-01-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113690, 'Guarambaré', 'Guarambare', 'Guarambare,Guarambaré', -25.4833300, -57.4666700, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113691, 'General José Eduvigis Díaz', 'General Jose Eduvigis Diaz', 'General Diaz,General Jose Eduvigis Diaz,General José Eduvigis Díaz,Jose Eduvigis Diaz,José Eduvigis Díaz', -27.1666700, -58.4166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113692, 'General Higinio Morínigo', 'General Higinio Morinigo', 'Colonia General Morinigo,Colonia General Morínigo,General Higinio Morinigo,General Higinio Morínigo,General Morinigo,General Morínigo', -25.9500000, -55.9166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113693, 'General Elizardo Aquino', 'General Elizardo Aquino', 'Colonia General Acuino,General Aquino,General Elizardo Aquino', -24.4333300, -56.7000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113694, 'General Delgado', 'General Delgado', 'Colonia General Delgado,General Delgado', -27.1666700, -56.5166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113695, 'General Artigas', 'General Artigas', 'Bobi,Bobi-Cango,Bobi-Cangó,Bobí,Cango,General Artigas', -26.9333300, -56.2166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113696, 'Fuerte Olimpo', 'Fuerte Olimpo', 'Fuehrte-Olimpo,Fuerte Olimpas,Fuerte-Olimpo,OLK,Olimpo,ao lin bo bao,fwyrty awlympw,pueleute-ollimpo,Фуерте-Олімпо,Фуэрте-Олимпо,فویرتی اولیمپو,ფუერტე-ოლიმპო,奥林波堡,푸에르테올림포', -21.0415300, -57.8737700, 'PY', '2012-04-10', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113697, 'Fram', 'Fram', 'Fram', -26.9833300, -55.8833300, 'PY', '2016-03-10', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113698, 'Fernando de la Mora', 'Fernando de la Mora', 'Fernando de la Mora,Fernando-de-la-Mor,fei er nan duo de la mo la,frnandw dla mwra,fyrnandw dy la mwra,pernando-de-la-mora,Фернандо де ла Мора,فرناندو دلا مورا,فيرناندو دي لا مورا,ფერნანდო-დე-ლა-მორა,費爾南多德拉莫拉', -25.3386000, -57.5216700, 'PY', '2014-07-07', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113699, 'Eusebio Ayala', 'Eusebio Ayala', 'Barrero Grande,Eusebio Ayala', -25.4000000, -56.9666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113700, 'Encarnación', 'Encarnacion', 'ENO,Ehnkarnas''on,Encarnacao,Encarnacion,Encarnación,Encarnação,Enkarnas''jon,Enkarnasion,Enkarnasjonas,ankaransywn,en ka na xi weng,engkaleunasion,enkarunashion,xe ngkar na si xxng,Енкарнасион,Енкарнасьйон,Энкарнасьон,אנקרנסיון,انکارانسیون,انکارنسیون، پیراگوئے,เองการ์นาซีออง,ენკარნასიონი,エンカルナシオン,恩卡纳西翁,엥카르나시온', -27.3305600, -55.8666700, 'PY', '2017-05-24', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113701, 'Emboscada', 'Emboscada', 'Emboscada', -25.1500000, -57.3500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113702, 'Edelira', 'Edelira', 'Edelira', -26.7500000, -55.2666700, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113703, 'Doctor Juan Manuel Frutos', 'Doctor Juan Manuel Frutos', 'Doctor Juan M. Frutos,Doctor Juan Manuel Frutos,Juan M. Fruto', -25.3666700, -55.8000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113704, 'Doctor Juan León Mallorquín', 'Doctor Juan Leon Mallorquin', 'Caarendy,Doctor J. Leon Mallorquin,Doctor J. León Mallorquín,Doctor Juan Leon Mallorquin,Doctor Juan León Mallorquín,J. Leon Mallorquin', -25.4000000, -55.2666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113705, 'Doctor Cecilio Báez', 'Doctor Cecilio Baez', 'Cecilio Baez,Cecilio Báez,Doctor Cecilio Baez,Doctor Cecilio Báez', -25.0500000, -56.3166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113706, 'Corpus Christi', 'Corpus Christi', '', -24.0333300, -54.8333300, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113707, 'Coronel Oviedo', 'Coronel Oviedo', 'Ajos,Coronel Oviedo,Koronel Ovjedas,Koronel Ovyedo,Koronel''-Ov''edo,ao wei duo shang xiao zhen,kolonel-obiedo,kwrwnl awwydw,kwrwnyl awwydw,Коронель-Овьедо,Коронель-Овьєдо,Կորոնել Օվյեդո,کورونل اوویدو,کورونیل اوویدو,კორონელ-ოვიედო,コロネル・オビエド,奥维多上校镇,코로넬오비에도', -25.4444400, -56.4402800, 'PY', '2012-04-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113708, 'Coronel Martínez', 'Coronel Martinez', 'Coronel Martinez,Coronel Martínez,Martinez', -25.7500000, -56.6166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113709, 'Concepción', 'Concepcion', 'CIO,Conceicao,Conceição,Concepcion,Concepción,Konseps''on,Konsepsjonas,Villa Concepcion,Villa Concepción,Консепсьон', -23.3998500, -57.4323600, 'PY', '2017-05-24', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113710, 'Colonia Yguazú', 'Colonia Yguazu', 'Colonia Yguazu,Colonia Yguazú', -25.4500000, -55.0000000, 'PY', '2013-04-04', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113711, 'Colonia Minga Porá', 'Colonia Minga Pora', 'Colonia Minga Pora,Colonia Minga Porá', -24.8666700, -54.9000000, 'PY', '2012-05-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113712, 'Colonia Menno', 'Colonia Menno', 'Colonia Menno', -22.3666700, -59.8166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113713, 'Colonia Mauricio José Troche', 'Colonia Mauricio Jose Troche', 'Colonia Cosme,Colonia Mauricio J. Troche,Colonia Mauricio Jose Troche,Colonia Mauricio José Troche,Cosme,Mauricio Jose Troche,Mauricio José Troche', -25.5666700, -56.2833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113714, 'Colonia Mariano Roque Alonso', 'Colonia Mariano Roque Alonso', 'Colonia Mariano Roque Alonso,Colonia Roque Alonso,Mariano Roque Alonso', -25.1666700, -57.5500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113715, 'Colonia General Alfredo Stroessner', 'Colonia General Alfredo Stroessner', '', -25.3666700, -55.7000000, 'PY', '2006-01-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113716, 'Colonia Catuete', 'Colonia Catuete', '', -24.1333300, -54.6166700, 'PY', '2006-01-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113717, 'Ciudad del Este', 'Ciudad del Este', 'AGT,Ciudad Presidente Stroessner,Ciudad del Este,Presidente Stroessner,Puerto Presidente Stroessner,S''judad-del''-Ehste,S''judad-del''-Este,Sijudad del Este,Siudad del Este,Siudad del Estė,Sjudad Del Este,Sjudad del Este,dong fang shi,siudadeudel-eseute,siw dad del xe s te,sywdad dl asth,Сиудад дел Есте,Сијудад дел Есте,Сьюдад-дель-Есте,Сьюдад-дель-Эсте,Сјудад дел Есте,סיודאד דעל עסטע,סיודד דל אסטה,سیوداد دل استه,سیوداد دیل استے,ซิวดัดเดลเอสเต,სიუდად-დელ-ესტე,シウダー・デル・エステ,東方市,시우다드델에스테', -25.5097200, -54.6111100, 'PY', '2013-08-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113718, 'Chore', 'Chore', 'Chore', -24.1860600, -56.5825100, 'PY', '2014-07-27', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113719, 'Cerrito', 'Cerrito', 'Cerrito', -27.3166700, -57.6666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113720, 'Carmen del Paraná', 'Carmen del Parana', 'Carmen,Carmen del Parana,Carmen del Paraná', -27.2333300, -56.2166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113721, 'Carlos Antonio López', 'Carlos Antonio Lopez', '', -26.4000000, -54.7666700, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113722, 'Carayaó', 'Carayao', 'Carayao,Carayaó', -25.1833300, -56.4000000, 'PY', '2014-04-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113723, 'Carapeguá', 'Carapegua', 'Carapegua,Carapeguá', -25.8000000, -57.2333300, 'PY', '2014-04-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113724, 'Caraguatay', 'Caraguatay', 'Caraguatay', -25.2333300, -56.8166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113725, 'Capitán Miranda', 'Capitan Miranda', 'Capitan Miranda,Capitán Miranda,Colonia Capitan Miranda,Colonia Capitán Miranda', -27.2000000, -55.8000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113726, 'Capitán Bado', 'Capitan Bado', 'Capitan Bado,Capitán Bado', -23.2666700, -55.5333300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113727, 'Capiíbary', 'Capiibary', 'Capiibary,Capiíbary', -24.8000000, -56.0333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113728, 'Capiatá', 'Capiata', 'Capiata,Capiatá,Capista,Kapiata,Kapiatã,Kapijata,Kapjata,ka pi ya ta,kapiata,kapyata,Капијата,کاپیاتا,კაპიატა,カピアタ,卡皮亞塔,카피아타', -25.3552000, -57.4454500, 'PY', '2012-03-22', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113729, 'Caazapá', 'Caazapa', 'Caazapa,Caazapá,Kaasapa,Kaazapa,ka sa pa,kasapa,Каазапа,کاساپا,კაასაპა,卡薩帕,카사파', -26.1958300, -56.3680600, 'PY', '2013-08-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113730, 'Caapucú', 'Caapucu', 'Caapucu,Caapucú', -26.2166700, -57.2000000, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113731, 'Caaguazú', 'Caaguazu', 'Caaguazu,Caaguazú', -25.4500000, -56.0166700, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113732, 'Caacupé', 'Caacupe', 'Caacupe,Caacupé,Kaakupe,ka ku pei,kakupe,kayakwph,Каакупе,کائاکوپه,کاکوپے,კააკუპე,卡庫佩,카쿠페', -25.3857500, -57.1421700, 'PY', '2014-12-28', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113733, 'Buena Vista', 'Buena Vista', 'Buena Vista', -26.1833300, -56.0833300, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113734, 'Benjamín Aceval', 'Benjamin Aceval', 'Benjamin Aceval,Benjamín Aceval,Colonia Aceval,Colonia Benjamin Aceval,Colonia Benjamín Aceval', -24.9666700, -57.5666700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113735, 'Bella Vista', 'Bella Vista', 'Bella Vista,Bella Vista de Alto Parana,Bella Vista de Alto Paraná,Colonia Bella Vista', -27.0500000, -55.5500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113736, 'Bella Vista', 'Bella Vista', 'Bella Vista', -22.1333300, -56.5166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113737, 'Belén', 'Belen', 'Belen,Belén', -23.4661100, -57.2619400, 'PY', '2012-02-02', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113738, 'Ayolas', 'Ayolas', 'AYO,Ayolas,Juan De Ayolas', -27.4000000, -56.9000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113739, 'Atyrá', 'Atyra', '', -25.2500000, -57.1666700, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113740, 'Asunción', 'Asuncion', 'ASU,Asounsion,Asounsyon,Asounsyòn,Asounthion,Assumptio,Assuncao,Assuncion,Assunção,Asuncion,Asunciono,Asunción,Asuns''jon,Asuns''on,Asunsaun,Asunsion,Asunsjon,Asunsjona,Asunsjonas,Asunson,Asunsyon,Asunsyun,Asúnsjón,Gorad Asuns''jon,Gunung Berapi Asuncion,La Muy Noble y Leal Ciudad de Nuestra Senora Santa Maria de la Asuncion,La Muy Noble y Leal Ciudad de Nuestra Señora Santa María de la Asunción,Nuestra Senora Santa Maria de la Asuncion,Nuestra Señora Santa María de la Asunción,Paraguay,acunciyon,asnshn,asunshion,asunsion,asunsioni,asunsiyona,asusi''ona,aswnsywn,xa sun si xxng,ya song sen,Ασουνθιόν,Ασουνσιόν,Асунсион,Асунсьйон,Асунсьон,Горад Асунсьён,Ասունսյոն,אסונסיאן,אסונסיון,آسونسیون,أسونسيون,ئاسۇنسىئون,اسنشن,اسونسیون,आसुन्सियोन,ਅਸੂੰਸੀਓਨ,அசுன்சியோன்,ಅಸೂನ್‌ಸಿಯಾನ್,อะซุนซิออง,ཨ་སུན་སི་འན།,ასუნსიონი,አሱንሲዮን,アスンシオン,亞松森,아순시온', -25.3006600, -57.6359100, 'PY', '2010-07-06', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113741, 'Arroyos y Esteros', 'Arroyos y Esteros', 'Arroyos y Esteros', -25.0666700, -57.1000000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113742, 'Arquitecto Tomás Romero Pereira', 'Arquitecto Tomas Romero Pereira', '', -26.4833300, -55.2500000, 'PY', '2006-01-17', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113743, 'Areguá', 'Aregua', 'Aregua,Areguá', -25.3125000, -57.3847200, 'PY', '2012-04-05', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113744, 'Antequera', 'Antequera', 'Antequera,Colonia Antequera,Puerto Antequera', -24.1333300, -57.0833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113745, 'Altos', 'Altos', 'Altos', -25.2626300, -57.2544300, 'PY', '2015-06-13', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113746, 'Acahay', 'Acahay', 'Acahai,Acahay,Acahaí', -25.9166700, -57.1500000, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113747, 'Abaí', 'Abai', 'Abai,Abay,Abaí', -26.0333300, -55.9333300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113748, 'Horqueta', 'Horqueta', 'Horqueta', -23.3427800, -57.0597200, 'PY', '2012-01-20', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113749, 'Filadelfia', 'Filadelfia', 'Colonia Filadelfia,FLM,Filadelfia,Filadelfija,Filadelfio,Philadelphia', -22.3393600, -60.0315700, 'PY', '2015-06-14', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113750, 'Colonia Neuland', 'Colonia Neuland', 'Colonia Neuland', -22.6666700, -60.1166700, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113751, 'Capitán Pablo Lagerenza', 'Capitan Pablo Lagerenza', 'Capitan Pablo Lagerenza,Capitán Pablo Lagerenza,Fortin Ingavi,Fortín Ingavi,Ingavi,Lagerenza,Mayor Pablo Lagerenza,Mayor Paulo Lagerenza', -19.9166700, -60.7833300, 'PY', '2012-01-18', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113752, 'Nueva Esperanza', 'Nueva Esperanza', '', -24.5076000, -54.8551000, 'PY', '2016-08-03', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113753, 'Colonia San Lorenzo', 'Colonia San Lorenzo', '', -26.4932400, -54.7998900, 'PY', '2017-04-25', 173);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113235, 'Arraiolos', 'Arraiolos', 'Arraiolos', 38.7236300, -7.9847800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113236, 'Armação de Pêra', 'Armacao de Pera', 'Armacao de Pera,Armação de Pêra', 37.1025600, -8.3569500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113237, 'Arco da Calheta', 'Arco da Calheta', 'Arco da Calheta,Arco da Calheta  Madeira,Arku-da-Kal''eta,Арку-да-Кальета', 32.7150200, -17.1497400, 'PT', '2016-11-23', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113238, 'Apelação', 'Apelacao', '', 38.8138700, -9.1322500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113239, 'Ansião', 'Ansiao', 'Anciao,Ancião,Ansiao,Ansião', 39.9117700, -8.4356800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113240, 'Amora', 'Amora', 'Amora', 38.6296100, -9.1155700, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113241, 'Amor', 'Amor', '', 39.8040400, -8.8598400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113242, 'Amadora', 'Amadora', 'Amadora,Αμαδόρα,Амадора', 38.7538200, -9.2308300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113243, 'Alvor', 'Alvor', '', 37.1299400, -8.5917400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113244, 'Alvito', 'Alvito', 'Alvito', 38.2561100, -7.9915800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113245, 'Alvaiázere', 'Alvaiazere', 'Alvaiazere,Alvaiázere', 39.8225600, -8.3799900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113246, 'Alter do Chão', 'Alter do Chao', '', 39.1974100, -7.6589300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113247, 'Alpiarça', 'Alpiarca', 'Alpiarca,Alpiarça', 39.2571200, -8.5818700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113248, 'Almodôvar', 'Almodovar', 'Almodovar,Almodôvar', 37.5127900, -8.0600800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113249, 'Almeirim', 'Almeirim', 'Almeirim', 39.2090300, -8.6164300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113250, 'Almargem', 'Almargem', 'Almargem,Almargem do Bispo', 38.8448500, -9.2731500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113251, 'Almancil', 'Almancil', 'Almancil,Almansil,Алмансил', 37.0868600, -8.0307400, 'PT', '2015-11-13', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113252, 'Almada', 'Almada', 'Almada,Almanta,Αλμάντα,Алмада', 38.6790200, -9.1569000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113253, 'Aljustrel', 'Aljustrel', 'Aljustrel', 37.8775900, -8.1651600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113254, 'Aljubarrota', 'Aljubarrota', 'Aljubarrota', 39.5671500, -8.9292500, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113255, 'Aljezur', 'Aljezur', 'Aljezur', 37.3191500, -8.8033000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113256, 'Alhos Vedros', 'Alhos Vedros', 'Alhos Vedros', 38.6548600, -9.0236800, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113257, 'Alhandra', 'Alhandra', 'Alhandra', 38.9273200, -9.0086400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113258, 'Algés', 'Alges', 'Alges,Algés', 38.7024500, -9.2293600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113259, 'Alferrarede', 'Alferrarede', 'Alferrarede', 39.4833300, -8.1666700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113260, 'Alenquer', 'Alenquer', 'Alenquer', 39.0531500, -9.0092800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113261, 'Alegrete', 'Alegrete', '', 39.2398300, -7.3234200, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113262, 'Aldeia de Paio Pires', 'Aldeia de Paio Pires', 'Aldea de Paio Pires,Aldeia de Paio Pires,Paio Pires', 38.6166700, -9.0833300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113263, 'Alcoutim', 'Alcoutim', 'Alcoutim', 37.4743200, -7.4722800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113264, 'Alcoentre', 'Alcoentre', '', 39.2085700, -8.9595300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113265, 'Alcochete', 'Alcochete', 'Alcochete', 38.7553400, -8.9608600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113266, 'Alcobaça', 'Alcobaca', 'Alcobaca,Alcobaça', 39.5522300, -8.9774900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113267, 'Alcanena', 'Alcanena', 'Alcanena,Alkanena,a er ka nei na,alkanyna,Алканена,الکانینا,阿尔卡内纳', 39.4590000, -8.6689200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113268, 'Alcanede', 'Alcanede', 'Alcanede', 39.4150100, -8.8218900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113269, 'Alcains', 'Alcains', 'Alcains', 39.9164200, -7.4565500, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113270, 'Alcácer do Sal', 'Alcacer do Sal', 'Alcacer da Sal,Alcacer do Sal,Alcácer da Sal,Alcácer do Sal,Alkaser-du-Sal,Beuibum,Beuipum,Bevipo,Cantnipo,Eviam,Evion,Keition,Ketivion,Ketouibon,Ketovibon,Ketovion,alkasr dw sal,alkasr dwsal,Алкасер-ду-Сал,آلکاسر دوسال,الكاسر دو سال,ალკასერ-დუ-სალი,アルカセル・ド・サル', 38.3732600, -8.5144400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113271, 'Alcabideche', 'Alcabideche', 'Alcabideche,Alkabideshe,Aloabideche,Aloabidèche,Алкабидеше', 38.7336600, -9.4092800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113272, 'Albufeira', 'Albufeira', 'Albufeira,Albufejra,albwfyra,Албуфейра,آلبوفیرا', 37.0881900, -8.2503000, 'PT', '2015-11-13', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113273, 'Alandroal', 'Alandroal', 'Alandroal', 38.7020000, -7.4030900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113274, 'Alagoa', 'Alagoa', '', 39.3612500, -7.5389400, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113275, 'A dos Cunhados', 'A dos Cunhados', 'A dos Cunhados,Aldeia dos Cunhados', 39.1523700, -9.2972000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113276, 'Abrantes', 'Abrantes', 'Abrantes,Abrantish,Gorad Abrantysh,a bu lan te shen,abrants,aburantesu,Абрантиш,Абрантіш,Горад Абрантыш,آبرانتس,ابرانتس,აბრანტეში,アブランテス,阿布兰特什', 39.4666700, -8.2000000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113277, 'Vouzela', 'Vouzela', 'Vouzela', 40.7236100, -8.1128300, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113278, 'Vizela', 'Vizela', 'Sao Faustino,São Faustino,Vizela,Визела', 41.3909600, -8.2638900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113279, 'Vizela', 'Vizela', 'Sao Jorge,São Jorge,Vizela,Визела', 41.3824200, -8.2488700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113280, 'Viseu', 'Viseu', 'VSE,Viseu,Vizeu,Vizeu Celorico,Визеу', 40.6610100, -7.9097100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113281, 'Vinhais', 'Vinhais', 'Vin''jajsh,Vinhaes,Vinhais,wei ni ai shen,Виньяйш,Віньяйш,维尼艾什', 41.8350900, -7.0050100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113282, 'Vimioso', 'Vimioso', 'Vimioso', 41.5847300, -6.5276700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113283, 'Vilela', 'Vilela', '', 41.2251100, -7.6033800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113284, 'Vila Verde', 'Vila Verde', 'Vila Verde', 41.6472900, -8.4371500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113285, 'Vilarinho', 'Vilarinho', 'Vilarinho', 41.3595500, -8.3312300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113286, 'Vila Real', 'Vila Real', 'Bila Real,Bila Rial,VRL,Vila Real,Vila Realas,Vila-Real,lei a er cheng,vila-reali,wyla ryal,Βίλα Ρεάλ,Вила Реал,Вила-Реал,ویلا رئال,ვილა-რეალი,ヴィラ・レアル,雷阿爾城', 41.3006200, -7.7441300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113287, 'Vilar do Paraíso', 'Vilar do Paraiso', 'Vilar do Paraiso,Vilar do Paraíso', 41.0897400, -8.6211000, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113288, 'Vilar de Andorinho', 'Vilar de Andorinho', 'Andorinho,Vilar de Andorinha,Vilar de Andorinho,Villar d''Andorinha,Villar d''Andorinho,Villar d’Andorinha,Villar d’Andorinho', 41.1075100, -8.5963200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113289, 'Vila Praia de Âncora', 'Vila Praia de Ancora', 'Ancora,Praia de Ancora,Praia de Âncora,Vila Praia de Ancora,Vila Praia de Âncora,Âncora', 41.8109800, -8.8525500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113290, 'Vila Pouca de Aguiar', 'Vila Pouca de Aguiar', 'Vila Pouca de Aguiar', 41.5001800, -7.6438300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113291, 'Vila Nova de Paiva', 'Vila Nova de Paiva', 'Barrellas,Vila Nova de Paiva', 40.8529100, -7.7279100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113292, 'Vila Nova de Gaia', 'Vila Nova de Gaia', 'Bila Noba nte Nkaia,Gaia,Portus Cale,Vila Nova de Gaia,Vila-Nova-de-Gajja,Βίλα Νόβα ντε Γκάια,Вила-Нова-де-Гайя', 41.1336300, -8.6174200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113293, 'Vila Nova de Foz Côa', 'Vila Nova de Foz Coa', 'Vila Nova de Foz Coa,Vila Nova de Foz Côa,Villa Nova de Foscoa,Villa Nova de Foscôa', 41.0833300, -7.2000000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113294, 'Vila Nova de Famalicão', 'Vila Nova de Famalicao', 'Famalicao,Famalicão,Vila Nova de Famalicao,Vila Nova de Famalicão,Vila Nova de Tamalicao,Vila Nova de Tamalicão', 41.4079700, -8.5197800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113295, 'Vila Nova da Telha', 'Vila Nova da Telha', '', 41.0717000, -8.6414600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113296, 'Vila Nova de Cerveira', 'Vila Nova de Cerveira', 'Vila Nova da Cereira,Vila Nova da Cerveira,Vila Nova de Cerveira,Vila Nova do Cerveira', 41.9411800, -8.7423000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113297, 'Vila Frescainha', 'Vila Frescainha', 'Sao Martinho,Sao Martinho Vila Frescainha,São Martinho,São Martinho Vila Frescainha,Vila Frescainha', 41.5384600, -8.6397100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113298, 'Vila do Conde', 'Vila do Conde', 'Bila nto Konte,Vila do Conde,Vila do Conde Municipality,Vila do Konde,Vila do Kondė,Vila-du-Konde,Vila-du-Kondi,kong di zhen,wyla dw kndh,Βίλα ντο Κόντε,Вила-ду-Конде,Вила-ду-Конди,ویلا دو کنده,ვილა-დუ-კონდე,孔迪镇', 41.3548100, -8.7434000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113299, 'Vila Chã', 'Vila Cha', '', 40.8666700, -8.4666700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113300, 'Vieira do Minho', 'Vieira do Minho', 'Vieira,Vieira do Minho', 41.6329200, -8.1425200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113301, 'Viana do Castelo', 'Viana do Castelo', 'Viana do Castelo,Vianna do Castello', 41.6932300, -8.8328700, 'PT', '2016-10-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113302, 'Valpaços', 'Valpacos', 'Valpacos,Valpassos,Valpaços', 41.6074600, -7.3108800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113303, 'Valongo', 'Valongo', 'Valonga,Valongo,Valongu,Валонгу', 41.1950100, -8.5102700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113304, 'Valongo', 'Valongo', '', 40.6166700, -8.4500000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113305, 'Valença', 'Valenca', 'Valenca,Valença', 42.0310400, -8.6459500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113306, 'Válega', 'Valega', '', 40.8362900, -8.5806100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113307, 'Vale de Cambra', 'Vale de Cambra', 'Vale de Cambra,Vila de Vale de Cambra', 40.8497000, -8.3938900, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113308, 'Valbom', 'Valbom', '', 41.1324700, -8.5641400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113309, 'Valadares', 'Valadares', '', 41.1473700, -7.9812000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113310, 'Vagos', 'Vagos', 'Vagos', 40.5560000, -8.6817500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113311, 'Urgeses', 'Urgeses', '', 41.4272000, -8.2979600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113312, 'Trancoso', 'Trancoso', 'Trancoso', 40.7832900, -7.3501600, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113313, 'Torre de Moncorvo', 'Torre de Moncorvo', 'Moncorvo,Torre de Moncorvo', 41.1745400, -7.0536400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113314, 'Tondela', 'Tondela', 'Tondela,tong de la,twndla,Тондела,توندلا,ტონდელა,通德拉', 40.5168200, -8.0808700, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113315, 'Terras de Bouro', 'Terras de Bouro', 'Terras de Bouro', 41.7176900, -8.3088800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113316, 'Telões', 'Teloes', '', 41.3105400, -8.1110100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113317, 'Teixoso', 'Teixoso', '', 40.3144800, -7.4575900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113318, 'Tavarede', 'Tavarede', 'Tavarede', 40.1707900, -8.8456600, 'PT', '2013-04-03', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113319, 'Tarouca', 'Tarouca', 'Tarouca', 41.0144400, -7.7814300, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113320, 'Tabuaço', 'Tabuaco', 'Taboaco,Taboaço,Tabuaco,Tabuaço', 41.1161500, -7.5679300, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113321, 'Tábua', 'Tabua', 'Taboa,Tabua,Táboa,Tábua', 40.3620700, -8.0293600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113322, 'Souto', 'Souto', '', 40.9867500, -8.6223000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113323, 'Soure', 'Soure', 'Perbandaran Soure,Sori,Soure,Soure Municipality,saure,Σούρε,Сори,সৌরে', 40.0598900, -8.6260500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113324, 'Sobreira', 'Sobreira', '', 41.5237100, -7.8023400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113325, 'Sobrado', 'Sobrado', '', 41.2104100, -8.4548800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113326, 'Cinfães', 'Cinfaes', 'Cinfaes,Cinfães,Sinfaes,Sinfais,Sinfães,Sinfãis', 41.0719700, -8.0899900, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113327, 'Silvalde', 'Silvalde', '', 40.9939700, -8.6260800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113328, 'Sever do Vouga', 'Sever do Vouga', 'Sever,Sever do Vouga', 40.7345900, -8.3672200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113329, 'Serzedo', 'Serzedo', '', 41.4050200, -8.2292600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113330, 'Serzedelo', 'Serzedelo', 'Cerzedelo,Serzedelo', 41.4012800, -8.3688800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113331, 'Seroa', 'Seroa', '', 41.2651100, -8.4289200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113332, 'Sernancelhe', 'Sernancelhe', 'Sernancelhe', 40.8987100, -7.4934200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113333, 'Sequeira', 'Sequeira', '', 40.5536400, -7.2259400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113334, 'Senhora da Hora', 'Senhora da Hora', 'Senhora da Hora', 41.1864100, -8.6517200, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113335, 'Selho', 'Selho', 'Sao Cristovao,Selho,São Cristóvão', 41.4193800, -8.3459900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113336, 'Seia', 'Seia', 'Seia', 40.4151000, -7.7085900, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113337, 'Sátão', 'Satao', 'Satam,Satao,Sátão,Vila da Igreja,Vila de Igreja', 40.7417700, -7.7328500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113338, 'São Roque', 'Sao Roque', '', 40.8721600, -8.4714900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113339, 'São Romão do Coronado', 'Sao Romao do Coronado', 'Coronado,Sao Romao do Coronado,São Romão do Coronado', 41.2854400, -8.5632000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113340, 'São Pedro do Sul', 'Sao Pedro do Sul', 'Santo Pedro do Sul,Sao Pedro do Sul,São Pedro do Sul', 40.7553700, -8.0726500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113341, 'São Pedro da Cova', 'Sao Pedro da Cova', '', 41.1550800, -8.5041200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113342, 'São Miguel do Couto', 'Sao Miguel do Couto', 'Sao Miguel do Couto,São Miguel do Couto', 41.3316700, -8.4618500, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113343, 'São Mamede de Infesta', 'Sao Mamede de Infesta', 'San-Mamed-de-Infeshta,Santo Mamede de Infesta,Sao Mamede,Sao Mamede da Infesta,Sao Mamede de Infesta,São Mamede,São Mamede da Infesta,São Mamede de Infesta,Сан-Мамед-де-Инфешта', 41.2004200, -8.6025100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113344, 'São João de Ver', 'Sao Joao de Ver', 'Sao Joao de Ver,São João de Ver', 40.9552700, -8.5511700, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113345, 'São João da Pesqueira', 'Sao Joao da Pesqueira', 'Sao Joao da Pesqueira,São João da Pesqueira', 41.1480500, -7.4048900, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113346, 'São João da Madeira', 'Sao Joao da Madeira', 'San-Zhuan-da-Madejra,Santo Joao da Madeira,Santo João da Madeira,Sao Joao da Madeiro,Sao Joao de Madeira,São João da Madeiro,São João de Madeira,Сан-Жуан-да-Мадейра', 40.9022900, -8.4896900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113347, 'São João', 'Sao Joao', '', 40.8680200, -8.6067200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113348, 'São Félix da Marinha', 'Sao Felix da Marinha', 'Marinha,Sao Felix da Marinha,São Félix da Marinha', 41.0355500, -8.6225900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113349, 'Santo Tirso', 'Santo Tirso', 'Santo Tirso', 41.3425700, -8.4774600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113350, 'Santa Marta de Penaguião', 'Santa Marta de Penaguiao', 'Santa Marta de Penaguiao,Santa Marta de Penaguião,Santa Martha de Penaguiao,Santa Martha de Penaguião', 41.2111600, -7.8001100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113351, 'Santa Cruz do Bispo', 'Santa Cruz do Bispo', '', 41.2255000, -8.6836100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113352, 'Santa Comba Dão', 'Santa Comba Dao', 'Santa Comba Dao,Santa Comba Dão', 40.3985600, -8.1316000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113353, 'Sangalhos', 'Sangalhos', 'Sangalhos', 40.4867800, -8.4696800, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113354, 'Sandim', 'Sandim', '', 41.0350800, -8.5070000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113355, 'Sande', 'Sande', '', 41.7019000, -8.3924600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113356, 'Salreu', 'Salreu', '', 40.7397100, -8.5572000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113357, 'Sabugal', 'Sabugal', 'Sabugal,sa bu jia er,sabwgal,Сабугал,سابوگال,سبگل بلدیہ,薩布加爾', 40.3512700, -7.0910400, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113358, 'Sabrosa', 'Sabrosa', 'Sabrosa', 41.2670200, -7.5760100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113359, 'Ronfe', 'Ronfe', 'Ronfe,Roufe', 41.4414600, -8.3841200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113360, 'Rio Tinto', 'Rio Tinto', 'Rio Tinto,Rio Tinto i Portugal,Riu-Tintu,li ao ting tuo,ryw tyntw,Риу-Тинту,ریو تینتو,რიო-ტინტო,里奧廷托', 41.1825900, -8.5581100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113361, 'Rio Meão', 'Rio Meao', 'Rio Meao,Rio Meão', 40.9577500, -8.5781800, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113362, 'Rio de Loba', 'Rio de Loba', '', 40.6659600, -7.8778100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113363, 'Ribeirão', 'Ribeirao', '', 41.3608100, -8.5677400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113364, 'Ribeira de Pena', 'Ribeira de Pena', 'Ribeira da Pena,Ribeira de Pena', 41.5214700, -7.8023700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113365, 'Resende', 'Resende', 'Resende,Rezende', 41.1058200, -7.9665000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113366, 'Refojos de Basto', 'Refojos de Basto', '', 41.5131800, -7.9951700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113367, 'Recarei', 'Recarei', 'Recarei', 41.1535600, -8.4117800, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113368, 'Rebordosa', 'Rebordosa', 'Rebordosa,Rebordoza', 41.2240500, -8.4066900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113369, 'Real', 'Real', '', 41.6388200, -8.1809800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113370, 'Prado', 'Prado', '', 41.6015300, -8.4713700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113371, 'Póvoa de Varzim', 'Povoa de Varzim', 'Poboa nte Barzim,Povoa de Varzim,Povua de Varzinas,Povua-di-Varzin,Póvoa de Varzim,Villa Euracini,bo wa-di wa er jin,pwwa dwarzym,Πόβοα ντε Βαρζίμ,Повоа де Варзим,Повуа-ди-Варзин,پووا دوارزیم,პოვუა-დე-ვარშინი,波瓦-迪瓦爾津', 41.3834400, -8.7636400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113372, 'Póvoa de Lanhoso', 'Povoa de Lanhoso', '', 41.5787300, -8.2819700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113373, 'Porto', 'Porto', 'OPO,Oporto,Porto,Portu,Portus Cale,bo tu,bwrtw,poruto,pwrtw,Πορτο,Πόρτο,Порто,Порту,פורטו,بورتو,پورتو,პორტუ,ポルト,波圖', 41.1496100, -8.6109900, 'PT', '2017-06-13', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113374, 'Ponte de Lima', 'Ponte de Lima', 'Ponte de Lima,Ponte do Lima,Понте де Лима', 41.7671900, -8.5839300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113375, 'Ponte da Barca', 'Ponte da Barca', 'Ponte da Barca,Ponte de Barca,Ponte-da-Barka,Ponti-da-Barka,Puonte de la Barca,peng di da ba er ka,Понте-да-Барка,Понти-да-Барка,蓬蒂達巴爾卡', 41.8045100, -8.4155400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113376, 'Ponte', 'Ponte', '', 41.4705700, -8.3299000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113377, 'Poiares', 'Poiares', 'Poiares,Vila Nova de Poiares', 40.2102600, -8.2574600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113378, 'Pinhel', 'Pinhel', 'Pinhel', 40.7740300, -7.0667500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113379, 'Peso da Régua', 'Peso da Regua', 'Peso da Regua,Peso da Regua Municipality,Peso da Régua,Peso da Régua Municipality,Peso de la Regua,Peso de la Régua,Pezu-da-Regua,Regoa,Regua,Régua,psw da rgwa,Пезу-да-Регуа,پسو دا رگوا,პეზუ-და-რეგუა', 41.1649100, -7.7870300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113380, 'Perozinho', 'Perozinho', 'Perosinho,Perozinho', 41.0651300, -8.5853100, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113381, 'Perafita', 'Perafita', '', 41.1825200, -8.2545000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113382, 'Penela', 'Penela', 'Penela', 40.0333300, -8.3833300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113383, 'Penedono', 'Penedono', 'Penedono', 40.9887500, -7.3938600, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113384, 'Penamacor', 'Penamacor', 'Penamacor', 40.1689500, -7.1698700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113385, 'Penafiel', 'Penafiel', 'Penafiel,Penafjelis,Penaphiel,pei na fei ye er,Πεναφιέλ,Пенафиел,პენაფიელი,佩納菲耶爾', 41.2083500, -8.2828500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113386, 'Penacova', 'Penacova', 'Penacova', 40.2688400, -8.2823700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113387, 'Pedrouços', 'Pedroucos', 'Pedroucos,Pedrouços', 41.1931500, -8.5816700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113388, 'Pedroso', 'Pedroso', '', 41.4110300, -8.7489700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113389, 'Paredes de Coura', 'Paredes de Coura', 'Parade de Coura,Parades de Coura,Paredes de Coura', 41.9101300, -8.5609400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113390, 'Paredes', 'Paredes', 'Paredes', 41.2048500, -8.3314700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113391, 'Pardilhó', 'Pardilho', '', 40.7992500, -8.6259800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113392, 'Pampilhosa do Botão', 'Pampilhosa do Botao', 'Pampilhosa,Pampilhosa do Bobao,Pampilhosa do Bobão,Pampilhosa do Botao,Pampilhosa do Botão', 40.3358000, -8.4273800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113393, 'Pampilhosa da Serra', 'Pampilhosa da Serra', 'Pampilhosa,Pampilhosa da Serra,Pampiliosa nta Sera,Παμπιλιόσα ντα Σέρα', 40.0462000, -7.9518200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113394, 'Paços de Ferreira', 'Pacos de Ferreira', 'Pacos de Ferreira,Pasos nte Phereira,Paços de Ferreira,Πάσος ντε Φερέϊρα', 41.2765700, -8.3761700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113395, 'Paços de Brandão', 'Pacos de Brandao', 'Pacos de Brandao,Paços de Brandão', 40.9754100, -8.5835000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113396, 'Ovar', 'Ovar', 'Ovar,Овар', 40.8586200, -8.6251300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113397, 'Oliveirinha', 'Oliveirinha', '', 40.6071500, -8.5919800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113398, 'Oliveira do Hospital', 'Oliveira do Hospital', 'Olibeira nto Ospital,Oliveira do Hospital,Olivejra-du-Oshpital,ao li wei la du ao shen pi ta er,awlywyra dw haspytal,Ολιβέιρα ντο Όσπιταλ,Оливейра-ду-Ошпитал,اولیویرا دو هاسپیتال,ოლივეირა-დუ-ოშპიტალი,奧利韋拉杜奧什皮塔爾', 40.3618000, -7.8601400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113399, 'Oliveira do Douro', 'Oliveira do Douro', '', 41.1246600, -8.5846300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113400, 'Oliveira do Bairro', 'Oliveira do Bairro', 'Oliveira de Bairro,Oliveira do Bairro', 40.5146000, -8.4938600, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113401, 'Oliveira de Frades', 'Oliveira de Frades', 'Oliveira de Frades', 40.7335700, -8.1748100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113402, 'Oliveira de Azemeis', 'Oliveira de Azemeis', 'Oliveira de Azemeis,Oliveira de Azeméis,Olivejra-di-Azemejsh,Оливейра-ди-Аземейш', 40.8410100, -8.4755500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113403, 'Oliveira', 'Oliveira', '', 41.4781900, -8.4696500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113404, 'Olival', 'Olival', '', 41.0502400, -8.5441600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113405, 'Oiã', 'Oia', '', 40.5426400, -8.5385600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113406, 'Nogueira da Regedoura', 'Nogueira da Regedoura', 'Nogueira,Nogueira da Regedoura', 41.0053000, -8.5919500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113407, 'Nogueira', 'Nogueira', '', 41.2424600, -8.5868500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113408, 'Nelas', 'Nelas', 'Nelas', 40.5321600, -7.8515200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113409, 'Negrelos', 'Negrelos', 'Negrelos,Sao Tome,São Tomé', 41.3494600, -8.4014500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113410, 'Murtosa', 'Murtosa', 'Murtosa', 40.7369500, -8.6377000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113411, 'Murça', 'Murca', '', 41.4060000, -7.4548500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113412, 'Mozelos', 'Mozelos', '', 41.8677400, -8.3977600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113413, 'Mortágua', 'Mortagua', 'Mortagua,Mortágua', 40.3967500, -8.2323400, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113414, 'Moreira de Conegos', 'Moreira de Conegos', 'Moreira de Conegos', 41.3868000, -8.3394000, 'PT', '2012-02-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113415, 'Moreira', 'Moreira', '', 41.0560000, -8.3893900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113416, 'Montemor-o-Velho', 'Montemor-o-Velho', 'Montemor-o-Vel''ju,Montemor-o-Velho,Montemor-u-Vel''ju,jiu meng te mo er,Монтемор-о-Велью,Монтемор-у-Велью,მონტემორ-უ-ველიუ,舊蒙特莫爾', 40.1728700, -8.6861600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113417, 'Montalegre', 'Montalegre', 'Montalegre', 41.8235700, -7.7897100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113418, 'Mondim de Basto', 'Mondim de Basto', 'Mondim,Mondim de Basto', 41.4115700, -7.9544100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113419, 'Monção', 'Moncao', 'Moncao,Monsao,Monsão,Monção', 42.0789200, -8.4807600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113420, 'Moimenta da Beira', 'Moimenta da Beira', 'Moimenta da Beira,Moimenta do Beira', 40.9838300, -7.6176500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113421, 'Mogadouro', 'Mogadouro', '', 41.3403400, -6.7118700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113422, 'Mirandela', 'Mirandela', 'Mirandela,Mirandella,Мирандела', 41.4873900, -7.1869500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113423, 'Miranda do Douro', 'Miranda do Douro', 'Miranda,Miranda de l Douro,Miranda del Douro,Miranda del Duero,Miranda do Doras,Miranda do Douro,Miranda l Douro,Miranda-du-Doru,miranda-du-doru,myranda dwdwywrw,Миранда-ду-Дору,Міранда-ду-Дору,میراندا دودوئورو,მირანდა-დუ-დორუ,ミランダ・ド・ドウロ', 41.4969200, -6.2730800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113424, 'Miranda do Corvo', 'Miranda do Corvo', 'Miranda do Corvo,Miranta nto Korbo,Μιράντα ντο Κόρβο', 40.0931800, -8.3326100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113425, 'Mira', 'Mira', 'Dunas de Mira,Mira', 40.4289200, -8.7374600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113426, 'Milheirós de Poiares', 'Milheiros de Poiares', 'Milheiros de Poiares,Milheirós de Poiares', 40.9216300, -8.4678800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113427, 'Milheirós', 'Milheiros', '', 41.2147800, -8.5883700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113428, 'Mesão Frio', 'Mesao Frio', 'Mesao Frio,Mesão Frio', 41.1631700, -7.8735300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113429, 'Melgaço', 'Melgaco', 'Melgaco,Melgaço', 42.1133700, -8.2601600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113430, 'Meinedo', 'Meinedo', '', 41.2482700, -8.2580700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113431, 'Mêda', 'Meda', 'Meda,Mêda', 40.9663500, -7.2616300, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113432, 'Mealhada', 'Mealhada', 'Mealhada', 40.3780600, -8.4499100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113433, 'Meadela', 'Meadela', '', 41.7065400, -8.7962800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113434, 'Matosinhos', 'Matosinhos', 'Matosinhos,Matosinhos Municipality,Matozin''jush,Matozinhos,Matozinjosas,matwsynws,Матозиньюш,ماتوسینوس,მატოზინიუში', 41.1820700, -8.6890800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113435, 'Marinhas', 'Marinhas', '', 41.5590600, -8.7829700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113436, 'Margaride', 'Margaride', '', 41.3682900, -8.2007200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113437, 'Marco de Canavezes', 'Marco de Canavezes', 'Marco de Cana,Marco de Canaveses,Marco de Canavezes', 41.1838900, -8.1486400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113438, 'Manteigas', 'Manteigas', 'Manteigas,Mantejgas,Мантейгас', 40.4028000, -7.5397700, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113439, 'Mangualde', 'Mangualde', 'Mangualde,Mangualdi,mangualdi,mangwlad,Мангуалде,Мангуалди,مانگولاد,მანგუალდი', 40.6042500, -7.7611500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113440, 'Maia', 'Maia', 'Maia,Majja,Майя', 41.2357400, -8.6199000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113441, 'Madalena', 'Madalena', '', 41.2161600, -8.3345100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113442, 'Macieira de Cambra', 'Macieira de Cambra', '', 40.8593900, -8.3733800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113443, 'Macedo de Cavaleiros', 'Macedo de Cavaleiros', 'Macedo de Cavaleiros', 41.5381600, -6.9611000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113444, 'Lustosa', 'Lustosa', '', 41.3408100, -8.3171500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113445, 'Luso', 'Luso', 'Luso,Lusu,Лусу', 40.3842900, -8.3784500, 'PT', '2015-05-12', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113446, 'Lousada', 'Lousada', 'Lousada,Louzada', 41.2782200, -8.2799300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113447, 'Lousã', 'Lousa', 'Lousa,Lousã,Louza,Louzã,Λούζα', 40.1167300, -8.2492100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113448, 'Lourosa', 'Lourosa', 'Lourosa,Louroza', 40.9842000, -8.5514200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113449, 'Lorvão', 'Lorvao', 'Lorvao,Lorvão', 40.2593800, -8.3168300, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113450, 'Lordelo', 'Lordelo', 'Lordello,Lordelo', 41.3741100, -8.3801600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113451, 'Lordelo', 'Lordelo', '', 41.2345100, -8.4029700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113452, 'Lobão', 'Lobao', 'Lobao,Lobão', 40.9866400, -8.4856600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113453, 'Leça do Bailio', 'Leca do Bailio', 'Leca do Bailio,Leca do Balio,Leca do Belio,Leça do Bailio,Leça do Balio', 41.2145700, -8.6134800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113454, 'Leça da Palmeira', 'Leca da Palmeira', 'Leca,Leca da Palmeira,Leca de Palmeira,Leça,Leça da Palmeira,Leça de Palmeira', 41.1910000, -8.7002700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113455, 'Lavra', 'Lavra', '', 41.2593500, -8.7184900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113456, 'Lavos', 'Lavos', '', 40.0936300, -8.8282600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113457, 'Lamego', 'Lamego', 'Lamego', 41.0974100, -7.8099100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113458, 'Lamas', 'Lamas', '', 40.9859700, -8.5692300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113459, 'Jovim', 'Jovim', 'Jovim,Juvim', 41.1110200, -8.5190300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113460, 'Joane', 'Joane', 'Joane', 41.4390600, -8.4084600, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113461, 'Ílhavo', 'Ilhavo', 'Ilhavo,Ílhavo', 40.5999000, -8.6673200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113462, 'Gulpilhares', 'Gulpilhares', 'Gulpilhares', 41.0829200, -8.6267900, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113463, 'Guimarães', 'Guimaraes', 'Gimarajnsh,Guimaraes,Guimarais,Guimarães,Guimarãis,Nkimaraes,Γκιμαράες,Гимарайнш', 41.4444300, -8.2961900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113464, 'Guifões', 'Guifoes', '', 41.2003900, -8.6671900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113465, 'Guarda', 'Guarda', 'Guarda,guaruda,Гуарда,グアルダ', 40.5373300, -7.2657500, 'PT', '2013-08-05', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113466, 'Grijó', 'Grijo', 'Grijo,Grijó', 41.0283600, -8.5801700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113467, 'Gondomar', 'Gondomar', 'Gondomar,Гондомар', 41.1445400, -8.5322300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113468, 'Góis', 'Gois', 'Gois,Góis', 40.1573500, -8.1100700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113469, 'Godim', 'Godim', '', 41.1710400, -7.8030300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113470, 'Gemunde', 'Gemunde', '', 41.2676600, -8.6451500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113471, 'Gandra', 'Gandra', 'Gandra,Гандра', 41.2011600, -8.4337600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113472, 'Galegos', 'Galegos', 'Galegos,Santa Maria', 41.5626800, -8.5720400, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113473, 'Gafanha da Nazaré', 'Gafanha da Nazare', 'Gafanha,Gafanha da Nazare,Gafanha da Nazaré', 40.6362100, -8.7133800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113474, 'Gafanha da Encarnação', 'Gafanha da Encarnacao', '', 40.6180600, -8.7330300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113475, 'Fundão', 'Fundao', 'Fundao,Fundão', 40.1402500, -7.5013500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113476, 'Freixo de Espada à Cinta', 'Freixo de Espada a Cinta', 'Freisco de Espada a Cinta,Freisco de Espada à Cinta,Freixo de Espada Cinta,Freixo de Espada a Cinta,Freixo de Espada a Cinta Municipality,Freixo de Espada à Cinta,Freixo de Espada à Cinta Municipality,Freixo de Espado a Cinta,Frejshu-di-Ehshpada-a-Sinta,Frejshu-di-Eshpada-a-Sinta,Фрейшу-ди-Эшпада-а-Синта,Фрейшу-ді-Ешпада-а-Сінта', 41.0903300, -6.8064800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113477, 'Freamunde', 'Freamunde', 'Freamunde,Фреамунде', 41.2883500, -8.3353300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113478, 'Frazão', 'Frazao', 'Frazao,Frazão', 41.2586600, -8.4001400, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113479, 'Foz do Sousa', 'Foz do Sousa', '', 41.0966800, -8.5018400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113480, 'Fornos de Algodres', 'Fornos de Algodres', 'Fornos,Fornos d''Algodres,Fornos de Algodres,Fornos d’Algodres', 40.6280700, -7.5406400, 'PT', '2014-07-08', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113481, 'Figueiró', 'Figueiro', '', 41.2992200, -8.1677900, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113482, 'Figueira de Castelo Rodrigo', 'Figueira de Castelo Rodrigo', 'Figejra-di-Kashtelu-Rodrigu,Figueira de Castelo Rodrigo,Figueira de Castelo Rodrigo Municipality,Фигейра-ди-Каштелу-Родригу', 40.8926200, -6.9635000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113483, 'Figueira da Foz', 'Figueira da Foz', 'Figeira da Fosas,Figeira de Foz,Figejra-da-Fosh,Figueira da Foz,Figueira da Foz Municipality,Figueira de la Foc,Figueira de la Foç,Phinkeira nta Phous,fei gai la-da fu shen,fygwyra dafwsh,pigeiladaposeu,pigeira-da-poshi,Φιγκέιρα ντα Φους,Фигеира де Фоз,Фигейра-да-Фош,فیگوئرا دافوش,ფიგეირა-და-ფოში,菲蓋拉-達福什,피게이라다포스', 40.1508500, -8.8617900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113484, 'Fiães', 'Fiaes', 'Fiaes,Fiais,Fiães,Fiãis', 40.9944600, -8.5253700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113485, 'Ferreiros', 'Ferreiros', '', 41.3500000, -8.5500000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113486, 'Ferreira', 'Ferreira', '', 41.2671800, -8.3443400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113487, 'Felgueiras', 'Felgueiras', 'Felgueiras,Phelnkeiras,Φέλγκεϊρας', 41.3680600, -8.1939600, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113488, 'Feira', 'Feira', 'Feira', 40.9253500, -8.5427700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113489, 'Fânzeres', 'Fanzeres', 'Fanzeres,Fânzeres', 41.1708700, -8.5257000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113490, 'Fafe', 'Fafe', 'Fafe,Фафе', 41.4542300, -8.1680000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113491, 'Estarreja', 'Estarreja', 'Ehshtarrezha,Eshtarrezha,Estarreja,Starreija,ai si ta lei ya,astarzha,Ештаррежа,Эштаррежа,استارژا,ეშტარეჟა,埃斯塔雷雅', 40.7564800, -8.5720700, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113492, 'Esposende', 'Esposende', 'Esposende,Espozende', 41.5361000, -8.7820100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113493, 'Esposende', 'Esposende', 'Ehshpozende,Esposende,Espozende,Эшпозенде', 41.5333300, -8.7833300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113494, 'Espinho', 'Espinho', 'Ehshpin''ju,Espinho,Espinio,Espinjas,esupinyo,Εσπίνιο,Эшпинью,エスピーニョ', 41.0076300, -8.6412500, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113495, 'Esmoriz', 'Esmoriz', 'Esmoris', 40.9577300, -8.6275300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113496, 'Ermesinde', 'Ermesinde', 'Ehrmezinde,Ermezinde,Эрмезинде', 41.2217600, -8.5546200, 'PT', '2014-11-13', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113497, 'Eixo', 'Eixo', 'Eixo', 40.6275800, -8.5692200, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113498, 'Darque', 'Darque', 'Darque', 41.6833300, -8.7666700, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113499, 'Custoias', 'Custoias', '', 41.1053000, -7.3209700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113500, 'Cucujães', 'Cucujaes', 'Couto de Cocujaes,Couto de Cocujães,Cucujaes,Cucujães', 40.8741300, -8.5068700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113501, 'Covilhã', 'Covilha', 'COV,Covilha,Covilhã,Kovil''jan,Ковильян', 40.2860100, -7.5039600, 'PT', '2016-12-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113502, 'Cortegaça', 'Cortegaca', '', 40.9488300, -8.6213000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113503, 'Condeixa-a-Nova', 'Condeixa-a-Nova', 'Condeixa,Condeixa-a-Nova', 40.1157300, -8.4983400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113504, 'Coimbra', 'Coimbra', 'CBP,Coimbra,Coímbra,Coïmbra,Koimbra,Koimbro,Koimpra,Koímbra,ke ying bu la,koinbura,Κόιμπρα,Коимбра,コインブラ,科英布拉', 40.2056400, -8.4195500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113505, 'Chaves', 'Chaves', 'CHV,Chaves', 41.7401900, -7.4687900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113506, 'Celorico de Basto', 'Celorico de Basto', 'Celorico de Basto', 41.3871400, -8.0010100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113507, 'Celorico da Beira', 'Celorico da Beira', 'Celorico,Celorico da Beira', 40.6372300, -7.3903700, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113508, 'Castro Daire', 'Castro Daire', 'Castro Daire', 40.8984000, -7.9338100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113509, 'Castelões de Cepeda', 'Casteloes de Cepeda', 'Casteloes de Cepeda,Castelões de Cepeda', 41.2026500, -8.3351600, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113510, 'Castelo de Paiva', 'Castelo de Paiva', '', 41.0630100, -8.2647000, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113511, 'Carvalhosa', 'Carvalhosa', '', 41.3005700, -8.3608000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113512, 'Carregal do Sal', 'Carregal do Sal', '', 40.4333300, -8.0000000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113513, 'Carrazeda de Anciães', 'Carrazeda de Anciaes', '', 41.2424700, -7.3072100, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113514, 'Cantanhede', 'Cantanhede', 'Cantanhede', 40.3467100, -8.5941900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113515, 'Canidelo', 'Canidelo', 'Canidello,Canidelo', 41.1240200, -8.6510400, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113516, 'Canelas', 'Canelas', '', 41.0833300, -8.6000000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113517, 'Candoso', 'Candoso', 'Candoso,Santiago', 41.4276800, -8.3216600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113518, 'Campo', 'Campo', '', 41.1851600, -8.4649300, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113519, 'Campo', 'Campo', '', 40.7108600, -7.9144500, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113520, 'Calendário', 'Calendario', '', 41.4036100, -8.5296700, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113521, 'Caldelas', 'Caldelas', 'Caldelas', 41.6710100, -8.3814800, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113522, 'Caldas de Vizela', 'Caldas de Vizela', 'Caldas de Vizela,Sao Miguel,São Miguel', 41.3821200, -8.3089000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113523, 'Cabeceiras de Basto', 'Cabeceiras de Basto', 'Cabeceiras de Basto,Kabesejrash-di-Bashtu,ka bei sai la shen de ba shen tu,Кабесейраш-ди-Башту,Кабесейраш-ді-Башту,卡貝塞拉什德巴什圖', 41.5143100, -7.9894200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113524, 'Buarcos', 'Buarcos', 'Buarcos', 40.1660400, -8.8768000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113525, 'Brito', 'Brito', 'Brito', 41.4582100, -8.3610300, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113526, 'Branca', 'Branca', '', 40.7665300, -8.4826200, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113527, 'Bragança', 'Braganca', 'BGC,Braganca,Bragance,Bragança,Браганца', 41.8058200, -6.7571900, 'PT', '2017-01-29', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113528, 'Braga', 'Braga', 'BGZ,Bracara Augusta,Braga,Mpranka,braga,buraga,Μπράγκα,Брага,براگا,ブラガ', 41.5503200, -8.4200500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113529, 'Bougado', 'Bougado', '', 41.3397900, -8.5518000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113530, 'Boticas', 'Boticas', 'Boticas', 41.6898700, -7.6659400, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113531, 'Belmonte', 'Belmonte', '', 40.3593000, -7.3486900, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113532, 'Beduido', 'Beduido', '', 40.7642700, -8.5611000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113533, 'Barrosas', 'Barrosas', 'Barrosas,Santa Eulalia,Santa Eulália', 41.3553400, -8.2994300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113534, 'Barcelos', 'Barcelos', 'Barcelos,Barselos,Barselosas,Barselush,ba sai lu shen,barselosa,barselushi,barslws,barsylws,baruserosu,Барселос,Барселуш,بارسلوس,بارسيلوس,বার্সেলোস,ბარსელუში,バルセロス,巴塞卢什', 41.5387600, -8.6150500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113535, 'Baltar', 'Baltar', 'Baltar', 41.1851200, -8.3734400, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113536, 'Baião', 'Baiao', 'Baiao,Baião', 41.1627300, -8.0347000, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113537, 'Baguim do Monte', 'Baguim do Monte', 'Baguim,Baguim do Monte', 41.1939200, -8.5413300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113538, 'Azenha', 'Azenha', '', 41.0765100, -8.6246800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113539, 'Avintes', 'Avintes', 'Avintes', 41.1174700, -8.5498600, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113540, 'Aves', 'Aves', 'Aves', 41.3703400, -8.4101000, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113541, 'Aver-o-Mar', 'Aver-o-Mar', 'A ver-o-mar,Abre Mar,Aver-o-Mar', 41.4077800, -8.7811800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113542, 'Aveiro', 'Aveiro', 'Abeiro,Aveiro,Avejru,ZAV,Αβέιρο,Авейру', 40.6442700, -8.6455400, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113543, 'Avanca', 'Avanca', 'Avanca', 40.8077100, -8.5722000, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113544, 'Árvore', 'Arvore', '', 41.3392200, -8.7180600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113545, 'Arrifana', 'Arrifana', 'Arrifana', 40.9156500, -8.4965700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113546, 'Arouca', 'Arouca', 'Arouca', 40.9305700, -8.2448800, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113547, 'Arões', 'Aroes', 'Aroes,Arões,Sao Romao,São Romão', 41.4555300, -8.2141900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113548, 'Armamar', 'Armamar', 'Armamar', 41.1076500, -7.6913900, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113549, 'Argoncilhe', 'Argoncilhe', 'Argoncilhe', 41.0254100, -8.5388500, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113550, 'Arganil', 'Arganil', 'Arganil,a jia ni er,Арганил,阿加尼爾', 40.2182600, -8.0540300, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113551, 'Areosa', 'Areosa', 'Areosa,Areoza,Ariosa', 41.7177900, -8.8570700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113552, 'Arcozelo', 'Arcozelo', '', 41.0532700, -8.6432600, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113553, 'Arcos', 'Arcos', '', 40.4477900, -8.4417100, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113554, 'Arazede', 'Arazede', 'Araxede,Arazede', 40.2862700, -8.6499900, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113555, 'Aradas', 'Aradas', 'Aradas', 40.6208400, -8.6419500, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113556, 'Apúlia', 'Apulia', 'Apulia,Apúlia', 41.4851200, -8.7641300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113557, 'Antas', 'Antas', '', 41.7364400, -8.3088800, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113558, 'Anta', 'Anta', '', 41.2663400, -8.6284400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113559, 'Anadia', 'Anadia', 'Anadia,Anadie,Anadija,anadia,anadya,Анадия,Анадія,آنادیا,ანადია', 40.4384100, -8.4335200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113560, 'Amares', 'Amares', 'Amares', 41.6309100, -8.3511700, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113561, 'Amarante', 'Amarante', '', 41.2727100, -8.0824500, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113562, 'Alhadas', 'Alhadas', 'Alhadas', 40.1860700, -8.7905700, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113563, 'Alfena', 'Alfena', 'Alfena', 41.2367100, -8.5245400, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113564, 'Alfarelos', 'Alfarelos', 'Al''farelosh'',Alfarelos,Альфарелошь', 40.1505700, -8.6532600, 'PT', '2013-01-09', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113565, 'Alfândega da Fé', 'Alfandega da Fe', 'Alfandega da Fe,Alfândega da Fé', 41.3431500, -6.9611200, 'PT', '2014-04-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113566, 'Aldeia de Joanes', 'Aldeia de Joanes', '', 40.1390500, -7.5169400, 'PT', '2012-06-14', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113567, 'Albergaria-a-Velha', 'Albergaria-a-Velha', 'Albergaria,Albergaria-a-Velha', 40.6931800, -8.4799400, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113568, 'Aguiar da Beira', 'Aguiar da Beira', 'Agiar-da-Bejra,Aguiar da Beira,Aguiar da Beira Municipality,Агиар-да-Бейра', 40.8172600, -7.5443100, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113569, 'Águeda', 'Agueda', 'Ageda,Agueda,Agueda Municipality,a ge da,ageda,agwyda,Águeda,Águeda Municipality,Агеда,آگوئدا,აგედა,阿格達', 40.5772000, -8.4444200, 'PT', '2014-03-06', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113570, 'Aguçadoura', 'Agucadoura', 'Agucadeira,Agucadoira,Agucadoura,Aguçadeira,Aguçadoira,Aguçadoura', 41.4317600, -8.7803800, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113571, 'Águas Santas', 'Aguas Santas', 'Aguas Santas,Águas Santas', 41.2106100, -8.5866000, 'PT', '2012-02-01', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113572, 'Aguada de Cima', 'Aguada de Cima', 'Aguada de Cima', 40.5229100, -8.4270000, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113573, 'Adaúfe', 'Adaufe', 'Adaufe,Adaúfe', 41.5873200, -8.3981700, 'PT', '2016-03-10', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113574, 'Abraveses', 'Abraveses', 'Abraveses', 40.6813700, -7.9210200, 'PT', '2012-08-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113575, 'Vila Franca do Campo', 'Vila Franca do Campo', 'Vila Franca do Campo,Villa Franca do Campo', 37.7166700, -25.4333300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113576, 'São Roque do Pico', 'Sao Roque do Pico', 'San Roque,San-Roke-du-Piku,Sao Roque,Sao Roque do Pico,São Roque,São Roque do Pico,Сан-Роке-ду-Пику', 38.5163100, -28.3075200, 'PT', '2014-10-20', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113577, 'Rosto de Cão', 'Rosto de Cao', 'Rosto de Cao,Rosto de Cão,Rosto do Cao,Rosto do Cão', 37.7500000, -25.6500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113578, 'Ribeira Grande', 'Ribeira Grande', '', 38.5166700, -28.7000000, 'PT', '2006-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113579, 'Rabo de Peixe', 'Rabo de Peixe', 'Rabo de Peixe,Ribo de Peixe', 37.8000000, -25.5833300, 'PT', '2015-03-08', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113580, 'Praia da Vitória', 'Praia da Vitoria', 'Praia,Praia da Victoria,Praia da Vitoria,Praia da Vitória,Vila da Praia da Victoria,Vila da Praia da Vitoria,Vila da Praia da Vitória', 38.7333300, -27.0666700, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113581, 'Ponta Delgada', 'Ponta Delgada', 'PDL,Ponta Delgada', 37.7333300, -25.6666700, 'PT', '2012-05-05', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113582, 'Madalena', 'Madalena', 'Magdalena', 38.5364200, -28.5266000, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113583, 'Lajes das Flores', 'Lajes das Flores', 'Floresh,Lagens,Lagens das Flores,Lajens das Flores,Lajes das Flores,Lazhish-dash-Florish,la ri shen da shen fu luo li shen,lajeuseudaseupeulloleuseu,Лажиш-даш-Флориш,Флореш,拉日什達什弗洛里什,라즈스다스플로르스', 39.3774400, -31.1784700, 'PT', '2016-06-12', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113584, 'Lagoa', 'Lagoa', '', 39.0500000, -27.9833300, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113585, 'Horta', 'Horta', 'Gorad Orta,HOR,Horta,Orta,ao er ta,awrta,hwrth,oleuta,Горад Орта,Орта,הורטה,اورتا,ორტა,奧爾塔,오르타', 38.5333300, -28.6333300, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113586, 'Furnas', 'Furnas', 'Furnash,puleunaseu hwasan,Фурнаш,푸르나스 화산', 37.7756700, -25.3103500, 'PT', '2011-09-04', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113587, 'Fajã de Baixo', 'Faja de Baixo', 'Faja de Baixo,Fajã de Baixo', 37.7500000, -25.6500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113588, 'Biscoitos', 'Biscoitos', 'Biscoitos,Biscoutos,Bishkojtush,Sao Pedro Biscoutos,São Pedro Biscoutos,Бишкойтуш', 38.7833300, -27.2500000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113589, 'Arrifes', 'Arrifes', 'Arrafes,Arrifes', 37.7666700, -25.7000000, 'PT', '2012-01-17', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113590, 'Angra do Heroísmo', 'Angra do Heroismo', 'Angra,Angra do Eroizmo,Angra do Heroismas,Angra do Heroismo,Angra do Heroišmas,Angra do Heroísmo,Angra du Ehroizhmu,Angra-du-Ehroishmu,Ankra nto Eroismo,Aнгра ду Эроижму,angra dw hrwyysmw,angra-du-eroizhmu,ying xiong gang,Άγκρα ντο Ερόϊσμο,Ангра до Ероизмо,Ангра-ду-Эроишму,آنگرا دو هروئیسمو,ანგრა-დუ-ეროიჟმუ,アングラ・ド・エロイズモ,英雄港', 38.6500000, -27.2166700, 'PT', '2012-11-23', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113591, 'Vilamoura', 'Vilamoura', 'Vilamoura,Vilamura,Виламура', 37.0810000, -8.1108300, 'PT', '2014-07-09', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113592, 'Valenza', 'Valenza', 'Valenca,Valensa,Valenza,Valença,Валенса', 42.0241800, -8.6347400, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113593, 'Vila', 'Vila', '', 42.0304000, -8.1588000, 'PT', '2011-08-28', 178);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113754, 'Umm Şalāl Muḩammad', 'Umm Salal Muhammad', 'Umm Salal Mohammad,Umm Salal Muhammad,Umm Ses Salal,Umm Silal Mohammed,Umm Slal Mohammed,Umm es Salal,Umm es Slal,Umm Şalāl Muḩammad,am slal mhmd,aum salaal muhamad,أم صلال محمد,أُمّ صَلاَل مُحَمَّد', 25.4152400, 51.4064700, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113755, 'Umm Şalāl ‘Alī', 'Umm Salal `Ali', 'Umm Salal `Ali,Umm Silal `Ali,Umm Slal Ali,Umm Şalāl ‘Alī,Umm Şilāl ‘Alī,Umm-al-Salal,أم صلال علي', 25.4697200, 51.3975000, 'QA', '2012-01-18', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113756, 'Musay‘īd', 'Musay`id', 'Mesaieed,Musay`id,Musay‘īd,Umm Sa''id,Umm Sa`ad,Umm Sa‘ad,Umm Sa‘īd,أم سعيد,مسيعيد', 24.9922600, 51.5506700, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113757, 'Umm Bāb', 'Umm Bab', 'Umm Bab,Umm Bāb,aum bab,أُمّ بَاب', 25.2141700, 50.8072200, 'QA', '2014-05-29', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113758, 'Madīnat ash Shamāl', 'Madinat ash Shamal', 'Madinat ash Shamal,Madīnat ash Shamāl,mdynt alshmal,مدينة الشمال', 26.1293300, 51.2009000, 'QA', '2013-08-10', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113759, 'Dukhān', 'Dukhan', 'Al Khathiyah,Dukhan,Dukhkhan,Dukhkhān,Dukhān,Ghariyat Adkhan,Ghariyat Dukhan,Ghāriyat Adkhān,Ghāriyat Dukhān,dukhan,دُخَان', 25.4248500, 50.7822700, 'QA', '2015-07-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113760, 'Az̧ Z̧a‘āyin', 'Az Za`ayin', 'Ad Da`ayin,Al Da`ain,Al Da‘ain,Al Dha''Sin,Al Dha’Sin,Az Za`a''in,Az Za`ayim,Az Za`ayin,Az̧ Z̧a‘āyim,Az̧ Z̧a‘āyin,Az̧ Z̧a‘ā’in,Aḑ Ḑa‘āyin,Dha`ain,Dha`an,Dha‘ain,Dha‘an,Edh Dha''ain,Edh Dha’ain,الضعاين,الظعاين', 25.5774400, 51.4830600, 'QA', '2012-02-02', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113761, 'Ash Shayḩānīyah', 'Ash Shayhaniyah', 'Al Shahaniyah,Ash Shahaniyah,Ash Shayhaniyah,Ash Shayḩānīyah,Ash Shaḩānīyah,aalshahaniat,alshyhanyt,الشيحانية,اَلشَّحَانِيَّة', 25.3708800, 51.2226400, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113762, 'Ar Ruways', 'Ar Ruways', 'Ar Ru''ays,Ar Ruwais,Ar Ruways,Ar Ru’ays,Ruwais,aalruways,alrwys,الرويس,اَلرُّؤَيْس', 26.1397800, 51.2149300, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113763, 'Ar Rayyān', 'Ar Rayyan', 'Al Raiyan,Al Rayyan,Ar Rayyan,Ar Rayyān,Raiyan,alryan,ar-Rayyan,الريان', 25.2919400, 51.4244400, 'QA', '2014-07-23', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113764, 'Al Wukayr', 'Al Wukayr', 'Al Wukair,Al Wukayr,aalwukayr,alwkyr,الوكير,اَلْوُكَيْر', 25.1510700, 51.5371800, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113765, 'Al Wakrah', 'Al Wakrah', 'Al Wakrah,Al Waqra,Al Waqrah,Wakra,Wakrah,Waqra,alwkrt,الوكرة', 25.1715100, 51.6033700, 'QA', '2012-01-18', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113766, 'Al Khawr', 'Al Khawr', 'Al Khawr,Al Khor,Al''-Khor,Al-Chaur,Al-Khaur,Chauras,Khaur Shaqiq,Khaur al-Mahanidah,Khawr Shaqiq,Khawr Shaqīq,Khor,Khor Shaqiq,Khor Shaqīq,Khor-al-Mahandah,Khor-al-Mahāndah,Municipio de Jor,Shakik,alkhwr,alkhwr waldkhyrh,alkhwr waldkhyrt,alkoleu,Аль-Хор,Хор,الخور,الخور و الدخیرہ,الخور والدخيرة,الخور والدخیره,알코르', 25.6838900, 51.5058300, 'QA', '2012-01-18', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113767, 'Al Jumaylīyah', 'Al Jumayliyah', 'Al Jamaliya,Al Jamliyah,Al Jamlīyah,Al Jumaliyah,Al Jumayliyah,Al Jumaylīyah,Jimaliyah,Jimalīyah,aaljumayliat,اَلْجُمَيْلِيَّة', 25.6094400, 51.0922200, 'QA', '2013-07-11', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113768, 'Al Ghuwayrīyah', 'Al Ghuwayriyah', 'Al Ghuwairiya,Al Ghuwairiyah,Al Ghuwayriyah,Al Ghuwayrīyah,Ghuwairiyah,Ghuwairīyah,aalghuayriat,اَلْغُوَيْرِيَّة', 25.8297200, 51.2452800, 'QA', '2013-07-11', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113769, 'Doha', 'Doha', 'Ad Dawha,Ad Dawhah,Ad Dawḩa,Ad Dawḩah,Ad Doha,Ad Dowhah,Ad-Dauha,Ad-Dawhah,Ad-Dawḩah,DOH,Daeuha,Dauha,Dauhá,Dawha,Dawhat al Qatar,Dawḥa,Dawḩat al Qaţar,Dewhe,Do''ha,Doh,Doha,Doho,Dokha,Dokhae,Dokho,Dooxa,Doʻha,Doḥa,Duoha,Däuha,Gorad Dokha,Ntocha,aaldawhat,aldwhh,aldwht,deaha,do ha,doha,dohara,duo ha,dwhh,toka,Ντόχα,Горад Доха,Дохæ,Доха,Дохо,Доҳа,Доһа,Դոհա,דאכא,דוחא,דוחה,الدوحة,الدوحه,اَلدَّوْحَة,دوحه,دوحہ,دوحە,دوھا,دەوحە,दोहा,দোহা,দোহার,ਦੋਹਾ,தோகா,ದೊಹಾ,ദോഹ,โดฮา,དྷོ་ཧ།,ဒိုဟာမြို့,დოჰა,ዶሃ,ドーハ,多哈,도하', 25.2793200, 51.5224500, 'QA', '2010-05-30', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113770, 'Fuwayriţ', 'Fuwayrit', 'Fuwayrit,Fuwayriţ,fuayrit,fwyrt,فويرط,فُوَيْرِط', 26.0256500, 51.3697100, 'QA', '2016-08-03', 180);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113771, 'Les Trois-Bassins', 'Les Trois-Bassins', 'Les Trois-Bassins', -21.1000000, 55.3000000, 'RE', '2017-01-10', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113772, 'Salazie', 'Salazie', 'Salazi,Salazie,Salazie Village,Салазі', -21.0273400, 55.5390000, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113773, 'Saint-Pierre', 'Saint-Pierre', 'Saint-Pierre,Sent-P''er,ZSE,Сент-Пьер', -21.3393000, 55.4781100, 'RE', '2016-01-19', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113774, 'Saint-Philippe', 'Saint-Philippe', 'Saint Phillippe,Saint-Philippe', -21.3585200, 55.7679500, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113775, 'Saint-Paul', 'Saint-Paul', 'Saint-Paul', -21.0096300, 55.2707100, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113776, 'Saint-Louis', 'Saint-Louis', 'Saint-Louis,Sen-Lui,Сен-Луи', -21.2858500, 55.4112400, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113777, 'Saint-Leu', 'Saint-Leu', 'Saint-Leu,Sankt-Leu,Санкт-Леу', -21.1705900, 55.2882400, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113778, 'Saint-Joseph', 'Saint-Joseph', 'Saint-Joseph,Sent-Dzhozef,Сент-Джозеф', -21.3783900, 55.6191800, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113779, 'Sainte-Suzanne', 'Sainte-Suzanne', 'Sainte-Suzanne', -20.9061400, 55.6088600, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113780, 'Sainte-Rose', 'Sainte-Rose', 'Sainte-Rose', -21.1298300, 55.7962900, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113781, 'Sainte-Marie', 'Sainte-Marie', 'Sainte-Marie,Sent-Mari,Сент-Мари', -20.8968400, 55.5496000, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113782, 'Saint-Denis', 'Saint-Denis', 'RUN,Saint-Denis,Saint-Denis de la Reunion,Saint-Denis de la Réunion,Sen-Deni,St. Denis,snt dnys,Сен-Дени,סנט דניס,サン・ドゥニ', -20.8823100, 55.4504000, 'RE', '2015-12-17', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113783, 'Saint-Benoît', 'Saint-Benoit', 'Saint-Benoit,Saint-Benoît,Sankt-Benua,Санкт-Бенуа', -21.0380100, 55.7193700, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113784, 'Saint-André', 'Saint-Andre', 'Saint-Andre,Saint-André,Sankt-Andre,Санкт-Андре', -20.9633300, 55.6503100, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113785, 'Petite-Île', 'Petite-Ile', 'Petit-Il'',Village de la Petite Ile,Петіт-Іль', -21.3500000, 55.5666700, 'RE', '2008-02-28', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113786, 'Le Tampon', 'Le Tampon', 'Le Tampon,Le-Tampon,Tampon,Village du Tampon,lw tampwn,Ле Тампон,Ле-Тампон,لو تامپون,ル・タンポン', -21.2830900, 55.5180200, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113787, 'Les Avirons', 'Les Avirons', 'Avirons,Les Avirons,Lez-Aviron,Лез-Авірон', -21.2418100, 55.3393800, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113788, 'Le Port', 'Le Port', 'La Point-aux-galets,Le Port,Le Port des Galets,Port,Port de la Pointe des Galets,Port des Galets', -20.9373000, 55.2918900, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113789, 'La Possession', 'La Possession', 'La Posesion,La Possession,La-Posses''jon,Possession,la pwsysywn,lpwssywn,Ла Посесион,Ла-Поссесьйон,لا پوسیسیون,لپوسسیون', -20.9289200, 55.3351300, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113790, 'Entre-Deux', 'Entre-Deux', '', -21.2333300, 55.4666700, 'RE', '2017-01-10', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113791, 'Cilaos', 'Cilaos', 'Cilaos,Silao,Сілао', -21.1335700, 55.4719000, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113792, 'Bras-Panon', 'Bras-Panon', 'Bra-Panon,Bras-Panon,Бра-Панон', -20.9966700, 55.6782300, 'RE', '2012-01-18', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113793, 'Piton Saint-Leu', 'Piton Saint-Leu', '', -21.2196200, 55.3151300, 'RE', '2016-06-22', 181);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113794, 'Ghioca', 'Ghioca', 'Crampoaia,Crâmpoaia,Gheoca,Ghioca', 44.3166700, 24.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113795, 'Zvoriştea', 'Zvoristea', 'Zvoristea,Zvoriştea', 47.8333300, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113796, 'Zorlenţu Mare', 'Zorlentu Mare', 'Alsozorlenc,Alsózorlenc,Nagy-Zorlencz,Zorlencz,Zorlenczmare,Zorlenczmáre,Zorlentu Mare,Zorlentul Mare,Zorlenţu Mare,Zorlenţul Mare', 45.4505600, 21.9561100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113797, 'Zorleni', 'Zorleni', 'Zorleni', 46.2666700, 27.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113798, 'Zorile', 'Zorile', 'Falcoaia,Falcoianca,Fălcoaia,Fălcoianca,Zorile', 44.3786400, 25.8067800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113799, 'Zorești', 'Zoresti', '', 45.1817700, 26.7029100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113800, 'Zmeu', 'Zmeu', '', 47.1916100, 27.1791700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113801, 'Zlătunoaia', 'Zlatunoaia', 'Stanesti,Stăneşti,Zlatunoaia,Zlatunoaia Mare,Zlătunoaia,Zlătunoaia Mare', 47.6502600, 27.0074300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113802, 'Zlatna', 'Zlatna', 'Zlatna', 46.1063300, 23.2316200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113803, 'Zlătărei', 'Zlatarei', '', 44.6305700, 24.2578800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113804, 'Zizin', 'Zizin', 'Zajzon,Zizin', 45.6369700, 25.7789800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113805, 'Zimnicele', 'Zimnicele', 'Zimmicelele,Zimnicele,Zimnicelele', 43.6612600, 25.4129100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113806, 'Zimnicea', 'Zimnicea', 'Opstina Zimnicea,Opština Zimnicea,Zimnica,Zimnice,Zimnicea,Zimnich,Zimnicha,Zimniçe,Zimniča,ji mu ni qia,jimnichea,zymnychh,zymnyzh,Зимница,Зимнич,Зимнича,Зімніча,זימניצה,زیمنیچه,濟姆尼恰,짐니체아', 43.6666700, 25.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113807, 'Zâmbreasca', 'Zambreasca', 'Zabreasca,Zimbreasca,Zâbreasca,Zîmbreasca', 44.3166700, 24.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113808, 'Zimbor', 'Zimbor', 'Zimbor,Zimborul,Zimborul-Mare,Zutor', 47.0000000, 23.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113809, 'Zimandu Nou', 'Zimandu Nou', 'Zimandu Nou,Zimandul-Nou', 46.2833300, 21.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113810, 'Zidurile', 'Zidurile', 'Domnita Balasa,Domniţa Bălaşa,Zidul,Ziduri,Zidurile', 44.5817600, 25.5545800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113811, 'Ziduri', 'Ziduri', 'Costienii de Jos,Ziduri', 45.3000000, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113812, 'Zetea', 'Zetea', 'Zetea,Zetelaka', 46.3833300, 25.3666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113813, 'Zerind', 'Zerind', 'Zerind', 46.6166700, 21.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113814, 'Zencani', 'Zencani', 'Zancani,Zencani,Zenconi,Zenkan,Zenkàn', 46.9270000, 25.3341100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113815, 'Zemeş', 'Zemes', 'Taslaul de Sus,Taslăul de Sus,Tazlau de Sus,Tazlău de Sus,Zemes,Zemeş', 46.5833300, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113816, 'Zebil', 'Zebil', 'Zbil,Zebil', 44.9460000, 28.7687300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113817, 'Zdrapți', 'Zdrapti', 'Zdrapti,Zdrapţi,Zurapti', 46.1561200, 22.8695400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113818, 'Zăvoiu', 'Zavoiu', 'Zavoiu,Zavoiu Orbului,Zavoiul-Orbului,Zăvoiu,Zăvoiu Orbului,Zăvoiul-Orbului', 44.6603800, 25.4035000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113819, 'Zăvoi', 'Zavoi', 'Zavoi,Zavoiu,Zăvoi,Zăvoiu', 45.5166700, 22.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113820, 'Zăvoaia', 'Zavoaia', 'Slujitorii-Albesti,Slujitorii-Albeşti,Zavoaia,Zăvoaia', 44.9500000, 27.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113821, 'Zăval', 'Zaval', 'Zavalu,Zavalul,Zăvalu,Zăvalul', 43.8471700, 23.8420800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113822, 'Zau de Câmpie', 'Zau de Campie', 'Mezozah,Mezőzáh', 46.6138200, 24.1308000, 'RO', '2015-12-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113823, 'Zăuan', 'Zauan', 'Szilagyzovany,Szilágyzovány,Zauan,Zovany,Zovány,Zăuan', 47.2249500, 22.6632800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113824, 'Zătreni', 'Zatreni', 'Zatreni,Zatrenii,Zătreni,Zătrenii', 44.7666700, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113825, 'Zărneștii de Slănic', 'Zarnestii de Slanic', 'Zarnesti,Zarnesti de Slanic,Zarnestii de Slanic,Zarneşti de Slanic,Zărneşti,Zărneştii de Slănic', 45.2770800, 26.7554900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113826, 'Zărnești', 'Zarnesti', 'Zarnesti,Zernesch,Zernest,Zărneşti', 45.5609300, 25.3178700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113827, 'Zărneşti', 'Zarnesti', '', 45.3000000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113828, 'Zărand', 'Zarand', 'Zarand,Zărand', 46.4000000, 21.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113829, 'Zăpodeni', 'Zapodeni', 'Zapodeni,Zăpodeni', 46.7500000, 27.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113830, 'Zănoaga', 'Zanoaga', '', 44.1551100, 24.0983200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113831, 'Zăneşti', 'Zanesti', 'Zanesti,Zăneşti', 46.8166700, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113832, 'Zamostea', 'Zamostea', 'Zamostea', 47.8666700, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113833, 'Zam', 'Zam', 'Sameschdorf,Zam', 46.0000000, 22.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113834, 'Zalha', 'Zalha', 'Zalha', 47.1833300, 23.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113835, 'Zalău', 'Zalau', 'Zalaou,Zalau,Zalehu,Zaleu,Zaluu,Zalyu,Zalău,Zelau,Zilah,jalleou,sylaw,zalaw,zaleu,zalyw,zha lei wu,zlyw,Ζαλάου,Залау,Залеу,Залъу,Залыу,Залэу,زالاو,زالیو,زلئو,سیلاؤ,ზალეუ,札勒烏,잘러우', 47.2000000, 23.0500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113836, 'Zagra', 'Zagra', '', 47.3333300, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113837, 'Zagon', 'Zagon', '', 45.7666700, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113838, 'Zagavia', 'Zagavia', '', 47.4191100, 26.8979000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113839, 'Zagăr', 'Zagar', 'Zagar,Zagra,Zagăr', 46.3500000, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113840, 'Zădăreni', 'Zadareni', 'Gaderlach,Sadarlach,Saderlach,Saderlak,Szaderlak,Zadareni,Zadarlac,Zaderlach,Zadorlak,Zadărlac,Zádorlak,Zădăreni', 46.1327400, 21.2182100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113841, 'Zăbrani', 'Zabrani', 'Gutenbrunn,Guttenbrunn,Guttennbrunn,Temeshidegkut,Temeshidegkút,Zabrani,Zabrany,Zábrány,Zăbrani', 46.0666700, 21.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113842, 'Zăbala', 'Zabala', 'Zabala,Zabola,Zăbala', 45.9000000, 26.1833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113843, 'Vutcani', 'Vutcani', 'Vutcani', 46.4666700, 27.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113844, 'Vurpăr', 'Vurpar', '', 46.0000000, 23.4666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113845, 'Vurpăr', 'Vurpar', 'Burgberg,Vurpar,Vurpod,Vurpód,Vurpăr', 45.9000000, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113846, 'Vulturu', 'Vulturu', 'Vulturu de Sus,Vulturul-de-Sus', 45.6166700, 27.4166700, 'RO', '2015-11-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113847, 'Vulturu', 'Vulturu', 'Caratal,Cartal,Vulturu,Vulturul', 44.6500000, 28.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113848, 'Vultureşti', 'Vulturesti', '', 47.5166700, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113849, 'Vultureşti', 'Vulturesti', 'Vulturesti,Vultureşti', 46.8166700, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113850, 'Vulturești', 'Vulturesti', '', 45.0661800, 25.0834700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113851, 'Vultureşti', 'Vulturesti', '', 44.7333300, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113852, 'Vultureni', 'Vultureni', 'Vultureni', 46.9666700, 23.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113853, 'Vultureni', 'Vultureni', 'Gura Tiganesti,Gura Ţigăneşti,Vultureni', 46.3666700, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113854, 'Vulpeni', 'Vulpeni', 'Vulpeni', 44.4666700, 23.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113855, 'Vulcăneasa', 'Vulcaneasa', 'Vulcaneasa,Vulcanesisa,Vulcăneasa,Vulcănesisa', 45.7738800, 26.9098100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113856, 'Vulcana-Pandele', 'Vulcana-Pandele', '', 45.0155800, 25.3931900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113857, 'Vulcana de Sus', 'Vulcana de Sus', '', 45.1012500, 25.3582600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113858, 'Vulcana Băi', 'Vulcana Bai', 'Baile Vulcan,Balle Vulcana,Băile Vulcan,Vulcan Bai,Vulcana Bai,Vulcana Băi', 45.0798200, 25.3821900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113859, 'Vulcan', 'Vulcan', 'Vulcan', 45.6333300, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113860, 'Vulcan', 'Vulcan', 'Vulcan', 45.3833300, 23.2666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113861, 'Vrâncioaia', 'Vrancioaia', 'Vrancioaia,Vrâncioaia', 45.8500000, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113862, 'Vrata', 'Vrata', 'Vrata', 44.1919700, 22.8492800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113863, 'Vrănești', 'Vranesti', '', 44.8459500, 25.0071600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113864, 'Voșlăbeni', 'Voslabeni', 'Vaslab,Vasláb,Voslobeni,Voşlobeni', 46.6500000, 25.6333300, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113865, 'Vorţa', 'Vorta', 'Vorta,Vorţa', 46.0166700, 22.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113866, 'Vorona Teodoru', 'Vorona Teodoru', '', 47.5500000, 26.6000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113867, 'Vorona', 'Vorona', 'Vorona,Vorona Noua,Vorona Nouă', 47.5966800, 26.6448200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113868, 'Vorniceni', 'Vorniceni', 'Voriuceni,Vorniceni', 47.9833300, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113869, 'Voluntari', 'Voluntari', 'Cetatea Voluntareasca,Cetatea Voluntărească,Parcu Voluntarilor,Stefanestii Noi,Stefăneştii Noi,Voluntari,Волунтари', 44.4900200, 26.1733800, 'RO', '2013-09-29', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113870, 'Volovăţ', 'Volovat', 'Volovat,Volovăţ', 47.8166700, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113871, 'Voloiac', 'Voloiac', '', 44.6166700, 23.1000000, 'RO', '2015-12-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113872, 'Voivozi', 'Voivozi', 'Derna Voevozi,Voivozi', 47.2156200, 22.3902400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113873, 'Voivodeni', 'Voivodeni', 'Vajdaszentivany,Vajdaszentivány,Voivodeni', 46.7000000, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113874, 'Voievodeasa', 'Voievodeasa', 'Voevodeasa,Voivodeasa', 47.7995300, 25.7493900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113875, 'Voitinel', 'Voitinel', 'Voitinel', 47.8836600, 25.7573500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113876, 'Voiteștii din Vale', 'Voitestii din Vale', 'Voitestii de Vale,Voiteștii de Vale', 45.0874600, 23.4214500, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113877, 'Voiteg', 'Voiteg', 'Vejte,Voiteg,Voiteni,Vojtek,Wojtek', 45.4688900, 21.2391700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113878, 'Voineşti', 'Voinesti', '', 47.0666700, 27.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113879, 'Voineşti', 'Voinesti', 'Cirtibasul,Cîrtibaşul,Voinesti,Voinesti-Boeresti,Voinesti-Boieresti,Voinesti-Razesi,Voinestii Boeresti,Voinestii-Razesi,Voineşti,Voineşti-Boereşti,Voineşti-Boiereşti,Voineşti-Răzeşi,Voineştii Boereşti,Voineştii-Răzeşi', 46.5666700, 27.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113880, 'Voinești', 'Voinesti', '', 45.3000700, 25.0722500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113881, 'Voineşti', 'Voinesti', 'Voinesti,Voinestu,Voineşti', 45.0666700, 25.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113882, 'Voineasa', 'Voineasa', 'Voineasa,Voineasca', 45.4166700, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113883, 'Voineasa', 'Voineasa', 'Voineasa,Voineasa Mare', 44.2833300, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113884, 'Voila', 'Voila', 'Voila', 45.8183900, 24.8421500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113885, 'Voetin', 'Voetin', 'Voetenu,Voetin,Voietenu', 45.4437000, 27.1458700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113886, 'Voiceşti', 'Voicesti', 'Voicesti,Voicestii de Mijloc,Voiceşti,Voiceştii de Mijloc', 44.6000000, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113887, 'Vlăsineşti', 'Vlasinesti', 'Vlasinesti,Vlăsineşti', 47.9333300, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113888, 'Vlăsceni', 'Vlasceni', '', 44.5852200, 25.5993100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113889, 'Vlașca', 'Vlasca', '', 44.3966400, 27.8486500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113890, 'Vlăhiţa', 'Vlahita', 'Szentegyhaza,Szentegyhazasfalu,Szentegyháza,Szentegyházasfalu,Vlahita,Vlăhiţa', 46.3500000, 25.5166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113891, 'Vlăduleni', 'Vladuleni', '', 44.8885700, 23.2372700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113892, 'Vlad Ţepeş', 'Vlad Tepes', '', 44.3500000, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113893, 'Vlad Țepeș', 'Vlad Tepes', '', 44.1328200, 26.1335500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113894, 'Vladimirescu', 'Vladimirescu', 'Glogovacz,Glogovat,Glogovácz,Glogovăţ,Glogowatz,Othalom,Tudor Vladimirescu,Vladimirescu,Öthalom', 46.1662800, 21.4010200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113895, 'Vlădila', 'Vladila', 'Vladila,Vladila Veche,Vlădila,Vlădila Veche', 44.0000000, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113896, 'Vlădești', 'Vladesti', 'Vladestii de Jos,Vlădeştii de Jos', 45.1500000, 24.9166700, 'RO', '2015-11-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113897, 'Vlădeşti', 'Vladesti', '', 45.8500000, 28.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113898, 'Vlădeşti', 'Vladesti', '', 45.1166700, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113899, 'Vlădeni-Deal', 'Vladeni-Deal', 'Vladeni,Vladeni-Deal,Vlădeni,Vlădeni-Deal', 47.5225000, 26.8729500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113900, 'Vlădeni', 'Vladeni', '', 47.7166700, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113901, 'Vlădeni', 'Vladeni', '', 47.4166700, 27.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113902, 'Vlădeni', 'Vladeni', 'Vladeni,Vladenii,Vlădeni,Vlădenii', 44.8755000, 25.7731800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113903, 'Vlădeni', 'Vladeni', '', 44.6166700, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113904, 'Vlădaia', 'Vladaia', 'Vladaia,Vlădaia', 44.3500000, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113905, 'Vizurești', 'Vizuresti', '', 44.6404000, 25.8074000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113906, 'Viziru', 'Viziru', 'Viziru,Vizirul', 45.0166700, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113907, 'Vizantea-Mânăstirească', 'Vizantea-Manastireasca', 'Vizante,Vizantea,Vizantea-Manastireasca,Vizantea-Minastireasca,Vizantea-Mânăstirească,Vizantea-Mînăstirească,Vizantia Monastueasc,Vizantia-Manastirea,Vizantia-Mânăstirea', 45.9833300, 26.7833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113908, 'Vitomireşti', 'Vitomiresti', 'Costesti,Costesti-Uda,Costestii,Costeşti,Costeşti-Uda,Vitomiresti,Vitomireşti', 44.8666700, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113909, 'Vitănești', 'Vitanesti', '', 44.5273000, 24.6958500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113910, 'Vităneşti', 'Vitanesti', 'Vitanesti,Vităneşti', 44.0000000, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113911, 'Viștea de Jos', 'Vistea de Jos', '', 45.7958200, 24.7238000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113912, 'Vişineşti', 'Visinesti', 'Visinesti,Vişineşti', 45.1000000, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113913, 'Vișina Nouă', 'Visina Noua', 'Visina Noua,Vişina Nouă', 43.8743400, 24.4182000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113914, 'Vişina', 'Visina', 'Visina,Vişina', 44.5833300, 25.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113915, 'Vişina', 'Visina', 'Visina,Visina Veche,Vişina,Vişina Veche', 43.8666700, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113916, 'Vişeu de Sus', 'Viseu de Sus', 'Felsoviso,Felsövisó,Visauel-de-Sus,Visaul-de-Sus,Viseu,Viseu de Sus,Viseul,Viseul de Sus,Visuel de-Sus,Vişeu,Vişeu de Sus,Vişeul,Vişeul de Sus,Vişuel de-Sus,Vişăuel-de-Sus,Vişăul-de-Sus', 47.7166700, 24.4333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113917, 'Vișeu de Mijloc', 'Viseu de Mijloc', 'Viseu de Mijloc,Viseul de Mijloc,Vişeu de Mijloc,Vişeul de Mijloc', 47.7156200, 24.4066100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113918, 'Vişeu de Jos', 'Viseu de Jos', 'Visaul-de-Jos,Viseu de Jos,Viseul de Jos,Vizaul de Jos,Vizăul de Jos,Vişeu de Jos,Vişeul de Jos,Vişăul-de-Jos', 47.7255800, 24.3661300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113919, 'Viscri', 'Viscri', 'Szaszfeheregyhaza,Szászfehéregyháza,Viskri,Вискри', 46.0552200, 25.0938900, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113920, 'Vişani', 'Visani', '', 45.1500000, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113921, 'Vârvoru de Jos', 'Varvoru de Jos', 'Ruptura,Virvoru de Jos,Vîrvoru de Jos', 44.2441500, 23.6079000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113922, 'Vârtop', 'Vartop', 'Vartop,Vartopu,Vartopul,Virtopu,Vârtop,Vârtopu,Vârtopul,Vîrtopu', 44.2068200, 23.3486900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113923, 'Vârtoapele de Sus', 'Vartoapele de Sus', 'Vartoapele-de-Sus,Virtoapele de Sus,Vârtoapele-de-Sus,Vîrtoapele de Sus', 44.1918200, 25.2002500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113924, 'Vârtoapele de Jos', 'Vartoapele de Jos', 'Vartoapele-de-Jos,Virtoapele de Jos,Vârtoapele-de-Jos,Vîrtoapele de Jos', 44.1833300, 25.2000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113925, 'Vârteşcoiu', 'Vartescoiu', 'Vartescoi,Vartescoiu,Virtescoiu,Vârteşcoi,Vârteşcoiu,Vîrteşcoiu', 45.7333300, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113926, 'Vârteju', 'Varteju', 'Vartej,Varteju,Vartejul,Vartejul-Nefliu,Virteju,Vârtej,Vârteju,Vârtejul,Vârtejul-Nefliu,Vîrteju', 44.3560600, 25.9918300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113927, 'Vârşolţ', 'Varsolt', 'Varsolt,Virsolt,Vârşolţ,Vîrşolţ', 47.2000000, 22.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113928, 'Vârlezi', 'Varlezi', 'Varlezi,Virlezi,Vârlezi,Vîrlezi', 45.9000000, 27.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113929, 'Vârghiş', 'Varghis', 'Varghis,Vargyas,Virghis,Vârghiş,Vârghiș,Vîrghiş', 46.1333300, 25.5333300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113930, 'Vârfurile', 'Varfurile', 'Csucs,Csúcs,Varfurile,Virfurile,Vârfurile,Vîrfurile', 46.3166700, 22.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113931, 'Vârfuri', 'Varfuri', 'Varfurile,Virfuri,Vârfurile,Vîrfuri', 45.1000000, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113932, 'Vârfu Câmpului', 'Varfu Campului', 'Varful-Campului,Virfu Cimpului,Vârful-Câmpului,Vîrfu Cîmpului', 47.8456600, 26.3305600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113933, 'Vârciorova', 'Varciorova', 'Varciorova,Virciorova,Vârciorova,Vîrciorova', 45.3271000, 22.3520800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113934, 'Vârciorog', 'Varciorog', 'Varciorog,Virciorog,Vârciorog,Vîrciorog', 46.9666700, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113935, 'Vipereşti', 'Viperesti', 'Viperesti,Vipereşti', 45.2333300, 26.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113936, 'Vintileasca', 'Vintileasca', 'Vintileasca', 45.6000000, 26.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113937, 'Vintileanca', 'Vintileanca', 'Gageni-Vintileanca,Găgeni-Vintileanca,Vintileanca', 44.9850000, 26.5800500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113938, 'Vintilă Vodă', 'Vintila Voda', 'Vintila Voda,Vintilă Vodă', 45.4666700, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113939, 'Vintere', 'Vintere', '', 46.7688300, 22.1465200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113940, 'Vânju-Mare', 'Vanju-Mare', 'Vanju-Mare,Vanjul-Mare,Vinju Mare,Vânju-Mare,Vânjul-Mare,Vînju Mare', 44.4252800, 22.8697200, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113941, 'Vânjuleţ', 'Vanjulet', 'Vanjulet,Vanjuletu,Vinjulet,Vânjuleţ,Vânjuleţu,Vînjuleţ', 44.4411100, 22.7925000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113942, 'Vinga', 'Vinga', 'Neu Winga,Theresiopel,Theresiopolis,Thereziopolis,Ujvinga,Vinga,Vinga Noua,Vinga Nouă,Winga,Winga an der Maresch,Újvinga', 46.0166700, 21.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113943, 'Vinerea', 'Vinerea', '', 45.8863200, 23.3528900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113944, 'Vinderei', 'Vinderei', 'Vinderei', 46.1500000, 27.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113945, 'Vânători-Neamţ', 'Vanatori-Neamt', 'Draguta,Drahutel,Drăguţa,Drăhutel,Schitu-Procov,Schitu-Sihlea,Schitu-Vovidenia,Schitul Sihlea,Todiriteni,Todiriţeni,Tudoriteni,Ungureni,Valea Drahutel,Valea Drăhuţel,Vanatori-Neamt,Vanatori-Neamtu,Vanatorii-Neamt,Vinatori-Neamt,Vânători-Neamţ,Vânători-Neamţu,Vânătorii-Neamţ,Vînători-Neamţ', 47.2000000, 26.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113946, 'Vânătorii Mici', 'Vanatorii Mici', 'Vanatorii Mici,Vinatorii Mici,Vânătorii Mici,Vînătorii Mici', 44.4902800, 25.5588900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113947, 'Vânătorii Mari', 'Vanatorii Mari', 'Vanatorii-Mari,Vinatorii Mari,Vânătorii-Mari,Vînătorii Mari', 44.4889800, 25.5454800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113948, 'Vânători', 'Vanatori', 'Stolniceni,Stolniceni-Ghitescu,Stolniceni-Ghiţescu,Vinatori,Vînători', 47.3598000, 26.7642300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113949, 'Vânători', 'Vanatori', 'Vinatori,Vînători', 47.2333300, 27.5333300, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113950, 'Vânători', 'Vanatori', 'Vanatori,Vinatori,Vânători,Vînători', 46.6245600, 21.6733200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113951, 'Vânători', 'Vanatori', 'Hasfalau,Haşfalău,Vanator,Vanatori,Vinatori,Vânător,Vânători,Vînători', 46.2333300, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113952, 'Vânători', 'Vanatori', 'Vanatori,Vinatori,Vânători,Vînători', 45.7333300, 27.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113953, 'Vânători', 'Vanatori', 'Vanatori,Vinatori,Vânători,Vînători', 45.5333300, 28.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113954, 'Vânători', 'Vanatori', 'Vanatori,Vinatori,Vânători,Vînători', 44.2427800, 22.9288900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113955, 'Vima Mică', 'Vima Mica', '', 47.4000000, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113956, 'Vâlcelele de Sus', 'Valcelele de Sus', 'Valcelele de Sus,Vilcelele de Sus,Vâlcelele de Sus,Vîlcelele de Sus', 44.2846100, 24.5582100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113957, 'Vâlcelele', 'Valcelele', 'Valcele,Valcelele,Vilcele,Vilcelele,Vâlcele,Vâlcelele,Vîlcele,Vîlcelele', 45.3443000, 27.3493700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113958, 'Vâlcelele', 'Valcelele', 'Crucea,Vilcelele,Vîlcelele', 44.3883400, 27.1502200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113959, 'Vâlcele', 'Valcele', 'Valcele,Vilcele,Vîlcele', 46.2980100, 26.6000500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113960, 'Vâlcele', 'Valcele', 'Elopatak,Elöpatak,Valcele,Vâlcele', 45.8500000, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113961, 'Vâlcele', 'Valcele', 'Valcelele,Vilcele,Vâlcelele,Vîlcele', 45.0869200, 26.6335300, 'RO', '2015-11-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113962, 'Vâlcele', 'Valcele', 'Valcelele de Jos,Vilcele,Vilcele de Jos,Vilcelele,Vâlcelele de Jos,Vîlcele,Vîlcele de Jos,Vîlcelele', 44.2826300, 24.5437600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113963, 'Vâlcăneşti', 'Valcanesti', 'Valcanesti,Vilcanesti,Vâlcăneşti,Vîlcăneşti', 45.1166700, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113964, 'Viișoara', 'Viisoara', '', 47.1033200, 24.4494900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113965, 'Viişoara', 'Viisoara', 'Bivolu Mare,Bivolul-Mare,Viisoara,Viişoara', 48.1666700, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113966, 'Viişoara', 'Viisoara', 'Patal,Patal-Mare,Păţal,Păţal-Mare,Viisoara,Viişoara', 47.3833300, 22.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113967, 'Viişoara', 'Viisoara', '', 46.9333300, 26.2333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113968, 'Viişoara', 'Viisoara', 'Agirbiciu,Agîrbiciu,Viisoara,Viişoara', 46.5500000, 23.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113969, 'Viişoara', 'Viisoara', 'Basesti,Băseşti,Viisoara,Viişoara', 46.3833300, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113970, 'Viișoara', 'Viisoara', '', 46.2832500, 26.6618700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113971, 'Viişoara', 'Viisoara', 'Hundorf,Viisoara,Viişoara', 46.2833300, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113972, 'Viișoara', 'Viisoara', 'Bou,Boul,Viisoara,Viişoara', 46.0516000, 27.0959300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113973, 'Viișoara', 'Viisoara', '', 44.8811600, 25.4273000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113974, 'Viișoara', 'Viisoara', 'Caceamac,Caciamac,Viisoara,Viişoara', 44.0775800, 28.1942400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113975, 'Viişoara', 'Viisoara', '', 43.7833300, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113976, 'Viile Satu Mare', 'Viile Satu Mare', 'Viile,Viile Satu Mare,Viile-Satmarului,Viile-Sătmarului', 47.6666700, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113977, 'Viile', 'Viile', 'Ignatesti,Ignăteşti,Viile', 45.8069100, 27.9474800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113978, 'Viile', 'Viile', 'Beilic,Viile', 44.1620000, 27.7576900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113979, 'Viforâta', 'Viforata', 'Viforata,Viforita,Viforâta,Viforîta', 44.9601100, 25.4579600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113980, 'Vieru', 'Vieru', 'Vieru,Vierul', 43.8878700, 25.8097400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113981, 'Vierșani', 'Viersani', '', 44.8787500, 23.5312000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113982, 'Vidra', 'Vidra', 'Vidra', 46.3675800, 22.8881100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113983, 'Vidra', 'Vidra', 'Vidra,Vrancea', 45.9166700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113984, 'Vidra', 'Vidra', '', 44.2605600, 26.1697200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113985, 'Videle', 'Videle', 'Vida,Vida Cirtojani,Vida Cîrtojani,Videle,Виделе', 44.2780600, 25.5244400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113986, 'Victor Vlad Delamarina', 'Victor Vlad Delamarina', 'Lugoskisfalu,Satu Mic,Szatulmik,Szatumik,Victor Vlad Delamarina', 45.6405600, 21.8927800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113987, 'Victoria', 'Victoria', '', 47.6101800, 27.1673000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113988, 'Victoria', 'Victoria', 'Carpiti,Cirpiti,Cârpiţi,Cîrpiţi,Victoria', 47.2833300, 27.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113989, 'Victoria', 'Victoria', 'Ucea,Victoria', 45.7296800, 24.7028000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113990, 'Victoria', 'Victoria', '', 44.8166700, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113991, 'Vicovu de Sus', 'Vicovu de Sus', 'Vicovu de Sus,Vicovul-de-Sus', 47.9333300, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113992, 'Vicovu de Jos', 'Vicovu de Jos', 'Vicovu de Jos,Vicovul-de-Jos', 47.9000000, 25.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113993, 'Veza', 'Veza', '', 46.1674700, 23.9247000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113994, 'Vetiş', 'Vetis', 'Vetes,Vetis,Vetiş,Vetés', 47.8000000, 22.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113995, 'Veţel', 'Vetel', 'Vetel,Veţel', 45.9000000, 22.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113996, 'Veţca', 'Vetca', 'Szekeylveczke,Székeylveczke,Vetca,Veţca', 46.3500000, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113997, 'Veștem', 'Vestem', '', 45.7175200, 24.2395800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113998, 'Veseuș', 'Veseus', 'Vesaus,Veseus,Veseuş,Vesăus', 46.2745600, 24.1427600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(113999, 'Verșești', 'Versesti', '', 46.4490400, 26.7018300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114000, 'Verșeni', 'Verseni', '', 47.1129400, 26.6434100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114001, 'Verneşti', 'Vernesti', 'Vernesti,Verneşti', 45.2166700, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114002, 'Vermești', 'Vermesti', 'Vermesti,Vermeşti,Vernesti,Verneşti', 46.4217200, 26.4766000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114003, 'Vermeş', 'Vermes', 'Krassovermes,Krassóvermes,Vermes,Vermeş,Vermus', 45.5205600, 21.6597200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114004, 'Verguleasa', 'Verguleasa', 'Verguleasa', 44.6500000, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114005, 'Vereşti', 'Veresti', 'Ion Gheorghe Duca,Veresti,Vereşti', 47.6000000, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114006, 'Verendin', 'Verendin', '', 45.0775500, 22.2391700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114007, 'Verbiţa', 'Verbita', 'Verbita,Verbiţa', 44.3000000, 23.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114008, 'Vela', 'Vela', 'Vela,Vella', 44.2833300, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114009, 'Vedea', 'Vedea', 'Gera Boului,Gura-Boului,Vedea', 44.7833300, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114010, 'Vedea', 'Vedea', 'Goala,Vedea', 44.0833300, 25.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114011, 'Vedea', 'Vedea', 'Arsache,Vedea', 43.7833300, 25.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114012, 'Vatra Moldoviţei', 'Vatra Moldovitei', 'Vatra Moldovitei,Vatra Moldoviţei', 47.6500000, 25.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114013, 'Vatra Dornei', 'Vatra Dornei', 'Dorna Vatra,Dornavatra,Dornavátra,Opstina Vatra Dornei,Opština Vatra Dornei,Vatra Dornei,Vatra Dornej,Vatra-Dornej,fatra dwrnh,wa te la duo er nei,wtrh dwrnh,Ватра Дорней,Ватра Дорнеј,Ватра-Дорней,ואטרה דורניי,فاترا دورنه,وتره دورنه,ვატრა-დორნეი,ヴァトラ・ドルネイ,瓦特拉多爾內', 47.3500000, 25.3666700, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114014, 'Vătava', 'Vatava', 'Felsorepa,Felsörèpa,Vatava,Vătava', 46.9666700, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114015, 'Vaţa de Jos', 'Vata de Jos', 'Alvaca,Alváca,Vata de Jos,Vaţa de Jos', 46.1833300, 22.6000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114016, 'Vaslui', 'Vaslui', 'Vasloui,Vaslui,Vasluiul,Vasluj,Vaslujus,Vaszlo,Vászló,baseullu-i,faslwy,vu~asurui,wa si lu yi,waslwy,waslwyy,wslwy,wzlw,Βασλούι,Васлуй,Васлуј,וסלוי,فاسلوي,واسلوئی,واسلوی,وزلو,ヴァスルイ,瓦斯盧伊,바슬루이', 46.6333300, 27.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114017, 'Umbrărești-Deal', 'Umbraresti-Deal', 'Carmen-Sylva,General Eremia Grigorescu,Vasile Roaita,Vasile Roaită', 45.7000000, 27.4666700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114018, 'Vasilaţi', 'Vasilati', 'Vasilati,Vasilatii,Vasilatii-Poporul,Vasilaţi,Vasilaţii,Vasilaţii-Poporul', 44.2877800, 26.4475000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114019, 'Vaşcău', 'Vascau', 'Korosbarafalva,Körösbarafalva,Vascau,Vaskoh,Vaşcău', 46.4666700, 22.4666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114020, 'Vășad', 'Vasad', '', 47.5186000, 22.2566000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114021, 'Vărşag', 'Varsag', 'Szekelyvarsag,Székelyvarság,Varsag,Virsag,Vîrşag,Vărşag', 46.5166700, 25.3500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114022, 'Varnița', 'Varnita', '', 44.8067900, 25.9453000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114023, 'Variaş', 'Varias', 'Varias,Variaş,Varjas,Warjasch', 46.0166700, 20.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114024, 'Vărgata', 'Vargata', 'Csikfalva,Vargata,Vărgata', 46.5666700, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114025, 'Vărbilău', 'Varbilau', '', 45.1833300, 25.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114026, 'Vărbila', 'Varbila', '', 45.0465400, 26.1969100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114027, 'Văratec', 'Varatec', '', 47.6398800, 26.4031200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114028, 'Vărăşti', 'Varasti', 'Varasti,Varastii,Vărăşti,Vărăştii', 44.2377800, 26.2486100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114029, 'Vărăști', 'Varasti', '', 44.2124400, 26.9718800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114030, 'Vărădia de Mureş', 'Varadia de Mures', 'Marosnagyvolgy,Marosnagyvölgy,Totvarad,Totvaradgya,Totvaradja,Tótvárad,Tótváradgya,Tótváradja,Valemare,Valemáre,Vallemare,Vallemáre,Varadia de Mures,Vărădia de Mureș', 46.0166700, 22.1500000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114031, 'Vărădia', 'Varadia', 'Arcidava,Varadia,Vărădia', 45.0783300, 21.5469400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114032, 'Vama Buzăului', 'Vama Buzaului', 'Vama Buzaului,Vama Buzăului', 45.5966800, 25.9935900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114033, 'Vama', 'Vama', 'Vama', 47.8333300, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114034, 'Vama', 'Vama', '', 47.5666700, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114035, 'Valu lui Traian', 'Valu lui Traian', 'Hasancea,Hozancha,Valu Traian,Valu lui Traian,Valul-lui-Traian', 44.1666700, 28.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114036, 'Văliug', 'Valiug', 'Ferenczfalva,Valiug,Văliug', 45.2333300, 22.0333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114037, 'Vălişoara', 'Valisoara', 'Valisoara,Vălişoara', 46.0500000, 22.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114038, 'Văleni-Podgoria', 'Valeni-Podgoria', 'Valdeni-Podgoria,Valeni,Valeni-Podgoria,Văldeni-Podgoria,Văleni-Podgoria', 44.8575500, 24.9893000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114039, 'Vălenii Șomcutei', 'Valenii Somcutei', 'Valeni,Valenii Somcutei,Văleni,Vălenii Şomcutei', 47.4729100, 23.4513800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114040, 'Vălenii de Mureș', 'Valenii de Mures', 'Disznajo,Disznajò,Porcesti,Porceşti,Valenii de Mures,Vălenii de Mureş', 46.8927400, 24.7979300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114041, 'Vălenii de Munte', 'Valenii de Munte', 'Opstina Valenii De Munte,Opština Vãlenii De Munte,Valeni-de-Munte,Valenii de Munte,Valeniji de Munte,Vehlenij-de-Munte,Velenij-de-Munte,Văleni-de-Munte,Vălenii de Munte,wlny dh mwnth,Валенији де Мунте,Веленій-де-Мунте,Вэлений-де-Мунте,ولنی ده مونته', 45.1833300, 26.0333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114042, 'Văleni-Dâmbovița', 'Valeni-Dambovita', '', 45.1666700, 25.1833300, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114043, 'Văleni', 'Valeni', '', 46.9029100, 26.3894500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114044, 'Văleni', 'Valeni', '', 47.7855900, 24.0162500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114045, 'Văleni', 'Valeni', '', 47.0310400, 26.6884600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114046, 'Văleni', 'Valeni', 'Valea Rea,Valeni,Văleni', 46.7473300, 27.7596000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114047, 'Văleni', 'Valeni', 'Valeni,Valenii,Văleni,Vălenii', 44.2333300, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114048, 'Valea Vișeului', 'Valea Viseului', 'Valea Visaului,Valea Viseului,Valea Vişeului,Valea Vişăului', 47.9120300, 24.1584200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114049, 'Valea Vinului', 'Valea Vinului', 'Valea Vinului', 47.7166700, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114050, 'Valea Viilor', 'Valea Viilor', 'Valea Viilor,Vorumloc', 46.0833300, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114051, 'Valea Ursului', 'Valea Ursului', 'Valea Ursului', 46.8166700, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114052, 'Valea Târsei', 'Valea Tarsei', 'Valea Tars,Valea Tarsei,Valea Tirsei,Valea Târsei,Valea Tîrsei', 45.1771100, 25.6332300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114053, 'Valea Teilor', 'Valea Teilor', 'Meidanchioi,Meidankioi,Valea Teilor', 45.1115000, 28.4880100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114054, 'Valea Strâmbă', 'Valea Stramba', 'Tekeropatak,Tekerőpatak,Valea Strimba,Valea Strîmbă,Valea-Stramba,Valea-Strâmbă', 46.6942900, 25.5995600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114055, 'Valea Stanciului', 'Valea Stanciului', 'Valea Stanciului', 43.9833300, 23.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114056, 'Valea Șoșii', 'Valea Sosii', 'Valea Sosei,Valea Sosii,Valea Şoşei', 46.4618000, 26.5499200, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114057, 'Valea Seacă', 'Valea Seaca', 'Valea Saca,Valea Sacă,Valea Seaca,Valea Seacă', 48.0808000, 23.1648900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114058, 'Valea Seacă', 'Valea Seaca', '', 47.2921900, 26.6687600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114059, 'Valea Seacă', 'Valea Seaca', 'Cotu din Jos,Cotu din Sus,Valea Seaca,Valea Seacă,Velea Seaca', 47.1394400, 26.2995600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114060, 'Valea Seacă', 'Valea Seaca', '', 46.4647500, 26.8805400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114061, 'Valea Seacă', 'Valea Seaca', '', 46.2428100, 27.0459400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114062, 'Ştefan Cel Mare', 'Stefan Cel Mare', '', 46.2052600, 26.8548800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114063, 'Valea Sării', 'Valea Sarii', 'Valea Sarii,Valea Sării,Valea-Sarei,Valea-Sărei', 45.8768600, 26.7987300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114064, 'Valea Salciei', 'Valea Salciei', 'Valea Salciei,Valea Sălciei', 45.4962200, 26.8236100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114065, 'Valea Roșie', 'Valea Rosie', '', 44.1775500, 26.6345700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114066, 'Valea Râmnicului', 'Valea Ramnicului', 'Baltatii Vechi,Bălţaţii Vechi,Valea Rimnicului,Valea Rîmnicului', 45.3639500, 27.0419700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114067, 'Valea Rece', 'Valea Rece', 'Hidegseg,Hidegsèg,Valea Rece', 46.6208200, 25.9582700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114068, 'Valea Popii', 'Valea Popii', 'Valea Popi,Valea Popii', 45.0925300, 25.0224000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114069, 'Valea Părului', 'Valea Parului', '', 45.3637400, 26.7770600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114070, 'Valea Părului', 'Valea Parului', 'Putintei,Putinteiu,Puţintei,Puţinteiu,Valea Parului,Valea Părului', 43.9172700, 25.4658900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114071, 'Valea Nucarilor', 'Valea Nucarilor', 'Ion Gheorghe Duca,Sarighiol-de Vale,Valea Nucarilor', 45.0333300, 28.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114072, 'Valea Moldovei', 'Valea Moldovei', 'Valea Moldovei,Valea Seaca,Valea Seacă', 47.4666700, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114073, 'Valea Merilor', 'Valea Merilor', '', 44.4716900, 24.6561100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114074, 'Valea Mărului', 'Valea Marului', 'Puteni,Puţeni,Valea Marului,Valea Mărului', 45.8386600, 27.6913800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114075, 'Valea Mare Pravăț', 'Valea Mare Pravat', 'Valea Mare Dimbovita,Valea Mare Dîmboviţa,Valea Mare-Pravat,Valea Mare-Pravăţ', 45.2917100, 25.0925000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114076, 'Valea Mare-Podgoria', 'Valea Mare-Podgoria', 'Ion Gheorghe Duca,Valea Mare,Valea Mare Podgorie,Valea Mare-Podgoria,Valea Podgoriei', 44.8851300, 24.9061300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114077, 'Valea Mare', 'Valea Mare', 'Nagyatak', 45.7666700, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114078, 'Valea Mare', 'Valea Mare', '', 45.1126300, 23.0800400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114079, 'Valea Mare', 'Valea Mare', '', 44.9378300, 24.2388300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114080, 'Valea Mare', 'Valea Mare', '', 44.7833300, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114081, 'Valea Mare', 'Valea Mare', '', 44.6666700, 24.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114082, 'Valea Mare', 'Valea Mare', 'Valea Mare,Valea Mare Noua,Valea Mare Nouă', 44.4666700, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114083, 'Valea Măcrișului', 'Valea Macrisului', 'Valea Macrisului,Valea Măcrişului', 44.7437900, 26.8301500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114084, 'Valea Lupului', 'Valea Lupului', 'Beldiman,Valea Lupului', 47.1792000, 27.4996500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114085, 'Valea Lungă Ogrea', 'Valea Lunga Ogrea', 'Ogrea,Valea Lunga-Ogrea,Valea Lungă-Ogrea', 45.0597800, 25.5902400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114086, 'Valea Lungă-Cricov', 'Valea Lunga-Cricov', 'Valea Lunga-Cricov,Valea Lunga-Cricovu,Valea Lungă-Cricov', 45.0652800, 25.5879300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114087, 'Valea Lungă', 'Valea Lunga', 'Hosszuaszo,Hosszuászó,Husasau,Husasău,Langenthal,Valea Lunga,Valea Lungă', 46.1259200, 24.0454100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114088, 'Valea lui Mihai', 'Valea lui Mihai', 'Ermihalyfalva,Opstina Valea Lui Mihai,Opština Valea Lui Mihai,Valea lui,Valea lui Mihai,Valja-luj-Mikhaj,mi ha yi gu xiang,wlh lwyy myhy,Érmihályfalva,Валя-луй-Михай,Валя-луй-Міхай,وله لویی میهی,米哈伊谷鄉', 47.5166700, 22.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114089, 'Valea lui Ion', 'Valea lui Ion', '', 46.7035000, 26.6249900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114090, 'Valea Leurzii', 'Valea Leurzii', 'Valea,Valea Leurzei,Valea Leurzii', 45.1618600, 25.4853300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114091, 'Valea Largă', 'Valea Larga', 'Tiguit,Valea Larga,Valea Largă,Ţiguit', 46.6225700, 24.0775800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114092, 'Valea Izvoarelor', 'Valea Izvoarelor', 'Besineu,Besineul,Beşineu,Beşineul,Valea Izvoarelor', 46.4385500, 24.3759700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114093, 'Valea Ierii', 'Valea Ierii', 'Valea Ierii', 46.6500000, 23.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114094, 'Valea Iaşului', 'Valea Iasului', 'Valea Iasului,Valea Iaşului', 45.1833300, 24.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114095, 'Valea Grecului', 'Valea Grecului', '', 46.7198500, 28.1012300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114096, 'Valea Dulce', 'Valea Dulce', '', 45.1142800, 26.2078700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114097, 'Valea Dragului', 'Valea Dragului', 'Valea Dragu,Valea Dragului', 44.2122200, 26.3036100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114098, 'Valea Danului', 'Valea Danului', 'Radesti,Rădeşti,Valea Danului', 45.1833300, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114099, 'Valea Dacilor', 'Valea Dacilor', 'Valea Dacilor,Valea Dracilor', 44.1949500, 28.3177600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114100, 'Valea Cucului', 'Valea Cucului', '', 45.0652500, 26.2279300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114101, 'Valea Crişului', 'Valea Crisului', 'Korospatak,Köröspatak,Valea Crisului,Valea Crişului', 45.9166700, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114102, 'Valea Cireșului', 'Valea Ciresului', 'Alexandru Lahovari,Lahovari,Valea Ciresului,Valea Cireşului', 44.1669900, 25.5643700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114103, 'Valea Ciorii', 'Valea Ciorii', 'Ciorusca,Cioruşca,Valea Ciorii', 44.7166700, 27.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114104, 'Valea Cânepii', 'Valea Canepii', 'Valea Cinepei,Valea Cînepei,Valea-Canepei,Valea-Cânepei', 45.0833300, 27.8166700, 'RO', '2015-11-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114105, 'Valea Chioarului', 'Valea Chioarului', 'Gaura,Kovargara,Valea Chioarului', 47.4333300, 23.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114106, 'Valea Caselor', 'Valea Caselor', '', 45.3500000, 25.1666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114107, 'Valea Călugărească', 'Valea Calugareasca', 'Valea Calugareasca,Valea Călugărească', 44.9666700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114108, 'Valea Borcutului', 'Valea Borcutului', '', 47.3748300, 24.6529300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114109, 'Valea Bolvașnița', 'Valea Bolvasnita', 'Valea Bolvasnica,Valea Bolvasnita,Valea Bolvaşniţa,Valea Bolvašnica', 44.9460200, 22.3901900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114110, 'Valea Arinilor', 'Valea Arinilor', 'Valea Arinilor,Valea-Aninilor', 46.4979300, 26.5091800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114111, 'Valea Arini', 'Valea Arini', '', 47.1269400, 26.2937700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114112, 'Valea Argovei', 'Valea Argovei', 'Brancoveni,Brincoveni,Brâncoveni,Brîncoveni,Frimu,I.C. Bratianu,I.C. Brătianu,I.C. Frimu,Ion I. C. Bratianu,Ion I. C. Brătianu,Valea Argovei', 44.3500000, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114113, 'Vale', 'Vale', 'Vajla,Vale', 46.9491000, 25.3786900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114114, 'Valcău de Jos', 'Valcau de Jos', 'Valcau de Jos,Valcaul-de-Jos,Valcău de Jos,Vălcăul-de-Jos', 47.1166700, 22.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114115, 'Vălcani', 'Valcani', 'Valcani,Valkani,Valkanj,Valkany,Valkány,Vălcani', 46.0035700, 20.3986500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114116, 'Vaideeni', 'Vaideeni', 'Vaideeni', 45.1666700, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114117, 'Vaida-Cămăraș', 'Vaida-Camaras', 'Camarasul,Cămăraşul,Vaida-Camaras,Vaida-Cămăraş', 46.8282300, 23.9472400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114118, 'Văgiuleşti', 'Vagiulesti', 'Vagiulesti,Văgiuleşti', 44.7166700, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114119, 'Vadu Sorești', 'Vadu Soresti', 'Vadu Soresti,Vadu Soreşti,Vadul Sorestilor', 45.3150000, 26.8774800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114120, 'Vadu Săpat', 'Vadu Sapat', 'Vadu Sapat,Vadu Săpat,Vadul Sapat', 45.0397300, 26.3870000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114121, 'Vadu Roșca', 'Vadu Rosca', 'Vadu Rosca,Vadu Roşca,Vadul-Rosca,Vadul-Roşca', 45.6386400, 27.4571600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114122, 'Vădurele', 'Vadurele', '', 46.9331900, 26.2507400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114123, 'Vădurele', 'Vadurele', '', 46.7295800, 26.5717300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114124, 'Vadu Paşii', 'Vadu Pasii', 'Vadu Pasi,Vadu Pasii,Vadu Paşi,Vadu Paşii,Vadul-Pasii,Vadul-Paşii', 45.1666700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114125, 'Vadu Părului', 'Vadu Parului', 'Vadu Parului,Vadul,Vadul-Parului,Vadul-Părului,Vădul', 44.9313200, 26.2094000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114126, 'Vadu Moţilor', 'Vadu Motilor', 'Sacatura,Secatura,Secătura,Săcătura,Vadu Motilor,Vadu Moţilor', 46.4000000, 22.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114127, 'Vadu Moldovei', 'Vadu Moldovei', 'Barasti-Ciumulesti,Barasti-Ciumulestii,Bărăsti-Ciumuleştii,Bărăşti-Ciumuleşti,Ciumulesti,Ciumuleşti,Vadu Moldovei', 47.3833300, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114128, 'Vadu Izei', 'Vadu Izei', '', 47.9333300, 23.8833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114129, 'Vadu Izei', 'Vadu Izei', 'Farkasicy,Farkasrev,Farkasrév,Vad,Vadu Izei', 47.8882100, 23.9320900, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114130, 'Vadu Crişului', 'Vadu Crisului', 'Rev,Rév,Vad,Vadu Crisului,Vadu Crişului,Vadul lui Carol II,Vadul-Carol II', 46.9833300, 22.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114131, 'Vădeni', 'Vadeni', 'Vadeni,Vădeni', 45.3666700, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114132, 'Vădăstriţa', 'Vadastrita', 'Vadastrita,Vădăstriţa', 43.8500000, 24.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114133, 'Vădastra', 'Vadastra', 'Vadastra,Vădastra', 43.8666700, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114134, 'Vad', 'Vad', 'Vad', 47.2000000, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114135, 'Văculeşti', 'Vaculesti', 'Vaculesti,Văculeşti', 47.8833300, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114136, 'Văcăreşti', 'Vacaresti', 'Vacaresti,Văcăreşti', 44.8500000, 25.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114137, 'Văcăreni', 'Vacareni', '', 45.3241500, 28.1951200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114138, 'Uzunu', 'Uzunu', 'Uzun,Uzunu,Uzunul', 44.1471600, 25.9671900, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114139, 'Utvin', 'Utvin', 'Otveny,Utfeny,Utfény,Utvin,Utwin,Ötvény', 45.7129800, 21.1301100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114140, 'Ususău', 'Ususau', 'Hosszuaszo,Hosszuszo,Hosszúaszó,Hosszúszó,Hoszszuszo,Hoszszúszó,Marosaszo,Marosaszó,Ususau,Ususău', 46.0706300, 21.8137100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114141, 'Urzicuţa', 'Urzicuta', 'Urzicuta,Urzicuţa', 44.0166700, 23.5500000, 'RO', '2017-07-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114142, 'Urziceni', 'Urziceni', 'Urziceni', 47.7333300, 22.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114143, 'Urziceni', 'Urziceni', 'Opstina Urziceni,Opština Urziceni,Urziceni,Urzicenis,Urzichen'',Urzicheni,Urzičenis,awrzychh,uleujicheni,urujicheni,wu er ji qie ni,Урзичени,Урзічень,אורזיצן,اورزیچه,ウルジチェニ,乌尔济切尼,우르지체니', 44.7166700, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114144, 'Urziceanca', 'Urziceanca', 'Urziceanca,Urziceanca-Alesi', 44.6305200, 25.8424000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114145, 'Urși', 'Ursi', '', 44.9940400, 24.0889500, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114146, 'Urseni', 'Urseni', 'Magyarmedves,Medues,Medueş,Medves,Medvis,Ungarisch-Medwisch,Urseni', 45.6926900, 21.3099300, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114147, 'Ursa', 'Ursa', '', 43.7878300, 24.6378700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114148, 'Urmeniş', 'Urmenis', 'Urmenis,Urmenisu,Urmenisul,Urmeniş,Urmenişu,Urmenişul', 46.7666700, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114149, 'Urleta', 'Urleta', '', 45.0873200, 25.7935400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114150, 'Urleasca', 'Urleasca', '', 45.1369700, 27.6473600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114151, 'Urlaţi', 'Urlati', 'Urlati,Urlatii,Urlaţi', 44.9833300, 26.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114152, 'Uriu', 'Uriu', 'Uri,Uriu,Uriul,Uriul-de-Sus', 47.2000000, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114153, 'Uricani', 'Uricani', '', 45.3373100, 23.1524000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114154, 'Urecheşti', 'Urechesti', 'Urechesti,Urechestii,Urecheşti,Urecheştii', 46.1333300, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114155, 'Urecheşti', 'Urechesti', '', 45.6000000, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114156, 'Urecheni', 'Urecheni', 'General Al. Averescu,General Averescu,General Uricheni,Urecheni', 47.1666700, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114157, 'Urdari', 'Urdari', 'Urdari,Urdarii de Jos', 44.8000000, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114158, 'Urca', 'Urca', '', 46.5488500, 23.9618700, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114159, 'Unţeni', 'Unteni', 'Unteni,Unţeni', 47.8000000, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114160, 'Unirea', 'Unirea', '', 47.1606000, 24.5307800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114161, 'Unirea', 'Unirea', 'Unirea,Vintul de Sus,Vinţul de Sus', 46.4038700, 23.8131400, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114162, 'Unirea', 'Unirea', 'Patesti,Păţeşti,Unirea', 45.7402000, 27.1074100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114163, 'General Berthelot', 'General Berthelot', 'Alsofarkadin,Alsófarkadin,Farcadinul de Jos,Fărcădinul de Jos,Unirea', 45.6166700, 22.8833300, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114164, 'Unirea', 'Unirea', 'Osmanu,Osmanul,Unirea', 45.1166700, 27.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114165, 'Unirea', 'Unirea', 'Socariciu,Socariciul,Unirea,Şocariciu,Şocariciul', 44.2666700, 27.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114166, 'Unirea', 'Unirea', 'Risipiti,Risipiţi', 44.1500000, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114167, 'Unguriu', 'Unguriu', 'Unguriu,Unguriul', 45.2793300, 26.6320800, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114168, 'Arini', 'Arini', 'Magyarfalu,Ungureni,Unguri', 46.3500000, 27.1833300, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114169, 'Ungureni-Jianu', 'Ungureni-Jianu', '', 47.8833300, 26.7833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114170, 'Ungureni', 'Ungureni', '', 46.5166700, 26.9500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114171, 'Ungureni', 'Ungureni', '', 47.5463100, 23.9524100, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114172, 'Ungureni', 'Ungureni', 'Leca Ungureni,Lecca,Slobozia-Leca,Slobozia-Parincea,Ungureni,Ungureni-Leca,Ungurenii', 46.5228300, 27.1118600, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114173, 'Ungureni', 'Ungureni', 'Ungureni,Ungurenii', 45.9130700, 27.4700000, 'RO', '2013-04-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114174, 'Ungureni', 'Ungureni', '', 44.8714700, 25.3918000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114175, 'Ungureni', 'Ungureni', 'Tudor Vladimirescu,Ungureni', 44.5780400, 25.5000600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114176, 'Unguraş', 'Unguras', 'Unguras,Unguraş', 47.1166700, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114177, 'Ungra', 'Ungra', 'Ungra', 45.9833300, 25.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114178, 'Ungheni', 'Ungheni', 'Nyaradto,Nyàràdtö,Ungheni', 46.4833300, 24.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114179, 'Ungheni', 'Ungheni', '', 44.5000000, 24.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114180, 'Umbrărești', 'Umbraresti', '', 45.8483500, 27.9184500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114181, 'Umbrăreşti', 'Umbraresti', 'Umbraresti,Umbraresti-Slobozia,Umbrăreşti,Umbrăreşti-Slobozia', 45.7166700, 27.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114182, 'Ulmu', 'Ulmu', 'General Poetas,General Poetaş,Poetas,Poetaş,Ulmu', 44.9500000, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114183, 'Ulmu', 'Ulmu', 'Ulmu,Ulmul,Ulmy', 44.2666700, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114184, 'Ulmi', 'Ulmi', 'Ulmi', 44.9000000, 25.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114185, 'Ulmi', 'Ulmi', 'Ulmi,Ulmii-Ornesti,Ulmii-Orneşti', 44.4866700, 25.7802800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114186, 'Ulmeni', 'Ulmeni', 'Ulmeni', 47.4666700, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114187, 'Ulmeni', 'Ulmeni', '', 45.0666700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114188, 'Ulmeni', 'Ulmeni', '', 44.1500000, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114189, 'Ulma', 'Ulma', '', 47.8833300, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114190, 'Ulieşti', 'Uliesti', 'Uliesti,Ulieşti', 44.5833300, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114191, 'Uivar', 'Uivar', 'Neuburg an der Bega,Uivar,Ujvar,Újvár', 45.6580600, 20.9058300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114192, 'Uioara de Jos', 'Uioara de Jos', 'Ciunga,Uioara de Jos', 46.3708700, 23.8386300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114193, 'Udupu', 'Udupu', '', 44.3965700, 25.1448800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114194, 'Udeşti', 'Udesti', 'Udesti,Udeşti,Uidesti,Uideşti', 47.5666700, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114195, 'Uda-Paciurea', 'Uda-Paciurea', '', 43.8797900, 24.7237900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114196, 'Uda-Clocociov', 'Uda-Clocociov', 'Uda-Clocociov,Uda-Clocociovul', 43.8879100, 24.7143700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114197, 'Uda', 'Uda', '', 47.3364500, 26.5716500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114198, 'Uda', 'Uda', '', 44.9166700, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114199, 'Ucea de Sus', 'Ucea de Sus', '', 45.7500000, 24.6833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114200, 'Ucea de Jos', 'Ucea de Jos', '', 45.7841000, 24.6709700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114201, 'Tuzla', 'Tuzla', '', 44.0000000, 28.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114202, 'Tutova', 'Tutova', 'Dragalina,Tutova', 46.1166700, 27.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114203, 'Ţuţora', 'Tutora', 'Tutora,Ţuţora', 47.1333300, 27.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114204, 'Tutana', 'Tutana', '', 45.0428600, 24.6512200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114205, 'Tuta', 'Tuta', 'Tuta,Tutu', 46.2564300, 26.6910300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114206, 'Tușnadu Nou', 'Tusnadu Nou', 'Tusnad Nou,Tusnad Ujfain,Tusnadu Nou,Tusnadul Nou,Tuşnad Nou,Tuşnadu Nou,Ujtusnad,Ujtusnàd', 46.1936400, 25.8875700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114207, 'Tuşnad', 'Tusnad', 'Gara Tusnad-Sat,Gara Tuşnad-Sat,Tusnad,Tusnad Sat,Tusnad-Kozseg,Tusnàd-Közsèg,Tuşnad,Tuşnad Sat', 46.2000000, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114208, 'Turulung', 'Turulung', 'Turulung', 47.9333300, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114209, 'Turţ', 'Turt', 'Turt,Turţ', 47.9833300, 23.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114210, 'Turnu Ruieni', 'Turnu Ruieni', 'Rueni-Turnu,Turnu Rueni', 45.3907000, 22.3355700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114211, 'Turnu Roşu', 'Turnu Rosu', 'Porcesti,Porceşti,Turnu Rosu,Turnu Roşu,Turnul Rosu,Turnul Roşu', 45.6333300, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114212, 'Turnu Măgurele', 'Turnu Magurele', 'Opstina Turnu Magurele,Opština Turnu Magurele,Turnu Magurele,Turnu Mugurele,Turnu Măgurele,Turnu-Megurele,Turnu-Mehgurele,Turnul-Magurele,Turnul-Măgurele,tu er nu mo gu lei lai,tuleunumeogulelle,twrnw mgwrl,Турну Магуреле,Турну Мъгуреле,Турну-Мегуреле,Турну-Мэгуреле,تورنو مگورل,トゥルヌ・マグレレ,圖爾努默古雷萊,투르누머구렐레', 43.7500000, 24.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114213, 'Turnu', 'Turnu', 'Sebestorony,Turnu,Turnul', 46.2576400, 21.1265700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114214, 'Turluianu', 'Turluianu', '', 46.4529800, 26.6460700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114215, 'Turia', 'Turia', 'Torja,Turia', 46.0333300, 26.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114216, 'Tureni', 'Tureni', 'Tur', 46.6293400, 23.7024000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114217, 'Tureac', 'Tureac', '', 47.2296700, 24.8058900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114218, 'Turdaş', 'Turdas', '', 45.8500000, 23.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114219, 'Turda', 'Turda', 'Opstina Turda,Opština Turda,Potaissa,Thorenburg,Torda,Turda,to~uruda,tu er da,twrda,Турда,توردا,ტურდა,トゥルダ,圖爾達', 46.5666700, 23.7833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114220, 'Turda', 'Turda', 'Armutlia,Turda,Турда', 44.9750100, 28.6240200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114221, 'Turcoaia', 'Turcoaia', 'Turcoaia', 45.1166700, 28.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114222, 'Turcineşti', 'Turcinesti', 'Turcinesti,Turcineşti', 45.1000000, 23.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114223, 'Turcești', 'Turcesti', '', 45.0402300, 23.8657400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114224, 'Turceni', 'Turceni', 'Turceni,Turcenii de Sus', 44.6833300, 23.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114225, 'Turburea', 'Turburea', 'Turburea,Turburea de Jos', 44.7166700, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114226, 'Tur', 'Tur', '', 47.8823100, 23.3904500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114227, 'Tupilaţi', 'Tupilati', 'Tupilati,Tupilaţi', 47.0666700, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114228, 'Tunelu-Teliu', 'Tunelu-Teliu', '', 45.7000000, 25.8500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114229, 'Tunari', 'Tunari', 'Tunari,Tunarii', 44.5500000, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114230, 'Tuluceşti', 'Tulucesti', 'Tulucesti,Tuluceşti', 45.5666700, 28.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114231, 'Tulnici', 'Tulnici', 'Tulnici,Tulnicii', 45.9166700, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114232, 'Tulgheş', 'Tulghes', 'Toelgyes,Tolgyes,Tulghes,Tulgheş,Tölgyes', 46.9500000, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114233, 'Tulcea', 'Tulcea', 'Aegyssos,Gorad Tulcha,TCE,Toultsea,Tul''cha,Tulca,Tulcea,Tulcha,Tulcsa,Tulcza,Tultscha,Tulča,to~urucha,tu er qia,tulchea,twlcha,twlchy,twltshya,Τούλτσεα,Горад Тулча,Тулча,Тулчә,Тульча,Տուլչա,טולצאה,تولتشيا,تولچا,طولچی,トゥルチャ,圖爾恰,툴체아', 45.1666700, 28.8000000, 'RO', '2012-12-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114234, 'Tulca', 'Tulca', 'Tulca', 46.7833300, 21.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114235, 'Ţuglui', 'Tuglui', 'Tuglui,Ţuglui', 44.1833300, 23.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114236, 'Tufeşti', 'Tufesti', '', 45.0500000, 27.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114237, 'Tufeni', 'Tufeni', '', 45.0579000, 25.8397600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114238, 'Tufeni', 'Tufeni', 'Tufeni,Tufeni din Vale,Tufenii-din Vale', 44.3666700, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114239, 'Tudor Vladimirescu', 'Tudor Vladimirescu', '', 47.6863500, 27.1721100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114240, 'Suceveni', 'Suceveni', 'Suceveni,Tudor Vladimirescu,Vladimirescu', 46.0122200, 28.0180600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114241, 'Tudor Vladimirescu', 'Tudor Vladimirescu', 'Chirilesti,Chirileşti,Tudor Vladimirescu', 45.5666700, 27.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114242, 'Tudor Vladimirescu', 'Tudor Vladimirescu', '', 45.2166700, 27.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114243, 'Tudor Vladimirescu', 'Tudor Vladimirescu', 'Principele Ferdinand,Tudor Vladimirescu', 43.9476100, 24.9061600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114244, 'Tudora', 'Tudora', 'Tudora', 47.5166700, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114245, 'Truşeşti', 'Trusesti', 'Trusesti,Truşeşti', 47.7666700, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114246, 'Troianul', 'Troianul', 'Belitori,Troianul', 44.0000000, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114247, 'Trivalea-Moşteni', 'Trivalea-Mosteni', 'Trivalea,Trivalea-Mosteni,Trivalea-Moşteni', 44.2666700, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114248, 'Tritenii de Sus', 'Tritenii de Sus', '', 46.6054400, 23.9984900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114249, 'Tritenii de Jos', 'Tritenii de Jos', 'Tritenii de Jos', 46.5833300, 24.0000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114250, 'Trip', 'Trip', '', 47.9245000, 23.3764800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114251, 'Trifeşti', 'Trifesti', '', 47.4500000, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114252, 'Trifeşti', 'Trifesti', 'Trifesti,Trifeşti', 46.9166700, 26.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114253, 'Treznea', 'Treznea', 'Tresnea,Treznea', 47.1000000, 23.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114254, 'Trestieni', 'Trestieni', '', 44.5044900, 25.7578900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114255, 'Trei Sate', 'Trei Sate', 'Harmasfalu,Hàrmasfalu,Trei Sate', 46.4757200, 24.8985500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114256, 'Trăisteni', 'Traisteni', 'Traisteni,Trestieni,Trăisteni', 45.3385700, 25.7276700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114257, 'Traian Vuia', 'Traian Vuia', 'Bujor,Traian Vuia', 45.8000000, 22.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114258, 'Traian', 'Traian', '', 46.9914000, 26.9043800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114259, 'Traian', 'Traian', '', 46.8333500, 26.5765500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114260, 'Traian', 'Traian', 'Traian,Trajan', 46.6333300, 27.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114261, 'Traian', 'Traian', '', 45.1833300, 27.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114262, 'Traian', 'Traian', '', 45.0287600, 28.2351800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114263, 'Traian', 'Traian', '', 44.7635000, 27.3433700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114264, 'Traian', 'Traian', '', 44.0166700, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114265, 'Traian', 'Traian', '', 43.7666700, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114266, 'Totoești', 'Totoesti', 'Falaesti,Falaeşti,Totesti,Toteşti,Totoesti,Totoeşti', 47.2510700, 27.2887900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114267, 'Toteşti', 'Totesti', 'Totesti,Toteşti', 45.5666700, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114268, 'Tortoman', 'Tortoman', 'Tortoman', 44.3500000, 28.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114269, 'Tormac', 'Tormac', 'Rittberg,Tormac,Tormak,Tormák', 45.5208300, 21.4936100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114270, 'Topraisar', 'Topraisar', 'Topraisar,Topraisari', 44.0166700, 28.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114271, 'Toporu', 'Toporu', 'Toporu,Toporul', 44.0105600, 25.6527800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114272, 'Topoloveni', 'Topoloveni', 'Targu-Carcinov,Topoloveni,Târgu-Cârcinov,Тополовени', 44.8166700, 25.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114273, 'Topolovăţu Mare', 'Topolovatu Mare', 'Grosstoplowetz,Nagy-Topolovecz,Nagytopoly,Topolovatu Mare,Topolovatul-Mare,Topolovăţu Mare,Topolovăţul-Mare', 45.7738900, 21.6188900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114274, 'Topolog', 'Topolog', 'Topolog', 44.8833300, 28.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114275, 'Topolița', 'Topolita', 'Ocea,Toplita,Topliţa,Topolita,Topoliţa', 47.1678700, 26.3834500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114276, 'Topliţa', 'Toplita', '', 45.6833300, 22.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114277, 'Toplița', 'Toplita', '', 45.0902200, 24.7323600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114278, 'Topliceni', 'Topliceni', 'Topliceni,Zgirciti,Zgirciţi', 45.4166700, 27.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114279, 'Topleţ', 'Toplet', 'Cernahevica,Toplet,Topleţ', 44.7972200, 22.3944400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114280, 'Topile', 'Topile', '', 47.2634000, 26.6688300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114281, 'Topana', 'Topana', 'Topana', 44.8166700, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114282, 'Topalu', 'Topalu', 'Topal,Topalu,Topalul', 44.5500000, 28.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114283, 'Tomşani', 'Tomsani', '', 45.1166700, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114284, 'Tomşani', 'Tomsani', '', 44.9500000, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114285, 'Tomnatic', 'Tomnatic', 'Nades,Nagyosz,Nagyősz,Tomnatic,Tribsveter,Triebswetter,Truswetter,Trüswetter', 45.9885700, 20.6618600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114286, 'Tomeşti', 'Tomesti', '', 47.1166700, 27.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114287, 'Tomești', 'Tomesti', 'Csikszenttamas,Csikszenttamás,Sanramas,Sânramas,Tomesti,Tomeşti', 46.5561700, 25.7792200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114288, 'Tomeşti', 'Tomesti', '', 46.2166700, 22.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114289, 'Tomeşti', 'Tomesti', '', 45.7833300, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114290, 'Țolici', 'Tolici', '', 47.1184000, 26.4484100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114291, 'Tohanu Nou', 'Tohanu Nou', 'Neu-Tohan,Tohanu Nou,Tohanul-Nou,Ujtohan,Újtohán', 45.5520800, 25.3862200, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114292, 'Toflea', 'Toflea', 'Toflea,Totlea', 46.0637200, 27.3341100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114293, 'Todireşti', 'Todiresti', 'Todiresti,Todireşti,Toedoresti,Toedoreşti', 47.7000000, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114294, 'Todireşti', 'Todiresti', '', 47.3166700, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114295, 'Todireşti', 'Todiresti', '', 46.8500000, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114296, 'Todireni', 'Todireni', 'Ceir,Movileni,Todireni', 47.6166700, 27.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114297, 'Tocileni', 'Tocileni', '', 47.7110400, 26.7865700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114298, 'Toboliu', 'Toboliu', 'Toboliul', 47.0418200, 21.7194600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114299, 'Tiur', 'Tiur', '', 46.1600900, 23.8892700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114300, 'Titu', 'Titu', 'Titu,Titu-Targ,Titu-Tirg,Titu-Tîrg,Titul,Титу', 44.6500000, 25.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114301, 'Titești', 'Titesti', '', 45.4197100, 24.3932300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114302, 'Titeşti', 'Titesti', 'Tatestii,Titesti,Titeşti,Ţaţeştii', 45.0166700, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114303, 'Tismana', 'Tismana', 'Tismana', 45.0500000, 22.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114304, 'Tisa', 'Tisa', 'Tisa,Virismort,Virismort la Tisa,Virişmort,Virişmort la Tisa', 47.9484400, 23.9576800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114305, 'Târşolţel', 'Tarsoltel', '', 47.9500000, 23.3500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114306, 'Târşolţ', 'Tarsolt', 'Tarsolt,Tirsolt,Târşolţ,Tîrşolţ', 47.9500000, 23.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114307, 'Târnova', 'Tarnova', 'Spineni,Tarnova,Tirnova,Târnova,Tîrnova', 46.3166700, 21.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114308, 'Târnova', 'Tarnova', 'Tarnova,Tirnova,Târnova,Tîrnova', 45.3425000, 22.0061100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114309, 'Târnăveni', 'Tarnaveni', 'Diciosanmartin,Diciosinmartin,Diciosânmartin,Diciosînmartin,Dicsoszentmarton,Dicsőszentmárton,Tarnaveni,Tirnaveni,Târnăveni,Tîrnăveni,to~urunavu~eni,トゥルナヴェニ', 46.3319100, 24.2966200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114310, 'Târnava', 'Tarnava', 'Prostea Mare,Proştea Mare,Tirnava,Tîrnava', 46.1397500, 24.2892600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114311, 'Târnava', 'Tarnava', 'Tarnava,Tarnavele,Tirnava,Târnava,Târnavele,Tîrnava', 44.1444000, 25.5634700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114312, 'Târlişua', 'Tarlisua', 'Tarlisua,Tirlisua,Târlişua,Tîrlişua', 47.3833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114313, 'Târgu Trotuş', 'Targu Trotus', 'Targu-Trotus,Targul Trotusului,Tirgu Trotus,Târgu-Trotuş,Târgul Trotusului,Tîrgu Trotuş', 46.2666700, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114314, 'Târguşor', 'Targusor', 'Pazarli,Pazarlia,Pazarlid,Targusor,Tirgusor,Târguşor,Tîrguşor', 44.4500000, 28.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114315, 'Târgu Secuiesc', 'Targu Secuiesc', 'Kezdivasarhely,Kezoi-Vasarmely,Kèzdivásàrhely,Kèzoi-Vasarmely,Kézdivásárhely,Opstina Targu Secuiesc,Opština Târgu Secuiesc,Tarcu Sacuesc,Targu Secuiesc,Targu Sekujesk,Targu-Sacuesc,Targul Sacuesc,Tirgu Secuesc,Tirgu Secuiesc,Tirgu-Sekuesk,Tirgu-Sekujesk,Tirgul Sacuesc,Turgu Sekujesk,Târgu Secuiesc,Târgu-Săcuesc,Târgul Săcuesc,Tîrgu Secuesc,Tîrgu Secuiesc,Tîrgul Săcuesc,te er gu-sai kui si,teuleuguseku-ieseukeu,trgw skwyys,Таргу Секујеск,Тиргу-Секуйеск,Тиргу-Секуєск,Търгу Секуйеск,ترگو سکوئیس,トゥルグ・セクイエスク,特尔古-塞奎斯,트르구세쿠이에스크', 46.0000000, 26.1333300, 'RO', '2017-06-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114316, 'Târgu Ocna', 'Targu Ocna', 'Aknavasar,Aknavásár,Opstina Targu Ocna,Opština Târgu Ocna,Targu Ocna,Targu Okna,Targul-Ocna,Tirgu Ocna,Tirgu Okna,Tirgu-Okna,Tyrgu-Okna,Târgu Ocna,Târgul-Ocna,Tîrgu Ocna,te er gu ao ke na,trgw awkna,Таргу Окна,Тиргу-Окна,Тыргу-Окна,Տիրգու Օկնա,ترگو اوکنا,特爾古奧克納', 46.2789900, 26.6130100, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114317, 'Târgu Neamţ', 'Targu Neamt', 'Neamtzu,Nemetvasar,Nemetvásár,Pomete,Pometea,Targu-Neamt,Targul Neamt,Tirgu Neamt,Tuteni,Târgu-Neamţ,Târgul Neamţ,Tîrgu Neamţ,Ţuţeni', 47.2000000, 26.3666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114318, 'Târgu-Mureş', 'Targu-Mures', 'Maros-Vasarhely,Maros-Vásárhely,Marosvasarhely,Marosvásárhely,Muresh,Neumarkt,Neumarkt am Mieresch,Novum Forum Siculorum,TGM,Targu Mures,Targul-Mures,Tirgu Mures,Turgul Mures,Tyrgu-Muresh,Târgu Mureş,Târgu Mureș,Târgul-Mureş,Tîrgu Mureş,Tîrgu Mureș,Vasarhely,Vásárhely,trgw mwrs,Тыргу-Муреш,טרגו מורש', 46.5424500, 24.5574700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114319, 'Târgu Lăpuş', 'Targu Lapus', 'Lapus,Lăpuş,Targu-Lapus,Targu-Lapusului,Targul Lapusul,Targul Lapusului,Târgu-Lăpuş,Târgu-Lăpuşului,Târgul Lăpuşul,Târgul Lăpuşului', 47.4526100, 23.8653900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114320, 'Târgu Jiu', 'Targu Jiu', 'Jiu,Targu Jiu,Targu Zhiju,Targul-Jiu,Tirgu Jiu,Tirgu Ziu,Tirgu Žiu,Tirgu-Zhiu,Tirnkou Ziou,Turgu Zhiu,Tyrgu-Zhiu,Târgu Jiu,Târgul-Jiu,Tîrgu Jiu,Zsilvasarhely,Zsilvásárhely,te er gu ri wu,teuleugujiu,trgw zhy,trgw zyw,trjw jyw,tyrgw zhyw,tyrgwjw,Τίργκου Ζίου,Таргу Жију,Тиргу-Жиу,Тиргу-Жіу,Търгу Жиу,Тыргу-Жиу,טרגו זיו,ترجو جيو,ترگو ژی,تیرگو ژیو,تیرگوجو,ტირგუ-ჟიუ,トゥルグ・ジウ,特爾古日烏,트르구지우', 45.0500000, 23.2833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114321, 'Târgu Frumos', 'Targu Frumos', 'Targu-Frumos,Targul Frumos,Tirgu Frumos,Târgu-Frumos,Târgul Frumos,Tîrgu Frumos', 47.2000000, 27.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114322, 'Târgu Cărbuneşti', 'Targu Carbunesti', 'Targu Carbunesti,Targul-Carbunesti,Tirgu Carbunesti,Târgu Cărbuneşti,Târgul-Cărbuneşti,Tîrgu Cărbuneşti', 44.9500000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114323, 'Târgşoru Vechi', 'Targsoru Vechi', 'Targsorul-Vechi,Targsorul-Vechiu,Tirgsoru Vechi,Târgşorul-Vechi,Târgşorul-Vechiu,Tîrgşoru Vechi', 44.8666700, 25.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114324, 'Târgovişte', 'Targoviste', 'Targoviste,Tirgoviste,Turgovishhe,Târgoviste,Târgovişte,Târgoviște,Tîrgovişte,to~urugovu~ishute,Търговище,トゥルゴヴィシュテ', 44.9254300, 25.4567000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114325, 'Tiream', 'Tiream', 'Tiream', 47.6166700, 22.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114326, 'Țipar', 'Tipar', '', 46.4756300, 21.6343100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114327, 'Ţinteşti', 'Tintesti', 'Tintesti,Ţinteşti', 45.0666700, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114328, 'Țintea', 'Tintea', '', 45.0340300, 25.9046000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114329, 'Tântava', 'Tantava', 'Tantava,Tintava,Tântava,Tîntava', 44.4151100, 25.8245000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114330, 'Ţânţăreni', 'Tantareni', 'Tantarea,Tantareni,Tintareni,Tăntarea,Ţânţăreni,Ţînţăreni', 44.6000000, 23.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114331, 'Tinosu', 'Tinosu', 'Tinosu,Tinosul', 44.8166700, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114332, 'Tânganu', 'Tanganu', 'Cernica-Tangau,Cernica-Tăngau,Tanganu,Tanganul,Tinganu,Tânganu,Tânganul,Tînganu', 44.4062800, 26.3126200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114333, 'Tinca', 'Tinca', 'Tinca', 46.7752900, 21.9330000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114334, 'Tâmna', 'Tamna', 'Tamna,Timna,Tâmna,Tîmna', 44.5666700, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114335, 'Timişoara', 'Timisoara', 'Freidorf,Josefvarosa,Josephs-Stadt,Jozsefvaros,Jósefvárosa,Józsefváros,Kendetelep,Szabadfalu,TSR,Temeschburg,Temeschwar,Temesvar,Temesvarinum,Temesvár,Temeswar,Temeşvar,Temešvár,Temishvar,Temisoara,Temisvar,Temişoara,Temišvar,Timishoara,Timisoara,Timişoara,Timišoara,Timișoara,timishoara,timisyoala,tmshwar,tymyshwara,Темишвар,Тимишоара,טימישוארה,تيميشوارا,طمشوار,ティミショアラ,티미쇼아라', 45.7537200, 21.2257100, 'RO', '2016-07-30', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114336, 'Timişeşti', 'Timisesti', 'Timisesti,Timişeşti', 47.2333300, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114337, 'Tâmboeşti', 'Tamboesti', 'Tamboesti,Timboesti,Tâmboeşti,Tîmboeşti', 45.5166700, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114338, 'Tilişca', 'Tilisca', 'Tilisca,Tilişca', 45.8000000, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114339, 'Tileagd', 'Tileagd', 'Telegd,Tileagd', 47.0666700, 22.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114340, 'Tihău', 'Tihau', '', 47.2272400, 23.3296400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114341, 'Tiha Bârgăului', 'Tiha Bargaului', 'Bargaului,Bârgăului,Tiha,Tiha Barg,Tiha Birgaului,Tiha Bîrgăului,Tiha-Bargaului,Tiha-Bârgăului', 47.2333300, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114342, 'Tigveni', 'Tigveni', '', 45.1333300, 24.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114343, 'Ţigăneşti', 'Tiganesti', 'Tiganesti,Ţigăneşti', 43.9000000, 25.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114344, 'Ţigănaşi', 'Tiganasi', 'Tiganasi,Tiganesti,Tigănesti,Ţigănaşi', 47.3333300, 27.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114345, 'Ţifeşti', 'Tifesti', 'Tifesti,Ţifeşti', 45.8500000, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114346, 'Ticvaniu Mare', 'Ticvaniu Mare', 'Ticvaniu Mare,Ticvaniul-Mare,Ticvanul-Mare,Tikvaniul Mare', 45.1352800, 21.6380600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114347, 'Ticuşu Vechi', 'Ticusu Vechi', 'Tecusu Vechi,Tecuşu Vechi,Ticcusul-Vechiu,Ticcuşul-Vechiu,Ticusu Vechi,Ticusul,Ticusul-Vechi,Ticusul-Vechiu,Ticuşu Vechi,Ticuşul-Vechi,Ticuşul-Vechiu', 45.9333300, 25.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114348, 'Ţicleni', 'Ticleni', 'Ticleni,Ţicleni', 44.8833300, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114349, 'Tichileşti', 'Tichilesti', '', 45.1166700, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114350, 'Ţibucani', 'Tibucani', 'Tibucani,Tibucani-de-Sus,Tibucanii de Sus,Ţibucani,Ţibucani-de-Sus,Ţibucanii de Sus', 47.1000000, 26.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114351, 'Țibeni', 'Tibeni', '', 47.8161800, 26.0243800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114352, 'Ţibăneşti', 'Tibanesti', 'Tibanesti,Ţibăneşti', 46.9166700, 27.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114353, 'Ţibana', 'Tibana', 'Tibana,Ţibana', 46.9833300, 27.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114354, 'Tia Mare', 'Tia Mare', 'Tia Mare,Tia-Mar', 43.8666700, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114355, 'Tetoiu', 'Tetoiu', 'Bugiulesti,Bugiuleşti,Tetoiu,Tetoiul', 44.7500000, 23.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114356, 'Tețcoiu', 'Tetcoiu', 'Tetcoiu,Tetcoiul,Teţcoiu,Teţcoiul', 44.6818800, 25.4384600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114357, 'Teslui', 'Teslui', 'Teslui', 44.5166700, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114358, 'Teșila', 'Tesila', '', 45.3035200, 25.7232400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114359, 'Terpeziţa', 'Terpezita', 'Terezita,Tereziţa,Terpezita,Terpeziţa', 44.2919100, 23.5055900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114360, 'Teremia Mare', 'Teremia Mare', 'Gross-Teremin,Mariafolde,Marienfeld,Máriafölde,Nagy-Terem,Nagy-Teremia,Nagy-Tezrem,Teremia Mare,Velika Teremija', 45.9352800, 20.5250000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114361, 'Teregova', 'Teregova', '', 45.1500000, 22.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114362, 'Terebeşti', 'Terebesti', 'Terebesti,Terebeşti', 47.6833300, 22.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114363, 'Ţepu', 'Tepu', 'Tepu,Tepu de Jos,Ţepu,Ţepu de Jos', 45.9666700, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114364, 'Țelna', 'Telna', '', 46.1590200, 23.5009900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114365, 'Teliucu Inferior', 'Teliucu Inferior', 'Alsotelek,Alsótelek,Teliuc,Teliucu Inferior,Teliucul-Inferior', 45.7166700, 22.8833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114366, 'Teliu', 'Teliu', 'Kreuzburg Tyei,Teliu,Teliuc,Teliud,Teliul', 45.6985600, 25.8559000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114367, 'Teleşti', 'Telesti', 'Telesti,Telesti-Birnici,Telestii Birnici,Teleşti,Teleşti-Birnici', 45.0000000, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114368, 'Teleormanu', 'Teleormanu', '', 43.9627100, 25.4587600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114369, 'Telega', 'Telega', 'Telega', 45.1333300, 25.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114370, 'Telec', 'Telec', '', 46.8797900, 25.8777500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114371, 'Telciu', 'Telciu', 'Telciu,Telciul,Telcs', 47.4333300, 24.4000000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114372, 'Telcișor', 'Telcisor', '', 47.4600000, 24.4515800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114373, 'Teiuş', 'Teius', 'Teius,Teiuş', 46.2000000, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114374, 'Teiu', 'Teiu', 'Teiu,Teiu din Deal,Teiul din Deal', 44.6666700, 25.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114375, 'Teişani', 'Teisani', 'Teisani,Teişani', 45.2333300, 25.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114376, 'Teiș', 'Teis', 'Teis,Teisu,Teisul,Teiş,Teişu,Teişul', 44.9628500, 25.4028000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114377, 'Tecuci', 'Tecuci', 'Opstina Tecuci,Opština Tecuci,Tecuci,Tekuch,Tekuchi,Tekucis,Tekucs,Tekučis,tai ku qi,tekuchi,tkwch,Текуч,Текучи,تکوچ,テクチ,泰庫奇', 45.8497300, 27.4344100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114378, 'Tecuci', 'Tecuci', 'Tecuci,Tecuci-Kalinderu', 44.3417900, 24.8596600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114379, 'Techirghiol', 'Techirghiol', 'Techirghiol,Tekerghiol', 44.0500000, 28.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114380, 'Teasc', 'Teasc', 'Teascu,Teascul', 44.1645400, 23.8646100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114381, 'Teaca', 'Teaca', 'Teaca', 46.9166700, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114382, 'Tazlău', 'Tazlau', 'Tazlau,Tazlaul,Tazlo,Tazlău,Tazlăul,Tázló', 46.7166700, 26.4666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114383, 'Tăuții-Măgherăuș', 'Tautii-Magheraus', 'Miszmogyoros,Miszmogyorós', 47.6500000, 23.4833300, 'RO', '2015-12-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114384, 'Tăuții de Sus', 'Tautii de Sus', '', 47.6566500, 23.6584100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114385, 'Tăuteu', 'Tauteu', 'Tautau,Tauteu,Toti,Tăuteu,Tăutău', 47.2666700, 22.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114386, 'Tăut', 'Taut', 'Taut,Tauti,Tăut,Tăuţi', 46.7199000, 21.8384500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114387, 'Tauţ', 'Taut', 'Taur,Taut,Tauti,Tauţ,Tauţi,Tăur', 46.2833300, 21.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114388, 'Tăureni', 'Taureni', 'Bikafalva,Taureni,Tăureni', 46.2666700, 25.2500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114389, 'Tătuleşti', 'Tatulesti', 'Tatulesti,Tătuleşti', 44.6333300, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114390, 'Tătăruşi', 'Tatarusi', 'Tatarusi,Tătăruşi', 47.3500000, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114391, 'Tătaru', 'Tataru', 'Tataru,Tătaru', 45.1000000, 26.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114392, 'Tătaru', 'Tataru', 'Tataru,Tatarul,Tătaru,Tătarul', 44.8448200, 27.4337600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114393, 'Tătărăștii de Sus', 'Tatarastii de Sus', 'Tatarasti,Tatarastii de Sus,Tătărăşti,Tătărăştii de Sus', 44.4076800, 25.1219200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114394, 'Tătărăștii de Jos', 'Tatarastii de Jos', 'Tatarasti-de-Jos,Tatarastii de Jos,Tatarestii de Jos,Tătăreştii de Jos,Tătărăşti-de-Jos,Tătărăştii de Jos', 44.3750100, 25.1772100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114395, 'Tătărăști', 'Tatarasti', 'Corni,Tatarestii,Tătăreştii', 46.2166700, 27.2000000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114396, 'Tătăranu', 'Tataranu', 'Tataranu,Tătăranu', 45.5166700, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114397, 'Tătărăni', 'Tatarani', 'Tatarani,Tătărăni', 46.6942200, 27.9644300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114398, 'Tătărani', 'Tatarani', 'Tatarani,Tătărani', 45.0000000, 25.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114399, 'Tătărani', 'Tatarani', 'Tarani,Tatarani,Tătărani', 44.8976300, 26.0350900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114400, 'Tăşnad', 'Tasnad', 'Tasnad,Tăşnad', 47.4833300, 22.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114401, 'Taşca', 'Tasca', 'Tasca,Taşca', 46.9000000, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114402, 'Tășad', 'Tasad', '', 46.9377300, 22.1251600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114403, 'Tărtăşeşti', 'Tartasesti', 'Tartasesti,Tărtăşeşti', 44.5772200, 25.8127800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114404, 'Tărlungeni', 'Tarlungeni', 'Tarlugeni,Tarlungeni,Tartrang,Tarungemi,Tatrang,Târungemi,Tărlugeni,Tărlungeni', 45.6333300, 25.7500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114405, 'Tariverde', 'Tariverde', 'Dororotea,Dorotea,Dorotheia,Tariverde,Tariverdi', 44.5626800, 28.6024500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114406, 'Tăriceni', 'Tariceni', '', 44.7962400, 25.9695800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114407, 'Tarcea', 'Tarcea', 'Tarcea', 47.4500000, 22.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114408, 'Tarcău', 'Tarcau', 'Ion Gheorghe Duca,Tarcau,Tarcau-Gheuca,Tarcău,Tarcău-Gheuca,Tarko,Tarkő', 46.8666700, 26.1333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114409, 'Tărcaia', 'Tarcaia', 'Korostarkany,Köröstárkány,Tarcaia,Tarkany,Tárkány,Tărcaia', 46.6333300, 22.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114410, 'Tansa', 'Tansa', '', 47.3013900, 27.0765300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114411, 'Tansa', 'Tansa', 'Tansa', 46.9166700, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114412, 'Ţăndărei', 'Tandarei', 'Tandarei,Ţăndărei', 44.6500000, 27.6666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114413, 'Tănăsoaia', 'Tanasoaia', 'Tanasoaia,Tănăsoaia', 46.1000000, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114414, 'Tanacu', 'Tanacu', 'Tanacu,Tanacul', 46.6833300, 27.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114415, 'Tamaşi', 'Tamasi', 'Tamas,Tamasi,Tamaşi,Tămaş', 46.4833300, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114416, 'Tamași', 'Tamasi', '', 44.5843800, 26.0072400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114417, 'Tămășeu', 'Tamaseu', 'Paptamasi,Paptamási,Tamasau,Tamaseu,Tamasi,Tamasău,Tamási,Tămăşeu', 47.2211600, 21.9276000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114418, 'Tămăşeni', 'Tamaseni', 'Tamaseni,Tămăşeni', 46.9833300, 26.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114419, 'Tămașda', 'Tamasda', '', 46.6445300, 21.5568500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114420, 'Tămădău Mare', 'Tamadau Mare', 'Tamadau,Tamadau Mare,Tamadaul-Mare,Tămădău,Tămădău Mare,Tămădăul-Mare', 44.4666700, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114421, 'Talpoș', 'Talpos', '', 46.6912400, 21.8033500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114422, 'Tălpigi', 'Talpigi', 'Talpiga,Talpigi,Tălpiga,Tălpigi', 46.0079600, 27.4724700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114423, 'Talpa-Trivalea', 'Talpa-Trivalea', '', 44.2833300, 25.2833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114424, 'Tălpaș', 'Talpas', 'Talpasiu,Talpasu,Talpasul,Tălpasiu,Tălpaşu,Tălpaşul', 44.6822700, 23.7455300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114425, 'Talpa-Ogrăzile', 'Talpa-Ograzile', '', 44.2872600, 25.2932800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114426, 'Tălmaciu', 'Talmaciu', 'Talmaciu,Talmaciul,Talmesch,Tălmaciu,Tălmaciul', 45.6671400, 24.2646400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114427, 'Tălmăcel', 'Talmacel', 'Talmacel,Tălmăcel', 45.6471200, 24.2427000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114428, 'Talea', 'Talea', 'Talea', 45.2256400, 25.5643300, 'RO', '2016-02-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114429, 'Ţaga', 'Taga', 'Taga,Ţaga', 46.9500000, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114430, 'Tăcuta', 'Tacuta', 'Tacuta,Tăcuta', 46.9166700, 27.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114431, 'Tăbărăști', 'Tabarasti', 'Tabarasti,Tabarastii Vechi,Tăbărăşti,Tăbărăştii Vechi', 45.0794800, 26.9194300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114432, 'Tabăra', 'Tabara', '', 47.5739500, 27.4121300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114433, 'Sviniţa', 'Svinita', 'Svinita,Sviniţa', 44.4997200, 22.1061100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114434, 'Sutești', 'Sutesti', 'Pietroasa,Sutesti,Suteşti', 44.6685100, 24.2147600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114435, 'Şuţeşti', 'Sutesti', 'Sutesti,Şuţeşti', 45.2166700, 27.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114436, 'Suseni Socetu', 'Suseni Socetu', 'Socetu-Suseni,Suseni-Socetu', 44.7561800, 25.7982900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114437, 'Susenii Bârgăului', 'Susenii Bargaului', 'Susenii Bargaului,Susenii Birgaului,Susenii Bârgâului,Susenii Bîrgăului', 47.2231100, 24.7073000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114438, 'Suseni', 'Suseni', 'Felfalu', 46.8138100, 24.7319400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114439, 'Suseni', 'Suseni', 'Suseni,Ujfalu,Ujfalù', 46.6666700, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114440, 'Suseni', 'Suseni', '', 44.9009200, 25.1442300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114441, 'Suseni', 'Suseni', '', 44.7166700, 24.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114442, 'Şuşani', 'Susani', 'Susani,Susanii de Jos,Şuşani,Şuşanii de Jos', 44.5833300, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114443, 'Surdulești', 'Surdulesti', '', 44.3921700, 24.9579800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114444, 'Surduc', 'Surduc', 'Surduc,Szurduk', 47.2500000, 23.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114445, 'Surdila-Greci', 'Surdila-Greci', 'Greci,Surdila-Greci', 45.0666700, 27.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114446, 'Surdila-Găiseanca', 'Surdila-Gaiseanca', 'Surdila-Gaiseanca,Surdila-Găiseanca', 45.0666700, 27.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114447, 'Șurdești', 'Surdesti', '', 47.6021500, 23.7689900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114448, 'Surani', 'Surani', 'Surani', 45.2000000, 26.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114449, 'Şura Mică', 'Sura Mica', 'Klein Scheuern,Sura Mica,Şura Mică', 45.8333300, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114450, 'Şura Mare', 'Sura Mare', 'Gross Scheuern', 45.8500000, 24.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114451, 'Suraia', 'Suraia', 'Suraia', 45.6833300, 27.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114452, 'Supuru de Jos', 'Supuru de Jos', 'Supuru de Jos,Supurul-de-Jos', 47.4666700, 22.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114453, 'Suplacu de Barcău', 'Suplacu de Barcau', 'Suplac,Suplac-de-Barcau,Suplac-de-Barcău,Suplacu de Barcau,Suplacu de Barcău,Suplacul-de-Barcau,Suplacul-de-Barcău', 47.2572900, 22.5319500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114454, 'Suplac', 'Suplac', 'Supla,Suplac', 46.3833300, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114455, 'Șupitca', 'Supitca', '', 47.6094100, 26.7835900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114456, 'Şuncuiuş', 'Suncuius', 'Sumcuius,Sumcuiuş,Suncuius,Şuncuiuş', 46.9333300, 22.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114457, 'Sultana', 'Sultana', '', 44.2606200, 26.8542400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114458, 'Sulița', 'Sulita', 'Sulita-Targ,Sulita-Tirg,Suliţa-Târg,Suliţa-Tîrg,Targ Sulita,Târg Suliţa', 47.6500000, 26.9166700, 'RO', '2015-11-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114459, 'Sulina', 'Sulina', 'Soulinas,Sulina,su li na,sulina,surina,swlyna,swlynh,Σουλινάς,Сулина,Սուլինա,סולינה,سولينا,سولینا,সুলিনা,სულინა,スリナ,蘇利納', 45.1559000, 29.6535600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114460, 'Şuletea', 'Suletea', 'Suletea,Şuletea', 46.2833300, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114461, 'Şuici', 'Suici', 'Suici,Şuici', 45.2500000, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114462, 'Suhurlui', 'Suhurlui', 'Suhurlui', 45.7287300, 27.8267800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114463, 'Suhuleț', 'Suhulet', '', 46.9036800, 27.2584900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114464, 'Suharău', 'Suharau', '', 48.1333300, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114465, 'Suhaia', 'Suhaia', 'Suhaia', 43.7333300, 25.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114466, 'Şugag', 'Sugag', 'Sugag,Sugág', 45.7666700, 23.6333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114467, 'Sudiți', 'Suditi', '', 45.2689000, 26.8718300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114468, 'Sudiţi', 'Suditi', '', 44.5833300, 27.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114469, 'Suciu de Sus', 'Suciu de Sus', 'Felsoszoos,Felsōszöos,Suciu de Sus,Suciul-de Sus', 47.4333300, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114470, 'Suciu de Jos', 'Suciu de Jos', 'Suciu de Jos,Suciul-de-Jos', 47.4458400, 23.9825000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114471, 'Suceviţa', 'Sucevita', '', 47.7833300, 25.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114472, 'Suceava', 'Suceava', 'Gorad Suchava,SCV,Soutseava,Sucava,Suceava,Suchava,Suczawa,Sučava,Szucsava,Szucsáva,su qia wa,suchava,suchavu~a,sucheaba,swchawa,swtshafa,swzʼbh,sʼz,Σουτσεάβα,Горад Сучава,Сучава,Сучәва,Սուչավա,סוצאבה,שאץ,سوتشافا,سوچاوا,სუჩავა,スチャヴァ,蘇恰瓦,수체아바', 47.6333300, 26.2500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114473, 'Suceagu', 'Suceagu', 'Suceag,Suceagu,Suciag,Suciagu,Sugeacu', 46.7843200, 23.4651100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114474, 'Subcetate', 'Subcetate', 'Gyorgyo-Varhegy,Györgyo-Várhegy,Subcetate,Varhegy,Vàrhegy', 46.8500000, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114475, 'Suatu', 'Suatu', 'Suatu,Suatul', 46.7666700, 23.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114476, 'Stulpicani', 'Stulpicani', 'Stulpicani', 47.4666700, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114477, 'Studinița', 'Studinita', '', 43.9769100, 24.4266800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114478, 'Studina', 'Studina', 'Studina', 43.9666700, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114479, 'Strunga', 'Strunga', 'Strunga', 47.1666700, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114480, 'Strugari', 'Strugari', '', 46.5333300, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114481, 'Stroiești', 'Stroiesti', '', 47.6104200, 26.9656200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114482, 'Stroiești', 'Stroiesti', '', 47.6166700, 26.1333300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114483, 'Stroești', 'Stroesti', 'Stroesti,Stroestii,Stroeşti,Stroeştii', 45.1295300, 24.7941800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114484, 'Stroeşti', 'Stroesti', '', 45.0833300, 23.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114485, 'Trestiana', 'Trestiana', 'Palerma,Stroe Beloescu', 46.2000000, 27.6500000, 'RO', '2016-01-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114486, 'Strâmtura', 'Stramtura', 'Stramtura,Strimtura,Strâmtura,Strîmtura', 47.7833300, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114487, 'Strâmtura', 'Stramtura', 'Stramtura,Strimtura,Strâmtura,Strîmtura', 47.5808200, 25.6814400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114488, 'Strâmbeni', 'Strambeni', 'Strambeni,Strimbeni,Strâmbeni,Strîmbeni', 44.4689700, 24.9731500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114489, 'Stremţ', 'Stremt', 'Stremt,Stremţ', 46.2166700, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114490, 'Strejnicu', 'Strejnicu', 'Strejnic,Strejnicu,Strejnicul', 44.9167600, 25.9510900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114491, 'Strejeștii de Sus', 'Strejestii de Sus', 'Strajestii-de-Sus,Strejestii de Sus,Strejeştii de Sus,Străjeştii-de-Sus', 44.5438900, 24.2277200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114492, 'Strejeşti', 'Strejesti', 'Strajestii-de-Jos,Strejesti,Strejestii de Jos,Strejeşti,Strejeştii de Jos,Străjeştii-de-Jos', 44.5333300, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114493, 'Strehaia', 'Strehaia', 'Strehaia', 44.6166700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114494, 'Străteni', 'Strateni', 'Rusii Strateni,Strateni,Străteni', 47.9367700, 26.2966400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114495, 'Străoane', 'Straoane', 'Stranoanii-de Jos,Straoane,Straoane de Jos,Străoane,Străoane de Jos', 45.9333300, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114496, 'Straja', 'Straja', 'Straja', 47.9166700, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114497, 'Straja', 'Straja', '', 46.4398900, 26.3625800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114498, 'Storobăneasa', 'Storobaneasa', 'Storobaneasa,Storobăneasa', 43.8833300, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114499, 'Stornești', 'Stornesti', '', 47.1166700, 27.1833300, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114500, 'Storeşti', 'Storesti', '', 47.5500000, 26.8666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114501, 'Stolnici', 'Stolnici', '', 44.5666700, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114502, 'Stolniceni-Prăjescu', 'Stolniceni-Prajescu', '', 47.1985800, 26.7481000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114503, 'Stolniceni', 'Stolniceni', '', 45.0394800, 24.3064000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114504, 'Stoina', 'Stoina', 'Stoina', 44.6833300, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114505, 'Stoileşti', 'Stoilesti', 'Popesti,Popeşti,Stoilesti,Stoileşti', 44.9000000, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114506, 'Stoicăneşti', 'Stoicanesti', '', 44.1833300, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114507, 'Stoeneşti', 'Stoenesti', 'Stoenesti,Stoenestii,Stoeneşti', 45.2500000, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114508, 'Stoeneşti', 'Stoenesti', '', 45.1166700, 24.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114509, 'Stoenești', 'Stoenesti', '', 44.9242200, 25.8588100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114510, 'Stoenești', 'Stoenesti', '', 44.4856900, 25.7119600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114511, 'Stoeneşti', 'Stoenesti', 'Stoenesti,Stoeneşti,Stoeresti', 44.1444400, 25.8950000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114512, 'Stoeneşti', 'Stoenesti', 'Stoenesti,Stoenestii,Stoeneşti,Stoeneştii', 44.1166700, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114513, 'Ştiuca', 'Stiuca', 'Csukas,Csukás,Ebendorf,Stiuca,Styuka,Ştiuca', 45.5713900, 21.9766700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114514, 'Ştiubieni', 'Stiubieni', 'Stiubeeni,Stiubeni,Stiubieni,Stubieni,Ştiubeeni,Ştiubeni,Ştiubieni,Ştubieni', 47.9666700, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114515, 'Stârciu', 'Starciu', 'Starciu,Starciul,Stirciu,Stârciu,Stârciul,Stîrciu', 47.0874700, 22.9199800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114516, 'Stângăceaua', 'Stangaceaua', 'Stangaceaua,Stingaceaua,Stângăceaua,Stîngăceaua', 44.6089600, 23.3127300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114517, 'Stâncești', 'Stancesti', 'Stincesti,Stînceşti', 47.7500000, 26.6000000, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114518, 'Stânceni', 'Stanceni', 'Goedemesterhaza,Gödemesterháza,Stinceni,Stînceni', 46.9833300, 25.2333300, 'RO', '2015-12-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114519, 'Stânca', 'Stanca', 'Stanca,Stinca,Stînca', 47.2306900, 26.1313900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114520, 'Stâna', 'Stana', 'Stana,Stina,Stâna,Stîna', 47.5075700, 22.9642300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114521, 'Stâlpu', 'Stalpu', 'Stalpu,Stalpul,Stilpu,Stâlpu,Stâlpul,Stîlpu', 45.0833300, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114522, 'Stâlpeni', 'Stalpeni', 'Stalpeni,Stalpenii,Stilpeni,Stâlpeni,Stâlpenii,Stîlpeni', 45.0500000, 24.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114523, 'Sticlăria', 'Sticlaria', '', 47.4011500, 26.8379700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114524, 'Sterpoaia', 'Sterpoaia', '', 44.7905800, 23.4360100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114525, 'Stelnica', 'Stelnica', 'Stelnica', 44.4166700, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114526, 'Stejaru', 'Stejaru', 'Stejaru,Stejarul', 46.9188800, 26.1802300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114527, 'Stejaru', 'Stejaru', 'Eschibaba,Eskibaba,Stejaru', 44.7666700, 28.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114528, 'Stejaru', 'Stejaru', 'Baltati,Bălţaţi,Stejaru', 44.1833300, 24.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114529, 'Stejari', 'Stejari', 'Cordesti,Cordeşti,Stejari,Stejarul', 44.7666700, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114530, 'Steierdorf', 'Steierdorf', 'Steierdorf,Steierdorfanina', 45.0635900, 21.8521600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114531, 'Ştefeşti', 'Stefesti', 'Stefesti,Ştefeşti', 45.2166700, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114532, 'Ştefan Vodă', 'Stefan Voda', 'Falcoianu,Fălcoianu,General Falcoianu,General Fălcoianu,Stefan Voda,Ştefan Vodă', 44.3166700, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114533, 'Ştefăneşti-Sat', 'Stefanesti-Sat', '', 47.7833300, 27.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114534, 'Ştefăneştii de Jos', 'Stefanestii de Jos', 'Stefanesti-de-Jos,Stefanestii de Jos,Ştefăneşti-de-Jos,Ştefăneştii de Jos', 44.5333300, 26.2000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114535, 'Ștefănești', 'Stefanesti', 'Stefanesci,Stefanescĭ,Stefanesti,Stefanesti-Targ,Stefanesti-Tirg,Stefanestii,Stefaneştii,Ştefăneşti,Ştefăneşti-Târg,Ştefăneşti-Tîrg', 47.7916900, 27.2005300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114536, 'Ştefăneşti', 'Stefanesti', 'Partizanii,Stefanesti,Ştefăneşti', 44.8650600, 24.9496100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114537, 'Ştefăneşti', 'Stefanesti', 'Scoala,Stefanesti,Stefanestii,Şcoala,Ştefanestii,Ştefăneşti', 44.6166700, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114538, 'Ştefan cel Mare', 'Stefan cel Mare', 'Serbesti,Şerbeşti', 46.9848200, 26.5107000, 'RO', '2012-06-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114539, 'Ştefan cel Mare', 'Stefan cel Mare', '', 46.7166800, 27.6287300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114540, 'Ștefan cel Mare', 'Stefan cel Mare', '', 44.4263900, 27.6455600, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114541, 'Ştefan cel Mare', 'Stefan cel Mare', 'Stefan cel Mare,Stefan-Celmore,Stefanesti,Ştefan cel Mare', 44.4928300, 25.2441800, 'RO', '2012-06-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114542, 'Ştefan cel Mare', 'Stefan cel Mare', '', 43.8112400, 24.2203900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114543, 'Stăvaru', 'Stavaru', 'Stavaru,Stavarul,Stăvaru,Stăvarul', 43.8644500, 24.2590200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114544, 'Stăuceni', 'Stauceni', 'Stauceni,Stăuceni', 47.7166700, 26.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114545, 'Starchiojd', 'Starchiojd', 'Starchiojd', 45.3166700, 26.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114546, 'Stăniţa', 'Stanita', 'Molfanesti,Molfăneşti,Stanita,Stăniţa', 47.0166700, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114547, 'Stănişeşti', 'Stanisesti', 'Stanisesti,Stănişeşti,Targul Stanisesti,Targul Stănişeşti', 46.4333300, 27.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114548, 'Stănileşti', 'Stanilesti', 'Slanilesti,Slănileşti,Stalinesti,Stalinestii,Stanilesti,Stălineşti,Stălineştii,Stănileşti', 46.6183300, 28.1713900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114549, 'Stăneşti', 'Stanesti', 'Mijlocu,Stanesti,Stăneşti', 45.1166700, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114550, 'Stăneşti', 'Stanesti', '', 43.9166700, 25.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114551, 'Stăncuţa', 'Stancuta', 'Stancuta,Stăncuţa', 44.9000000, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114552, 'Stăncești', 'Stancesti', 'Stancesti,Stincesti,Stînceşti,Stănceşti', 45.1266500, 26.9231900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114553, 'Stancea', 'Stancea', '', 44.1368000, 26.8122600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114554, 'Stamate', 'Stamate', 'Baluseni Stamate,Băluşeni Stamate,Stamate', 47.6059800, 26.5169800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114555, 'Spulber', 'Spulber', 'Spulber,Spulberu', 45.7518600, 26.7608000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114556, 'Şpring', 'Spring', 'Spring,Şpring', 45.9666700, 23.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114557, 'Sprâncenata', 'Sprancenata', 'Sprincenata,Sprîncenata', 44.0833300, 24.6333300, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114558, 'Spiru Haret', 'Spiru Haret', 'Geormaneasa,Geormăneasa,Spiru Haret', 44.8671500, 27.7446300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114559, 'Spinuş', 'Spinus', 'Spinus,Spinuş', 47.2000000, 22.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114560, 'Spermezeu', 'Spermezeu', 'Spermezeu,Spermezu', 47.3000000, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114561, 'Speriețeni', 'Sperieteni', '', 44.7661100, 25.4522300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114562, 'Spătărei', 'Spatarei', '', 43.8884800, 25.1365000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114563, 'Spanţov', 'Spantov', 'Spantov,Spanţov', 44.1166700, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114564, 'Sovata', 'Sovata', 'Opstina Sovata,Opština Sovata,QSV,Sovata,Szovata,Szovàta,Szováta,suo wa ta,swt,Совата,سوت,索瓦塔', 46.5833300, 25.0666700, 'RO', '2014-01-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114565, 'Şovarna', 'Sovarna', 'Sovarna,Sovarna de Jos,Şovarna', 44.8536100, 22.7925000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114566, 'Şotrile', 'Sotrile', 'Sotrile,Şotrile', 45.2166700, 25.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114567, 'Şotânga', 'Sotanga', 'Sotanga,Sotinga,Şotânga,Şotînga', 44.9833300, 25.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114568, 'Şopotu Nou', 'Sopotu Nou', 'Novi Sopot,Sopotu Nou,Sopotul-Nou,Şopotu Nou,Şopotul-Nou', 44.8419400, 21.8627800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114569, 'Sopot', 'Sopot', '', 44.4166700, 23.5000000, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114570, 'Soporu de Câmpie', 'Soporu de Campie', 'Soporu de Cimpie,Soporu de Cîmpie,Soporul-de-Campie,Soporul-de-Câmpie', 46.6961800, 24.0065800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114571, 'Şopârliţa', 'Soparlita', 'Soparlita,Sopirlita,Sopârliţa,Şopîrliţa', 44.2833300, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114572, 'Şona', 'Sona', 'Sona,Şona', 46.2166700, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114573, 'Somușca', 'Somusca', '', 46.4014700, 26.9118900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114574, 'Somova', 'Somova', 'Somova,Somovo', 45.1833300, 28.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114575, 'Someş-Odorhei', 'Somes-Odorhei', 'Somes-Odorhei,Somes-Odorheiu,Somes-Odorheu,Someş-Odorhei,Someş-Odorheiu,Someş-Odorheu', 47.3166700, 23.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114576, 'Şomcuta Mare', 'Somcuta Mare', 'Somcuta Mare,Somcutza,Şomcuta Mare', 47.5166700, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114577, 'Solovăstru', 'Solovastru', 'Gorgenyoroszfalu-Solovaestru,Görgenyoroszfalù-Solovæstru,Solovastrau,Solovastru,Solovastrul,Solovăstru,Solovăstrul,Solovăstrău', 46.7666700, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114578, 'Solonţ', 'Solont', 'Solont,Solonţ', 46.5500000, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114579, 'Soloneț', 'Solonet', '', 47.6868200, 26.0322200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114580, 'Soleşti', 'Solesti', 'Solesti,Soleşti', 46.7666700, 27.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114581, 'Şoldanu', 'Soldanu', 'Soldanu,Soldanul,Şoldanu,Şoldanul', 44.2166700, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114582, 'Solca', 'Solca', 'Solca', 47.7000000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114583, 'Şoimuş', 'Soimus', 'Marossolymos,Scholmosch,Soimus,Şoimuş', 45.9166700, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114584, 'Şoimi', 'Soimi', 'Soimi,Şoimi', 46.6833300, 22.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114585, 'Şoimari', 'Soimari', 'Soimari,Şoimari', 45.1833300, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114586, 'Sohodol', 'Sohodol', '', 45.0553100, 22.8819400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114587, 'Sohodol', 'Sohodol', 'Sohodol', 46.3558100, 23.0292300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114588, 'Sohodol', 'Sohodol', '', 45.5282900, 25.4024400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114589, 'Sohatu', 'Sohatu', 'Sohani,Sohatu,Sohatul', 44.3166700, 26.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114590, 'Şofronea', 'Sofronea', 'Sofronea,Sofronia,Şofronea,Şofronia', 46.2666700, 21.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114591, 'Sodomeni', 'Sodomeni', '', 47.2223300, 26.6880500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114592, 'Socond', 'Socond', 'Socond', 47.5666700, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114593, 'Socol', 'Socol', 'Socol,Socolovati,Socolovăţi,Sokolovac', 44.8608300, 21.3702800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114594, 'Socodor', 'Socodor', 'Socodor', 46.5166700, 21.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114595, 'Soci', 'Soci', '', 47.1857300, 26.6444600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114596, 'Socetu', 'Socetu', '', 44.1950200, 24.8542100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114597, 'Şoarş', 'Soars', 'Sears,Soars,Soarsu,Şoarş,Şoarşu', 45.9285900, 24.9286700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114598, 'Snagov', 'Snagov', 'Dobrosesti,Dobroşeşti,Snagov', 44.7000000, 26.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114599, 'Smulţi', 'Smulti', 'Smulti,Smulţi', 45.9333300, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114600, 'Smirna', 'Smirna', '', 44.7240500, 27.3547800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114601, 'Smârdioasa', 'Smardioasa', 'Smardioasa,Smirdioasa,Smârdioasa,Smîrdioasa', 43.8500000, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114602, 'Smârdan', 'Smardan', 'Smardan,Smirdan,Smârdan,Smîrdan', 45.4833300, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114603, 'Smârdan', 'Smardan', 'Smardan,Smirdan,Smârdan,Smîrdan', 43.9338200, 22.9659200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114604, 'Smeeni', 'Smeeni', 'Smeeni', 44.9833300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114605, 'Slon', 'Slon', 'Slon,Slonu,Slonul', 45.3552100, 26.0418900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114606, 'Slobozia Moara', 'Slobozia Moara', 'Slobozia Moara', 44.6000000, 25.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114607, 'Slobozia-Mândra', 'Slobozia-Mandra', 'Mandra,Slobozia,Slobozia-Mandra,Slobozia-Mindra,Slobozia-Mândra,Slobozia-Mîndra', 43.9166700, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114608, 'Slobozia Conachi', 'Slobozia Conachi', '', 45.5833300, 27.7833300, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114609, 'Slobozia-Ciorăşti', 'Slobozia-Ciorasti', 'Ciorasti,Ciorăşti,Slobozia-Cioraesti,Slobozia-Ciorasti,Slobozia-Ciorăeşti,Slobozia-Ciorăşti', 45.6166700, 27.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114610, 'Slobozia-Câmpineanca', 'Slobozia-Campineanca', 'Campineanca,Câmpineanca,Slobozia,Slobozia-Cimpineanca,Slobozia-Cîmpineanca', 45.7000000, 27.1333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114611, 'Slobozia Bradului', 'Slobozia Bradului', 'Slobozia,Slobozia Bradului', 45.5000000, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114612, 'Slobozia', 'Slobozia', '', 47.4772000, 26.8895800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114613, 'Slobozia', 'Slobozia', '', 47.0575800, 27.4144600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114614, 'Slobozia', 'Slobozia', '', 46.8489200, 26.5334400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114615, 'Slobozia', 'Slobozia', 'Slobozia,Slobozia de Jos,Slobozia-Panu,Slobozija,Слобозия', 46.4749500, 27.3111100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114616, 'Slobozia', 'Slobozia', 'Slobozia,Slobozia de Sus,Slobozija,Слобозия', 44.5252700, 25.2426300, 'RO', '2012-06-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114617, 'Slobozia', 'Slobozia', '', 43.8500000, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114618, 'Slivileşti', 'Slivilesti', 'Slivilesti,Slivileşti', 44.7833300, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114619, 'Slimnic', 'Slimnic', 'Slimnic', 45.9166700, 24.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114620, 'Slăveni', 'Slaveni', '', 44.0855800, 24.5284300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114621, 'Slava Rusă', 'Slava Rusa', 'Slava Rusa,Slava Ruseaska,Slava Rusă', 44.8502900, 28.6055700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114622, 'Slava Cercheză', 'Slava Cercheza', '', 44.9012800, 28.5475300, 'RO', '2016-01-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114623, 'Slătioara', 'Slatioara', '', 44.4000000, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114624, 'Slatina-Timiş', 'Slatina-Timis', 'Slatina,Slatina-Timis,Slatina-Timisului,Slatina-Timiş,Slatina-Timişului', 45.2500000, 22.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114625, 'Slatina', 'Slatina', 'Draceni,Drăceni,Slatina,Слатина', 47.4500000, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114626, 'Slatina', 'Slatina', 'Slatina,Slatina i Romania,Striharet,seullatina,si la di na,slatyna,styya,suratina,Σλάτινα,Слатина,Слатіна,ستیئا,سلاتينا,سلاتینا,سلاتینا، رومانیہ,スラティナ,斯拉蒂納,슬라티나', 44.4333300, 24.3666700, 'RO', '2013-01-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114627, 'Slănic-Moldova', 'Slanic-Moldova', 'Baile Slanic,Băile Slănic,Slanic-Bai,Slanic-Moldova,Slănic-Băi,Slănic-Moldova,Szlanikfuerdo,Szlanikfürdő', 46.2230800, 26.4741300, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114628, 'Slănic', 'Slanic', 'Slanic,Slanicul,Slănic', 45.2500000, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114629, 'Slănic', 'Slanic', '', 45.2310800, 24.8941100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114630, 'Șivița', 'Sivita', '', 45.6128500, 28.0575700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114631, 'Sita Buzăului', 'Sita Buzaului', 'Sita,Sita Buzaului,Sita Buzăului', 45.6500000, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114632, 'Şiştarovăţ', 'Sistarovat', 'Sistaroc,Sistarocz,Sistarovat,Sistarovecz,Sistaróc,Sistarócz,Sistaróvecz,Szisztarovecz,Şiştarovăţ', 46.0166700, 21.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114633, 'Șisești', 'Sisesti', '', 47.6350600, 23.7079400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114634, 'Şişeşti', 'Sisesti', 'Sisesti,Sisestii de Jos,Siseştii de Jos,Şişeşti', 44.7775000, 22.8394400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114635, 'Şirna', 'Sirna', 'Sirna,Şirna', 44.8000000, 25.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114636, 'Şirineasa', 'Sirineasa', 'Sirineasa,Şirineasa', 44.9333300, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114637, 'Şiria', 'Siria', 'Siria,Şiria', 46.2666700, 21.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114638, 'Sireţel', 'Siretel', 'Siretel,Siretelul,Sireţel,Sireţelul,Siritel,Siriţel', 47.4000000, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114639, 'Siret', 'Siret', 'Opstina Siret,Opština Siret,Seret,Siret,Szeretvasar,Szeretvásár,shireto,sileteu,syrh,syrt,xi lei te,Серет,Сирет,Սիրետ,סירט,סערעט,سیره,シレト,錫雷特,시레트', 47.9500000, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114640, 'Sârbii-Măgura', 'Sarbii-Magura', 'Sarbi-Magura,Sarbii-Magura,Sarbii-Măgura,Sirbii-Magura,Sârbi-Măgura,Sîrbii-Măgura', 44.5500000, 24.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114641, 'Sârbi', 'Sarbi', 'Sarbi,Sirbi,Sârbi,Sîrbi', 47.9426800, 26.9181800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114642, 'Sârbi', 'Sarbi', 'Sarbi,Sirbi,Sârbi,Sîrbi', 47.7618400, 23.9449000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114643, 'Sârbi', 'Sarbi', 'Sarbi,Sirbi,Sârbi,Sîrbi', 47.1931500, 22.1221500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114644, 'Sârbeni', 'Sarbeni', 'Adunatii Sirbeni,Adunaţii Sîrbeni,Sarbeni,Sirbeni,Sârbeni,Sîrbeni', 44.4666700, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114645, 'Șipotu', 'Sipotu', '', 45.0407600, 26.0171400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114646, 'Şipote', 'Sipote', 'Sipote,Sipotel,Sipotele,Şipote,Şipotel,Şipotele', 47.4666700, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114647, 'Sânzieni', 'Sanzieni', 'Kezdisznetlelek,Kèzdisznetlèlek,Sanzieni,Sinzieni,Sânzieni,Sînzieni', 46.0500000, 26.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114648, 'Sântion', 'Santion', 'Santion,Sintion,Sântion,Sîntion', 47.0963400, 21.8366000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114649, 'Sântimbru', 'Santimbru', 'Baile Sintimbru,Băile Sîntimbru,Csik-Szent-Karg,Csikszentimre,Santimbru,Sintimbru,Szentimre,Szentimrei Furdo,Szentimrei Fürdo,Sântimbru,Sîntimbru', 46.2812600, 25.8543900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114650, 'Sântimbru', 'Santimbru', 'Santimbru,Sintimbru,Sântimbru,Sîntimbru', 46.1333300, 23.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114651, 'Şinteu', 'Sinteu', 'Sinteu,Şinteu', 47.1500000, 22.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114652, 'Sintești', 'Sintesti', '', 44.3004600, 26.1212600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114653, 'Şintereag', 'Sintereag', 'Sintereag,Şintereag', 47.1833300, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114654, 'Sintea Mare', 'Sintea Mare', 'Sintea,Sintea Mare', 46.5166700, 21.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114655, 'Sântandrei', 'Santandrei', 'Santandrei,Sântandrei', 47.0661500, 21.8535200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114656, 'Sântana de Mureş', 'Santana de Mures', 'Marosszentanna,Santana-de-Mures,Sintana de Mures,Sântana-de-Mureş,Sîntana de Mureş', 46.5666700, 24.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114657, 'Sântana', 'Santana', 'Santana,Santana-de-Mures,Santana-de-Mureş,Sfanta Ana,Sfinta Ana,Sfânta Ana,Sfînta Ana,Sintana,Sîntana', 46.3500000, 21.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114658, 'Sântămăria-Orlea', 'Santamaria-Orlea', 'Santamaria Orlea,Sintamaria-Orlea,Sântămăria Orlea,Sîntămăria-Orlea', 45.5887400, 22.9704200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114659, 'Santa Mare', 'Santa Mare', '', 47.6166700, 27.3500000, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114660, 'Sânsimion', 'Sansimion', 'Csikszentsimon,Sansimion,Sinsimion,Sânsimion,Sînsimion', 46.2500000, 25.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114661, 'Sânpetru Mare', 'Sanpetru Mare', 'Gross-Sankt-Peter,Nagyszentpeter,Nagyszentpéter,Racz-Szent-Peter,Rácz-Szent-Péter,Sanpetru Mare,Sanpetrul-Mare,Sinpetru Mare,Szerb-Szent-Peter,Szerb-Szent-Péter,Sânpetru Mare,Sânpetrul-Mare,Sînpetru Mare', 46.0451500, 20.8183400, 'RO', '2016-01-31', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114662, 'Sânpetru German', 'Sanpetru German', 'Deutsch-Sankt-Peter,Nemetszentpeter,Németszentpéter,Sanpetru,Sanpetru German,Sanpetrul-German,Sinpetru German,Sânpetru,Sânpetru German,Sânpetrul-German,Sînpetru German', 46.1132700, 21.0493200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114663, 'Sânpetru de Câmpie', 'Sanpetru de Campie', 'Sanpetru-de-Campie,Sanpetrul de Campie,Sanpetu de Campie,Sinpetru de Cimpie,Sânpetru-de-Câmpie,Sânpetrul de Câmpie,Sânpetu de Câmpie,Sînpetru de Cîmpie', 46.7158900, 24.2624300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114664, 'Sânpetru', 'Sanpetru', 'Perersberg,Petersberg,Sanpetrul,Sapetru,Simpetru,Sinpetru,Szentpeter,Sânpetrul,Sâpetru,Sîmpetru,Sînpetru', 45.7108200, 25.6367800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114665, 'Sânpaul', 'Sanpaul', 'Sanpaul,Sinpaul,Sînpaul,Sănpaul', 46.8833300, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114666, 'Sânpaul', 'Sanpaul', 'Sanpaul,Sinpaul,Sînpaul,Sănpaul', 46.4500000, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114667, 'Sânnicolau Român', 'Sannicolau Roman', 'Sannicolaul-Roman,Sinnicolau Romin,Sânnicolaul-Român,Sînnicolau Romîn', 46.9610100, 21.7146600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114668, 'Sânnicolau Mare', 'Sannicolau Mare', 'Deutsch-Sankt-Nikolaus,Gross-Sankt-Nikolaus,Nad-Sentmiklos,Nagyszentmiklos,Nagyszentmiklós,Opstina Sannicolau Mare,Opština Sânnicolau Mare,Racz-Nagy-Szent-Miklos,Rácz-Nagy-Szent-Miklós,Sannicolau Mare,Sannicolaul Mare,Sannikolau Mare,Sinmiclaus Mare,Sinnicolau Mare,Sinnicolaul Mare,Sinnikolau-Mare,Sunnikolau Mare,Synnikolau-Mare,Szerb-Nagy-Szent-Miklos,Szerb-Nagy-Szent-Miklós,Sânnicolau Mare,Sânnicolaul Mare,Sînmiclăus Mare,Sînnicolau Mare,Sînnicolaul Mare,Veliki Semiklush,snnykwlyw mrh,Велики Семиклуш,Синниколау-Маре,Синніколау-Маре,Сънниколау Маре,Сынниколау-Маре,سننیکولئو مره', 46.0833300, 20.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114669, 'Sânnicoară', 'Sannicoara', 'Sanicoara,Sinnicoara,Sânicoară,Sînnicoară', 46.7899000, 23.7257000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114670, 'Sânmihaiu Român', 'Sanmihaiu Roman', 'Deutsch-Sankt-Michael,Nemetszentmihaly,Németszentmihály,Rautendorf,Sanmihaiu Roman,Sinmihaiu Roman,Sinmihaiu Romin,Sânmihaiu Român,Sînmihaiu Român,Sînmihaiu Romîn', 45.7044400, 21.0888900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114671, 'Sânmihaiu de Câmpie', 'Sanmihaiu de Campie', 'Sanmihaiu de Campie,Sanmihaiul-de-Campie,Sinmihaiu de Cimpie,Sânmihaiu de Câmpie,Sânmihaiul-de-Câmpie,Sînmihaiu de Cîmpie', 46.8925700, 24.3358900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114672, 'Sânmihaiu Almaşului', 'Sanmihaiu Almasului', 'Sanmihaiul-Almasului,Sinmihaiu Almasului,Sânmihaiul-Almaşului,Sînmihaiu Almaşului', 47.0166700, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114673, 'Sânmărtin', 'Sanmartin', 'Sanmartin,Sinmartin,Szepkenyeruszentmarton,Szépkenyerűszentmárton,Sânmărtin,Sînmărtin', 47.0095300, 24.0781100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114674, 'Sînmartin', 'Sinmartin', 'Santmartin,Sinmartin,Sântmartin,Sînmartin', 47.0072600, 21.9741800, 'RO', '2015-09-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114675, 'Sânmărtin', 'Sanmartin', 'Sanmartin,Sinmartin,Sânmărtin,Sînmărtin', 46.9000000, 23.5666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114676, 'Sânmartin', 'Sanmartin', 'Sanmartin,Sinmartin,Sânmartin,Sînmartin', 46.4165300, 21.3482100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114677, 'Sânmartin', 'Sanmartin', 'Csikszentmarton,Csikszentmàrton,Sanmartin,Sinmartin,Sânmărtin,Sînmartin', 46.2666700, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114678, 'Sânmărghita', 'Sanmarghita', 'Sanmarghita,Sinmarghita,Sânmărghita,Sînmărghita', 47.1564900, 23.9946100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114679, 'Singureni', 'Singureni', 'Singureni', 44.2336100, 25.9433300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114680, 'Sângeru', 'Sangeru', 'Sangeru,Sangerul,Singeru,Sângeru,Sângerul,Sîngeru', 45.1333300, 26.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114681, 'Sânger', 'Sanger', 'Sanger,Singer,Singeru de Cimpie,Sânger,Sînger,Sîngeru de Cîmpie', 46.5582900, 24.1376900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114682, 'Sângeorz-Băi', 'Sangeorz-Bai', 'Sangeorz-Bai,Singeorz-Bai,Singiorz-Bai,Sângeorz-Băi,Sîngeorz-Băi,Sîngiorz-Băi', 47.3685000, 24.6721200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114683, 'Sângeorgiu de Pădure', 'Sangeorgiu de Padure', 'Erdoszentgyorgy,Erdöszentgyörgy,Sangeorgiu-de-Padure,Sangeorgiul de Padure,Sangiorgiul de Padure,Singeorgiu de Padure,Sângeorgiu-de-Pădure,Sângeorgíul de Pădure,Sângiorgiul de Pădure,Sîngeorgiu de Pădure', 46.4306100, 24.8427400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114684, 'Sângeorgiu de Mureş', 'Sangeorgiu de Mures', 'Marosszentgyoergy,Marosszentgyörgy,Sangeorg-de Mures,Sangeorgiul de Mures,Sângeorg-de Mureş,Sângeorgiul de Mureş', 46.5696000, 24.5945300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114685, 'Sineşti', 'Sinesti', '', 47.1166700, 27.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114686, 'Sineşti', 'Sinesti', '', 44.9500000, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114687, 'Sineşti', 'Sinesti', 'Sinesti,Sinesti-Noi,Sinestii Noi,Sinestii-Noui,Sineşti,Sineşti-Noi,Sineştii Noi,Sineştii-Noui', 44.5666700, 26.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114688, 'Sinești', 'Sinesti', '', 44.4677700, 24.6658500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114689, 'Șindrilari', 'Sindrilari', '', 45.7908300, 26.8794700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114690, 'Sândominic', 'Sandominic', 'Csikszentdomokos,Csíkszentdomokos,Sandominic,Sindominic,Sândominic,Sîndominic', 46.5840000, 25.7802800, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114691, 'Sâncraiu de Mureş', 'Sancraiu de Mures', 'Marosszentkiraly,Marosszentkiràly,Sancraiul-de-Mures,Sâncraiul-de-Mures', 46.5511900, 24.5266300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114692, 'Sâncraiu', 'Sancraiu', 'Kalotaszentkiraly,Kalotaszentkirály,Sancrai,Sancraiu,Sancraiul,Sincraiu,Sâncrai,Sâncraiu,Sâncraiul,Sîncraiu,Vamsancraiu,Vamsâncraiu,Zam Sancraiu,Zam Sâncraiu', 46.8333300, 22.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114693, 'Sâncrai', 'Sancrai', 'Sincrai,Szekelyszentkiraly,Székelyszentkirály,Sîncrai', 46.3666700, 25.3166700, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114694, 'Sâncrăieni', 'Sancraieni', 'Csik Szlkirole,Csikszentkiraly,Csikszentkiràly,Sancraeni,Sancraiem,Sancraieni,Sincraieni,Sâncráiem,Sâncrăeni,Sâncrăieni,Sîncrăieni', 46.3143900, 25.8394100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114695, 'Sâncrai', 'Sancrai', 'Sancrai,Sincrai,Sâncrai,Sîncrai', 46.2939400, 23.7520900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114696, 'Sâncel', 'Sancel', 'Sancel,Sincel,Sâncel,Sîncel', 46.2000000, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114697, 'Şinca Veche', 'Sinca Veche', '', 45.7666700, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114698, 'Șinca Nouă', 'Sinca Noua', 'Ujsinka,Újsinka', 45.6945700, 25.2434800, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114699, 'Şincai', 'Sincai', 'Sincai,Şincai', 46.6500000, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114700, 'Sânandrei', 'Sanandrei', 'Sanandrei,Sankt Andreas,Sinandrei,Szentandras,Szentandrás,Sânandrei,Sînandrei,Temesszentandras,Temesszentandrás', 45.8530600, 21.1680600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114701, 'Sinaia', 'Sinaia', 'Gorad Sinaja,Opstina Sinaia,Opština Sinaia,Sinaia,Sinaja,Sinaïa,shinaya,sinaia,sinaya,synaya,xi na ya,Горад Сіная,Синая,Синаја,Сіная,סינאיה,سينايا,سینایا,সিনায়া,სინაია,シナヤ,錫納亞,시나이아', 45.3500000, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114702, 'Simoneşti', 'Simonesti', 'Simenfalva,Simionesti,Simonesti,Simoneşti,Simènfalva,Şimioneşti', 46.3333300, 25.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114703, 'Șimon', 'Simon', '', 45.4848400, 25.3566400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114704, 'Şimnicu de Sus', 'Simnicu de Sus', 'Simnicu de Sus,Simnicul de Sus,Şimnicu de Sus', 44.3833300, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114705, 'Şimleu Silvaniei', 'Simleu Silvaniei', 'Simleu Silvaniei,Simleul Silvaiei,Szilagysomlyo,Szilágysomlyó,Şimleu Silvaniei', 47.2333300, 22.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114706, 'Șimișna', 'Simisna', 'Simisna,Şimişna', 47.2320200, 23.6237000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114707, 'Siminoc', 'Siminoc', 'Siminoc,Siminocu,Siminocul,Turc-Murfat', 44.1686600, 28.3527700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114708, 'Siminicea', 'Siminicea', 'Siminicea', 47.7000000, 26.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114709, 'Şimian', 'Simian', 'Simian,Şimian', 47.4833300, 22.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114710, 'Şimian', 'Simian', 'Simian,Simijanii,Şimian', 44.6141700, 22.7072200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114711, 'Simeria', 'Simeria', 'Opstina Simeria,Opština Simeria,Piski,Simerija,symrya,xi mei li ya,Симерия,Симерија,Сімерія,سیمریا,錫梅里亞', 45.8500000, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114712, 'Sâmbureşti', 'Samburesti', 'Samburesti,Simburesti,Sâmbureşti,Sîmbureşti', 44.8000000, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114713, 'Sâmbotin', 'Sambotin', 'Simbotin,Sîmbotin', 45.1333300, 23.3333300, 'RO', '2015-12-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114714, 'Sâmbăteni', 'Sambateni', 'Sambateni,Simbateni,Szabadhely,Szombathely,Sâmbăteni,Sîmbăteni', 46.1411000, 21.5268900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114715, 'Sâmbăta de Sus', 'Sambata de Sus', 'Felsoszombatfalva,Felsőszombatfalva,Sambata-de-Sus,Simbata Rasariteana,Simbata de Sus,Sâmbăta-de-Sus,Sîmbăta Răsăriteană,Sîmbăta de Sus', 45.7617800, 24.8205300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114716, 'Sâmbăta', 'Sambata', 'Sambata,Simbasag,Simbata,Szombatsag,Szombatság,Sâmbăta,Sîmbaşag,Sîmbăta', 46.8017300, 22.2035700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114717, 'Şimand', 'Simand', 'Simand,Şimand', 46.4333300, 21.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114718, 'Silivașu de Câmpie', 'Silivasu de Campie', 'Mezoszilvas,Mezőszilvás,Silvasu de Cimpie,Silvasul-de-Campie,Silvaşu de Cîmpie,Silvaşul-de-Câmpie', 46.7833300, 24.3000000, 'RO', '2015-11-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114719, 'Siliștea Snagovului', 'Silistea Snagovului', 'Coadele,Silistea Snagovului,Siliştea Snagovului,Turbati,Turbaţi', 44.7392000, 26.1794200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114720, 'Siliștea Gumești', 'Silistea Gumesti', '', 44.3833300, 25.0000000, 'RO', '2016-01-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114721, 'Siliştea Crucii', 'Silistea Crucii', 'Silistea Crucii,Siliştea Crucii', 44.0333300, 23.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114722, 'Siliștea', 'Silistea', '', 46.7778100, 26.6930300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114723, 'Siliştea', 'Silistea', 'Nazaru,Nazarul,Naziru,Nazâru,Nazârul,Nazîru,Silistea,Siliştea', 45.3000000, 27.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114724, 'Siliştea', 'Silistea', 'Silistea,Siliştea,Taspunor,Taşpunor', 44.4000000, 28.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114725, 'Siliştea', 'Silistea', '', 44.3833300, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114726, 'Șilindru', 'Silindru', 'Erselend,Erselénd,Silindru,Silindrul,Şilindru,Şilindrul', 47.4372500, 22.0468300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114727, 'Şilindia', 'Silindia', 'Silindia,Şilindia', 46.3500000, 21.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114728, 'Sihlea', 'Sihlea', 'Sihlea', 45.5000000, 27.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114729, 'Sighetu Marmaţiei', 'Sighetu Marmatiei', 'Maramaros Szighet,Maramarossziget,Marmaros Sihot,Marmarosska,Marmaroš Sihot,Máramarossziget,Sighet,Sighetu Marmatiei,Sighetu Marmaţiei,Sighetu Marmației,Sigit Marmaros''kij,sygt,Сигіт Мармароський,סיגט', 47.9319500, 23.8860300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114730, 'Sâg', 'Sag', 'Sag,Sig,Sâg,Sîg', 47.0754500, 22.7808400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114731, 'Şieuţ', 'Sieut', 'Sieu,Sieut,Şieuţ', 46.9833300, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114732, 'Şieu-Odorhei', 'Sieu-Odorhei', 'Sieu-Odorhei,Sieu-Odorheiu,Sieul Odorhei,Şieu-Odorhei,Şieu-Odorheiu,Şieul Odorhei', 47.1519400, 24.2915900, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114733, 'Şieu-Măgheruş', 'Sieu-Magherus', 'Sieu,Sieu-Magherus,Sieul,Şieu,Şieu-Măgheruş,Şieul', 47.0833300, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114734, 'Șieu', 'Sieu', 'Sieu,Sieul,Şieu,Şieul', 47.7246200, 24.2238900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114735, 'Şieu', 'Sieu', 'Nagysajo,Nagysajó,Sieu,Şieu', 47.0166700, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114736, 'Siculeni', 'Siculeni', 'Harghita,Madefalva,Mádéfalva,Siculeni', 46.4166700, 25.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114737, 'Şicula', 'Sicula', 'Sicula,Şicula', 46.4333300, 21.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114738, 'Șiclău', 'Siclau', 'Siclau,Siclaul,Şiclău,Şiclăul', 46.4912400, 21.3683400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114739, 'Sicheviţa', 'Sichevita', 'Sichevita,Sicheviţa,Sikevica', 44.7350000, 21.8486100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114740, 'Sic', 'Sic', 'Sic,Szek,Szék', 46.9333300, 23.8833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114741, 'Şibot', 'Sibot', 'Sfoot,Sibot,Şfoot,Şibot', 45.9500000, 23.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114742, 'Sibiu', 'Sibiu', 'Cibinium,Gorad Sibiu,Hermannstadt,Hermanstat,Hermanştat,Nagy-Szeben,Nagy-Szében,Nagyszeben,SBZ,Sibin,Sibiu,Simpiou,Sybin,Szeben,shibiu,sibi xu,sibiu,sibiva,sybw,sybyw,xi bi wu,Σιμπίου,Горад Сібіу,Сибиу,Сибињ,Сібіу,סיביו,سيبيو,سیبو,سیبیو,सिबिव,ซีบีอู,სიბიუ,シビウ,錫比烏,시비우', 45.8000000, 24.1500000, 'RO', '2013-05-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114743, 'Sfârcea', 'Sfarcea', 'Sfarcea,Sfircea,Sfârcea,Sfîrcea', 44.4861300, 23.5466100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114744, 'Sfântu-Gheorghe', 'Sfantu-Gheorghe', 'Sepsiszentgyorgy,Sepsiszentgyőrgy,Sfantu Gheorghe,Sfantu-Gheorghe,Sfantul,Sfantul-Gheorghe,Sfehntu-Georg,Sfintu Gheorghe,Sfântu Gheorghe,Sfântu-Gheorghe,Sfântul,Sfântul-Gheorghe,Sfîntu Gheorghe,snt dszʼrdzs,Сфэнту-Георг,סנט דשזארדזש', 45.8666700, 25.7833300, 'RO', '2016-07-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114745, 'Sfântu Gheorghe', 'Sfantu Gheorghe', 'Kadirlez,Kedrilles,Saint George,Sfantu Gheorghe,Sfintu Gheorghe,Sfântu Gheorghe,Sfîntu Gheorghe', 44.8833300, 29.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114746, 'Sfântu Gheorghe', 'Sfantu Gheorghe', 'Sfantu-Gheorghe,Sfintu Gheorghe,Sfântu-Gheorghe,Sfîntu Gheorghe', 44.6500000, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114747, 'Sfinţeşti', 'Sfintesti', 'Sfintesti,Sfinţeşti', 44.1833300, 25.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114748, 'Serdanu', 'Serdanu', 'Serdanu,Serdanul', 44.6273200, 25.6312400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114749, 'Şercaia', 'Sercaia', 'Sercaia,Şercaia', 45.8333300, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114750, 'Șerboeni', 'Serboeni', 'Serboeni,Serboenii,Şerboeni,Şerboenii', 44.6381800, 24.8935500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114751, 'Șerbăuți', 'Serbauti', 'Serbauti,Şerbăuţi', 47.8268400, 26.1400900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114752, 'Ștefan Vodă', 'Stefan Voda', '', 46.3169200, 26.5125000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114753, 'Șerbănești', 'Serbanesti', '', 47.8101400, 26.3192200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114754, 'Șerbănești', 'Serbanesti', '', 44.6814200, 24.9923600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114755, 'Şerbăneşti', 'Serbanesti', 'Serbanesti,Serbanesti-de-Jos,Serbanestii de Jos,Şerbăneşti,Şerbăneşti-de-Jos,Şerbăneştii de Jos', 44.3333300, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114756, 'Șepreuș', 'Sepreus', 'Sepreus,Şepreuş', 46.5712500, 21.7341700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114757, 'Şendriceni', 'Sendriceni', 'Ghilia,Sendriceni,Şendriceni', 47.9500000, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114758, 'Şendreni', 'Sendreni', 'Sendreni,Şendreni', 45.4000000, 27.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114759, 'Semlac', 'Semlac', 'Semlac,Semlak,Szemlak', 46.1166700, 20.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114760, 'Şelimbăr', 'Selimbar', 'Schellenberg', 45.7666700, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114761, 'Seleuș', 'Seleus', 'Seleusu,Seleusu-Mare,Seleusul,Seleuşu,Seleuşu-Mare,Seleuşul', 46.2426100, 24.6942700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114762, 'Seleuş', 'Seleus', 'Seleus,Seleuş', 46.3833300, 21.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114763, 'Şelaru', 'Selaru', 'Selaru,Selarul,Şelaru,Şelarul', 44.4766700, 25.2999700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114764, 'Şeitin', 'Seitin', 'Sajteny,Sajtin,Sajtény,Seitin,Şeitin', 46.1000000, 20.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114765, 'Seini', 'Seini', 'Seini,Szinervaralja,Szinervaraljá,Сеини', 47.7500000, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114766, 'Seimeni', 'Seimeni', 'Seimeni,Seimeni-Mari,Seimenii Mari', 44.3833300, 28.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114767, 'Şeica Mică', 'Seica Mica', 'Seica Mica,Şeica Mică', 46.0500000, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114768, 'Şeíca Mare', 'Seica Mare', 'Seica Mare,Şeíca Mare', 46.0166700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114769, 'Segarcea Vale', 'Segarcea Vale', 'Segarcea,Segarcea Vale,Segarcea-din-Vale', 43.8166700, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114770, 'Segarcea-Deal', 'Segarcea-Deal', 'Segarcea Deal,Segarcea-din Deal', 43.8254800, 24.8402000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114771, 'Segarcea', 'Segarcea', 'Segarcea', 44.1000000, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114772, 'Secusigiu', 'Secusigiu', 'Secusigiu,Secusigiul,Sekeschut,Sekushich,Szekeskut,Székeskút', 46.0833300, 20.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114773, 'Secui', 'Secui', 'Secuiu,Secuiul', 44.1918600, 23.8631900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114774, 'Secuieni', 'Secuieni', 'Campeni,Cimpeni,Câmpeni,Cîmpeni,Dumbrava,Secueni,Secuieni', 46.6500000, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114775, 'Secuieni', 'Secuieni', '', 46.8500000, 26.8333300, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114776, 'Secu', 'Secu', 'Secu,Secul', 44.4666700, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114777, 'Seciu', 'Seciu', '', 45.0327500, 26.0647400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114778, 'Secaş', 'Secas', 'Secas,Secaş,Sekasch,Szekas,Székás,Temesszekas,Temesszékás', 45.8850000, 21.8191700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114779, 'Secăria', 'Secaria', 'Secaria,Secăria', 45.2833300, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114780, 'Sebiş', 'Sebis', 'Borossebes,Sebis,Sebiș', 46.3666700, 22.1166700, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114781, 'Sebeșel', 'Sebesel', 'Sebesel,Sebeşel,Sebisel,Sebişel', 45.8877100, 23.5660600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114782, 'Sebeş', 'Sebes', 'Muehlbach,Muhlbach,Mühlbach,Sebes,Sebesh,Sebeş,Себеш', 45.9564600, 23.5710000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114783, 'Seaca de Pădure', 'Seaca de Padure', 'Seaca de Padure,Seaca de Pădure', 44.3661100, 23.3058700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114784, 'Seaca de Câmp', 'Seaca de Camp', 'Seaca,Seaca de Camp,Seaca de Cimp,Seaca de Câmp,Seaca de Cîmp', 43.9333300, 23.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114785, 'Seaca', 'Seaca', 'Belciugata,Seaca', 44.1666700, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114786, 'Seaca', 'Seaca', 'Seaca', 43.7500000, 25.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114787, 'Scutelnici', 'Scutelnici', 'Meteleu,Meteleu-Scutelnici,Meteleul,Meteleul-Scutelnici,Scurtelnici,Scutelnici', 44.8500000, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114788, 'Scurtu Mare', 'Scurtu Mare', 'Scurtu,Scurtu Mare,Scurtul', 44.3500000, 25.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114789, 'Scurtești', 'Scurtesti', '', 45.2375900, 25.9026400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114790, 'Scurtești', 'Scurtesti', '', 45.1382900, 26.9039700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114791, 'Scurta', 'Scurta', '', 46.2613300, 27.0154800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114792, 'Scundu', 'Scundu', 'Paduretu,Pădureţu,Scundu', 44.8333300, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114793, 'Sculia', 'Sculia', 'Sculia,Skulja,Szigetfalu,Szkulya', 45.4442900, 21.4322500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114794, 'Scrioaştea', 'Scrioastea', 'Scrioastea,Scrioaştea,Scriostea', 44.1500000, 24.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114795, 'Scorţoasa', 'Scortoasa', 'Scortoasa,Scorţoasa', 45.3640300, 26.6611600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114796, 'Scorţeni', 'Scorteni', '', 46.5500000, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114797, 'Scorţeni', 'Scorteni', 'Scorteni,Scorţeni', 45.1000000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114798, 'Scorțaru Vechi', 'Scortaru Vechi', 'Scortaru,Scortaru Vechi,Scortaru Vechiu,Scortarul Vechi,Scorţaru,Scorţaru Vechi,Scorţaru Vechiu,Scorţarul Vechi', 45.2188600, 27.7548900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114799, 'Scorţaru Nou', 'Scortaru Nou', 'Scortaru Nou,Scortarul Nou,Scorţaru Nou,Scorţarul Nou', 45.3166700, 27.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114800, 'Scorniceşti', 'Scornicesti', 'Piscantesti,Piscanteşti,Scornicesti,Scorniceşti', 44.5666700, 24.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114801, 'Scobinţi', 'Scobinti', 'Scobinti,Scobinţi', 47.3833300, 26.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114802, 'Scoarţa', 'Scoarta', 'Scoarta,Scoarţa', 45.0166700, 23.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114803, 'Scânteia', 'Scanteia', 'Scanteia,Scanteia Noua,Scinteia,Scinteia Noua,Scânteia,Scânteia Noua,Scînteia,Scînteia Nouă', 46.9166700, 27.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114804, 'Scânteia', 'Scanteia', 'Brateanu,Bratianu,Brăteanu,Brătianu,Scinteia,Scînteia', 44.7340400, 27.4659300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114805, 'Scânteiești', 'Scanteiesti', 'Scinteiesti,Scînteieşti', 45.6833300, 27.9833300, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114806, 'Schiulești', 'Schiulesti', '', 45.2847100, 25.9540300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114807, 'Schitu-Goleşti', 'Schitu-Golesti', 'Schitu-Golesti,Schitu-Goleşti,Schitul-Golesti,Schitul-Golesu,Schitul-Goleşti,Schitul-Goleşu,Shutu Golestio,Shutu Goleştio', 45.2000000, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114808, 'Schitu Frumoasa', 'Schitu Frumoasa', 'Schitu-Frumoasa,Schitul Frumoasa', 46.6354100, 26.4876100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114809, 'Schitu-Duca', 'Schitu-Duca', 'Schitu-Duca,Schitul-Duca,Situl Duca,Şitul Duca', 47.0333300, 27.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114810, 'Schitu', 'Schitu', 'Schitu,Schitul Greci', 44.3500000, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114811, 'Schitu', 'Schitu', 'Pangalesti,Pingalesti,Pîngăleşti,Păngăleşti', 44.1408300, 25.8366700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114812, 'Schitu', 'Schitu', 'Schitu,Schitul', 43.9427900, 28.6282900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114813, 'Văleni', 'Valeni', 'Schiopeni,Valeni,Văleni,Şchiopeni', 46.5927800, 28.0625000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114814, 'Schela', 'Schela', 'Lascar Catargiu,Lascăr Catargiu,Schela', 45.5000000, 27.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114815, 'Scheiu de Sus', 'Scheiu de Sus', 'Scheiu de Sus,Scheiul de Sus', 44.9560200, 25.1931700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114816, 'Scheiu de Jos', 'Scheiu de Jos', 'Scheiu de Jos,Scheiul de Jos', 44.9346000, 25.1998600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114817, 'Scheia', 'Scheia', '', 47.6500000, 26.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114818, 'Scheia', 'Scheia', '', 47.1172500, 26.8815300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114819, 'Şcheia', 'Scheia', '', 46.9333300, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114820, 'Scărişoara', 'Scarisoara', 'Scarisoar,Scarisoara,Scărişoar,Scărişoara', 46.4666700, 22.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114821, 'Scărişoara', 'Scarisoara', '', 44.0000000, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114822, 'Scăeşti', 'Scaesti', 'Scaesti,Scăeşti', 44.4666700, 23.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114823, 'Săvârşin', 'Savarsin', 'Savarsin,Savirsin,Schoborschin,Soborsin,Săvârșin,Săvîrşin,Vam,Vinesti,Vineşti,Vám', 46.0166700, 22.2333300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114824, 'Săvineşti', 'Savinesti', 'Sevinesti,Sevineşti', 46.8500000, 26.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114825, 'Săveni', 'Saveni', 'Saveni,Savenii,Săveni', 47.9500000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114826, 'Săveni', 'Saveni', '', 44.6000000, 27.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114827, 'Săvădisla', 'Savadisla', 'Saradisla,Savadisla,Sărădisla,Săvădisla', 46.6833300, 23.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114828, 'Şăulia', 'Saulia', 'Saulia,Şăulia', 46.6333300, 24.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114829, 'Săuleşti', 'Saulesti', 'Saulesti,Săuleşti', 44.8000000, 23.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114830, 'Săucești', 'Saucesti', 'Saucesti,Săuceşti', 46.6185300, 26.9414100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114831, 'Săuca', 'Sauca', 'Sauca,Săuca', 47.4666700, 22.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114832, 'Sauca', 'Sauca', '', 46.6526800, 27.6052300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114833, 'Sat-Șugatag', 'Sat-Sugatag', 'Satsugatag,Satu Sugatag,Satu Şugatag', 47.7979600, 23.9063700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114834, 'Satu Nou Calopăr', 'Satu Nou Calopar', '', 44.1666700, 23.7666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114835, 'Satu Nou', 'Satu Nou', '', 47.3214700, 27.0955500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114836, 'Satu Nou', 'Satu Nou', 'Satu Nou,Satul Nou', 46.6960800, 27.7487600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114837, 'Satu Nou', 'Satu Nou', 'Satu Nou,Satul-Nou', 46.3580600, 28.1500000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114838, 'Satu Nou', 'Satu Nou', '', 46.2444700, 26.6534300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114839, 'Satu Nou', 'Satu Nou', 'Satu Nou,Satul-Nou', 44.2691800, 28.2257900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114840, 'Satu Mare', 'Satu Mare', 'Satu Mare,Satu-Mare,Satul-Mare,Сату-Маре', 47.8333300, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114841, 'Satu Mare', 'Satu Mare', 'Gorad Satu-Mareh,SUJ,Sathmar,Satmar,Satmarinum,Satou Mare,Satu Mare,Satu Marė,Satu-Mare,Satul Mare,Szathmar,Szatmar,Szatmar-Nemeti,Szatmarnemeti,Szatmár,Szatmár-Németi,Szatmárnémeti,Sătmar,sa tu ma lei,satumale,satw mary,stw marh,Σάτου Μάρε,Горад Сату-Марэ,Сату Маре,Сату-Маре,סאַטמאַר,סאטו מארה,סאטמאר,סטו מארה,ساتو ماري,ساتو مارے,ستو ماره,サトゥ・マーレ,薩圖馬雷,사투마레', 47.7992600, 22.8625500, 'RO', '2016-02-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114842, 'Satu Mare', 'Satu Mare', 'Marefalva,Márèfalva,Sacul Mare,Satu Mare,Satu-Mare,Satul-Mare,Сату-Маре', 46.3408200, 25.3837800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114843, 'Satu Mare', 'Satu Mare', 'Grossdorf,Nadfal,Nagyfalu,Satu Mare,Satu-Mare,Satul-Mare,Temesnagyfalu,Сату-Маре', 46.0662800, 20.9582600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114844, 'Satulung', 'Satulung', '', 47.5666700, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114845, 'Sătmărel', 'Satmarel', 'Satmarel,Sătmărel', 47.7347000, 22.7953600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114846, 'Săteni', 'Sateni', '', 44.9712900, 25.4168300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114847, 'Satchinez', 'Satchinez', 'Knees,Knes,Knez,Knéz,Satchinez,Temeskenez,Temeskenéz', 45.9375000, 21.0405600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114848, 'Sălcioara', 'Salcioara', '6 Martie', 44.7666700, 28.8833300, 'RO', '2016-01-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114849, 'Sascut-Sat', 'Sascut-Sat', 'Sascut,Sascut-Sat', 46.1872700, 27.0685100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114850, 'Sascut', 'Sascut', 'Sascut,Sascut-Tirg,Sascut-Tîrg,Targu Sascut,Tirgu Sascut,Târgu Sascut,Tîrgu Sascut', 46.2000000, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114851, 'Săsciori', 'Sasciori', 'Sasciori,Săsciori', 45.8666700, 23.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114852, 'Saschiz', 'Saschiz', 'Saschiz,Szaszkezd,Szászkézd', 46.1833300, 24.9666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114853, 'Sasca Montană', 'Sasca Montana', 'Sasca Montana,Sasca Montană,Saska Banja', 44.8854600, 21.7091500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114854, 'Săsar', 'Sasar', '', 47.6440600, 23.4986900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114855, 'Sărulești-Gară', 'Sarulesti-Gara', 'Gara Sarulesti,Gara Săruleşti,Sarulesti,Sarulesti-Gara,Săruleşti,Săruleşti-Gară', 44.4444400, 26.6578000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114856, 'Săruleşti', 'Sarulesti', 'Sarulesti,Săruleşti', 45.5000000, 26.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114857, 'Săruleşti', 'Sarulesti', '', 44.4166700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114858, 'Şaru Dornei', 'Saru Dornei', 'Sar,Saru,Saru Dornei,Sarul Dornei,Şar,Şaru,Şaru Dornei,Şarul Dornei', 47.2833300, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114859, 'Șaroș pe Târnave', 'Saros pe Tarnave', 'Saros,Saros pe Tirnave,Sarosu Sasesc,Sarosul,Saroşu Săsesc,Szaszsaros,Szászsáros,Şaroş,Şaroş pe Tîrnave,Şaroşul', 46.2000000, 24.5500000, 'RO', '2015-12-28', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114860, 'Sarmizegetusa', 'Sarmizegetusa', 'Gradiste,Grădişte,Sarmisegethuza,Sarmisegetuza,Sarmizegetusa,Sarmizegetuza', 45.5166700, 22.7833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114861, 'Sărmaşu', 'Sarmasu', 'Sarmas,Sarmasu,Sarmasu Mare,Sarmasul,Sărmaş,Sărmaşu,Şărmaşu Mare,Şărmaşul', 46.7500000, 24.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114862, 'Şărmăşag', 'Sarmasag', 'Sarmasag,Şărmăşag', 47.3500000, 22.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114863, 'Sărmaş', 'Sarmas', 'Salamas,Salamàs,Salarnas,Salarnás,Sarmas,Sarmasul,Sărmaş,Sărmaşul', 46.8833300, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114864, 'Sarichioi', 'Sarichioi', 'Sarichioi,Sarikioi', 44.9500000, 28.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114865, 'Șard', 'Sard', '', 46.1281400, 23.5352000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114866, 'Saravale', 'Saravale', 'Sarafalva,Sarafola,Saravale,Saravele,Szarafalva,Szaravola,Szaravolla,Szárafalva,Sárafalva', 46.0692900, 20.7408500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114867, 'Sărăuad', 'Sarauad', '', 47.4794400, 22.6255900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114868, 'Sărățeni', 'Sarateni', 'Sarateni,Sovarad,Sòvàrad,Sărăţeni', 46.5624700, 25.0133100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114869, 'Sărățeni', 'Sarateni', '', 44.6342200, 26.9268600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114870, 'Sărata', 'Sarata', '', 46.5024900, 26.8685700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114871, 'Sărata', 'Sarata', '', 43.7743600, 24.0335100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114872, 'Sarasău', 'Sarasau', 'Sarasau,Sărăsău', 47.9551000, 23.8287400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114873, 'Saraiu', 'Saraiu', 'Sarai,Saraiu,Saraiul', 44.7166700, 28.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114874, 'Sarafinești', 'Sarafinesti', '', 47.6170800, 26.6074000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114875, 'Săpunari', 'Sapunari', '', 44.5014100, 26.8366500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114876, 'Săpoca', 'Sapoca', 'Sapoca,Săpoca', 45.2500000, 26.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114877, 'Săpânţa', 'Sapanta', 'Sapanta,Sapinta,Săpânta,Săpînţa', 47.9666700, 23.7000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114878, 'Santău', 'Santau', 'Santau,Santău', 47.5166700, 22.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114879, 'Șanț', 'Sant', 'Rodna Noua,Rodna Nouă,Ujradna,Újradna', 47.4500000, 24.9000000, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114880, 'Sanislău', 'Sanislau', '', 47.6333300, 22.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114881, 'Sănduleşti', 'Sandulesti', 'Sandulesti,Sind,Sănduleşti', 46.5833300, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114882, 'Sănduleni', 'Sanduleni', 'Sanduleni,Sănduleni', 46.4500000, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114883, 'Şandra', 'Sandra', 'Alexanderhausen,Sandorhaza,Sandra,Sándorháza,Şandra', 45.9250000, 20.8902800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114884, 'Şamşud', 'Samsud', 'Samsud,Şamşud', 47.3500000, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114885, 'Samarineşti', 'Samarinesti', 'Samarinesti,Samarineşti', 44.7500000, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114886, 'Salva', 'Salva', 'Salva', 47.3000000, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114887, 'Sălsig', 'Salsig', '', 47.5333300, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114888, 'Salonta', 'Salonta', 'Nagyszalonta,Opstina Salonta,Opština Salonta,Salonta,sa long ta,sallonta,saronta,slwnth,Салонта,سلونته,サロンタ,薩隆塔,살론타', 46.8000000, 21.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114889, 'Săliştea de Sus', 'Salistea de Sus', 'Felsoszelistye,Felsőszelistye,Saliste-de-Sus,Salistea de Sus,Sălişte-de-Sus,Săliştea de Sus', 47.6500000, 24.3500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114890, 'Săliştea-Deal', 'Salistea-Deal', '', 45.9000000, 23.4000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114891, 'Săliștea', 'Salistea', 'Cioara,Cioara-Deal,Salistea,Săliştea', 45.9074400, 23.3978900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114892, 'Sălişte', 'Saliste', 'Szelistye', 45.7963300, 23.8867700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114893, 'Saligny', 'Saligny', 'Azigia,Saligny', 44.2811100, 28.0909200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114894, 'Sălcuța', 'Salcuta', 'Cornetu,Salcuta,Sălcuţa', 44.6437400, 25.5810300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114895, 'Sălcuţa', 'Salcuta', '', 44.2500000, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114896, 'Sălcuța', 'Salcuta', '', 44.1598600, 23.7024700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114897, 'Sălciua de Sus', 'Salciua de Sus', '', 46.4000000, 23.4166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114898, 'Sălcioara', 'Salcioara', '', 45.3087400, 27.1769200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114899, 'Sălcioara', 'Salcioara', 'Besteloaia,Beşteloaia,Salcioara,Sălcioara', 44.7166700, 25.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114900, 'Sălcioara', 'Salcioara', '', 44.5333300, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114901, 'Sălciile', 'Salciile', 'Salciile,Sălciile', 44.8166700, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114902, 'Salcia Tudor', 'Salcia Tudor', 'Domnita Ileana,Domniţa Ileana,Salcia Tudor,Tudor Vladimirescu', 45.3666700, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114903, 'Salcia', 'Salcia', 'Salcia', 45.1833300, 26.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114904, 'Salcia', 'Salcia', '', 44.4819500, 23.4464500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114905, 'Salcia', 'Salcia', '', 44.1408300, 22.9277800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114906, 'Salcia', 'Salcia', '', 43.9500000, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114907, 'Salcea', 'Salcea', 'Salcea', 47.6500000, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114908, 'Sălătrucu', 'Salatrucu', 'Salatrucu,Salatrucu de Sus,Salatrucul-de-Sus,Sălătrucu,Sălătrucu de Sus,Sălătrucul-de-Sus', 45.3333300, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114909, 'Sălătrucel', 'Salatrucel', 'Salatruc,Salatrucel,Salatrucelu,Sălătruc,Sălătrucel,Sălătrucelu', 45.2500000, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114910, 'Sălăţig', 'Salatig', 'Salatig,Sălăţig', 47.3666700, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114911, 'Sălaşu de Sus', 'Salasu de Sus', 'Salasu Superior,Salasu de Sus,Salasul-Superior,Salasul-de-Sus,Sălaşu Superior,Sălaşu de Sus,Sălaşul-Superior,Sălaşul-de-Sus', 45.5166700, 22.9500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114912, 'Sălard', 'Salard', 'Salard,Sălard', 47.2166700, 22.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114913, 'Sălacea', 'Salacea', 'Salacea,Sălacea', 47.4666700, 22.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114914, 'Săhăteni', 'Sahateni', 'Sahateni,Sahateni-de-Jos,Sahatenii de Jos,Satucul,Satueul,Săhăteni,Săhăteni-de-Jos,Săhătenii de Jos', 45.0333300, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114915, 'Şagu', 'Sagu', 'Dreispitz,Nemetsag,Németság,Saagh,Sag,Sagu,Sagul,Segentau,Segenthau,Ság,Şagu,Şagul', 46.0500000, 21.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114916, 'Sagna', 'Sagna', 'La Duliba,Sagna', 46.9833300, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114917, 'Săgeata', 'Sageata', 'Sageata,Sageata de Sus,Sageta de Jos,Săgeata,Săgeata de Sus,Săgeta de Jos', 45.1000000, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114918, 'Şag', 'Sag', 'Saag,Sag,Sagh,Saág,Schag,Ság,Ságh,Temessag,Temesság,Şag', 45.6486100, 21.1755600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114919, 'Șaeș', 'Saes', 'Saes,Şaeş', 46.1563800, 24.7689400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114920, 'Saelele', 'Saelele', 'Saele,Saelele', 43.8557700, 24.7278900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114921, 'Sadu', 'Sadu', 'Cod,Cód,Sadu,Sadul', 45.6666700, 24.1833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114922, 'Sadova', 'Sadova', '', 47.5333300, 25.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114923, 'Sadova', 'Sadova', 'Sadova', 43.9000000, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114924, 'Sadina', 'Sadina', '', 44.4114300, 25.5295300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114925, 'Săcuieu', 'Sacuieu', 'Sacueu,Sacuieu,Săcueu,Săcuieu', 46.8233500, 22.8882400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114926, 'Săcueni', 'Sacueni', 'Sacuieni,Secueni,Szekelyhid,Székelyhíd', 47.3500000, 22.1000000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114927, 'Săcueni', 'Sacueni', '', 44.9107700, 25.5722300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114928, 'Sacu', 'Sacu', 'Sacu,Sacul', 45.5666700, 22.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114929, 'Sacoşu Turcesc', 'Sacosu Turcesc', 'Sacosu Turcesc,Sacosu-Mare,Sacosul Turcesu,Sacosul-Mare,Sacosul-Turcesc,Sacoşu Turcesc,Sacoşu-Mare,Sacoşul Turcesu,Sacoşul-Mare,Sacoşul-Turcesc,Sacoșu Turcesc,Toeroekszakos,Torokszakos,Törökszákos', 45.6519400, 21.4288900, 'RO', '2015-04-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114930, 'Sacoșu Mare', 'Sacosu Mare', 'Gross-Sakosch,Magyarszakos,Magyarszákos,Sacos,Sacosu Mare,Sacosul Mare,Sacoş,Sacoşu Mare,Sacoşul Mare,Sakosch', 45.5850300, 21.7295800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114931, 'Săceni', 'Saceni', 'Saceni,Săceni', 44.2333300, 25.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114932, 'Săcelu', 'Sacelu', 'Sacelu,Săcelu', 45.1000000, 23.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114933, 'Săcele', 'Sacele', 'Hetfalu,Negyfalu,Négyfalu,Opstina Sacele,Opština Sãcele,Sechele,Sehchele,Sieben Dorfer,Sieben Dörfer,sachlh,se qie lai,Сечеле,Сэчеле,ساچله,سکیلے,瑟切萊', 45.6167400, 25.7110100, 'RO', '2013-02-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114934, 'Săcele', 'Sacele', 'Peletlia,Pelitlia,Sacele,Sehchele,Săcele,Сэчеле', 44.4833300, 28.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114935, 'Săcel', 'Sacel', 'Izaszacsal,Sacel,Sacelu,Sicsel,Szacsal,Săcelu,sytsl,סיטשל', 47.6333300, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114936, 'Săcel', 'Sacel', 'Izaszacsal,Sacel,Săcel', 46.3000000, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114937, 'Săcăşeni', 'Sacaseni', 'Sacaseni,Socaciu,Săcăşeni', 47.4833300, 22.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114938, 'Săcălaz', 'Sacalaz', 'Sacalaz,Sackelhaus,Sackelhausen,Szakalhaza,Szakálháza,Săcălaz', 45.7583300, 21.1122200, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114939, 'Săcălășeni', 'Sacalaseni', '', 47.5818000, 23.5643200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114940, 'Săcădat', 'Sacadat', 'Sacadad,Sacadat,Săcădad,Săcădat', 47.0333300, 22.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114941, 'Sabasa', 'Sabasa', '', 47.2017400, 25.8176000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114942, 'Săbăreni', 'Sabareni', 'Sabareni,Săbăreni', 44.5018500, 25.8882000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114943, 'Săbăoani', 'Sabaoani', 'Sabaoani,Sabaoani-Lecuseni,Sabaoani-Leuseni,Săbăoani,Săbăoani-Lecuşeni,Săbăoani-Leuşeni', 47.0166700, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114944, 'Ruşii Munţi', 'Rusii Munti', 'Marosoroszfalu,Marosoroszfalù,Rusii Munti,Ruşii Munţi', 46.9166700, 24.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114945, 'Ruşeţu', 'Rusetu', 'Rusetu,Rusetul,Ruşeţu,Ruşeţul', 44.9500000, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114946, 'Ruseni', 'Ruseni', '', 46.7984100, 26.5394300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114947, 'Ruscova', 'Ruscova', '', 47.7928900, 24.2854600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114948, 'Rusca Montană', 'Rusca Montana', 'Rusca Montana,Rusca Montană', 45.5674100, 22.4581600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114949, 'Rusca', 'Rusca', '', 45.1451700, 22.3385900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114950, 'Rusăneşti', 'Rusanesti', 'Rusanesti,Rusanestii de Jos,Rusăneşti,Rusăneştii de Jos', 43.9333300, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114951, 'Rus', 'Rus', 'Oroszinezo,Oroszinezö,Oroszmezo,Rus', 47.2833300, 23.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114952, 'Rupea', 'Rupea', 'Cohalm,Kohalom,Kőhalom,Rupea,Rupja,Рупя', 46.0333300, 25.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114953, 'Runcu Salvei', 'Runcu Salvei', 'Runcu Salvei,Runcul Salvei', 47.3438200, 24.3252900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114954, 'Runcu', 'Runcu', 'Runcu,Runcul', 45.1833300, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114955, 'Runcu', 'Runcu', 'Runcu,Runcul', 45.1666700, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114956, 'Runcu', 'Runcu', 'Runcu,Runcur', 45.1166700, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114957, 'Ruja', 'Ruja', '', 46.0117500, 24.6504800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114958, 'Ruginoasa', 'Ruginoasa', '', 47.2500000, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114959, 'Ruginoasa', 'Ruginoasa', '', 46.9862200, 26.7063500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114960, 'Rugineşti', 'Ruginesti', 'Ruginesti,Ruginestii,Rugineşti,Rugineştii', 46.0666700, 27.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114961, 'Rugășești', 'Rugasesti', '', 47.2314700, 23.8732600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114962, 'Rudeni', 'Rudeni', '', 44.4724200, 25.9732500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114963, 'Rucăreni', 'Rucareni', 'Rucarena,Rucareni,Rucărena,Rucăreni', 45.9943800, 26.6549600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114964, 'Rucăr', 'Rucar', '', 45.4000000, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114965, 'Rubla', 'Rubla', 'Rubla,Rubla Mare', 45.3530000, 27.0752500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114966, 'Roznov', 'Roznov', 'Rasnov,Roznov', 46.8333300, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114967, 'Rozavlea', 'Rozavlea', 'Rozavlea', 47.7333300, 24.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114968, 'Pecica', 'Pecica', 'Magyarpecska,Magyarpécska,Opecska,Pecica,Pecica Ungureasca,Pecica Ungurească,Pecica Veche,Petschka,Rovine,Ópécska', 46.1666700, 21.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114969, 'Rovine', 'Rovine', '', 44.6954000, 27.0936400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114970, 'Rovinari', 'Rovinari', 'Rovinari', 44.9166700, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114971, 'Rotunda', 'Rotunda', '', 47.4874500, 26.5246600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114972, 'Rotunda', 'Rotunda', '', 47.0221000, 26.9626600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114973, 'Rotunda', 'Rotunda', 'Ratunda,Rotunda,Rătunda', 43.9833300, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114974, 'Roșu', 'Rosu', 'Rosu,Rosul,Roşu,Roşul', 44.4502500, 26.0112200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114975, 'Roșiorii de Vede', 'Rosiorii de Vede', 'Rosiori de Vede,Roşiori de Vede', 44.1166700, 24.9833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114976, 'Roșiori', 'Rosiori', '', 47.7609500, 26.7216700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114977, 'Roșiori', 'Rosiori', '', 47.2567700, 21.9520900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114978, 'Roşiori', 'Rosiori', '', 46.7166700, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114979, 'Roşiori', 'Rosiori', '', 44.8000000, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114980, 'Roșiori', 'Rosiori', '', 44.6126500, 26.5349600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114981, 'Roșiori', 'Rosiori', '', 44.2563300, 22.9283800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114982, 'Roşiile', 'Rosiile', 'Rosiile,Roşiile', 44.8666700, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114983, 'Roşieşti', 'Rosiesti', 'Rosiesti,Roşieşti', 46.4333300, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114984, 'Roșia Montană', 'Rosia Montana', 'Comuna Rosia Montana,Comuna Roșia Montană,Opstina Rosia Montana,Opština Roşia Montană,Roshija-Montane,Roshja Montana,Rosia Montana,Roşia Montană,Verespatak,rwshya mwntana,Рошія-Монтане,Рошја Монтана,روشيا مونتانا', 46.3066900, 23.1337300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114985, 'Roşia de Secaş', 'Rosia de Secas', 'Rosia de Secas,Roşia de Secaş', 46.0500000, 23.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114986, 'Roşia de Amaradia', 'Rosia de Amaradia', 'Rosia de Amaradia,Rosia de Amaradia-de-Sus,Rosia de Sus,Roşia de Amaradia,Roşia de Amaradia-de-Sus,Roşia de Sus', 45.0500000, 23.7500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114987, 'Roşia', 'Rosia', 'Rosia,Roşia', 46.8000000, 22.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114988, 'Roşia', 'Rosia', 'Rosia,Rosia Saseasca,Roşia,Roşia Săsească', 45.8166700, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114989, 'Roseţi', 'Roseti', 'Roset,Roseti,Rosetti,Roseţ,Roseţi', 44.2148200, 27.4484800, 'RO', '2012-06-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114990, 'Roșcani', 'Roscani', '', 47.5334600, 26.5490900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114991, 'Roșcani', 'Roscani', '', 47.4558100, 27.4002100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114992, 'Rona de Sus', 'Rona de Sus', 'Rona de Sus', 47.9000000, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114993, 'Rona de Jos', 'Rona de Jos', 'Rona de Jos', 47.9166700, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114994, 'Romuli', 'Romuli', 'Romuli', 47.5333300, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114995, 'Romos', 'Romos', 'Romos', 45.8333300, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114996, 'Români', 'Romani', 'Romani,Romini,Români,Romîni', 46.7833300, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114997, 'Româneşti', 'Romanesti', 'Romanesti,Rominesti,Româneşti,Romîneşti,Rumanesti,Rumăneşti', 47.2833300, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114998, 'Românești', 'Romanesti', 'Rominesti,Romîneşti,Rumanesti,Rumăneşti', 44.8666700, 26.0666700, 'RO', '2015-11-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(114999, 'Românești', 'Romanesti', 'Rominesti,Romîneşti,Rumanesti,Rumăneşti', 44.5666700, 25.6166700, 'RO', '2015-11-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115000, 'Românaşi', 'Romanasi', '', 47.1000000, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115001, 'Romanu', 'Romanu', 'Romanu,Romanul', 45.2833300, 27.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115002, 'Români', 'Romani', 'Babeni-Bistrita,Băbeni-Bistriţa,Romani,Romini,Români,Romîni', 44.9731000, 24.2051300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115003, 'Românești', 'Romanesti', 'Ostopceni Razesti,Ostopceni Răzesti,Ostopceni-Bals,Ostopceni-Balş,Ostopceni-Razesi,Ostopceni-Rominesti,Ostopceni-Romîneşti,Ostopceni-Răzeşi,Ostopcenii-Bals,Ostopcenii-Balş,Romanesti,Rominesti,Româneşti,Romîneşti,Rumanesti,Rumăneşti', 47.7314100, 27.2402700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115004, 'Roman', 'Roman', 'Roman,Roman i Romania,Romanas,Romanvasar,Románvásár,loman,luo man,rwman,Ρόμαν,Роман,ראמאן,רומאן,رومان,羅曼,로만', 46.9211900, 26.9264600, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115005, 'Roma', 'Roma', '', 47.8333300, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115006, 'Rojiște', 'Rojiste', '', 44.0668300, 23.9389800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115007, 'Rogoz', 'Rogoz', '', 47.4674900, 23.9321400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115008, 'Rogova', 'Rogova', 'Rogova', 44.4716700, 22.8066700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115009, 'Roeşti', 'Roesti', '', 44.9166700, 24.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115010, 'Rodna', 'Rodna', 'Rodna,Rodna-Veche', 47.4166700, 24.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115011, 'Rociu', 'Rociu', 'Rociu,Rociul,Rosiul', 44.6666700, 25.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115012, 'Robeasca', 'Robeasca', 'Puturosal,Robeasca', 45.1666700, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115013, 'Roata de Jos', 'Roata de Jos', 'Roata de Jos', 44.4108300, 25.5433300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115014, 'Râu Sadului', 'Rau Sadului', 'Raul Sadului,Riu Sadului,Riuszad,Riuszád,Râul Sadului,Rîu Sadului', 45.6166700, 24.0666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115015, 'Râu de Mori', 'Rau de Mori', 'Rau-de-Mori,Raul-de-Mori,Riu de Mori,Râu-de-Mori,Râul-de-Mori,Rîu de Mori', 45.4833300, 22.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115016, 'Râu Alb de Jos', 'Rau Alb de Jos', '', 45.1365300, 25.3474500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115017, 'Râşnov', 'Rasnov', 'Barcarozsnyo,Barcarozsnyó,R"shnov,Rasnov,Risnov,Rosenau,Ryshnov,Râşnov,Râșnov,Rîşnov,Ръшнов,Рышнов', 45.5833300, 25.4500000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115018, 'Râșești', 'Rasesti', 'Rasesti,Risesti,Râseşti,Rîşeşti', 46.7721900, 28.1427300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115019, 'Râşca', 'Rasca', 'Peste Vale,Rasca,Risca,Risca peste Vale,Râşca,Rîşca,Rîşca peste Vale', 47.3666700, 26.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115020, 'Râșca', 'Rasca', 'Roska', 46.7396700, 23.1062500, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115021, 'Ripiceni', 'Ripiceni', 'Ripiceni,Ripiceni-Fabrica,Ripiceni-Fabrică', 47.9500000, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115022, 'Rânzești', 'Ranzesti', 'Banzestii,Banzeştii,Ranzasti,Ranzesti,Ranzăşti,Rinzesti,Rânzeşti,Rînzeşti', 46.2210100, 28.0946800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115023, 'Râncăciov', 'Rancaciov', 'Rancaciov,Rancaciovu,Rancaciovul,Rincaciov,Râncăciov,Râncăciovu,Râncăciovul,Rîncăciov', 44.8887200, 25.3577800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115024, 'Râmnicu Vâlcea', 'Ramnicu Valcea', 'Ramnicu Valcea,Ramnicul Valcea,Ramniku Valcha,Rimnicu Vilcea,Rimnikou Viltsea,Rimniku Vilca,Rimniku Vilča,Rimniku-Vilcha,Rumniku Vulcha,Rymniku-Vylcha,Râmnicu Vâlcea,Râmnicul Vâlcea,Rîmnicu Vîlcea,lei mu ni ku wo er qia,leumnikubeulchea,rmnykw wlcha,rmnyqw wlzh,rmynkw fyltsha,rymnkw wylcha,rymnykw wylcha,Ρίμνικου Βίλτσεα,Рамнику Валча,Римнику-Вилча,Римніку-Вилча,Ръмнику Вълча,Рымнику-Вылча,רמניקו ולצה,رمنیکو ولچا,رمينكو فيلتشا,ریمنکو ویلچا,ریمنیکو ویلچا,რიმნიკუ-ვილჩა,ルムニク・ヴルチャ,勒姆尼庫沃爾恰,름니쿠블체아', 45.1000000, 24.3666700, 'RO', '2012-12-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115025, 'Râmnicu Sărat', 'Ramnicu Sarat', 'Opstina Ramnicu Sarat,Opština Râmnicu Sãrat,Ramnicu Sarat,Ramnicul Sarat,Ramniku Sarat,Rimnic,Rimnicu Sarat,Rimnik,Rimniku-Sehrat,Rumniku Surat,Rymnik,Rymniku-Sehrat,Râmnicu Sarat,Râmnicu Sărat,Râmnicul Sărat,Rîmnic,Rîmnicu Sărat,rmnykw srh,Рамнику Сарат,Римник,Римнику-Сэрат,Ръмнику Сърат,Рымнику-Сэрат,רמניקו סראט,رمنیکو سره,ルムニク・サラト', 45.3833300, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115026, 'Râmniceni', 'Ramniceni', 'Ramniceni,Ramniceni-Bratlanu,Rimniceni,Râmniceni,Râmniceni-Brătlanu,Rîmniceni', 45.5132200, 27.4484300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115027, 'Râmnicelu', 'Ramnicelu', 'Obiditi,Obidiţi,Rimnicelu,Rîmnicelu', 45.3638100, 27.1112100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115028, 'Râmnicelu', 'Ramnicelu', 'Ramnicelu,Ramnicelul,Rimnicelu,Râmnicelu,Râmnicelul,Rîmnicelu', 45.2833300, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115029, 'Rimetea', 'Rimetea', 'Rimetea,Torocko,Torockó', 46.4500000, 23.5666700, 'RO', '2014-06-06', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115030, 'Râmești', 'Ramesti', 'Rimesti,Rîmești', 44.5666700, 24.1000000, 'RO', '2016-01-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115031, 'Râfov', 'Rafov', 'Rafovul,Rifov,Râfovul,Rîfov', 44.8666700, 26.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115032, 'Rieni', 'Rieni', 'Reny,Rieni,Rieny,Rény', 46.5748500, 22.4458400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115033, 'Râciu', 'Raciu', 'Mezorucs,Mezörücs,Raciu,Raciul,Riciu,Râciu,Râciul,Rîciu', 46.6833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115034, 'Râca', 'Raca', 'Raca,Raca-Veche,Rica,Rica Veche,Râca,Râca-Veche,Rîca,Rîca Veche', 44.4342600, 25.0433300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115035, 'Ribiţa', 'Ribita', 'Ribita,Ribiţa', 46.1833300, 22.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115036, 'Reviga', 'Reviga', 'Reviga', 44.7166700, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115037, 'Retevoiești', 'Retevoiesti', '', 45.1401600, 24.8379700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115038, 'Reteag', 'Reteag', '', 47.1958200, 24.0186200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115039, 'Reşiţa', 'Resita', 'QRS,Recita,Reciţa,Reschitz,Reschitza,Resicabanya,Resicabánya,Resicza,Resiczabanya,Resiczabánya,Resita,Reşiţa,Reșița', 45.3008300, 21.8891700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115040, 'Repedea', 'Repedea', 'Ordszko,Repedea', 47.8333300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115041, 'Remuș', 'Remus', 'Remus,Remuş,Vasile Epurescu', 43.9429500, 25.9803900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115042, 'Remeţi', 'Remeti', '', 47.9833300, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115043, 'Remetea Mare', 'Remetea Mare', 'Remete,Remetea Mare,Remetea Timisana,Remetea Timişană,Temesremete', 45.7794400, 21.3761100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115044, 'Remetea Chioarului', 'Remetea Chioarului', 'Remetea Chioarulu,Remetea Chioarului,Remeţea Chioarulu', 47.5333300, 23.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115045, 'Remetea', 'Remetea', 'Gyergyoremete,Gyergyóremete,Remete,Remetea', 46.7833300, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115046, 'Remetea', 'Remetea', '', 46.7333300, 22.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115047, 'Remetea', 'Remetea', 'Besa,Bese,Beşa', 46.5743200, 24.5135900, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115048, 'Reghiu', 'Reghiu', 'Reghiu', 45.7833300, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115049, 'Reghin-Sat', 'Reghin-Sat', '', 46.7833300, 24.7166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115050, 'Reghin', 'Reghin', 'Opstina Reghin,Opština Reghin,Regen,Reghin,Reghinul,Reghinul Sashsisch,Reghinul Săshsisch,Regin,Régen,Sachs Reen,Sachsisch Regen,Saechsisch-Regen,Szasz Regen,Szasz Régen,Szaszregen,Szászrégen,Sächs Reen,Sächsisch-Regen,lei jing,regin,rgyn,Регин,Регін,رگین,レギン,雷京', 46.7742000, 24.7021600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115051, 'Rediu', 'Rediu', 'Radiu,Rediu,Rădiu', 46.6337400, 27.6943900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115052, 'Rediu', 'Rediu', '', 48.2307500, 26.7784100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115053, 'Rediu', 'Rediu', '', 47.2403300, 26.8640600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115054, 'Rediu', 'Rediu', 'Capu Rediului,Copou Rediului,Rediu,Rediu-Tatar,Rediu-Tătar,Rediu-lui-Tatar,Rediu-lui-Tătar,Rediul lui Tatar,Rediul lui Tătar', 47.2166700, 27.5000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115055, 'Rediu', 'Rediu', 'Rediu,Rediul', 46.7559800, 26.5625400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115056, 'Rediu', 'Rediu', 'Oasele,Rediu', 45.7166700, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115057, 'Redea', 'Redea', 'Redea', 44.0500000, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115058, 'Reci', 'Reci', 'Rety,Rèty', 45.8500000, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115059, 'Recea Cristur', 'Recea Cristur', '', 47.0666700, 23.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115060, 'Recea', 'Recea', '', 47.6333300, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115061, 'Recea', 'Recea', 'Telechi Rece,Telechi-Recea,Telechi-Reci,Vaida-Recea', 45.7133400, 24.9315200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115062, 'Recea', 'Recea', 'Recea,Recea de Sus', 44.5333300, 25.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115063, 'Recea', 'Recea', '', 44.3194900, 22.9165900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115064, 'Recaş', 'Recas', 'Armag,Recas,Recaş,Rekas,Rekasch,Rékas,Temesrekas,Temesrékas', 45.7988900, 21.5008300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115065, 'Rebrişoara', 'Rebrisoara', 'Rebrisoara,Rebrişoara', 47.2833300, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115066, 'Rebricea', 'Rebricea', 'Gura Vaii,Gura Văii,Rebricea', 46.8666700, 27.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115067, 'Rebra', 'Rebra', 'Rebra', 47.3166700, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115068, 'Răzvani', 'Razvani', 'Rasvan,Rasvani,Rasvanu,Razvan,Razvani,Răsvan,Răsvani,Răsvanu,Răzvan,Răzvani', 44.4211400, 26.8809200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115069, 'Răzvad', 'Razvad', 'Rasvadu-de-Jos,Rasvadul de Jos,Razvad,Razvadu de Jos,Răsvadu-de-Jos,Răsvadul de Jos,Răzvad,Răzvadu de Jos', 44.9333300, 25.5333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115070, 'Războienii de Jos', 'Razboienii de Jos', 'Uscati,Uscaţi', 47.0688700, 26.5637400, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115071, 'Războieni-Cetate', 'Razboieni-Cetate', 'Feldioara,Rasboeni,Rasboeni-Cetate,Rasboieni-Cetate,Razboeni-Cetate,Razboieni-Cetate,Răsboeni-Cetate,Răsboieni-Cetate,Războeni-Cetate,Războieni-Cetate', 46.4133500, 23.8715800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115072, 'Războieni', 'Razboieni', 'Razboeni,Razboeni-Noui,Războeni,Războeni-Noui', 47.2175400, 27.0503900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115073, 'Răuseni', 'Rauseni', '', 47.5666700, 27.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115074, 'Răuceşti', 'Raucesti', 'Raucesti,Răuceşti', 47.2500000, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115075, 'Răteşti', 'Ratesti', '', 44.7333300, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115076, 'Răsuceni', 'Rasuceni', 'Rasuceni,Rasuceni-de-Sus,Rasucenii de Sus,Răsuceni,Răsuceni-de-Sus,Răsucenii de Sus', 44.0916700, 25.6638900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115077, 'Rast', 'Rast', '', 43.8833300, 23.2833300, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115078, 'Răstoliţa', 'Rastolita', 'Ratosnya', 46.9725800, 24.9928700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115079, 'Răstoaca', 'Rastoaca', 'Rastoaca,Răstoaca', 45.6608300, 27.2872300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115080, 'Rasova', 'Rasova', 'Rasova', 44.2500000, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115081, 'Răsmireşti', 'Rasmiresti', 'Rasmiresti,Răsmireşti', 43.9833300, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115082, 'Răşinari', 'Rasinari', 'Rasinari,Resinar,Resinár,Răşinari', 45.7000000, 24.0666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115083, 'Rași', 'Rasi', '', 44.5353400, 26.9248500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115084, 'Răscruci', 'Rascruci', 'Rascruci,Răscruci,Valaszut,Válaszút', 46.9056900, 23.7686000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115085, 'Răscăeți', 'Rascaeti', '', 44.5922100, 25.2699000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115086, 'Rasa', 'Rasa', '', 44.2140400, 27.1471700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115087, 'Rapoltu Mare', 'Rapoltu Mare', 'Rapoldul-Mare,Rapoltu Mare,Rapoltul-Mare', 45.8666700, 23.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115088, 'Răpănaşu', 'Rapanasu', '', 47.3833300, 24.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115089, 'Ramna', 'Ramna', 'Raffna,Rafna,Ramna,Rustica Villa', 45.4383300, 21.6883300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115090, 'Rafaila', 'Rafaila', 'Rafaila,Schitu-Rafauila', 46.8006400, 27.3623600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115091, 'Radu Vodă', 'Radu Voda', 'Radu Voda,Radu Vodă,Rodu Voda,Rodu Vodă', 44.3856300, 26.9254100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115092, 'Răducăneni', 'Raducaneni', 'Raducaneni,Răducăneni', 46.9500000, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115093, 'Radovanu', 'Radovanu', 'Radovanu,Radovanul', 44.2000000, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115094, 'Radovan', 'Radovan', '', 44.1666700, 23.6166700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115095, 'Radomir', 'Radomir', 'Radomiru,Radomirul', 44.1211500, 24.1683200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115096, 'Radomireşti', 'Radomiresti', 'Fripti,Fripţi,Radomiresti,Radomireşti', 44.1166700, 24.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115097, 'Rădoiești-Deal', 'Radoiesti-Deal', '', 44.1500000, 25.1333300, 'RO', '2016-01-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115098, 'Radna', 'Radna', 'Radna,Rodna', 46.0944400, 21.6873200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115099, 'Rădeşti', 'Radesti', 'Radesti,Rădeşti', 46.2666700, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115100, 'Rădești', 'Radesti', '', 46.0726300, 27.7893600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115101, 'Rădești', 'Radesti', 'Radesti,Radestii,Rădeşti', 45.0718400, 25.0020700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115102, 'Rădeni', 'Radeni', '', 47.5118600, 26.8924900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115103, 'Rădeni', 'Radeni', '', 47.1426000, 26.5370300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115104, 'Rădăuți-Prut', 'Radauti-Prut', '', 48.2333300, 26.8000000, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115105, 'Rădăuți', 'Radauti', 'Opstina Radauti,Opština Rãdãuţi,Radauci,Radauti,Radautio,Radautz,Radivci,Radoc,Radowce,Radóc,Rantaoutsi,Rehdehuci,Rehdehutsi,Ruduuc,Rădăutio,Rădăuţi,Rădăuți,lei de wu qi,radautsu~i,rdwts,Ρανταούτσι,Радауци,Радівці,Ръдъуц,Рэдэутси,Рэдэуци,ראדעוויץ,רדאוץ,ردوتس,ラダウツィ,勒德烏齊', 47.8500000, 25.9166700, 'RO', '2015-12-30', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115106, 'Rădăşeni', 'Radaseni', 'Iazu,Radaseni,Rădăşeni,Valea Visinului,Valea Vişinului', 47.4666700, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115107, 'Racu', 'Racu', 'Csikrakos,Csikrákos,Racu,Racul', 46.4517800, 25.7606000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115108, 'Racşa', 'Racsa', '', 47.8206800, 23.3324700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115109, 'Racoviţeni', 'Racoviteni', 'Nisipenii,Racoviteni,Racoviţeni', 45.3666700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115110, 'Racoviţa', 'Racovita', 'Racovita,Racoviţa,Rakovica,Rakovicza', 45.6983300, 21.6358300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115111, 'Racoviţa', 'Racovita', 'Racovita,Racoviţa', 45.6833300, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115112, 'Racoviţa', 'Racovita', '', 45.4166700, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115113, 'Racoviţa', 'Racovita', 'Racovita,Racoviţa,Suligata', 45.3000000, 27.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115114, 'Racovița', 'Racovita', '', 44.9708100, 24.9758200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115115, 'Racovița', 'Racovita', '', 44.8392700, 25.6208200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115116, 'Racova', 'Racova', 'Racova', 46.7000000, 26.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115117, 'Răcoasa', 'Racoasa', 'Racoasa,Răcoasa', 46.0000000, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115118, 'Raciu', 'Raciu', 'Raciu,Raciul', 44.8179100, 25.4410600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115119, 'Gârlenii de Sus', 'Garlenii de Sus', 'Racila,Racsila,Rácsila', 46.6541400, 26.7949100, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115120, 'Răchitova', 'Rachitova', 'Rachitova,Rechitova,Răchitova', 45.6000000, 22.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115121, 'Răchitoasa', 'Rachitoasa', 'Rachitoasa,Răchitoasa', 46.4333300, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115122, 'Răchiţi', 'Rachiti', 'Rachiti,Rachiti-Topauti,Răchiţi,Răchiţi-Topăuţi', 47.7666700, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115123, 'Răchiteni', 'Rachiteni', 'Rachiteni,Răchiţeni', 47.0534700, 26.9173000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115124, 'Răchita', 'Rachita', '', 45.8382700, 22.1061500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115125, 'Rachieri', 'Rachieri', '', 44.9543800, 26.1284100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115126, 'Rachelu', 'Rachelu', 'Rachel,Rachelu', 45.2866700, 28.3234900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115127, 'Răcăuți', 'Racauti', 'Racauti,Racautul,Răcăuţi,Răcăuţul', 46.2247600, 26.7872300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115128, 'Răcăşdia', 'Racasdia', 'Racasdia,Rakazdija,Rakaždija,Răcăşdia', 44.9930600, 21.6180600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115129, 'Răcarii de Sus', 'Racarii de Sus', '', 44.5353900, 23.5574600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115130, 'Răcari', 'Racari', 'Racari,Răcari', 44.6333300, 25.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115131, 'Răcăciuni', 'Racaciuni', '', 46.3333300, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115132, 'Răbăgani', 'Rabagani', 'Rabagani,Răbăgani', 46.7500000, 22.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115133, 'Puțuri', 'Puturi', 'Puturi,Puturile,Puţuri,Puţurile', 44.1383500, 24.0101700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115134, 'Putna', 'Putna', 'Putna', 47.8666700, 25.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115135, 'Putineiu', 'Putineiu', 'Putineiu,Putineiul,Putineu', 43.9000000, 25.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115136, 'Putineiu', 'Putineiu', 'Putineiu,Putineiul', 43.9000000, 24.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115137, 'Pustiana', 'Pustiana', '', 46.5899000, 26.6308300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115138, 'Pusta', 'Pusta', '', 47.2459600, 22.7237400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115139, 'Pușcași', 'Puscasi', 'Puscasi,Puşcaşi', 46.6215400, 27.6450300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115140, 'Purcăreni', 'Purcareni', '', 45.6447600, 25.7912900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115141, 'Purcăreni', 'Purcareni', '', 44.9684700, 24.8873600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115142, 'Stănești', 'Stanesti', '', 44.8166700, 24.0500000, 'RO', '2016-01-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115143, 'Purani', 'Purani', 'Purani,Puranii de Jos', 44.3612500, 25.4252800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115144, 'Purani', 'Purani', '', 43.9798900, 25.4365600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115145, 'Punghina', 'Punghina', 'Punghina', 44.2819400, 22.9347200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115146, 'Pungeşti', 'Pungesti', 'Pungesti,Pungesti-Tirg,Pungeşti,Pungeşti-Tîrg', 46.7000000, 27.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115147, 'Puieşti', 'Puiesti', 'Puesti,Puesti-Tirg,Puestii Targ,Pueşti,Pueşti-Tîrg,Pueştii Targ,Puiesti,Puieşti', 46.4166700, 27.5000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115148, 'Pui', 'Pui', 'Pui', 45.5166700, 23.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115149, 'Pufeşti', 'Pufesti', 'Pufesti,Pufestii,Pufeşti,Pufeştii', 46.0000000, 27.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115150, 'Puieștii de Jos', 'Puiestii de Jos', 'Poestii-de-Jos,Poeştii-de-Jos,Puesti-de-Jos,Puestii de Jos,Pueşti-de-Jos,Pueştii de Jos', 45.4026700, 27.2201300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115151, 'Puieni', 'Puieni', 'Pueni,Puieni', 44.0767500, 26.1911400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115152, 'Pucioasa', 'Pucioasa', 'Pucioasa', 45.0780700, 25.4323200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115153, 'Puchenii Moșneni', 'Puchenii Mosneni', 'Mosneni,Moşneni,Puchenii-Mosneni,Puchenii-Moşneni', 44.8121300, 26.0870100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115154, 'Puchenii Mari', 'Puchenii Mari', 'Pucheni,Puchenii Mari,Puchenii-Crainici', 44.8166700, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115155, 'Pucheni', 'Pucheni', 'Pucheni', 45.1833300, 25.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115156, 'Prunişor', 'Prunisor', 'Prunisor,Prunisori,Prunisoru,Prunişor,Prunişori', 44.6094400, 22.9152800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115157, 'Prundu Bârgăului', 'Prundu Bargaului', 'Borgoprund,Borgóprund,Prundu Birgaului,Prundu Bîrgăului,Prundul Secului,Prundul-Bargaului,Prundul-Bârgăului', 47.2197500, 24.7412300, 'RO', '2015-11-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115158, 'Prundu', 'Prundu', 'Prundu,Prundu Comenii,Prundul', 44.0947200, 26.2269400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115159, 'Prundu', 'Prundu', 'Prundu,Rudari', 43.8239400, 24.6919600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115160, 'Prundeni', 'Prundeni', 'Daesti,Dăeşti,Prundeni', 44.7333300, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115161, 'Proviţa de Sus', 'Provita de Sus', '', 45.1333300, 25.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115162, 'Proviţa de Jos', 'Provita de Jos', 'Provita de Jos,Proviţa de Jos', 45.1166700, 25.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115163, 'Prohozești', 'Prohozesti', '', 46.4815500, 26.5517000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115164, 'Progresu', 'Progresu', 'Progresu,Progresul,Putu Dimii,Puţu Dimii', 44.3588600, 26.4611000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115165, 'Produleşti', 'Produlesti', 'Produlesti,Produleşti', 44.7000000, 25.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115166, 'Probota', 'Probota', '', 47.3758400, 26.6241500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115167, 'Probota', 'Probota', 'Probota,Probota-Ciulnesti,Probota-Ciulneşti', 47.3833300, 27.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115168, 'Pristol', 'Pristol', 'Pristol,Pristolu', 44.2247200, 22.7091700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115169, 'Priseaca', 'Priseaca', 'Priseaca', 44.5166700, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115170, 'Prisăcani', 'Prisacani', 'Prisacani,Prisacani-Moreni,Prisecani,Prisecani-Moreni,Prisăcani,Prisăcani-Moreni', 47.0833300, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115171, 'Priponeşti', 'Priponesti', 'Priponescii-de Sus,Priponesti,Priponestii de Sus,Priponeşti,Priponeştii de Sus', 46.0833300, 27.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115172, 'Prigoria', 'Prigoria', 'Prigoria', 45.0666700, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115173, 'Prigor', 'Prigor', 'Prigor', 44.9383300, 22.1133300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115174, 'Pricaz', 'Pricaz', '', 45.8592900, 23.1726600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115175, 'Priboiu', 'Priboiu', '', 45.0300600, 25.2579000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115176, 'Priboieni', 'Priboieni', 'Priboeni,Priboieni', 44.8833300, 25.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115177, 'Pribești', 'Pribesti', '', 46.9100100, 27.7965900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115178, 'Preuteşti', 'Preutesti', 'Preutesti,Preuteşti', 47.4500000, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115179, 'Prelipca', 'Prelipca', '', 47.6108500, 26.3541400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115180, 'Prejmer', 'Prejmer', 'Prazsmar,Prejmer,Prázsmár,Tartlau', 45.7166700, 25.7666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115181, 'Predeşti', 'Predesti', 'Predesti,Predeşti', 44.3500000, 23.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115182, 'Predeal', 'Predeal', 'Predeal,Predeál,Predjal,prda,pu lei dai ya er,Предеал,Предял,פרדיאל,پردا,普雷代亞爾', 45.5000000, 25.5666700, 'RO', '2017-01-28', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115183, 'Preajba', 'Preajba', '', 44.2651100, 23.8502400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115184, 'Prapor', 'Prapor', 'Praporu,Praporul', 43.9448700, 24.1747500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115185, 'Prajila', 'Prajila', '', 45.0827000, 24.1694900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115186, 'Prăjești', 'Prajesti', '', 46.6546900, 26.9763100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115187, 'Prăjeni', 'Prajeni', '', 47.5166700, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115188, 'Prăjani', 'Prajani', 'Prajani,Prajarii,Prăjani', 45.2042200, 25.9515100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115189, 'Praid', 'Praid', 'Parajd,Praid', 46.5500000, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115190, 'Potoceni', 'Potoceni', 'Potoceni,Potoceni de Jos,Potocenii de Jos', 45.1966000, 26.7764900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115191, 'Potlogi', 'Potlogi', 'Potlogi', 44.5500000, 25.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115192, 'Potlogeni', 'Potlogeni', '', 43.8799500, 24.6309200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115193, 'Potigrafu', 'Potigrafu', 'Potigraf,Potigrafu', 44.7850400, 26.1001400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115194, 'Potelu', 'Potelu', 'Potelu,Potelul', 43.7657700, 24.2053500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115195, 'Potcoava Fălcoeni', 'Potcoava Falcoeni', 'Broscari,Potcoava-Falcoieni,Potcoava-Fălcoieni', 44.4948400, 24.6165000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115196, 'Potcoava', 'Potcoava', 'Potcoava,Potcoava Cirstesti,Potcoava Cîrsteşti', 44.4833300, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115197, 'Potcoava', 'Potcoava', '', 44.2633200, 27.1322300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115198, 'Potău', 'Potau', 'Potau,Potaul,Potău,Potăul', 47.7567300, 23.1209000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115199, 'Poşta Câlnău', 'Posta Calnau', 'Calugari,Călugări,Posta,Posta Calnau,Posta Cilnau,Poşta,Poşta Calnau,Poşta Cîlnău,Scarisoara,Scărisoara', 45.2333300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115200, 'Poseștii-Pământeni', 'Posestii-Pamanteni', 'Posestii-Paminteni,Poseștii-Pămînteni', 45.2666700, 26.1500000, 'RO', '2015-12-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115201, 'Poşaga de Sus', 'Posaga de Sus', '', 46.4666700, 23.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115202, 'Posada', 'Posada', '', 45.2871400, 25.6188200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115203, 'Porumbești', 'Porumbesti', 'Koekenyesd,Kökényesd,Porumbesti,Porumbeşti', 47.9830500, 22.9807600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115204, 'Porumbenii Mari', 'Porumbenii Mari', 'Nagygalambfalva,Porumbenii Mari,Porumbenii-Mare', 46.2754900, 25.1362000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115205, 'Porumbacu de Jos', 'Porumbacu de Jos', 'Porumbacu de Jos,Porumbacul de Jos', 45.7500000, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115206, 'Poroschia', 'Poroschia', 'Poroschia', 43.9333300, 25.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115207, 'Poroina Mare', 'Poroina Mare', 'Poroina Mare', 44.4952800, 22.9363900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115208, 'Popricani', 'Popricani', 'Popricani,Popricani-Coarba', 47.3000000, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115209, 'Popoveni', 'Popoveni', '', 44.2880000, 23.7820800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115210, 'Poporogi', 'Poporogi', '', 44.3666700, 25.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115211, 'Poplaca', 'Poplaca', 'Poplaca', 45.7166700, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115212, 'Popeşti-Leordeni', 'Popesti-Leordeni', 'Popesti,Popesti-Leordeni,Popesti-Leurdeni,Popestii,Popestii-Conduratu,Popeşti,Popeşti-Leordeni,Popeşti-Leurdeni,Popeştii,Popeştii-Conduratu,Popoestii-Leordeni,Popoeştii-Leordeni', 44.3833300, 26.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115213, 'Popeşti', 'Popesti', '', 47.2333300, 22.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115214, 'Popeşti', 'Popesti', '', 47.1500000, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115215, 'Popești', 'Popesti', '', 45.5953300, 27.0791600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115216, 'Popeşti', 'Popesti', '', 44.9833300, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115217, 'Popești', 'Popesti', '', 44.8607600, 25.9955700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115218, 'Popeşti', 'Popesti', '', 44.7666700, 25.0666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115219, 'Popeşti', 'Popesti', '', 44.4418100, 25.1000700, 'RO', '2012-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115220, 'Popești', 'Popesti', '', 44.3044400, 25.9637000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115221, 'Popeni', 'Popeni', '', 46.2466700, 27.8052000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115222, 'Ponor', 'Ponor', 'Ponor', 46.3333300, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115223, 'Ponoarele', 'Ponoarele', 'Ponoarele', 44.9738900, 22.7644400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115224, 'Pomârla', 'Pomarla', 'Pomarla,Pomirla,Pomârla,Pomîrla', 48.0666700, 26.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115225, 'Pomi', 'Pomi', 'Pomi', 47.7000000, 23.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115226, 'Pomezeu', 'Pomezeu', 'Pomezeu', 46.7833300, 22.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115227, 'Polovragi', 'Polovragi', 'Polovragi,Polovragiu', 45.1833300, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115228, 'Poloboc', 'Poloboc', '', 46.7610900, 26.5497500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115229, 'Pojorâta', 'Pojorata', 'Pojarata,Pojarâta,Pojorata,Pojorita,Pojorâta,Pojorîta', 47.5166700, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115230, 'Pojogeni', 'Pojogeni', '', 44.9911900, 23.4842500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115231, 'Pojejena', 'Pojejena', 'Pojejena,Pojejena de Jos,Rumunska Pozezena,Rumunska Požežena', 44.7741700, 21.5791700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115232, 'Poienile-Mogoş', 'Poienile-Mogos', 'Poienile-Mogos,Poienile-Mogoş,Sularesti,Sulăreşti', 46.2833300, 23.2833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115233, 'Poienile Izei', 'Poienile Izei', 'Poienile Glodului,Poienile Izei,Sajomezo,Sajómező', 47.7000000, 24.1166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115234, 'Poienile de sub Munte', 'Poienile de sub Munte', 'Poienele de sub Munte,Poieni de Sub Munte,Poienile de sub Munte', 47.8166700, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115235, 'Poienile', 'Poienile', 'Lingurari,Lingurari Ursari,Poienile', 46.9333300, 27.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115236, 'Poieneşti', 'Poienesti', 'Dealu Poenesti,Dealu Poeneşti,Poenesti,Poenesti Minastire,Poenesti-Ghica,Poenesti-Manastirei,Poenestii-Manastirei,Poeneşti,Poeneşti Mînăstire,Poeneşti-Ghica,Poeneşti-Mănăstirei,Poeneştii-Mânăstirei,Poiana,Poienesti,Poienesti-Ghica,Poieneşti,Poieneşti-Ghica', 46.6166700, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115237, 'Poienari', 'Poienari', 'Poenari,Poenita,Poeniţa,Poienari', 46.8877700, 27.1276500, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115238, 'Poiana Vadului', 'Poiana Vadului', 'Neagra,Poiana Vadului', 46.4000000, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115239, 'Poiana Teiului', 'Poiana Teiului', 'Poiana Teiului,Poiana Teului,Poiana-Teiuluui', 47.1000000, 25.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115240, 'Poiana Țapului', 'Poiana Tapului', '', 45.3934400, 25.5406600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115241, 'Poiana Stampei', 'Poiana Stampei', 'Poiana Stampei,Poiana Stampii', 47.3166700, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115242, 'Poiana Sibiului', 'Poiana Sibiului', 'Poiana,Poiana Sibiului', 45.8000000, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115243, 'Poiana Mărului', 'Poiana Marului', '', 47.4118800, 26.0407700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115244, 'Poiana Mărului', 'Poiana Marului', 'Poiana Marului,Poiana Mărului,Varati,Viriti,Vârâţi,Vîrîţi', 47.3795100, 26.8924300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115245, 'Poiana Mărului', 'Poiana Marului', 'Marulin,Poiana Marului,Poiana Mărului', 45.6000000, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115246, 'Poiana Mare', 'Poiana Mare', 'Poiana Mare', 43.9166700, 23.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115247, 'Poiana Lacului', 'Poiana Lacului', 'Poiana Lacului', 44.8166700, 24.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115248, 'Poiana Ilvei', 'Poiana Ilvei', 'Poiana Ilvei', 47.3574900, 24.7410400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115249, 'Poiana Cristei', 'Poiana Cristei', 'Poiana Cristei', 45.6500000, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115250, 'Poiana Crăcăoani', 'Poiana Cracaoani', 'Piona,Poiana,Poiana Almasului,Poiana Almaşului,Poiana Cracaoani,Poiana Crăcăoani', 47.0666700, 26.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115251, 'Poiana Copăceni', 'Poiana Copaceni', 'Copaceni,Copăceni,Poeana Copaciului,Poiana Copaceni,Poiana Copăceni', 45.1639200, 26.0691800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115252, 'Poiana Codrului', 'Poiana Codrului', '', 47.6266700, 23.2505600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115253, 'Poiana Câmpina', 'Poiana Campina', 'Poiana,Poiana Cimpina,Poiana Cîmpina,Poiana-Campina,Poiana-Câmpina,Poiana-de-Prahova', 45.1333300, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115254, 'Poiana Blenchii', 'Poiana Blenchii', 'Poiana Blenchii', 47.3000000, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115255, 'Poiana', 'Poiana', '', 47.6014900, 26.6082600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115256, 'Poiana', 'Poiana', '', 47.5643600, 26.8638700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115257, 'Poiana', 'Poiana', '', 47.4929900, 26.8638700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115258, 'Poiana', 'Poiana', 'Cautiseni-Burchi,Cautiseni-Razesi,Căutişeni-Burchi,Căutişeni-Răzeşi,Poiana,Poiana Iurascu,Poiana lui Iurascu,Poiana lui Iuraşcu,Poiana lui Jurascu,Poiana lui Juraşcu,Sasa', 46.6981900, 27.0176500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115259, 'Poiana', 'Poiana', '', 45.9922800, 27.2560900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115260, 'Poiana', 'Poiana', 'Poiana,Poiana Comarnic', 45.2453600, 25.6630200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115261, 'Poiana', 'Poiana', 'Poiana,Poiana-de-Sus', 44.6517400, 23.5314800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115262, 'Poiana', 'Poiana', 'Poiana,Poiana de Sus', 44.5666700, 25.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115263, 'Poiana', 'Poiana', 'Flamanda,Flaminda,Flămânda,Flămînda,Poiana', 43.7419200, 24.9524400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115264, 'Poian', 'Poian', 'Poian,Pojan', 46.0666700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115265, 'Pogonești', 'Pogonesti', 'Pogonesti,Pogonestii,Pogoneşti,Pogoneştii', 46.1522900, 27.5322500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115266, 'Pogonele', 'Pogonele', 'Pogoanele,Tintesti-Pogoanele,Ţinteşti-Pogoanele,Погоанеле', 45.0864500, 26.8645400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115267, 'Pogoanele', 'Pogoanele', 'Pogoanele', 44.9166700, 27.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115268, 'Pogănești', 'Poganesti', '', 46.6923700, 28.1677900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115269, 'Pogana', 'Pogana', 'Pogana', 46.3166700, 27.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115270, 'Pogăceaua', 'Pogaceaua', 'Pogaceana,Pogaceaua,Pogăceana,Pogăceaua', 46.6833300, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115271, 'Poieni-Solca', 'Poieni-Solca', 'Poeni,Poeni pe Solca,Poeni-Solca,Poieni', 47.6862600, 25.8937400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115272, 'Poieni', 'Poieni', 'Kissebes,Poeni', 46.9188000, 22.8582600, 'RO', '2015-11-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115273, 'Poieni', 'Poieni', '', 46.8333300, 26.3500000, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115274, 'Poeni', 'Poeni', 'Ion C. Bratianu-Poeni,Poeni', 44.4000000, 25.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115275, 'Poienarii Apostoli', 'Poienarii Apostoli', 'Poenari-Apostoli,Poenarii-Apostoli', 44.7720400, 26.0538800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115276, 'Poienarii Burchii', 'Poienarii Burchii', 'Burchi', 44.7500000, 26.0166700, 'RO', '2015-12-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115277, 'Poienari', 'Poienari', '', 46.8852800, 27.1330600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115278, 'Poienari', 'Poienari', 'Poenari,Poenarii', 45.2166700, 25.0500000, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115279, 'Podu Turcului', 'Podu Turcului', 'Podu Turcului,Podul-Turcului', 46.2000000, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115280, 'Poduri', 'Poduri', '', 46.6166700, 24.0666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115281, 'Poduri', 'Poduri', '', 46.4666700, 26.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115282, 'Podu Iloaiei', 'Podu Iloaiei', 'Podu Iloaei,Podu Iloaie,Podu Iloaiei,Podul-Iloaei,Podul-Iloaiei,Podulloae', 47.2166700, 27.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115283, 'Podolenii de Sus', 'Podolenii de Sus', 'Podoleni-de-Sus,Podolenii de Sus', 46.8571600, 28.0154500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115284, 'Podoleni', 'Podoleni', 'Podoleni', 46.8000000, 26.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115285, 'Podoleni', 'Podoleni', '', 45.7483000, 27.4466100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115286, 'Podgoria', 'Podgoria', 'Jideni,Podgoria', 45.4166700, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115287, 'Podenii Vechi', 'Podenii Vechi', 'Podeni Vechi,Podenii Vechi', 45.0893900, 26.1158400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115288, 'Podenii Noi', 'Podenii Noi', 'Podenii Noi,Podenii-Noui', 45.1166700, 26.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115289, 'Podeni', 'Podeni', 'Podeni', 44.8813900, 22.5433300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115290, 'Podari', 'Podari', 'Podari', 44.2500000, 23.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115291, 'Pocruia', 'Pocruia', '', 45.0447000, 22.9249500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115292, 'Pocola', 'Pocola', 'Pocola', 46.6833300, 22.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115293, 'Pociovaliștea', 'Pociovalistea', '', 45.1531500, 23.6439200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115294, 'Pochidia', 'Pochidia', 'Pochidia', 46.0431800, 27.5874600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115295, 'Poboru', 'Poboru', 'Poboru,Poborul', 44.6666700, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115296, 'Poarta Albă', 'Poarta Alba', 'Alacap,Alacop,Poarta Alba,Poarta Albu,Poarta Albă,Poarta Albŭ', 44.2166700, 28.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115297, 'Plugova', 'Plugova', 'Plugova,Plugovo', 44.9625000, 22.3586400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115298, 'Plugari', 'Plugari', 'Balus,Băluş,Hanu Balus,Hanu Băluş,Plugari', 47.4833300, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115299, 'Plutonița', 'Plutonita', '', 47.4808100, 25.7914500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115300, 'Ploștina', 'Plostina', '', 44.8239800, 22.9879100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115301, 'Ploscuțeni', 'Ploscuteni', 'Ploscuteni,Ploscutenii,Ploscuţeni,Ploscuţenii', 46.0785900, 27.2703200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115302, 'Ploscoș', 'Ploscos', 'Palackos,Ploszkos', 46.6430300, 23.8466300, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115303, 'Plosca', 'Plosca', 'Plosca', 44.0333300, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115304, 'Plopu', 'Plopu', 'Plop,Plopu,Plopul', 46.3925600, 26.5026800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115305, 'Plopu', 'Plopu', 'Plopu,Plopul', 45.1484700, 27.5138700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115306, 'Plopu', 'Plopu', 'Plopu,Plopul', 45.0166700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115307, 'Plopşoru', 'Plopsoru', 'Plopsoru,Plopsorul,Plopşoru,Plopşorul', 44.7833300, 23.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115308, 'Plopșoru', 'Plopsoru', '', 44.0119000, 25.9930600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115309, 'Plopiş', 'Plopis', 'Plopis,Plopiş', 47.1333300, 22.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115310, 'Plopii Slăviţeştí', 'Plopii Slavitesti', 'Plopi-Slavitesti,Plopi-Slăviteşti,Plopii Slavitesti,Plopii Slăviţeştí', 43.9666700, 24.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115311, 'Plopeni', 'Plopeni', '', 47.6587400, 26.3391300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115312, 'Plopeni', 'Plopeni', 'Margineanca,Mărgineanca,Plopeni,Stejarul,Плопени', 45.0495500, 25.9520200, 'RO', '2015-12-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115313, 'Plopeni', 'Plopeni', 'Caraclar,Cavaclar,Plopeni,Плопени', 43.9508900, 28.1945200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115314, 'Plopana', 'Plopana', 'Plopana,Plopana Targ,Plopana Târg,Plopana-Sat,Plopana-Tirg,Plopana-Tîrg,Targul Plopana,Târgul Plopana', 46.6833300, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115315, 'Ploieşti', 'Ploiesti', 'Ploeshh,Ploesti,Ploeszti,Ploeşti,Ploiesti,Ploieşti,Ploiești,plwyst,plwysty,Плоещ,פלוישט,פלוישטי', 44.9500000, 26.0166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115316, 'Ploieștiori', 'Ploiestiori', '', 44.9815700, 26.0179500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115317, 'Plevna', 'Plevna', '', 45.3781500, 27.0131000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115318, 'Pleşoiu', 'Plesoiu', 'Plesoiu,Plesoiul,Pleşoiu,Pleşoiul', 44.4666700, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115319, 'Pleșoi', 'Plesoi', 'Plesoiu,Plesoiul,Pleşoiu,Pleşoiul', 44.3507700, 23.5334500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115320, 'Pleşcuţa', 'Plescuta', 'Peleskefalva,Plescuta,Pleskucza,Pleșcuța', 46.3000000, 22.4333300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115321, 'Pleniţa', 'Plenita', 'Plenita,Pleniţa', 44.2166700, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115322, 'Pleașov', 'Pleasov', 'Pleasov,Pleasovul,Pleaşov,Pleaşovul', 43.8497100, 24.7488600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115323, 'Pleașa', 'Pleasa', '', 45.0058300, 26.0721100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115324, 'Plăvălari', 'Plavalari', '', 47.5683200, 26.3592500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115325, 'Platonești', 'Platonesti', '', 44.6071200, 27.6970600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115326, 'Plătăreşti', 'Plataresti', 'Plataresti,Plătăreşti', 44.3500000, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115327, 'Piteşti', 'Pitesti', 'Pitesci,Pitescï,Piteshh,Piteshti,Pitesti,Piteşti,Pitești,pytst,Питещ,פיטשט', 44.8500000, 24.8666700, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115328, 'Piteasca', 'Piteasca', '', 44.4933900, 26.3302500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115329, 'Pitaru', 'Pitaru', 'Pitaru,Pitarul', 44.5906100, 25.5840700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115330, 'Piscu Vechi', 'Piscu Vechi', 'Piscu Vechi,Piscu de Cimpie,Piscu de Cîmpie,Piscu-Vechiu,Piscul-Vechiu', 43.9000000, 23.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115331, 'Piscu Sadovei', 'Piscu Sadovei', 'Piscu,Piscu Sadovei,Piscul', 43.8772900, 23.9368700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115332, 'Piscu Nou', 'Piscu Nou', 'Piscu Nou,Piscul-Nou', 43.9240000, 23.1791700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115333, 'Piscu', 'Piscu', 'Piscu,Piscul', 45.5000000, 27.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115334, 'Pişcolt', 'Piscolt', 'Piscolt,Pişcolt', 47.5833300, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115335, 'Piscoiu', 'Piscoiu', 'Piscoiu,Piscoiul', 44.8521100, 23.7538700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115336, 'Pişchia', 'Pischia', 'Bruckenau,Hidasliget,Pischia,Pişchia', 45.9030600, 21.3372200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115337, 'Pârşcoveni', 'Parscoveni', 'Parscoveni,Pirscoveni,Pârşcoveni,Pîrşcoveni', 44.3000000, 24.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115338, 'Pârscov', 'Parscov', 'Parscov,Parscovu,Parscovul,Pirscov,Pârscov,Pârscovu,Pârscovul,Pîrscov', 45.2833300, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115339, 'Pârjol', 'Parjol', 'Parjol,Pirjol,Pârjol,Pîrjol', 46.5833300, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115340, 'Pârâu', 'Parau', 'Parau,Piriu,Pârâu,Pîrîu', 45.8500000, 25.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115341, 'Pârgăreşti', 'Pargaresti', 'Pargarestii,Pirgaresti,Pîrgăreşti', 46.2500000, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115342, 'Pârcovaci', 'Parcovaci', 'Parcovaci,Parcovici,Pircovaci,Pârcovaci,Pîrcovaci', 47.4358600, 26.8507500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115343, 'Pâraie', 'Paraie', 'Parae,Paraeie,Paraie,Piraie,Pârae,Pâraeie,Pâraie,Pîraie', 47.4629900, 26.0660800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115344, 'Pir', 'Pir', 'Pir', 47.4666700, 22.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115345, 'Pipirig', 'Pipirig', 'Pioirig,Pipirig', 47.2500000, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115346, 'Pângăraţi', 'Pangarati', 'Pangarati,Pingarati,Pângăraţi,Pîngăraţi', 46.9333300, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115347, 'Pângărăcior', 'Pangaracior', 'Pingaracior,Pîngărăcior', 46.9333300, 26.2166700, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115348, 'Pâncota', 'Pancota', 'Pancota,Pâncota', 46.3333300, 21.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115349, 'Pânceşti', 'Pancesti', 'Pancesti,Pincesti,Pînceşti,Păncesti', 46.9029600, 27.1531400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115350, 'Pilu', 'Pilu', 'Pilu,Pilul', 46.5666700, 21.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115351, 'Pildești', 'Pildesti', '', 46.9967500, 26.8255800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115352, 'Pietrosu', 'Pietrosu', '', 47.3411800, 26.6081700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115353, 'Pietrosu', 'Pietrosu', '', 45.0592800, 26.7582700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115354, 'Pietroşiţa', 'Pietrosita', 'Pietrosita,Pietroşiţa', 45.1833300, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115355, 'Pietroşani', 'Pietrosani', 'Pietrosani,Pietrosanii,Pietroşani,Pietroşanii', 45.1833300, 24.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115356, 'Pietroșani', 'Pietrosani', '', 44.8396300, 26.1038200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115357, 'Pietroşani', 'Pietrosani', 'Petrosani,Pietrosani,Pietroşani', 43.7166700, 25.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115358, 'Pietroasele', 'Pietroasele', 'Pietroasa-de-Jos,Pietroasele,Pietroasele-de-Jos', 45.1000000, 26.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115359, 'Pietroasa', 'Pietroasa', 'Petroasa,Petrosz,Petrosza,Petrósz,Petrósza,Pietroasa,Vasaskofalva,Vasaskőfalva', 46.5833300, 22.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115360, 'Pietroasa', 'Pietroasa', 'Petroasa,Pietroasa', 45.8333300, 22.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115361, 'Pietrișu', 'Pietrisu', 'Pietrisu,Pietrisul,Pietrişu,Pietrişul,Stirbei-Voda,Ştirbei-Vodă', 43.7250800, 25.6746400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115362, 'Pietreni', 'Pietreni', 'Cocargea,Cogarcea,Pietreni', 44.0960900, 28.0683300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115363, 'Pietrele', 'Pietrele', 'Petrile,Pietrele,Pietrile', 44.0625800, 26.1201900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115364, 'Pietrarii de Sus', 'Pietrarii de Sus', '', 45.1169700, 24.0933600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115365, 'Pietrari', 'Pietrari', 'Pietrari,Pietrari de Jos,Pietrarii de Jos', 45.1000000, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115366, 'Pietrari', 'Pietrari', 'Pietrari,Pietrarii', 45.0937700, 25.2928900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115367, 'Pieleştí', 'Pielesti', 'Pielesti,Pielestii,Pieleştí', 44.3333300, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115368, 'Picior de Munte', 'Picior de Munte', '', 44.7824700, 25.3904700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115369, 'Piatra Şoimului', 'Piatra Soimului', 'Calu,Calul,Piatra Soimului,Piatra Şoimului', 46.8333300, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115370, 'Piatra Olt', 'Piatra Olt', 'Piatra Olt', 44.3666700, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115371, 'Piatra Neamţ', 'Piatra Neamt', 'Karacsonko,Karácsonkő,Piatra Neamt,Piatra Neamţ,Piatra Neamț,Piatra-Neamt', 46.9166700, 26.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115372, 'Piatra', 'Piatra', 'Piatra,Tasaul,Tashaul,Taşaul', 44.4049200, 28.5614300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115373, 'Piatra', 'Piatra', 'Petra,Piatra,Pintra', 44.3605400, 24.2955700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115374, 'Piatra', 'Piatra', 'Petra,Piatra,Vacaresti de Rasoaca,Văcăreşti de Răsoaca', 43.8166700, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115375, 'Pianu de Sus', 'Pianu de Sus', 'Pianu de Sus,Pianul-de-Sus', 45.9000000, 23.4833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115376, 'Pianu de Jos', 'Pianu de Jos', 'Alsopian,Alsópián,Pianu de Jos,Pianul-de-Jos', 45.9352800, 23.4891200, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115377, 'Petrova', 'Petrova', '', 47.8298100, 24.2153300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115378, 'Petroșnița', 'Petrosnita', '', 45.3235100, 22.2592000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115379, 'Petroşani', 'Petrosani', 'Petrosani,Petroseni,Petroshani,Petrozseny,Petrozsény,Petroşani,Petroşeni,Petroșani,Pietrosani,Pietroşani,Петрошани', 45.4166700, 23.3666700, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115380, 'Petriș', 'Petris', '', 47.1030100, 24.6231400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115381, 'Petriş', 'Petris', 'Marospetres,Petris,Petriș', 46.0500000, 22.3833300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115382, 'Petrila', 'Petrila', 'Petrila', 45.4500000, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115383, 'Pietriceaua', 'Pietriceaua', 'Petriceaua,Pietricea', 45.2191000, 25.8085900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115384, 'Petricani', 'Petricani', 'Petricani', 47.1666700, 26.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115385, 'Petreu', 'Petreu', '', 47.3373800, 22.2960700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115386, 'Petreştii de Jos', 'Petrestii de Jos', 'Magyarpeterd,Petrestii de Jos,Petreştii de Jos,Petridu de Jos', 46.5833300, 23.6500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115387, 'Petreşti', 'Petresti', 'Petresti,Petreşti', 47.6000000, 22.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115388, 'Petrești', 'Petresti', '', 45.9210200, 23.5608300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115389, 'Petrești', 'Petresti', 'Petresti,Petrestii,Petreşti,Petreştii', 45.0436400, 24.8898900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115390, 'Petreşti', 'Petresti', '', 44.6500000, 25.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115391, 'Petrăchioaia', 'Petrachioaia', 'Creata-Petrachioaia,Creata-Petrachioata,Creaţa-Petrăchioaia,Creaţa-Petrăchioata,Petrachioaia,Petrichioaia,Petrăchioaia', 44.5809900, 26.3126900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115392, 'Petelea', 'Petelea', 'Petele', 46.7289200, 24.7065400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115393, 'Peştişu Mic', 'Pestisu Mic', 'Pestisu Mic,Pestisul-Mic,Pestişul-Mic,Peştişu Mic', 45.8000000, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115394, 'Peștișu Mare', 'Pestisu Mare', 'Pestisu Mare,Pestisul-Mare,Pestişul-Mare,Peştişu Mare', 45.8019200, 22.9270400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115395, 'Peştişani', 'Pestisani', 'Pestisani,Peştişani', 45.0666700, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115396, 'Peștiș', 'Pestis', '', 47.0725200, 22.4122600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115397, 'Peştera', 'Pestera', 'Pestera,Peştera', 44.1833300, 28.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115398, 'Peșteana Jiu', 'Pesteana Jiu', 'Pesteana Jiu,Pesteana-de-Jiu,Peşteana Jiu,Peşteana-de-Jiu', 44.8469500, 23.3040100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115399, 'Peșteana de Jos', 'Pesteana de Jos', 'Pesteana,Pesteana de Jos,Peşteana,Peşteana de Jos', 44.8333300, 23.2697400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115400, 'Pesceana', 'Pesceana', 'Pesceana,Pesceana-Cueni', 44.8833300, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115401, 'Glăvile', 'Glavile', '', 44.8166700, 24.1500000, 'RO', '2016-01-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115402, 'Coronini', 'Coronini', 'Coronini,Koronini,Pescari', 44.6800400, 21.6855200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115403, 'Pesac', 'Pesac', 'Pesac,Pesak,Peszak,Pészak', 45.9959000, 20.8352200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115404, 'Perșunari', 'Persunari', 'Persinarii,Persunari,Perşunari,Tohaneanca Ungureni,Tohăneanca Ungureni', 45.0568200, 26.4478400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115405, 'Perșinari', 'Persinari', 'Persinari,Perşinari,Piersinari,Pierşinari', 44.8018500, 25.4988000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115406, 'Perșani', 'Persani', '', 45.7816000, 25.2128500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115407, 'Perișoru', 'Perisoru', 'Perisoru,Perisorul,Perişoru,Perişorul', 45.1126800, 27.4981700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115408, 'Perişoru', 'Perisoru', 'Duca,Ion Gheorghe Duca,Perisoru,Perişoru', 44.4500000, 27.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115409, 'Perișor', 'Perisor', 'Perisor,Perisoru,Perisorul,Perişor,Perişoru,Perişorul', 44.1433100, 23.4750900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115410, 'Perişani', 'Perisani', 'Perisani,Perisanii,Perişani,Perişanii', 45.3833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115411, 'Periş', 'Peris', 'Peris,Periş', 44.6847200, 26.0138900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115412, 'Perii Broșteni', 'Perii Brosteni', 'Perii,Perii-Brosteni,Perii-Broşteni', 44.2033600, 25.2637700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115413, 'Perieţi', 'Perieti', '', 44.5500000, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115414, 'Perieţi', 'Perieti', 'Perieti,Perietii de Mijloc,Perietii de Myloc,Perieţi,Perieţii de Mijloc', 44.4000000, 24.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115415, 'Perieni', 'Perieni', '', 47.3846900, 27.4745300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115416, 'Perieni', 'Perieni', 'Perieni', 46.3000000, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115417, 'Pericei', 'Pericei', 'Szilagyperecsen,Szilágyperecsen', 47.2333300, 22.8833300, 'RO', '2015-12-28', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115418, 'Periam', 'Periam', 'Pergemes,Periam,Perjamos,Perjamosch,Perjámos', 46.0500000, 20.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115419, 'Peretu', 'Peretu', 'Peretu,Peretul', 44.0500000, 25.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115420, 'Peregu Mic', 'Peregu Mic', 'Kispereg,Kleinpereg,Peregu Mic,Peregul-Mic', 46.2502100, 20.9488500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115421, 'Peregu Mare', 'Peregu Mare', 'Deutschpereg,Gross-Perek,Nagy-Pereg,Nemetpereg,Németpereg,Pereg,Peregu,Peregu Mare,Peregul-Mare', 46.2333300, 20.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115422, 'Peciu Nou', 'Peciu Nou', 'Neu-Petsch,Peciu Nou,Peciul Nou,Ujbecs,Ujpecs,Ulmbach,Újbécs,Újpécs', 45.6063900, 21.0577800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115423, 'Pecineaga', 'Pecineaga', 'Gherengii,Ghrengic,Ion Gheorghe Duca,Peceneaga,Pecineaga', 43.9000000, 28.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115424, 'Pechea', 'Pechea', 'Pechea', 45.6333300, 27.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115425, 'Peceneaga', 'Peceneaga', 'Peceneaga,Pecineaga', 45.0166700, 28.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115426, 'Peceiu', 'Peceiu', 'Peceiu,Peceiul', 47.1241500, 22.8623800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115427, 'Păuşeşti-Măglaşi', 'Pausesti-Maglasi', 'Pausesti-Maglas,Pausesti-Maglasi,Pausestii-Maglasti,Păuşeşti-Măglaş,Păuşeşti-Măglaşi,Păuşeştii-Maglaşti', 45.1333300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115428, 'Păușești', 'Pausesti', '', 47.1581000, 27.3259400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115429, 'Păuşeşti', 'Pausesti', '', 45.0735800, 24.1347300, 'RO', '2012-06-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115430, 'Păuneşti', 'Paunesti', 'Paunesti,Paunestii,Păuneşti,Păuneştii', 46.0333300, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115431, 'Păuliş', 'Paulis', 'Alt-Paulisch,Neu-Paulisch,Opalos,Opaulis,Paulis,Paulisu Nou,Paulisul Nou,Păuliş,Păulişu Nou,Păulişul Nou,Ópaulis,Ópálos', 46.1166700, 21.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115432, 'Păuleşti', 'Paulesti', 'Paulesti,Păuleşti', 47.7833300, 22.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115433, 'Păulești', 'Paulesti', 'Paulesti,Paulestii,Păuleşti,Păuleştii', 45.8915400, 26.6891400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115434, 'Păuleşti', 'Paulesti', 'Paulesti,Păuleşti', 45.0000000, 25.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115435, 'Păuleni-Ciuc', 'Pauleni-Ciuc', 'Csikpalfalva,Csíkpálfalva,Palfalva,Pauleni,Pauleni-Ciuc,Pàlfalva,Păuleni,Păuleni-Ciuc', 46.4000000, 25.8333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115436, 'Păuca', 'Pauca', 'Pauca,Păuca', 46.0166700, 23.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115437, 'Pătuleni', 'Patuleni', '', 44.7324700, 25.1649500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115438, 'Pătulele', 'Patulele', 'Patule,Patulele,Pătule,Pătulele', 44.3452800, 22.7727800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115439, 'Patru Frați', 'Patru Frati', '', 44.7367200, 26.4705900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115440, 'Pătrăuţi', 'Patrauti', 'Patrauti,Patrautii-Sucevei,Patrautii-Sucevii,Patrautii-pe-Suceava,Pătrăuţi,Pătrăuţii-Sucevei,Pătrăuţii-Sucevii,Pătrăuţii-pe-Suceava', 47.7166700, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115441, 'Pătârlagele', 'Patarlagele', 'Patarlagele,Patirlagele,Pătârlagele,Pătîrlagele', 45.3208100, 26.3613400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115442, 'Păstrăveni', 'Pastraveni', 'Pastraveni,Păstrăveni', 47.1666700, 26.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115443, 'Păsăreni', 'Pasareni', 'Baczkamadaras,Pasareni,Păsăreni', 46.4833300, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115444, 'Parva', 'Parva', 'Parva', 47.4000000, 24.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115445, 'Părteştii de Jos', 'Partestii de Jos', '', 47.6333300, 25.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115446, 'Parța', 'Parta', 'Parac,Paracz,Paratz,Parta,Parác,Parácz,Parátz,Parţa', 45.6288800, 21.1387700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115447, 'Parincea', 'Parincea', 'Parincea,Parincea-Tirg,Parincea-Tîrg', 46.4833300, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115448, 'Părhăuți', 'Parhauti', '', 47.7105700, 26.0901200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115449, 'Parepa-Rușani', 'Parepa-Rusani', 'Parepa,Parepa-Rusani,Parepa-Ruşani,Rusani,Ruşani', 44.9057700, 26.3547800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115450, 'Pardoşi', 'Pardosi', 'Pardosi,Pardosii,Pardoşi,Pardoşii', 45.3666700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115451, 'Pardina', 'Pardina', 'Pardina,Pardine', 45.3000000, 28.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115452, 'Parava', 'Parava', 'Parava', 46.3000000, 27.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115453, 'Papiu Ilarian', 'Papiu Ilarian', 'Budiu de Cimpie,Budiu de Cîmpie,Papiu Ilarian', 46.5500000, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115454, 'Păpăuți', 'Papauti', 'Papolc', 45.7833300, 26.1333300, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115455, 'Panticeu', 'Panticeu', 'Panticeu,Panticeul,Pinticeu,Pînticeu,Pănticeul', 47.0333300, 23.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115456, 'Pantelimon de Jos', 'Pantelimon de Jos', 'Pantelimon de Jos,Pantelimonul de Jos', 44.5666700, 28.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115457, 'Pantelimon', 'Pantelimon', 'Pantelimon,Pantelimon de Sus,Pantelimonul de Sus', 44.5458900, 28.3309400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115458, 'Pantelimon', 'Pantelimon', '', 44.4500000, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115459, 'Pantazi', 'Pantazi', '', 44.9349200, 26.1402000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115460, 'Pănet', 'Panet', 'Mezopanit,Mezöpanit', 46.5551400, 24.4697300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115461, 'Panciu', 'Panciu', 'Panciu', 45.9000000, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115462, 'Pănceşti', 'Pancesti', '', 46.3333300, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115463, 'Păncești', 'Pancesti', 'Pancesti,Pancestii,Pănceşti,Pănceştii', 46.2111800, 27.0679700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115464, 'Pănătău', 'Panatau', 'Panatau,Pănătău', 45.3211300, 26.3944200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115465, 'Panaci', 'Panaci', 'Panaci', 47.2666700, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115466, 'Păltinoasa', 'Paltinoasa', 'Paltinoasa,Păltinoasa', 47.5500000, 25.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115467, 'Păltiniş', 'Paltinis', 'Paltinis,Păltiniş', 48.2166700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115468, 'Păltiniş', 'Paltinis', 'Paltinis,Păltiniş,Valea Boului', 45.4333300, 22.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115469, 'Păltineni', 'Paltineni', '', 45.3959600, 26.3233400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115470, 'Paltin', 'Paltin', 'Paltin,Paltinu,Paltinul', 45.7833300, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115471, 'Paleu', 'Paleu', 'Paleu', 47.1153100, 21.9592900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115472, 'Palazu Mare', 'Palazu Mare', 'Palass-Mare,Palaz Marc,Palaz Mare,Palazu Mare,Palazul-Mare', 44.2290200, 28.6011400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115473, 'Pălatca', 'Palatca', '', 46.8500000, 23.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115474, 'Palanca', 'Palanca', '', 46.5333300, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115475, 'Palanca', 'Palanca', 'Palanca,Palanga', 44.8156200, 26.1999500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115476, 'Palanca', 'Palanca', 'Palanca,Palanga', 44.4757500, 25.7256500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115477, 'Pădureni', 'Padureni', 'Padurenii,Pădurenii,Tigareni,Ţigăreni', 46.5931600, 24.0270000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115478, 'Pădureni', 'Padureni', 'Buhai,Padureni,Pădureni', 47.9743400, 26.3167200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115479, 'Pădureni', 'Padureni', 'Carligatii,Carligatii-Noui,Cirligati,Cârligaţii-Noui,Cîrligaţi,Padureni,Pădureni', 46.6219200, 28.0825800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115480, 'Pădureni', 'Padureni', 'Liget,Lighed,Padureni,Pădureni,Temesliget', 45.6003900, 21.2177300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115481, 'Pădureni', 'Padureni', 'Gascesti,Gasti,Gistesti,Gâşceşti,Gâşti,Gîşteşti,Padureni,Pădureni', 44.3457600, 25.8046900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115482, 'Pădurea Neagră', 'Padurea Neagra', '', 47.1655400, 22.4132300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115483, 'Padina Mică', 'Padina Mica', '', 44.4272200, 22.9925000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115484, 'Padina Matei', 'Padina Matei', 'Padina Matei,Padina Matej', 44.7584300, 21.7506700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115485, 'Padina', 'Padina', '', 44.8333300, 27.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115486, 'Padeş', 'Pades', 'Pades,Padesu,Padesul,Padeş,Padeşu,Padeşul', 45.0166700, 22.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115487, 'Padea', 'Padea', '', 44.0212800, 23.8682700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115488, 'Păcureţi', 'Pacureti', '', 45.1500000, 26.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115489, 'Ozun', 'Ozun', 'Ozun,Uzon', 45.8000000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115490, 'Ovidiu', 'Ovidiu', 'Canara,Kanara,Oridiu,Ovidiu,Овидиу', 44.2666700, 28.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115491, 'Oveselu', 'Oveselu', 'Maciuca,Măciuca,Ovesel,Oveselu', 44.7500000, 24.0166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115492, 'Otopeni', 'Otopeni', 'Opstina Otopeni,Opština Otopeni,Otopen'',Otopeni,Otopeni-de-Sus,Otopenii de Sus,Otopenis,ao tuo pei ni,awtwph,Отопени,Отопень,אוטופן,اوتوپه,奧托佩尼', 44.5500000, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115493, 'Otetelișu', 'Otetelisu', 'Otetelisu,Otetelisul,Otetelişu,Otetelişul', 44.6383900, 23.9591700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115494, 'Oteşani', 'Otesani', 'Otesani,Oteşani', 45.0666700, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115495, 'Oţelu Roşu', 'Otelu Rosu', 'Ferdinand,Gara Ferdinand,Otelu Rosu,Otelul Rosu,Oţelu Roşu,Oţelul Roşu', 45.5333300, 22.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115496, 'Oţeleni', 'Oteleni', 'Oteleni,Oţeleni', 47.0833300, 27.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115497, 'Otelec', 'Otelec', 'Otelec,Otelek,Ótelek', 45.6147800, 20.8495200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115498, 'Ostrovu Mare', 'Ostrovu Mare', 'Ostrovu Mare,Ostrovul-Mare', 44.3793100, 22.5158100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115499, 'Ostrovu', 'Ostrovu', 'Ostrovu,Strambeni,Strimbeni,Strâmbeni,Strîmbeni', 45.2035100, 25.9034500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115500, 'Ostroveni', 'Ostroveni', 'Ostroveni', 43.8000000, 23.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115501, 'Ostrov', 'Ostrov', '', 44.9333300, 28.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115502, 'Ostrov', 'Ostrov', 'Ostrov', 44.1166700, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115503, 'Ostra', 'Ostra', '', 47.4000000, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115504, 'Oșorhei', 'Osorhei', 'Fugyivasarhely,Fugyivásárhely', 47.0333300, 22.0500000, 'RO', '2015-11-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115505, 'Osoi', 'Osoi', 'Osoi,Osoiu', 47.0947900, 27.8009100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115506, 'Osica de Sus', 'Osica de Sus', 'Osica,Osica de Sus', 44.2500000, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115507, 'Osica de Jos', 'Osica de Jos', 'Osica de Jos', 44.2443900, 24.2792600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115508, 'Oşeşti', 'Osesti', 'Fundu Negrei,Negrele,Osesti,Oşeşti,Ruginoa,Ruginoasa', 46.7666700, 27.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115509, 'Osebiți', 'Osebiti', 'Osebiti,Osebiti-Luizi-Calugara,Osebiţi,Osebiţi-Luizi-Călugăra', 46.5383900, 26.8394600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115510, 'Orţişoara', 'Ortisoara', 'Cocota,Kakota,Orczidorf,Orczifalva,Orczydorf,Orczyfalva,Ortisoara,Orzidorf,Orţişoara', 45.9636100, 21.1983300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115511, 'Orşova', 'Orsova', 'Orsava,Orsova,Orşova,Oršava', 44.7252800, 22.3961100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115512, 'Oroftiana', 'Oroftiana', 'Orofreana-de-Sus,Oroftiana,Oroftiana de Sus', 48.1775800, 26.3485600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115513, 'Orodel', 'Orodel', '', 44.2333300, 23.2333300, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115514, 'Ormeniş', 'Ormenis', 'Ormenis,Ormeniş', 46.0166700, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115515, 'Orleşti', 'Orlesti', 'Orlesti,Orlestii de Sus,Orleşti,Orleştii de Sus,Valea Bisericii', 44.8000000, 24.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115516, 'Orlea Nouă', 'Orlea Noua', '', 43.7552200, 24.3583400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115517, 'Orlea', 'Orlea', 'Orlea', 43.7500000, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115518, 'Orlat', 'Orlat', 'Orlat,Orlát', 45.7500000, 23.9666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115519, 'Orevița Mare', 'Orevita Mare', '', 44.4571500, 22.9131700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115520, 'Oreavu', 'Oreavu', 'Daramati,Darimati,Dărâmaţi,Dărîmaţi', 45.3682600, 27.0230100, 'RO', '2015-11-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115521, 'Orbeni', 'Orbeni', 'Orbeni,Orbeni-de-Jos,Orbenii de Jos', 46.2833300, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115522, 'Orbeasca de Sus', 'Orbeasca de Sus', '', 44.1500000, 25.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115523, 'Orbeasca de Jos', 'Orbeasca de Jos', '', 44.1217700, 25.3295200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115524, 'Oraviţa', 'Oravita', 'Oravica,Oravicabanya,Oravicabánya,Oravicsa,Oravicza,Oravita,Oravitza,Oraviţa', 45.0325000, 21.6894400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115525, 'Oraşu Nou', 'Orasu Nou', 'Orasu Nou,Orasul Nou,Oraşu Nou,Oraşul Nou', 47.8333300, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115526, 'Orăştioara de Sus', 'Orastioara de Sus', 'Orastioara de Sus,Orastiora de-Sus,Orăstiora de-Sus,Orăştioara de Sus', 45.7333300, 23.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115527, 'Orăştie', 'Orastie', 'Broos,Orastie,Orehshtie,Orăştie,Орэштие', 45.8333300, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115528, 'Orășeni-Deal', 'Oraseni-Deal', 'Oraseni,Oraseni din Deal,Oraseni-Deal,Orasenii-Deal,Orăşeni,Orăşeni din Deal,Orăşeni-Deal,Orăşenii-Deal', 47.6759700, 26.6767100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115529, 'Orășa', 'Orasa', 'Orasa,Orasa Mare,Orăsa Mare,Orăşa', 46.4222500, 26.7437000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115530, 'Oradea', 'Oradea', 'Gorad Aradzja,Grosswardein,Großwardein,Nagy-Varad,Nagy-Várad,Nagyvarad,Nagyvárad,OMR,Oradae,Oradea,Oradea-Mare,Oradia,Oradja,Oradja khot,Oradä,Orantea,Varadinum,Veliki Varadin,Velky Varadin,Velký Varadín,ao la di ya,awradya,oladea,oradea,oradeas,oradia,orateya,ʼwrʼdyh,Οράντεα,Велики Варадин,Горад Арадзя,Орадя,Орадя хот,אוראדיה,גרויסווארדיין,أوراديا,اورادئا,اورادیا,ஒராதேயா,ორადია,オラデア,奥拉迪亚,오라데아', 47.0458000, 21.9183300, 'RO', '2017-04-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115531, 'Optaşi', 'Optasi', '', 44.5833300, 24.6500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115532, 'Oprişor', 'Oprisor', 'Oprisor,Oprisoru,Oprisorul,Oprişor,Oprişoru,Oprişorul', 44.2833300, 23.0833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115533, 'Oporelu', 'Oporelu', 'Oporelu,Oporelul', 44.6000000, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115534, 'Oniceni', 'Oniceni', '', 47.3244100, 26.4621700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115535, 'Oniceni', 'Oniceni', 'Naimon,Oniceni', 46.8166700, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115536, 'Oneaga', 'Oneaga', '', 47.5762600, 26.7324400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115537, 'Oncești', 'Oncesti', '', 47.8481400, 23.9818300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115538, 'Onceşti', 'Oncesti', 'Oncesti,Oncesti Noui,Oncestii Noi,Onceşti,Onceşti Noui,Onceştii Noi', 46.4666700, 27.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115539, 'Oltina', 'Oltina', 'Oltina,Oluna', 44.1666700, 27.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115540, 'Olteniţa', 'Oltenita', 'Oltenice,Oltenita,Oltenitao,Olteniţa,Олтенице', 44.0833300, 26.6333300, 'RO', '2013-08-30', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115541, 'Olteni', 'Olteni', '', 44.3930700, 25.9502100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115542, 'Olteni', 'Olteni', 'Olteni', 44.1833300, 25.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115543, 'Olteneşti', 'Oltenesti', 'Oltenesti,Olteneşti', 46.5833300, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115544, 'Olteanca', 'Olteanca', 'Olteanca,Olteanca din Deal', 43.8304700, 24.7959700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115545, 'Ologeni', 'Ologeni', '', 44.7337000, 25.9505900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115546, 'Oleșești', 'Olesesti', '', 45.8478100, 27.1009700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115547, 'Olcea', 'Olcea', 'Olcea', 46.6833300, 21.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115548, 'Olari', 'Olari', '', 46.3833300, 21.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115549, 'Olari', 'Olari', 'Olari', 44.7848200, 26.2172800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115550, 'Olari', 'Olari', 'Olari,Vilsanesti,Vîlsăneşti', 44.3078300, 24.2085700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115551, 'Olanu', 'Olanu', '', 44.8666700, 24.3000000, 'RO', '2016-01-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115552, 'Olănești', 'Olanesti', 'Clanest,Claneşt,Olanesti,Olăneşti', 45.1820900, 24.2599000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115553, 'Ojdula', 'Ojdula', 'Ojdula,Oszdola,Ozsdola', 45.9833300, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115554, 'Oituz', 'Oituz', 'Grozesti,Grozeşti,Oituz', 46.2000000, 26.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115555, 'Oinacu', 'Oinacu', 'Oinac,Oinacu,Oinacul', 43.9500000, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115556, 'Ohaba Lungă', 'Ohaba Lunga', 'Hosszuszabadi,Hosszúszabadi,Ohaba Lunga,Ohaba Lungă,Ohabarumunyaszka,Ohábarumunyaszka', 45.9074000, 21.9853500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115557, 'Ohaba', 'Ohaba', 'Ohaba', 46.0666700, 23.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115558, 'Ogrezeni', 'Ogrezeni', 'Ogrezeni', 44.4197200, 25.7683300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115559, 'Ogretin', 'Ogretin', 'Ogretin,Ogretinu', 45.2648300, 26.0916900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115560, 'Ograda', 'Ograda', '', 44.6145700, 27.5704700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115561, 'Ogra', 'Ogra', 'Marosugra,Ogra', 46.4333300, 24.3166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115562, 'Oglinzi', 'Oglinzi', '', 47.2505500, 26.3502600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115563, 'Oeștii Pământeni', 'Oestii Pamanteni', 'Oesti-Paminteni,Oeşti-Pămînteni,Pamanteni,Pământeni', 45.2524100, 24.6565800, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115564, 'Odorheiu Secuiesc', 'Odorheiu Secuiesc', 'Areopolis,Oderhellen,Odorheiu,Odorheiu Secuiesc,Odorheiul Secuiesc,Odorheju Sekujeskas,Odorkheju Sekujesk,Odorkheju-Sekuesk,Odorkheju-Sekujesk,Opstina Odorheiu Secuiesc,Opština Odorheiu Secuiesc,Szekelyudvarhely,Székelyudvarhely,ao duo er hei you-sai ku ye si ke,awdwrhyw skwys,Одорхею Секуйеск,Одорхею-Секуеск,Одорхею-Секуйеск,Одорхею-Секуєск,Одорхеју Секујеск,اودورهیو سکویس,オドルヘユ・セクイエスク,奧多爾黑尤-塞庫耶斯克', 46.3000000, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115565, 'Odoreu', 'Odoreu', 'Odoreu,Odoreul', 47.8000000, 23.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115566, 'Odobești', 'Odobesti', '', 46.6760800, 27.1498300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115567, 'Odobeşti', 'Odobesti', 'Odobesci,Odobeşci', 45.7666700, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115568, 'Odobeşti', 'Odobesti', '', 44.6166700, 25.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115569, 'Odăile', 'Odaile', 'Odaile,Odăile', 45.3833300, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115570, 'Odaia Turcului', 'Odaia Turcului', '', 44.6977700, 25.4508200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115571, 'Odaia Manolache', 'Odaia Manolache', 'Odaia Manolache,Odaia-Manolachi', 45.5489700, 27.9905700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115572, 'Ocoliş', 'Ocolis', 'Ocolis,Ocolisu Mare,Ocolisul,Ocoliş,Ocolişu Mare', 46.4833300, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115573, 'Ocnița', 'Ocnita', '', 46.8626600, 24.4867700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115574, 'Ocniţa', 'Ocnita', '', 44.9833300, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115575, 'Ocna Şugatag', 'Ocna Sugatag', 'Aknasugatag,Ocna Sugatag,Ocna Şugatag', 47.7833300, 23.9333300, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115576, 'Ocna Sibiului', 'Ocna Sibiului', 'Ocna Sibiului,Salzburg,Vizakna,Vízakna', 45.8833300, 24.0500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115577, 'Ocna Mureş', 'Ocna Mures', 'Ocna Mures,Ocna Mureş,Ocna-Muresului,Ocna-Mureşului', 46.3833300, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115578, 'Ocna de Sus', 'Ocna de Sus', 'Felsosofalva,Felsösofalva,Ocna de Sus', 46.5272900, 25.1513100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115579, 'Ocna Dejului', 'Ocna Dejului', 'Desakna,Désakna,Ocna Dej,Ocna Dejului', 47.1158100, 23.8593400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115580, 'Ocna de Jos', 'Ocna de Jos', 'Alsosofalva,Alsòsòfalva,Ocna de Jos', 46.5263500, 25.1294500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115581, 'Ocland', 'Ocland', 'Ocland,Okland,Oklànd', 46.1666700, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115582, 'Ocina de Sus', 'Ocina de Sus', '', 45.2006000, 25.5988200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115583, 'Obrejița', 'Obrejita', 'Obrejita,Obrejiţa', 45.5010200, 27.0897400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115584, 'Obreja', 'Obreja', 'Obreja', 45.4833300, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115585, 'Oboga', 'Oboga', 'Oboga,Oboga de Mijloc', 44.4166700, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115586, 'Obârşia-Cloşani', 'Obarsia-Closani', 'Obarsia-Closani,Obirsia-Closani,Obârşia-Cloşani,Obîrşia-Cloşani', 45.0166700, 22.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115587, 'Obârșia de Câmp', 'Obarsia de Camp', '', 44.1722200, 22.9800000, 'RO', '2015-12-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115588, 'Obârşia', 'Obarsia', 'Obarsia-Veche,Obirsia,Obirsia Veche,Obârşia-Veche,Obîrşia,Obîrşia Veche', 43.8833300, 24.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115589, 'Oarţa de Jos', 'Oarta de Jos', '', 47.4582700, 23.1274200, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115590, 'Oarja Sat', 'Oarja Sat', '', 44.7642900, 24.9714100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115591, 'Oarda', 'Oarda', 'Alsovaradja,Alsóváradja,Oarda de Jos', 46.0333300, 23.5666700, 'RO', '2015-11-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115592, 'Oar', 'Oar', 'Oar,Ovari', 47.8056900, 22.7308500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115593, 'Oanțu', 'Oantu', 'Oantu,Oantul,Oanţu,Oanţul', 46.9097000, 26.1988700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115594, 'Oancea', 'Oancea', 'Oancea', 45.9166700, 28.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115595, 'Nuşfalău', 'Nusfalau', 'Nusfalau,Nuşfalău', 47.2000000, 22.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115596, 'Nuşeni', 'Nuseni', 'Nuseni,Nuşeni', 47.1000000, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115597, 'Nuntași', 'Nuntasi', 'Duingi,Nuntasi,Nuntaşi', 44.5375500, 28.6488000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115598, 'Nufăru', 'Nufaru', 'Ada Marinescu,Domnita Maria,Domniţa Maria', 45.1500000, 28.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115599, 'Nucşoara', 'Nucsoara', '', 45.3333300, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115600, 'Nuci', 'Nuci', 'Nuci', 44.7166700, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115601, 'Nucet', 'Nucet', 'Nucet', 46.4873200, 22.5585000, 'RO', '2015-11-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115602, 'Nucet', 'Nucet', 'Nucet,Nucetu', 44.7833300, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115603, 'Novaci', 'Novaci', '', 45.1833300, 23.6666700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115604, 'Novaci', 'Novaci', '', 44.3010900, 25.9863200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115605, 'Nou', 'Nou', 'Szaszujfalu,Szászújfalu', 45.8333300, 24.2833300, 'RO', '2015-12-29', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115606, 'Noşlac', 'Noslac', 'Noslac,Noşlac', 46.4000000, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115607, 'Nojorid', 'Nojorid', 'Nojorid', 46.9833300, 21.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115608, 'Nocrich', 'Nocrich', 'Gara Petre Luciu,Nocrich,Petre Luciu', 45.9000000, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115609, 'Niţchidorf', 'Nitchidorf', 'Niczkidorf,Niczkydorf,Niczkyfalva,Nitchidorf,Nitzkidorf,Nitzkydorf,Niţchidorf', 45.5833300, 21.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115610, 'Nistru', 'Nistru', 'Miszbanya,Nistru,Nistrul', 47.7208800, 23.4549500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115611, 'Nistoreşti', 'Nistoresti', '', 45.8333300, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115612, 'Nisiporești', 'Nisiporesti', 'Nisiporesti,Nisiporesti-Zapodia,Nisiporeşti,Nisiporeşti-Zăpodia,Nisporesti-Zapodia,Nisporeşti-Zăpodia,Nistoresti,Nistoreşti,Zapodia,Zăpodia', 47.0772000, 26.7379100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115613, 'Nisipari', 'Nisipari', 'Caratai,Caratoi,Nisipari', 44.2596400, 28.3984000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115614, 'Nireș', 'Nires', 'Nires,Nireş,Nyires,Nyíres,Szasznyires,Szásznyíres', 47.1149900, 23.9809200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115615, 'Nimigea de Sus', 'Nimigea de Sus', '', 47.2833300, 24.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115616, 'Nimigea de Jos', 'Nimigea de Jos', '', 47.2535700, 24.3008400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115617, 'Niculiţel', 'Niculitel', 'Monaster,Nicolitel,Nicolitza,Nicoliţel,Niculitel,Niculiţel', 45.1833300, 28.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115618, 'Niculești', 'Niculesti', 'Niculescu,Niculesti,Niculeşti', 44.6826600, 25.9422100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115619, 'Nicşeni', 'Nicseni', '', 47.8666700, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115620, 'Nicoreşti', 'Nicoresti', 'Nicoresti,Nicoreşti,Targul Nicoresti,Targul Nicoreşti', 45.9322300, 27.3086600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115621, 'Nicolești', 'Nicolesti', 'Csikszentmiklos,Csikszentmiklós,Nicolesti,Nicoleşti', 46.4391800, 25.8444600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115622, 'Nicolae Titulescu', 'Nicolae Titulescu', 'Atirnati,Atîrnaţi,Nicolae Titulescu,Titulesti,Tituleşti', 44.3000000, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115623, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bălcescu Nicolae,Nicolae Balcescu,Nicolae Bălcescu,Nicole Balcescu,Nicole Bălcescu,Uriceni', 47.5666400, 26.8962900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115624, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bălcescu Nicolae,Ferdinand,Nicolae Balcescu,Nicolae Bălcescu', 46.4666700, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115625, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bas Chioi,Bălcescu Nicolae,Nicolae Balcescu,Nicolae Bălcescu,Principele-Mihai', 44.9971400, 28.5875700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115626, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bălcescu Nicolae,Nicolae Balcescu,Nicolae Bălcescu,Presna-Gara,Presna-Gară', 44.4500000, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115627, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bălcescu Nicolae,Carol I,Nicolae Balcescu,Nicolae Bălcescu', 44.3833300, 28.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115628, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Elisabeta,Nicolae Balcescu,Nicolae Bălcescu', 44.3742700, 22.8583700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115629, 'Nicolae Bălcescu', 'Nicolae Balcescu', 'Balcescu Nicolae,Bălcescu Nicolae,Carol I,Nicolae Balcescu,Nicolae Balceseu,Nicolae Bălcescu,Nicolae Bălceseu,Podul Lupi', 44.2860400, 27.0787700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115630, 'Neudorf', 'Neudorf', 'Neudorf,Szatulnou,Temesujfalu,Temesújfalu,Ujfalu', 46.0696000, 21.6189900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115631, 'Nereju Mic', 'Nereju Mic', '', 45.7061800, 26.6964100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115632, 'Nereju', 'Nereju', 'Nereju,Nereju-Mare', 45.7166700, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115633, 'Nerău', 'Nerau', 'Dugosello,Dugoselo,Dugoszela,Nerau,Nero,Nerău,Njere,Nyarrev,Nyero,Nyerő,Nyárrév', 45.9692900, 20.5607000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115634, 'Nepos', 'Nepos', '', 47.2775000, 24.5332000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115635, 'Nenciulești', 'Nenciulesti', 'Nencilesti,Nencileşti,Nenciulesti,Nenciuleşti', 44.0348600, 25.2006100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115636, 'Nemțișor', 'Nemtisor', 'Nemtisor,Nemtisoru,Nemţişor,Nemţişoru', 47.2396200, 26.2720900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115637, 'Nehoiu', 'Nehoiu', 'Nehoiu,Nehoiul', 45.4166700, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115638, 'Negru Vodă', 'Negru Voda', 'Caraomer,Negru Voda,Negru Vodă', 43.8166700, 28.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115639, 'Negrilești', 'Negrilesti', '', 47.2706800, 24.0493600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115640, 'Negrilești', 'Negrilesti', 'Negrilesti,Negrilestii,Negrileşti,Negrileştii', 45.9572900, 27.4808500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115641, 'Negrilești', 'Negrilesti', 'Negrilesti,Negrilestii,Negrileşti,Negrileştii', 45.9369700, 26.7063500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115642, 'Negrileasa', 'Negrileasa', '', 47.4234800, 25.8161700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115643, 'Negri', 'Negri', '', 46.7000000, 26.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115644, 'Negreşti-Oaş', 'Negresti-Oas', 'Negresti,Negresti-Oas,Negreşti,Negreşti-Oaş', 47.8666700, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115645, 'Negrești', 'Negresti', 'Negresti,Negreşti', 47.0293800, 26.3795800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115646, 'Negreşti', 'Negresti', 'Negresti,Negresti Targ,Negresti Tirg,Negreşti,Negreşti Târg,Negreşti Tîrg', 46.8333300, 27.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115647, 'Negreni', 'Negreni', 'Negreni', 46.9537800, 22.7634700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115648, 'Negreni', 'Negreni', '', 44.5684800, 24.5953500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115649, 'Negraşi', 'Negrasi', 'Negrasi,Negraşi', 44.6000000, 25.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115650, 'Negostina', 'Negostina', '', 47.9228200, 26.0820900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115651, 'Negomir', 'Negomir', '', 44.8333300, 23.1666700, 'RO', '2015-12-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115652, 'Negoi', 'Negoi', 'Negoiu,Negoiul', 43.9139600, 23.3728800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115653, 'Negoiești', 'Negoiesti', '', 44.8739300, 25.9816000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115654, 'Negoiești', 'Negoiesti', '', 44.5358400, 23.7269000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115655, 'Negoești', 'Negoesti', '', 44.2306500, 26.5015100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115656, 'Nedelea', 'Nedelea', '', 44.9719100, 25.8164700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115657, 'Nedeia', 'Nedeia', '', 43.8499200, 23.7764300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115658, 'Necşeşti', 'Necsesti', 'Necsesti,Necşeşti', 44.2500000, 25.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115659, 'Neaua', 'Neaua', 'Havad,Neaua', 46.4833300, 24.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115660, 'Neagra Șarului', 'Neagra Sarului', 'Neagra Sarului,Neagra Şarului,Sarului', 47.2390700, 25.3292300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115661, 'Nazna', 'Nazna', 'Nasna,Nazna,Naznanfalva,Nàznànfalva', 46.5355200, 24.5021000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115662, 'Năvodari', 'Navodari', 'Caracoim,Caracoium,Karakoium,Navodari,Nehvodari,Năvodari,Нэводари', 44.3166700, 28.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115663, 'Năvodari', 'Navodari', 'Cioara,Navodari,Năvodari', 43.7420800, 25.0941000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115664, 'Năsturelu', 'Nasturelu', 'Nasturelu,Nasturelul,Năsturelu,Năsturelul', 43.6666700, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115665, 'Năsăud', 'Nasaud', 'Nasaud,Naszod,Năsăud', 47.2833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115666, 'Năruja', 'Naruja', 'Naruja,Năruja', 45.8333300, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115667, 'Năpradea', 'Napradea', 'Napradea,Năpradea', 47.3666700, 23.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115668, 'Nanov', 'Nanov', 'Nanov', 44.0000000, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115669, 'Năneşti', 'Nanesti', 'Nanesti,Năneşti', 45.5500000, 27.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115670, 'Nana', 'Nana', '', 44.2666700, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115671, 'Nămoloasa-Sat', 'Namoloasa-Sat', '', 45.5333300, 27.5833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115672, 'Nămoloasa', 'Namoloasa', 'Namoloasa,Namoloasa-Targ,Namoloasa-Tirg,Nămoloasa,Nămoloasa-Târg,Nămoloasa-Tîrg', 45.5361000, 27.5522600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115673, 'Nalbant', 'Nalbant', 'Nalband,Nalbant', 45.0500000, 28.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115674, 'Naipu', 'Naipu', 'Naipu,Naipul', 44.1518700, 25.7617500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115675, 'Naidăș', 'Naidas', 'Naida,Naidas,Naidăş,Najdas,Najdaš', 44.8810800, 21.5906100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115676, 'Năeni', 'Naeni', 'Naeni,Năeni', 45.1000000, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115677, 'Nădrag', 'Nadrag', 'Nadrag,Nădrag', 45.6500000, 22.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115678, 'Nădlac', 'Nadlac', 'Nadlac,Nadlak,Nagylak,Nădlac,Weliky-Lak,Weliký-Lak', 46.1666700, 20.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115679, 'Nadeş', 'Nades', 'Nades,Nadesu-Secuesc,Nadeş,Nadeşu-Secuesc', 46.3166700, 24.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115680, 'Nadăș', 'Nadas', '', 46.2249000, 21.9503600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115681, 'Nadab', 'Nadab', '', 46.4819500, 21.5117800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115682, 'Mușătești', 'Musatesti', '', 45.2165100, 24.7794100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115683, 'Muşeteşti', 'Musetesti', '', 45.1500000, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115684, 'Muşeniţa', 'Musenita', 'Musenita,Muşeniţa', 47.9666700, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115685, 'Murighiol', 'Murighiol', 'Morughiol,Muri Geul,Murighiol,Murughiol', 45.0333300, 29.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115686, 'Murgeşti', 'Murgesti', 'Murgesti,Murgeşti,Murgosti,Murgoşti', 45.4000000, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115687, 'Murgeni', 'Murgeni', 'Murgeni,Murgenii Targ,Murgenii Târg', 46.2044400, 28.0197200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115688, 'Murgași', 'Murgasi', 'Murgasi,Murgasu,Murgaşi,Murgaşu,Murgosul,Murgoşul', 44.4996800, 23.8669800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115689, 'Murfatlar', 'Murfatlar', 'Basarabi,Murfatlar', 44.1833300, 28.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115690, 'Muntenii de Sus', 'Muntenii de Sus', 'Muntenii de Sus', 46.6896800, 27.7776300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115691, 'Muntenii de Jos', 'Muntenii de Jos', 'Muntenii de Jos', 46.6166700, 27.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115692, 'Munteni Buzău', 'Munteni Buzau', 'Munteni Buzau,Munteni Buzău,Muntenii-Buzau,Muntenii-Buzău', 44.6333300, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115693, 'Munteni', 'Munteni', '', 47.3153000, 27.1383900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115694, 'Munteni', 'Munteni', 'Munteni,Muntenii', 45.9333300, 27.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115695, 'Muntele Mic', 'Muntele Mic', '', 45.3833300, 22.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115696, 'Muncelu de Sus', 'Muncelu de Sus', 'Muncelu de Sus,Muncelul-de-Sus', 47.1238400, 26.7351800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115697, 'Mugeni', 'Mugeni', 'Boegoez,Bogoz,Bögöz,Mugeni', 46.2500000, 25.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115698, 'Muereasca', 'Muereasca', 'Muereasca,Muereasca de Jos', 45.1833300, 24.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115699, 'Mozăceni', 'Mozaceni', 'Mozaceni,Mozăceni', 44.5666700, 25.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115700, 'Moviliţa', 'Movilita', '', 45.9500000, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115701, 'Moviliţa', 'Movilita', 'Movilita,Movilita-Noua,Moviliţa,Moviliţa-Nouă', 44.6500000, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115702, 'Movileni', 'Movileni', 'Movileni,Movilenii', 47.3166700, 27.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115703, 'Movileni', 'Movileni', 'Movileni de Sus,Movilenii de Sus', 45.7615400, 27.3718400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115704, 'Movileni', 'Movileni', 'Benga,Movileni,Tampeni,Timpeni,Tîmpeni,Tămpeni', 44.3666700, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115705, 'Movila Miresii', 'Movila Miresii', 'Movila Miresei', 45.2166700, 27.6000000, 'RO', '2015-11-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115706, 'Movila Banului', 'Movila Banului', 'Movila Banului', 44.9833300, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115707, 'Movila', 'Movila', 'Movila,Movila Gildaului,Movila Gîldăului,Vasile Roaita,Vasile Roaită', 44.5500000, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115708, 'Motru', 'Motru', 'Motru', 44.8033300, 22.9719400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115709, 'Motoşeni', 'Motoseni', 'Motoseni,Motoşeni,Ursa,Ursa-Motoseni', 46.3333300, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115710, 'Moţca', 'Motca', 'Motca,Moţca', 47.2500000, 26.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115711, 'Moţăţei', 'Motatei', 'Motate,Motatei,Moţăţe,Moţăţei', 44.0833300, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115712, 'Moțăieni', 'Motaieni', '', 45.1000000, 25.4166700, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115713, 'Moșteni', 'Mosteni', 'Flamanda,Flaminda,Flămânda,Flămînda,Mosteni,Moşteni', 44.1978700, 25.5085400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115714, 'Moşoaia', 'Mosoaia', 'Mosoaia,Mosoala,Moşoaia,Moşoala', 44.8166700, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115715, 'Moşniţa Nouă', 'Mosnita Noua', 'Mosnica,Mosnita Noua,Moşniţa Nouă', 45.7172200, 21.3252800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115716, 'Moșnița Veche', 'Mosnita Veche', 'Besenyo,Besenyő,Mosnicza,Mosnita,Mosnita Veche,Moşniţa,Moşniţa Veche', 45.7354900, 21.3339600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115717, 'Moșneni', 'Mosneni', 'Mosneni,Moşneni,Pervelia', 43.9348700, 28.5313200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115718, 'Moşna', 'Mosna', '', 46.9166700, 27.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115719, 'Moşna', 'Mosna', 'Mojna,Mosna,Moşna', 46.0833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115720, 'Moscu', 'Moscu', 'Moscu,Moscul', 45.9026000, 27.9312000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115721, 'Morunglav', 'Morunglav', 'Morunglav,Morunglavu,Morunglavul', 44.4666700, 24.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115722, 'Morteni', 'Morteni', 'Morteni', 44.6666700, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115723, 'Moroeni', 'Moroeni', 'Moreni,Moroeni,Moroenii,Moroieni', 45.2166700, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115724, 'Moreni', 'Moreni', 'Moreni', 44.9830100, 25.6441500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115725, 'Moraviţa', 'Moravita', 'Moravica,Moravicza,Moravita,Moraviţa,Moravița,Morawitz,Morawitza,Temesmora,Temesmóra', 45.2558300, 21.2702800, 'RO', '2015-04-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115726, 'Morăreşti', 'Moraresti', '', 45.0166700, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115727, 'Monor', 'Monor', 'Monerfalva,Monor,Monorfalva,Mônorfalva', 46.9666700, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115728, 'Moneasa', 'Moneasa', 'Menyhaza,Menyháza,Moneasa,Monyahaza,Monyaháza,Monyasza,Monyásza', 46.4500000, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115729, 'Moldoviţa', 'Moldovita', 'Moldorita Ferast,Moldorita Ferăst,Moldovita,Moldoviţa', 47.6833300, 25.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115730, 'Moldoveni', 'Moldoveni', 'Moldoveni,Porcesti,Porceşti', 46.8333300, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115731, 'Moldoveni', 'Moldoveni', '', 44.7142500, 26.5187900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115732, 'Moldoveni', 'Moldoveni', '', 43.7777200, 24.7280200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115733, 'Moldoveneşti', 'Moldovenesti', 'Moldovenesti,Moldoveneşti,Varfalau,Varfalva,Varfalău,Várfalva', 46.5000000, 23.6500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115734, 'Moldova Suliţa', 'Moldova Sulita', '', 47.6833300, 25.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115735, 'Moldova Nouă', 'Moldova Noua', 'Moldova Noua,Moldova Nouă,Moldova-Noue,Moldova-Noueh,Nova Moldava,Nová Moldava,Opstina Moldova Noua,Opština Moldova Nouã,Ujmoldova,mwldwa nwyh,mwldwfa nwa,xin mo er duo wa,Újmoldova,Молдова-Ноуе,Молдова-Ноуэ,Нова Молдава,مولدوا نوئه,مولدوفا نوا,新摩爾多瓦', 44.7375000, 21.6669400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115736, 'Moișeni', 'Moiseni', '', 47.9279800, 23.4683300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115737, 'Moisei', 'Moisei', 'Majszin,Moiseu,Mojszin,מאסיף', 47.6556200, 24.5401100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115738, 'Moineşti', 'Moinesti', 'Moinesti,Moineşti', 46.4752300, 26.4890700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115739, 'Mogoşoaia', 'Mogosoaia', 'Mogosoaia,Mogoşoaia', 44.5291700, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115740, 'Mogoşeşti-Siret', 'Mogosesti-Siret', 'Mogosesti,Mogosesti-Siret,Mogoşeşti,Mogoşeşti-Siret', 47.1333300, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115741, 'Mogoşeşti', 'Mogosesti', 'Mogosesti,Mogoşeşti', 47.0333300, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115742, 'Mogoşani', 'Mogosani', 'Mogosani,Mogoşani', 44.6833300, 25.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115743, 'Mogoș', 'Mogos', 'Miclesti,Micleşti,Mogos,Mogos Miclesti,Mogos Micleşti,Mogoş', 46.2755400, 23.2803800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115744, 'Moftinu Mic', 'Moftinu Mic', 'Moftinu Mic,Moftinul Mic', 47.6866900, 22.6005400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115745, 'Moftinu Mare', 'Moftinu Mare', 'Moftinu Mare,Moftinul-Mare', 47.6666700, 22.6666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115746, 'Mofleni', 'Mofleni', '', 44.3022000, 23.7584800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115747, 'Moeciu de Jos', 'Moeciu de Jos', 'Al Moecs,Alsomoecs,Alsómoécs,Moeciu de Jos,Moeciul-de Jos', 45.4833300, 25.3166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115748, 'Modelu', 'Modelu', 'Model,Modelu,Sat Model,Satu-Model', 44.1957400, 27.3872000, 'RO', '2012-06-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115749, 'Mociu', 'Mociu', 'Mociu,Mociul', 46.8000000, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115750, 'Moceşti', 'Mocesti', 'Mocesti,Mocestii,Moceşti', 45.0500000, 26.2500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115751, 'Moara Vlăsiei', 'Moara Vlasiei', 'Moara Saraca,Moara Săracă,Moara Vlasiei,Moara Vlăsiei', 44.6409000, 26.2061600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115752, 'Moara Nica', 'Moara Nica', 'Moara Nica,Mora Nichi', 47.6008600, 26.2226200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115753, 'Moara Grecilor', 'Moara Grecilor', '', 46.6714500, 27.7456900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115754, 'Moara Domnească', 'Moara Domneasca', '', 46.7144800, 27.7589000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115755, 'Moara Carp', 'Moara Carp', '', 47.5666700, 26.2333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115756, 'Moacşa', 'Moacsa', 'Maksa,Moacsa,Moacşa', 45.8666700, 25.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115757, 'Mlenăuți', 'Mlenauti', '', 48.1266300, 26.4896100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115758, 'Mizil', 'Mizil', 'Mizil,Mizilue,Opstina Mizil,Opština Mizil,mi ji er,myzyl,Мизил,Мізіл,میزیل,米濟爾', 45.0166700, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115759, 'Mitrofani', 'Mitrofani', 'Milrofa,Mitrofani', 44.7326800, 24.2091000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115760, 'Mitreni', 'Mitreni', 'Mitreni', 44.1666700, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115761, 'Mitocu Dragomirnei', 'Mitocu Dragomirnei', 'Mitocu Dragomirnei,Mitocul-Dragomirnei', 47.7333300, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115762, 'Mitoc', 'Mitoc', '', 48.1000000, 27.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115763, 'Mislea', 'Mislea', '', 45.0966800, 25.8244400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115764, 'Misentea', 'Misentea', 'Csik Mindszent,Mindszent,Misentea', 46.3271400, 25.8950600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115765, 'Mischii', 'Mischii', 'Mischii', 44.3833300, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115766, 'Mișca', 'Misca', '', 47.2629100, 22.2591400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115767, 'Mișca', 'Misca', 'Misca,Mişca', 46.6028000, 21.5999800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115768, 'Mâsca', 'Masca', 'Masca,Misca,Mâsca,Mîsca', 46.3000000, 21.6833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115769, 'Mârzăneşti', 'Marzanesti', 'Marzanesti,Mirzanesti,Mârzăneşti,Mîrzăneşti', 43.9333300, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115770, 'Mârţeşti', 'Martesti', 'Mirtesti,Mirtesti-Moraresti,Mîrţeşti,Mîrţeşti-Morăreşti', 44.7166700, 24.7500000, 'RO', '2012-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115771, 'Mirşid', 'Mirsid', 'Mirsid,Mirşid', 47.2333300, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115772, 'Mârşani', 'Marsani', 'Marsani,Mirsani,Mârşani,Mîrşani', 44.0166700, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115773, 'Mârşa', 'Marsa', 'Marsa,Mirsa,Mârşa,Mîrşa', 44.3741700, 25.5569400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115774, 'Miroslovești', 'Miroslovesti', '', 47.1500000, 26.6500000, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115775, 'Miroslăvești', 'Miroslavesti', 'Miroslavesti,Miroslăveşti,Puchenii-Miroslavesti,Puchenii-Miroslăvesti,Puchienii-Miroslavesti,Puchienii-Miroslăveşti', 44.8038300, 26.0868900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115776, 'Miroslava', 'Miroslava', 'Miroslava', 47.1500000, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115777, 'Miroşi', 'Mirosi', '', 44.4166700, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115778, 'Mironeasa', 'Mironeasa', 'Brusturet,Brustureţ,Frunzisul,Frunzişul,La Lingurari,Lingurari,Mironeasa', 46.9666700, 27.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115779, 'Miron Costin', 'Miron Costin', '', 46.9203000, 26.8056700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115780, 'Mironu', 'Mironu', '', 47.4879900, 26.0095200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115781, 'Mireşu Mare', 'Miresu Mare', 'Miresu Mare,Miresul-Mare,Mireşu Mare,Mireşul-Mare,Nagy-Nyires,Nagy-Nyíres,Nagynyires,Nagynyíres', 47.5000000, 23.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115782, 'Mireșu Mare', 'Miresu Mare', '', 45.1350800, 26.3771400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115783, 'Mirceștii Noi', 'Mircestii Noi', 'Mircesti Noi,Mircestii Noi,Mircestii-Noui,Mirceştii Noi,Mirceştii-Noui', 45.7507200, 27.2726000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115784, 'Mirceşti', 'Mircesti', 'Mircesti,Mirceşti', 47.0833300, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115785, 'Călăraşi', 'Calarasi', 'Mircea Voda,Mircea Vodă,Miroea Voda,Miroea Vodă', 44.2051000, 27.3135600, 'RO', '2013-07-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115786, 'Mircea Vodă', 'Mircea Voda', '', 45.1166700, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115787, 'Mircea Vodă', 'Mircea Voda', 'Celebichioi,Celibichioi,Mircea Voda,Mircea Vodă', 44.2833300, 28.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115788, 'Mirăslău', 'Miraslau', 'Miraslau,Mirislau,Mirislaul,Mirislău,Mirislăul,Mirăslău', 46.3666700, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115789, 'Miorcani', 'Miorcani', '', 48.2022300, 26.8527900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115790, 'Mânzăleşti', 'Manzalesti', 'Manzalesti,Manzalestii,Minzalesti,Mânzăleşti,Mânzăleştii,Mînzăleşti', 45.5000000, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115791, 'Mintiu Gherlii', 'Mintiu Gherlii', 'Mintiu Gherlii,Mintiul-Gherlei', 47.0500000, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115792, 'Minieri', 'Minieri', 'Minieri,Orasu Nou,Oraşu Nou', 44.9837200, 25.7608300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115793, 'Mineri', 'Mineri', 'Casla,Cisla,Câşla,Cîşla,Kishla,Mineri', 45.1647200, 28.7157300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115794, 'Mândruloc', 'Mandruloc', 'Mandruloc,Mindruloc,Monderlak,Mondorlak,Mândruloc,Mîndruloc,Szeplak,Széplak', 46.1486300, 21.4657000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115795, 'Mândrești', 'Mandresti', 'Mindresti,Mîndreşti', 47.7333300, 26.4833300, 'RO', '2015-11-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115796, 'Mândrești', 'Mandresti', 'Mindresti,Mîndreşti', 45.8833300, 27.7000000, 'RO', '2015-11-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115797, 'Mândra', 'Mandra', 'Mandra,Mindra,Mândra,Mîndra', 45.8166700, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115798, 'Mânău', 'Manau', 'Manau,Minau,Mânău,Mînău', 47.4817900, 23.2624700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115799, 'Mânăstireni', 'Manastireni', 'Manastireni,Minastireni,Mânăstireni,Mînăstireni', 46.7666700, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115800, 'Mănăstirea Humorului', 'Manastirea Humorului', 'Manastirea Homorului,Manastirea-Humorului,Minastirea Humorului,Mânăstirea Homorului,Mânăstirea-Humorului,Mînăstirea Humorului', 47.6000000, 25.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115801, 'Mânăstirea Caşin', 'Manastirea Casin', 'Desrobitii-Minastirea,Desrobiţii-Mînăstirea,Manastirea Casin,Manastirea Casinu,Manastirea Caşinu,Minastirea Casin,Mânăstirea Caşin,Mînăstirea Caşin', 46.1500000, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115802, 'Mănăstirea', 'Manastirea', 'Manastirea,Minastirea,Mânăstirea,Mînăstirea', 46.9500000, 27.2000000, 'RO', '2015-11-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115803, 'Mânăstirea', 'Manastirea', 'Manastirea,Minastirea,Mânăstirea,Mînăstirea', 44.2166700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115804, 'Miloşeşti', 'Milosesti', '', 44.7333300, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115805, 'Milişăuţi', 'Milisauti', 'Milesauti,Milesăuţi,Milisauti,Milişăuţi', 47.7833300, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115806, 'Mileanca', 'Mileanca', '', 48.0833300, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115807, 'Milcovul', 'Milcovul', 'Milcovul,Risipiti,Risipiţi', 45.6500000, 27.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115808, 'Milcovățu', 'Milcovatu', 'Milcovatu,Milcovăţu,Rusii lui Asan,Ruşii lui Asan', 44.2657000, 25.6988200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115809, 'Milcoiu', 'Milcoiu', 'Milcoiu,Milcoiul', 45.0500000, 24.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115810, 'Milaş', 'Milas', 'Milas,Milaş', 46.8166700, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115811, 'Mijlocenii Bârgăului', 'Mijlocenii Bargaului', 'Mijlocenii Bargaului,Mijlocenii Birgaului,Mijlocenii Bârgăului,Mijlocenii Bîrgăului', 47.2159200, 24.6893600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115812, 'Mija', 'Mija', '', 44.9135600, 25.6758500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115813, 'Mihoveni', 'Mihoveni', '', 47.6799400, 26.1822000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115814, 'Miheşu de Câmpie', 'Mihesu de Campie', 'Mihasul-de-Campie,Mihesu de Cimpie,Mihesul de Campie,Miheşu de Cîmpie,Miheşul de Câmpie,Mihăşul-de-Câmpie', 46.6833300, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115815, 'Mihalţ', 'Mihalt', 'Mihalt,Mihalţ', 46.1500000, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115816, 'Mihălceni', 'Mihalceni', 'Mihaileni,Mihalceni,Mihăileni,Mihălceni', 45.4449300, 27.3046600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115817, 'Mihălăşeni', 'Mihalaseni', 'Mihalasceni,Mihalaseni,Mihalasenii,Mihălăşceni,Mihălăşeni,Mihălăşenii', 47.8833300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115818, 'Mihai Vodă', 'Mihai Voda', 'Mihai Voda,Mihai Vodă,Mihai-Voda-Tigania,Mihai-Vodă-Tigania,Tigania,Ţigănia', 44.4391600, 25.8195700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115819, 'Mihai Viteazu', 'Mihai Viteazu', 'Alsoszentmihalyfalva,Alsószentmihályfalva,Mihai Viteazu,Mihai-Viteazul,Mihaiu Viteazul,Szentmihaly,Szentmihály', 46.5333300, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115820, 'Mihai Viteazu', 'Mihai Viteazu', 'Mihai Viteazu,Mihai-Viteazul,Mihaiu Viteazul', 44.6333300, 28.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115821, 'Mihai Viteazu', 'Mihai Viteazu', 'Mihai Viteazu,Mihai-Viteazul', 44.3486400, 27.0736100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115822, 'Mihail Kogălniceanu', 'Mihail Kogalniceanu', 'Cogalniceanu,Cogălniceanu,Mihail Kogalniceanu,Mihail Kogălniceanu,Mihail-Cogalniceanu,Mihail-Cogălniceanu', 45.0333300, 28.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115823, 'Mihail Kogălniceanu', 'Mihail Kogalniceanu', 'Cogalniceanu,Cogălniceanu,Mihail Kogalniceanu,Mihail Kogălniceanu,Mihail-Cogalniceanu,Mihail-Cogălniceanu', 44.6833300, 27.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115824, 'Mihail Kogălniceanu', 'Mihail Kogalniceanu', 'Bulgarien,CND,Caramurat,Cogalniceanu,Cogălniceanu,Ferdinand I,Ferdinandi,Karamurat,Kogalniceanu,Mihail Cogalniceanu,Mihail Cogălniceanu,Mihail Kogalniceanu,Mihail Kogălniceanu,Mikhail-Kogelnichanu', 44.3679800, 28.4600000, 'RO', '2013-11-28', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115825, 'Mihăileşti', 'Mihailesti', 'Mihailesti,Mihăileşti', 44.9166700, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115826, 'Mihăileşti', 'Mihailesti', 'Mihailesti,Mihailestii de Sus,Mihăileşti,Mihăileştii de Sus', 44.3266700, 25.9083300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115827, 'Mihăileni', 'Mihaileni', '', 47.9666700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115828, 'Mihăileni', 'Mihaileni', 'Csikszentmihaly,Csikszentmihály,Mihaileni,Mihăileni', 46.4666700, 25.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115829, 'Mihăileni', 'Mihaileni', 'Mihaileni,Mihăileni,Saldorf,Şaldorf', 45.9833300, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115830, 'Mihai Bravu', 'Mihai Bravu', '', 47.2578000, 21.9381100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115831, 'Mihai Bravu', 'Mihai Bravu', 'Camber,Mihai Bravu,Mihai-Bravul', 44.9500000, 28.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115832, 'Mihai Bravu', 'Mihai Bravu', 'Mihai Bravu,Mihai-Bravul', 44.7846900, 27.7214400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115833, 'Mihai Bravu', 'Mihai Bravu', 'Mihai Bravu,Mihai Bravul', 44.1405600, 26.0627800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115834, 'Mihăiești', 'Mihaiesti', '', 47.5156300, 26.2173400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115835, 'Mihăeşti', 'Mihaesti', '', 45.1166700, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115836, 'Mihăeşti', 'Mihaesti', 'Mihaesti,Mihăeşti', 45.0333300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115837, 'Mihăeşti', 'Mihaesti', 'Mihaesti,Mihaesti-de-Sus,Mihaestii-de Sus,Mihăeşti,Mihăeşti-de-Sus,Mihăeştii-de Sus', 44.1333300, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115838, 'Miercurea Sibiului', 'Miercurea Sibiului', 'Mercurea,Mercurea-Sibiului,Miercurea,Miercurea Sibiului', 45.8833300, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115839, 'Miercurea Nirajului', 'Miercurea Nirajului', 'Mercurea Nirajului,Miercurea Nirajului,Miereurea Nirajului,Nyaradszereda,Nyàràdszereda', 46.5333300, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115840, 'Miercurea-Ciuc', 'Miercurea-Ciuc', 'Csikszereda,Csíkszereda,Mercurea Ciuc,Merkurja-Chuk,Miercurea Ciuc,Miercurea-Ciuc,Miercurea-Ciucului,Меркуря-Чук', 46.3500000, 25.8000000, 'RO', '2013-05-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115841, 'Micula', 'Micula', 'Micula,Micula Colonia', 47.9000000, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115842, 'Micleşti', 'Miclesti', 'Miclesti,Micleşti', 46.8166700, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115843, 'Micfalău', 'Micfalau', 'Micfalau,Micfalău,Mikos Ujfalu,Mikoujfalu,Mikôujfalù', 46.0534200, 25.8373700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115844, 'Miceştii de Câmpie', 'Micestii de Campie', 'Micestii de Cimpie,Micestii-de-Campie,Miceştii de Cîmpie,Miceştii-de-Câmpie', 46.8666700, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115845, 'Micești', 'Micesti', '', 46.1014100, 23.5557300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115846, 'Miceşti', 'Micesti', '', 44.9500000, 24.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115847, 'Micăsasa', 'Micasasa', 'Micasasa,Micăsasa', 46.0833300, 24.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115848, 'Mica', 'Mica', 'Mica', 47.1333300, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115849, 'Mica', 'Mica', '', 46.3666700, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115850, 'Meziad', 'Meziad', '', 46.7409000, 22.4284600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115851, 'Meteş', 'Metes', 'Metes,Meteş', 46.1000000, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115852, 'Meseşenii de Jos', 'Mesesenii de Jos', 'Catalusa,Catelusa,Catelusul,Căţeluşa,Căţeluşul,Căţăluşa,Mesesenii de Jos,Meseşenii de Jos', 47.1500000, 22.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115853, 'Merişani', 'Merisani', 'Merisani,Merisanii,Merişani,Merişanii', 44.9682000, 24.7432700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115854, 'Merișani', 'Merisani', '', 44.2519000, 24.8755000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115855, 'Merișani', 'Merisani', 'Calugarita,Călugăriţa,Merisani,Merişani', 44.1166900, 25.3998000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115856, 'Merii Petchii', 'Merii Petchii', 'Merii Petchii,Merii-Petchi', 44.7353200, 26.3005400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115857, 'Meri', 'Meri', 'Meri,Merii', 44.8336600, 26.3086300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115858, 'Merghindeal', 'Merghindeal', 'Merghindeal', 45.9666700, 24.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115859, 'Mereşti', 'Meresti', 'Homorodalmas,Homoròdalmàs,Homotodalmas,Homotödalmas,Meresti,Mereşti', 46.2333300, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115860, 'Merenii de Sus', 'Merenii de Sus', 'Mereni-de-Sus,Merenii de Sus', 44.2283900, 25.6210300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115861, 'Merenii de Jos', 'Merenii de Jos', 'Mereni-de-Jos,Merenii de Jos', 44.2321400, 25.6434600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115862, 'Mereni', 'Mereni', 'Almas,Almàs,Kezdi Almas,Kézdi Almas,Mereni', 46.0792400, 26.2359700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115863, 'Mereni', 'Mereni', 'Enghe-Mahale,Engimahale,Mereni', 44.0500000, 28.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115864, 'Merei', 'Merei', 'Merei', 45.1333300, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115865, 'Mera', 'Mera', '', 46.8152500, 23.4540500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115866, 'Mera', 'Mera', 'Miera', 45.7666700, 26.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115867, 'Melineşti', 'Melinesti', 'Melinesti,Melineşti', 44.5666700, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115868, 'Mehadica', 'Mehadica', 'Mehadica', 45.0333300, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115869, 'Mehadia', 'Mehadia', 'Mebadia,Mehadia,Mehadija,Mehádia,mhadyh,مهادیه', 44.9008300, 22.3669400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115870, 'Medieşu Aurit', 'Mediesu Aurit', 'Mediesu Aurit,Mediesul-Aurit,Medieşu Aurit,Medieşul-Aurit', 47.7833300, 23.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115871, 'Mediaş', 'Medias', 'Aranyosmeggyes,Medgyes,Medias,Mediasch,Mediaş,Mediaș,Medivisch', 46.1666700, 24.3500000, 'RO', '2014-04-22', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115872, 'Medgidia', 'Medgidia', 'Mecidiye,Medgidia,Medjidia,Medzhidija,Medzidija,Medžidija,Opstina Medgidia,Opština Medgidia,mdjyja,medeujidia,mei ji di ya,mjydyh,mjydyt,Меджидия,Меджидія,Меџидија,Меҷидия,Мәҗидия,مجيدية,مجیدیه,مدجیجا,梅吉迪亞,메드지디아', 44.2500000, 28.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115873, 'Măzănăești', 'Mazanaesti', '', 47.5279500, 26.0840100, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115874, 'Maxut', 'Maxut', '', 47.4404000, 26.8920400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115875, 'Măxineni', 'Maxineni', 'Maxineni,Măxineni', 45.4000000, 27.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115876, 'Maxenu', 'Maxenu', 'Maxenu,Maxenul', 45.0516200, 26.8549800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115877, 'Mavrodin', 'Mavrodin', '', 44.6491900, 25.7173100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115878, 'Mavrodin', 'Mavrodin', 'Mavrodin,Mavrodinu', 44.0333300, 25.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115879, 'Măureni', 'Maureni', 'Maureni,Moricfeld,Moricfold,Moriczfold,Moritfeld,Moritzfeld,Moriţfeld,Móricföld,Móriczföld,Măureni', 45.4038900, 21.5025000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115880, 'Mătești', 'Matesti', '', 45.2133900, 26.7560700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115881, 'Matei', 'Matei', 'Matei,Mateiu', 46.9833300, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115882, 'Mateeşti', 'Mateesti', 'Mateesti,Mateeşti', 45.0666700, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115883, 'Matca', 'Matca', '', 45.8500000, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115884, 'Mățău', 'Matau', '', 45.2356500, 25.0828600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115885, 'Mătăsaru', 'Matasaru', 'Matasaru,Matasarul,Mătăsaru,Mătăsarul', 44.7166700, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115886, 'Mătăsari', 'Matasari', 'Matasari,Mătăsari', 44.8500000, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115887, 'Mătăcina', 'Matacina', '', 45.8833300, 26.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115888, 'Măstăcani', 'Mastacani', 'Mastacani,Măstăcani', 45.7833300, 28.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115889, 'Mastacăn', 'Mastacan', 'Mastacan,Mastacanul,Mastacăn,Măstacănul', 46.7891800, 26.4867700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115890, 'Maşloc', 'Masloc', 'Blumental,Macsalaka,Maslak,Masloc,Maslok,Maşloc,Mácsalaka,Máslak,Máslok', 45.9980600, 21.4497200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115891, 'Mărunțișu', 'Maruntisu', 'Maruntis,Maruntisu,Măruntiş,Mărunţişu', 45.2861000, 26.3542100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115892, 'Mărunţei', 'Maruntei', '', 44.2000000, 24.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115893, 'Măru', 'Maru', 'Maru,Marul,Măru,Mărul', 45.4758600, 22.4503900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115894, 'Mărtiniş', 'Martinis', 'Homorodszentmarton,Homoródszentmàrton,Martinis,Mărtiniş', 46.2333300, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115895, 'Mărtineşti', 'Martinesti', 'Martinesti,Mărtineşti', 45.8166700, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115896, 'Marpod', 'Marpod', 'Marpod', 45.8666700, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115897, 'Măriței', 'Maritei', 'Maratei,Maritei,Măriţei,Mărăţei', 47.7527000, 26.1462600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115898, 'Mărişelu', 'Mariselu', 'Mariselu,Mariselul,Mărişelu,Mărişelul', 47.0166700, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115899, 'Mărişel', 'Marisel', 'Marisel,Mariselu,Mariselul,Mărişel,Mărişelu,Mărişelul', 46.6500000, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115900, 'Marin', 'Marin', '', 47.1275400, 22.8105500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115901, 'Mărgineni Slobozia', 'Margineni Slobozia', '', 44.5312100, 24.5567500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115902, 'Mărgineni-Munteni', 'Margineni-Munteni', '', 46.6000000, 26.9000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115903, 'Mărginenii de Sus', 'Marginenii de Sus', 'Margineni-de-Sus,Marginenii de Sus,Mărgineni-de-Sus,Mărginenii de Sus', 44.9317200, 25.7522800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115904, 'Mărginenii de Jos', 'Marginenii de Jos', '', 44.9591000, 25.7598900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115905, 'Mărgineni', 'Margineni', '', 46.9000000, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115906, 'Mărgineni', 'Margineni', 'Margineni,Margineni-Razesi,Margineni-Ungureni,Mărgineni,Mărgineni-Răzeşi,Mărgineni-Ungureni', 46.5876000, 26.8509500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115907, 'Marginea', 'Marginea', 'Marginea', 47.8166700, 25.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115908, 'Margina', 'Margina', '', 45.8500000, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115909, 'Marghita', 'Marghita', 'Margita,Margitta,Opstina Marghita,Opština Marghita,ma er ji ta,marugita,mrgyth,Маргита,Маргіта,מארגארעטין,מרגיטה,مرگیته,マルギタ,馬爾吉塔', 47.3500000, 22.3333300, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115910, 'Mărgău', 'Margau', 'Margau,Mărgău', 46.7500000, 22.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115911, 'Mărgăriteşti', 'Margaritesti', 'Lac,Margaritesti,Mărgăriteşti,Popescari', 45.4333300, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115912, 'Marga', 'Marga', 'Marga', 45.5000000, 22.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115913, 'Mareș', 'Mares', '', 44.7782400, 24.7900500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115914, 'Mărculești', 'Marculesti', '', 44.5669800, 27.5156200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115915, 'Mărcești', 'Marcesti', '', 44.8053700, 25.7095100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115916, 'Marca', 'Marca', 'Marca', 47.2166700, 22.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115917, 'Măraşu', 'Marasu', 'Marasu,Marasul,Măraşu,Măraşul', 44.8500000, 27.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115918, 'Mărășești', 'Marasesti', 'Marasheshty', 45.8833300, 27.2333300, 'RO', '2016-01-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115919, 'Mărăcineni', 'Maracineni', 'Maracineni,Mărăcineni', 45.2000000, 26.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115920, 'Mărăcineni', 'Maracineni', '', 44.9000000, 24.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115921, 'Mara', 'Mara', 'Cracesti,Craceşti,Mara', 47.7555200, 23.8312600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115922, 'Manoleasa', 'Manoleasa', 'Manoleasa,Manoleasa-Volovat,Manoleasa-Volovăţ', 47.9833300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115923, 'Mangalia', 'Mangalia', 'Callatis,Mangalia,Mangalija,Mangalla,Mankalya,Opstina Mangalia,Opština Mangalia,man jia li ya,mangalia,mangallia,manghalaya,manjalya,mnglya,Мангалия,Мангалија,Мангалія,مانجاليا,مانغالايا,منگلیا,მანგალია,曼加利亞,만갈리아', 43.8000000, 28.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115924, 'Măneşti', 'Manesti', 'Manesti,Manestii,Măneşti,Măneştii', 44.9666700, 25.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115925, 'Măneşti', 'Manesti', 'Manesti,Măneşti', 44.8666700, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115926, 'Măneciu-Ungureni', 'Maneciu-Ungureni', 'Maneciu,Maneciul-Ungureni,Mineciu,Mineciu-Ungureni,Mîneciu-Ungureni,Măneciu,Măneciul-Ungureni', 45.3166700, 25.9833300, 'RO', '2015-11-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115927, 'Mănăștur', 'Manastur', 'Manastur,Manester,Monostor,Mănăştur', 46.0094900, 21.1336200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115928, 'Mănăştiur', 'Manastiur', 'Manastiur,Mănăştiur', 45.8166700, 22.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115929, 'Manasia', 'Manasia', 'Manasia', 44.7000000, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115930, 'Mănăilești', 'Manailesti', '', 45.0246400, 24.1245100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115931, 'Mamaia-Sat', 'Mamaia-Sat', 'Mamaja,Мамая', 44.3115900, 28.6254600, 'RO', '2015-11-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115932, 'Măluşteni', 'Malusteni', 'Malusteni,Măluşteni', 46.1833300, 27.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115933, 'Malu Spart', 'Malu Spart', 'Malu Spart,Malul-Spart', 44.4439100, 25.7175800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115934, 'Malu Roșu', 'Malu Rosu', 'Malu Rosu,Malu Roşu,Radulesti,Răduleşti', 44.7808800, 26.5794500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115935, 'Mălureni', 'Malureni', '', 45.1000000, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115936, 'Malu Mare', 'Malu Mare', 'Malu Mare,Malul Mare', 44.2418200, 23.8532100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115937, 'Malu cu Flori', 'Malu cu Flori', 'Malu cu Flori,Malul cu Flori', 45.1500000, 25.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115938, 'Malu', 'Malu', 'Malu,Malul', 43.8151800, 25.8186300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115939, 'Malovăţ', 'Malovat', 'Malovacu,Malovat,Malovatu,Malovăţ,Malovăţu', 44.7044400, 22.7311100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115940, 'Malnaş', 'Malnas', 'Malnas,Malnaş', 46.0166700, 25.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115941, 'Mălini', 'Malini', 'Malini,Mălini', 47.4666700, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115942, 'Mălâncrav', 'Malancrav', 'Malancrav,Malincrav,Mălîncrav,Mălăncrav', 46.1100300, 24.6481000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115943, 'Măldăreşti', 'Maldaresti', 'Maldaresti,Maldarestii de Sus,Măldăreşti,Măldăreştii de Sus', 45.1166700, 24.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115944, 'Măldăeni', 'Maldaeni', 'Maldaeni,Măldăeni', 44.1166700, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115945, 'Malcoci', 'Malcoci', '', 45.1385100, 28.8882400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115946, 'Malaia', 'Malaia', 'Malaia', 45.3500000, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115947, 'Mal', 'Mal', '', 47.0697900, 22.8144100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115948, 'Mailat', 'Mailat', 'Mailat,Majlat,Majlatfalva,Majlathfalva,Majlát,Majlátfalva,Majláthfalva', 46.0418900, 21.1070200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115949, 'Măieruş', 'Maierus', 'Maierus,Măieruş', 45.9000000, 25.5333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115950, 'Măieru', 'Maieru', 'Maier,Maieru,Major,Măieru', 47.4000000, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115951, 'Măicăneşti', 'Maicanesti', 'Bolboaca,Maicanesti,Maicanesti-Bolboaca,Măicăneşti,Măicăneşti-Bolboaca', 45.5000000, 27.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115952, 'Maia', 'Maia', '', 44.7361600, 26.4015100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115953, 'Mahmudia', 'Mahmudia', 'Mahmudia,Mahmudie,Mahmudla', 45.0833300, 29.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115954, 'Măguri-Răcătău', 'Maguri-Racatau', 'Maguri-Racatau,Măguri-Răcătău', 46.6450000, 23.1970000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115955, 'Măguri', 'Maguri', 'Maguri,Măguri,Racatau-Maguri,Răcătău-Măguri', 46.6284900, 23.1029400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115956, 'Măgureni', 'Magureni', 'Magureni,Măgureni', 45.0666700, 25.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115957, 'Măgurele', 'Magurele', 'Magurele,Magurelele,Măgurele,Măgurelele', 45.1000000, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115958, 'Măgurele', 'Magurele', 'Magurele,Magurelele,Măgurele,Măgurelele,Otelelesanii', 44.3500000, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115959, 'Măgura Ilvei', 'Magura Ilvei', 'Magura Ilvei,Măgura Ilvei', 47.3833300, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115960, 'Măgura', 'Magura', '', 46.5666700, 26.8500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115961, 'Măgura', 'Magura', 'Calugara Mare,Călugăra Mare,Magura,Măgura', 46.5619600, 26.8593200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115962, 'Măgura', 'Magura', 'Magura,Măgura', 45.2666700, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115963, 'Măgura', 'Magura', 'Magura,Magura-Laceanca,Măgura,Măgura-Lăceanca', 44.0333300, 25.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115964, 'Magula', 'Magula', 'Bagula,Magula', 44.9318500, 26.3011400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115965, 'Maglavit', 'Maglavit', 'Maglavit,Maglavitu,Maglavitul', 44.0333300, 23.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115966, 'Măgireşti', 'Magiresti', 'Magiresti,Măgireşti', 46.5166700, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115967, 'Măgherani', 'Magherani', 'Magherani,Măgherani,Nyaradmogyoros,Nyàràdmogyoròs', 46.5666700, 24.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115968, 'Măgeşti', 'Magesti', 'Magesti,Măgeşti', 47.0166700, 22.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115969, 'Mogești', 'Mogesti', '', 45.1166700, 23.9166700, 'RO', '2016-01-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115970, 'Măerişte', 'Maeriste', 'Maeriste,Maieriste,Măerişte,Măierişte', 47.3166700, 22.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115971, 'Mădulari', 'Madulari', 'Madulari,Madulari-Cernisoara,Madularii-Cernisoara,Mădulari,Mădulari-Cernişoara,Mădularii-Cernişoara', 45.0333300, 24.0000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115972, 'Mădârjac', 'Madarjac', 'Frumusele,Frumuselele,Frumuselile-Popesti,Frumuşele,Frumuşelele,Frumuşelile-Popeşti,Madarjac,Madirjac,Mădârjac,Mădîrjac', 47.0499400, 27.2618200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115973, 'Măderat', 'Maderat', '', 46.2949300, 21.7113700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115974, 'Mădăras', 'Madaras', '', 47.6840300, 22.8655400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115975, 'Mădăraş', 'Madaras', 'Madaras,Mădăraş', 46.8333300, 21.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115976, 'Mădăraș', 'Madaras', 'Madaras,Madarasul,Madarasul-de Camp,Mezomadaras,Mezömadaras,Mădăraş,Mădăraşul,Mădăraşul-de Câmp', 46.6048800, 24.4344600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115977, 'Mădăraș', 'Madaras', 'Madaras,Mădăraş', 46.4947200, 25.7475000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115978, 'Măcin', 'Macin', 'Macin,Maçin,Măcin,machyn,ماچین', 45.2437100, 28.1356400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115979, 'Măceşu de Sus', 'Macesu de Sus', 'Macesiu-de-Sus,Macesu de Sus,Macesul-de-Sus,Măceşiu-de-Sus,Măceşu de Sus,Măceşul-de-Sus', 43.9166700, 23.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115980, 'Măceşu de Jos', 'Macesu de Jos', 'Macesiu-de-Jos,Macesu de Jos,Macesul-de-Jos,Măceşiu-de-Jos,Măceşu de Jos,Măceşul-de-Jos', 43.8833300, 23.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115981, 'Macea', 'Macea', 'Macea', 46.3833300, 21.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115982, 'Lupşanu', 'Lupsanu', 'Lupsanu,Lupsanul,Lupşanu,Lupşanul', 44.3833300, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115983, 'Lupşa', 'Lupsa', 'Lupsa,Lupşa', 46.3666700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115984, 'Lupeni', 'Lupeni', 'Farkaslaka,Farkaslaxa,Lupeni,Лупени', 46.3833300, 25.2166700, 'RO', '2017-05-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115985, 'Lupeni', 'Lupeni', 'Luoeni,Lupeni,Lupeny,Lupény,Лупени', 45.3602900, 23.2383200, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115986, 'Lupac', 'Lupac', 'Lupac', 45.2800000, 21.8127800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115987, 'Lunguleţu', 'Lunguletu', 'Lunguletu,Lunguletul,Lunguleţu,Lunguleţul', 44.6166700, 25.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115988, 'Lungeşti', 'Lungesti', '', 44.5666700, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115989, 'Lungani', 'Lungani', 'Lungani', 47.1833300, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115990, 'Lunga', 'Lunga', 'Lunga,Nyujtod,Nyujtòd', 46.0182200, 26.2120800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115991, 'Luncșoara', 'Luncsoara', '', 47.0366300, 22.5421300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115992, 'Luncoiu de Jos', 'Luncoiu de Jos', 'Luncoiu de Jos,Luncoiul-de-Jos', 46.1000000, 22.7666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115993, 'Luncaviţa', 'Luncavita', 'Luncavita,Luncaviţa', 45.2833300, 28.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115994, 'Luncaviţa', 'Luncavita', '', 45.0833300, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115995, 'Lunca Priporului', 'Lunca Priporului', '', 45.4390900, 26.3086900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115996, 'Lunca Prahovei', 'Lunca Prahovei', 'Lunca Prahovei,Paroasa,Păroasa', 45.0471400, 25.7716100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115997, 'Luncani', 'Luncani', '', 46.4727400, 23.9509500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115998, 'Lunca Mureşului', 'Lunca Muresului', 'Lunca Muresului,Lunca Mureşului', 46.4333300, 23.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(115999, 'Lunca Leșului', 'Lunca Lesului', '', 47.3094300, 24.7760200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116000, 'Lunca la Tisa', 'Lunca la Tisa', 'Lunca,Lunca la Tisa', 47.9521300, 24.0521600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116001, 'Lunca Jariștei', 'Lunca Jaristei', 'Broasca,Lunca Jaristei,Lunca Jariştei', 45.4788100, 26.2604900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116002, 'Lunca Ilvei', 'Lunca Ilvei', 'Lunca,Lunca Ilvei,Lunca Vinului', 47.3666700, 24.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116003, 'Lunca de Sus', 'Lunca de Sus', 'Gyimesfelsolok,Gyimesfelsőlok,Lunca de Sus', 46.5333300, 25.9666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116004, 'Lunca de Jos', 'Lunca de Jos', 'Gyimeskoezeplok,Gyimesközéplok,Lunca de Jos', 46.5666700, 25.9833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116005, 'Lunca Corbului', 'Lunca Corbului', 'Lunca Corbului', 44.6839100, 24.7585500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116006, 'Lunca Cetățuii', 'Lunca Cetatuii', 'Lunca Cetatuiei,Lunca Cetatuii,Lunca Cetăţuiei,Lunca Cetăţuii,Zanca,Zanea', 47.0966000, 27.5631900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116007, 'Lunca Cernii de Jos', 'Lunca Cernii de Jos', 'Lunca Cernii de Jos', 45.6333300, 22.6166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116008, 'Lunca Bradului', 'Lunca Bradului', '', 46.9559500, 25.1114000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116009, 'Lunca Banului', 'Lunca Banului', 'Lunca Banului', 46.5950000, 28.1683300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116010, 'Lunca', 'Lunca', '', 47.2814400, 26.7370800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116011, 'Lunca', 'Lunca', '', 47.6166700, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116012, 'Lunca', 'Lunca', '', 47.2276500, 26.2997900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116013, 'Lunca', 'Lunca', 'Tekeujfalu', 46.8500000, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116014, 'Lunca', 'Lunca', '', 46.5166700, 22.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116015, 'Lunca', 'Lunca', '', 45.2002200, 25.4435100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116016, 'Lunca', 'Lunca', 'Lunca,Strambu,Strambul,Strimbu,Strâmbu,Strâmbul,Strîmbu', 45.0049400, 27.2133500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116017, 'Lunca', 'Lunca', 'Cauli-Buceag,Caulî-Buceag,Lunca', 44.7328800, 28.7749500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116018, 'Lunca', 'Lunca', 'Lunca,Raioasa,Riiosa,Râioasa,Rîiosa', 43.8333300, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116019, 'Luna de Sus', 'Luna de Sus', 'Magyarlona,Magyarlóna', 46.7431300, 23.4353900, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116020, 'Luminiș', 'Luminis', 'Iapa,Luminis,Luminiş,Tapa', 46.8133200, 26.4527500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116021, 'Lumina', 'Lumina', 'Cogea Ali,Cogealia,Kogea Ali,Lumina,Valea Neagra,Valea Neagră', 44.2833300, 28.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116022, 'Luizi-Călugăra', 'Luizi-Calugara', 'Luizi-Calugara,Luizi-Călugăra,Luizii-Calugara,Luizii-Călugăra,Lujzakalagor', 46.5333300, 26.8333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116023, 'Luica', 'Luica', 'Luica', 44.2333300, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116024, 'Lugoj', 'Lugoj', 'Deutsch-Lugosch,LGJ,Lugas,Lugoi,Lugoj,Lugos,Lugosch,Lugosh,Lugozh,Nemet-Lugos,Német-Lugos,Olah-Lugos,Oláh-Lugos,Opstina Lugoj,Opština Lugoj,Walachisch-Lugosch,lu ge ri,lugoji,lwghwj,lwgwzh,rugoji,Лугож,Лугош,لوغوج,لوگوژ,ルゴジ,盧戈日,루고지', 45.6886100, 21.9030600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116025, 'Lugaşu de Jos', 'Lugasu de Jos', 'Lugasu de Jos,Lugasul-de-Jos,Lugaşu de Jos,Lugaşul-de-Jos', 47.0666700, 22.3500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116026, 'Lueta', 'Lueta', 'Loevete,Lovete,Lueta,Lövete,Lövéte', 46.2666700, 25.4833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116027, 'Luduş', 'Ludus', 'Ludas,Ludos,Ludus,Luduş', 46.4833300, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116028, 'Ludoş', 'Ludos', 'Ludos,Ludosu Mare,Ludoş,Ludoşu Mare', 45.9166700, 23.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116029, 'Ludeşti', 'Ludesti', 'Ludesti,Ludeşti', 44.8666700, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116030, 'Ludași', 'Ludasi', 'Ludas,Ludasi,Ludaş,Ludaşi', 46.6196200, 26.5792600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116031, 'Luciu', 'Luciu', 'Luciu,Luciul', 44.9666700, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116032, 'Luciu', 'Luciu', 'Luciu,Luciul', 44.7472200, 27.7276000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116033, 'Lucieni', 'Lucieni', 'Lucieni', 44.8500000, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116034, 'Lucăceni', 'Lucaceni', '', 47.7419400, 22.4781900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116035, 'Lozna', 'Lozna', '', 47.9514400, 26.2772300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116036, 'Lozna', 'Lozna', 'Lozna', 47.3166700, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116037, 'Lovrin', 'Lovrin', 'Lorand,Lorandium,Lorant,Lovrand,Lovrin,Lovránd,Lowrin,Lóránd,Lóránt', 45.9680600, 20.7702800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116038, 'Lopătari', 'Lopatari', 'Lopatari,Lopătari', 45.4833300, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116039, 'Lopadea Nouă', 'Lopadea Noua', 'Lopadea Noua,Lopadea Nouă', 46.2909000, 23.8190100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116040, 'Loloiasca', 'Loloiasca', '', 44.9680800, 26.2914100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116041, 'Logrești Moșteni', 'Logresti Mosteni', 'Logresti-Mosteni,Logreşti-Moşteni,Mosteni,Moşteni', 44.9066300, 23.7048000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116042, 'Logreşti', 'Logresti', 'Logresti,Logreşti', 44.9000000, 23.7000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116043, 'Loamneş', 'Loamnes', 'Loamnas,Loamnes,Loamneş,Loamnăs', 45.9333300, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116044, 'Livezi-Vale', 'Livezi-Vale', 'Livezi-Vale,Valea Rea-Sat', 46.4166700, 26.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116045, 'Livezile', 'Livezile', 'Iad,Jad,Jád,Livezile', 47.1833300, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116046, 'Livezile', 'Livezile', 'Cacova,Livezile', 46.3500000, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116047, 'Livezile', 'Livezile', 'Livezile,Tolvad,Tolvadia,Tolvadija,Tolvajd,Tolvád,Tolvádiá,Tolvădia,Tolwadia', 45.3902600, 21.0579400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116048, 'Livezile', 'Livezile', 'Broscari,Livezile', 44.5122200, 22.8633300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116049, 'Livezi', 'Livezi', 'Livezi,Valea Rea,Valea Rea Targ,Valea Rea Târg,Valea Rea-Tirg,Valea Rea-Tîrg', 46.4063900, 26.7361300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116050, 'Livezi', 'Livezi', 'Livezi,Mahalaua Veaca,Veaca,Veaca de Gradistea,Veaca de Grădiştea', 44.8402900, 23.8250500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116051, 'Livezeni', 'Livezeni', 'Iedu,Iedul,Jedd,Livezeni', 46.5500000, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116052, 'Livezeni', 'Livezeni', '', 45.0383800, 24.9767600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116053, 'Livadia', 'Livadia', '', 45.2054600, 24.2419200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116054, 'Livadea', 'Livadea', '', 45.1866300, 25.9280500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116055, 'Livada de Bihor', 'Livada de Bihor', '', 47.0103900, 21.8083600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116056, 'Livada', 'Livada', 'Livada,Sarkoz,Sarköz', 47.8666700, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116057, 'Livada', 'Livada', 'Baumgarten,Fachert,Fakert,Livada', 46.2228400, 21.3840300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116058, 'Liubcova', 'Liubcova', 'Dolina-Liubcova,Donja Ljubkova,Liubcova,Liubcova de Jos', 44.6588500, 21.8955900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116059, 'Liteni', 'Liteni', '', 47.5666700, 26.2000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116060, 'Liteni', 'Liteni', 'Liteni', 47.5204900, 26.5283000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116061, 'Liteni', 'Liteni', 'Liteni,Ulmi-Liteni,Ulmii-Liteni', 47.3016900, 27.0383700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116062, 'Liţa', 'Lita', 'Lita,Liţa', 43.8000000, 24.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116063, 'Lișteava', 'Listeava', 'Listeava,Listiva,Lişteava', 43.8341800, 23.9202200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116064, 'Lisa', 'Lisa', 'Lisa,Lissa', 45.7166700, 24.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116065, 'Lisa', 'Lisa', 'Lisa,Lissa', 43.8000000, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116066, 'Lipovu', 'Lipovu', 'Lipovu,Lipovul', 44.1000000, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116067, 'Lipovăţ', 'Lipovat', 'Lipovat,Lipovatul,Lipovăţ,Lipovăţul', 46.5666700, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116068, 'Lipova', 'Lipova', 'Lipova,Popesti,Popeşti,Satu Nou,Липова', 46.7166700, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116069, 'Lipova', 'Lipova', 'Lipova,Lippa,Lippova,Mariaradna,Máriaradna,Opstina Lipova,Opština Lipova,Solymosvar,Solymosvár,li bo wa,lpwh,lypwh  arad,Липова,Ліпова,لپوه,لیپوه، آراد,利波瓦', 46.0908500, 21.6962800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116070, 'Lipniţa', 'Lipnita', 'Lipnita,Lipniţa', 44.1000000, 27.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116071, 'Lipia', 'Lipia', '', 45.1397000, 26.7350500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116072, 'Lipia', 'Lipia', '', 44.7100300, 26.2644500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116073, 'Lipăneşti', 'Lipanesti', 'Lipanesti,Lipanseti,Lipăneşti,Lipănseti', 45.0500000, 26.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116074, 'Izvoru', 'Izvoru', 'Linia Ciolanu', 45.1924900, 26.5915400, 'RO', '2015-11-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116075, 'Limpeziș', 'Limpezis', 'Limpezis,Limpezisu,Limpezisul,Limpeziş,Limpezişu,Limpezişul', 44.9535700, 26.7049000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116076, 'Limanu', 'Limanu', 'Caracicula,Limanu,Limanul', 43.8000000, 28.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116077, 'Liliești', 'Liliesti', '', 45.0345800, 25.8855400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116078, 'Lilieci', 'Lilieci', '', 46.6286100, 26.8717600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116079, 'Lieşti', 'Liesti', 'Lieste,Liesti,Lieşte,Lieşti', 45.6166700, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116080, 'Liebling', 'Liebling', 'Lieblig,Liebling', 45.5775000, 21.3216700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116081, 'Licurici', 'Licurici', '', 44.9166700, 23.6166700, 'RO', '2015-12-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116082, 'Libotin', 'Libotin', '', 47.5054100, 23.9683300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116083, 'Leu', 'Leu', 'Leu,Leul', 44.1833300, 24.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116084, 'Letea Veche', 'Letea Veche', 'Letea Veche', 46.5500000, 26.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116085, 'Letca Veche', 'Letca Veche', '', 44.1991100, 25.6868100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116086, 'Letca Nouă', 'Letca Noua', 'Letca Noua,Letca Nouă', 44.2349600, 25.7426200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116087, 'Leţcani', 'Letcani', 'Letcani,Leţcani', 47.1833300, 27.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116088, 'Letca', 'Letca', 'Letca,Letka', 47.3333300, 23.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116089, 'Leşu', 'Lesu', 'Lesu,Lesul,Leşu,Leşul', 47.3166700, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116090, 'Lespezi', 'Lespezi', 'Lespezi', 47.3666700, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116091, 'Lespezi', 'Lespezi', '', 46.6649300, 26.7688200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116092, 'Lespezi', 'Lespezi', 'Lespezi,Lespezile', 46.1602700, 27.2406500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116093, 'Lereşti', 'Leresti', 'Leresti,Lereşti', 45.3333300, 25.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116094, 'Leordina', 'Leordina', 'Leordina', 47.7833300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116095, 'Leordeni', 'Leordeni', 'Leordeni,Leurdeni', 44.7833300, 25.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116096, 'Leorda', 'Leorda', '', 47.8166700, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116097, 'Lenauheim', 'Lenauheim', 'Cetad,Cetat,Comuna Lenauheim,Csatad,Csatád,Lenaugajm,Lenauheim,Lenaukhejm,Opstina Lenauheim,Opština Lenauheim,Schadat,Ленаугайм,Ленаухејм', 45.8719400, 20.7994400, 'RO', '2016-07-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116098, 'Lemnia', 'Lemnia', 'Alszeg,Lemheny,Lemhèny,Lemnia', 46.0500000, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116099, 'Leliceni', 'Leliceni', 'Leliceni,Szentlelek,Szentlélek', 46.3471300, 25.8478200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116100, 'Leleşti', 'Lelesti', 'Lelesti,Leleşti', 45.1000000, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116101, 'Lelese', 'Lelese', 'Lelese', 45.7333300, 22.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116102, 'Leleasca', 'Leleasca', 'Leleasca,Stefanesti,Ştefăneşti', 44.7833300, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116103, 'Leicești', 'Leicesti', '', 45.0958600, 24.8610800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116104, 'Lehliu-Gară', 'Lehliu-Gara', 'Gara Lehliul,Lehliu,Lehliu-Gara,Lehliu-Gară', 44.4333300, 26.8500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116105, 'Lehliu', 'Lehliu', 'Lehliu,Lehliul', 44.4666700, 26.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116106, 'Lechinţa', 'Lechinta', 'Lechinta,Lechinţa', 47.0166700, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116107, 'Lazuri de Beiuş', 'Lazuri de Beius', 'Belenyes,Belenyes-Lazur,Belenyesirtas,Belényes,Belényes-Lazúr,Belényesirtás,Lazuri,Lazuri de Beius,Lazuri de Beiuș', 46.5833300, 22.4000000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116108, 'Lazuri', 'Lazuri', 'Lazar,Lazuri,Lăzar', 47.8500000, 22.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116109, 'Lazuri', 'Lazuri', 'Lazuri,Lazurile', 44.8785900, 25.5496400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116110, 'Lăzărești', 'Lazaresti', '', 45.1565900, 24.9954000, 'RO', '2013-12-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116111, 'Lăzăreni', 'Lazareni', 'Lazareni,Lăzăreni,Miclo-Lazuri', 46.8666700, 22.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116112, 'Lăzarea', 'Lazarea', 'Lazarea,Lazaresti,Lăzarea,Lăzareşti,Szarheg,Szarhegy,Szárhegy', 46.7500000, 25.5333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116113, 'Laza', 'Laza', 'Ferma Laza,Laza', 46.6500000, 27.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116114, 'Laslea', 'Laslea', 'Laslea', 46.2166700, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116115, 'Largu', 'Largu', 'Largu,Largul', 44.9666700, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116116, 'Larga', 'Larga', '', 46.3506000, 26.5332100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116117, 'Lăpuşnicu Mare', 'Lapusnicu Mare', 'Lapusnicu Mare,Lapusnicul-Mare,Lapusnik,Lapušnik,Lăpuşnicu Mare,Lăpuşnicul-Mare', 44.9130600, 21.9441700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116118, 'Lăpuşnicel', 'Lapusnicel', 'Lapusnicel,Lopusnicel,Lopušničel,Lăpuşnicel', 44.9830600, 22.2269400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116119, 'Lăpușel', 'Lapusel', '', 47.6183000, 23.4791300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116120, 'Lăpuş', 'Lapus', 'Dlanlepos,Dlanlěpos,Lapus,Lăpuş', 47.5000000, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116121, 'Lăpugiu de Jos', 'Lapugiu de Jos', 'Lapugiu Inferior,Lapugiu de Jos,Lapusiul-Inferior,Lăpugiu Inferior,Lăpugiu de Jos,Lăpusiul-Inferior', 45.8833300, 22.4833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116122, 'Lapoș', 'Lapos', '', 45.1519700, 26.4191100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116123, 'Lăpoș', 'Lapos', 'Lapos,Laposul,Lapoş,Lapoşul', 46.3936300, 26.4624500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116124, 'Lanurile', 'Lanurile', 'Golasei,Golăşei,Lanurile', 45.0414900, 27.7491600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116125, 'Lancrăm', 'Lancram', '', 45.9870800, 23.5566500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116126, 'Lămășeni', 'Lamaseni', '', 47.4932200, 26.2280600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116127, 'Laloşu', 'Lalosu', 'Lalosiu,Lalosu,Lalosul,Laloşiu,Laloşu,Laloşul', 44.5500000, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116128, 'Lădeşti', 'Ladesti', 'Ladesti,Lădeşti', 44.8833300, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116129, 'Lăcusteni', 'Lacusteni', '', 44.6954400, 23.8998400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116130, 'Lăcusteni', 'Lacusteni', 'Lacusteni,Lăcusteni', 44.6071500, 27.6756900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116131, 'Lacu Sărat', 'Lacu Sarat', 'Lacu Sarat,Lacu Sarat-Baile,Lacu Sărat,Lacu Sărat-Băile,Lacul-Sarat,Lacul-Sărat', 45.2186700, 27.8876400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116132, 'Lăculețe', 'Laculete', 'Darulete,Laculete,Lăculeţe', 45.0183700, 25.4310800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116133, 'Lăceni', 'Laceni', '', 44.0846600, 25.3327000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116134, 'Jurilovca', 'Jurilovca', 'Jurilofca,Jurilofka,Jurilovca', 44.7666700, 28.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116135, 'Jupânești', 'Jupanesti', 'Jupinesti,Jupîneşti', 45.0666700, 24.8500000, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116136, 'Jupâneşti', 'Jupanesti', 'Jupanesti,Jupinesti,Jupâneşti,Jupîneşti', 44.9000000, 23.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116137, 'Jugureni', 'Jugureni', 'Jugure,Jugureni', 45.1000000, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116138, 'Jugureanu', 'Jugureanu', 'Jugureanu,Jugureanul', 44.9431300, 27.2787800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116139, 'Jugur', 'Jugur', 'Jugur,Juguru', 45.1925500, 25.0849300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116140, 'Josenii Bârgăului', 'Josenii Bargaului', 'Josenii Birgaului,Josenii Bîrgăului,Josenii-Bargaului,Josenii-Bârgăului', 47.2166700, 24.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116141, 'Joseni', 'Joseni', 'Alfalu,Alfalù,Gyergyoalfalu,Gyergyóalfalu,Joseni,Joseri', 46.7000000, 25.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116142, 'Jorăşti', 'Jorasti', '', 45.9833300, 27.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116143, 'Jorăști', 'Jorasti', '', 45.7147700, 27.2633500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116144, 'Joldești', 'Joldesti', '', 47.5600400, 26.5770500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116145, 'Joiţa', 'Joita', '', 44.4941700, 25.8538900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116146, 'Jiu-Paroșeni', 'Jiu-Paroseni', 'Jiu Paroseni,Jiu Paroşeni,Paroseni,Paroseni-Jiu,Paroşeni-Jiu', 45.3617500, 23.2604400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116147, 'Jitia', 'Jitia', 'Jitia', 45.5833300, 26.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116148, 'Jirov', 'Jirov', 'Jirovu,Jirovul', 44.6709800, 23.0869300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116149, 'Jirlău', 'Jirlau', 'Jirlau,Jirlaul,Jirlău,Jirlăul', 45.1666700, 27.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116150, 'Jina', 'Jina', '', 45.7833300, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116151, 'Jimbolia', 'Jimbolia', 'Dzombolj,Hacfeld,Haczfeld,Hatzfeld,Jimbolia,Nacfeld,Opstina Jimbolia,Opština Jimbolia,Zhimbolija,Zhombol,Zimbolija,Zombolj,Zsombolya,jymbwlya,ren bo li ya,Žimbolija,Žombolj,Жимболия,Жимболія,Жомбољ,جیمبولیا,任博利亞', 45.7913900, 20.7172200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116152, 'Jilavele', 'Jilavele', 'Jilavele', 44.7666700, 26.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116153, 'Jilava', 'Jilava', 'Jilava', 44.3333300, 26.0780600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116154, 'Jijila', 'Jijila', 'Jijila', 45.3000000, 28.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116155, 'Jieni', 'Jieni', '', 43.9509500, 24.5934900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116156, 'Jidvei', 'Jidvei', 'Jidvei,Jidveiu,Jidveiul', 46.2166700, 24.1000000, 'RO', '2015-11-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116157, 'Jidoștița', 'Jidostita', 'Jidostita,Jidoştiţa,Zidoscica,Zidošcica', 44.7158200, 22.5931100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116158, 'Jichişu de Jos', 'Jichisu de Jos', 'Jichisu de Jos,Jichisul-de-Jos,Jichişu de Jos,Jichişul-de-Jos', 47.1166700, 23.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116159, 'Jibou', 'Jibou', 'Jibau,Jibou,Jiboul,Opstina Jibou,Opština Jibou,Zhibou,Zsibo,Zsibó,ri bo wu,zhybw,zsybwy,Жибоу,זשיבוי,ژیبو,日博烏', 47.2589600, 23.2565100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116160, 'Jiblea Veche', 'Jiblea Veche', 'Jiblea,Jiblea Veche', 45.2436000, 24.3516300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116161, 'Jibert', 'Jibert', 'Jibert', 46.0000000, 25.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116162, 'Jiana Veche', 'Jiana Veche', '', 44.3908300, 22.6686100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116163, 'Jiana', 'Jiana', 'Flamanda,Flaminda,Flămânda,Flămînda,Jiana', 44.4018400, 22.7127800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116164, 'Jegălia', 'Jegalia', 'Jegalia,Jegălia', 44.3000000, 27.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116165, 'Jebel', 'Jebel', 'Jebel,Schebel,Szephely,Széphely,Zsebely', 45.5555600, 21.2136100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116166, 'Jariştea', 'Jaristea', 'Jaristea,Jariştea', 45.7833300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116167, 'Jamu Mare', 'Jamu Mare', 'Jamu Mare,Jamul-Mare,Nagyzsam,Nagyzsám', 45.2541700, 21.4169400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116168, 'Jabenița', 'Jabenita', 'Gorgenysoakna,Görgènysòakna,Jabenita,Jabeniţa', 46.7840700, 24.7967100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116169, 'Izvoru Dulce', 'Izvoru Dulce', 'Isvorul-Dulce,Izvoru Dulce,Izvorul Dulce', 45.3417800, 26.7773000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116170, 'Izvoru de Sus', 'Izvoru de Sus', 'Isvorul de Sus,Izvoru de Sus', 44.8166700, 24.6500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116171, 'Izvoru Crişului', 'Izvoru Crisului', 'Izvoru Crisului,Izvoru Crişului,Izvorul Crisului,Izvorul Crişului', 46.8333300, 23.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116172, 'Izvoru Bârzii', 'Izvoru Barzii', 'Izvoru Barzii,Izvoru Birzei,Izvoru Birzii,Izvoru Bârzii,Izvoru Bîrzei,Izvoru Bîrzii,Izvorul Barzej', 44.7066700, 22.6741700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116173, 'Izvoru Berheciului', 'Izvoru Berheciului', 'Cimbala,Gloduri,Izvoru Berheciului,Targel Glodurile,Tirgu Gloduri,Tîrgu Gloduri', 46.5833300, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116174, 'Izvoru', 'Izvoru', 'Isvoru-de-Sus,Isvorul de Sus,Izvoru,Izvoru Sus', 44.4941400, 25.0647000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116175, 'Izvoarele Sucevei', 'Izvoarele Sucevei', 'Isvoarele Sucevii,Isvor,Isvorul,Izvoarele Sucevei,Izvor,Jzwor', 47.7500000, 25.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116176, 'Izvoarele', 'Izvoarele', 'I.C. Frimu,Izvoarele,Sturza', 47.0424100, 26.9023000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116177, 'Izvoarele', 'Izvoarele', 'Ciufud,Izvoarele', 46.1701100, 23.9037700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116178, 'Izvoarele', 'Izvoarele', 'Filimon Sirbu,Filimon Sîrbu,Izvoarele', 45.0333300, 28.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116179, 'Izvoarele', 'Izvoarele', 'Isvoarele,Izvoarele', 45.0333300, 25.2666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116180, 'Izvoarele', 'Izvoarele', 'Isvoarele,Izvoarele', 44.3095800, 22.6634800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116181, 'Izvoarele', 'Izvoarele', 'Isvoarele,Izvoarele', 44.2666700, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116182, 'Izvoarele', 'Izvoarele', 'Isvoarele', 44.1696800, 26.3137400, 'RO', '2016-01-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116183, 'Izvoarele', 'Izvoarele', 'Beiu,Beiul,Izvoarele', 44.0338900, 25.7747200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116184, 'Izvoarele', 'Izvoarele', 'Gauriciu,Găuriciu', 43.8166700, 25.3833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116185, 'Izvoare', 'Izvoare', 'Isvoare,Izvoare', 46.9101300, 26.4701400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116186, 'Izvoare', 'Izvoare', 'Izvoare,Ruptura', 46.7469900, 26.8022100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116187, 'Izvoare', 'Izvoare', 'Rudari', 44.1477300, 23.2958200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116188, 'Izvin', 'Izvin', 'Izvin,Jeszvin,Jezvin,Oszeny,Őszény', 45.8003400, 21.4606600, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116189, 'Izimșa', 'Izimsa', 'Izimsa,Izimsea,Izimşa,Izimşea', 44.1781900, 22.9564900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116190, 'Izbiceni', 'Izbiceni', 'Isbiceni,Izbiceni', 43.8333300, 24.6500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116191, 'Iveşti', 'Ivesti', 'Ivesti,Ivestii,Iveşti,Iveştii', 46.1833300, 27.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116192, 'Iveşti', 'Ivesti', '', 45.6833300, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116193, 'Ivănești', 'Ivanesti', 'Balica,Chilia,Golgofta,Gologofta,Ivanesti,Ivăneşti,Valea Canepei,Valea Cinepei,Valea Cânepei,Valea Cînepei', 46.6348100, 27.4604800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116194, 'Iugani', 'Iugani', 'Iugani,Jugani', 47.0443100, 26.8289100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116195, 'Viile Tecii', 'Viile Tecii', 'Ida Mare,Iuda,Kolozsnagyida,Nagyida', 46.9333300, 24.4833300, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116196, 'Iteşti', 'Itesti', '', 46.6530900, 26.8725600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116197, 'Isverna', 'Isverna', 'Isverna,Izverna', 44.9797200, 22.6291700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116198, 'Istria', 'Istria', 'Caranasuf,Caranasut,Histria,Istria,Istrus,Karanasuf', 44.5666700, 28.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116199, 'Islaz', 'Islaz', '', 44.4611700, 26.3872400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116200, 'Islaz', 'Islaz', 'Islaz,Islazu,Islazul,Izlaz', 43.7333300, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116201, 'Iscroni', 'Iscroni', 'Barbateni-Iscroni,Bărbăteni-Iscroni,Iscroni', 45.3779400, 23.3420100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116202, 'Işalniţa', 'Isalnita', 'Isalnita,Işalniţa', 44.4000000, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116203, 'Isaccea', 'Isaccea', 'Isaccea,Isakcha,aysakchh,yi sa ke qia,Ісакча,Исакча,ایساکچه,伊薩克恰', 45.2666700, 28.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116204, 'Irești', 'Iresti', 'Iresti,Irestii,Ireşti,Ireştii', 45.9299300, 26.9439300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116205, 'Iratoşu', 'Iratosu', 'Iratos,Iratosu,Iratosul,Iratoş,Iratoşu,Iratoşul', 46.3166700, 21.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116206, 'Ipoteşti', 'Ipotesti', '', 47.6166700, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116207, 'Ipotești', 'Ipotesti', '', 44.3252900, 24.4008900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116208, 'Ipatele', 'Ipatele', 'Halita,Haliţa,Ipatele,Petresti,Petreşti', 46.9166700, 27.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116209, 'Ip', 'Ip', 'Ip', 47.2333300, 22.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116210, 'Iordăcheanu', 'Iordacheanu', 'Iordacheanu,Iordachianu,Iordăcheanu,Iordăchianu', 45.0439200, 26.2392000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116211, 'Ion Roată', 'Ion Roata', 'Ion Roata,Ion Roată,Principesa Maria', 44.6666700, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116212, 'Ion Neculce', 'Ion Neculce', 'Ion Neculce,Prigorenii Mici', 47.2034400, 27.0526800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116213, 'I. L. Caragiale', 'I. L. Caragiale', 'Haimanale,I.L. Caragiale,Ion Luca Caragiale', 44.9096300, 25.7025100, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116214, 'Ioneşti', 'Ionesti', '', 44.8500000, 24.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116215, 'Ionești', 'Ionesti', '', 44.6937400, 25.2778000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116216, 'Ioneşti', 'Ionesti', 'Ionesti,Ioneşti', 44.6166700, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116217, 'Ion Corvin', 'Ion Corvin', 'Cuzgun,Ioan Corvin,Ion Corvin', 44.1166700, 27.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116218, 'Ionășeni', 'Ionaseni', '', 47.7302900, 26.9932900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116219, 'Iojib', 'Iojib', '', 47.8161700, 23.1560300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116220, 'Intregalde', 'Intregalde', 'Intregalde', 46.2500000, 23.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116221, 'Întorsura Buzăului', 'Intorsura Buzaului', 'Intorsatura-Buzaului,Intorsura Buzauli,Intorsura Buzaului,Intorsura Buzăuli,Magyarbodza,Întorsura Buzăului', 45.6833300, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116222, 'Întorsura', 'Intorsura', 'Intorsura,Întorsura', 44.1122600, 23.5757400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116223, 'Însurăţei', 'Insuratei', 'Insuratei,Însurăţei', 44.9166700, 27.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116224, 'Inotești', 'Inotesti', '', 44.9614600, 26.3578200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116225, 'Ineu', 'Ineu', '', 47.0833300, 22.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116226, 'Ineu', 'Ineu', 'Ineu,Ineul,Jenofalva,Jenőfalva,Инеу', 46.5453000, 25.7635700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116227, 'Ineu', 'Ineu', 'Borosjeno,Borosjenő,Ineu,Janopol,Jenopole,Yanova,aynyw,yanwh,yi nei wu,Інеу,Јенопоље,Инеу,اینئو,یانوه,伊內烏', 46.4337200, 21.8404800, 'RO', '2012-06-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116228, 'Independenţa', 'Independenta', '', 45.4833300, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116229, 'Independenţa', 'Independenta', '', 44.2833300, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116230, 'Independenţa', 'Independenta', 'Bairamdede,Independenta,Independenţa', 43.9666700, 28.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116231, 'Imper', 'Imper', 'Imper,Kaszoninper,Kàszoninper', 46.2166700, 26.1000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116232, 'Ilva Mică', 'Ilva Mica', 'Ilva Mica,Ilva Mică', 47.3166700, 24.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116233, 'Ilva Mare', 'Ilva Mare', 'Ilva Mare,Nagyilva', 47.3666700, 24.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116234, 'Iloviţa', 'Ilovita', 'Hovita,Hoviţa,Ilovica,Ilovita,Iloviţa', 44.7563900, 22.4727800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116235, 'Ilovăț', 'Ilovat', 'Ilovat,Ilovatu,Ilovatul,Ilovăţ,Ilovăţu,Ilovăţul', 44.8119700, 22.7633300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116236, 'Ilișești', 'Ilisesti', 'Ilisesti,Ilişeşti', 47.6087800, 26.0506100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116237, 'Ilieni', 'Ilieni', 'Ilieni,Ilyefalva', 45.8000000, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116238, 'Ilia', 'Ilia', 'Ilia', 45.9333300, 22.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116239, 'Ileanda', 'Ileanda', 'Ileanda,Nagyilonda', 47.3333300, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116240, 'Ileana', 'Ileana', '', 44.5166700, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116241, 'Ilba', 'Ilba', '', 47.7128000, 23.3576500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116242, 'Igriș', 'Igris', 'Egres,Egresch,Egrisch,Igris,Igrisch,Igriş', 46.1131300, 20.7849600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116243, 'Igoiu', 'Igoiu', 'Igoiu,Igoiul', 45.0482400, 23.8083500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116244, 'Igneşti', 'Ignesti', 'Ignafalva,Ignest,Ignesti,Ignesty,Ignești', 46.4000000, 22.1666700, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116245, 'Ighiu', 'Ighiu', 'Igen,Ighiu,Ighiul,Magyarigen', 46.1500000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116246, 'Ighișu Nou', 'Ighisu Nou', 'Ighisu Nou,Ighisul Nou,Ighişu Nou,Ighişul Nou', 46.1112100, 24.3492000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116247, 'Ighiel', 'Ighiel', '', 46.1468000, 23.4796800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116248, 'Igești', 'Igesti', 'Igesti,Igestii,Igeşti,Igeştii', 45.8204300, 27.1825300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116249, 'Iezeru', 'Iezeru', 'Beilic,Beilicu,Iezeru', 44.2861700, 27.6244700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116250, 'Ieud', 'Ieud', 'Ieud,Jeud,Jod,Jód', 47.6779600, 24.2339900, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116251, 'Iernuțeni', 'Iernuteni', 'Iernuteni,Iernuţeni,Radnotfaja,Radnòtfàja', 46.7638700, 24.7191900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116252, 'Iernut', 'Iernut', 'Iernut', 46.4500000, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116253, 'Iecea Mică', 'Iecea Mica', 'Iecea Mica,Iecea Mică,Iecia-Mica,Iecia-Mică,Jecia-Mica,Jecia-Mică,Kisjecsa,Kisjécsa,Klein-Jetscha', 45.8214700, 20.9232200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116254, 'Iecea Mare', 'Iecea Mare', 'Gross-Jetscha,Iecea Mare,Iecia-Mare,Jecia-Mare,Nagyjecsa,Nagyjécsa', 45.8507400, 20.8931000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116255, 'Ideciu de Jos', 'Ideciu de Jos', 'Alsoidecs,Alsòidecs,Ideciu de Jos,Ideciul-de-Jos', 46.8000000, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116256, 'Icuseşti', 'Icusesti', 'Icusesti,Icuseşti', 46.8000000, 26.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116257, 'Icușeni', 'Icuseni', '', 47.5926900, 26.5960500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116258, 'Icoana', 'Icoana', '', 44.4930900, 25.7462300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116259, 'Icoana', 'Icoana', 'Icoana', 44.4166700, 24.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116260, 'Iclod', 'Iclod', 'Iclod,Nagyiklod,Nagyiklód', 46.9833300, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116261, 'Iclănzel', 'Iclanzel', 'Iclanzeiu,Iclanzel,Iclanzelul,Iclausel,Iclănzeiu,Iclănzel,Iclănzelul,Iclăuşel', 46.5333300, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116262, 'Ibrianu', 'Ibrianu', 'Ibrianul,Ibrieanu', 44.7750900, 25.8437500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116263, 'Ibănești-Pădure', 'Ibanesti-Padure', 'De Ibanesti,De Ibăneşti,Erdolibanfalva,Erdőlibànfalva,Ibanesti Padure,Ibăneşti Pădure', 46.7589300, 24.9867600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116264, 'Ibăneşti', 'Ibanesti', '', 48.0666700, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116265, 'Ibăneşti', 'Ibanesti', 'Ibanesti,Ibăneşti,Libanfalva,Libànfalva', 46.7666700, 24.9333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116266, 'Ibănești', 'Ibanesti', 'Ibanesti,Ibăneşti', 46.3948200, 27.6254800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116267, 'Iazurile', 'Iazurile', 'Calica,Iazurile', 45.0216200, 28.9428100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116268, 'Iazu Nou', 'Iazu Nou', 'Arbora,Iazu Nou', 47.4827200, 27.2091300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116269, 'Iazu', 'Iazu', 'Iazu,Iazul', 44.7312000, 27.4207400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116270, 'Iazu', 'Iazu', 'Iazu,Rudari', 44.7176400, 25.8311900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116271, 'Iaslovăț', 'Iaslovat', 'Iaslovat,Iaslovăţ', 47.7586200, 25.9774200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116272, 'Iaşi', 'Iasi', 'Copou,Copou-Targ,Copou-Târg,Galata,Gorad Jasy,IAS,Iasi,Iasio,Iassium,Iaşi,Iași,Ilasi,Jasai,Jash,Jashi,Jasi,Jassenmarkt,Jassi,Jassy,Jasy,Jaszvasar,Jaßenmarkt,Jászvásár,Munteni,Pacurari,Pacuret,Podgoria,Păcurari,Păcureţ,Socol,Socola,Yas,Yashi,Yasi,Yassi,Yassy,Yaş,ayashy,iasi,ya xi,yach,yasa,yash,yashi,Ιάσιο,Јаши,Горад Ясы,Ясси,Яссы,Яш,Յասի,יאס,יאשי,ایاشی,ياش,یاش,याश,ยาช,ヤシ,雅西,이아시', 47.1666700, 27.6000000, 'RO', '2013-06-29', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116273, 'Iara', 'Iara', 'Iara', 46.5500000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116274, 'Iapa', 'Iapa', 'Ciarda-Iapa,Iapa', 47.9251300, 23.8253900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116275, 'Ianoșda', 'Ianosda', '', 46.8379100, 21.8077800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116276, 'Iancu Jianu', 'Iancu Jianu', 'Iancu Jianu,Stirbei,Ştirbei', 44.5000000, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116277, 'Ianca', 'Ianca', 'Ianca', 45.1333300, 27.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116278, 'Ianca', 'Ianca', '', 43.7833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116279, 'Iana', 'Iana', 'Iana', 46.3833300, 27.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116280, 'Iadăra', 'Iadara', '', 47.4792700, 23.3989300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116281, 'Iacobeni', 'Iacobeni', 'Iacobeni,Iacobeni-Mari,Iacobeni-Vechi', 47.8611500, 26.9130400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116282, 'Iacobeni', 'Iacobeni', '', 47.4333300, 25.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116283, 'Iacobeni', 'Iacobeni', 'Iacobeni,Obeni', 46.0500000, 24.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116284, 'Iablaniţa', 'Iablanita', 'Bela Jablanica,Iablanita,Iablaniţa,Jablanita,Jablaniţa', 44.9502800, 22.3141700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116285, 'Huta Certeze', 'Huta Certeze', 'Huta Certeze,Hutta', 47.9258300, 23.4871500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116286, 'Husnicioara', 'Husnicioara', 'Husnicioara', 44.6780600, 22.8425000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116287, 'Huşi', 'Husi', 'Gusi,Husi,Huşi,Гуси', 46.6736100, 28.0594400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116288, 'Husasău de Tinca', 'Husasau de Tinca', 'Husasau de Tinca,Husasaul-de-Tinca,Husasău de Tinca,Husasăul-de-Tinca,Hususau de Bihor,Hususău de Bihor', 46.8166700, 21.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116289, 'Hurjuieni', 'Hurjuieni', '', 47.9166700, 25.8166700, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116290, 'Huruiești', 'Huruiesti', 'Huruesti,Huruestii,Hurueşti,Hurueştii', 46.2666700, 27.2500000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116291, 'Hurezani', 'Hurezani', 'Hurezani,Hurezani de Sus', 44.8000000, 23.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116292, 'Hunia', 'Hunia', '', 44.0553200, 23.0989300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116293, 'Hunedoara', 'Hunedoara', 'Hunedoara,Khunedoara,Vajdahunyad,Хунедоара,חונדוארה', 45.7500000, 22.9000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116294, 'Humoreni', 'Humoreni', '', 47.6666700, 25.9833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116295, 'Humulești', 'Humulesti', 'Humulesti,Humuleşti', 47.1984600, 26.3527300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116296, 'Humele', 'Humele', '', 44.5261200, 24.9771400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116297, 'Hulubeşti', 'Hulubesti', 'Hulubesti,Hulubeşti', 44.8333300, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116298, 'Huedin', 'Huedin', 'Banffyhunyad,Bánffyhunyad,Guedin,Huedin,Khuedin,Opstina Huedin,Opština Huedin,hu ai ding,hwydy,Гуєдін,Хуедин,هوئدی,胡埃丁', 46.8666700, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116299, 'Hudeşti', 'Hudesti', 'Hudesti,Hudesti Mari,Hudesti-Lupeni,Hudeşti,Hudeşti-Lupeni,Lupeni', 48.1500000, 26.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116300, 'Hotarele', 'Hotarele', 'Hotarele', 44.1725000, 26.3702800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116301, 'Hotar', 'Hotar', '', 47.0196700, 22.2851500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116302, 'Horodnic de Sus', 'Horodnic de Sus', '', 47.8401200, 25.8235400, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116303, 'Horodnic de Jos', 'Horodnic de Jos', '', 47.8652300, 25.8185600, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116304, 'Horodniceni', 'Horodniceni', 'Horodniceni', 47.5333300, 26.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116305, 'Horoatu Crasnei', 'Horoatu Crasnei', 'Horoatu Crasnei,Horoatul Crasnei', 47.1333300, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116306, 'Horleşti', 'Horlesti', '', 47.1166700, 27.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116307, 'Horia', 'Horia', 'Horia,Neupanat,Panad,Panat,Panath,Panatu Nou,Panatul-Nou,Panád,Panáth,Pănat,Ujpanad,Újpanád', 46.2084700, 21.4628700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116308, 'Horia', 'Horia', 'Horia,Orta Chioi,Regina-Maria', 45.0166700, 28.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116309, 'Horia', 'Horia', 'Horia,Muskubei,Muslu-Bei', 44.6333300, 28.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116310, 'Horgeşti', 'Horgesti', '', 46.4333300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116311, 'Horezu', 'Horezu', '', 45.1500000, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116312, 'Hopârta', 'Hoparta', 'Hoparta,Hopirta,Hopârţa,Hopîrta', 46.3213400, 23.8724400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116313, 'Homorodu de Jos', 'Homorodu de Jos', 'Alsohomorod,Alsóhomoród,Homorod-de Jos,Homorodu de Jos,Homorodul-de-Jos', 47.6666700, 23.0833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116314, 'Homorod', 'Homorod', 'Homorod', 46.0500000, 25.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116315, 'Homorâciu', 'Homoraciu', 'Homoraciu,Homoraciul,Homoriciu,Homorâciu,Homorâciul,Homorîciu', 45.2694000, 26.0163400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116316, 'Homocea', 'Homocea', 'Homocea', 46.1333300, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116317, 'Holt', 'Holt', 'Holt,Holtu,Holţu', 46.5785600, 26.9749900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116318, 'Holod', 'Holod', 'Holod', 46.7833300, 22.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116319, 'Holboca', 'Holboca', 'Holboca', 47.1500000, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116320, 'Holbav', 'Holbav', '', 45.6592200, 25.3874400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116321, 'Hoghiz', 'Hoghiz', 'Hoghiz', 45.9833300, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116322, 'Hoghilag', 'Hoghilag', 'Hoghilag', 46.2333300, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116323, 'Hodoșa', 'Hodosa', 'Ditro Hodas,Ditró Hodas,Hodos,Hodosa,Hodosa-de-Ciuc,Hodoşa,Hodoşa-de-Ciuc', 46.8655800, 25.4462000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116324, 'Hodoşa', 'Hodosa', 'Hodosa,Hodoşa,Szekelyhodos,Szèkelyhodos', 46.6333300, 24.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116325, 'Hodora', 'Hodora', '', 47.3371200, 27.0197000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116326, 'Hodoni', 'Hodoni', 'Hodani,Hodon,Hodoni,Hodony', 45.9064600, 21.0885100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116327, 'Hodod', 'Hodod', 'Hadad,Hodod', 47.4000000, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116328, 'Hodac', 'Hodac', 'Gorgenyhodak,Gorgenyhodák,Hodac', 46.7666700, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116329, 'Hociungi', 'Hociungi', '', 46.8131100, 26.7759600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116330, 'Hoceni', 'Hoceni', 'Hoceni,Hoceni Targ,Hoceni Tirg,Hoceni Târg,Hoceni Tîrg', 46.5391700, 28.0066700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116331, 'Hlipiceni', 'Hlipiceni', 'Cobiceni,Hlipiceni,Odaia Veche,Slobozia-Hlipiceni', 47.6000000, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116332, 'Hlăpești', 'Hlapesti', 'Hlapesti,Hlăpeşti,I.C. Bratianu,I.C. Brătianu', 47.0381700, 26.5984200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116333, 'Hârtop', 'Hartop', 'Bilhac,Bîlhac,Hartop,Hartopul,Hirtop,Hârtop,Hârtopul,Hîrtop', 47.4900000, 26.3722600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116334, 'Hârtoape', 'Hartoape', 'Hartoape,Hartoapele,Hirtoape,Hârtoape,Hârtoapele,Hîrtoape', 47.3216400, 26.7245900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116335, 'Hârtieşti', 'Hartiesti', 'Hartiesti,Hartiestii,Hirtiesti,Hârtiestii,Hârtieşti,Hîrtieşti', 45.1166700, 25.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116336, 'Hârşova', 'Harsova', 'Harosora,Harsova,Hirsova,Hâroşora,Hârşova,Hîrşova,Khursovo,khrswh,Хърсово,خرسوه', 44.6857400, 27.9481900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116337, 'Hârseşti', 'Harsesti', 'Harsesti,Hirsesti,Hârseşti,Hîrseşti', 44.5333300, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116338, 'Hârşeni', 'Harseni', 'Harseni,Hirseni,Hârseni,Hîrşeni', 45.7500000, 25.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116339, 'Hârlău', 'Harlau', 'Harlau,Hirlau,Hârlau,Hîrlău', 47.4333300, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116340, 'Hinova', 'Hinova', 'Hinova', 44.5405600, 22.7769400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116341, 'Hilişeu-Horia', 'Hiliseu-Horia', 'Hiliseu-Curt,Hiliseu-Horia,Hiliseul Curt,Hilişeu-Curt,Hilişeu-Horia,Hilişeul Curt', 48.0333300, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116342, 'Hidişelu de Sus', 'Hidiselu de Sus', 'Hidiselu de Sus,Hidiselul-de Sus,Hidişelu de Sus,Hidişelul-de Sus', 46.9500000, 22.0500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116343, 'Hida', 'Hida', 'Hida,Hidalma,Hidalmas,Hidalmás', 47.0666700, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116344, 'Herla', 'Herla', '', 47.4428600, 26.0125400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116345, 'Hereclean', 'Hereclean', 'Hereclean', 47.2500000, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116346, 'Herculian', 'Herculian', 'Herculian,Magyarhermany,Magyarhermàny', 46.1340200, 25.7097700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116347, 'Herăști', 'Herasti', 'Herasti,Herăşti', 44.2117400, 26.3590300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116348, 'Hemeiuș', 'Hemeius', 'Hemeius,Hemeiusi,Hemeiuş,Hemeiuşi', 46.6264300, 26.8544000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116349, 'Heleșteni', 'Helesteni', '', 47.2030300, 26.8775500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116350, 'Helegiu', 'Helegiu', 'Helegiu,Helegiul', 46.3500000, 26.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116351, 'Heci', 'Heci', 'Heci,Heciu', 47.3432500, 26.6622600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116352, 'Havârna', 'Havarna', 'Havarna,Havirna,Havârna,Havîrna', 48.0666700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116353, 'Haţeg', 'Hateg', 'Hateg,Hatszeg,Haţeg,Hotzing,Hátszeg,Hötzing', 45.6166700, 22.9500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116354, 'Hășmaș', 'Hasmas', 'Belhagymas,Bélhagymás,Hagymas,Hagymás,Hatzmas,Hesmas,Hesmás', 46.5000000, 22.0833300, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116355, 'Hărțăgani', 'Hartagani', '', 46.0501200, 22.9218300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116356, 'Hărmăneștii Vechi', 'Harmanestii Vechi', 'Harmanesti-Vechi,Harmanestii Vechi,Hărmăneşti-Vechi,Hărmăneştii Vechi', 47.2773200, 26.8139400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116357, 'Hărmăneasa', 'Harmaneasa', 'Harmaneasa,Helesteni Harmaneasa,Helesteni Hărmăneasa,Hărmăneasa', 47.2000000, 26.8666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116358, 'Hărman', 'Harman', 'Harman,Herman,Honigberg,Hărman,Szaszhermany,Szászhermány', 45.7166700, 25.6833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116359, 'Hărău', 'Harau', 'Harau,Haraul,Hărău,Hărăul', 45.9000000, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116360, 'Hanu Conachi', 'Hanu Conachi', '', 45.5865000, 27.5948100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116361, 'Hănțești', 'Hantesti', 'Hantesti,Hănţeşti', 47.7550700, 26.3736600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116362, 'Hangu', 'Hangu', 'Hangu,Hangul', 47.0500000, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116363, 'Hăneşti', 'Hanesti', 'Hanescii,Hanesti,Hânescii,Hăneşti', 47.9166700, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116364, 'Hamcearca', 'Hamcearca', 'Hamcearca', 45.1166700, 28.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116365, 'Halmeu', 'Halmeu', 'Halmeriu,Halmeu', 47.9666700, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116366, 'Halmăşd', 'Halmasd', 'Halmajd,Halmasd,Halmăjd,Halmăşd', 47.1500000, 22.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116367, 'Hălmagiu', 'Halmagiu', 'Grosshalmagen,Halmagiu,Halmagy,Halmágy,Hamagiul,Hălmagiu,Hămagiul,Nagyhalmagy,Nagyhalmágy', 46.2666700, 22.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116368, 'Hălmăgel', 'Halmagel', 'Halmagel,Halmagy,Halmágy,Hălmăgel,Kishalmagy,Kishalmágy', 46.2666700, 22.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116369, 'Halânga', 'Halanga', 'Halanga,Halinga,Halânga,Halînga', 44.6811600, 22.6903700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116370, 'Hălchiu', 'Halchiu', 'Heldsdorf', 45.7666700, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116371, 'Hălăuceşti', 'Halaucesti', 'Halaucesti,Hălăuceşti', 47.1000000, 26.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116372, 'Hălărești', 'Halaresti', '', 46.3944700, 27.5561400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116373, 'Hăghig', 'Haghig', 'Haghig,Hăghig', 45.8333300, 25.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116374, 'Hăghiac', 'Haghiac', '', 46.3120000, 26.5184100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116375, 'Hăbeni', 'Habeni', '', 44.8562900, 25.6287300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116376, 'Gvardinița', 'Gvardinita', 'Gvardenita,Gvardeniţa,Gvardinita,Gvardiniţa', 44.3950500, 23.1463500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116377, 'Guşoeni', 'Gusoeni', 'Butari,Gusoeni,Guşoeni', 44.7333300, 24.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116378, 'Guruieni', 'Guruieni', 'Gureni,Gurueni,Ion T. Ghica', 44.0584500, 25.3965600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116379, 'Gurghiu', 'Gurghiu', 'Goergenyszentimre,Gorgeny,Gurghiu,Gurghiul,Görgényszentimre,Gőrgeny', 46.7666700, 24.8500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116380, 'Gurbediu', 'Gurbediu', 'Gurbediu,Gurbediul', 46.7937900, 21.8648000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116381, 'Gurbăneşti', 'Gurbanesti', 'Gurbanesti,Gurbăneşti', 44.3833300, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116382, 'Gurba', 'Gurba', '', 46.4675600, 21.7878900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116383, 'Gura Vulcanei', 'Gura Vulcanei', '', 45.0244200, 25.3959600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116384, 'Gura Viţioarei', 'Gura Vitioarei', '', 45.1500000, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116385, 'Gura Văii', 'Gura Vaii', 'Gura Vaei,Gura Vaii,Gura Văei,Gura Văii', 46.3333300, 26.7333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116386, 'Gura Văii', 'Gura Vaii', '', 46.2723400, 26.8260400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116387, 'Gura Văii', 'Gura Vaii', 'Gura Vai,Gura Vaii,Gura Văii', 44.6673200, 22.5564600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116388, 'Gura Vadului', 'Gura Vadului', 'Gura Vadului', 45.0500000, 26.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116389, 'Gura Teghii', 'Gura Teghii', 'Gura Teghii,Gura Teohii', 45.4833300, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116390, 'Gura Şuţii', 'Gura Sutii', 'Gura Sutei,Gura Sutii,Gura Şuţei,Gura Şuţii', 44.7500000, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116391, 'Gura Suhașului', 'Gura Suhasului', 'Ocnele Mari', 45.0880300, 24.2988600, 'RO', '2016-01-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116392, 'Gura Râului', 'Gura Raului', 'Gura Rauhii,Gura Rauhui,Gura Riului,Gura Rîului,Gura Răuhii,Gura Răuhui,Gura-Raului,Gura-Râului,Guraro,Guraró', 45.7333300, 23.9833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116393, 'Gura Putnei', 'Gura Putnei', '', 47.8995100, 25.5951000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116394, 'Gura Padinii', 'Gura Padinii', 'Gura Padina,Gura Padinei,Gura Padini,Gura Padinii', 43.7570400, 24.3161500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116395, 'Gura Ocniței', 'Gura Ocnitei', 'Gura Ocnitei', 44.9416600, 25.5684600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116396, 'Gura Ialomiței', 'Gura Ialomitei', 'Gura Ialomitei,Gura Ialomiţei', 44.7160800, 27.7531000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116397, 'Gura Humorului', 'Gura Humorului', 'Gura Homorului,Gura Humorului,Gura Khumoruluji,Gura-Gumoruluj,Gura-Humourlui,Gura-Khumoruluj,Guragumora,Opstina Gura Humorului,Opština Gura Humorului,gwra hwmwrwl,gwrh hwmwrwlwy,Гура Хуморулуји,Гура-Гуморулуй,Гура-Хуморулуй,Ґурагумора,גורא הומארא,גורה הומורולוי,گورا هومورول', 47.5500000, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116398, 'Gurahonţ', 'Gurahont', 'Baltele,Baltfalva,Balthelye,Baltyele,Báltfalva,Báltyele,Gurahoncz,Gurahont,Gurahonț,Honcto,Honctő,Iosasel,Iosaşel,Joszashely,Jószáshely', 46.2666700, 22.3500000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116399, 'Gura Foii', 'Gura Foii', 'Gura Foii', 44.7500000, 25.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116400, 'Gura Căluiu', 'Gura Caluiu', 'Gura Caluiu,Gura Caluiul,Gura Căluiu,Gura Căluiul', 44.4590300, 24.0354700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116401, 'Gura Caliţei', 'Gura Calitei', 'Gura Calitei,Gura Caliţei', 45.5833300, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116402, 'Gura Beliei', 'Gura Beliei', '', 45.2106400, 25.6494600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116403, 'Gulia', 'Gulia', '', 47.4120300, 26.6085400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116404, 'Gulia', 'Gulia', '', 44.5468700, 25.8730400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116405, 'Gugești', 'Gugesti', '', 46.7634200, 27.9005000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116406, 'Gugeşti', 'Gugesti', 'Gugesti,Gugeşti', 45.5666700, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116407, 'Grunji', 'Grunji', '', 45.5000000, 26.6500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116408, 'Grumăzeşti', 'Grumazesti', 'Deleni,Grumazesti,Grumăzeşti,Valea Suseni', 47.1333300, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116409, 'Gruiu', 'Gruiu', 'Gruiu,Gruiu-Fierbinti,Gruiu-Fierbinţi,Gruiul', 44.7333300, 26.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116410, 'Gruia', 'Gruia', 'Gruia', 44.2675000, 22.7047200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116411, 'Grozeşti', 'Grozesti', '', 46.9908300, 28.0505600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116412, 'Grozeşti', 'Grozesti', 'Grozesti,Grozeşti', 44.6500000, 23.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116413, 'Grozăvești', 'Grozavesti', '', 44.5688200, 25.4536000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116414, 'Groșii Țibleșului', 'Grosii Tiblesului', 'Grosi,Grosii Tiblesului,Groşi,Groşii Ţibleşului', 47.4898300, 24.0636800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116415, 'Groşi', 'Grosi', '', 47.6166700, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116416, 'Groși', 'Grosi', '', 47.0452500, 22.4796500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116417, 'Groșani', 'Grosani', '', 45.2482200, 25.9479500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116418, 'Gropșani', 'Gropsani', '', 44.4407200, 23.9704700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116419, 'Gropniţa', 'Gropnita', 'Gropnita,Gropniţa', 47.3500000, 27.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116420, 'Grojdibodu', 'Grojdibodu', 'Grojdibod,Grojdibodu,Grojdibodul', 43.7500000, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116421, 'Griviţa', 'Grivita', '', 46.1500000, 27.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116422, 'Griviţa', 'Grivita', '', 45.7166700, 27.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116423, 'Griviţa', 'Grivita', '', 44.7333300, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116424, 'Grinţieş', 'Grinties', 'Grinties,Grintiesul Mare,Grinţieş,Grinţieşul Mare', 47.0500000, 25.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116425, 'Grindu', 'Grindu', 'Grindu,Pisica', 45.4000000, 28.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116426, 'Grindu', 'Grindu', 'Grindu,Grindul', 44.7666700, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116427, 'Greoni', 'Greoni', '', 45.0890100, 21.6173100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116428, 'Greci', 'Greci', '', 45.1833300, 28.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116429, 'Greci', 'Greci', '', 44.6613200, 25.3434600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116430, 'Greci', 'Greci', 'Grec,Greci', 44.5500000, 23.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116431, 'Greci', 'Greci', 'Greci,Ion Kalinderu', 44.3302500, 24.5592300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116432, 'Greci', 'Greci', '', 44.2812500, 24.3523800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116433, 'Greceşti', 'Grecesti', 'Grecesti,Greceşti', 44.4500000, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116434, 'Greceanca', 'Greceanca', '', 45.0786300, 26.5446800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116435, 'Greblești', 'Greblesti', '', 45.4751400, 24.3118200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116436, 'Grebenişu de Câmpie', 'Grebenisu de Campie', 'Grebenisu de Cimpie,Grebenisul,Grebenisul-de-Campie,Grebenişu de Cîmpie,Grebenişul,Grebenişul-de-Câmpie', 46.6000000, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116437, 'Greaca', 'Greaca', '', 44.1094400, 26.3394400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116438, 'Grebănu', 'Grebanu', 'Grebanul,Grebănul', 45.3833300, 26.9666700, 'RO', '2015-11-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116439, 'Gratia', 'Gratia', 'Gratia,Gratia Mare', 44.4333300, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116440, 'Grăniceşti', 'Granicesti', 'Granicesti,Grăniceşti', 47.8166700, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116441, 'Grăniceri', 'Graniceri', 'Graniceri,Grăniceri,Otlaca,Ottlaka', 46.5166700, 21.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116442, 'Grămeşti', 'Gramesti', 'Gramesti,Grămeşti', 47.9166700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116443, 'Grajduri', 'Grajduri', 'Grajduri', 46.9666700, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116444, 'Grăjdana', 'Grajdana', '', 45.2086500, 26.6311400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116445, 'Grădiştea', 'Gradistea', 'Gradistea,Gradistea de Sus,Grădiştea,Grădiştea de Sus', 45.2666700, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116446, 'Gradiștea', 'Gradistea', '', 44.8880300, 26.5152000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116447, 'Grădiştea', 'Gradistea', '', 44.8666700, 23.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116448, 'Grădiştea', 'Gradistea', '', 44.6666700, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116449, 'Grădiştea', 'Gradistea', 'Cacomeanca,Gradistea,Grădiştea', 44.2333300, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116450, 'Grădiștea', 'Gradistea', '', 44.2106200, 26.1654700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116451, 'Grădinari', 'Gradinari', 'Cacova,Cacovo,Gradinari,Gradinarii,Gradinaril,Grădinari,Grădinarii,Grădinaril,Kakova', 45.1186100, 21.5988900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116452, 'Grădinari', 'Gradinari', 'Gradinari,Grădinari,Runcu Mic', 44.5666700, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116453, 'Grădina', 'Gradina', 'Gradina,Grădina,Taksoff,Toxof', 44.5552000, 28.4323600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116454, 'Grabăț', 'Grabat', 'Garabos,Garaboš,Grabacz,Grabat,Grabati,Grabatz,Grabaţ,Grabaţi,Grabácz', 45.8786100, 20.7423800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116455, 'Gottlob', 'Gottlob', 'Gotlob,Gottlob,Kises,Kisosz,Kisősz,Kišes', 45.9360000, 20.7116800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116456, 'Gostinu', 'Gostinu', 'Gostimil,Gostinu,Gostinul', 44.0000000, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116457, 'Goştinari-Văcăreşti', 'Gostinari-Vacaresti', 'Gostinari-Vacaresti,Gostinarii-Vacaresti,Gostinarii-Văcăreşti,Goştinari-Văcăreşti', 44.1833300, 26.2166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116458, 'Gostinari', 'Gostinari', 'Gostinari,Gostinari-Belu,Gostinarii-Belu,Goştinari-Belu', 44.1862400, 26.2280700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116459, 'Gostavăţu', 'Gostavatu', 'Gostavatu,Gostavatul,Gostavăţu,Gostavăţul,Gostovatu,Gostovăţu', 44.0833300, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116460, 'Goșmani', 'Gosmani', 'Barcu,Barcu-Gosmani,Barcul,Bircu Gosmani,Bârcu,Bârcu-Goşmani,Bârcul,Bîrcu Goşmani,Gosmani,Goşmani', 46.8362000, 26.7152200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116461, 'Goruni', 'Goruni', '', 47.1038900, 27.7185400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116462, 'Goruna', 'Goruna', '', 45.0869600, 25.9420200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116463, 'Goruia', 'Goruia', 'Goruia', 45.1872200, 21.7791700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116464, 'Gornet-Cricov', 'Gornet-Cricov', 'Cricov,Gornet-Cricov,Gornetu-Cricov', 45.0833300, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116465, 'Gornet', 'Gornet', 'Gornet,Gornetul-Cuib', 45.1166700, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116466, 'Gorneşti', 'Gornesti', 'Gernyeszeg', 46.6712900, 24.6475700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116467, 'Gorgota', 'Gorgota', '', 44.9762600, 25.5083700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116468, 'Gorgota', 'Gorgota', 'Gorgota', 44.7833300, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116469, 'Gorganu', 'Gorganu', '', 44.8424100, 25.0383800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116470, 'Goreni', 'Goreni', 'Dedradszeplok,Dedràdszèplok,Goreni', 46.8547400, 24.6556900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116471, 'Gorbăneşti', 'Gorbanesti', 'Gorbanesti,Gorbăneşti', 47.7833300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116472, 'Gorban', 'Gorban', 'Gorban', 46.8761100, 28.0788900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116473, 'Goranu', 'Goranu', 'Goranu,Goranul', 45.1052300, 24.3843100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116474, 'Gologanu', 'Gologanu', 'Gologanu,Gologanul', 45.6097900, 27.2709100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116475, 'Goleşti', 'Golesti', '', 45.6666700, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116476, 'Golești', 'Golesti', '', 44.8397000, 24.9653000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116477, 'Golăiești', 'Golaiesti', '', 47.2333300, 27.7000000, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116478, 'Goicea', 'Goicea', 'Goicea,Goicea Mare', 43.9166700, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116479, 'Gohor', 'Gohor', 'Gohor,Gohorul', 46.0666700, 27.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116480, 'Gogoşu', 'Gogosu', 'Gogosiu,Gogosu,Gogosul,Gogoşiu,Gogoşu,Gogoşul', 44.4166700, 23.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116481, 'Gogoşu', 'Gogosu', 'Gogosu,Gogosul,Gogoşu,Gogoşul', 44.3738900, 22.5930600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116482, 'Gogoşari', 'Gogosari', 'Gogosari,Gogosarii-Vechi,Gogoşari,Gogoşarii-Vechi', 43.8666700, 25.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116483, 'Goești', 'Goesti', '', 47.1565400, 27.1365900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116484, 'Goiești', 'Goiesti', '', 44.4833300, 23.7666700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116485, 'Godineşti', 'Godinesti', 'Godinesti,Godineşti', 45.0000000, 22.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116486, 'Godeni', 'Godeni', '', 45.2333300, 24.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116487, 'Godeanu', 'Godeanu', 'Godeanu,Godeanul', 44.8011100, 22.6086100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116488, 'Glogova', 'Glogova', 'Glogova', 44.9280600, 22.9066700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116489, 'Glodenii Gândului', 'Glodenii Gandului', 'Garbesti-Tibanesti,Girbesti-Tibanesti,Glodenii Gindului,Glodenii Gîndului,Gârbeşti-Ţibăneşti,Gîrbeşti-Ţibăneşti', 46.9515800, 27.2993800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116490, 'Glodeni', 'Glodeni', '', 45.0634500, 25.4534200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116491, 'Glodeni', 'Glodeni', 'Glodeni,Sarpatak,Sàrpatak', 46.6500000, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116492, 'Glodeni', 'Glodeni', 'Glodeni', 45.0166700, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116493, 'Glodeanu-Siliştea', 'Glodeanu-Silistea', 'Glodeanu-Silistea,Glodeanu-Siliştea,Glodeanul Silistea,Glodeanul Siliştea', 44.8333300, 26.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116494, 'Glodeanu-Sărat', 'Glodeanu-Sarat', 'Glodeanu-Sarat,Glodeanu-Sărat,Glodeanul Sarat,Glodeanul Sărat', 44.8666700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116495, 'Glod', 'Glod', 'Glod,La Glod', 45.2416300, 25.4499400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116496, 'Glina', 'Glina', '', 44.3833300, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116497, 'Glimboca', 'Glimboca', 'Glimboca,Novaci', 45.4833300, 22.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116498, 'Glăvăneşti', 'Glavanesti', 'Glavanesii,Glavanesti,Glavăneşii,Glăvăneşti', 46.2500000, 27.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116499, 'Giuvărăşti', 'Giuvarasti', 'Giuvarasti,Giuvaresti,Giuvăreşti,Giuvărăşti', 43.8000000, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116500, 'Giurtelecu Șimleului', 'Giurtelecu Simleului', 'Giurletecu-Simleului,Giurtelecu-Simleului,Giurtelecu-Şimleului,Giurtelecul Simleului,Giurtelecul Şimleului,Giurtelecul-Simeului,Giurtelecul-Şimeului', 47.2968000, 22.7955700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116501, 'Giurgiu', 'Giurgiu', 'Giurgiu,Gjurgevo,Gyurgyevo,Gyurgyevó,Yergogu,Yergoğu,giurgiu,Гюргево,გიურგიუ', 43.8833300, 25.9666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116502, 'Giurgiţa', 'Giurgita', 'Giurgita,Giurgiţa', 44.0166700, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116503, 'Giurgeni', 'Giurgeni', 'Giurgeni', 44.7666700, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116504, 'Giulvăz', 'Giulvaz', 'Gilwas,Giulvaz,Giulvăz,Gyulvesz,Gyulvez,Gyulvéz,Gyülvész,Julves,Torontalgyulvesz,Torontálgyülvész', 45.5488900, 20.9844400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116505, 'Giuleşti', 'Giulesti', 'Giulesti,Giuleşti', 47.8166700, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116506, 'Giubega', 'Giubega', 'Giubega', 44.1274000, 23.4075700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116507, 'Girov', 'Girov', 'Girov', 46.9500000, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116508, 'Giroc', 'Giroc', 'Giroc,Gjirok,Gyirok,Gyuereg,Gyurok,Gyüreg,Gyürök', 45.6941700, 21.2358300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116509, 'Gârnic', 'Garnic', 'Garnic,Gernik,Girnic,Gârnic,Gîrnic', 44.7863900, 21.7944400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116510, 'Gârliciu', 'Garliciu', 'Garliciu,Garliciul,Girliciu,Gârliciu,Gârliciul,Gîrliciu', 44.7666700, 28.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116511, 'Gârleni', 'Garleni', 'Garleni,Girleni,Gârleni,Gîrleni', 46.6666700, 26.8000000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116512, 'Gârla-Mare', 'Garla-Mare', 'Garla-Mare,Girla Mare,Gârla-Mare,Gîrla Mare', 44.2091700, 22.7750000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116513, 'Girișu de Criș', 'Girisu de Cris', 'Girisul-de-Cris,Girişul-de-Criş,Koeroesgyeres,Körösgyéres', 47.0641600, 21.7610800, 'RO', '2015-11-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116514, 'Gârdani', 'Gardani', 'Gardani,Girdani,Gîrdani,Gărdani', 47.5513500, 23.3088000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116515, 'Gârda de Sus', 'Garda de Sus', 'Felsogirda,Felsőgirda,Garda de Sus,Girda de Sus,Gârda de Sus,Gîrda de Sus', 46.4500000, 22.8166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116516, 'Gârcov', 'Garcov', 'Garcovu,Garcovul,Gircov,Gârcovu,Gârcovul,Gîrcov', 43.7666700, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116517, 'Gârcina', 'Garcina', 'Gircina,Gircina de Jos,Gîrcina,Gîrcina de Jos', 46.9769100, 26.3457300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116518, 'Gârceni', 'Garceni', 'Garceni,Girceni,Gârceni,Gîrceni', 46.7666700, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116519, 'Gârbovi', 'Garbovi', 'Garbovi,Girbovi,Gârbovi,Gîrbovi', 44.7833300, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116520, 'Gârbova', 'Garbova', 'Garbova,Girbova,Gârbova,Gîrbova', 45.8666700, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116521, 'Gârbou', 'Garbou', 'Garbou,Girbou,Gârbou,Gîrbou', 47.1500000, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116522, 'Gârbești', 'Garbesti', 'Girbesti,Girbesti Mari,Girbesti Mici,Gîrbeşti,Gîrbeşti Mari,Gîrbeşti Mici,Palanca', 46.9833300, 27.3000000, 'RO', '2015-11-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116523, 'Gârbău', 'Garbau', 'Garbau,Garbaul,Girbau,Gârbăul,Gîrbău,Gărbău', 46.8330500, 23.3524000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116524, 'Gângiova', 'Gangiova', 'Gangeova,Gangiova,Ghinjova,Gingiova,Gângeova,Gângiova,Gîngiova', 43.9000000, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116525, 'Gâlgău Almaşului', 'Galgau Almasului', 'Galgau,Gilgau,Gilgau Almasului,Gâlgău,Gîlgău,Gîlgău Almaşului', 47.2000000, 23.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116526, 'Gâlgău', 'Galgau', 'Galgau,Gilgau,Gâlgău,Gîlgău', 47.2818300, 23.7015700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116527, 'Gâldău', 'Galdau', 'Galdau,Galdaul,Gildau,Gâldău,Gâldăul,Gîldău', 44.3054400, 27.6697200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116528, 'Gilău', 'Gilau', 'Gyalu', 46.7324500, 23.3617400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116529, 'Gighera', 'Gighera', 'Gighera', 43.8500000, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116530, 'Giera', 'Giera', 'Djer,Ger,Gier,Giera,Gyer,Gyér,Gér', 45.4072200, 20.9922200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116531, 'Gâdinţi', 'Gadinti', 'Gadinti,Gidinti,Gîdinţi,Gădinţi', 46.9333300, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116532, 'Giarmata-Vii', 'Giarmata-Vii', '', 45.7996000, 21.3002600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116533, 'Giarmata', 'Giarmata', 'Giarmata,Gyarmata,Gyarmatha,Jahrmarkt,Temesgyarmat', 45.8383300, 21.3108300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116534, 'Ghizela', 'Ghizela', 'Ghizela,Giseladorf,Giselladorf,Gizela,Gizellafalva', 45.8241700, 21.7372200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116535, 'Ghizdăvești', 'Ghizdavesti', '', 44.0575700, 24.1081100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116536, 'Ghiroda', 'Ghiroda', 'Ghiroda,Ghiroda Noua,Ghiroda Nouă,Giroda,Gyoroed,Győröd', 45.7638900, 21.3002800, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116537, 'Ghirdoveni', 'Ghirdoveni', '', 44.9405900, 25.6736800, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116538, 'Ghioșești', 'Ghiosesti', 'Chiosesti,Ghiosesti,Ghioşeşti', 45.2423500, 25.6267100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116539, 'Ghioroiu', 'Ghioroiu', 'Ghioroiu,Ghioroiul', 44.7000000, 23.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116540, 'Ghioroc', 'Ghioroc', 'Ghiorac,Ghioroc,Gioroc,Gyorok', 46.1500000, 21.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116541, 'Ghiorac', 'Ghiorac', 'Gherac,Ghiorac', 46.7134000, 21.6830900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116542, 'Ghinești', 'Ghinesti', '', 44.7477400, 25.5530000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116543, 'Ghindeni', 'Ghindeni', 'Ghindeni', 44.2122300, 23.9233600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116544, 'Ghindari', 'Ghindari', 'Makfalva,Makkafalva', 46.5000000, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116545, 'Ghindăreşti', 'Ghindaresti', 'Ghindaresti,Ghindăreşti,Ghizaresti,Ghizăreşti', 44.6500000, 28.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116546, 'Ghindăoani', 'Ghindaoani', 'Ghindaoani,Ghindăoani,Vasile-Conta', 47.1098300, 26.3390900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116547, 'Ghimpețeni', 'Ghimpeteni', 'Ghimpeteni,Ghimpeţeni', 44.2810100, 24.7745800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116548, 'Ghimpați', 'Ghimpati', 'Ghimpati,Ghimpaţi,Salcioara,Sălcioara', 44.1958600, 25.7833600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116549, 'Ghimpați', 'Ghimpati', '', 44.1535900, 24.4269800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116550, 'Ghimeş-Făget', 'Ghimes-Faget', 'Ghimes-Faget,Ghimeş-Făget,Gyimesbuekk,Gyimesbükk', 46.5833300, 26.0666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116551, 'Ghimeș', 'Ghimes', '', 46.5682100, 26.0888600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116552, 'Ghimbav', 'Ghimbav', 'Ghimbav,Vidombak,Vidombák', 45.6666700, 25.5000000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116553, 'Ghilad', 'Ghilad', 'Ghilad,Gilad,Gilád', 45.4650100, 21.1382400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116554, 'Ghighișeni', 'Ghighiseni', 'Ghighiseni,Ghighișeni,Gyegyeseny,Gyegyesény,Gyigyiseny-Vojen,Gyigyisény-Vojén', 46.5514100, 22.4314800, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116555, 'Ghidigeni', 'Ghidigeni', 'Ghidigeni,Ghidigenii', 46.0500000, 27.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116556, 'Ghidici', 'Ghidici', 'Ghidici,Ghidiciu,Ghidicu', 43.8910300, 23.1945400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116557, 'Ghidfalău', 'Ghidfalau', 'Ghidfalau,Ghidfalaul,Ghidfalău,Ghidfalăul,Ghidialau,Ghidialău,Gidofalva,Gidófalva', 45.9000000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116558, 'Gheaba', 'Gheaba', 'Gheaba,Ghiaba', 45.3091600, 26.0062600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116559, 'Gherteniș', 'Ghertenis', 'Gertenisch,Gertenyes,Gertinesti,Ghertenis,Gherteniş,Gnertenis,Gnerteniš,Gyertyanos,Gyertyános', 45.4331500, 21.5812600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116560, 'Gherţa Mică', 'Gherta Mica', 'Gherta Mica,Gherţa Mică', 47.9333300, 23.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116561, 'Gherța Mare', 'Gherta Mare', '', 47.9688400, 23.2085300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116562, 'Ghermănești', 'Ghermanesti', '', 46.8299800, 28.0810500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116563, 'Ghermănești', 'Ghermanesti', '', 44.6882900, 26.1496200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116564, 'Gherla', 'Gherla', 'Gerla,Gherla,Opstina Gherla,Opština Gherla,Szamosujvar,Szamosújvár,gai er la,gerura,grlh,Герла,Գեռլա,גרלה,گرله,ゲルラ,蓋爾拉', 47.0333300, 23.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116565, 'Gherghiţa', 'Gherghita', 'Gherghita,Gherghiţa', 44.8000000, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116566, 'Ghergheşti', 'Gherghesti', 'Micesti,Miceşti', 46.5000000, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116567, 'Ghergheasa', 'Ghergheasa', 'Ghergheasa,Ghergheasa-Veche,Neculai Iorga', 45.2666700, 27.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116568, 'Gherăseni', 'Gheraseni', 'Gheraseni,Gherăşeni', 45.0258900, 26.7912800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116569, 'Gherăeşti', 'Gheraesti', 'Gheraesti,Gherăeşti', 47.0166700, 26.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116570, 'Gheorgheni', 'Gheorgheni', 'Georgen'',Georgeni,Gheorghem,Gheorgheni,Gheorghieni,Gyergoszentmiklos,Gyergyo,Gyergyoszentmiklos,Gyergyószentmiklós,Gyergòszentmiklòs,Opstina Gheorgheni,Opština Gheorgheni,ge ao er gai ni,georgieni,georugeni,gywrgh,Георгени,Георгень,گئورگه,გეორგიენი,ゲオルゲニ,格奧爾蓋尼', 46.7229200, 25.6005500, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116571, 'Gheorghieni', 'Gheorghieni', 'Gheorgheni,Gheorghieni,Giurfalau,Giurfalău', 46.7139300, 23.6885300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116572, 'Gheorghe Lazăr', 'Gheorghe Lazar', '', 44.6333300, 27.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116573, 'Onesti', 'Onesti', 'Onesti,Onestii,Oneşti,Oneştii,Onești,Onyest', 46.2500000, 26.7500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116574, 'Gheorghe Doja', 'Gheorghe Doja', 'Dozsa Gyorgy,Dòzsa György,Gheorghe Doja,Luca', 46.4666700, 24.5000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116575, 'Gheorghe Doja', 'Gheorghe Doja', '', 46.3783100, 26.9624800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116576, 'Ghelinţa', 'Ghelinta', 'Gelence,Gelencze,Ghelinta,Ghelinţa', 45.9500000, 26.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116577, 'Ghelari', 'Ghelari', 'Ghelar,Gyalar,Gyalár', 45.7166700, 22.7833300, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116578, 'Gheja', 'Gheja', '', 46.4472700, 24.0649100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116579, 'Gheboieni', 'Gheboieni', 'Gheboeni,Gheboieni', 44.9870100, 25.3067000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116580, 'Gheboaia', 'Gheboaia', '', 44.8020300, 25.7487500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116581, 'Gepiu', 'Gepiu', 'Gepiu,Gepiul', 46.9303400, 21.7901600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116582, 'Gioseni', 'Gioseni', 'Geoseni,Gioseni', 46.4292500, 26.9923900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116583, 'George Enescu', 'George Enescu', 'George Enescu,Gheorghe Doja,Liveni Virnav,Liveni Vîrnav,Liventi Varnov,Liventi Vârnov', 48.0333300, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116584, 'Geoagiu', 'Geoagiu', 'Geoagiu,Geoagiul', 45.9166700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116585, 'Gemeni', 'Gemeni', '', 44.1726500, 23.0825100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116586, 'Gemenele', 'Gemenele', 'Gemenele', 45.2833300, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116587, 'Gemenea Brătulești', 'Gemenea Bratulesti', 'Gemenea,Gemenea-Bratuleesti,Gemenea-Bratulesti,Gemenea-Brătuleeşti,Gemenea-Brătuleşti', 45.1083900, 25.2315500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116588, 'Gelu', 'Gelu', 'Chetfel,Colonia Mica,Colonia Mică,Gelu,Gelul,Ketfel,Kistelep,Kleinsiedel,Kétfél', 46.0059100, 21.0600200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116589, 'Geamăna', 'Geamana', '', 44.8200500, 24.8910900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116590, 'Geaca', 'Geaca', 'Geaca', 46.8666700, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116591, 'Găzărie', 'Gazarie', 'Garlele Gazarii,Gazarie,Girlele Gazariei,Gârlele Găzării,Gîrlele Găzăriei,Găzărie', 46.4892800, 26.5187700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116592, 'Gavojdia', 'Gavojdia', 'Gavojdia', 45.6166700, 22.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116593, 'Găvănești', 'Gavanesti', '', 45.0882500, 27.0649900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116594, 'Găvănești', 'Gavanesti', 'Gavanesti,Găvăneşti', 44.4172400, 24.0165400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116595, 'Găujani', 'Gaujani', 'Gaujani,Găujani', 43.7333300, 25.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116596, 'Gătaia', 'Gataia', 'Gataia,Gataja,Gatalja,Gattaj,Gattaja,Gattáj,Gehtaja,Getaja,Gátalja,Gáttája,Gătaia,Opstina Gataia,Opština Gãtaia,ge ta ya,gtaya,Гатая,Гатаја,Гетая,Гэтая,گتایا,格塔亞', 45.4311100, 21.4300000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116597, 'Garvăn', 'Garvan', '', 45.3471000, 28.1618700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116598, 'Garoafa', 'Garoafa', 'Garoafa,Guroala', 45.7833300, 27.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116599, 'Gărăgău', 'Garagau', '', 44.2318600, 25.1892000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116600, 'Dâlga-Gară', 'Dalga-Gara', '', 44.4333300, 27.0500000, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116601, 'Găneşti', 'Ganesti', 'Ganesti,Ganfalau,Ganfalău,Găneşti', 46.3333300, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116602, 'Gănești', 'Ganesti', '', 46.0897000, 27.9933700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116603, 'Găneasa', 'Ganeasa', '', 44.4833300, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116604, 'Găneasa', 'Ganeasa', '', 44.4166700, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116605, 'Galșa', 'Galsa', '', 46.2881000, 21.6513700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116606, 'Galoșpetreu', 'Galospetreu', 'Galos-Petreiu,Galospetreu,Galoşpetreu', 47.4834500, 22.2173000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116607, 'Galiciuica', 'Galiciuica', 'Galiciuica', 44.1032400, 23.3906700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116608, 'Galicea Mare', 'Galicea Mare', 'Galicea Mare', 44.1000000, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116609, 'Galicea', 'Galicea', 'Galicea', 44.9166700, 24.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116610, 'Găleşti', 'Galesti', 'Galesti,Găleşti,Nyaradgalfalva,Nyàràdgàlfalva', 46.5166700, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116611, 'Galda de Jos', 'Galda de Jos', 'Alsogald,Alsógáld,Galda de Jos', 46.1833300, 23.6166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116612, 'Gălbinaşi', 'Galbinasi', '', 45.0833300, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116613, 'Gălbinași', 'Galbinasi', 'Galbinasi,Gălbinaşi', 44.3172400, 26.4194100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116614, 'Galbenu', 'Galbenu', 'Galbenu,Galbenul', 45.2166700, 27.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116615, 'Galbeni', 'Galbeni', '', 46.4566100, 26.9466400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116616, 'Gălăuţaş', 'Galautas', 'Galautas,Galautasi,Galocas,Galócaş,Gălăuţaş,Gălăuţaşi', 46.9166700, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116617, 'Galaţii Bistriţei', 'Galatii Bistritei', 'Galatii Bistritei,Galaţii Bistriţei', 46.9833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116618, 'Galaţi', 'Galati', 'Galac,Galacis,Galacz,Galati,Galats,Galatz,Galaz,Galaţi,Galați,Gałacz,Nkalatsi,galatsy,gallachi,garatsu~i,ghalats,glatsy,jia la ci,Γκαλάτσι,Галатс,Галац,גאלאץ,גאלץ,غالاتس,گالاتسی,گلاتسی,ガラツィ,加拉茨,갈라치', 45.4500000, 28.0500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116619, 'Gălăţeni', 'Galateni', 'Galateni,Galeteni,Găleteni,Gălăţeni', 44.2166700, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116620, 'Gălășești', 'Galasesti', 'Galasesti,Galesesti,Gălesesti,Gălăşeşti', 44.9559300, 24.7860200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116621, 'Gălăneşti', 'Galanesti', 'Galanesti,Gălăneşti', 47.9166700, 25.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116622, 'Găiseni', 'Gaiseni', 'Gaiseni,Găiseni', 44.5150000, 25.6452800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116623, 'Găinești', 'Gainesti', '', 47.4196800, 25.9180900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116624, 'Găiceana', 'Gaiceana', 'Gaiceana,Găiceana,Tirgu Gaiceana,Tîrgu Găiceana', 46.3333300, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116625, 'Găgeşti', 'Gagesti', 'Gagesti,Găgeşti', 46.3333300, 27.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116626, 'Găgești', 'Gagesti', '', 45.8559800, 27.0554000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116627, 'Găgeni', 'Gageni', '', 45.0216400, 25.9458500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116628, 'Găeşti', 'Gaesti', 'Gaesti,Găeşti', 44.7166700, 25.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116629, 'Furtunești', 'Furtunesti', 'Furtunesti,Furtunestii,Furtuneşti,Furtuneştii', 45.4594000, 26.3976000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116630, 'Furculești', 'Furculesti', 'Furculesti,Furculeşti', 43.8720200, 25.1428500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116631, 'Furcenii Noi', 'Furcenii Noi', '', 45.8111800, 27.3395400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116632, 'Fundu Răcăciuni', 'Fundu Racaciuni', 'Fundu Racaciuni,Fundu Răcăciuni,Racaciuni,Răcăciuni', 46.3586400, 26.8898700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116633, 'Fundu Moldovei', 'Fundu Moldovei', 'Fundu Moldovei,Fundul Moldovei,Moldova', 47.5333300, 25.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116634, 'Fundulea', 'Fundulea', 'Fundule,Fundulea,Fundulele', 44.4666700, 26.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116635, 'Fundeni', 'Fundeni', 'Fundeni,Ion C. Bratianu', 45.5412300, 27.5405600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116636, 'Fundeni', 'Fundeni', 'Fundeni,Fundeni-Zarnesti,Fundeni-Zărneşti', 45.2914100, 26.8802800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116637, 'Fundeni', 'Fundeni', '', 44.4589200, 26.1656500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116638, 'Fundeni', 'Fundeni', 'Fundeni,Fundenii', 44.3833300, 26.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116639, 'Fundata', 'Fundata', 'Fundata,Fundáta', 45.4500000, 25.3000000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116640, 'Fulga de Sus', 'Fulga de Sus', '', 44.9000000, 26.4500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116641, 'Fulga de Jos', 'Fulga de Jos', '', 44.8815200, 26.4425800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116642, 'Frunzi', 'Frunzi', '', 46.9000000, 24.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116643, 'Fruntișeni', 'Fruntiseni', 'Fruntisani,Fruntiseni,Fruntişani,Fruntişeni', 46.2063400, 27.7690400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116644, 'Frumuşiţa', 'Frumusita', 'Frumusita,Frumuşiţa', 45.6666700, 28.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116645, 'Frumuşica', 'Frumusica', 'Frumusica,Frumusica-Targ,Frumuşica,Frumuşica-Târg,Targ Frumusica,Târg Frumuşica', 47.5333300, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116646, 'Frumușelu', 'Frumuselu', 'Frumuselu,Frumuselul,Frumuşelu,Frumuşelul', 46.2779600, 27.3520300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116647, 'Frumuşani', 'Frumusani', 'Frumusani,Frumuşani', 44.2961100, 26.3255600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116648, 'Frumosu', 'Frumosu', 'Frumosu,Frumosul', 47.6166700, 25.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116649, 'Frumoasa', 'Frumoasa', '', 46.6629800, 26.5419600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116650, 'Frumoasa', 'Frumoasa', 'Frumoasa,Szepviz,Szépviz', 46.4500000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116651, 'Frumoasa', 'Frumoasa', 'Frumoasa', 43.8000000, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116652, 'Frecăţei', 'Frecatei', 'Frecatei,Frecăţei,Frekatei', 45.1000000, 28.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116653, 'Frecăţei', 'Frecatei', '', 44.9000000, 28.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116654, 'Fratoștița', 'Fratostita', '', 44.5867100, 23.5704400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116655, 'Frăteşti', 'Fratesti', '', 43.9666700, 25.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116656, 'Frătăuţii Vechi', 'Fratautii Vechi', 'Alftratautz,Deutsch Alftratautz,Fratautii Vechi,Fratautii Vechi German,Fratautii Vechi Roman,Fratiwci Stari Nimecki,Frawici Stari Rumunski,Frawici Stari Rumuński,Frătăuţii Vechi,Frătăuții Vechi,Frătăuții Vechi Germân,Frătăuții Vechi Român,Rumaenisch Altfratautz,Rumänisch Altfratautz', 47.9000000, 25.8833300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116657, 'Frătăuţii Noi', 'Fratautii Noi', 'Fratauti-Noi,Fratautii Noi,Fratautii Noui,Fratiwci Nowi,Frătăuţi-Noi,Frătăuţii Noui,Frătăuții Noi,Neufratautz', 47.9425700, 25.8446500, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116658, 'Frata', 'Frata', 'Frata', 46.7000000, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116659, 'Frăsinet', 'Frasinet', 'Frasinet,Frasinetul,Frăsinet,Frăsinetul', 44.3166700, 26.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116660, 'Frăsinet', 'Frasinet', 'Frasinet,Frasinetu,Frăsinet,Frăsinetu', 44.1803800, 25.3823800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116661, 'Frasin', 'Frasin', 'Frasin', 47.5333300, 25.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116662, 'Forotic', 'Forotic', 'Forotic,Forotik', 45.2302800, 21.5875000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116663, 'Forău', 'Forau', '', 46.7107000, 22.2011300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116664, 'Forăşti', 'Forasti', 'Forasti,Forăşti', 47.3500000, 26.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116665, 'Folteşti', 'Foltesti', 'Foltesti,Folteşti', 45.7500000, 28.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116666, 'Foglaş', 'Foglas', '', 47.2500000, 22.5333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116667, 'Foieni', 'Foieni', '', 47.7000000, 22.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116668, 'Foeni', 'Foeni', 'Feny,Foeni,Fény', 45.4986100, 20.8758300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116669, 'Focuri', 'Focuri', '', 47.3500000, 27.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116670, 'Focșani', 'Focsani', 'Focsani,Focşani,Focșani,Foksany,Fokschan,Fokshani,Foksány,Фокшани,פוקשאן,פוקשאני', 45.7000000, 27.1833300, 'RO', '2016-01-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116671, 'Floroaia', 'Floroaia', 'Floroaia,Floroaia Mare,Floroia-Mare', 45.6949700, 26.0156300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116672, 'Florica', 'Florica', 'Florica', 44.9080200, 26.7662700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116673, 'Floreşti', 'Floresti', 'Floresti,Floreşti', 46.7457400, 23.4937500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116674, 'Floreşti', 'Floresti', 'Floresti,Floreşti', 45.0500000, 25.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116675, 'Floreşti', 'Floresti', 'Floresti,Floreşti', 44.7630600, 22.9477800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116676, 'Florești', 'Floresti', '', 44.6191800, 23.5283800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116677, 'Florești', 'Floresti', 'Floresti,Floresti-de-Sus,Florestii de Sus,Floreşti,Floreşti-de-Sus,Floreştii de Sus', 44.5131300, 25.6965800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116678, 'Flămânzi', 'Flamanzi', 'Flamanzi,Flaminzi,Flămânzi,Flămînzi', 47.5500000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116679, 'Fizeşu Gherlii', 'Fizesu Gherlii', 'Fizesu Gherlii,Fizesul-Gherlei,Fizeşu Gherlii,Fizeşul-Gherlei,OErdoengoesfuezes,Ördöngösfüzes', 47.0166700, 23.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116680, 'Fizeș', 'Fizes', 'Fizes,Fizesch,Fizess,Fizeş,Krassofuzes,Krassófüzes', 45.3640300, 21.5951700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116681, 'Fitioneşti', 'Fitionesti', 'Fitionesti,Fitionestii,Fitioneşti,Fitioneştii', 45.9833300, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116682, 'Fâstâci', 'Fastaci', 'Fastaci,Fistici,Fâstâci,Fîstîci', 46.7305800, 27.4490100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116683, 'Fișer', 'Fiser', '', 46.0791200, 25.1510300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116684, 'Fârţăneşti', 'Fartanesti', 'Fartanesti,Firtanesti,Fârţăneşti,Fîrţăneşti', 45.8166700, 27.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116685, 'Fârliug', 'Farliug', 'Farliug,Firliug,Furluk,Fârliug,Fîrliug', 45.4883300, 21.8494400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116686, 'Fârdea', 'Fardea', 'Fardia,Firdea,Fârdia,Fîrdea', 45.7333300, 22.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116687, 'Fântânele', 'Fantanele', 'Fantanele,Fintinele,Fântânele,Fîntînele', 47.5746300, 26.5327700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116688, 'Fântânele', 'Fantanele', 'Fantanele,Fintinele,Fântânele,Fîntînele', 47.5166700, 26.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116689, 'Fântânele', 'Fantanele', 'Fintinele,Fintinele Noi,Fintinele Vechi,Fîntînele,Fîntînele Noi,Fîntînele Vechi', 47.4149800, 27.1806600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116690, 'Fântânele', 'Fantanele', 'Fantanele,Fintinele,Fântânele,Fîntînele,Gyulakuta', 46.4166700, 24.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116691, 'Fântânele', 'Fantanele', 'Angyalkut,Angyalkút,Engelsbrunn,Fantanele,Fintinele,Fântânele,Fîntînele,Kisfalud', 46.1237000, 21.3842000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116692, 'Fântânele', 'Fantanele', 'Fantanele,Fintinele,Fântânele,Fîntînele', 45.7015200, 28.0035400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116693, 'Fântânele', 'Fantanele', 'Fantanela,Fantanelele,Fintinele,Fontanelele,Fontânelele,Fântânela,Fântânelele,Fîntînele,Mazahi', 45.0070000, 26.3772000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116694, 'Fântânele', 'Fantanele', 'Fintinele,Fîntînele', 44.7166700, 25.8666700, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116695, 'Fântânele', 'Fantanele', 'Fantanele,Fantanelele,Fintinele,Fântânele,Fântânelele,Fîntînele,Inan Cisme,Inancismea,Inancişmea', 44.6127800, 28.5765500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116696, 'Fântânele', 'Fantanele', 'Fantanele,Fintinele,Fontanelile,Fontânelile,Fântânele,Fîntînele', 43.7210400, 25.2926500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116697, 'Fântâna Mare', 'Fantana Mare', 'Fantana-Mare,Fintina Mare,Font-Mare,Fântâna-Mare,Fîntîna Mare', 47.4143200, 26.3001500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116698, 'Finta Mare', 'Finta Mare', 'Finta,Finta Mare', 44.8000000, 25.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116699, 'Finiş', 'Finis', 'Fenes,Fenis,Finis,Finiș,Varasfenes,Várasfenes', 46.6333300, 22.3166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116700, 'Filipeştii de Târg', 'Filipestii de Targ', 'Filipestii de Targ,Filipestii de Tirg,Filipeştii de Târg,Filipeştii de Tîrg', 44.9833300, 25.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116701, 'Filipeştii de Pădure', 'Filipestii de Padure', 'Filipestii de Padure,Filipeştii de Pădure', 45.0000000, 25.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116702, 'Filipeşti', 'Filipesti', '', 46.7500000, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116703, 'Filipeni', 'Filipeni', 'Filipeni,Lunca', 46.5333300, 27.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116704, 'Filioara', 'Filioara', '', 47.1604000, 26.2792000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116705, 'Filiaşi', 'Filiasi', 'Filias,Filiasi,Filiaş,Filiaşi', 44.5500000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116706, 'Filiaș', 'Filias', 'Fiatfalva,Filias,Filiaş,Fiàtfalva', 46.2707500, 25.0212000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116707, 'Filia', 'Filia', 'Erdofule,Filia,Fule,Füle', 46.1440900, 25.6214000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116708, 'Fildu de Jos', 'Fildu de Jos', 'Felsofuld,Fildu de Jos,Fildul-de-Jos', 46.9333300, 23.0666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116709, 'Fierbinţi-Târg', 'Fierbinti-Targ', 'Ferbinti Tirg,Ferbinţi Tîrg,Fierbinti-Tirg,Fierbinţi-Tîrg,Targul Fierbinti,Tirgu Fierbinti,Târgul Fierbinti,Tîrgu Fierbinţi', 44.7000000, 26.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116710, 'Fierbinții de Sus', 'Fierbintii de Sus', 'Fierbinti,Fierbinti de Sus,Fierbintii-de-Sus,Fierbinţi,Fierbinţi de Sus,Fierbinţii-de-Sus', 44.6818600, 26.4020000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116711, 'Fierbinții de Jos', 'Fierbintii de Jos', 'Fierbinti de Jos,Fierbintii-de-Jos,Fierbinţi de Jos,Fierbinţii-de-Jos', 44.6952300, 26.3962900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116712, 'Fierbinți', 'Fierbinti', 'Ferbinti,Fierbinti,Fierbinţi', 44.5074700, 25.2876000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116713, 'Fieni', 'Fieni', 'Fieni,Fierii,Фиени', 45.1333300, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116714, 'Fibiș', 'Fibis', 'Febis,Febiş,Fibis,Fibisch,Fibiş,Temesfuves,Temesfüves', 45.9728000, 21.4235500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116715, 'Fetești-Gară', 'Fetesti-Gara', '', 44.4196000, 27.8253600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116716, 'Fetești', 'Fetesti', '', 47.4093200, 26.9088500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116717, 'Feteşti', 'Fetesti', 'Fetesti,Feteşti', 44.3833300, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116718, 'Ferești', 'Feresti', 'Feresti,Fereşti', 46.7817900, 27.7009300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116719, 'Ferestrău-Oituz', 'Ferestrau-Oituz', 'Ferastrau Oituz,Ferăstrău Oituz,Fierastraul', 46.2024900, 26.5762900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116720, 'Feneș', 'Fenes', '', 46.1043100, 23.2951100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116721, 'Felnac', 'Felnac', 'Felnac,Fenlak,Fonlak,Fönlak', 46.1166700, 21.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116722, 'Feliceni', 'Feliceni', 'Feliceni,Felsoboldogfalva', 46.2666700, 25.2666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116723, 'Feleacu', 'Feleacu', 'Erdoefelek,Erdöfelek,Feleac,Feleacu,Feleacul', 46.7166700, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116724, 'Feldru', 'Feldru', 'Feldru,Feldrul', 47.2833300, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116725, 'Feldioara', 'Feldioara', 'Feldioara,Foeldvar,Földvár,Marienburg', 45.8166700, 25.6000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116726, 'Feisa', 'Feisa', '', 46.2260800, 24.1449200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116727, 'Făureşti', 'Fauresti', 'Fauresti,Făureşti', 44.5666700, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116728, 'Făurei', 'Faurei', '', 46.9166700, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116729, 'Făurei', 'Faurei', 'Faurei,Filimon Sarbu,Filimon Sirbu,Filimon Sârbu,Filimon Sîrbu,Făurei,I.C. Bratianu,I.C. Brătianu,Ion I. C. Bratianu', 45.0833300, 27.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116730, 'Fărtăţeşti', 'Fartatesti', 'Fartatesti,Firtatesti,Fîrtăţeşti,Fărtăţeşti', 44.7833300, 24.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116731, 'Fărcașu de Jos', 'Farcasu de Jos', 'Farcasele,Farcasele-de-Jos,Farcasu de Jos,Farcasul,Farcasul-de-Jos,Fărcaşele,Fărcaşele-de-Jos,Fărcaşu de Jos,Fărcaşul,Fărcaşul-de-Jos', 44.1353900, 24.4590100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116732, 'Fărcaș', 'Farcas', '', 44.6000000, 23.7500000, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116733, 'Fărcăşeşti', 'Farcasesti', 'Farcasesti,Fărcăşeşti', 44.8666700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116734, 'Fărcășeni', 'Farcaseni', 'Farcasani,Farcaseni,Fărcăşani,Fărcăşeni', 47.1598700, 26.8961500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116735, 'Fărcaşele', 'Farcasele', 'Farcasu de Sus,Farcasul de Sus,Fărcaşu de Sus,Fărcaşul de Sus', 44.1500000, 24.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116736, 'Grădinari', 'Gradinari', 'Farcasanca,Fărcăşanca,Gradinari,Gradinari Ciocanal,Gradinari Ciocanu,Gratia-Farcasanca,Gratia-Fărcăşanca,Grădinari,Grădinari Ciocanal,Grădinari Ciocanu', 44.3922200, 25.8155600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116737, 'Fărcaşa', 'Farcasa', '', 47.5833300, 23.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116738, 'Fărcaşa', 'Farcasa', '', 47.1666700, 25.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116739, 'Fărău', 'Farau', 'Farau,Faraul,Fărău,Fărăul', 46.3333300, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116740, 'Faraoaní', 'Faraoani', 'Faraoani,Faraoaní', 46.4333300, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116741, 'Fărăgău', 'Faragau', 'Faragau,Faragaul,Farago,Faragò,Fărăgău,Fărăgăul', 46.7666700, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116742, 'Fălticeni', 'Falticeni', 'Buciumeni,Falticeni,Falticenii Vechi,Falticheni,Falticsen,Falticsén,Fehlticheni,Felticenis,Feltichen'',Feltičenis,Fulticheni,Fălticeni,Fălticenii Vechi,Gradinile,Grădinile,Opriseni,Oprişeni,Opstina Falticeni,Opština Fãlticeni,Tampesti,Timpesti,Tâmpeşti,Tîmpeşti,faltychh,faruticheni,fu er di qie ni,pltyzn,Фалтичени,Фелтічень,Фълтичени,Фэлтичени,פלטיצן,فالتیچه,ファルティチェニ,弗爾蒂切尼', 47.4500000, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116743, 'Fălcoiu', 'Falcoiu', 'Falcoiu,Falcoiul,Fălcoiu,Fălcoiul', 44.2333300, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116744, 'Fălciu', 'Falciu', 'Falciu,Falciu Tirg,Falciu-Targ,Fălciu,Fălciu Tîrg,Fălciu-Târg', 46.2961100, 28.1408300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116745, 'Falcău', 'Falcau', '', 47.9108700, 25.4690800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116746, 'Falaștoaca', 'Falastoaca', '', 44.1909800, 26.1847500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116747, 'Făgetu', 'Fagetu', 'Fagetu,Făgetu,Scaioi,Scaiosi,Scăioi,Scăioşi', 45.1366800, 26.0201800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116748, 'Făgeţelu', 'Fagetelu', 'Fagetel,Fagetelu,Fagetelul,Făgeţel,Făgeţelu,Făgeţelul', 44.7833300, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116749, 'Făget', 'Faget', 'Biserica,Buha,Faget,Făget', 46.5889100, 26.0534900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116750, 'Făget', 'Faget', 'Facsad,Facsád,Faget,Fedzhet,Fehdzhet,Fudzhet,Opstina Faget,Opština Fãget,fjh,fu jie te,Фагет,Феджет,Фъджет,Фэджет,Фэҷет,فاگیٹ,فجه,弗傑特', 45.8500000, 22.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116751, 'Făgăraș', 'Fagaras', 'Fagaras,Fagarash,Fegerasas,Fegerash,Fegerašas,Fehgehrash,Fogaras,Fogarasch,Fogarasz,Fugurash,Făgăraş,Opstina Fagaras,Opština Fãgãraş,fagaras,fagarashu,fak a rach,fgrh,fu ge la shen,pegerashi,Фагараш,Фегераш,Фъгъраш,Фэгэраш,فاگاراس,فگره,ฟาการาช,ფეგერაში,ファガラシュ,弗格拉什', 45.8500000, 24.9666700, 'RO', '2015-11-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116752, 'Făclia', 'Faclia', 'Faclia,Facria,Făclia', 44.2803900, 28.1058300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116753, 'Făcăi', 'Facai', '', 44.2735600, 23.8202900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116754, 'Făcăeni', 'Facaeni', 'Facaeni,Făcăeni', 44.5666700, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116755, 'Ezeriş', 'Ezeris', 'Ezeres,Ezeris,Ezeriş,Iezeris,Iezeriş', 45.4108300, 21.8858300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116756, 'Estelnic', 'Estelnic', 'Estelnic,Esztebiek,Esztelnek', 46.1044500, 26.2126200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116757, 'Eşelniţa', 'Eselnita', 'Eselnita,Eşelniţa,Ieselnita,Ieşelniţa,Jeselnica,Jeselnita,Jeşelniţa', 44.6991700, 22.3622200, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116758, 'Ernei', 'Ernei', 'Erneiul,Nagyernye', 46.6050500, 24.6414800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116759, 'Eremitu', 'Eremitu', 'Eremitu,Eremitul,Nyaradremete,Nyàradremete', 46.6666700, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116760, 'Erbiceni', 'Erbiceni', 'Erbiceni', 47.2666700, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116761, 'Iepureşti', 'Iepuresti', 'Epuresti,Epureşti,Iepuresti,Iepureşti', 44.2580600, 25.8822200, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116762, 'Epureni', 'Epureni', '', 46.7076900, 28.0382900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116763, 'Epureni', 'Epureni', 'Epureni', 46.2469300, 27.9112300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116764, 'Enisala', 'Enisala', 'Enisala,Yeni sala', 44.8795600, 28.8187200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116765, 'Emil Racoviță', 'Emil Racovita', 'Emil Racovita,Emil Racoviţă,Suranesti,Şurăneşti', 46.8714700, 27.6793700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116766, 'Eliseni', 'Eliseni', 'Eliseni,Szekelyszenterzsebet,Szèkelyszenterzsèbet', 46.2923500, 24.9372400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116767, 'Eftimie Murgu', 'Eftimie Murgu', 'Eftimie Murgu,Rudaria,Rudarija,Rudăria', 44.9002800, 22.0927800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116768, 'Eforie Sud', 'Eforie Sud', '', 44.0229400, 28.6494300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116769, 'Eforie Nord', 'Eforie Nord', '', 44.0653000, 28.6321100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116770, 'Eforie', 'Eforie', 'Baile Eforia,Băile Eforia,Eforia,Eforie,Ефорие', 44.0397300, 28.6468500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116771, 'Iedera de Sus', 'Iedera de Sus', '', 45.0417400, 25.6308400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116772, 'Iedera de Jos', 'Iedera de Jos', '', 45.0333300, 25.6333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116773, 'Durneşti', 'Durnesti', '', 47.7666700, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116774, 'Dunăreni', 'Dunareni', 'Dunareni,Dunăreni,Marleanu,Marleanul,Mirleanu,Mârleanu,Mârleanul,Mîrleanu', 44.2046300, 27.7905800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116775, 'Cârna', 'Carna', 'Carna,Cirna,Cârna,Cîrna,Dunareni,Dunăreni', 43.8861300, 23.6015300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116776, 'Dumitrița', 'Dumitrita', 'Dumitrita,Dumitriţa', 47.0714300, 24.6257900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116777, 'Dumitrești', 'Dumitresti', 'Dumitresti,Dumitresti de Jos,Dumitrestii de Jos,Dumitreşti,Dumitreştii de Jos', 45.5524300, 26.9272700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116778, 'Dumitrești', 'Dumitresti', '', 44.6837000, 24.3162800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116779, 'Dumitra', 'Dumitra', 'Dumitra', 47.2166700, 24.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116780, 'Dumeşti', 'Dumesti', '', 47.1833300, 27.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116781, 'Dumeşti', 'Dumesti', 'Cioate,Dumestii Noi,Dumeştii Noi', 46.8500000, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116782, 'Dumeni', 'Dumeni', '', 48.0072400, 26.5428700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116783, 'Dumbrăvița', 'Dumbravita', '', 48.0190000, 26.4272400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116784, 'Dumbrăviţa', 'Dumbravita', '', 47.6000000, 23.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116785, 'Dumbrăvița', 'Dumbravita', 'Dumbravita,Dumbravita de Jos,Dumbravita de Sus,Dumbrăviţa,Dumbrăviţa de Jos,Dumbrăviţa de Sus', 47.3984500, 26.3457800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116786, 'Dumbrăvița', 'Dumbravita', '', 47.2548300, 26.8416900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116787, 'Dumbrăviţa', 'Dumbravita', 'Dumbravita,Dumbrăviţa,Dumbrăvița,Neussentesch,Uisentes,Uisenteş,Ujszentes,Vadaszerdo,Vadászerdő,Újszentes', 45.7969400, 21.2425000, 'RO', '2015-04-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116788, 'Dumbrăviţa', 'Dumbravita', 'Schnackendorf,Tantari,Tintari,Ţânţari,Ţînţari', 45.7666700, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116789, 'Dumbrăveşti', 'Dumbravesti', 'Dumbravesti,Dumbrăveşti', 45.0833300, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116790, 'Dumbrăveni', 'Dumbraveni', '', 47.6500000, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116791, 'Dumbrăveni', 'Dumbraveni', 'Dumbraveni,Dumbrăveni,Elisabethstadt,Ibasfalau,Ibaşfalău', 46.2333300, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116792, 'Dumbrăveni', 'Dumbraveni', 'Dumbraveni,Dumbrăveni,Generalissimul Suvorov,Plainesti,Plăineşti,Suvorov,Targu Cucu,Targul Cucului,Tirgu Cucului,Târgu Cucu,Târgul Cucului', 45.5333300, 27.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116793, 'Dumbrăveni', 'Dumbraveni', 'Dumbraveni,Dumbrăveni,Hairanchioi', 43.9333300, 27.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116794, 'Dumbrava Roşie', 'Dumbrava Rosie', 'Dumbrava Rosie,Dumbrava Rosie din Deal,Dumbrava Roşie', 46.8833300, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116795, 'Dumbrava de Sus', 'Dumbrava de Sus', 'Baltati de Sus,Baltatii de Sus,Bălţaţii de Sus,Dumbrava de Sus', 44.5166700, 23.1166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116796, 'Dumbrava', 'Dumbrava', '', 47.8441800, 23.0806000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116797, 'Dumbrava', 'Dumbrava', 'Dumbrava,Grasi,Graşi', 47.2162000, 26.4630900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116798, 'Dumbrava', 'Dumbrava', 'Baba Nicula,Dumbrava,Dumbrava cu Baba Nicula', 47.0757800, 27.5517400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116799, 'Dumbrava', 'Dumbrava', 'Dumbrava,Gropile', 46.3096900, 26.8908700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116800, 'Dumbrava', 'Dumbrava', 'Dumbrava,Igazfalva', 45.8166700, 22.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116801, 'Dumbrava', 'Dumbrava', 'Dumbrava,Dumbrava-Netoti,Netoti,Netoţi', 44.8833300, 26.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116802, 'Dulceşti', 'Dulcesti', '', 46.9666700, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116803, 'Dulcești', 'Dulcesti', 'Dulcesti,Dulceşti,Kuchuk Tatligeak,Tatlageacu-Mic', 43.9050600, 28.5479600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116804, 'Dudu', 'Dudu', 'Dudu,Dudul', 43.9789700, 24.6778600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116805, 'Dudeştii Vechi', 'Dudestii Vechi', 'Altbeschenowa,Besenje,Besenova,Besenova Veche,Besenyo,Besenyő,Beşenova,Beşenova Veche,Bešenje,Dudestii Vechi,Dudeştii Vechi,Obesenyo,Obessenyo,Stara Beshenova,Óbesenyő,Óbessenyő', 46.0500000, 20.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116806, 'Dudeștii Noi', 'Dudestii Noi', 'Besenova Noua,Besenyo,Besenyő,Bessenova,Beşenova Nouă,Dudestii Noi,Dudeştii Noi,Neu-Beschenowa,Ujbesenyo,Újbesenyő', 45.8398900, 21.1021500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116807, 'Dudeşti', 'Dudesti', 'Dudesti,Dudeşti,Nicolesti-Jianu,Nicoleşti-Jianu,Niculesti Jianu,Niculeşti Jianu', 44.9000000, 27.4333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116808, 'Dudașu', 'Dudasu', 'Dudasi,Dudasu,Dudaşi,Dudaşu', 44.6525300, 22.6968300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116809, 'Duda', 'Duda', '', 46.7525000, 28.0372200, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116810, 'Dubova', 'Dubova', 'Dubova', 44.6166700, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116811, 'Drobeta-Turnu Severin', 'Drobeta-Turnu Severin', 'Drobeta,Drobeta - Turnu Severin,Drobeta Turnu Severin,Drobeta Turnu-Severin,Drobeta-Turnu Severin,Drobeta-Turnu Severinas,Drobeta-Turnu-Severin,Drubeta,Gorad Drabeta-Turnu-Severyn,Ntrompeta-Tournou Severin,Szoerenyvar,Szörényvár,Turnu Severin,Turnul Severin,atla drwbyta trnw,de luo bei ta-sai wei lin bao,deulobetatuleunusebelin,dor beta-thur nu se weri n,drwbta-twrnw swryn,drwbth-twrnw sbryn,drwbyta twrnw syfyryn,drwbyta-twrnw sywyryn,Ντρομπέτα-Τούρνου Σεβερίν,Горад Драбета-Турну-Северын,Дробета - Турну Северин,Дробета-Турну Северин,Дробета-Турну-Северин,Дробета-Турну-Северін,דרובטה-טורנו סברין,اتلا دروبیتا ترنو,دروبتا-تورنو سورین,دروبيتا تورنو سيفيرين,دروبیتا-تورنو سیویرین,โดรเบตา-ทูร์นูเซเวรีน,დრობეტა-ტურნუ-სევერინი,ドロベタ＝トゥルヌ・セヴェリン,德羅貝塔-塞維林堡,드로베타투르누세베린', 44.6319400, 22.6561100, 'RO', '2012-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116812, 'Băile Drânceni', 'Baile Dranceni', 'Baile Dranceni,Baile Drinceni,Băile Drânceni,Băile Drînceni,Dranceni Sat,Drinceni-Sat,Drânceni Sat,Drînceni-Sat', 46.8136100, 28.1008300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116813, 'Drânceni', 'Dranceni', 'Branceni,Dranceni,Dranceni Targ,Drinceni,Drinceni-Tirg,Drânceni,Drânceni Târg,Drînceni,Drînceni-Tîrg', 46.8014600, 28.1326400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116814, 'Dridu', 'Dridu', 'Dridu,Dridu-Movile,Dridul,Movila', 44.7000000, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116815, 'Drauț', 'Draut', 'Draut,Drauti,Drauţ,Drauţi', 46.2604800, 21.8092400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116816, 'Dranovățu', 'Dranovatu', 'Dranovatu,Dranovatul,Dranovăţu,Dranovăţul', 44.4361900, 24.2789400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116817, 'Drănic', 'Dranic', 'Dranic,Dranicu,Dranicul,Drănic,Drănicu,Drănicul', 44.0551900, 23.8467800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116818, 'Drajna Nouă', 'Drajna Noua', '', 44.4226200, 27.3800700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116819, 'Drajna de Sus', 'Drajna de Sus', '', 45.2570900, 26.0738800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116820, 'Drajna de Jos', 'Drajna de Jos', 'Drajna,Drajna de Jos', 45.2166700, 26.0500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116821, 'Drăguţeşti', 'Dragutesti', 'Dragutesti,Drăguţeşti', 44.9666700, 23.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116822, 'Drăguşeni', 'Draguseni', 'Draguseni,Dragusenii,Drăguşeni,Drăguşenii', 48.0166700, 26.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116823, 'Drăgușeni', 'Draguseni', '', 47.9054100, 23.0778000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116824, 'Drăguşeni', 'Draguseni', '', 47.2833300, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116825, 'Drăgușeni', 'Draguseni', 'Draguseni,Dragusenii,Drăguşeni,Drăguşenii,Holniul', 46.9011600, 27.5126000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116826, 'Drăguşeni', 'Draguseni', 'Diocheti,Diocheţi,Dragusen,Draguseni,Drăguşen,Drăguşeni', 45.9666700, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116827, 'Drăguș', 'Dragus', 'Dragus,Drăguş', 45.7614600, 24.7790600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116828, 'Drăgugești', 'Dragugesti', '', 46.3679600, 26.7743300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116829, 'Dragu', 'Dragu', 'Drag,Dragu,Dragul', 47.0166700, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116830, 'Drăgoteşti', 'Dragotesti', 'Dragotesti,Drăgoteşti', 44.8000000, 23.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116831, 'Drăgoteşti', 'Dragotesti', '', 44.2500000, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116832, 'Dragosloveni', 'Dragosloveni', 'Dragoslaveni,Dragosloveni,Dragoslăveni', 46.0000000, 26.6666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116833, 'Dragoș Vodă', 'Dragos Voda', '', 44.4333300, 27.1500000, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116834, 'Dragomireşti-Vale', 'Dragomiresti-Vale', 'Dragomiresti-Vale,Dragomiresti-din Vale,Dragomirestii din Vale,Dragomireşti-Vale,Dragomireşti-din Vale,Dragomireştii din Vale', 44.4750000, 25.9350000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116835, 'Dragomirești-Deal', 'Dragomiresti-Deal', 'Dragomiresti-Deal,Dragomiresti-din Deal,Dragomirestii-din Deal,Dragomireşti-Deal,Dragomireşti-din Deal,Dragomireştii-din Deal', 44.4624000, 25.9447800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116836, 'Dragomireşti', 'Dragomiresti', 'Dragomerfalu,Dragomerfalva,דראגאמירעשט', 47.6683900, 24.2911100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116837, 'Dragomireşti', 'Dragomiresti', 'Dragomiresti,Dragomireşti,Dragomirosti,Drăgomirosti', 47.0166700, 26.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116838, 'Dragomireşti', 'Dragomiresti', 'Dragomiresti,Dragomireşti,Dupa Deal,După Deal', 46.6333300, 27.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116839, 'Dragomireşti', 'Dragomiresti', '', 44.9166700, 25.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116840, 'Dragomir', 'Dragomir', '', 46.4137300, 26.6316300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116841, 'Drăgoeşti-Snagov', 'Dragoesti-Snagov', 'Dragoesti Znagov,Dragoesti-Snagov,Dragoestii-Snagov,Drăgoeşti Znagov,Drăgoeşti-Snagov,Drăgoeştii-Snagov,Znagov', 44.5666700, 26.5333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116842, 'Drăgoiești', 'Dragoiesti', '', 47.5500000, 26.0833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116843, 'Drăgoeşti', 'Dragoesti', '', 44.8166700, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116844, 'Drăgoești', 'Dragoesti', 'Dragoesti,Dragoesti-Maeni,Dragoestii-Maeni,Drăgoeşti,Drăgoeşti-Măeni,Drăgoeştii-Măeni,Maeni,Măeni', 44.5678600, 26.5395000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116845, 'Dragodănești', 'Dragodanesti', '', 45.0555200, 25.2363100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116846, 'Dragodana', 'Dragodana', 'Dragodana', 44.7333300, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116847, 'Drăghinești', 'Draghinesti', '', 44.4309300, 25.4260800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116848, 'Drăghici', 'Draghici', 'Draghici,Draghiciul,Drăghici', 45.1286500, 25.0450800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116849, 'Drăghiceni', 'Draghiceni', 'Draghiceni,Drăghiceni', 44.1333300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116850, 'Drăgeşti', 'Dragesti', 'Dragesti,Drăgeşti', 46.8833300, 22.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116851, 'Drăgăşani', 'Dragasani', 'Dragasani,Drehgehshani,Drăgăşani,Дрэгэшани', 44.6500000, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116852, 'Drăganu-Olteni', 'Draganu-Olteni', '', 44.9333300, 24.7166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116853, 'Drăgăneşti-Vlaşca', 'Draganesti-Vlasca', 'Draganasti,Draganesti,Draganesti-Vlasca,Drăgăneşti,Drăgăneşti-Vlaşca', 44.1013900, 25.5980600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116854, 'Drăgăneşti-Olt', 'Draganesti-Olt', 'Draganesti-Olt,Drăgăneşti-Olt', 44.1666700, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116855, 'Drăgăneşti de Vede', 'Draganesti de Vede', 'Draganesti,Draganesti de Vede,Drăgăneşti,Drăgăneşti de Vede', 44.1333300, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116856, 'Drăgănești', 'Draganesti', 'Draganesti,Drăgăneşti,Panuresti,Pănureşti', 47.3088600, 26.4055100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116857, 'Drăgăneşti', 'Draganesti', 'Draganesti,Draganfalva,Dragonyesd,Dragonyest,Dragánfalva,Drăgănești', 46.6166700, 22.3833300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116858, 'Drăgăneşti', 'Draganesti', '', 45.7833300, 27.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116859, 'Drăgăneşti', 'Draganesti', 'Draganesti,Drăgăneşti', 44.8166700, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116860, 'Drăgăneasa', 'Draganeasa', '', 45.1046700, 25.6813800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116861, 'Dragalina', 'Dragalina', '', 44.4333300, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116862, 'Drăgăești Ungureni', 'Dragaesti Ungureni', 'Dragaesti-Ungureni,Dragaestii Ungurenii,Drăgăestii Ungurenii,Drăgăeşti-Ungureni', 44.9455700, 25.3104800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116863, 'Draxini', 'Draxini', '', 47.6500000, 26.8166700, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116864, 'Dracșani', 'Dracsani', '', 47.6294500, 26.9302900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116865, 'Drăcşani', 'Dracsani', 'Dracsani,Dracsenei,Drăcşani,Drăcşenei', 44.2166700, 24.9833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116866, 'Dracea', 'Dracea', 'Dracea', 43.8491400, 25.0519400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116867, '23 August', '23 August', 'Domnita Elena,Domniţa Elena,Tatlageac Mare', 43.9166700, 28.5833300, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116868, 'Doştat', 'Dostat', 'Dostat,Doştat', 45.9666700, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116869, 'Dorolţ', 'Dorolt', 'Dorolt,Dorolti,Dorolţ,Dorolţi,Pusztadaroc,Pusztadaróc', 47.8500000, 22.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116870, 'Dorohoi', 'Dorohoi', 'Dorohoi,Dorohoiu,Dorohoj,Dorokhoj,Dorokhoy,Opstina Dorohoi,Opština Dorohoi,dorohoi,duo luo huo yi,dwrwhw,dwrwhwy,Дорохой,Дорохој,דורוחוי,دوروهو,ドロホイ,多羅霍伊', 47.9500000, 26.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116871, 'Dorobanţu', 'Dorobantu', 'Dorobantu,Dorobantul,Dorobanţu,Dorobanţul', 44.9500000, 28.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116872, 'Dorobanțu', 'Dorobantu', 'Dorobantu,Dorobantul,Dorobanţu,Dorobanţul', 44.4103500, 28.3268700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116873, 'Dorobanțu', 'Dorobantu', 'Dorobanti,Dorobantul,Dorobanţi,Dorobanţul', 44.3541600, 26.3934100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116874, 'Dorobanţu', 'Dorobantu', 'Dorobantu,Dorobantul,Dorobanţu,Dorobanţul', 44.2166700, 26.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116875, 'Dorobanți', 'Dorobanti', 'Dorobant,Dorobanţ', 47.8823400, 26.6472300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116876, 'Dorobanți', 'Dorobanti', '', 46.3502200, 21.2444100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116877, 'Dorneşti', 'Dornesti', 'Dornestie,Hadikfalva', 47.8717400, 26.0043000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116878, 'Dorna Cândrenilor', 'Dorna Candrenilor', 'Dorna Cindrenilor,Dorna Cîndrenilor,Dorna-Candrenilor,Dorna-Cândrenilor', 47.3500000, 25.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116879, 'Dor Mărunt', 'Dor Marunt', 'Dor Marunt,Dor Mărunt', 44.4500000, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116880, 'Dorgoş', 'Dorgos', '', 46.0500000, 21.8333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116881, 'Domnița', 'Domnita', '', 47.0209100, 27.3350000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116882, 'Domnești-Târg', 'Domnesti-Targ', 'Domnesti-Tirg,Domnești-Tîrg', 46.0166700, 27.1833300, 'RO', '2016-01-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116883, 'Domneşti-Sârbi', 'Domnesti-Sarbi', 'Domnesti-Sarbi,Domnesti-Sirbi,Domneşti-Sârbi,Domneşti-Sîrbi', 44.3833300, 25.9166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116884, 'Domneşti', 'Domnesti', 'Domnesti,Domnestii,Domneşti,Domneştii', 45.2000000, 24.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116885, 'Domnești', 'Domnesti', 'Domnesti,Domnesti Fort,Domnesti-de Sus,Domnestii de Sus,Domneşti,Domneşti Fort,Domneşti-de Sus,Domneştii de Sus', 44.3991900, 25.9161800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116886, 'Domaşnea', 'Domasnea', 'Domasnea,Domasnia,Domaşnea,Domaşnia', 45.0833300, 22.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116887, 'Domănești', 'Domanesti', 'Domahida,Domanesti,Domăneşti', 47.7107100, 22.5897500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116888, 'Doljeşti', 'Doljesti', 'Doljesti,Doljeşti', 47.0333300, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116889, 'Dolheștii Mici', 'Dolhestii Mici', 'Dolhestii Mici,Dolhestimic,Dolheştii Mici', 47.4363300, 26.5517800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116890, 'Dolheștii-Mari', 'Dolhestii-Mari', 'Dolhesti,Dolhesti Mari,Dolhestii Mari,Dolheştii Mari', 47.4502000, 26.5132600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116891, 'Dolhești', 'Dolhesti', '', 47.2118900, 26.0673800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116892, 'Dolheşti', 'Dolhesti', '', 46.8666700, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116893, 'Dolhasca', 'Dolhasca', 'Dolhasca', 47.4333300, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116894, 'Doiceşti', 'Doicesti', 'Doicesti,Doiceşti', 44.9833300, 25.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116895, 'Dognecea', 'Dognecea', 'Dogneca,Dognecea,Dogneča', 45.2741700, 21.7569400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116896, 'Dofteana', 'Dofteana', 'Doftana,Dofteana,Doftána', 46.3166700, 26.5166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116897, 'Doftana', 'Doftana', '', 45.1500000, 25.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116898, 'Dodești', 'Dodesti', 'Dodesti,Dodeşti', 46.3545500, 27.8931100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116899, 'Dodeni', 'Dodeni', 'Dedeni,Dodeni', 46.9258700, 26.0927700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116900, 'Ștei', 'Stei', 'Doctor Petru Groza,Dr. Petru Groza,Opstina Stei,Opština Ştei,Shhej,Shtej,Stei,Steiu,Stejus,Vaskohsziklas,Vaskohsziklás,shth,Ştei,Şteiu,Štėjus,Штей,Щей,شته', 46.5333300, 22.4500000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116901, 'Doclin', 'Doclin', 'Doclin,Doklin', 45.2969400, 21.6538900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116902, 'Dochia', 'Dochia', '', 46.9073100, 26.5676300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116903, 'Dobrușa', 'Dobrusa', '', 44.6264200, 24.2077900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116904, 'Dobrun', 'Dobrun', 'Dobrun,Dobrunu,Dobrunul', 44.2666700, 24.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116905, 'Dobrovăţ', 'Dobrovat', 'Dobrovat,Dobrovatii Rusi,Dobrovăţ,Dobrovăţii Rusi', 46.9500000, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116906, 'Dobrotu', 'Dobrotu', 'Dobrot,Dobrotu', 45.2063300, 24.6585900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116907, 'Dobrotinet', 'Dobrotinet', 'Catunu de Sus,Catunul de Sus,Cătunu de Sus,Dobrotinet', 44.4795700, 24.3473000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116908, 'Dobroteşti', 'Dobrotesti', 'Dobrotesti,Dobroteşti', 44.2833300, 24.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116909, 'Dobrotești', 'Dobrotesti', '', 43.9614100, 24.1240500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116910, 'Dobroteasa', 'Dobroteasa', 'Dobroteasa', 44.7833300, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116911, 'Dobrosloveni', 'Dobrosloveni', 'Dobrosloveni,Ion Gheorghe Duca', 44.1833300, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116912, 'Dobromir', 'Dobromir', 'Dobromir,Dobromir din Vale,Dobromir-Vale,Dobromiru,Dobromiru din Vale,Dobromirul din Vale', 44.0166700, 27.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116913, 'Dobroeşti', 'Dobroesti', 'Dobroesti,Dobroeşti,Pricipele Nicolae,Principele Nicolae', 44.4500000, 26.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116914, 'Dobrița', 'Dobrita', '', 45.1350400, 23.1740600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116915, 'Dobrin', 'Dobrin', 'Dobrin', 47.2833300, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116916, 'Dobridor', 'Dobridor', 'Dobridor,Dobridoru', 44.1186600, 23.1696900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116917, 'Dobric', 'Dobric', '', 47.2469000, 24.1277700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116918, 'Dobreţu', 'Dobretu', 'Dobretu,Dobretul,Dobreţu,Dobreţul', 44.5000000, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116919, 'Dobreşti', 'Dobresti', 'Dobresti,Dobresti in Bihor,Dobreşti,Dobreşti in Bihor', 46.8500000, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116920, 'Dobreşti', 'Dobresti', '', 44.9666700, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116921, 'Dobreşti', 'Dobresti', '', 43.9666700, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116922, 'Dobreni', 'Dobreni', 'Dobrein,Dobreni', 46.9833300, 26.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116923, 'Dobreni', 'Dobreni', 'Dobreni,Dobrenii', 44.4166700, 25.1166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116924, 'Dobreni', 'Dobreni', '', 44.2543000, 26.2134400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116925, 'Dobra', 'Dobra', '', 47.4947700, 22.8276200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116926, 'Dobra', 'Dobra', 'Dobra', 45.9166700, 22.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116927, 'Dobra', 'Dobra', '', 45.7691300, 23.6421800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116928, 'Dobra', 'Dobra', '', 44.7833300, 25.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116929, 'Doboșeni', 'Doboseni', 'Doboseni,Doboşeni,Szekelyszaldobos,Szèkelyszáldobos', 46.1243100, 25.5934700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116930, 'Dobârlău', 'Dobarlau', 'Dobarlau,Doberleu,Dobirlau,Dobârlău,Dobîrlău', 45.7333300, 25.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116931, 'Dobârceni', 'Dobarceni', 'Dobarceni,Dobirceni,Dobârceni,Dobîrceni', 47.8166700, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116932, 'Doba', 'Doba', 'Doba', 47.7333300, 22.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116933, 'Doanca', 'Doanca', '', 43.8487000, 24.6494900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116934, 'Ditrău', 'Ditrau', 'Ditrau,Ditro,Ditrău,Ditrō,Gyergyoditro,Gyergyóditró', 46.8166700, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116935, 'Dițești', 'Ditesti', 'Ditesti,Ditestii,Diţeşti,Diţeştii', 44.9799000, 25.7265500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116936, 'Dârza', 'Darza', 'Darza,Darzea,Dirza,Dârza,Dârzea,Dîrza', 44.6017500, 25.9495600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116937, 'Dârvari', 'Darvari', 'Darvari,Dirvari,Dârvari,Dîrvari', 44.4210800, 25.8798900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116938, 'Dârvari', 'Darvari', 'Darvari,Dirvari,Dârvari,Dîrvari', 44.2000000, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116939, 'Dârlos', 'Darlos', 'Darlos,Dirlos,Dârlos,Dîrlos', 46.1833300, 24.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116940, 'Dârjiu', 'Darjiu', 'Darjiu,Darjiul,Dirjiu,Dârjiu,Dârjiul,Dîrjiu,Szekelyders,Szèkelyders,Székelyders', 46.2000000, 25.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116941, 'Dioşti', 'Diosti', 'Diosti,Dioşti', 44.1166700, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116942, 'Dioșod', 'Diosod', '', 47.2923800, 23.0209900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116943, 'Diosig', 'Diosig', 'Bihardioszeg,Bihardiószeg,Dioszeg,Diószeg', 47.3000000, 22.0000000, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116944, 'Dângeni', 'Dangeni', 'Dangeni,Dingeni,Dângeni,Dîngeni', 47.8500000, 26.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116945, 'Hurdugi', 'Hurdugi', '', 46.5077800, 28.0547200, 'RO', '2016-01-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116946, 'Dâmbu', 'Dambu', 'Dambul,Dimbu,Dâmbul,Dîmbu', 45.0453300, 25.8885400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116947, 'Dâmbroca', 'Dambroca', 'Dambroca,Dimbroca,Dâmbroca,Dîmbroca', 45.1232800, 26.9557800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116948, 'Dâmbovicioara', 'Dambovicioara', 'Dambovicioara,Dimbovicioara,Dâmbovicioara,Dîmbovicioara', 45.4500000, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116949, 'Dâmbovicioara', 'Dambovicioara', 'Dambovicioara,Dimbovicioara,Dâmbovicioara,Dîmbovicioara', 44.6756900, 25.5537400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116950, 'Dâmbău', 'Dambau', 'Dambau,Dimbau,Dîmbău,Dămbău', 46.3199800, 24.2344300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116951, 'Dimăcheni', 'Dimacheni', 'Damacheni,Damăcheni,Dimacheni,Dimăcheni', 47.9113900, 26.5456000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116952, 'Dieci', 'Dieci', 'Deakfalva,Decs,Decse,Deákfalva,Diakfalva,Dieci,Diecs,Diákfalva,Diécs,Décs,Décse', 46.3166700, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116953, 'Diculești', 'Diculesti', '', 44.5935100, 23.9896800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116954, 'Dichiseni', 'Dichiseni', 'Dichiseni,Dichisenii', 44.2333300, 27.5333300, 'RO', '2012-06-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116955, 'Dezna', 'Dezna', 'Dezna', 46.4000000, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116956, 'Dezmir', 'Dezmir', 'Dezmer,Dezmir,Dezmiru,Dezmér', 46.7647500, 23.7245100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116957, 'Deveselu', 'Deveselu', 'Deveselu,Deveselul', 44.0666700, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116958, 'Devesel', 'Devesel', 'Devesel,Deveselu', 44.4688900, 22.6672200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116959, 'Deva', 'Deva', 'Deva,Deva i Romania,Diemrich,Déva,Nteva,Sargetia,de wa,deba,deva,devu~a,dwa,dyfa,Ντέβα,Дева,دوا,ديفا,دیوا ،رومانیہ,دیوا، رومانیہ,დევა,デヴァ,德瓦,데바', 45.8833300, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116960, 'Deta', 'Deta', 'Deta,Detta,Vijile Deta,Дета', 45.3888900, 21.2244400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116961, 'Deseşti', 'Desesti', 'Desesti,Deseşti', 47.7666700, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116962, 'Desa', 'Desa', 'Desa,Dessa', 43.8666700, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116963, 'Derșida', 'Dersida', '', 47.3881000, 22.8017000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116964, 'Dersca', 'Dersca', 'Dersca', 47.9833300, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116965, 'Derna', 'Derna', 'Derna', 47.2000000, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116966, 'Deparați', 'Deparati', '', 44.2811600, 25.2215100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116967, 'Denta', 'Denta', 'Denta', 45.3538900, 21.2491700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116968, 'Densuş', 'Densus', 'Demsus,Demsuş,Densus,Densuş', 45.5833300, 22.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116969, 'Demacușa', 'Demacusa', 'Demacusa,Demacuşa,Demakusza', 47.6971700, 25.5049900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116970, 'Beznea', 'Beznea', 'Beznea,Delureni', 46.9596700, 22.6195400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116971, 'Deleşti', 'Delesti', 'Delesti,Deleşti', 46.7000000, 27.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116972, 'Deleni', 'Deleni', 'Delenii,Magyarsaros,Magyarsáros,Saros,Şaroş', 46.2634000, 24.3411900, 'RO', '2015-12-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116973, 'Deleni', 'Deleni', '', 47.4666700, 26.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116974, 'Deleni', 'Deleni', 'Deleni', 46.5500000, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116975, 'Deleni', 'Deleni', 'Delen,Deleni', 46.3536000, 26.7762800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116976, 'Deleni', 'Deleni', 'Deleni,Enigea', 44.1000000, 28.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116977, 'Dejești', 'Dejesti', '', 44.8309300, 24.3564800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116978, 'Deja', 'Deja', '', 47.3553700, 23.1830000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116979, 'Dej', 'Dej', 'Dej,Des,Dezas,Dezh,Dežas,Dés,dai ri,deji,dh,dz,Деж,Дей,דז,דעזש,ده,デジ,代日', 47.1500000, 23.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116980, 'Dedulești', 'Dedulesti', '', 45.1467900, 27.3890700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116981, 'Dedrad', 'Dedrad', '', 46.8263200, 24.6579900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116982, 'Dedulești', 'Dedulesti', 'Dediulesti,Dediuleşti,Dedulesti,Deduleşti', 45.4700300, 26.9673700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116983, 'Deda', 'Deda', 'Dade,Deda,Deda Bistra,Déda', 46.9333300, 24.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116984, 'Decindeni', 'Decindeni', '', 44.9123400, 25.3260700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116985, 'Decebal', 'Decebal', '', 47.7663000, 22.7560300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116986, 'Dealu Morii', 'Dealu Morii', 'Dealu Morii', 46.3166700, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116987, 'Dealu Mare', 'Dealu Mare', 'Dealu Mare,Tata,Tita,Ţâta,Ţîţa', 45.1607200, 25.4487100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116988, 'Dealu Frumos', 'Dealu Frumos', 'Dealu Frumos,Valea Tatei,Valea Titii,Valea Tâtei,Valea Ţîţii', 45.1857500, 25.4132900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116989, 'Dealu Dănicei', 'Dealu Danicei', '', 44.9000000, 24.4333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116990, 'Dealu Aluniș', 'Dealu Alunis', 'Dealu Alunis,Dealu Aluniş,Stramba,Strimba,Strâmba,Strîmba', 44.9825200, 23.8674900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116991, 'Dealu', 'Dealu', 'Dealu,Dealul,Oroszhegy', 46.4000000, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116992, 'Dealu', 'Dealu', 'Dealu,Golasei,Golăşei', 44.3993800, 25.6485700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116993, 'Deaj', 'Deaj', 'Deaj,Deas,Deaş,Desfalva,Désfalva', 46.3471100, 24.4020600, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116994, 'Davideşti', 'Davidesti', 'Davidesa,Davidesti,Davidestii,Davideşti', 45.0166700, 25.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116995, 'Dascălu', 'Dascalu', 'Dascalu,Dascalul,Dascălu,Dascălul', 44.6000000, 26.2333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116996, 'Dăscălești', 'Dascalesti', '', 45.4062600, 27.2503900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116997, 'Darova Nouă', 'Darova Noua', '', 45.6333300, 21.7666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116998, 'Darova', 'Darova', 'Darova,Darowa,Daruvar,Daruwa,Imrefalva,Istvanfalva,Istvánfalva,Kranichstatten,Kranichstätten', 45.6420000, 21.7733300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(116999, 'Dărmăneşti', 'Darmanesti', 'Darmanesti,Darmanesti-Bucovina,Dărmăneşti,Dărmăneşti-Bucovina', 47.7333300, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117000, 'Dărmăneşti', 'Darmanesti', 'Darmanesti,Darmanestii,Dârmaneştii,Dărmăneşti', 46.3666700, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117001, 'Dărmăneşti', 'Darmanesti', 'Barmonestii,Barmoneştii,Darmanesti,Darmonesti,Dirmonesti,Dârmoneşti,Dîrmoneşti,Dărmăneşti', 45.0166700, 24.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117002, 'Dărmăneşti', 'Darmanesti', 'Darmanesti,Darmnesti,Darmneşti,Dărmăneşti', 44.9166700, 25.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117003, 'Dărăști-Vlașca', 'Darasti-Vlasca', 'Darasti,Darasti-Vlasca,Darastii de Sus,Dărăşti,Dărăşti-Vlaşca,Dărăştii de Sus', 44.2940100, 26.0111900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117004, 'Dărăşti-Ilfov', 'Darasti-Ilfov', 'Darasti,Darasti-Ilfov,Dărăşti,Dărăşti-Ilfov', 44.3088900, 26.0183300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117005, 'Darabani', 'Darabani', 'Darabani', 48.1833300, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117006, 'Dara', 'Dara', '', 47.8163600, 22.7521600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117007, 'Dăneţi', 'Daneti', 'Danet,Daneti,Daneţ,Dăneţi', 43.9833300, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117008, 'Dăneşti', 'Danesti', '', 46.8500000, 27.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117009, 'Dăneşti', 'Danesti', 'Csiksanfalva,Csiksánfalva,Danesti,Danfalva,Dánfalva,Dăneşti', 46.5166700, 25.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117010, 'Dăneşti', 'Danesti', 'Danesti,Dăneşti', 44.9666700, 23.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117011, 'Daneş', 'Danes', 'Danes,Daneş', 46.2166700, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117012, 'Dăneasa', 'Daneasa', '', 44.1500000, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117013, 'Dancu', 'Dancu', '', 47.1541700, 27.6662300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117014, 'Dănciuleşti', 'Danciulesti', 'Danciulesti,Danculesti,Dănciuleşti,Dănculeşti', 44.7333300, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117015, 'Dănceu', 'Danceu', 'Danceu,Danceul,Dănceu,Dănceul', 44.3641600, 22.7209800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117016, 'Dămuc', 'Damuc', 'Damuc,Damucu de Jos,Damucul,Damucul de Jos,Domuc,Dămuc,Dămucu de Jos', 46.8000000, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117017, 'Dămoc', 'Damoc', '', 46.4666700, 26.8666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117018, 'Dămieneşti', 'Damienesti', 'Damienesti,Dămieneşti', 46.7333300, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117019, 'Dămăcușeni', 'Damacuseni', '', 47.4570900, 23.9091400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117020, 'Dalnic', 'Dalnic', 'Dalnic,Dalnok,Dalnol,Dàlnok,Dálnol', 45.9224200, 25.9874100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117021, 'Dalboșeț', 'Dalboset', 'Dalbosec,Dalboset,Dalboşeţ,Dalbošec', 44.8639900, 21.9585400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117022, 'Daia Română', 'Daia Romana', 'Dacia-Romana,Dacia-Româna,Daia Romina,Daia Romînă,Daia-Romana,Daia-Română', 46.0166700, 23.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117023, 'Daia', 'Daia', '', 44.0000000, 25.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117024, 'Dagâţa', 'Dagata', 'Dagata,Dagita,Dagâţa,Dagîţa', 46.9333300, 27.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117025, 'Dăești', 'Daesti', '', 45.2010700, 24.3868400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117026, 'Dăeşti', 'Daesti', '', 44.9666700, 24.1333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117027, 'Dăeni', 'Daeni', 'Daeni,Dăeni', 44.8333300, 28.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117028, 'Dăbuleni', 'Dabuleni', 'Dabuleni,Dăbuleni', 43.8000000, 24.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117029, 'Dăbâca', 'Dabaca', 'Dabaca,Dobaca,Doboka,Dobâca,Dăbâca', 46.9833300, 23.6666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117030, 'Cuza Vodă', 'Cuza Voda', '', 45.5959500, 27.7926700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117031, 'Cuza Vodă', 'Cuza Voda', '', 45.3901700, 27.4483800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117032, 'Cuza Vodă', 'Cuza Voda', 'Cuza Voda,Cuza Vodă,Parlita,Pirlita,Pârlita,Pîrlita', 44.9251300, 27.7327300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117033, 'Cuza Vodă', 'Cuza Voda', 'Cuza Voda,Cuza Vodă,Docuzol', 44.2877300, 28.3100500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117034, 'Cuza Vodă', 'Cuza Voda', '', 44.2666700, 27.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117035, 'Cuzăplac', 'Cuzaplac', 'Cuzaplac,Cuzaplacu,Cuzăplac,Cuzăplacu', 46.9666700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117036, 'Cuzap', 'Cuzap', '', 47.2028800, 22.4152300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117037, 'Cuvin', 'Cuvin', 'Aradkovi,Aradkövi,Cuvin,Kovi,Kovin,Kuvin,Kövi', 46.1700100, 21.5936000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117038, 'Cut', 'Cut', '', 46.8825800, 26.4192800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117039, 'Cut', 'Cut', 'Cut', 45.9397200, 23.6671900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117040, 'Cuzdrioara', 'Cuzdrioara', 'Kozarvar,Kozárvár', 47.1666700, 23.9166700, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117041, 'Curtuișeni', 'Curtuiseni', 'Curtuiseni,Curtuiuseni,Curtuiuşeni,Curtuişeni', 47.5463300, 22.2026300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117042, 'Curtişoara', 'Curtisoara', '', 44.5000000, 24.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117043, 'Curtici', 'Curtici', 'Curtici,Kuertoes,Kurtich,Kurtichi,Kürtös,Opstina Curtici,Opština Curtici,ku er di qi,kwrtych,Куртичи,Куртіч,کورتیچ,庫爾蒂奇', 46.3500000, 21.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117044, 'Curteşti', 'Curtesti', '', 47.7166700, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117045, 'Curtea de Argeş', 'Curtea de Arges', 'Argyasudvarhely,Curt de-Arges,Curt de-Argeş,Curtea de Arges,Curtea de Argeş,Curtea de Argeș', 45.1342200, 24.6740900, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117046, 'Curtea', 'Curtea', 'Curtea', 45.8166700, 22.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117047, 'Curcani', 'Curcani', 'Curcani', 44.2000000, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117048, 'Curăţele', 'Curatele', 'Curatele,Curăţele', 46.7000000, 22.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117049, 'Cupşeni', 'Cupseni', '', 47.5500000, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117050, 'Cungrea', 'Cungrea', 'Cungrea', 44.6666700, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117051, 'Cumpăna', 'Cumpana', 'Cumpana,Cumpăna,Hasi Diu luk,Hasiduluc,Hasin Duluc', 44.1166700, 28.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117052, 'Culciu Mic', 'Culciu Mic', 'Culciu Mic,Culciul Mic', 47.7666700, 23.0333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117053, 'Cujmir', 'Cujmir', 'Cujmir,Cujmiru,Cujmirul', 44.2066700, 22.9266700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117054, 'Cugir', 'Cugir', 'Cugir,Kudzhir,Kudziras,Kudzsir,Kudžiras,Kugir,Opstina Cugir,Opština Cugir,ku ji er,kwjy,Кугир,Куджир,Куҷир,کوجی,庫吉爾', 45.8365100, 23.3699800, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117055, 'Cuejdiu', 'Cuejdiu', 'Cuejdiu,Cuejdiul', 46.9904000, 26.2945500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117056, 'Cudalbi', 'Cudalbi', 'Cudalbi', 45.7833300, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117057, 'Cucuteni', 'Cucuteni', 'Cucuteni', 47.2833300, 26.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117058, 'Cucuruzu', 'Cucuruzu', 'Cucurezu,Cucuruzu,Cucuruzul', 44.0802000, 25.7324200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117059, 'Cucuieți', 'Cucuieti', '', 46.5898000, 26.5287500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117060, 'Cucuieți', 'Cucuieti', 'Cucueti,Cucuetii,Cucueţi,Cucueţii', 46.3273100, 26.5550400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117061, 'Cucueți', 'Cucueti', '', 44.1843200, 24.9482600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117062, 'Cuciulata', 'Cuciulata', 'Cuciulata', 45.9438900, 25.2754100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117063, 'Cuci', 'Cuci', 'Cuci,Cuciu,Cuciul', 46.4666700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117064, 'Cucerdea', 'Cucerdea', 'Cucerdea', 46.4000000, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117065, 'Cuca', 'Cuca', '', 45.7333300, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117066, 'Cuca', 'Cuca', '', 44.9500000, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117067, 'Cubulcut', 'Cubulcut', '', 47.3227000, 22.1864800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117068, 'Crușovu', 'Crusovu', 'Crusovu,Crusovul,Cruşovu,Cruşovul', 43.9247300, 24.4148600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117069, 'Crușeț', 'Cruset', '', 44.6333300, 23.6666700, 'RO', '2015-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117070, 'Crucişor', 'Crucisor', 'Crucisor,Crucişor', 47.6833300, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117071, 'Crucea', 'Crucea', '', 47.3500000, 25.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117072, 'Crucea', 'Crucea', '', 47.1656700, 27.1709300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117073, 'Crucea', 'Crucea', 'Crucea,Satischioi,Satişchioi', 44.5333300, 28.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117074, 'Crovu', 'Crovu', 'Crovu,Crovul', 44.5894700, 25.5368400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117075, 'Croitori', 'Croitori', 'Croitori,Croitorii,Petresti-Croitori,Petrestii Croitori,Petreşti-Croitori,Petreştii Croitori', 44.5751200, 25.4135600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117076, 'Crizbav', 'Crizbav', 'Crisbav,Crizbav', 45.8151500, 25.4671800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117077, 'Crivina', 'Crivina', '', 45.5833300, 25.9833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117078, 'Crivina', 'Crivina', '', 44.7863600, 26.0560400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117079, 'Crivești', 'Crivesti', '', 47.3243000, 26.7824000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117080, 'Crivăț', 'Crivat', 'Crivat,Crivatu,Crivatul,Crivăţ,Crivăţu,Crivăţul', 44.1933800, 26.4384600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117081, 'Cristuru Secuiesc', 'Cristuru Secuiesc', 'Cristur,Cristuru Secuiesc,Ion Gheorghe Duca,Kristuru Sekujesk,Kristuru-Sekuesk,Opstina Cristuru Secuiesc,Opština Cristuru Secuiesc,Szekelykeresztur,Szèkelykeresztur,Székelykeresztúr,da la ba ni,krystwrw skwyysk,Кристуру Секујеск,Кристуру-Секуеск,Крістуру-Секуєск,کریستورو سکوئیسک,達拉巴尼', 46.2833300, 25.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117082, 'Cristur', 'Cristur', 'Csernakeresztur,Csernakeresztúr', 45.8293600, 22.9432300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117083, 'Cristolţ', 'Cristolt', 'Crastoltul-Mare,Cristolt,Cristoltu Mare,Cristoltul Mare,Cristolţ,Cristolţu Mare,Cristolţul Mare,Crâstolţul-Mare', 47.2000000, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117084, 'Criştioru de Jos', 'Cristioru de Jos', 'Alsokristyor,Alsókristyór,Biharkristyor,Biharkristyór,Cristior-de-Jos,Cristioru de Jos,Criştior-de-Jos,Criștioru de Jos,Felsokristyor,Felsőkristyór,Kristyor', 46.4193700, 22.5345700, 'RO', '2015-11-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117085, 'Cristineşti', 'Cristinesti', 'Cristinesti,Cristineşti', 48.1000000, 26.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117086, 'Cristian', 'Cristian', 'Cristian,Crossau', 45.7833300, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117087, 'Cristian', 'Cristian', 'Cristian', 45.6166700, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117088, 'Cristeștii Ciceului', 'Cristestii Ciceului', 'Cristestii Ciceiului,Cristestii-Ciceului,Cristeştii Ciceiului,Cristeştii-Ciceului', 47.1932600, 24.0960500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117089, 'Cristeşti', 'Cristesti', '', 47.6333300, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117090, 'Cristeşti', 'Cristesti', '', 47.2666700, 26.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117091, 'Cristești', 'Cristesti', '', 47.1622400, 27.0815500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117092, 'Cristeşti', 'Cristesti', 'Maroskeresztur', 46.5000000, 24.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117093, 'Crişeni', 'Criseni', 'Criseni,Crişeni', 47.2333300, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117094, 'Crişcior', 'Criscior', 'Criscior,Cristior,Crişcior,Criştior', 46.1166700, 22.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117095, 'Crişan', 'Crisan', 'Crisan,Crişan', 44.9666700, 29.4666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117096, 'Crângurile de Sus', 'Crangurile de Sus', 'Crangurile de Sus,Cringurile de Sus,Crângurile de Sus,Crîngurile de Sus', 44.7666700, 25.2333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117097, 'Crângu', 'Crangu', 'Cringu,Crîngu,Ologi', 43.8461100, 25.0735000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117098, 'Crângeni', 'Crangeni', 'Crangem,Crangeni,Cringeni,Crângeni,Crîngeni,Crăngem', 44.0333300, 24.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117099, 'Crâmpoia', 'Crampoia', '', 44.3021500, 24.7451300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117100, 'Criciova', 'Criciova', 'Cliciova,Criciova,Kricso,Kricsova,Kricsó', 45.6333300, 22.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117101, 'Cricău', 'Cricau', 'Cricau,Cricaul,Cricău,Cricăul', 46.1833300, 23.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117102, 'Crevenicu', 'Crevenicu', 'Crevenicu,Crevenicul', 44.2408300, 25.5886100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117103, 'Crevedia Mare', 'Crevedia Mare', 'Crevedia Mare', 44.4291700, 25.6255600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117104, 'Crevedia', 'Crevedia', 'Crevedia', 44.6000000, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117105, 'Crețești', 'Cretesti', '', 46.6333300, 27.9500000, 'RO', '2016-01-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117106, 'Crețești', 'Cretesti', 'Cretesti,Cretestii,Creţestii,Creţeşti', 44.2823800, 26.1353000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117107, 'Creţeni', 'Creteni', 'Creteni,Creţeni', 44.6833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117108, 'Creaca', 'Creaca', 'Creaca', 47.2000000, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117109, 'Crasna Vișeului', 'Crasna Viseului', '', 47.8286900, 24.2300000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117110, 'Crasna', 'Crasna', 'Crasna', 47.1666700, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117111, 'Crasna', 'Crasna', 'Crasna,Crasna Ungureni', 45.1666700, 23.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117112, 'Craiva', 'Craiva', '', 46.5833300, 21.9666700, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117113, 'Craiova', 'Craiova', 'CRA,Craiova,Croiova,Gorad Krajova,Kraiov,Kraiova,Krajova,Krajova khot,Krajowa,ke la yue wa,keulaioba,kraywfa,kraywwa,krayywwa,kurayovu~a,qrywbh,Κραϊόβα,Горад Краёва,Крайова,Крайова хот,Крајова,קראיובה,קריובה,كرايوفا,کرائیؤوا,کرايووا,کرایووا,クラヨーヴァ,克拉約瓦,크라이오바', 44.3166700, 23.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117114, 'Crăieşti', 'Craiesti', 'Craesti,Craiesti,Crăeşti,Crăieşti', 46.3000000, 24.1833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117115, 'Craidorolţ', 'Craidorolt', 'Craidorolt,Craidorolţ', 47.6166700, 22.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117116, 'Crăiești', 'Craiesti', 'Craesti,Craifalau,Craifalău,Crăeşti', 46.7577100, 24.4249900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117117, 'Crăiești', 'Craiesti', '', 45.9431400, 27.8113600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117118, 'Crăciunești', 'Craciunesti', '', 47.9555100, 23.9826700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117119, 'Crăciuneşti', 'Craciunesti', 'Nyaradkaracsonyfalva,Nyárádkarácsonyfalva', 46.4793000, 24.5823400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117120, 'Crăciunelu de Jos', 'Craciunelu de Jos', 'Craciunelu de Jos,Craciunelul-de-Jos,Crăciunelu de Jos,Crăciunelul-de-Jos', 46.1833300, 23.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117121, 'Crăciunei', 'Craciunei', '', 44.1457500, 24.6630900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117122, 'Cracăul Negru', 'Cracaul Negru', 'Cracau Negru,Cracaul Negru,Cracăul Negru,Crăcău Negru', 47.0936300, 26.2406100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117123, 'Crăcăoani', 'Cracaoani', 'Cracaoani,Cracaoani de Jos,Cracaoani de Sus,Crăcăoani,Crăcăoani de Jos,Crăcăoani de Sus,Valea Horotici', 47.0983600, 26.3111100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117124, 'Cozmeşti', 'Cozmesti', 'Cosmesti,Cosmeşti,Cozmesti,Cozmeşti', 46.8833300, 27.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117125, 'Cozmești', 'Cozmesti', 'Cozmesti,Cozmeşti', 46.7337500, 27.5016400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117126, 'Cozmeni', 'Cozmeni', 'Cozinem,Cozmeni,Csik-Kozmas,Csikkozmas,Csíkkozmás,Kormas,Kormàs', 46.2267800, 25.9420900, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117127, 'Cozma', 'Cozma', 'Cosma,Cozma,Kozmatelke', 46.8166700, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117128, 'Cozieni', 'Cozieni', 'Cozieni,Trestia', 45.3333300, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117129, 'Cozia', 'Cozia', '', 47.0031900, 27.8943400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117130, 'Covrigi', 'Covrigi', '', 44.7382500, 23.1492100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117131, 'Covasna', 'Covasna', '', 47.0025500, 27.8510600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117132, 'Covasna', 'Covasna', 'Kavasma,Kovaszna,Kovàszna,Kovászna', 45.8500000, 26.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117133, 'Covăsinţ', 'Covasint', 'Covasint,Covasinti,Covasnit,Covăsinţ,Covăsinţi,Covăsniţ,Kovaszi,Kovaszincz,Kovesd,Kovászi,Kövesd,Podgoria', 46.2000000, 21.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117134, 'Cotu Vameș', 'Cotu Vames', 'Cotu Vames,Cotu Vameş,Cotul-Vames,Cotul-Vameş', 46.9060000, 26.9553500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117135, 'Coţuşca', 'Cotusca', 'Cotusca,Coţuşca', 48.1333300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117136, 'Cotumba', 'Cotumba', '', 46.4974300, 26.1911200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117137, 'Coțofenii din Față', 'Cotofenii din Fata', 'Cotofenii din Fata,Coţofenii din Faţă', 44.4597100, 23.6568800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117138, 'Coţofenii din Dos', 'Cotofenii din Dos', 'Cotofenii din Dos,Coţofenii din Dos', 44.4333300, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117139, 'Coţofăneşti', 'Cotofanesti', 'Cotofanesti,Cotofanestii,Cotofenesti,Coţofeneşti,Coţofăneşti,Coţofăneştii', 46.1500000, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117140, 'Cotnari', 'Cotnari', 'Cotnari', 47.3500000, 26.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117141, 'Cotmeana', 'Cotmeana', '', 44.9666700, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117142, 'Coteşti', 'Cotesti', '', 45.6500000, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117143, 'Cotenești', 'Cotenesti', '', 45.2346200, 25.1861700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117144, 'Coteana', 'Coteana', 'Coteana,Ion I. C. Bratianu', 44.3000000, 24.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117145, 'Coțatcu', 'Cotatcu', 'Cotacu,Cotatcu,Cotatcul,Coţacu,Coţatcu,Coţatcul', 45.4664300, 27.0148600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117146, 'Coșula', 'Cosula', 'Cosula,Coşula', 47.6257000, 26.7782700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117147, 'Costuleni', 'Costuleni', '', 47.0333300, 27.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117148, 'Costişa', 'Costisa', '', 46.7500000, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117149, 'Costineşti', 'Costinesti', 'Costinesti,Costineşti', 43.9500000, 28.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117150, 'Costâna', 'Costana', 'Costana,Costina,Costâna,Costîna', 47.6926500, 26.1190000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117151, 'Costeştii din Vale', 'Costestii din Vale', 'Costesti de Vale,Costesti-Vale,Costesti-Vatra,Costestii din Vale,Costeşti de Vale,Costeşti-Vale,Costeşti-Vatra,Costeştii din Vale', 44.6500000, 25.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117152, 'Costeștii din Deal', 'Costestii din Deal', 'Costesti-Deal,Costestii din Deal,Costestii-Deal,Costeşti-Deal,Costeştii din Deal,Costeştii-Deal', 44.6813200, 25.4893800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117153, 'Costești', 'Costesti', '', 47.8003200, 26.6758400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117154, 'Costești', 'Costesti', '', 47.2342800, 26.9262200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117155, 'Costeşti', 'Costesti', 'Costesti,Costeşti', 46.5000000, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117156, 'Costeşti', 'Costesti', '', 45.1500000, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117157, 'Costeşti', 'Costesti', '', 45.0500000, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117158, 'Costești', 'Costesti', '', 44.7326400, 23.4449100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117159, 'Costeşti', 'Costesti', 'Costesti,Costeşti', 44.6666700, 24.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117160, 'Coşteiu', 'Costeiu', 'Checea Romana,Checea Română,Costei,Costeiu,Costeiul,Costeiul Mare,Costeiul Mic,Coştei,Coşteiu,Coşteiul,Coşteiul Mare,Coşteiul Mic,Kiskastely,Kiskastély,Nagykastely,Nagykastély,Nagykostely,Nagykostély,Salha,Salha Costei,Silha,Szilha,Sâlha,Sâlha Coştei,Sîlha', 45.7411100, 21.8491700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117161, 'Costache Negri', 'Costache Negri', 'Costache Negri,Manjina,Mânjina', 45.7000000, 27.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117162, 'Coşoveni', 'Cosoveni', 'Cosoveni,Cosovenii de Sus,Coşoveni,Coşovenii de Sus', 44.2500000, 23.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117163, 'Cosoba', 'Cosoba', '', 44.5226800, 25.8190300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117164, 'Coșna', 'Cosna', 'Cosna,Coşna,Rosna', 47.3709800, 25.1813300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117165, 'Cosmina de Jos', 'Cosmina de Jos', '', 45.1500000, 25.8833300, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117166, 'Cosmeștii-Vale', 'Cosmestii-Vale', 'Cosmesti din Vale,Cosmesti-Vale,Cosmestii din Vale,Cosmeşti din Vale,Cosmeşti-Vale,Cosmeştii din Vale,Cozmesti-Vale,Cozmeşti-Vale', 45.8693100, 27.2877100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117167, 'Cosmeşti', 'Cosmesti', 'Cosmesti,Cosmesti din Deal,Cosmesti-Deal,Cosmestii din Deal,Cosmeşti,Cosmeşti din Deal,Cosmeşti-Deal,Cosmeştii din Deal,Cozmesti-Deal,Cozmeşti-Deal', 45.8701700, 27.3111500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117168, 'Cosmeşti', 'Cosmesti', 'Cosmesti,Cosmeşti', 44.3000000, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117169, 'Cosâmbeşti', 'Cosambesti', 'Cosambesti,Cosâmbeşti', 44.5592900, 27.4344100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117170, 'Coşeşti', 'Cosesti', 'Cosesti,Coşeşti', 45.0666700, 24.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117171, 'Coşereni', 'Cosereni', 'Cosareni,Cosereni,Coşereni,Coşăreni', 44.6833300, 26.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117172, 'Coşeiu', 'Coseiu', 'Coseiu,Coseiul,Coşeiu,Coşeiul', 47.3166700, 22.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117173, 'Coşbuc', 'Cosbuc', 'Cojbuc,Cosbuc,Coşbuc,Hordo', 47.3654000, 24.3911500, 'RO', '2013-02-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117174, 'Coșani', 'Cosani', '', 45.0078800, 24.1918800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117175, 'Corund', 'Corund', 'Corund,Korond', 46.4666700, 25.1833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117176, 'Corunca', 'Corunca', 'Koronka', 46.5207500, 24.6179200, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117177, 'Coropceni', 'Coropceni', '', 46.9419300, 27.8371000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117178, 'Coroisânmartin', 'Coroisanmartin', 'Coroisanmartin,Coroisinmartin,Coroisânmartin,Coroisînmartin', 46.4000000, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117179, 'Coroieşti', 'Coroiesti', 'Coroiesti,Coroiestii de Jos,Coroieşti,Coroieştii de Jos', 46.2500000, 27.4833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117180, 'Coroieni', 'Coroieni', 'Karulyfalva', 47.3666700, 23.7666700, 'RO', '2015-12-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117181, 'Corod', 'Corod', 'Corod', 45.9000000, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117182, 'Corocăiești', 'Corocaiesti', '', 47.6333300, 26.4833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117183, 'Cornuțel', 'Cornutel', 'Cornatel,Cornutel,Cornutel-Banat Gara,Cornuţel,Cornuţel-Banat Gară,Cornăţel', 45.4348900, 22.0955600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117184, 'Cornu Luncii', 'Cornu Luncii', 'Cornu Luncii', 47.4666700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117185, 'Cornu de Sus', 'Cornu de Sus', 'Cornu de Sus,Cornul de Sus', 45.1666700, 25.7000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117186, 'Cornu de Jos', 'Cornu de Jos', 'Connul de Jos,Cornu de Jos', 45.1566500, 25.7045200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117187, 'Corni-Albești', 'Corni-Albesti', 'Corni-Albesti,Corni-Albeşti,Cornii-Albesti,Cornii-Albeşti', 46.5181300, 27.8717100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117188, 'Corni', 'Corni', '', 47.6500000, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117189, 'Corni', 'Corni', '', 45.8500000, 27.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117190, 'Cornetu', 'Cornetu', '', 45.5045600, 27.0530500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117191, 'Cornetu', 'Cornetu', 'Cornetu,Cornetul', 44.3416700, 25.9408300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117192, 'Corneşti', 'Cornesti', 'Cornesti,Corneşti', 47.0333300, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117193, 'Cornești', 'Cornesti', '', 46.2921800, 24.2127700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117194, 'Corneşti', 'Cornesti', '', 44.7833300, 25.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117195, 'Cornereva', 'Cornereva', 'Cornereva', 45.0666700, 22.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117196, 'Cornea', 'Cornea', '', 45.0333300, 22.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117197, 'Cornăţelu', 'Cornatelu', 'Cornatelu,Cornatelul,Cornaţelul,Cornăţelu', 44.7500000, 25.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117198, 'Cornățel', 'Cornatel', 'Cornatel,Cornatelu,Cornatelul,Cornăţel,Cornăţelu,Cornăţelul', 44.5797200, 24.9548700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117199, 'Cormaia', 'Cormaia', '', 47.3666700, 24.6833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117200, 'Corlătești', 'Corlatesti', '', 44.9134100, 26.0872600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117201, 'Corlăteni', 'Corlateni', 'Corlateni,Corlăteni', 47.9333300, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117202, 'Corlăţel', 'Corlatel', 'Corlatel,Corlatelu,Corlatelul,Corlăţel,Corlăţelu,Corlăţelul', 44.3986100, 22.9330600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117203, 'Cordun', 'Cordun', 'Cordun,Cordunu', 46.9500000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117204, 'Cordău', 'Cordau', 'Cordau,Cordău,Kardo,Kardó', 46.9500000, 21.9833300, 'RO', '2015-12-06', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117205, 'Cordăreni', 'Cordareni', 'Cordareni,Cordareni-Vechi,Cordarenii Vechi,Cordăreni,Cordăreni-Vechi,Cordărenii Vechi', 47.9833300, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117206, 'Corcova', 'Corcova', 'Corcova', 44.7000000, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117207, 'Corbu Nou', 'Corbu Nou', 'Corbu,Corbu Nou,Corbul-Nou', 45.4099600, 27.5919100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117208, 'Corbu', 'Corbu', 'Corbu,Corbul,Hollo,Hollò', 46.9833300, 25.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117209, 'Corbu', 'Corbu', 'Corbu,Corbul', 45.3210800, 26.2493600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117210, 'Corbu', 'Corbu', 'Corbu,Corbu-Nou,Corbul-Nou', 44.4833300, 24.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117211, 'Corbu', 'Corbu', 'Corbu,Corbu de Jos,Corbul-de-Jos,Gargalacul-Mic,Gargalic Mic,Gargaliku Mik,Gargalâcul-Mic,Gargalîc Mic', 44.3833300, 28.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117212, 'Corbiţa', 'Corbita', 'Corbita,Corbiţa', 46.1500000, 27.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117213, 'Corbii Mari', 'Corbii Mari', 'Corbii Mari', 44.5500000, 25.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117214, 'Corbi', 'Corbi', 'Corbi', 45.2833300, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117215, 'Corbeni', 'Corbeni', 'Corbeni', 45.3000000, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117216, 'Corbeanca', 'Corbeanca', 'Corbeanca', 44.6000000, 26.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117217, 'Corbasca', 'Corbasca', 'Corbasca', 46.2833300, 27.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117218, 'Corabia', 'Corabia', 'Corabia,Korabija,Opstina Corabia,Opština Corabia,ke la bi ya,korabia,kwrbya,Корабия,Корабија,Корабія,کوربیا,コラビア,科拉比亞', 43.7833300, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117219, 'Copşa Mică', 'Copsa Mica', 'Copsa,Copsa Mica,Copşa,Copşa Mică,Klein Kopisch', 46.1166700, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117220, 'Copalnic Mănăştur', 'Copalnic Manastur', 'Copalnic Manastur,Copalnic Monastur,Copalnic Mănăştur', 47.5000000, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117221, 'Copălău', 'Copalau', 'Copalau,Copălău', 47.6166700, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117222, 'Copaciu', 'Copaciu', 'Copaciu,Copaciul', 44.1817800, 25.7692100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117223, 'Copăceni', 'Copaceni', 'Copaceni,Copaceni de Jos,Copacenii de Jos,Copăceni,Copăcenii de Jos', 44.2629700, 26.0937400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117224, 'Copăceni', 'Copaceni', 'Copaceni,Copand,Copăceni', 46.5967500, 23.7388600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117225, 'Copăceni', 'Copaceni', 'Copaceni,Copăceni', 45.0000000, 23.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117226, 'Copăcelu', 'Copacelu', 'Copacel,Copacelu,Copăcel,Copăcelu', 45.0676200, 24.3116100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117227, 'Copăcele', 'Copacele', 'Copacele,Copăcele', 45.5000000, 22.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117228, 'Copăcel', 'Copacel', 'Copacel,Copăcel', 46.9833300, 22.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117229, 'Conțești', 'Contesti', 'Contasti,Contesti,Conţeşti,Conţăşti', 47.3096000, 26.6560500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117230, 'Conțești', 'Contesti', '', 44.9849400, 25.0103200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117231, 'Conțești', 'Contesti', 'Contesti,Contestii de Jos,Conţesţi,Conţeştii de Jos', 44.6851800, 25.6387900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117232, 'Conţeşti', 'Contesti', 'Contesti,Conţeşti', 43.8000000, 25.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117233, 'Constantin Daicoviciu', 'Constantin Daicoviciu', 'Cavaran,Constantin Daicoviciu,Căvăran', 45.5500000, 22.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117234, 'Constanţa', 'Constanta', 'CND,Constanca,Constancia,Constanta,Constantia,Constantza,Constanza,Constança,Constanţa,Constanța,Costansa,Costanza,Gorad Kanstanca,Kjustendzha,Koestence,Konstanca,Konstancae,Konstanco,Konstansa,Konstantsa,Konstantza,Konstanza,Kuestence,Kustenja,Kustenje,Kustenji,Kyustendja,Köstence,Küstence,Küstenja,Tomis,kang si tan cha,khxn s tan sa,konseutancha,konstantsa,konsutantsu~a,kwnstansa,kwnstantsa,qwnstnzh,Κωνστάντζα,Горад Канстанца,Константса,Констанцæ,Констанца,Кюстенджа,Կոնստանցա,קונסטנצה,كونستانتسا,کونستانتسا,کونستانسا,कोन्स्तांत्सा,คอนสตันซา,კონსტანცა,コンスタンツァ,康斯坦察,콘스탄차', 44.1807300, 28.6343200, 'RO', '2016-10-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117235, 'Conop', 'Conop', 'Conop,Konop', 46.1018600, 21.8797000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117236, 'Conduratu', 'Conduratu', 'Conduratu,Conduratul', 44.9723600, 26.4336500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117237, 'Condeești', 'Condeesti', '', 44.6276100, 26.6914700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117238, 'Conceşti', 'Concesti', 'Concesti,Conceşti', 48.1666700, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117239, 'Comoșteni', 'Comosteni', '', 43.8740500, 23.8635600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117240, 'Comloşu Mare', 'Comlosu Mare', 'Comlosu Mare,Comlosul-Mare,Comloşu Mare,Comloşul-Mare,Gross-Komlosch,Komlosch,Nagykomlos,Nagykomlós,Veliki Komlus,Veliki Komluš', 45.8905600, 20.6272200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117241, 'Comişani', 'Comisani', 'Comisani,Comişani', 44.8833300, 25.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117242, 'Comarnic', 'Comarnic', 'Comarnic', 45.2500000, 25.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117243, 'Comarna', 'Comarna', 'Comarna', 47.0500000, 27.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117244, 'Comani', 'Comani', '', 44.1828600, 24.4916000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117245, 'Comănești', 'Comanesti', '', 47.6693900, 25.9883600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117246, 'Comăneşti', 'Comanesti', 'Comanesti,Comăneşti', 46.4213500, 26.4364500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117247, 'Comandău', 'Comandau', 'Comanda,Comando,Komando,Kommando,Kommandó,Komàndo', 45.7666700, 26.2666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117248, 'Comanda', 'Comanda', '', 44.6486300, 23.1641300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117249, 'Comanca', 'Comanca', '', 44.0779000, 24.3586300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117250, 'Comana de Sus', 'Comana de Sus', '', 45.9000000, 25.2666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117251, 'Comana de Jos', 'Comana de Jos', '', 45.9137500, 25.2312900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117252, 'Comana', 'Comana', 'Comana', 44.1705600, 26.1450000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117253, 'Comana', 'Comana', 'Comana,Mustafa-Aci,Mustafaci', 43.9000000, 28.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117254, 'Colţi', 'Colti', 'Colti,Colţi,Intre Sibicii,Între Sibicii', 45.3833300, 26.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117255, 'Coltău', 'Coltau', 'Coltau,Coltaul,Coltău,Coltăul,Kolto,Koltó', 47.5983700, 23.5245900, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117256, 'Colonia Fabricii', 'Colonia Fabricii', '', 45.7662000, 22.3146300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117257, 'Colonia Bod', 'Colonia Bod', '', 45.7558800, 25.5996000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117258, 'Coloneşti', 'Colonesti', 'Colonesti,Coloneşti,Corbu,Parus,Păruş,Valea lui Matei', 46.5666700, 27.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117259, 'Coloneşti', 'Colonesti', '', 44.6500000, 24.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117260, 'Colibași', 'Colibasi', '', 44.9354400, 24.9090500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117261, 'Colibaşi', 'Colibasi', 'Cohbasi,Colibasi,Colibaşi', 44.2022200, 26.1947200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117262, 'Colelia', 'Colelia', '', 44.7611200, 27.0069300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117263, 'Colceag', 'Colceag', 'Colceag,Colceagu', 44.9500000, 26.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117264, 'Colacu', 'Colacu', 'Colacu,Colacul', 47.5383000, 25.3721100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117265, 'Colacu', 'Colacu', 'Colacu,Colacul', 44.6689500, 25.7588100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117266, 'Cojocna', 'Cojocna', 'Cojocna,Kolozs', 46.7500000, 23.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117267, 'Cojasca', 'Cojasca', 'Cojasca', 44.7166700, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117268, 'Cogeasca', 'Cogeasca', 'Cogeasca,Cogeasca Veche,Hasnaseni,Hăsnăşeni', 47.1664400, 27.3853700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117269, 'Cogealac', 'Cogealac', 'Cogealac,Domnesti,Domneşti,Kogealak', 44.5500000, 28.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117270, 'Codlea', 'Codlea', 'Codlea,Feketehalom,Kodla,Kodlja,Opstina Codlea,Opština Codlea,Zeiden,ke de lai ya,kodorea,kwdlh,Кодля,Кодља,کودله,コドレア,科德萊亞', 45.7000000, 25.4500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117271, 'Codăeşti', 'Codaesti', 'Codaesti,Codăeşti', 46.8666700, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117272, 'Cocu', 'Cocu', 'Cocu,Cocul', 44.8666700, 24.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117273, 'Cocoreni', 'Cocoreni', '', 44.8277200, 23.3140500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117274, 'Cocorăștii Mislii', 'Cocorastii Mislii', '', 45.0852800, 25.9220600, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117275, 'Cocorăștii Colț', 'Cocorastii Colt', 'Cocarastii Colt,Cocorasti-Colt,Cocorasti-Colti,Cocorastii-Colt,Cocorăşti-Colţ,Cocorăşti-Colţi,Cocorăştii-Colţ,Cocărăştii Colţ,Coltu,Coltul,Colţu', 44.8342500, 25.8993700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117276, 'Cocora', 'Cocora', 'Cocora', 44.7333300, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117277, 'Coconi', 'Coconi', '', 44.2476900, 26.8840900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117278, 'Cociuba Mare', 'Cociuba Mare', 'Cociuba Mare,Cociuba de Jos', 46.7333300, 22.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117279, 'Cociu', 'Cociu', 'Cociu,Cociul', 47.1992600, 24.2323800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117280, 'Cochirleanca', 'Cochirleanca', 'Cochirleanca,Cochirleanca-Gageanu,Cochirleanca-Găgeanu,Gageanu,Gagenul,Găgenul,Regele-Carol II', 45.2166700, 27.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117281, 'Cobadin', 'Cobadin', 'Cobadin', 44.0833300, 28.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117282, 'Coaș', 'Coas', '', 47.5395700, 23.5858400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117283, 'Coarnele Caprei', 'Coarnele Caprei', 'Coarnele Caprei', 47.3833300, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117284, 'Coada Izvorului', 'Coada Izvorului', '', 44.8576600, 25.8185100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117285, 'Cluj-Napoca', 'Cluj-Napoca', 'CLJ,Castrum Clus,Claudiopolis,Clausemburgo,Clausenburg,Cluj,Cluj Napoca,Cluj-Napoca,Gorad Kluzh-Napoka,Kalosvar,Kaloşvar,Klausenburg,Klouz-Napoka,Klujo,Kluz,Kluz Napok,Kluz-Napoka,Kluza-Napoka,Kluzas-Napoka,Kluzh-Napoka,Kluzh-Napoka khot,Kluĵo,Kluż-Napoka,Kluž,Kluž Napok,Kluža-Napoka,Klužas-Napoka,Koloszvar,Koloszvár,Kolozsvar,Kolozsvár,Municipium Aelium Hadrianum Napoca,Napoca,ke lu ri-na bo ka,keullujinapoka,khluch-na po ka,kluja-napoka,klwj nabwka,klwj napwka,klwzh napwka,klwzh-napwka,klwzh-npwka,kuruju=napoka,qlwyznbwrg,qlwz-nʼpwqh,Κλουζ-Ναπόκα,Горад Клуж-Напока,Клуж-Напока,Клуж-Напока хот,Կլուժ-Նապոկա,קלוז''-נאפוקה,קלוז-נאפוקה,קלויזנבורג,كلوج نابوكا,کلوج ناپوکا,کلوژ ناپوکا,کلوژ-ناپوکا,کلوژ-نپوکا,क्लुज-नापोका,คลูช-นาโปกา,კლუჟ-ნაპოკა,クルジュ＝ナポカ,克卢日-纳波卡,클루지나포카', 46.7666700, 23.6000000, 'RO', '2012-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117286, 'Cloșani', 'Closani', '', 45.0689700, 22.8025000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117287, 'Clocotici', 'Clocotici', '', 45.2449500, 21.8346700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117288, 'Clit', 'Clit', '', 47.7539600, 25.8569100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117289, 'Clinceni', 'Clinceni', 'Clinceni', 44.3733300, 25.9547200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117290, 'Clejani', 'Clejani', '', 44.3197200, 25.6994400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117291, 'Cleja', 'Cleja', '', 46.4166700, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117292, 'Cleanov', 'Cleanov', 'Cleanov,Cleanovu', 44.3528800, 23.2103200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117293, 'Cizer', 'Cizer', 'Cizer,Czizer,Czizér', 47.0666700, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117294, 'Ciutelec', 'Ciutelec', '', 47.2620000, 22.3869000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117295, 'Ciușlea', 'Ciuslea', '', 45.7876100, 27.3064400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117296, 'Ciuruleasa', 'Ciuruleasa', 'Abrud-Sat-Ciuruleasa,Ciuruleasa', 46.2500000, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117297, 'Ciurila', 'Ciurila', 'Ciurila,Csueruelye,Csürülye', 46.6500000, 23.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117298, 'Ciurea', 'Ciurea', 'Ciurea,Lunca', 47.0500000, 27.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117299, 'Ciupercenii Vechi', 'Ciupercenii Vechi', 'Ciuperceni,Ciupercenii Vechi', 43.9451200, 22.8946900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117300, 'Ciupercenii Noi', 'Ciupercenii Noi', 'Ciuperceni,Ciupercenii Noi,Ciupercenii-Noui', 43.9097200, 22.9483300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117301, 'Ciuperceni', 'Ciuperceni', 'Ciuperceni', 44.9333300, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117302, 'Ciuperceni', 'Ciuperceni', '', 44.3175000, 25.3786900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117303, 'Ciuperceni', 'Ciuperceni', 'Ciuperceni', 43.7666700, 24.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117304, 'Ciumești', 'Ciumesti', 'Ciumesti,Ciumeşti', 47.6638200, 22.3406900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117305, 'Ciumeghiu', 'Ciumeghiu', 'Ciumeghiu,Ciumeghiul', 46.7333300, 21.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117306, 'Ciumbrud', 'Ciumbrud', '', 46.3081000, 23.7622200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117307, 'Ciumani', 'Ciumani', 'Ciumani,Csomafalva,Gyergyocsomafalva,Gyergyócsomafalva', 46.6833300, 25.5166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117308, 'Ciulnița', 'Ciulnita', 'Ciulnita,Ciulnita-Eustatiade,Ciulniţa,Ciulniţa-Eustatiade', 44.7876900, 25.1538800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117309, 'Ciulniţa', 'Ciulnita', '', 44.5333300, 27.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117310, 'Ciugud', 'Ciugud', 'Ciugud', 46.0500000, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117311, 'Ciugheș', 'Ciughes', 'Ciughes,Ciugheş,Ciunghes,Ciungheş', 46.5222000, 26.1197000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117312, 'Ciudanoviţa', 'Ciudanovita', 'Ciudanovita,Ciudanoviţa', 45.1447200, 21.7977800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117313, 'Ciucurova', 'Ciucurova', 'Ciucurova', 44.9333300, 28.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117314, 'Ciucsângeorgiu', 'Ciucsangeorgiu', 'Ciucsangeorgiu,Ciucsingeorgiu,Ciucsângeorgiu,Ciucsîngeorgiu,Csik Szent Gyorgu,Csik Szent Györgu,Csikszentgyorgy,Csikszentgyörgy', 46.3166700, 25.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117315, 'Ciuchici', 'Ciuchici', 'Ciuchici,Ciuchiciu,Cukic,Cukič', 44.9413900, 21.6100000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117316, 'Ciucea', 'Ciucea', 'Ciucea', 46.9500000, 22.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117317, 'Ciucani', 'Ciucani', 'Ciucani,Csekefalva,Csik Csekefalod', 46.2570100, 25.9474400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117318, 'Ciuani', 'Ciuani', 'Ciuani,Mereni-Ciuani,Mereni-Stefeni,Mereni-Ştefeni', 44.2333300, 25.6500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117319, 'Câţcău', 'Catcau', 'Catcau,Catcaul,Citcau,Câţcău,Câţcăul,Cîţcău', 47.2000000, 23.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117320, 'Cisnădie', 'Cisnadie', 'Cisnadie,Cisnădie,Heltau,Nagydisznod,Nagydisznód', 45.7166700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117321, 'Cișmele', 'Cismele', 'Cismele,Cişmele,Fantanele,Fânţanele', 45.5163400, 27.9297500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117322, 'Cislău', 'Cislau', 'Cislau,Cislău', 45.2500000, 26.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117323, 'Cârţişoara', 'Cartisoara', 'Cirtisoara,Cîrţişoara,Kercisora,Kercisóra,Streja Cartisoara,Streja Cârtişoara,Streza-Cartisoara,Streza-Cirtisoara,Streza-Cârtişoara,Streza-Cîrţişoara', 45.7166700, 24.5833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117324, 'Cârţa', 'Carta', 'Carta,Cirta,Cârţa,Cîrţa,Karcfalva', 46.5333300, 25.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117325, 'Cârţa', 'Carta', 'Carta,Cirta,Cirta Saseasca,Cârţa,Cîrţa,Cîrţa Săsească', 45.7833300, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117326, 'Cârniceni', 'Carniceni', 'Carniceni,Cirniceni,Cârniceni,Cîrniceni', 47.3394200, 27.5050800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117327, 'Cârlogani', 'Carlogani', 'Carlogani,Cirlogani,Cârlogani,Cîrlogani', 44.5166700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117328, 'Cârligi', 'Carligi', 'Carligi,Cirligi,Cârligi,Cîrligi', 46.7658300, 26.8505300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117329, 'Cârligele', 'Carligele', 'Carlige,Carligele,Cirligele,Cârlige,Cârligele,Cîrligele', 45.6833300, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117330, 'Cârlibaba', 'Carlibaba', 'Carlibaba,Cirlibaba,Cirlibaba Veche,Cârlibaba,Cîrlibaba,Cîrlibaba Veche', 47.5833300, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117331, 'Cârjoaia', 'Carjoaia', 'Carjoaia,Cirjoaia,Cârjoaia,Cîrjoaia', 47.3403200, 26.9086300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117332, 'Cârjiţi', 'Carjiti', 'Carjiti,Cârjiti', 45.8500000, 22.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117333, 'Cârja', 'Carja', 'Carja,Cirja,Cirja de Sus,Cârja,Cîrja,Cîrja de Sus', 46.1487800, 28.1101200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117334, 'Cireşu', 'Ciresu', 'Ciresu,Ciresul,Cireşu,Cireşul', 44.9500000, 27.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117335, 'Cireşu', 'Ciresu', 'Ciresiju,Ciresu,Ciresul,Cireşu,Cireşul', 44.8233300, 22.5380600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117336, 'Cireșoaia', 'Ciresoaia', '', 47.1426500, 24.0621700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117337, 'Cireșoaia', 'Ciresoaia', 'Biserica Slanic,Biserica Slanicel,Biserica Slănic,Ciresoaia,Cireşoaia', 46.2481600, 26.5492900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117338, 'Cârcea', 'Carcea', 'Carcea,Circea,Cîrcea', 44.2691700, 23.9000700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117339, 'Ciprian Porumbescu', 'Ciprian Porumbescu', 'Ciprian Porumbescu,Stupca', 47.5666700, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117340, 'Cipău', 'Cipau', 'Cipau,Cipaul,Cipău,Cipăul', 46.4487600, 24.2778600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117341, 'Ciorteşti', 'Ciortesti', 'Ciortesti,Ciorteşti', 46.9000000, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117342, 'Cioroiași', 'Cioroiasi', '', 44.0833300, 23.4500000, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117343, 'Ciorogârla', 'Ciorogarla', 'Ciorogarla,Ciorogirla,Ciorogârla,Ciorogîrla', 44.4425000, 25.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117344, 'Cioroboreni', 'Cioroboreni', 'Ciorobereni,Cioroboreni', 44.3887700, 22.7632600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117345, 'Ciorăști', 'Ciorasti', 'Ciorascii,Ciorasti,Ciorăşcii,Ciorăşti', 46.1138000, 27.4531100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117346, 'Ciorăşti', 'Ciorasti', '', 45.4333300, 27.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117347, 'Cioranii de Sus', 'Cioranii de Sus', 'Ciorani-de-Sus,Cioranii de Sus', 44.8392300, 26.3947300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117348, 'Cioranii de Jos', 'Cioranii de Jos', 'Ciorani-de-Jos,Cioranii de Jos', 44.8166700, 26.4166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117349, 'Ciorani', 'Ciorani', 'Ciorani,Cioranii', 45.9882400, 27.2161400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117350, 'Ciomăgeşti', 'Ciomagesti', 'Ciomagesti,Ciomăgeşti,Fedelesti-Ciomagesti,Fedeleşti-Ciomăgesti', 44.8333300, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117351, 'Ciolpani', 'Ciolpani', 'Ciolpani', 44.7333300, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117352, 'Ciohorăni', 'Ciohorani', 'Cichoreni,Ciohorani,Ciohorăni', 47.1352000, 26.6895500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117353, 'Ciofrângeni', 'Ciofrangeni', 'Ciofranceni,Ciofrangeni,Ciofringeni,Ciofrânceni,Ciofrângeni,Ciofrîngeni', 45.0833300, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117354, 'Ciofliceni', 'Ciofliceni', '', 44.6812200, 26.1192300, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117355, 'Ciocârlia de Sus', 'Ciocarlia de Sus', 'Biulbiu Mare,Ciocarlia-de-Sus,Ciocirlia de Sus,Ciocârlia-de-Sus,Ciocîrlia de Sus', 44.1171200, 28.3340200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117356, 'Ciocârlia', 'Ciocarlia', 'Ciocarlia,Ciocirlia,Ciocârlia,Ciocîrlia', 44.8000000, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117357, 'Ciocârlia', 'Ciocarlia', 'Biulbiu Mic,Ciocarlia-de-Jos,Ciocirlia,Ciocirlia de Jos,Ciocârlia-de-Jos,Ciocîrlia,Ciocîrlia de Jos', 44.1000000, 28.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117358, 'Ciocile', 'Ciocile', 'Ciocile', 44.8166700, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117359, 'Ciochiuța', 'Ciochiuta', 'Ciochiut,Ciochiuta,Ciochiutu,Ciochiuţ,Ciochiuţa', 44.6030600, 23.1169800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117360, 'Ciochina', 'Ciochina', 'Ciochina', 44.5833300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117361, 'Ciocani', 'Ciocani', 'Ciocani', 46.2604400, 27.5599400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117362, 'Ciocănești', 'Ciocanesti', '', 47.4810700, 25.2791200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117363, 'Cicănești', 'Cicanesti', 'Ciocanesti,Ciocăneşti', 45.2460100, 24.6052600, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117364, 'Ciocăneşti', 'Ciocanesti', '', 44.6000000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117365, 'Ciocăneşti', 'Ciocanesti', '', 44.2000000, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117366, 'Ciocănari', 'Ciocanari', '', 44.6977000, 25.9771700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117367, 'Ciobanu', 'Ciobanu', 'Ciobanu,Ciobanul', 44.7175900, 27.9869800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117368, 'Cintei', 'Cintei', '', 46.4443400, 21.5655600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117369, 'Cândeşti Vale', 'Candesti Vale', 'Candesti,Candesti Vale,Candosti,Cindesti Vale,Cândeşti,Cândeşti Vale,Cândoşti,Cîndeşti Vale,Gandesti,Gândeşti', 45.0833300, 25.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117370, 'Cândeşti', 'Candesti', 'Candesti,Cindesti,Cindesti-Dorohoi,Cândeşti,Cîndeşti,Cîndeşti-Dorohoi', 47.9333300, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117371, 'Cândeşti', 'Candesti', 'Candesti,Cindesti,Cândesti,Cîndeşti', 46.7166700, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117372, 'Cincu', 'Cincu', 'Cincu,Cincul,Gross-Schenk,Grossschenk,Großschenk', 45.9166700, 24.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117373, 'Câmpurile de Jos', 'Campurile de Jos', 'Campuri-de-Jos,Campurile,Campurile de Jos,Cimpuri de Jos,Cimpurile de Jos,Câmpuri-de-Jos,Câmpurile,Câmpurile de Jos,Cîmpuri de Jos,Cîmpurile de Jos', 46.0166700, 26.7833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117374, 'Câmpuri', 'Campuri', '', 46.0153500, 26.7880200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117375, 'Câmpurelu', 'Campurelu', 'Campurelu,Cimpurelu,Câmpurelu,Cîmpurelu', 44.2339200, 26.1871900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117376, 'Câmpulung Moldovenesc', 'Campulung Moldovenesc', 'Campulung,Campulung Moldovenesc,Campulungul Moldov,Campulungul Moldovenesc,Cimpulung Moldovenesc,Câmpulung,Câmpulung Moldovenesc,Câmpulungul Moldov,Câmpulungul Moldovenesc,Cîmpulung Moldovenesc,Kimpolung,Kimpulung Moldawski,Kimpulung Moldovanesk,Kimpulung Moldoveneskas,Kimpulung Mołdawski,Kimpulung-Moldovenesk,Kumpulung Moldovenesk,Kympulung-Moldovenesk,Moldvahosszumezo,Moldvahosszúmező,Opstina Campulung Moldovenesc,Opština Câmpulung Moldovenesc,kwmpwlwng mwldwmnh,mo er duo wa de qu ken pu long ge,qmpwlwng mwldwbnsq,Кимполунг,Кимпулунг Молдованеск,Кимпулунг-Молдовенеск,Къмпулунг Молдовенеск,Кымпулунг-Молдовенеск,קמפולונג מולדובנסק,کومپولونگ مولدومنه,კიმპულუნგ-მოლდოვენესკი,クンプルング・モルドヴェネスク,摩爾多瓦地區肯普隆格', 47.5333300, 25.5666700, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117377, 'Câmpulung la Tisa', 'Campulung la Tisa', 'Campulung-la Tisa,Campulung-pe-Tisa,Cimpulung la Tisa,Câmpulung-la Tisa,Câmpulung-pe-Tisa,Cîmpulung la Tisa', 47.9865100, 23.7726300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117378, 'Câmpulung', 'Campulung', 'Campulung,Campulung Muscel,Câmpulung,Kampulung,Kimpulung,Kimpulung-Muschel,Kimpulungas,Kumpulung,Kympulung,Opstina Campulung,Opština Câmpulung,ken pu long ge,kmpwlwn,Кампулунг,Кимпулунг,Кимпулунг-Мусчел,Къмпулунг,Кымпулунг,کمپولون,肯普隆格', 45.2666700, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117379, 'Câmpineanca', 'Campineanca', 'Cimpineanca,Cîmpineanca,Floresti,Floresti-Slobozia,Floreşti,Floreşti-Slobozia', 45.7116600, 27.1283200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117380, 'Câmpina', 'Campina', 'Campina,Cimpina,Câmpina,Cîmpina,Kimpina,Kumpina,Kympina,Opstina Campina,Opština Câmpina,kan pi na,kmpya,Кимпина,Кимпіна,Къмпина,Кымпина,کمپیا,坎皮納', 45.1261900, 25.7349600, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117381, 'Câmpia Turzii', 'Campia Turzii', 'Aranyosgyeres,Aranyosgyéres,Campia Turzei,Campia Turzi,Campia Turzii,Cimpia Turzii,Câmpia Turzei,Câmpia Turzi,Câmpia Turzii,Cîmpia Turzii,Kampija Turziji,Kimpija Turzis,Kimpija-Turzij,Kympija-Turzi,Opstina Campia Turzii,Opština Câmpia Turzii,ken pi ya tu er ji,kmpya twrzy,Кампија Турзији,Кимпия-Турзий,Кимпія-Турзій,Кымпия-Турзи,کمپیا تورزی,クンピア・トゥルジー,肯皮亞圖爾濟', 46.5500000, 23.8833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117382, 'Câmpeni', 'Campeni', 'Campeni,Cimpeni,Câmpeni,Cîmpeni,Kimpen'',Kimpeni,Opstina Campeni,Opština Câmpeni,Topanfalva,Topánfalva,ken pei ni,kmph,Кимпени,Кимпень,کمپه,肯佩尼', 46.3666700, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117383, 'Câmpani', 'Campani', 'Alsokimpany,Alsókimpány,Campani,Campanii-de-Jos,Campanii-de-Sus,Cimpanii de Jos,Cimpanii de Sus,Câmpani,Câmpanii-de-Jos,Câmpanii-de-Sus,Cîmpanii de Jos,Cîmpanii de Sus,Felsokimpany,Felsomezos,Felsőkimpány,Felsőmezős,Kimpany,Kimpány', 46.5141500, 22.5218600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117384, 'Câmpani de Pomezeu', 'Campani de Pomezeu', 'Campani,Cimpani de Pomezeu,Câmpani,Cîmpani de Pomezeu', 46.8000000, 22.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117385, 'Câlnic', 'Calnic', 'Calnicu,Calnicul,Cilnicu,Câlnicu,Câlnicul,Cîlnicu', 44.9500000, 23.0833300, 'RO', '2015-11-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117386, 'Câlnic', 'Calnic', 'Calnic,Cilnic,Câlnic,Cîlnic,Kelling', 45.8833300, 23.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117387, 'Câlnic', 'Calnic', 'Calnic,Cilnic,Câlnic,Cîlnic,Kelnik,Kolnik,Kolnok,Kölnik,Kölnök', 45.3384400, 21.8575400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117388, 'Cilieni', 'Cilieni', 'Chilieni,Cilieni', 43.9000000, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117389, 'Cilibia', 'Cilibia', 'Cilibia', 45.0666700, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117390, 'Câinenii Mici', 'Cainenii Mici', 'Caineni,Ciinenii Mici,Câineni,Cîinenii Mici', 45.4833300, 24.3000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117391, 'Cidreag', 'Cidreag', 'Cidreag,Csedreg', 47.9867700, 22.9639500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117392, 'Ciclova-Română', 'Ciclova-Romana', 'Ciclova Romina,Ciclova Romînă,Ciclova-Romana,Ciclova-Română,Ciklova Romana', 45.0136100, 21.7191700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117393, 'Cicârlău', 'Cicarlau', 'Cicarlau,Cicirlau,Cicîrlău,Cicărlâu', 47.6915500, 23.4038000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117394, 'Ciceu-Mihăiești', 'Ciceu-Mihaiesti', 'Ciceu-Mihaesti,Ciceu-Mihaiesti,Ciceu-Mihăeşti,Ciceu-Mihăieşti', 47.1856800, 23.9748000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117395, 'Ciceu-Giurgeşti', 'Ciceu-Giurgesti', 'Ciceu-Giurgesti,Ciceu-Giurgeşti', 47.2500000, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117396, 'Ciceu', 'Ciceu', 'Ciceu,Ciceul,Csicso,Csicsó', 46.4132800, 25.7820400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117397, 'Ciacova', 'Ciacova', 'Ciacova,Csak,Csák,Tschakowa', 45.5080600, 21.1286100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117398, 'Chiuza', 'Chiuza', 'Chiuza', 47.2333300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117399, 'Chiuiești', 'Chiuiesti', 'Chiuesti,Chiueşti,Chiuiesti,Chiuieşti,Pecsetszeg', 47.2968600, 23.8755300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117400, 'Chițorani', 'Chitorani', '', 44.9745800, 26.1189500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117401, 'Chițoc', 'Chitoc', '', 46.5954500, 27.6745000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117402, 'Chitila', 'Chitila', 'Chitil,Chitila', 44.5080600, 25.9822200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117403, 'Chișoda', 'Chisoda', 'Chisoda,Chişoda,Kischoda,Kisoda,Kissoda,Tesold,Tesöld', 45.7038000, 21.2143700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117404, 'Chişlaz', 'Chislaz', 'Chislaz,Chişlaz', 47.2833300, 22.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117405, 'Chişineu-Criş', 'Chisineu-Cris', 'Chisinau-Cris,Chisineu Cris,Chişineu Criş,Chişinău-Criş', 46.5250900, 21.5184400, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117406, 'Chisindia', 'Chisindia', 'Biszindia,Chisindia,Keszend,Kiszindia,Koszend,Kőszend', 46.2833300, 22.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117407, 'Chiselet', 'Chiselet', 'Chiselet', 44.1833300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117408, 'Chișcăreni', 'Chiscareni', '', 47.4697400, 27.1962600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117409, 'Chiscani', 'Chiscani', 'Chiscani', 45.1833300, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117410, 'Chirpăr', 'Chirpar', 'Chirpar,Chirpăr', 45.9000000, 24.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117411, 'Chirnogi', 'Chirnogi', 'Chirnogi', 44.1166700, 26.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117412, 'Chirnogeni', 'Chirnogeni', 'Chirnogeni,Chiuvenlia', 43.9000000, 28.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117413, 'Chiriacu', 'Chiriacu', 'Chiriac,Chiriacu,Chiriacul', 44.0503600, 25.7772600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117414, 'Chircești', 'Chircesti', '', 46.8462900, 27.8492000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117415, 'Chiraftei', 'Chiraftei', '', 45.7722000, 28.0271600, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117416, 'Chiojdu', 'Chiojdu', 'Chiojd,Chiojdu,Chiojdul', 45.3500000, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117417, 'Chiojdeni', 'Chiojdeni', 'Chiojdeni', 45.5500000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117418, 'Chiojdeanca', 'Chiojdeanca', 'Chiojdeanca', 45.1666700, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117419, 'Chiochiş', 'Chiochis', 'Chiochis,Chiochiş,Kekes', 46.9833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117420, 'Chintinici', 'Chintinici', 'Chintinci,Chintinici,Chitinici', 46.8275400, 26.4933900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117421, 'Chinteni', 'Chinteni', 'Chinteni,Kajanto,Kajántó', 46.8666700, 23.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117422, 'Chiliile', 'Chiliile', 'Chiliile', 45.4500000, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117423, 'Chilii', 'Chilii', '', 46.8025400, 27.0339400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117424, 'Chilia Veche', 'Chilia Veche', 'Achillea,Chilia Veche,Khilvaci,Kiliya Veki,Licostomo', 45.4166700, 29.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117425, 'Chiheru de Jos', 'Chiheru de Jos', 'Alsokoher,Alsòköhèr,Chiheru de Jos,Chiherul-de Jos', 46.6833300, 24.8833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117426, 'Chieşd', 'Chiesd', 'Chiesd,Chieşd', 47.3833300, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117427, 'Chier', 'Chier', '', 46.3419900, 21.8248800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117428, 'Chichiş', 'Chichis', 'Chichis,Chichiş,Kokos,Kökös', 45.7833300, 25.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117429, 'Chibed', 'Chibed', 'Chibed,Kibed,Kibèd', 46.5332800, 24.9621500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117430, 'Chiajna', 'Chiajna', 'Cheajna,Chiajna', 44.4600000, 25.9733300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117431, 'Chevereşu Mare', 'Cheveresu Mare', 'Cheveres,Cheveresu Mare,Cheveresul-Mare,Chevereş,Chevereşu Mare,Chevereşul-Mare,Nagy-Keveres,Nagykoveres,Nagykövéres', 45.6669400, 21.4908300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117432, 'Cheţani', 'Chetani', 'Chelani,Cheta,Chetani,Cheţa,Cheţani', 46.4666700, 24.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117433, 'Cheț', 'Chet', '', 47.4194300, 22.3387700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117434, 'Chesinț', 'Chesint', 'Chesint,Chesinţ,Keszencz,Keszincz,Keszéncz,Lippakeszi', 46.0497300, 21.5794400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117435, 'Cheșereu', 'Chesereu', 'Chesereu,Chesereul,Cheşereu', 47.4277900, 22.1141600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117436, 'Chereluș', 'Cherelus', '', 46.4686000, 21.7070600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117437, 'Cherechiu', 'Cherechiu', 'Cherechiu,Cherechiul', 47.3833300, 22.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117438, 'Chendu', 'Chendu', 'Chendu,Chendu Mare,Chendul-Mare,Nagykend', 46.3923400, 24.7291200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117439, 'Chendrea', 'Chendrea', '', 47.1223600, 23.2990400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117440, 'Chelința', 'Chelinta', 'Chelinta,Chelinţa,Chelnita,Chelniţa', 47.4531100, 23.3179900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117441, 'Cheia', 'Cheia', '', 45.1830600, 24.2166600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117442, 'Checea', 'Checea', 'Checea,Checia,Cheeia,Kecsa,Kécsa,Nagykocse,Nagykőcse', 45.7529800, 20.8359600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117443, 'Cezieni', 'Cezieni', 'Cezieni', 44.1833300, 24.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117444, 'Cetăţeni', 'Cetateni', 'Cetateni,Cetateni Deal,Cetatenii Deal,Cetăteni Deal,Cetătenii Deal,Cetăţeni', 45.2000000, 25.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117445, 'Cetatea de Baltă', 'Cetatea de Balta', 'Cetatea de Balta,Cetatea de Baltă', 46.2479400, 24.1724400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117446, 'Cetatea', 'Cetatea', 'Cetatea,Turbatu,Turbatul', 43.9510500, 25.9345000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117447, 'Cetate', 'Cetate', 'Centatea,Cetate', 44.1000000, 23.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117448, 'Cetariu', 'Cetariu', 'Cetariu', 47.1333300, 22.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117449, 'Cervenia', 'Cervenia', 'Cervenia', 43.8333300, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117450, 'Ceru-Băcăinţi', 'Ceru-Bacainti', 'Ceru-Bacainti,Ceru-Băcăinţi,Cerul-Bacainti,Cerul-Băcăinţi', 45.9833300, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117451, 'Certeze', 'Certeze', 'Certeze', 47.9000000, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117452, 'Cerţeşti', 'Certesti', 'Certesti,Cerţeşti', 46.0166700, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117453, 'Certeju de Sus', 'Certeju de Sus', 'Certeju de Sus,Certejul-de Sus,Felsocsertes,Felsőcsertés', 45.9666700, 22.9666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117454, 'Cernu', 'Cernu', 'Cernu,Cernul', 46.4699900, 26.5847700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117455, 'Cernişoara', 'Cernisoara', 'Cernisoara,Cernişoara', 45.0333300, 23.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117456, 'Cernica', 'Cernica', 'Cernica,Cernica-Tanganu,Cernica-Tanganul,Cernica-Tânganu', 44.4166700, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117457, 'Cernetu', 'Cernetu', 'Atarnati,Atirnati,Atârnaţi,Atîrnaţi,Cernetu', 43.9072700, 25.4568800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117458, 'Cerneți', 'Cerneti', 'Cerneci,Cerneti,Cerneţi', 44.6347600, 22.7093100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117459, 'Cerneşti', 'Cernesti', '', 47.5166700, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117460, 'Cernele', 'Cernele', 'Cernele,Cernelele de Jos', 44.3336300, 23.7414000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117461, 'Cernavodă', 'Cernavoda', 'Bogazkoey,Boğazköy,Cernavoda,Cernavodă,Cherna voda,Chernavoda,Chernavode,Chernavodeh,Opstina Cernavoda,Opština Cernavodã,Tcherna Voda,cherunavu~oda,chrnwda,qie er na wo de,tshrnafwda,Черна вода,Чернавода,Чернаводе,Чернаводэ,Չերնավոդե,تشرنافودا,چرنودا,チェルナヴォダ,切爾納沃德', 44.3395700, 28.0327300, 'RO', '2014-10-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117462, 'Cernăteşti', 'Cernatesti', 'Cernatesti,Cernăteşti', 45.2666700, 26.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117463, 'Cernăteşti', 'Cernatesti', 'Cernatesti,Cernăteşti', 44.4500000, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117464, 'Cernat', 'Cernat', 'Alsocsernaton,Alsòcsernàton,Cernat,Cernatu de Jos,Cernatul-de-Jos,Csernaton,Csernáton', 45.9500000, 26.0333300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117465, 'Cerna', 'Cerna', 'Cerna', 45.0833300, 28.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117466, 'Cermei', 'Cermei', 'Cermei,Cermeiu', 46.5500000, 21.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117467, 'Cergău Mic', 'Cergau Mic', 'Cergau Mic,Cergaul-Mic,Cergău Mic,Cergăul-Mic', 46.0833300, 23.9333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117468, 'Cergău Mare', 'Cergau Mare', 'Cergau Mare,Cergaul-Mare,Cergău Mare,Cergăul-Mare', 46.0986900, 23.9228400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117469, 'Didești', 'Didesti', '', 44.2166700, 24.8833300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117470, 'Cerdac', 'Cerdac', 'Cerdac,Slanic,Slanic-Cerdac,Slanicu-Cerdac,Slănic,Slănic-Cerdac,Slănicu-Cerdac', 46.2379400, 26.5163800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117471, 'Ceardac', 'Ceardac', 'Ceardac,Cerdac,Ceurdacu', 45.6696700, 27.1661100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117472, 'Cerchezu', 'Cerchezu', 'Cerchezchioi,Cerchezu,Cerchezul', 43.8166700, 28.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117473, 'Cerbăl', 'Cerbal', 'Cerbal,Cerbăl', 45.7833300, 22.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117474, 'Cerăt', 'Cerat', '', 44.0666700, 23.6666700, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117475, 'Ceraşu', 'Cerasu', 'Cerasu,Cerasul,Ceraşu,Ceraşul', 45.3166700, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117476, 'Ceptura de Sus', 'Ceptura de Sus', '', 45.0166700, 26.3166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117477, 'Ceptura de Jos', 'Ceptura de Jos', '', 45.0208800, 26.3272200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117478, 'Cepleniţa', 'Ceplenita', 'Ceplenita,Cepleniţa', 47.3833300, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117479, 'Ceparii Pământeni', 'Ceparii Pamanteni', 'Cepari,Cepari Paminteni,Cepari Pămînteni,Ceparii', 45.2166700, 24.5666700, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117480, 'Cepari', 'Cepari', '', 44.4973300, 24.1712200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117481, 'Cenei', 'Cenei', 'Cenei,Csene,Csenej,Cseney,Horvathcsene,Horváthcsene,Szerbcsene,Tschene', 45.7158300, 20.9038900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117482, 'Cenade', 'Cenade', 'Cenade', 46.0500000, 24.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117483, 'Cenad', 'Cenad', 'Canad,Cenad,Cenadium,Cenadu Mare,Cenadu Sirbesc,Cenadu Sîrbesc,Cenadu Vechi,Cenadul-Mare,Cenadul-Vechi,Cenadul-Vechiu,Chanad,Chenad,Comuna Cenad,Csanad,Csanád,Deutsch-Tschanad,Escanad,Eščanad,Gross Tschanad,Nadcanad,Nadčanad,Nagycsanad,Nagycsanád,Nemet Canad,Nemet Čanad,Opstina Cenad,Opština Cenad,Oscsanad,Racz-Csanad,Raitzisch-Tschanad,Rácz-Csanád,Čanád,Őscsanád,Чанад,Ченад', 46.1333300, 20.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117484, 'Celaru', 'Celaru', 'Celaru,Celarul', 44.0500000, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117485, 'Ceica', 'Ceica', '', 46.8500000, 22.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117486, 'Cehu Silvaniei', 'Cehu Silvaniei', 'Cehu Silvaniei,Cehul Silvaniel,Cehul-Silvaniei,Chekhu-Silvaniej,Opstina Cehu Silvaniei,Opština Cehu Silvaniei,Szilagycseh,Szilágycseh,khw sylwanyh,qie hu xi er wa nie yi,Чеху-Силванией,Чеху-Сілванієй,کهو سیلوانیه,切胡錫爾瓦涅伊', 47.4117700, 23.1748900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117487, 'Cehei', 'Cehei', 'Cehaiu,Ceheiu,Ceheiul', 47.2563200, 22.7750700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117488, 'Cehal', 'Cehal', 'Cehal', 47.3833300, 22.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117489, 'Cegani', 'Cegani', 'Cegani,Ceganii', 44.4627900, 27.9017500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117490, 'Cefa', 'Cefa', 'Cefa', 46.9166700, 21.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117491, 'Ceuașu de Câmpie', 'Ceuasu de Campie', 'Ceuasu de Cimpie,Ceuaşu de Cîmpie,Mezocsavas,Mezőcsávás', 46.6333300, 24.5166700, 'RO', '2015-12-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117492, 'Ceauru', 'Ceauru', 'Ceauru,Ceaurul,Ciauru', 45.0117500, 23.2021100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117493, 'Ceatalchioi', 'Ceatalchioi', 'Ceatal,Ceatalchioi,Cetalchioi,Chatal,Pichet Ceatal', 45.2833300, 28.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117494, 'Ceanu Mare', 'Ceanu Mare', 'Ceanu Mare,Ceanul-Mare', 46.6666700, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117495, 'Ceamurlia de Sus', 'Ceamurlia de Sus', 'Ceamurli-de-Sus,Ceamurlia de Sus,Keamurli de sus', 44.7637300, 28.6088100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117496, 'Ceamurlia de Jos', 'Ceamurlia de Jos', 'Ceamurli-de-Jos,Ceamurlia de Jos,Keamurli de jos', 44.7333300, 28.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117497, 'Ceahlău', 'Ceahlau', 'Ceahlau,Ceahlău,Ciahlau,Ciahlau-Shitul,Ciahlău,Ciahlău-Shitul,Csalho,Csalhó,Rapciuni,Răpciuni,Schit,Schitu,Shitu', 47.0500000, 25.9666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117498, 'Ceacu', 'Ceacu', 'Ceacu,Ceacul,Valea Plopului', 44.2653000, 27.2521300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117499, 'Cazasu', 'Cazasu', 'Cazasu,Cazasul', 45.2717200, 27.8901100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117500, 'Căzăneşti', 'Cazanesti', 'Cazanesti,Căzăneşti', 44.7233300, 22.8905600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117501, 'Căzăneşti', 'Cazanesti', 'Cazanesti,Căzăneşti', 44.6166700, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117502, 'Cazaci', 'Cazaci', 'Cazachi,Cazaci', 44.8015200, 25.5540500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117503, 'Cavnic', 'Cavnic', 'Cavnic,Kapnikbanya,Kapnikbánya', 47.6666700, 23.8666700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117504, 'Cavadineşti', 'Cavadinesti', 'Cavadinesti,Cavadineşti', 46.0666700, 28.0169400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117505, 'Căuaş', 'Cauas', 'Cauas,Căuaş', 47.5666700, 22.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117506, 'Cătunele', 'Catunele', 'Catunele,Catunele-de-Sus,Cătunele,Cătunele-de-Sus', 44.8644200, 22.9070700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117507, 'Cătina', 'Catina', '', 46.8500000, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117508, 'Cătina', 'Catina', 'Catina,Cătina', 45.3000000, 26.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117509, 'Cătina', 'Catina', '', 45.0098400, 25.7839500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117510, 'Cățelu', 'Catelu', 'Catelu,Catelul,Căţelu,Căţelul', 44.4029200, 26.2197500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117511, 'Căteasca', 'Cateasca', 'Cateasca,Căteasca', 44.7666700, 25.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117512, 'Catanele', 'Catanele', '', 44.3819900, 24.5614500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117513, 'Catane', 'Catane', '', 43.9267100, 23.4117800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117514, 'Cătămărești-Deal', 'Catamaresti-Deal', 'Catamarasti,Catamaresti-Deal,Cătămăreşti-Deal,Cătămărăsti', 47.7699900, 26.5989700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117515, 'Cataloi', 'Cataloi', 'Cataloi,Kataloi', 45.0958100, 28.7285600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117516, 'Catalina', 'Catalina', 'Catalina,Szentkatolna', 45.9666700, 26.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117517, 'Caţa', 'Cata', 'Cata,Caţa,Katzendorf', 46.0833300, 25.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117518, 'Castrele Traiane', 'Castrele Traiane', '', 44.2286500, 23.1392100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117519, 'Castranova', 'Castranova', '', 44.1166700, 24.0166700, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117520, 'Castelu', 'Castelu', 'Castelu,Castelul,Chiostel', 44.2500000, 28.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117521, 'Căstău', 'Castau', '', 45.8146500, 23.2117300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117522, 'Cașoca', 'Casoca', '', 45.4826300, 26.2589200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117523, 'Caşin', 'Casin', 'Casin,Casinul,Caşin,Caşinul', 46.2000000, 26.7500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117524, 'Casimcea', 'Casimcea', 'Casimcea', 44.7333300, 28.3666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117525, 'Căşeiu', 'Caseiu', 'Casei,Caseiu,Caseiul,Căşei,Căşeiu,Căşeiul', 47.1833300, 23.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117526, 'Căscioarele', 'Cascioarele', '', 44.4991100, 25.6381700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117527, 'Căscioarele', 'Cascioarele', 'Cascioarele,Căscioarele', 44.1261100, 26.4697200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117528, 'Cartojani', 'Cartojani', '', 44.4322100, 25.4899400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117529, 'Cărpiniș', 'Carpinis', '', 45.1840700, 23.5805200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117530, 'Cărpiniş', 'Carpinis', 'Carpinis,Carpins,Cărpiniş,Cărpinş,Gertiamos,Gertianosch,Gyertyamos,Gyertyanos,Gyertyámos,Gyertyános,Kerpenis,Korpenis', 45.7872200, 20.9041700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117531, 'Cărpinet', 'Carpinet', 'Carpinet,Cărpinet,Kerpenyed,Kerpenyet,Kerpenyéd', 46.4500000, 22.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117532, 'Carpen', 'Carpen', 'Carpen,Carpenu,Carpenul', 44.3333300, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117533, 'C.A. Rosetti', 'C.A. Rosetti', 'C.A. Rosetti,Satanof,Satul Nou,Statul Nou', 45.3000000, 29.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117534, 'C.a. Rosetti', 'C.a. Rosetti', 'C.A. Roseti,C.A. Rosetti', 45.0462200, 27.1664000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117535, 'Carei', 'Carei', 'Carei,Careii,Careii Mare,Careii Mari,Gross-Karol,Grosskarol,Groß-Karol,Großkarol,Karej,Nagy Karoly,Nagy Károly,Nagykaroly,Nagykároly,ka lei,karei,krh,Карей,Кареј,קראלי,کره,カレイ,卡雷', 47.6833300, 22.4666700, 'RO', '2016-01-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117536, 'Carcaliu', 'Carcaliu', 'Carcaliu,Carcaliul', 45.1833300, 28.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117537, 'Cărbuneşti', 'Carbunesti', 'Carbunesti,Cărbuneşti', 45.2333300, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117538, 'Cărbunari', 'Carbunari', 'Carbunari,Cărbunari,Karbonar', 44.8344400, 21.7441700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117539, 'Caraula', 'Caraula', 'Caraula', 44.1833300, 23.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117540, 'Carastelec', 'Carastelec', 'Carastelec', 47.3000000, 22.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117541, 'Caraşova', 'Carasova', 'Carasova,Caraşova,Crasova,Craşova', 45.1986100, 21.8700000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117542, 'Cărășeu', 'Caraseu', 'Caraseu,Caraseul,Cărăşeu,Cărăşeul', 47.7412600, 23.0979800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117543, 'Caransebeş', 'Caransebes', 'CSB,Caransebes,Caransebeş,Carensebes,Karansebes,Karansebesch,Karansebeshe,Karánsebes,Карансебеше', 45.4166700, 22.2166700, 'RO', '2017-01-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117544, 'Carani', 'Carani', 'Carani,Karany,Kárány,Merczidorf,Merczifalva,Merczydorf,Merczyfalva,Merzydorf', 45.9109500, 21.1568600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117545, 'Cărand', 'Carand', 'Carand,Carandu,Cărand,Cărandu,Hevizkarand,Hévízkáránd,Karand,Káránd,Toplicza-Karand,Toplicza-Káránd', 46.4500000, 22.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117546, 'Caraclău', 'Caraclau', 'Caraclau,Caraclaul,Caraclău,Caraclăul', 46.3069600, 26.7164100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117547, 'Caracal', 'Caracal', 'Caracal,Karakal,Karakalis,Opstina Caracal,Opština Caracal,ka la ka er,karakaru,krkl,Каракал,کرکل,カラカル,卡拉卡爾', 44.1166700, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117548, 'Căpuşu Mare', 'Capusu Mare', 'Capusu Mare,Capusul-Mare,Căpuşu Mare,Căpuşul-Mare', 46.7833300, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117549, 'Capu Piscului', 'Capu Piscului', 'Capu Piscului,Capul-Piscului', 45.1799900, 24.9767900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117550, 'Capu Codrului', 'Capu Codrului', 'Capu Codrului,Capul-Codrului', 47.5311700, 25.9872400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117551, 'Capu Câmpului', 'Capu Campului', 'Capu Campului,Capu Cimpului,Capu Câmpului,Capu Cîmpului', 47.5082200, 25.9795900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117552, 'Căprioru', 'Caprioru', 'Caprioru,Capriorul,Căprioru,Căpriorul', 44.9823600, 25.2811600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117553, 'Căpreni', 'Capreni', 'Capreni,Caprenii de Mijloc,Caprenii de Myloc,Căpreni,Căprenii de Mijloc,Căprenii de Myloc', 44.7500000, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117554, 'Caporal Alexa', 'Caporal Alexa', 'Caporal Alexa,Cherechiu', 46.3379300, 21.5831600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117555, 'Căpleni', 'Capleni', 'Capleni,Căpleni', 47.7166700, 22.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117556, 'Căpâlniţa', 'Capalnita', 'Capalnita,Capilnita,Căpâlniţa,Căpîlniţa,Kapolnasfahi,Kapolnasfalu,Kàpolnàsfalù,Käpolnasfahi', 46.3666700, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117557, 'Căpâlna', 'Capalna', 'Capalna,Capilna,Căpâlna,Căpîlna', 46.7333300, 22.1000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117558, 'Căpeni', 'Capeni', 'Capeni,Colonia Capeni,Colonia Căpeni,Căpeni', 46.0411100, 25.5785800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117559, 'Căpățânești', 'Capatanesti', 'Capatinesti,Căpăţîneşti', 45.1833300, 26.8000000, 'RO', '2015-11-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117560, 'Căpățânenii Pământeni', 'Capatanenii Pamanteni', 'Capatineni-Paminteni,Căpăţîneni-Pămînteni', 45.3166700, 24.6500000, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117561, 'Căneşti', 'Canesti', 'Canesti,Căneşti,Pirlita,Pîrlita', 45.4000000, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117562, 'Cămin', 'Camin', 'Camin,Cămin', 47.7283600, 22.4798700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117563, 'Cămărzana', 'Camarzana', 'Camarazana,Camarzana,Camirzana,Cămîrzana,Cămărzana,Cămărăzana,Komorzan', 48.0000000, 23.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117564, 'Cămăraşu', 'Camarasu', 'Camarasu,Camarasu-Desert,Camarasul,Cămaraşul,Cămăraşu,Cămăraşu-Deşert', 46.7833300, 24.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117565, 'Camăr', 'Camar', 'Camar,Camăr,Kemer', 47.3000000, 22.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117566, 'Calvini', 'Calvini', 'Calvini', 45.2500000, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117567, 'Călui', 'Calui', 'Caluiu,Caluiul,Căluiu,Căluiul', 44.4529700, 24.0636000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117568, 'Călugăreni', 'Calugareni', 'Calugareni,Călugăreni', 45.0833300, 26.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117569, 'Călugăreni', 'Calugareni', 'Calugareni,Călugăreni', 44.1716700, 25.9955600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117570, 'Calopăr', 'Calopar', 'Caloparu,Caloparul,Calopăru,Calopărul', 44.1650200, 23.7606000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117571, 'Calomfirești', 'Calomfiresti', '', 43.9173600, 25.3580100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117572, 'Călmăţuiu', 'Calmatuiu', 'Calmatuiu,Carligati,Cirligati,Cârligaţi,Cîrligaţi,Călmăţuiu', 43.9666700, 24.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117573, 'Călineşti-Oaş', 'Calinesti-Oas', 'Calinesti,Calinesti-Oas,Călineşti,Călineşti-Oaş', 47.9000000, 23.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117574, 'Călinești', 'Calinesti', 'Arinii,Calinesti,Calinesti-Cuparencu,Calinestii-Cuparencu,Cuparencu,Călineşti,Călineşti-Cuparencu,Călineştii-Cuparencu', 47.8032900, 26.1534500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117575, 'Călineşti', 'Calinesti', '', 47.7833300, 23.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117576, 'Călineşti', 'Calinesti', 'Calinesti,Calinosti,Călineşti,Călinoşti', 44.8166700, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117577, 'Călineşti', 'Calinesti', 'Calinesti,Calmesti,Călineşti,Călmesti', 44.0833300, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117578, 'Călinești', 'Calinesti', 'Calinesti,Calinestii,Călineşti,Călineştii', 44.0772700, 24.6879600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117579, 'Călina', 'Calina', '', 44.7020500, 24.2543900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117580, 'Călimăneşti', 'Calimanesti', 'Calimanesti,Călimăneşti', 45.2333300, 24.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117581, 'Căldărăști', 'Caldarasti', 'Caldarasti,Caldaresti,Căldăreşti,Căldărăşti', 44.8937500, 27.0340000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117582, 'Căldăraru', 'Caldararu', 'Caldararu,Caldararul,Caldarau,Căldăraru,Căldărarul,Căldărău', 44.4500000, 24.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117583, 'Căldăraru', 'Caldararu', '', 44.4130700, 26.2631300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117584, 'Călăţele', 'Calatele', 'Calatele,Călăţele,Kiskalota', 46.7666700, 23.0166700, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117585, 'Călăraşi', 'Calarasi', 'Calarasi,Ciornohal,Călăraşi,Kalarasi,Калараси', 47.6166700, 27.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117586, 'Călăraşi', 'Calarasi', 'Calarasi,Călăraşi,Harastas,Hărăstaş,Kalarasi,Калараси', 46.4833300, 23.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117587, 'Călăraşi', 'Calarasi', 'Calarasi,Calarasu,Calarasul,Călăraşi,Călăraşu,Călăraşul,Kalarasi,Калараси', 43.8000000, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117588, 'Călan', 'Calan', 'Calan,Calanul-Mare,Călan,Călanul-Mare', 45.7333300, 22.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117589, 'Calafindeşti', 'Calafindesti', 'Calafindesti,Calafindeşti', 47.8500000, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117590, 'Calafat', 'Calafat', 'Calafat,Kalafat,Kalafatas,Opstina Calafat,Opština Calafat,ka la fa te,kallapateu,klfh,Калафат,کلفه,卡拉法特,칼라파트', 43.9911100, 22.9327800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117591, 'Călacea', 'Calacea', '', 46.6768700, 21.9329200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117592, 'Cajvana', 'Cajvana', 'Cajvana', 47.7000000, 25.9666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117593, 'Căiuţi-Sat', 'Caiuti-Sat', '', 46.1833300, 26.9333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117594, 'Căiuți', 'Caiuti', 'Caiuti,Caiuti-Tirg,Caiutii-Targusor,Caiutul,Caiuţul,Căiutii-Târguşor,Căiuţi,Căiuţi-Tîrg', 46.1805700, 26.9257100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117595, 'Căianu Mic', 'Caianu Mic', 'Caianu Mic,Caianul-Mic,Căianu Mic', 47.2333300, 24.1500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117596, 'Căianu Mic', 'Caianu Mic', '', 46.7833300, 23.9166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117597, 'Căianu', 'Caianu', 'Caian,Caianu,Caianul,Calian,Căian,Căianu,Căianul,Călian', 46.7846000, 23.9185000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117598, 'Cadea', 'Cadea', 'Cadea,Cadea-Mare', 47.3118500, 22.0622500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117599, 'Căciulați', 'Caciulati', '', 44.6274100, 26.1725500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117600, 'Cacica', 'Cacica', '', 47.6333300, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117601, 'Căbeşti', 'Cabesti', 'Cabesti,Căbeşti', 46.7666700, 22.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117602, 'Buzoeşti', 'Buzoesti', 'Buzoesti,Buzoeşti', 44.5833300, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117603, 'Buznea', 'Buznea', '', 47.1951500, 27.0157200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117604, 'Buziaş', 'Buzias', 'Busiasch,Buzias,Buziasfuerdo,Buziaş,Buziaș,Buziás,Buziásfürdő', 45.6491700, 21.6036100, 'RO', '2015-04-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117605, 'Buzescu', 'Buzescu', 'Buzescu', 44.0166700, 25.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117606, 'Buzău', 'Buzau', 'Bodzavasar,Bodzavásár,Bouzaou,Buzau,Buzehu,Buzeu,Buzuu,Buzyu,Buzău,bu ze wu,bujeou,buzau,bwzaw,bwzayw,Μπουζάου,Бузау,Бузеу,Бузъу,Бузыу,Бузэу,בוזאו,بوزاؤ,بوزائو,بوزاو,ブザウ,布澤烏,부저우', 45.1500000, 26.8333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117607, 'Buza', 'Buza', 'Buza', 46.9000000, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117608, 'Buturugeni', 'Buturugeni', 'Buturugeni,Buturugenii,Buturugenii-Falcoianca', 44.3652800, 25.8352800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117609, 'Butoieşti', 'Butoiesti', 'Butoesti,Butoiesti,Butoieşti', 44.5833300, 23.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117610, 'Butimanu', 'Butimanu', 'Buliman,Butimanu,Butimanul', 44.6833300, 25.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117611, 'Buteni', 'Buteni', 'Bokony,Buteni,Buttyen,Buttyin,Buttyén,Butyen,Butyin,Butyén,Bököny,Korosbokeny,Körösbökény', 46.3166700, 22.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117612, 'Butea', 'Butea', 'Butea', 47.0666700, 26.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117613, 'Bustuchin', 'Bustuchin', 'Bustucheni,Bustuchin,Bustuchini', 44.9666700, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117614, 'Buşteni', 'Busteni', 'Busteni,Bustenii,Buşteni', 45.4000000, 25.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117615, 'Bușca', 'Busca', 'Busca,Buşca,Mihaestii de Jos,Mihăeştii de Jos', 44.1116600, 24.8023800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117616, 'Burzuc', 'Burzuc', '', 47.1555200, 22.1709600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117617, 'Burueneşti', 'Buruenesti', '', 45.3166700, 26.3500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117618, 'Buruienești', 'Buruienesti', '', 46.9959500, 26.9773200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117619, 'Bursuceni', 'Bursuceni', '', 47.6509700, 26.4753000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117620, 'Burla', 'Burla', '', 47.7903300, 25.9269600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117621, 'Burjuc', 'Burjuc', 'Burjuc', 45.9500000, 22.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117622, 'Burila Mare', 'Burila Mare', 'Burila Mare', 44.4527800, 22.5736100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117623, 'Buriaș', 'Burias', 'Burias,Buriasi,Buriaş,Buriaşi,Valeni-Burias,Văleni-Buriaş', 44.7330400, 25.9805300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117624, 'Burca', 'Burca', '', 45.9122400, 26.9490500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117625, 'Bunteşti', 'Buntesti', 'Bontesd,Buntesti,Buntești,Buntyesd', 46.6166700, 22.4666700, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117626, 'Bunila', 'Bunila', 'Bunila', 45.7000000, 22.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117627, 'Bungetu', 'Bungetu', 'Bungetu,Bungetul', 44.8432300, 25.5381600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117628, 'Bunești', 'Bunesti', 'Bunesti,Bunesti-Falticeni,Bunestii-Falticeni,Buneşti,Buneşti-Fălticeni,Buneştii-Fălticeni', 47.5250100, 26.2882600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117629, 'Buneşti', 'Bunesti', '', 46.8333300, 27.9666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117630, 'Buneşti', 'Bunesti', 'Bundorf,Bunesti,Buneşti', 46.1000000, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117631, 'Buneşti', 'Bunesti', '', 45.1166700, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117632, 'Bumbeşti-Jiu', 'Bumbesti-Jiu', 'Bumbesti,Bumbesti-Jiu,Bumbestii-Jiu,Bumbeşti,Bumbeşti-Jiu,Bumbeştii-Jiu', 45.1666700, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117633, 'Bulzeștii de Sus', 'Bulzestii de Sus', 'Felsobulzesd,Felsőbulzesd', 46.3007000, 22.7611800, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117634, 'Bulzeşti', 'Bulzesti', 'Bulzesta,Bulzesti,Bulzeşti', 44.5333300, 23.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117635, 'Bulz', 'Bulz', 'Bulz', 46.9166700, 22.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117636, 'Buliga', 'Buliga', '', 44.3573100, 27.7922500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117637, 'Bulgăruș', 'Bulgarus', 'Bogaros,Bogarosch,Bogaroş,Bogáros,Bulgarus,Bulgăruş', 45.9194700, 20.8221900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117638, 'Bulbucata', 'Bulbucata', 'Bulbucata', 44.2833300, 25.8033300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117639, 'Bujoru', 'Bujoru', 'Bujoru,Bujorul', 43.7166700, 25.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117640, 'Bujoreni', 'Bujoreni', '', 45.1333300, 24.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117641, 'Târgu Bujor', 'Targu Bujor', '', 45.8666700, 27.9000000, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117642, 'Buhuşi', 'Buhusi', 'Buhus,Buhusi,Buhuş,Buhuşi', 46.7166700, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117643, 'Buhoci', 'Buhoci', 'Bejghir,Buhoci,Buhociu,Satu Nou', 46.5666700, 27.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117644, 'Buhalnița', 'Buhalnita', '', 47.3789200, 26.9154700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117645, 'Bughea de Sus', 'Bughea de Sus', '', 45.2981200, 25.0328400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117646, 'Bughea de Jos', 'Bughea de Jos', '', 45.2666700, 25.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117647, 'Bughea de Jos', 'Bughea de Jos', 'Bughea de Jos,Bughile de Jos', 45.1798500, 26.0204400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117648, 'Buftea', 'Buftea', 'Bouftea,Buftea,Buftja,bftya,bu fu tai ya,bufutea,bupeutea,bwfth,bwftya,Μπούφτεα,Буфтеа,Буфтя,بفتیا,بوفته,بوفتيا,بوفتیا,ブフテア,布夫泰亞,부프테아', 44.5613900, 25.9488900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117649, 'Buești', 'Buesti', 'Budesti,Budeşti,Buesti,Bueşti', 44.5447300, 27.1872900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117650, 'Buduslău', 'Buduslau', 'Buduslau,Buduslaul,Buduslău,Buduşlăul', 47.4000000, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117651, 'Budureasa', 'Budureasa', 'Budureasa', 46.6666700, 22.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117652, 'Budila', 'Budila', 'Budila', 45.6666700, 25.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117653, 'Budeşti', 'Budesti', '', 47.7333300, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117654, 'Budești', 'Budesti', 'Budesti,Budesti-Ghica,Budestii-Ghica,Budeşti,Budeşti-Ghica,Budeştii-Ghica', 46.9408400, 26.7117700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117655, 'Budeşti', 'Budesti', '', 46.8833300, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117656, 'Budești', 'Budesti', '', 45.6277900, 27.0566900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117657, 'Budeşti', 'Budesti', '', 45.0500000, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117658, 'Budeşti', 'Budesti', 'Budesti,Budeşti', 44.2347200, 26.4658300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117659, 'Budeni', 'Budeni', '', 47.4138300, 26.6592700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117660, 'Budeasa Mică', 'Budeasa Mica', '', 44.9500000, 24.8500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117661, 'Budeasa', 'Budeasa', 'Budeasa', 45.0166700, 24.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117662, 'Budăi', 'Budai', 'Budai,Budaile,Budaiu,Budăi,Budăile,Budăiu', 47.2177300, 27.2228200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117663, 'Budacu de Sus', 'Budacu de Sus', 'Budacu de Sus,Budacul de Sus,Felsobudak', 47.0611800, 24.6575200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117664, 'Budacu de Jos', 'Budacu de Jos', 'Budacu de Jos,Budacul-de-Jos', 47.0833300, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117665, 'Buda', 'Buda', '', 47.4031800, 26.6783500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117666, 'Buda', 'Buda', '', 46.7623100, 27.4211300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117667, 'Buda', 'Buda', '', 46.6711100, 26.7195300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117668, 'Buda', 'Buda', 'Buda', 45.5000000, 26.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117669, 'Buda', 'Buda', 'Buda,Buda-Palanga', 44.8244300, 26.1852200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117670, 'Bucharest', 'Bucharest', 'BUH,Boekarest,Boukouresti,Bucarest,Bucaresta,Bucareste,Bucarèst,Bucharest,Bucuresti,Bucureşti,București,Buekres,Bukarest,Bukarestas,Bukareste,Bukaresto,Bukareszt,Bukareŝto,Bukareštas,Bukharest,Bukureshh,Bukuresht,Bukureshta,Bukureshti,Bukurest,Bukurešt,Bukurešť,Buxarest,Búkarest,Bûkarest,Bükreş,bkharst,bu jia lei si te,bukaresuto,bukulesyuti,bwkharst,bwqrst,Βουκουρέστι,Букурешт,Букурещ,Бухарест,Բուխարեստ,בוקאַרעשט,בוקרשט,بخارست,بوخارست,بۇخارېست,པུ་ཁ་རེ་སིད,ბუქარესტი,ቡካረስት,ブカレスト,布加勒斯特,부쿠레슈티', 44.4322500, 26.1062600, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117671, 'Bucureşci', 'Bucuresci', 'Bucuresci,Bucuresti,Bucureşci,Bucureşti', 46.1333300, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117672, 'Bucu', 'Bucu', 'Bucul', 44.6053200, 27.4933700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117673, 'Bucșoaia', 'Bucsoaia', 'Bucsoaia,Bucsoia,Bucşoaia,Bucşoia', 47.5397200, 25.8111800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117674, 'Bucșești', 'Bucsesti', '', 46.4838100, 26.5823000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117675, 'Bucșenești-Lotași', 'Bucsenesti-Lotasi', '', 45.0130700, 24.9684500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117676, 'Bucșenești', 'Bucsenesti', '', 45.3009600, 24.6584100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117677, 'Bucşani', 'Bucsani', 'Bucsani,Bucşani', 44.8666700, 25.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117678, 'Bucşani', 'Bucsani', 'Bucsani,Bucşani', 44.3761100, 25.6552800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117679, 'Bucovineni', 'Bucovineni', '', 47.8500000, 26.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117680, 'Bucovăț', 'Bucovat', 'Albina,Brodipuszta,Brodpuszta,Bródipuszta,Bródpuszta,Bucovat,Bucovăţ,Bukfalva,Bukkfalva,Bukovec,Bukovecz,Bükfalva,Bükkfalva', 45.7556900, 21.3832400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117681, 'Bucovăţ', 'Bucovat', 'Bucovat,Bucovatu,Bucovatul,Bucovăţ,Bucovăţu,Bucovăţul', 44.3000000, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117682, 'Bucova', 'Bucova', '', 45.5090600, 22.6373100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117683, 'Bucov', 'Bucov', 'Bucov,Satu Bucovei', 44.9666700, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117684, 'Bucoşniţa', 'Bucosnita', 'Bucosnita,Bucoşniţa', 45.3000000, 22.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117685, 'Bucium-Orlea', 'Bucium-Orlea', '', 45.5833300, 22.9666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117686, 'Buciumi', 'Buciumi', 'Buciumi,Buciumi-Bodia,Buciumii', 47.0333300, 23.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117687, 'Buciumi', 'Buciumi', 'Buciumi,Buciumii', 46.2023000, 26.7844500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117688, 'Buciumeni', 'Buciumeni', '', 46.0000000, 27.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117689, 'Buciumeni', 'Buciumeni', 'Buciumeni,Buonimeni', 45.1500000, 25.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117690, 'Buciumeni', 'Buciumeni', '', 44.5497500, 25.9641900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117691, 'Bucium', 'Bucium', 'Bucium,Bucium Sasa,Bucium Şasa,Sasa,Şasa', 46.2640200, 23.1791000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117692, 'Bucium', 'Bucium', '', 46.2333300, 23.2166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117693, 'Bucinişu', 'Bucinisu', 'Bucinisu,Bucinisul,Bucinişu,Bucinişul', 43.9500000, 24.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117694, 'Buchin', 'Buchin', 'Buchin', 45.3666700, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117695, 'Bucești', 'Bucesti', '', 45.6525000, 27.5300800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117696, 'Buceş', 'Buces', 'Buces,Buceş', 46.1833300, 22.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117697, 'Bucerdea-Grânoasă', 'Bucerdea-Granoasa', 'Bucerbea-Grenoasa,Bucerbea-Grenoasă,Bucerdea-Granoasa,Bucerdea-Grinoasa,Bucerdea-Grânoasă,Bucerdea-Grînoasă', 46.2000000, 23.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117698, 'Bucecea', 'Bucecea', 'Bucecea', 47.7666700, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117699, 'Brusturoasa', 'Brusturoasa', 'Brusturoasa', 46.5166700, 26.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117700, 'Brusturi', 'Brusturi', 'Brusturi', 47.2833300, 26.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117701, 'Brusturi', 'Brusturi', '', 47.1500000, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117702, 'Bruiu', 'Bruiu', 'Bruiu,Bruiul', 45.8666700, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117703, 'Broșteni', 'Brosteni', '', 47.3045900, 26.5562500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117704, 'Broşteni', 'Brosteni', 'Brosteni,Brosteri,Broşteni,Broşteri', 47.2333300, 25.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117705, 'Broşteni', 'Brosteni', '', 45.7500000, 27.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117706, 'Broşteni', 'Brosteni', '', 44.7608300, 22.9794400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117707, 'Broșteni', 'Brosteni', 'Brosteni,Brosteni-Vale,Brostenii-Vale,Broşteni,Broşteni-Vale,Broştenii-Vale', 44.7205300, 25.5093500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117708, 'Broșteni', 'Brosteni', '', 44.6719200, 26.7478700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117709, 'Broscăuţi', 'Broscauti', 'Broscauti,Broscăuţi', 47.9500000, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117710, 'Brodoc', 'Brodoc', 'Brodoc,Brodocul', 46.6509000, 27.6766900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117711, 'Brodina', 'Brodina', 'Brodina', 47.8833300, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117712, 'Brâncoveni', 'Brancoveni', 'Brancoveni,Brincoveni,Brâncoveni,Brîncoveni', 44.3166700, 24.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117713, 'Brâncoveneşti', 'Brancovenesti', 'Brancovenesti,Brâncovenești,Marosvecs,Marosvécs', 46.8563200, 24.7594100, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117714, 'Brâncoveanca', 'Brancoveanca', '', 43.9407500, 24.6933600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117715, 'Brânceni', 'Branceni', 'Branceni,Brinceni,Brânceni,Brînceni', 43.8833300, 25.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117716, 'Brezoi', 'Brezoi', 'Brezoi,Brezoiu,Brezoiul', 45.3379700, 24.2486300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117717, 'Brezoaele', 'Brezoaele', 'Brailoiu,Brezoaele-Brailoiu,Brezoaele-Brăiloiu,Brăiloiu', 44.5833300, 25.7333300, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117718, 'Brezoaia', 'Brezoaia', '', 44.5568300, 25.7852700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117719, 'Brezniţa Ocol', 'Breznita Ocol', 'Bresnica,Bresnita,Bresnita-Ocol,Bresnita-de-Ocol,Bresniţa,Bresniţa-Ocol,Bresniţa-de-Ocol,Breznita Ocol,Brezniţa Ocol', 44.6666700, 22.6183300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117720, 'Brezniţa-Motru', 'Breznita-Motru', 'Bresnita-Motru,Bresnita-de-Motru,Bresniţa-de-Motru,Breznita-Motru,Brezniţa-Motru,Breşniţa-Motru', 44.5666700, 23.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117721, 'Bretea Română', 'Bretea Romana', 'Bretea Romina,Bretea Romînă,Bretea-Romana,Bretea-Română', 45.6608500, 23.0173900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117722, 'Breţcu', 'Bretcu', 'Bereczk,Brecku,Bretcu,Bretcul,Breţcu,Breţcul', 46.0500000, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117723, 'Brestovăț', 'Brestovat', 'Aga,Brestovat,Brestovăţ,Brestowatz,Bresztovacz', 45.8734200, 21.6820100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117724, 'Brehuiești', 'Brehuiesti', '', 47.7019400, 26.5447200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117725, 'Brebu Nou', 'Brebu Nou', 'Brebu Nou,Brebul-Nou,Vaidental', 45.2333300, 22.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117726, 'Brebu Mânăstirei', 'Brebu Manastirei', 'Brebu,Brebu Minastirei,Brebu Mînăstirei,Brebu-Manastirei,Brebu-Monastire,Brebu-Mânăstirei,Brebul,Brebul-Manastirei,Brebul-Mânăstirei', 45.1833300, 25.7666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117727, 'Brebu Megieșesc', 'Brebu Megiesesc', 'Brebu Megiesesc,Brebu Megieşesc,Magiesese,Magieşese', 45.1677400, 25.7747400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117728, 'Brebu', 'Brebu', 'Brebu,Brebul,Perlo,Perlő', 45.4202800, 21.9925000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117729, 'Brebeni', 'Brebeni', 'Brebeni,Brebeni Sarbii-Magiesesc,Brebeni Sârbii-Magiesesc,Brebeni-Sarbi,Brebeni-Sirbi,Brebeni-Sârbi,Brebeni-Sîrbi,Brebenii-Sarbi,Brebenii-Sârbi', 44.3666700, 24.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117730, 'Breb', 'Breb', 'Breb,Brebu,Bréb', 47.7485400, 23.9049400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117731, 'Breazu', 'Breazu', 'Breazu,Tatarusi,Tătăruşi', 47.2134300, 27.5181500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117732, 'Breaza de Sus', 'Breaza de Sus', 'Brazi de Sus,Breaza de Sus', 45.1987900, 25.6557800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117733, 'Breaza de Jos', 'Breaza de Jos', 'Brazi de Jos,Breaza de Jos', 45.1712500, 25.6757100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117734, 'Breaza', 'Breaza', '', 47.6150200, 25.3181600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117735, 'Breaza', 'Breaza', '', 47.3510800, 24.0622000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117736, 'Breaza', 'Breaza', 'Beresztelke,Breaza', 46.7666700, 24.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117737, 'Breaza', 'Breaza', 'Breaza', 45.1833300, 25.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117738, 'Breaza', 'Breaza', '', 45.1000000, 26.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117739, 'Breasta', 'Breasta', 'Breasta', 44.3333300, 23.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117740, 'Brazii de Sus', 'Brazii de Sus', 'Brazi,Brazi de Sus,Brazii de Sus', 44.8666700, 26.0166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117741, 'Brazii', 'Brazii', 'Brazii,Raj,Saturau,Saturău,Szatureo,Szatureő,Szaturo,Szaturó', 46.2333300, 22.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117742, 'Rădulești', 'Radulesti', 'Brazii,Radulesti Filitis,Răduleşti Filitis', 44.7666700, 26.3500000, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117743, 'Brazi', 'Brazi', 'Brazi,Gaureni,Gureni,Găureni', 45.4871600, 22.8404000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117744, 'Bratovoești', 'Bratovoesti', '', 44.1333300, 23.9000000, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117745, 'Brătila', 'Bratila', 'Bratila,Bratila de Mijloc,Brătila,Brătila de Mijloc', 46.3234800, 26.7744200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117746, 'Brătești', 'Bratesti', '', 47.1913500, 26.6858000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117747, 'Brătești', 'Bratesti', '', 46.3254000, 26.6433300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117748, 'Brateş', 'Brates', 'Baratos,Baràtos,Brates,Brateş', 45.8333300, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117749, 'Brateiu', 'Brateiu', 'Brateiu,Brateiul', 46.1666700, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117750, 'Bratca', 'Bratca', 'Banatka,Banátka,Bratca', 46.9333300, 22.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117751, 'Brastavățu', 'Brastavatu', 'Brastavat,Brastavatu,Brastavatul,Brastavăţu,Brastavăţul,Brastăvăţ', 43.9063400, 24.4078400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117752, 'Braşov', 'Brasov', 'Brashov,Brasov,Brasso,Brassó,Braszow,Braszów,Brazov,Braşov,Brašov,Brașov,Kronstadt,Kronstant,Orasu Stalin,Orasul Stalin,Oraşu Stalin,Oraşul Stalin,XHV,beulasyobeu,brswb,burashofu,Брашов,ברשוב,ブラショフ,브라쇼브', 45.6486100, 25.6061300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117753, 'Braniştea', 'Branistea', '', 47.1666700, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117754, 'Braniştea', 'Branistea', '', 45.4500000, 27.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117755, 'Braniştea', 'Branistea', '', 44.6833300, 25.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117756, 'Braniștea', 'Branistea', '', 44.2420100, 22.9735400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117757, 'Braniștea', 'Branistea', '', 43.9631500, 26.0381200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117758, 'Brăniștari', 'Branistari', '', 44.1762600, 26.0595300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117759, 'Brănişca', 'Branisca', 'Branisca,Brănişca', 45.9166700, 22.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117760, 'Braneț', 'Branet', 'Branet,Branetu,Branetul,Braneţu,Brăneţ,Brăneţul', 44.3257600, 24.1779200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117761, 'Brăneşti', 'Branesti', 'Branesti,Branestii,Brăneşti,Brăneştii', 45.0333300, 25.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117762, 'Brăneşti', 'Branesti', 'Branesti,Brăneşti', 44.6500000, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117763, 'Brăneşti', 'Branesti', 'Branesti,Brăneşti', 44.4500000, 26.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117764, 'Bran', 'Bran', 'Bran,Bran-Poarta,Bran-Poartă,Slottet Bran,Toercsvar,Torzburg,Törcsvár,Törzburg', 45.5166700, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117765, 'Braloştiţa', 'Bralostita', 'Bralostita,Braloştiţa', 44.5000000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117766, 'Brăila', 'Braila', 'Braila,Brailov,Braiła,Brăila,Ibrail,Браила,בראילה', 45.2666700, 27.9833300, 'RO', '2012-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117767, 'Brăhăşeştii de Sus', 'Brahasestii de Sus', 'Brahasesti,Brahasesti-de-Sus,Brahasestii de Sus,Brăhăşeşti,Brăhăşeşti-de-Sus,Brăhăşeştii de Sus', 46.0500000, 27.3500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117768, 'Brăhășești', 'Brahasesti', '', 46.0333300, 27.3666700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117769, 'Bragadiru', 'Bragadiru', 'Bragadiru,Bragadirul', 44.3711100, 25.9775000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117770, 'Bragadiru', 'Bragadiru', 'Bragadiru,Bragadirul', 43.7666700, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117771, 'Brăeşti', 'Braesti', '', 47.8666700, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117772, 'Brăiești', 'Braiesti', '', 47.4967300, 26.0718200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117773, 'Brăeşti', 'Braesti', 'Bradesti,Braesti,Brădeşti,Brăeşti', 47.1500000, 27.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117774, 'Brăeşti', 'Braesti', 'Braesti,Braestii,Brăestii,Brăeşti', 45.4333300, 26.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117775, 'Brăduţ', 'Bradut', 'Bardocz,Bardócz,Bradut,Brăduţ', 46.1333300, 25.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117776, 'Brăduleţ', 'Bradulet', 'Bradulet,Brateni,Bratienii,Brăduleţ,Brăteni,Brătienii', 45.2833300, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117777, 'Bradu', 'Bradu', 'Bradu,Bradul,Gierelsau', 45.7222100, 24.3323400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117778, 'Bradu', 'Bradu', 'Bradu,Bradu de Jos,Bradul-de Jos', 44.7833300, 24.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117779, 'Brădicești', 'Bradicesti', '', 46.8481000, 27.9027000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117780, 'Brădeşti', 'Bradesti', 'Bradesti,Brădeşti,Fenyed,Fenyèd', 46.3500000, 25.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117781, 'Brădeşti', 'Bradesti', '', 44.4833300, 23.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117782, 'Brădeni', 'Bradeni', 'Bradeni,Brădeni,Hendorf', 46.0833300, 24.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117783, 'Brădeanu', 'Bradeanu', 'Bradeanu,Bradeanul,Brădeanu,Brădeanul', 44.9333300, 26.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117784, 'Brad', 'Brad', 'Brad,Brád,Opstina Brad,Opština Brad,brh,bu la de,burado,Брад,بره,ブラド,布拉德', 46.1333300, 22.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117785, 'Brabova', 'Brabova', 'Brabova', 44.3666700, 23.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117786, 'Brabeți', 'Brabeti', '', 43.9609800, 24.0133900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117787, 'Bozovici', 'Bozovici', 'Bozovic,Bozovici', 44.9388900, 22.0016700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117788, 'Bozioru', 'Bozioru', 'Bozioru', 45.3833300, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117789, 'Bozieni', 'Bozieni', 'Bozieni,Bozienii de Jus,Bozienii-Fundacescului,Bozienii-Fundăcescului', 46.8333300, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117790, 'Boureni', 'Boureni', '', 47.2649700, 26.9767200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117791, 'Boureni', 'Boureni', '', 47.2131400, 26.6309200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117792, 'Boureni', 'Boureni', '', 44.0158900, 23.4339300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117793, 'Botoşeşti-Paia', 'Botosesti-Paia', 'Botosesti-Paia,Botosestii Paia,Botoşeşti-Paia,Botoşeştii Paia', 44.4000000, 23.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117794, 'Botoşani', 'Botosani', 'Botosan,Botosani,Botoshani,Botoszany,Botosán,Botoşani,Botoșani,QDD,Ботошани,בוטושאן', 47.7500000, 26.6666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117795, 'Botoşana', 'Botosana', 'Botosana,Botoşana,Botusana,Botuşana', 47.6833300, 25.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117796, 'Botoroaga', 'Botoroaga', 'Botoroaga,Hodoroaga,Ion Gheorghe Duca', 44.1483300, 25.5447200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117797, 'Botiza', 'Botiza', '', 47.6666700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117798, 'Botiz', 'Botiz', 'Botiz', 47.8333300, 22.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117799, 'Botești', 'Botesti', 'Botesti,Boteşti', 47.0520000, 26.7486300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117800, 'Boţeşti', 'Botesti', 'Botesti,Boţeşti', 46.8000000, 27.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117801, 'Boţeşti', 'Botesti', '', 45.0166700, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117802, 'Boteni', 'Boteni', 'Boten,Boteni', 45.1833300, 25.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117803, 'Boşorod', 'Bosorod', 'Bosorod,Boşorod', 45.6833300, 23.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117804, 'Bosia', 'Bosia', 'Bosia-Beresti,Bosia-Bereşti', 47.2169600, 27.7670700, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117805, 'Bosanci', 'Bosanci', 'Bosancea,Bosanci', 47.5833300, 26.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117806, 'Borsec', 'Borsec', 'Borsec,Borsek,Borszek,Borszèk,Borszék,Opstina Borsec,Opština Borsec,bo er sai ke,bwrsh,bwrsq,Борсек,בורסק,بورسه,ბორსეკი,博爾塞克', 46.9500000, 25.5666700, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117807, 'Borşa', 'Borsa', '', 47.6552700, 24.6632800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117808, 'Borşa', 'Borsa', 'Borsa,Borşa,Kolozsoorsa', 46.9333300, 23.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117809, 'Borş', 'Bors', 'Bors,Borş', 47.1166700, 21.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117810, 'Borosoaia', 'Borosoaia', '', 47.4630000, 27.0986200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117811, 'Boroşneu Mare', 'Borosneu Mare', 'Borosnaul-Mare,Borosneu Mare,Borosneul-Mare,Boroşnaul-Mare,Boroşneu Mare,Boroşneul-Mare,Nagyborosnyo,Nagyborosnyò', 45.8166700, 26.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117812, 'Borod', 'Borod', 'Borod', 46.9833300, 22.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117813, 'Boroaia', 'Boroaia', 'Boroaia,Boroaia-Risca,Boroaia-Rîşca,Sibicheni,Suseni', 47.3500000, 26.3333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117814, 'Borlova', 'Borlova', '', 45.3673800, 22.3520000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117815, 'Borleşti', 'Borlesti', 'Borlesti,Borleşti', 46.7666700, 26.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117816, 'Borduşani', 'Bordusani', 'Bordusani,Bordusanii,Borduşani,Borduşanii', 44.4833300, 27.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117817, 'Bordeşti', 'Bordesti', 'Bordesti,Bordesti-de-Sus,Bordestii de Sus,Bordeşti,Bordeşti-de-Sus,Bordeştii de Sus', 45.5500000, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117818, 'Bordenii Mari', 'Bordenii Mari', 'Bordeni-Mari,Bordenii Mari', 45.0895100, 25.8696400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117819, 'Bordei Verde', 'Bordei Verde', 'Bordei Verde,Bordeiu-Verde,Bordeiul Verde', 45.0833300, 27.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117820, 'Bordeasca Veche', 'Bordeasca Veche', 'Bordeasca,Bordeasca Veche', 45.5444700, 27.3173000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117821, 'Borcut', 'Borcut', '', 47.4820000, 23.8407100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117822, 'Borcea', 'Borcea', 'Borcea,Cacargeaua,Cocargeaua,Cocargeaua Noua,Cocargeaua Nouă,Cocargeua', 44.3333300, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117823, 'Borca', 'Borca', '', 47.1833300, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117824, 'Borăscu', 'Borascu', 'Borascu,Borăscu', 44.7000000, 23.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117825, 'Borănești', 'Boranesti', '', 44.6606900, 26.6050500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117826, 'Bolvașnița', 'Bolvasnita', 'Bolovasnita,Bolovaşniţa,Bolvasnita,Bolvaşniţa', 45.3455800, 22.3101200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117827, 'Bolovăniș', 'Bolovanis', 'Balavanis,Bolovani,Bolovanii,Bolovanis,Bolovăniş,Bălăvăniş', 46.6163300, 26.0526300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117828, 'Boloteşti', 'Bolotesti', 'Bolotesti,Boloteşti', 45.8333300, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117829, 'Bolintin Vale', 'Bolintin Vale', 'Bolintin Vale,Bolintin-Vale,Bolintin-din-Vale,Bolintineanu,Bolintinu-din-Vale,Bolintinul-din-Vale,Болинтин-Вале', 44.4488900, 25.7577800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117830, 'Bolintin Deal', 'Bolintin Deal', 'Bolintin,Bolintin Deal,Bolintinu,Bolintinu din Deal,Bolintinul', 44.4591700, 25.8211100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117831, 'Boldur', 'Boldur', 'Boldor,Boldur', 45.6941700, 21.7766700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117832, 'Boldu', 'Boldu', 'Boldu,Boldul', 45.3333300, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117833, 'Boldeşti-Scăeni', 'Boldesti-Scaeni', 'Boldesti-Scaeni,Boldeşti-Scăeni', 45.0333300, 26.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117834, 'Boldeşti', 'Boldesti', '', 44.8659700, 26.5490600, 'RO', '2012-06-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117835, 'Bolboşi', 'Bolbosi', 'Bolbosi,Bolboşi', 44.7500000, 23.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117836, 'Bolătău', 'Bolatau', 'Balatau,Bolatau,Bolătău,Bălătău', 46.6334500, 26.4014900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117837, 'Boiu Mare', 'Boiu Mare', 'Boiu Mare,Boiul-Mare', 47.4000000, 23.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117838, 'Boiu', 'Boiu', 'Boiu,Boiul', 46.2663200, 24.8728500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117839, 'Boița', 'Boita', 'Boita,Boiţa', 45.6345400, 24.2603700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117840, 'Boişoara', 'Boisoara', 'Boisoara,Boişoara,Doisoara,Doişoara', 45.4333300, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117841, 'Boinești', 'Boinesti', '', 47.9156700, 23.3511700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117842, 'Boianu Mare', 'Boianu Mare', 'Boianu Mare,Boianul-Mare', 47.3833300, 22.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117843, 'Boian', 'Boian', 'Boian', 46.2015900, 24.2286200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117844, 'Bohotin', 'Bohotin', '', 46.9391400, 27.9778200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117845, 'Bogza', 'Bogza', '', 45.5079800, 27.1977300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117846, 'Boghiș', 'Boghis', 'Boghis,Boghiş', 47.1551200, 22.7388000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117847, 'Boghicea', 'Boghicea', '', 47.0541400, 27.0693500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117848, 'Bogheşti', 'Boghesti', 'Boghesti,Boghesti de Jos,Boghestii-de-Jos,Bogheşti,Bogheşti de Jos,Bogheştii-de-Jos', 46.1666700, 27.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117849, 'Bogei', 'Bogei', 'Bogeiu,Bogeiul', 47.2655000, 22.3607900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117850, 'Bogdan Vodă', 'Bogdan Voda', 'Bogdan Voda,Bogdan Vodă,Cuhea', 47.6919700, 24.2660500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117851, 'Bogdăniţa', 'Bogdanita', 'Bogdanita,Bogdăniţa', 46.4500000, 27.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117852, 'Bogdăneşti', 'Bogdanesti', '', 46.6333300, 23.1333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117853, 'Bogdăneşti', 'Bogdanesti', 'Bogdaneasca,Bogdanesti,Bogdăneasca,Bogdăneşti,Plopi', 47.3666700, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117854, 'Bogdănești', 'Bogdanesti', '', 46.4496500, 27.7267900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117855, 'Bogdăneşti', 'Bogdanesti', 'Bogdanesti,Bogdanestii,Bogdăneşti,Bogdăneştii', 46.2166700, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117856, 'Bogdand', 'Bogdand', 'Bogdan,Bogdand', 47.4166700, 22.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117857, 'Bogdana', 'Bogdana', '', 46.5266800, 27.6327800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117858, 'Bogdana', 'Bogdana', 'Bogdana', 43.9333300, 25.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117859, 'Bogda', 'Bogda', 'Bogda,Bogda-Rigos,Bogda-Rigós,Neuhof,Rigosfurdo,Rigósfürdő', 45.9783300, 21.5725000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117860, 'Bogaţi', 'Bogati', 'Bogati,Bogaţi', 44.8666700, 25.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117861, 'Bogata', 'Bogata', '', 47.4078900, 26.1865500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117862, 'Bogata', 'Bogata', 'Bogata,Bogata de Mures,Bogata de Mureş', 46.4500000, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117863, 'Bodoc', 'Bodoc', 'Bodoc,Bodok', 45.9500000, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117864, 'Bodeștii de Jos', 'Bodestii de Jos', 'Bodesti-de-Jos,Bodestii de Jos,Bodeşti-de-Jos,Bodeştii de Jos', 47.0275200, 26.4448300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117865, 'Bodeşti', 'Bodesti', 'Bodest Precista,Bodesti,Bodesti Precista,Bodesti-de-Sus,Bodestii-de-Sus,Bodeşti,Bodeşti Precista,Bodeşti-de-Sus,Bodeştii-de-Sus', 47.0333300, 26.4166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117866, 'Bodești', 'Bodesti', '', 45.1416700, 24.1154900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117867, 'Bod', 'Bod', '', 45.7666700, 25.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117868, 'Bocsig', 'Bocsig', 'Bocsig,Caragheorghevici', 46.4166700, 21.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117869, 'Bocşa', 'Bocsa', 'Bocsa,Bocşa', 47.2939000, 22.9140500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117870, 'Bocşa', 'Bocsa', 'Bocsa,Bocsa Montana,Bocsa Romina,Bocsa-Romaana,Bocsa-Romana,Bocşa,Bocşa Montană,Bocşa Romînă,Bocşa-Româană,Bocşa-Română,Bogsan,Bogsán,Boksa Romana,Boksan,Boksanbanya,Bokschan,Boksán,Boksánbánya,Bokša Romana,Deutsch-Bogschan,Deutsch-Bokschan,Nemet-Bogsan,Nemet-Bogschan,Nemet-Boksan,Német-Bogschán,Német-Bogsán,Német-Boksán,Varkboksan,Vassafalva,Várkboksán,Wallachisch-Bokschan,Werk-Bogschan', 45.3733300, 21.7091700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117871, 'Bocicoiu Mare', 'Bocicoiu Mare', 'Bocicoiu Mare,Bocicoiul Mare', 47.9666700, 24.0000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117872, 'Bobulești', 'Bobulesti', 'Bobotesti,Boboteşti,Bobulesti,Bobuleşti', 47.7513500, 27.2269700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117873, 'Bobota', 'Bobota', 'Bobota', 47.3833300, 22.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117874, 'Bobolia', 'Bobolia', '', 45.0939500, 25.7425900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117875, 'Bobohalma', 'Bobohalma', '', 46.3519100, 24.2316600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117876, 'Boboiești', 'Boboiesti', '', 47.2537000, 26.0374900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117877, 'Boboc', 'Boboc', 'Boboc,Bobocu', 45.1957000, 26.9813600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117878, 'Bobâlna', 'Bobalna', 'Bobilna,Bobîlna,Olpret', 47.1438500, 23.6446100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117879, 'Bobiceşti', 'Bobicesti', 'Bobicesti,Bobiceşti', 44.3833300, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117880, 'Blânzi', 'Blanzi', 'Blanzi,Blinzi,Blânzi,Blînzi', 45.9357500, 27.6506300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117881, 'Blândiana', 'Blandiana', 'Blandiana,Blindiana,Blîndiana', 45.9794300, 23.3854300, 'RO', '2012-06-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117882, 'Blândeşti', 'Blandesti', 'Blandesti,Blindesti,Blândesti,Blîndeşti', 47.7000000, 26.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117883, 'Blideşti', 'Blidesti', '', 46.3000000, 23.1333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117884, 'Blejoi', 'Blejoi', 'Blejoi,Blejoiu', 45.0000000, 26.0166700, 'RO', '2014-01-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117885, 'Blejeşti', 'Blejesti', 'Blejesti,Blejeşti', 44.3000000, 25.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117886, 'Bălcaciu', 'Balcaciu', 'Balcaciu,Balcaciul,Bălcaciu,Bălcaciul', 46.1912200, 24.0613900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117887, 'Blăjeni', 'Blajeni', 'Blaieni,Blajeni,Blăieni,Blăjeni', 46.2333300, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117888, 'Blăjel', 'Blajel', 'Blajel,Blăjel', 46.2166700, 24.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117889, 'Blăjani', 'Blajani', 'Blajani,Blăjani', 45.3166700, 26.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117890, 'Blaj', 'Blaj', 'Balazsfalva,Balázsfalva,Blaj,Blasendorf,Blazas,Blazh,Blažas,Opstina Blaj,Opština Blaj,blh,bu la ri,buraji,Блаж,Блай,بله,ブラジ,布拉日', 46.1750800, 23.9157800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117891, 'Blăgeşti', 'Blagesti', '', 46.6833300, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117892, 'Blăgeşti', 'Blagesti', 'Blagesti,Blăgeşti', 46.1372200, 28.0130600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117893, 'Bixad', 'Bixad', 'Bicsad,Bicsad-Bai,Bicsad-Băi,Bixad', 47.9333300, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117894, 'Bivolărie', 'Bivolarie', 'Bivolaria,Bivolăria', 47.9146400, 25.6552500, 'RO', '2015-12-30', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117895, 'Bivolari', 'Bivolari', 'Bivolari', 47.5333300, 27.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117896, 'Bistriţa Bârgăului', 'Bistrita Bargaului', 'Bargaului,Bistrita Barsaului,Bistrita Birgaului,Bistrita-Bargaului,Bistriţa Bîrgăului,Bistriţa Bărsăului,Bistriţa-Bârgăului', 47.2166700, 24.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117897, 'Bistriţa', 'Bistrita', 'Beszterce,Besztercze,Bistrica,Bistrita,Bistritz,Bistriţa,Bistrița,QBY,bisutoritsu~a,Бистрица,ビストリツァ', 47.1331600, 24.5001100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117898, 'Bistrița', 'Bistrita', '', 46.9485600, 26.2959800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117899, 'Bistrița', 'Bistrita', 'Bistrita,Bistriţa,Manastirea Bistrita,Mânăstirea Bistriţa', 45.1861200, 24.0401000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117900, 'Bistrița', 'Bistrita', '', 44.5851100, 22.7876200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117901, 'Bistreț', 'Bistret', '', 43.9000000, 23.5000000, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117902, 'Bistra Mureșului', 'Bistra Muresului', 'Bistra Muresului,Bistra Mureşului,Dedabisztra,Dèdabisztra', 46.9609300, 24.9060800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117903, 'Bistra', 'Bistra', '', 47.8666700, 24.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117904, 'Bistra', 'Bistra', 'Bistra,Spurcani', 47.2547800, 22.4229500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117905, 'Bistra', 'Bistra', 'Bistra', 46.3782000, 23.1008100, 'RO', '2012-06-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117906, 'Bisoca', 'Bisoca', 'Bisoca', 45.5333300, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117907, 'Bâscoveni', 'Bascoveni', 'Bascoveni,Biscoveni,Bâscoveni,Bîscoveni', 44.2444400, 25.3599800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117908, 'Bâscenii de Sus', 'Bascenii de Sus', 'Bascenii de Sus,Biscenii de Sus,Bîscenii de Sus', 45.2666200, 26.2707300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117909, 'Bâscenii de Jos', 'Bascenii de Jos', 'Bascenii de Jos,Biscenii de Jos,Bâscenii de Jos,Bîscenii de Jos', 45.2470800, 26.3212200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117910, 'Bâsca Rozilei', 'Basca Rozilei', 'Basca Rozilii,Basca-Roziliei,Bisca Rozilei,Bâsca Rozilii,Bâsca-Roziliei,Bîsca Rozilei', 45.4538700, 26.3371400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117911, 'Bâsca Chiojdului', 'Basca Chiojdului', 'Basca,Bisca,Bisca Chiojdului,Bâsca,Bîsca,Bîsca Chiojdului', 45.3712000, 26.1835500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117912, 'Bârzești', 'Barzesti', 'Birzesti,Bîrzeşti,Razest', 46.7500000, 27.5500000, 'RO', '2015-11-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117913, 'Bârzava', 'Barzava', 'Barzava,Bazava,Berzava,Berzova,Birzava,Bârzava,Bâzava,Bîrzava,Marosborsa', 46.1166700, 21.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117914, 'Bârza', 'Barza', '', 46.5500000, 24.1333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117915, 'Bârza', 'Barza', 'Balsu,Barza,Birza,Bârza,Bîrza', 44.3281100, 24.1418800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117916, 'Bârseşti', 'Barsesti', 'Barsesti,Barsestii,Birsesti,Bârseşti,Bârseştii,Bîrseşti', 45.9166700, 26.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117917, 'Bârsău de Sus', 'Barsau de Sus', 'Barsaul de-Sus,Birsau de Sus,Bârsăul de-Sus,Bîrsău de Sus', 47.6000000, 23.2166700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117918, 'Bârsăneşti', 'Barsanesti', 'Barsanesti,Birsanesti,Bârsăneşti,Bîrsăneşti', 46.3333300, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117919, 'Bârsana', 'Barsana', 'Barsana,Birsana,Bârsana,Bîrsana', 47.8166700, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117920, 'Bârsa', 'Barsa', 'Barsa,Barza,Bersza,Berza,Birsa,Bursza,Bârsa,Bîrsa', 46.3833300, 22.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117921, 'Bârnova', 'Barnova', 'Barnova,Birnova,Bîrnova', 47.0666700, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117922, 'Bârna', 'Barna', 'Barna,Bira,Birna,Bârna,Bîra,Bîrna', 45.7166700, 22.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117923, 'Bârlogu', 'Barlogu', 'Barlogu,Barlogul,Birlogu,Bârlogu,Bârlogul,Bîrlogu', 44.6265800, 25.0806600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117924, 'Bârlad', 'Barlad', 'Barlad,Barlád,Birlad,Birladas,Burlad,Byrlad,Bârlad,Bîrlad,Opstina Barlad,Opština Bârlad,beuleulladeu,birladi,bo er la de,brlh,Барлад,Бирлад,Бърлад,Бырлад,ברלאד,برله,ბირლადი,伯尔拉德,브를라드', 46.2317500, 27.6690700, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117925, 'Bârla', 'Barla', 'Barla,Birla,Bîrla,Bărla', 44.4260600, 24.7774300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117926, 'Bârghiş', 'Barghis', 'Barghis,Birghis,Bârghiş,Bîrghiş', 45.9833300, 24.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117927, 'Birda', 'Birda', 'Birda', 45.4299600, 21.3435900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117928, 'Bircii', 'Bircii', 'Birci,Bircii', 44.5167300, 24.6032400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117929, 'Birchiş', 'Birchis', 'Birchis,Birchiş', 45.9666700, 22.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117930, 'Bârca', 'Barca', 'Barca,Birca,Bârca,Bîrca', 43.9666700, 23.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117931, 'Bâra', 'Bara', 'Bara,Bira,Bâra,Bîra', 47.0333300, 27.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117932, 'Bâlvăneşti', 'Balvanesti', 'Balvanesti,Bilvanesti,Bâlvăneşti,Bîlvăneşti', 44.7975000, 22.6802800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117933, 'Bâlteni', 'Balteni', 'Balteni,Bilteni,Bâlteni,Bîlteni', 44.8691900, 23.2731100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117934, 'Bâlta', 'Balta', 'Balta,Bilta,Bâlta,Bîlta', 45.1179100, 23.1022000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117935, 'Bâlta', 'Balta', 'Balta,Bilta,Bâlta,Bîlta', 44.5356400, 23.4701900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117936, 'Biliești', 'Biliesti', 'Biliesti,Bilieşti', 45.7210600, 27.3487900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117937, 'Biled', 'Biled', 'Biled,Bille,Billed,Billet,Billiet,Billéd,Billét,Comuna Biled,Opstina Biled,Opština Biled,Билед,Білед', 45.8863900, 20.9588900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117938, 'Bâldana', 'Baldana', 'Baldana,Bildana,Bîldana,Băldana', 44.6030000, 25.7783600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117939, 'Bilciureşti', 'Bilciuresti', 'Bilciresti,Bilcireşti,Bilciuresti,Bilciureşti', 44.7333300, 25.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117940, 'Bilca', 'Bilca', 'Bilca', 47.9166700, 25.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117941, 'Bilbor', 'Bilbor', 'Belbor,Bilbor,Bèlbòr', 47.0500000, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117942, 'Biia', 'Biia', '', 46.2309700, 24.0046100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117943, 'Biharia', 'Biharia', 'Bihar,Biharea', 47.1500000, 21.9166700, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117944, 'Biertan', 'Biertan', 'Berethalom,Bertan,Biertan,Birthelm,Comuna Biertan,Opstina Biertan,Opština Biertan,bierutan,Биертан,Бєртан,ビエルタン', 46.1333300, 24.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117945, 'Bâcu', 'Bacu', 'Bacu,Bacul,Bicu,Bâcu,Bâcul,Bîcu', 44.4825900, 25.8890400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117946, 'Bixad', 'Bixad', 'Sepsibuekszad,Sepsibükszád', 46.1000000, 25.8666700, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117947, 'Bâcleș', 'Bacles', 'Bicles,Bîcleş', 44.4833300, 23.1333300, 'RO', '2015-12-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117948, 'Bichiş', 'Bichis', 'Bichis,Bichiş', 46.3666700, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117949, 'Bichigiu', 'Bichigiu', 'Bichigiu,Bichigiul,Bighigiu,Ciblasfalva', 47.4252200, 24.3389300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117950, 'Bicazu Ardelean', 'Bicazu Ardelean', 'Bicazul Ardelean', 46.8500000, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117951, 'Bicaz-Chei', 'Bicaz-Chei', 'Almasmezo,Almásmező,Bicaz Chei,Bicazul-Chei', 46.8166700, 25.8833300, 'RO', '2015-11-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117952, 'Bicaz', 'Bicaz', 'Bicas,Bicaz,Bikaclalya,Bikáclalya', 47.4666700, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117953, 'Bicaz', 'Bicaz', '', 46.9166700, 26.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117954, 'Bezdead', 'Bezdead', 'Bezdeadu,Bezdeadul', 45.1500000, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117955, 'Beuca', 'Beuca', 'Beuca', 44.2520000, 24.9663700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117956, 'Bethausen', 'Bethausen', 'Becliza,Bethausen,Bethlenhaas,Bethlenhaza,Bethlenháza', 45.8330600, 21.9527800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117957, 'Beștepe', 'Bestepe', 'Besh Tepe,Bestepe,Beştepe', 45.0924100, 29.0147800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117958, 'Berzunţi', 'Berzunti', 'Berzunt,Berzunti,Berzunţi,Martin-Berzunt,Martin-Berzunti,Martin-Berzunţ,Martin-Berzunţi,Martinul', 46.4000000, 26.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117959, 'Berzovia', 'Berzovia', 'Bersovia,Berzobis,Berzovia,Jidovin,Zsidovin', 45.4261100, 21.6280600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117960, 'Berzasca', 'Berzasca', 'Berszaszko,Berszászkó,Berzasca,Berzaska', 44.6471200, 21.9542800, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117961, 'Berveni', 'Berveni', 'Berveni,Borvely,Börvely', 47.7500000, 22.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117962, 'Berteştii de Jos', 'Bertestii de Jos', 'Berestii-de-Jos,Bereştii-de-Jos,Bertesti-de-Jos,Bertestii de Jos,Berteştii de Jos', 44.8333300, 27.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117963, 'Bertea', 'Bertea', 'Bertea', 45.2333300, 25.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117964, 'Berlişte', 'Berliste', 'Berliste,Berlişte,Brljiste,Brljište', 44.9866700, 21.4630600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117965, 'Berleşti', 'Berlesti', 'Berlesti,Berleşti', 44.9166700, 23.6666700, 'RO', '2015-11-06', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117966, 'Beriu', 'Beriu', 'Beriu', 45.7833300, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117967, 'Berislăveşti', 'Berislavesti', 'Berislavesti,Berislăveşti', 45.2500000, 24.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117968, 'Berghin', 'Berghin', 'Berghin,Berghiu', 46.0778200, 23.7374200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117969, 'Berezeni', 'Berezeni', 'Berezeni', 46.3761100, 28.1477800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117970, 'Berevoeşti', 'Berevoesti', 'Berevoesti,Berevoesti-Ungureni,Berevoestii-Ungureni,Berevoeşti,Berevoeşti-Ungureni,Berevoeştii-Ungureni', 45.2333300, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117971, 'Berești', 'Beresti', '', 46.1000000, 27.8833300, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117972, 'Bereşti-Tazlău', 'Beresti-Tazlau', 'Beresti,Beresti-Tazlau,Bereşti,Bereşti-Tazlău', 46.4666700, 26.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117973, 'Bereşti-Sat', 'Beresti-Sat', '', 46.1000000, 27.8833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117974, 'Bereşti-Bistriţa', 'Beresti-Bistrita', 'Beresti,Beresti-Bistrita,Berestii-Bistrita,Bereşti,Bereşti-Bistriţa,Bereştii-Bistriţa', 46.7166700, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117975, 'Berești', 'Beresti', 'Beresti,Berestii,Bereşti,Bereştii', 46.2032900, 27.1447600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117976, 'Bereni', 'Bereni', 'Bereni,Szekelybere,Szèkelybere', 46.5573300, 24.8682100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117977, 'Beregsău Mare', 'Beregsau Mare', 'Beregsau Mare,Beregsaul-Mare,Beregsen,Beregshafen,Beregshofen,Beregszo,Beregszó,Beregsău Mare,Beregsăul-Mare,Berekszo,Berekszó,Gross-Beregsau', 45.7592100, 21.0266600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117978, 'Berchișești', 'Berchisesti', 'Berchisesti,Berchişeşti', 47.5230600, 26.0320700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117979, 'Berceni', 'Berceni', 'Berceni', 44.9333300, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117980, 'Berceni', 'Berceni', '', 44.3141700, 26.1855600, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117981, 'Berca', 'Berca', 'Berca', 45.2833300, 26.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117982, 'Berbești', 'Berbesti', '', 47.8486500, 23.9344800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117983, 'Berbeşti', 'Berbesti', 'Berbesti,Berbestii,Berbeşti,Berbeştii,Herbesti,Herbeşti', 44.9833300, 23.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117984, 'Bengești', 'Bengesti', 'Bengestii de Mijloc,Bengeştii de Mijloc', 45.0666700, 23.6000000, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117985, 'Benesat', 'Benesat', 'Benesat', 47.4104900, 23.2890400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117986, 'Beltiug', 'Beltiug', 'Belthiug,Beltiug,Krasznabeltek', 47.5500000, 22.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117987, 'Beliu', 'Beliu', 'Beliu,Beliul', 46.4833300, 21.9833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117988, 'Beliş', 'Belis', 'Belis,Beliş', 46.6500000, 23.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117989, 'Belin-Vale', 'Belin-Vale', 'Belin Vale,Bolonpatak,Bölönpatak', 45.9323700, 25.6087800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117990, 'Belinţ', 'Belint', 'Belence,Belencze,Belincz,Belint,Belinţ', 45.7550000, 21.7602800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117991, 'Belin', 'Belin', 'Belin,Bolon,Bölön', 45.9333300, 25.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117992, 'Beleţi', 'Beleti', '', 44.9000000, 25.0833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117993, 'Belciugatele', 'Belciugatele', 'Belciugatele', 44.4833300, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117994, 'Belceşti', 'Belcesti', 'Belcesti,Belceşti,Cioreni,Rusi,Ruşi,Valeni,Văleni', 47.3000000, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117995, 'Beiuş', 'Beius', 'Beius,Beiuș,Bejusas,Bejush,Bejušas,Belenyes,Belényes,bei you shen,byhwr,Беюш,Бејуш,بیهور,貝尤什', 46.6666700, 22.3500000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117996, 'Beiu', 'Beiu', 'Beiu,Beiul', 43.8735200, 25.4554800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117997, 'Beidaud', 'Beidaud', 'Beidaiu,Beidaud,Beidaut', 44.7166700, 28.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117998, 'Beica de Jos', 'Beica de Jos', 'Alsobolkeny,Alsòbölkèny,Beica de Jos', 46.7333300, 24.8000000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(117999, 'Beclean', 'Beclean', 'Beclean', 47.1833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118000, 'Beclean', 'Beclean', '', 45.8311900, 24.9218000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118001, 'Beciu', 'Beciu', 'Beciu,Beciul', 44.0042900, 24.6657100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118002, 'Becicherecu Mic', 'Becicherecu Mic', 'Becicherecu Mic,Becicherecul-Mic,Becskerek,Kisbecskerek,Klein-Betschkerek', 45.8291700, 21.0513900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118003, 'Bechet', 'Bechet', 'Bechet,Bechetu,Bechetu Vechi,Bechetul', 43.7818800, 23.9570600, 'RO', '2013-05-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118004, 'Beceni', 'Beceni', 'Beceni', 45.3833300, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118005, 'Beba Veche', 'Beba Veche', 'Alt-Beba,Beba,Beba Veche,Mala Beba,Obeb,Stara Beba,Óbéb', 46.1333300, 20.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118006, 'Bazna', 'Bazna', 'Bazna,Bázna', 46.2000000, 24.2833300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118007, 'Băuţar', 'Bautar', 'Bautar,Bautaru Superior,Bautarul-Superior,Băuţar,Băuţaru Superior,Băuţarul-Superior', 45.5166700, 22.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118008, 'Bătrâni', 'Batrani', '', 45.3142500, 26.1509100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118009, 'Bătrâna', 'Batrana', 'Batrana,Batrina,Bătrâna,Bătrîna', 45.7833300, 22.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118010, 'Batoş', 'Batos', 'Batos,Batoş', 46.8833300, 24.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118011, 'Batârăşti', 'Batarasti', '', 44.8166700, 24.1500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118012, 'Bătești', 'Batesti', '', 44.8483000, 26.0403100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118013, 'Bătarci', 'Batarci', 'Batarci,Bătarci', 48.0333300, 23.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118014, 'Batăr', 'Batar', 'Batar,Batăr', 46.7000000, 21.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118015, 'Băţanii Mari', 'Batanii Mari', 'Batanii Mari,Băţanii Mari,Nagybacon', 46.0833300, 25.6833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118016, 'Bata', 'Bata', 'Bata,Batta', 46.0166700, 22.0333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118017, 'Băseşti', 'Basesti', '', 47.4833300, 23.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118018, 'Başcov', 'Bascov', 'Bascov,Bascovu,Başcov', 44.9000000, 24.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118019, 'Basarabi', 'Basarabi', '', 47.4537000, 26.4397200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118020, 'Basarabi', 'Basarabi', '', 44.0056100, 23.0091500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118021, 'Barza', 'Barza', '', 46.1199000, 22.8569500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118022, 'Barza', 'Barza', 'Barza', 44.3333300, 24.7833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118023, 'Baru Mic', 'Baru Mic', 'Baru Mic,Barul Mic', 45.4666700, 23.1500000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118024, 'Baru', 'Baru', 'Baru,Baru Mare,Barul-Mare', 45.4721800, 23.1627100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118025, 'Barticești', 'Barticesti', '', 47.0632400, 26.7925400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118026, 'Bârgăuani', 'Bargauani', 'Bargovan,Bargován', 46.9833300, 26.6333300, 'RO', '2015-12-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118027, 'Barcea', 'Barcea', 'Barcea', 45.7500000, 27.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118028, 'Barcani', 'Barcani', 'Barcani,Barkani,Bărkani', 45.7000000, 26.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118029, 'Bărcăneşti', 'Barcanesti', '', 46.7166700, 26.5833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118030, 'Bărcăneşti', 'Barcanesti', 'Barcanesti,Bărcăneşti', 44.8833300, 26.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118031, 'Bărcăneşti', 'Barcanesti', '', 44.6333300, 26.6500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118032, 'Bărbuleţu', 'Barbuletu', 'Barbuletu,Barbuletul,Barbulotul,Bărbuletul,Bărbuleţu,Bărbulotul', 45.1333300, 25.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118033, 'Bărbulești', 'Barbulesti', '', 44.7262900, 26.5992900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118034, 'Bărbăteşti', 'Barbatesti', '', 45.1833300, 24.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118035, 'Bărbăteşti', 'Barbatesti', '', 44.8666700, 23.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118036, 'Barați', 'Barati', '', 46.5756900, 26.8711800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118037, 'Bărăștii de Vede', 'Barastii de Vede', 'Barasti de Vede,Barastii de Vede,Bărăşti de Vede,Bărăştii de Vede', 44.7160100, 24.6591900, 'RO', '2015-11-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118038, 'Bărăști', 'Barasti', '', 45.2536900, 24.5965100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118039, 'Baraolt', 'Baraolt', 'Baraolt,Baraot,Baraót,Barot,Barót,Бараолт', 46.0751400, 25.6002900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118040, 'Bărăganul', 'Baraganul', 'Baraganul,Bărăganul,Cioara-Doicesti,Cioara-Doiceşti', 44.8000000, 27.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118041, 'Bărăganu', 'Baraganu', 'Baragabu,Baraganu,Baraganul,Bărăgabu,Bărăganu,Bărăganul,Osmanfaca', 44.0893900, 28.4198000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118042, 'Bărăbanț', 'Barabant', '', 46.0993000, 23.5848700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118043, 'Bara', 'Bara', 'Bara', 45.8947200, 21.8719400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118044, 'Banloc', 'Banloc', 'Banlak,Banloc,Banlok,Bánlak', 45.3874200, 21.1358100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118045, 'Băniţa', 'Banita', 'Banita,Băniţa', 45.4500000, 23.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118046, 'Bănişor', 'Banisor', 'Banisor,Bănişor', 47.1043100, 22.8373100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118047, 'Bănia', 'Bania', 'Bania,Banja,Bănia', 44.8958300, 22.0447200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118048, 'Bănești', 'Banesti', '', 47.5894600, 26.5233500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118049, 'Băneşti', 'Banesti', 'Banesti,Băneşti', 45.1000000, 25.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118050, 'Băneasa', 'Baneasa', '', 45.9333300, 27.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118051, 'Băneasa', 'Baneasa', 'Baneasa,Băneasa,Parachioi', 44.0666700, 27.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118052, 'Băneasa', 'Baneasa', 'Baneasa,Băneasa', 44.0461100, 26.0641700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118053, 'Băneasa', 'Baneasa', '', 43.9397500, 24.9499700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118054, 'Band', 'Band', 'Band,Bandu de Cimpie,Bandu de Cîmpie,Mezoband,Mezöbànd', 46.5833300, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118055, 'Bancu', 'Bancu', 'Bancu,Bancul,Bankfalva,Csik Bankfolva', 46.3029100, 25.9442200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118056, 'Banca', 'Banca', '', 46.3000000, 27.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118057, 'Bălușești', 'Balusesti', '', 46.8159100, 26.9988500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118058, 'Băluşeni', 'Baluseni', '', 47.6666700, 26.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118059, 'Bălțești', 'Baltesti', 'Baltesti,Bălteşti', 45.1096500, 26.1293700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118060, 'Bădeana', 'Badeana', '', 46.1500000, 27.5833300, 'RO', '2016-01-08', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118061, 'Bălteni', 'Balteni', 'Balteni,Balteni-Vale,Baltenii-din-Vale,Bălteni,Bălteni-Vale,Băltenii-din-Vale', 46.6666700, 27.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118062, 'Bălteni', 'Balteni', '', 44.6648800, 25.6933900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118063, 'Bălteni', 'Balteni', 'Balteiu,Balteni,Bălteni', 44.4488300, 24.5324700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118064, 'Balta Verde', 'Balta Verde', '', 44.3441100, 22.5987800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118065, 'Bălţaţi', 'Baltati', 'Baltati,Bălţaţi', 47.2166700, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118066, 'Bălţăteşti', 'Baltatesti', 'Baltatesti,Burla,Bălţăteşti,Piriu Sarat,Prihodistea,Prihodiştea,Prihojdia,Pîrîu Sărat', 47.1166700, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118067, 'Balta Doamnei', 'Balta Doamnei', 'Balta Doamnei', 44.7500000, 26.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118068, 'Balta Albă', 'Balta Alba', '', 45.3042300, 27.2855700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118069, 'Balta', 'Balta', '', 44.8869400, 22.6369400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118070, 'Balşa', 'Balsa', 'Balsa,Balşa', 46.0333300, 23.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118071, 'Balș', 'Bals', '', 47.2962800, 26.9785600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118072, 'Balş', 'Bals', 'Bals,Balş', 44.3500000, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118073, 'Baloteşti', 'Balotesti', 'Balotesti,Balotesu,Baloteşti,Baloteşu', 44.6166700, 26.1166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118074, 'Bălnaca', 'Balnaca', '', 46.9438400, 22.5720600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118075, 'Balintești', 'Balintesti', '', 46.0293700, 27.9220100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118076, 'Balinţ', 'Balint', 'Balinc,Balincz,Balint,Balintin,Balintz,Balinţ,Bálinc,Bálincz', 45.8125000, 21.8536100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118077, 'Bălileşti', 'Balilesti', '', 45.0666700, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118078, 'Băleşti', 'Balesti', '', 45.4333300, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118079, 'Băleşti', 'Balesti', 'Balesti,Băleşti', 45.0166700, 23.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118080, 'Băleni Sârbi', 'Baleni Sarbi', 'Baleni Sirbi,Balenii-Sarbi,Băleni Sîrbi,Bălenii-Sârbi', 44.8166700, 25.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118081, 'Băleni', 'Baleni', '', 45.8166700, 27.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118082, 'Baldovinești', 'Baldovinesti', '', 45.3218200, 27.9110700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118083, 'Baldovineşti', 'Baldovinesti', 'Baldovinesti,Baldovineşti', 44.3833300, 24.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118084, 'Balda', 'Balda', 'Balda,Balta', 46.7335300, 24.1436200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118085, 'Bălcești', 'Balcesti', '', 45.1051600, 23.6329000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118086, 'Bălceşti', 'Balcesti', 'Balcesti,Bălceşti', 44.6166700, 23.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118087, 'Bălcăuţi', 'Balcauti', 'Balkoutz', 47.8914900, 26.0727900, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118088, 'Balcani', 'Balcani', 'Balcani', 46.6333300, 26.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118089, 'Balc', 'Balc', 'Balc', 47.2833300, 22.5333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118090, 'Bălăuşeri', 'Balauseri', 'Balauseri,Balavasar,Bàlavàsàr,Bălăuşeri', 46.4000000, 24.6833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118091, 'Bălăşeşti', 'Balasesti', '', 46.1000000, 27.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118092, 'Bălănești', 'Balanesti', '', 44.2497000, 24.4821600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118093, 'Bălan', 'Balan', 'Balan,Bălan', 47.1559900, 23.3121300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118094, 'Bălan', 'Balan', 'Balan,Balanbanya,Balánbánya,Bălan', 46.6505000, 25.8083400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118095, 'Balaciu', 'Balaciu', 'Balaciu de Sus', 44.6333300, 26.8833300, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118096, 'Bălăciţa', 'Balacita', 'Balacita,Bălăciţa', 44.3833300, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118097, 'Balaci', 'Balaci', 'Balaci', 44.3500000, 24.9166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118098, 'Bălăceanu', 'Balaceanu', 'Balaceanu,Bălăceanu', 45.2666700, 27.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118099, 'Bălăceanca', 'Balaceanca', '', 44.3924900, 26.2900900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118100, 'Bălăceana', 'Balaceana', '', 47.6433800, 26.0476400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118101, 'Bălăbănești', 'Balabanesti', '', 46.0954600, 27.7220600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118102, 'Băla', 'Bala', 'Bala,Băla', 46.7166700, 24.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118103, 'Bala', 'Bala', 'Bala,Bala de Jos', 44.8838900, 22.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118104, 'Bajura', 'Bajura', '', 48.2011900, 26.5398700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118105, 'Băjești', 'Bajesti', 'Bajesti,Bajestii,Băjeşti,Băjeştii', 45.0261500, 24.9400600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118106, 'Băiuţ', 'Baiut', 'Baiut,Baiuti,Banit,Băiuţ,Băiuţi,Băniţ,Erzsebetbanya,Erzsébetbánya', 47.6166700, 24.0000000, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118107, 'Băiţa de sub Codru', 'Baita de sub Codru', 'Baita,Baita de sub Codru,Băiţa,Băiţa de sub Codru', 47.5333300, 23.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118108, 'Băița', 'Baita', '', 47.7061400, 23.4932600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118109, 'Băiţa', 'Baita', 'Baita,Băiţa', 46.0333300, 22.9000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118110, 'Băişoara', 'Baisoara', 'Baisoara,Băişoara', 46.5833300, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118111, 'Băișești', 'Baisesti', 'Baiasesti,Baiaşeşti,Baisesti,Băişeşti', 47.4802400, 26.1111500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118112, 'Băile Tuşnad', 'Baile Tusnad', 'Baile Tusnad,Behile-Tushnad,Băile Tuşnad,Băile Tușnad,Gara Tusnad-Bai,Gara Tuşnad-Băi,Tusnad Bai,Tusnad Furdo,Tusnad Fürdö,Tusnad-Baile Gara,Tusnadfuerdo,Tusnádfürdő,Tuşnad Băi,Tuşnad-Băile Gara,Бэиле-Тушнад', 46.1500000, 25.8500000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118113, 'Băileşti', 'Bailesti', 'Bailesti,Băileşti', 44.0166700, 23.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118114, 'Băile Olăneşti', 'Baile Olanesti', 'Baile Olanesti,Băile Olăneşti,Cserepfuerdo,Cserépfürdő', 45.2000000, 24.2333300, 'RO', '2014-01-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118115, 'Băile Herculane', 'Baile Herculane', 'Baile Erculane,Baile Herculane,Baile Herkulane,Baile Kherkulane,Behile-Erkulane,Behile-Kherkulane,Beile Herkulane,Beile Herkulanė,Beile-Kherkulane,Băile Erculane,Băile Herculane,Herculane,Herkules-Banja,Herkulesbad,Herkulesfuerdo,Herkulesfürdő,Opstina Baile Herculane,Opština Bãile Herculane,bo yi lai hai er ku la nei,bylh hrkwlanh,Баиле Херкулане,Беїле-Херкулане,Бэиле-Еркулане,Бэиле-Херкулане,מרחצאות הרקולאנה,بیله هرکولانه,ბეილე-ერკულანე,伯伊萊海爾庫拉內', 44.8797200, 22.4125000, 'RO', '2013-12-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118116, 'Băile Govora', 'Baile Govora', 'Baile Govora,Băile Govora', 45.0833300, 24.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118117, 'Băile Borșa', 'Baile Borsa', '', 47.6841600, 24.7139100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118118, 'Băiculeşti', 'Baiculesti', 'Baiculesti,Băiculeşti', 45.0666700, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118119, 'Băicoi', 'Baicoi', 'Baicoi,Baicoiu,Băicoi,Băicoiu', 45.0333300, 25.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118120, 'Baia Sprie', 'Baia Sprie', 'Baia Sprie,Civitas in medio monte,Felsobanya,Felsőbánya,Mittelstadt', 47.6618900, 23.6921500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118121, 'Baia Mare', 'Baia Mare', 'BAY,Baia Mare,Baja Mare,Baja-Mare,Frauenbach,Nagybanya,Nagybánya,Neustadt,Rivulus Dominarum,Бая-Маре', 47.6572900, 23.5680800, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118122, 'Baia de Fier', 'Baia de Fier', 'Baia de Fier', 45.1666700, 23.7666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118123, 'Baia de Criş', 'Baia de Cris', 'Baia de Cris,Baia de Criş', 46.1666700, 22.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118124, 'Baia de Arieş', 'Baia de Aries', 'Baia de Aries,Baia de Arieş,Ofenabia', 46.3804500, 23.2811500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118125, 'Baia de Aramă', 'Baia de Arama', 'Baia de Arama,Baia de Aramă', 44.9992900, 22.8078400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118126, 'Baia', 'Baia', 'Baia,Movila Mare', 47.4166700, 26.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118127, 'Baia', 'Baia', 'Baia,Hamagia,Hamangi,Hamangia', 44.7166700, 28.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118128, 'Bahnea', 'Bahnea', 'Bachnea,Bahnea', 46.3666700, 24.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118129, 'Bahna', 'Bahna', 'Bahna,Vasile Gheorghe Mortun,Vasile Gheorghe Morţun,Vasile Mortun,Vasile Morţun', 46.7833300, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118130, 'Băgaciu', 'Bagaciu', 'Bagaciu,Bagaciul,Băgaciu,Băgaciul', 46.2666700, 24.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118131, 'Băduleasa', 'Baduleasa', '', 43.9228600, 24.9827400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118132, 'Bădoși', 'Badosi', '', 44.1472300, 23.8897400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118133, 'Bădeuți', 'Badeuti', 'Badeut,Badeutii-Noi,Badeutii-Vechi,Bădeuţ,Bădeuţii-Noi,Bădeuţii-Vechi', 47.8027700, 25.9838700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118134, 'Bădești', 'Badesti', 'Badesti,Badestii,Bădeşti,Bădeştii,Radesti,Radeşti', 45.1715700, 24.8606400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118135, 'Bădeni', 'Badeni', '', 47.4058100, 26.9489800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118136, 'Bădeni', 'Badeni', '', 45.1527200, 25.4026300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118137, 'Bacova', 'Bacova', 'Bachovar,Bachóvár,Bacova,Bakovar,Bakowa,Bakuwa,Bakóvár,Bochovar', 45.6641000, 21.5523800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118138, 'Baciu', 'Baciu', 'Baciu,Baciul', 46.8000000, 23.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118139, 'Baciu', 'Baciu', 'Baciu,Baciul,Surani', 44.3315200, 25.4442900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118140, 'Băcioiu', 'Bacioiu', 'Bacioiu,Baicioiul,Baicoi,Băcioiu,Băicioiul,Băicoi', 46.3143100, 27.1574500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118141, 'Băcia', 'Bacia', 'Bacia,Băcia', 45.8000000, 23.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118142, 'Băceşti', 'Bacesti', 'Atreiaparte,Bacesti-Sat,Bacesti-Tirg,Băceşti-Sat,Băceşti-Tîrg,Ezeru,Iezeru', 46.8500000, 27.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118143, 'Bacea', 'Bacea', '', 44.3982400, 24.6375900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118144, 'Bacău', 'Bacau', 'BCM,Bacau,Bacău,Bako,Bakuu,Bákó,Бакъу,בקאו', 46.5671800, 26.9138400, 'RO', '2016-02-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118145, 'Băcani', 'Bacani', 'Bacani,Băcani', 46.3333300, 27.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118146, 'Băcălești', 'Bacalesti', '', 44.0599700, 24.8163600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118147, 'Babța', 'Babta', '', 47.4577800, 22.9428300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118148, 'Băbiciu', 'Babiciu', 'Babiciu,Babiciu Episcopiei,Babiciul,Babiciul-Episcopiei,Băbiciu,Băbiciu Episcopiei,Băbiciul,Băbiciul-Episcopiei', 44.0333300, 24.5666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118149, 'Babeţi', 'Babeti', 'Babeti,Babeţi,Babita,Babiţa', 45.3166700, 26.3833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118150, 'Băbeni-Oltețu', 'Babeni-Oltetu', 'Babeni-Oltetu,Babeni-Oltetul,Băbeni-Olteţu,Băbeni-Olteţul', 44.6140400, 23.9779800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118151, 'Băbeni', 'Babeni', 'Babeni,Băbeni', 47.3000000, 23.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118152, 'Băbeni', 'Babeni', '', 45.4463500, 26.9787500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118153, 'Băbeni', 'Babeni', 'Babeni,Băbeni,Ungureni', 44.9666700, 24.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118154, 'Băbana', 'Babana', 'Babana,Băbana', 44.9000000, 24.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118155, 'Băbăiţa', 'Babaita', 'Babaita,Babiata,Băbiăţa,Băbăiţa', 44.1666700, 25.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118156, 'Babadag', 'Babadag', 'Babadag,Babadagh,Babadagi,Babadau,Babadağ,Babadağı,babataghy,باباطاغی', 44.9000000, 28.7166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118157, 'Baba Ana', 'Baba Ana', 'Baba Ana', 44.9666700, 26.4500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118158, 'Azuga', 'Azuga', 'Azuga', 45.4500000, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118159, 'Axintele', 'Axintele', 'Axintel,Axintele', 44.6000000, 26.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118160, 'Axente Sever', 'Axente Sever', 'Axente Sever,Fraua,Frina,Frâua,Frîna', 46.1000000, 24.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118161, 'Avrig', 'Avrig', 'Avrig,Felek,Freek,Fryk,Авриг', 45.7166700, 24.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118162, 'Avram Iancu', 'Avram Iancu', 'Avram Iancu,Avram Jancu,Avramdancu,Felsovidra,Felsővidra,Vidra de Sus', 46.3833300, 22.7833300, 'RO', '2012-06-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118163, 'Avram Iancu', 'Avram Iancu', 'Avram Iancu', 46.6694400, 21.5241700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118164, 'Avrămeşti', 'Avramesti', 'Avramesti,Avrămeşti,Szentabraham,Szentàbrahàm', 46.3333300, 25.0166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118165, 'Avrămeni', 'Avrameni', 'Avrameni,Avrămeni', 48.0166700, 26.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118166, 'Auşeu', 'Auseu', 'Auseu,Auşeu', 47.0333300, 22.5000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118167, 'Augustin', 'Augustin', 'Agostin,Agoştin,Augustin', 46.0461300, 25.5533300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118168, 'Aţintiş', 'Atintis', 'Atintis,Atintisi,Aţintiş,Aţintişi', 46.4333300, 24.1000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118169, 'Atid', 'Atid', 'Atid,Eted', 46.4500000, 25.0500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118170, 'Aţel', 'Atel', 'Atel,Aţel', 46.1500000, 24.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118171, 'Asuaju de Sus', 'Asuaju de Sus', 'Asuagiul-de-Sus,Asuaju de Sus,Asuajul-de-Sus', 47.5666700, 23.1833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118172, 'Aştileu', 'Astileu', 'Astilau,Astileu,Aştileu,Aştilău', 47.0333300, 22.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118173, 'Aşchileu Dorna', 'Aschileu Dorna', '', 46.9833300, 23.4833300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118174, 'Asău', 'Asau', 'Asau,Asaul,Asău', 46.4333300, 26.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118175, 'Bujoreni', 'Bujoreni', 'Asan Aga', 44.1166700, 25.6333300, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118176, 'Arsura', 'Arsura', 'Arsura', 46.8133300, 28.0222200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118177, 'Arpașu de Sus', 'Arpasu de Sus', 'Arpasu de Sus,Arpasul-de-Sus,Arpaşu de Sus,Arpaşul-de-Sus', 45.7343600, 24.6190600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118178, 'Arpaşu de Jos', 'Arpasu de Jos', 'Arpas,Arpasu de Jos,Arpasul-de-Jos,Arpaş,Arpaşu de Jos,Arpaşul-de-Jos', 45.7833300, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118179, 'Aroneanu', 'Aroneanu', 'Aroneanu', 47.2000000, 27.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118180, 'Armeniş', 'Armenis', 'Armenis,Armeniş', 45.2000000, 22.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118181, 'Armăşeşti', 'Armasesti', '', 44.7500000, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118182, 'Ariniş', 'Arinis', '', 47.5000000, 23.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118183, 'Arieşeni', 'Arieseni', 'Arieseni,Arieşeni', 46.4764100, 22.7574100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118184, 'Ariceștii Zeletin', 'Aricestii Zeletin', 'Aricesti,Aricești', 45.2222100, 26.1795700, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118185, 'Ariceştii-Rahtivani', 'Aricestii-Rahtivani', '', 44.9500000, 25.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118186, 'Arghira', 'Arghira', '', 47.4541200, 26.4725000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118187, 'Teslui', 'Teslui', '', 44.2055900, 24.1548200, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118188, 'Argetoaia', 'Argetoaia', 'Argetoaia', 44.5166700, 23.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118189, 'Argeșelu', 'Argeselu', 'Argeselu,Argeşelu,Ciumesti,Ciumeşti', 44.9274000, 24.8711500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118190, 'Argel', 'Argel', '', 47.7613600, 25.4704900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118191, 'Arefu', 'Arefu', 'Arefii,Arefu,Areful', 45.3333300, 24.6000000, 'RO', '2015-11-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118192, 'Ardusat', 'Ardusat', 'Ardusat', 47.6500000, 23.3666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118193, 'Ardud', 'Ardud', 'Arded,Ardud,Erdeed,Erdod,Erdöd,Erdőd,Opstina Ardud,Opština Ardud,a er du de,ardwd,Ардуд,اردود,阿爾杜德', 47.6333300, 22.8833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118194, 'Ardeoani', 'Ardeoani', 'Ardedani,Ardeoani', 46.5333300, 26.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118195, 'Arcuș', 'Arcus', 'Arcus,Arcuş,Arkos,Árkos', 45.9007700, 25.7767300, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118196, 'Archiş', 'Archis', 'Archis,Archiș,Arkis,Arkus,Belarkos,Bélárkos,Árkis,Árkus', 46.4833300, 22.0500000, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118197, 'Arcani', 'Arcani', 'Arcani', 45.0833300, 23.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118198, 'Arbore', 'Arbore', 'Arbore', 47.7333300, 25.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118199, 'Arad', 'Arad', 'ARW,Altarad,Arad,Aradia,Aradinum Vetus,Micalaca,Micălaca,Mikelaka,Murasel,Muresel,Mureşel,Murăşel,O-Arad,Orodinum,Zsigmondhaza,Zsigmondháza,Ō-Arad,ʻrd,Арад,ערד', 46.1833300, 21.3166700, 'RO', '2017-07-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118200, 'Araci', 'Araci', '', 45.8118700, 25.6548200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118201, 'Aprozi', 'Aprozi', '', 44.2661600, 26.5021300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118202, 'Apostolache', 'Apostolache', 'Apostolache', 45.1333300, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118203, 'Apoldu de Jos', 'Apoldu de Jos', 'Apoldu de Jos,Apoldul-de-Jos', 45.8666700, 23.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118204, 'Apold', 'Apold', 'Apold', 46.1166700, 24.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118205, 'Apele Vii', 'Apele Vii', 'Apele Vii', 44.0666700, 24.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118206, 'Apateu', 'Apateu', 'Apateu', 46.6166700, 21.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118207, 'Apaţa', 'Apata', 'Apata,Apaţa', 45.9500000, 25.5166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118208, 'Apalina', 'Apalina', 'Abafaja,Abafàja,Apalina', 46.7521200, 24.6944700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118209, 'Apahida', 'Apahida', 'Apahida', 46.8166700, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118210, 'Apa Asău', 'Apa Asau', '', 46.4874700, 26.3788800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118211, 'Apa', 'Apa', 'Apa', 47.7666700, 23.2000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118212, 'Aninoasa', 'Aninoasa', '', 45.4092400, 23.3150500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118213, 'Aninoasa', 'Aninoasa', '', 45.1833300, 24.9333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118214, 'Aninoasa', 'Aninoasa', '', 44.9666700, 25.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118215, 'Aninoasa', 'Aninoasa', 'Aninoasa', 44.7500000, 23.4833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118216, 'Anina', 'Anina', 'Anina,Staierdorfanina,Stajerlakanina,Steierdorf,Stájerlakanina,a ni na,anyna,Анина,Аніна,انینا,阿尼納', 45.0794400, 21.8569400, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118217, 'Anieș', 'Anies', '', 47.4134700, 24.7685300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118218, 'Anghelești', 'Anghelesti', 'Anghelesti,Anghelestii,Angheleşti,Angheleştii', 46.0787500, 27.0645900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118219, 'Andrieşeni', 'Andrieseni', 'Andrieseni,Andrieşeni', 47.5333300, 27.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118220, 'Andrid', 'Andrid', 'Andrid', 47.5166700, 22.3500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118221, 'Andrei Șaguna', 'Andrei Saguna', '', 46.2881000, 21.3917500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118222, 'Andreiaşu de Jos', 'Andreiasu de Jos', 'Andreiasu de Jos,Andreiaşu de Jos,Andriesu,Andriesu-de-Jos,Andriesul-de-Jos,Andrieşu,Andrieşu-de-Jos,Andrieşul-de-Jos', 45.7500000, 26.8333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118223, 'Andreești', 'Andreesti', '', 44.7894800, 23.5509900, 'RO', '2015-12-03', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118224, 'Andrăşeşti', 'Andrasesti', 'Andrasesti,Andrăşeşti', 44.5666700, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118225, 'Amzacea', 'Amzacea', 'Amzacea', 43.9500000, 28.4000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118226, 'Amaru', 'Amaru', 'Amaru,Amarul', 44.9333300, 26.5833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118227, 'Amărăştii de Sus', 'Amarastii de Sus', 'Amarastii de Sus,Amărăştii de Sus', 43.9833300, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118228, 'Amărăştii de Jos', 'Amarastii de Jos', 'Amarasti-de-Jos,Amarastii de Jos,Amăraşti-de-Jos,Amărăştii de Jos', 43.9500000, 24.1666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118229, 'Amărăşti', 'Amarasti', '', 44.7666700, 24.1500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118230, 'Amara', 'Amara', 'Amara,Amara Veche', 45.2486600, 27.2924400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118231, 'Amara', 'Amara', 'Amara', 44.6166700, 27.3166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118232, 'Alunu', 'Alunu', 'Alunu,Alunul', 45.0166700, 23.8166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118233, 'Alunișu', 'Alunisu', 'Alunisu de Jos,Alunişu de Jos', 44.7166700, 24.5500000, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118234, 'Alunișu', 'Alunisu', 'Alunisu,Alunişu,Filipescu', 44.3388300, 26.0583700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118235, 'Aluniş', 'Alunis', 'Alunis,Aluniş', 47.0333300, 23.7500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118236, 'Aluniş', 'Alunis', 'Magyaro', 46.8928700, 24.7985500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118237, 'Aluniş', 'Alunis', 'Alunis,Aluniş', 45.2000000, 25.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118238, 'Alțâna', 'Altana', 'Alcina,Altina,Alzen,Alțîna', 45.9333300, 24.4666700, 'RO', '2015-12-29', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118239, 'Alparea', 'Alparea', 'Alpare,Alparea', 47.0305400, 22.0481200, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118240, 'Almaşu Mare', 'Almasu Mare', 'Aimasul Mare,Aimaşul Mare,Almasel,Almasu Mare,Almasul-Mare,Almaşel,Almaşu Mare,Almaşul-Mare', 46.1101400, 23.1172100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118241, 'Almaşu', 'Almasu', 'Almasu,Almasul,Almaşu,Almaşul,Varalmas,Varalmás', 46.9454600, 23.1296500, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118242, 'Almaş', 'Almas', 'Almas,Almaș,Almás,Haromalmas,Háromalmás', 46.2833300, 22.2333300, 'RO', '2013-12-01', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118243, 'Almăj', 'Almaj', '', 44.4500000, 23.7166700, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118244, 'Alma', 'Alma', 'Alma', 46.2135900, 24.4803700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118245, 'Alimpeşti', 'Alimpesti', 'Alimpesti,Alimpeşti', 45.0833300, 23.8000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118246, 'Alimănești', 'Alimanesti', '', 44.2569300, 24.5389500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118247, 'Aliman', 'Aliman', 'Aliman,Alimanul', 44.1833300, 27.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118248, 'Alexeni', 'Alexeni', '', 44.6833300, 26.7000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118249, 'Alexandru Vlăhuţă', 'Alexandru Vlahuta', 'Alexandru Vlahuta,Alexandru Vlăhuţă,Patrascani,Pătrăşcani', 46.4166700, 27.6333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118250, 'Alexandru Odobescu', 'Alexandru Odobescu', 'Alexandru Odobescu,Barza', 44.2666700, 27.0833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118251, 'Alexandru I. Cuza', 'Alexandru I. Cuza', 'Alexandru Ioan Cuza,Cuza-Voda,Cuza-Vodă', 47.1333300, 26.8500000, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118252, 'Alexandria', 'Alexandria', 'Aleksandrija,Alexandria,Alexandria i Romania,alkzandrya,allegsandeulia,alyksandrya,arekusandoria,ya li shan de li ya,Александрия,Александрија,Александрія,أليكساندريا,الکزاندریا,الیکساندریا، رومانیہ,الیگزاندریا ،رومانیہ,アレクサンドリア,亚历山德里亚,알렉산드리아', 43.9833300, 25.3333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118253, 'Aleşd', 'Alesd', 'Alesd,Aleşd', 47.0666700, 22.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118254, 'Albota', 'Albota', '', 44.7833300, 24.8500000, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118255, 'Albota de Jos', 'Albota de Jos', 'Albota de Jos,Mosteni,Moşteni', 44.7666700, 24.8333300, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118256, 'Albiș', 'Albis', '', 47.3902400, 22.2452800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118257, 'Albeștii Ungureni', 'Albestii Ungureni', 'Albesti-Ungureni,Albestii-Ungureni,Albeşti-Ungureni,Albeştii-Ungureni,Ungureni', 45.2252900, 24.6725400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118258, 'Albeşti-Paleologu', 'Albesti-Paleologu', 'Albesti-Paleologu,Albestii-Paleolog,Albestii-Paleologu,Albeşti-Paleologu,Albeştii-Paleolog,Albeştii-Paleologu,Paleologu', 44.9500000, 26.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118259, 'Albești-Muru', 'Albesti-Muru', 'Albesti-Muru,Albesti-de Mur,Albestii,Albestii-Muru,Albeşti-Muru,Albeşti-de Mur,Albeştii,Albeştii-Muru', 44.9444000, 26.2089900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118260, 'Albeştii Pământeni', 'Albestii Pamanteni', 'Albesti,Albesti-Pamanteni,Albesti-Paminteni,Albestii Paminteni,Albestii-Pamanteni,Albeşti,Albeşti-Pământeni,Albeşti-Pămînteni,Albeştii Pămînteni,Albeştii-Pământeni,Pamanteni,Paminteni,Pământeni,Pămînteni', 45.2166700, 24.6666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118261, 'Albeşti', 'Albesti', '', 47.7000000, 27.0666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118262, 'Albeşti', 'Albesti', 'Albestii,Albeştii', 46.5000000, 27.8666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118263, 'Albeşti', 'Albesti', 'Albesti,Albeşti,Ferihaza', 46.2333300, 24.8500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118264, 'Albeşti', 'Albesti', '', 45.3095500, 25.0078000, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118265, 'Albeşti', 'Albesti', '', 44.5333300, 27.1333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118266, 'Albeşti', 'Albesti', 'Albesti,Albeşti,Sarighial,Sarighiol,Sarighoil', 43.8000000, 28.4166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118267, 'Albeni', 'Albeni', 'Albeni', 45.0333300, 23.6000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118268, 'Alba Iulia', 'Alba Iulia', 'Alba Iulia,Alba Julija,Alba-Julija,Almpa Ioulia,Balgrad,Bălgrad,Gorad Alba-Julija,Gyulafehervar,Gyulafehérvár,Karlsburg,QAY,Weissenburg,Weisskirchen,Weißenburg,Weißkirchen,a er ba you li ya,alba aywlya,alba ywlya,alba-iulia,albaiullia,alpa luliya,Άλμπα Ιούλια,Алба Јулија,Алба Юлия,Алба-Юлия,Алба-Юлія,Горад Алба-Юлія,אלבה יוליה,آلبا ایولیا,ألبا يوليا,البا ایولیا,البا یولیا,அல்பா லூலியா,ალბა-იულია,アルバ・ユリア,阿爾巴尤利亞,알바이울리아', 46.0666700, 23.5833300, 'RO', '2012-12-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118269, 'Albac', 'Albac', 'Albac,Albak,Fehervoelgy,Fehérvölgy,Gmina Albac,Opstina Albac,Opština Albac,a er ba ke xiang,albak,Албак,ألباك,الباک,阿尔巴克乡', 46.4524600, 22.9516400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118270, 'Alba', 'Alba', '', 48.1585900, 26.4773600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118271, 'Alămor', 'Alamor', '', 45.9300300, 23.9937000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118272, 'Aiudul de Sus', 'Aiudul de Sus', 'Aiudu de Sus,Aiudul-de-Sus', 46.3165300, 23.6905300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118273, 'Aiud', 'Aiud', 'Aiud,Ajud,Ajudas,Ajuds,Egidiopolis,Nagyenyed,Opstina Aiud,Opština Aiud,Strassburg,a you de,ayw,Айуд,Аюд,Ајуд,ایو,阿尤德', 46.3100600, 23.7212800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118274, 'Aiton', 'Aiton', 'Aiton,Anton', 46.6833300, 23.7333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118275, 'Aita Mare', 'Aita Mare', 'Aita Mare,Nagyaita,Nagyajta', 45.9666700, 25.5500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118276, 'Agrișu Mare', 'Agrisu Mare', 'Agris,Agrisu Mare,Agriş,Agrişu Mare', 46.2724300, 21.7555800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118277, 'Agriș', 'Agris', 'Agris,Agriş', 47.8807500, 23.0034000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118278, 'Agrij', 'Agrij', 'Agrij', 47.0668500, 23.0991800, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118279, 'Agrieș', 'Agries', '', 47.4002200, 24.1349100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118280, 'Agnita', 'Agnita', 'Agnita,Opstina Agnita,Opština Agnita,Szentagota,Szentágota,a ge ni ta,agnyt,Агнита,Агніта,اگنیت,阿格尼塔', 45.9666700, 24.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118281, 'Agârbiciu', 'Agarbiciu', 'Agarbiciu,Agarbiciul,Agirbiciu,Agârbiciu,Agârbiciul,Agîrbiciu', 46.0676400, 24.1938600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118282, 'Agighiol', 'Agighiol', 'Agi Geul,Agighiol,Hagighiol', 45.0336200, 28.8762800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118283, 'Agigea', 'Agigea', 'Agigea', 44.0833300, 28.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118284, 'Aghireșu-Fabrici', 'Aghiresu-Fabrici', 'Egeres-banyatelep,Egeres-bányatelep,Egeres-gyartelep,Egeres-gyártelep', 46.8669000, 23.2712900, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118285, 'Aghireșu', 'Aghiresu', 'Aghires,Aghiresu,Aghiresul,Aghireş,Aghireşu,Aghireşul,Aghiris,Aghiriş', 46.8720900, 23.2377300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118286, 'Aghireș', 'Aghires', '', 47.1616400, 23.0176400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118287, 'Agăş', 'Agas', 'Agas,Agăş', 46.4833300, 26.2166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118288, 'Agapia', 'Agapia', 'Agapia', 47.1666700, 26.2833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118289, 'Afumaţi', 'Afumati', 'Afumati,Afumaţi', 44.5166700, 26.2666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118290, 'Afumaţi', 'Afumati', '', 44.0000000, 23.4666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118291, 'Adunații-Copăceni', 'Adunatii-Copaceni', 'Adunatii-Copaceni,Adunaţii-Copăceni', 44.2541300, 26.0492900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118292, 'Adunaţi', 'Adunati', 'Adunati,Adunatii-Proviti,Adunatii-Provitii,Adunaţi,Adunaţii-Proviti,Adunaţii-Proviţii', 45.1333300, 25.6166700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118293, 'Adjudu Vechi', 'Adjudu Vechi', 'Adjudu Vechi,Adjudu-Vechiu,Adjudul-Vechi,Adjudul-Vechiu', 46.1348500, 27.1889100, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118294, 'Adjudeni', 'Adjudeni', '', 47.0140800, 26.9490300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118295, 'Adjud', 'Adjud', 'Ad Judul,Adjud', 46.1000000, 27.1666700, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118296, 'Adâncata', 'Adancata', 'Adancata,Adaseni,Adincata,Adâncata,Adîncata,Adăseni', 47.7333300, 26.3000000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118297, 'Adâncata', 'Adancata', 'Adancata,Adanoata,Adincata,Adâncata,Adânoata,Adîncata', 44.7666700, 26.4333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118298, 'Adânca', 'Adanca', 'Adanca,Adinca,Adincata,Adânca,Adînca,Adîncata', 44.9225000, 25.6100500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118299, 'Adea', 'Adea', '', 46.5551100, 21.5843300, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118300, 'Adășeni', 'Adaseni', 'Adaseni,Adasenii,Adăşeni,Adăşenii', 48.0692000, 26.9378900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118301, 'Adămuş', 'Adamus', 'Adamus,Adămuş', 46.3000000, 24.2333300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118302, 'Adamclisi', 'Adamclisi', 'Adamclisi', 44.0833300, 27.9500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118303, 'Acriș', 'Acris', 'Acris,Acrisu,Acriş,Acrişu', 45.6367300, 25.9924700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118304, 'Acâş', 'Acas', 'Acas,Acis,Acâş,Acîş', 47.5333300, 22.7833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118305, 'Acăţari', 'Acatari', 'Acatar,Acătar,Akosfalva,Ákosfalva', 46.4797500, 24.6332400, 'RO', '2014-06-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118306, 'Abrud-Sat', 'Abrud-Sat', '', 46.2816600, 23.0609800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118307, 'Abrud', 'Abrud', 'Abrud,Abrudbanya,Abrudbánya,Aktenburg,Opstina Abrud,Opština Abrud,a bu lu de,abrw,Абруд,ابرو,阿布鲁德', 46.2740600, 23.0633900, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118308, 'Abrămuţ', 'Abramut', 'Abramut,Abrămuţ', 47.3166700, 22.2500000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118309, 'Abram', 'Abram', '', 47.3166700, 22.3833300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118310, '1 Decembrie', '1 Decembrie', '30 Decembrie,Copaceni-Carada,Copacenii de Sus,Copăceni-Carada,Copăcenii de Sus,Regele Ferdinand', 44.2908300, 26.0580600, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118311, 'Vrani', 'Vrani', 'Vrani', 45.0383300, 21.4925000, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118312, 'Vetrişoaia', 'Vetrisoaia', 'Vetrisoaia,Vetrişoaia', 46.4300000, 28.2083300, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118313, 'Moieciu de Jos', 'Moieciu de Jos', '', 45.5031300, 25.3371900, 'RO', '2015-11-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118314, 'Bucuresti', 'Bucuresti', '', 44.4280200, 26.0966500, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118315, 'Baia Mare', 'Baia Mare', 'Baia Mare,Baja Mare,Baja Marė,Baja-Mare,Nagybanya,Nagybánya,Rivulus Dominarum,ba ya ma lei,baia-mare,baiamale,baya marh,baya mary,Μπάια Μάρε,Бая Маре,Бая-Маре,Баја Маре,באיה מארה,بائیا مارے,بايا ماري,بایا ماره,بایا مارے,ბაია-მარე,バヤ・マレ,巴亞馬雷,바이아마레', 47.6533100, 23.5794900, 'RO', '2008-11-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118316, 'Mârșa', 'Marsa', 'Marsa,Mirsa', 45.7000200, 24.3704600, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118317, 'Paşcani', 'Pascani', '', 47.2469000, 26.7229100, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118318, 'Dorna-Arini', 'Dorna-Arini', '', 47.3383200, 25.4074000, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118319, 'Mioveni', 'Mioveni', '', 44.9590500, 24.9419800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118320, 'Uileacu de Beiuș', 'Uileacu de Beius', '', 46.6853200, 22.2214800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118321, 'Albeştii de Argeş', 'Albestii de Arges', '', 45.2166700, 24.6666700, 'RO', '2012-06-12', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118322, 'Crișan', 'Crisan', '', 45.1746200, 29.3859800, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118323, 'Horea', 'Horea', '', 46.5024600, 22.9503400, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118324, 'Frumușeni', 'Frumuseni', '', 46.1025200, 21.4616700, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118325, 'Dragoslavele', 'Dragoslavele', '', 45.3480100, 25.1692500, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118326, 'Sighișoara', 'Sighisoara', 'Gorad Sigishaara,Schaesburgum,Segeshvar,Segesvar,Segesvár,Sighisoara,Sighişoara,Sigishoara,Sigisoara,Sigišoara,shigishoara,sigishoara,sigisyoala,syghyshwara,sygyshwara,xi ji shen wa la,Горад Сігішаара,Сегешвар,Сигишоара,Сігішоара,סיגישוארה,سيغيشوارا,سیگیشوآرا,სიგიშოარა,シギショアラ,锡吉什瓦拉,시기쇼아라', 46.2214100, 24.7927900, 'RO', '2013-04-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118327, 'Slobozia', 'Slobozia', '', 44.5647000, 27.3633000, 'RO', '2013-07-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118328, 'Vințu de Jos', 'Vintu de Jos', 'Alvinc,Vint,Vinț,Winz', 45.9946200, 23.4861200, 'RO', '2015-11-09', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118329, 'Făgetu', 'Fagetu', '', 44.9061600, 24.9115900, 'RO', '2015-11-10', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118330, 'Poienari', 'Poienari', '', 45.0703400, 24.5305600, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118331, 'Oarja', 'Oarja', '', 44.7605300, 24.9759600, 'RO', '2015-11-11', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118332, 'Bijghir', 'Bijghir', '', 46.6018500, 27.0185900, 'RO', '2015-11-13', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118333, 'Izvoarele', 'Izvoarele', '', 45.2837600, 26.0011900, 'RO', '2015-11-14', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118334, 'Sâniob', 'Saniob', 'Szentjobb', 47.2646100, 22.1277800, 'RO', '2015-11-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118335, 'Baranca', 'Baranca', '', 48.1965100, 26.4789300, 'RO', '2015-11-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118336, 'Ungureni', 'Ungureni', '', 47.8817600, 26.7989900, 'RO', '2015-11-17', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118337, 'Racoș', 'Racos', 'Alsorakos,Alsórákos', 46.0252400, 25.4107500, 'RO', '2015-11-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118338, 'Gropeni', 'Gropeni', '', 45.0754700, 27.8796900, 'RO', '2015-11-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118339, 'Smârdan', 'Smardan', '', 45.2867000, 28.0036800, 'RO', '2015-11-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118340, 'Constantin Brâncoveanu', 'Constantin Brancoveanu', '', 44.4784200, 27.4127400, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118341, 'Bonțida', 'Bontida', 'Bonchida', 46.9155000, 23.8147500, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118342, 'Luna', 'Luna', 'Aranyoslona,Aranyoslóna', 46.5065900, 23.9195900, 'RO', '2015-11-23', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118343, 'Culmea', 'Culmea', '', 44.2575900, 28.4664300, 'RO', '2015-11-24', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118344, 'Valea Voievozilor', 'Valea Voievozilor', '', 44.9380500, 25.4851800, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118345, 'Ocolna', 'Ocolna', '', 43.8791700, 24.1340500, 'RO', '2015-11-25', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118346, 'Hulubești', 'Hulubesti', 'Stramba,Strâmba', 44.1674800, 25.9414600, 'RO', '2015-11-27', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118347, 'Gurasada', 'Gurasada', 'Guraszada,Guraszáda', 45.9548300, 22.5949100, 'RO', '2015-12-04', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118348, 'Gheorghe Doja', 'Gheorghe Doja', 'Principesa Elena,Valea lui Siman,Valea lui Șiman', 44.6162200, 27.1874000, 'RO', '2015-12-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118349, 'Toaca', 'Toaca', 'Toka', 46.7997500, 24.9641000, 'RO', '2015-12-16', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118350, 'Horia', 'Horia', 'Elisabeta-Doamna', 46.9069800, 26.9191900, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118351, 'Ion Creangă', 'Ion Creanga', '', 46.8702900, 26.9802300, 'RO', '2015-12-18', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118352, 'Urzica', 'Urzica', '', 43.8567000, 24.2895200, 'RO', '2015-12-19', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118353, 'Plopeni', 'Plopeni', '', 45.0655200, 25.9811400, 'RO', '2015-12-20', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118354, 'Tarna Mare', 'Tarna Mare', 'Nagytarna', 48.0917500, 23.1936900, 'RO', '2015-12-21', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118355, 'Călmățuiu de Sus', 'Calmatuiu de Sus', '', 44.0263200, 24.8123000, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118356, 'Drăcșenei', 'Dracsenei', '', 44.2267600, 24.9854200, 'RO', '2016-01-02', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118357, 'I. C. Brătianu', 'I. C. Bratianu', '', 45.4058100, 28.0538100, 'RO', '2016-01-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118358, 'Maliuc', 'Maliuc', '', 45.1767800, 29.1133400, 'RO', '2016-01-05', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118359, 'Sector 1', 'Sector 1', 'Sectorul 1', 44.4923900, 26.0483100, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118360, 'Sector 2', 'Sector 2', 'Sectorul 2', 44.4528000, 26.1332100, 'RO', '2016-10-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118361, 'Sector 3', 'Sector 3', 'Sectorul 3', 44.4234000, 26.1687400, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118362, 'Sector 4', 'Sector 4', 'Sectorul 4', 44.3757100, 26.1208500, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118363, 'Sector 5', 'Sector 5', 'Sectorul 5', 44.3880800, 26.0714400, 'RO', '2016-02-07', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118364, 'Sector 6', 'Sector 6', 'Sectorul 6', 44.4357900, 26.0164900, 'RO', '2016-10-15', 182);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118365, 'Zvečka', 'Zvecka', 'Zvecka,Zvečka', 44.6402500, 20.1643200, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118366, 'Žujince', 'Zujince', 'Zhunice,Zhunicë,Zuince,Zujince,Žuince,Žujince', 42.3156800, 21.7021200, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118367, 'Zrenjanin', 'Zrenjanin', 'Becicherecu Mare,Becicherecul Mare,Beckerek,Becskerek,Betschkerek,Beçkerek,Gross-Betschkerek,Nagybecskerek,Petrovgrad,Veliki Beckerek,Veliki Bečkerek,Zrenanin,Zrenianin,Zrenianinas,Zrenjanin,Zrenjanin-grad,bchkrk,ci lei ni ya ning,jeulenyanin,zrnjanyn,zrynyann,zrynyanyn,zurenyanin,Ζρένιανιν,Зренянин,Зрењанин,זרניאנין,بچکرک,زرنجانین,زرینیانن,زرینیانین,زرێنیانین,ズレニャニン,兹雷尼亚宁,즈레냐닌', 45.3836100, 20.3819400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118368, 'Žitorađa', 'Zitoraga', 'Zhitoradzha,Zhitoraxhe,Zhitoraxhë,Zitorada,ri tuo la gu,zytarada,Žitorađa,Житораджа,Житорађа,زیتارادا,日托拉贾', 43.1900000, 21.7130600, 'RS', '2012-04-13', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118369, 'Žitište', 'Zitiste', 'Bega-Szent-Gyorgy,Begaszentgyoergy,Begaszentgyörgy,Begej Sveti Durad,Begej Sveti Ðurađ,Béga-Szent-György,Jitiste,Jitiște,Sankt Georgen,Sankt Georgen an der Bega,Sveti Jurat,Zhitishte,Zitiste,jytyshty,ri di shen tai,Ĵitiŝte,Žitište,Житиште,جيتيشتي,ژیتشتے,日蒂什泰', 45.4850000, 20.5497200, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118370, 'Zemun', 'Zemun', 'Opstina Zemun,Opština Zemun,Semlin,Semlino,Taurunum,Zeman,Zemlen,Zemlén,Zemun,Zimony,jemun,ze meng,zemun,zmwn,Σεμλίνο,Земун,זמון,ゼムン,泽蒙,제문', 44.8430600, 20.4011100, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118371, 'Zaječar', 'Zajecar', 'Gorad Zaechar,Zaechar,Zagetsar,Zaicear,Zaiciar,Zajchar,Zajecar,Zajechar,Zaječar,Zaychar,jayechaleu,zaechari,zai~echaru,zaychar,zayychar,zayytshar,zha ye cha er,Ζάγετσαρ,Горад Заечар,Заечар,Зайчар,Зајечар,زائیچار,زاييتشار,زایئچار,زایچار,زایێچار,ზაეჩარი,ザイェチャル,扎耶查尔,자예차르', 43.9035800, 22.2640500, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118372, 'Žagubica', 'Zagubica', 'Opshtina Zhagubica,Opstina Zagubica,Opština Žagubica,Zagubica,Zhagubica,zagwbycha,zhagbyka,Žagubica,Жагубица,Општина Жагубица,زاگوبیچا,ژاگبیکا,ჟაგუბიცის მუნიციპალიტეტი', 44.1968500, 21.7883800, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118373, 'Žabari', 'Zabari', 'Opstina Zabari,Opština Žabari,Zabar,Zabare,Zabari,Zhabari,zabary,zhabary,Žabare,Žabari,Жабари,زاباری,ژاباری,ჟაბარის მუნიციპალიტეტი', 44.3561100, 21.2150000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118374, 'Žabalj', 'Zabalj', 'Jabalj,Josefsdorf,Josephsdorf,Josipovac,Zabalj,Zhabal,Zsablya,Zseblye,jabaly,zha ba li,zhabaly,Ĵabalj,Žabalj,Жабаљ,جابالي,ژابالی,扎巴利', 45.3722200, 20.0638900, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118375, 'Vršac', 'Vrsac', 'Hennemannstadt,Varset,Versec,Versecz,Vershice,Vrsac,Vrsacas,Vrsats,Vrshac,Vršac,Vršacas,Vurshac,Vârșeț,Werschetz,Werschitz,beuleusyacheu,frshas,frshats,fu er sha ci,vrshats,vrshatsi,vurushatsu,wrshaj,Βρσατς,Вршац,Вършац,ורשאץ,فرشاتس,فرشاس,ورشاج,ڤرشاتس,ვრშაცი,ヴルシャツ,弗尔沙茨,브르샤츠', 45.1166700, 21.3036100, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118376, 'Vrnjačka Banja', 'Vrnjacka Banja', 'Vrnachka Bana,Vrniacka Bania,Vrniačka Bania,Vrnjachka-Banja,Vrnjacka Banja,Vrnjačka Banja,Vurnjachka banja,frnyatshka banya,fu er ni ya qi ka kuang quan zhen,wrnyachka banya,Врнячка-Баня,Врњачка Бања,Върнячка баня,فرنياتشكا بانيا,ورنیاچکا بانیا,弗爾尼亞奇卡礦泉鎮', 43.6272500, 20.8963400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118377, 'Vranjska Banja', 'Vranjska Banja', 'Banja,Vranjska Banja', 42.5550000, 21.9922200, 'RS', '2012-04-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118378, 'Vranje', 'Vranje', 'Ivranya,Vrane,Vranie,Vranja,Vranje,Vranya,beulane,franyy,fu la nie,vuranye,wranyh,Βράνιε,Вране,Враня,Врање,וראניה,فرانيي,وارنیے,ورانیئے,ورانیه,ڤرانیێ,ヴラニェ,弗拉涅,브라네', 42.5513900, 21.9002800, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118379, 'Vranić', 'Vranic', 'Vranic,Vranić', 44.6023700, 20.3287200, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118380, 'Vračar', 'Vracar', '', 44.7925600, 20.4749100, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118381, 'Vojvoda Stepa', 'Vojvoda Stepa', 'Vojvoda Stepa', 45.6853700, 20.6553600, 'RS', '2016-10-13', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118382, 'Vojka', 'Vojka', 'Vojka', 44.9371300, 20.1523600, 'RS', '2016-10-13', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118383, 'Vlasotince', 'Vlasotince', 'Vlasotince,Vlasotinci,flaswtynsy,fu la suo ting cai,vlasotʼintses temi,Власотинце,Власотинци,فلاسوتينسي,ولاسوتینچے,ვლასოტინცეს თემი,弗拉索廷采', 42.9669700, 22.1340200, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118384, 'Vlajkovac', 'Vlajkovac', 'Temesvajkoc,Temesvajkóc,Vajkoc,Vajkóc,Vlaikovecz,Vlajkovac,Vlajkovecz', 45.0720700, 21.1994500, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118385, 'Vladimirovac', 'Vladimirovac', 'Petersdorf,Petre,Petrovosello,Roman-Petre,Román-Petre,Vladimirovac', 45.0312200, 20.8656600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118386, 'Vladičin Han', 'Vladicin Han', 'Vladichin Khan,Vladichin khan,Vladicin,Vladicin Han,Vladicki Han,Vladičin,Vladičin Han,fladytshyn han,fu la di qin han,Владичин Хан,Владичин хан,فلاديتشين هان,ولادیچن ہان,弗拉迪欽漢', 42.7077800, 22.0633300, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118387, 'Vilovo', 'Vilovo', 'Tunderes,Tündéres,Villova,Vilova,Vilovo', 45.2485900, 20.1552100, 'RS', '2012-08-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118388, 'Veliko Središte', 'Veliko Srediste', 'Gross Sredischte,Nagy-Szredistye,Nagyszered,Sredishtje Velke,Szredistye Mare,Veliko Srediste,Veliko Središte', 45.1791900, 21.4035300, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118389, 'Veliko Gradište', 'Veliko Gradiste', 'Gradiste,Gradište,Veliko Gradishhe,Veliko Gradishte,Veliko Gradiste,Veliko Gradište,Veliko-Gradishte,da ge la di shen tai,fylykw ghradyshty,wlykw grdysht,Велико Градиште,Велико Градище,Велико-Градиште,فيليكو غراديشتي,ولیکو گردیشت,ویلیکو گرادیشتے,大格拉迪什泰', 44.7620300, 21.5157800, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118390, 'Veliki Gaj', 'Veliki Gaj', 'Gaju Mare,Gáju Mare,Maleniczfalva,Nagy-Gaj,Nagy-Gáj,Nagygaj,Nemet-Gaj,Német-Gáj,Racz-Gaj,Rácz-Gáj,Veliki Gaj', 45.2884900, 21.1705700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118391, 'Aleksandrovo', 'Aleksandrovo', 'Aleksandrovo,Banatsko Aleksandrovo,Livade,Velike Livade', 45.6375500, 20.5928800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118392, 'Velika Plana', 'Velika Plana', 'Velika Plana,bellikapeullana,da pu la na,fylyka blana,wlyka plna,wylyka plana,Велика Плана,فيليكا بلانا,ولیکا پلنا,ویلیکا پلانا,大普拉納,벨리카플라나', 44.3338900, 21.0767600, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118393, 'Velika Moštanica', 'Velika Mostanica', 'Mostanica,Moštanica,Velika Mostanica,Velika Moštanica', 44.6648600, 20.3539500, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118394, 'Velika Greda', 'Velika Greda', 'Georgshausen,Gyorgyhaz,Gyorgyhaza,Györgyház,Györgyháza,Velika Greda', 45.2437600, 21.0349800, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118395, 'Varvarin', 'Varvarin', 'Varvarin,wa er wa lin,warwarn,wrwryn,Варварин,واروارن,ورورین,瓦尔瓦林', 43.7239700, 21.3624000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118396, 'Uzdin', 'Uzdin', 'Ujozora,Usdin,Uzdin,Újozora', 45.2051200, 20.6234200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118397, 'Umka', 'Umka', 'Umka', 44.6780600, 20.3047200, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118398, 'Uljma', 'Uljma', 'Homokszil,Uljma,Ullma,Ulma', 45.0421300, 21.1539300, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118399, 'Ugrinovci', 'Ugrinovci', 'Ugrinovci', 44.8763500, 20.1876300, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118400, 'Ub', 'Ub', 'Ub', 44.4561100, 20.0738900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118401, 'Tutin', 'Tutin', 'Tutin,Tutini,Tutinje,tu ting,twtn,twtn  srbya,twtyn  srbstan,Тутин,توتن,توتن، سربیا,توتین، صربستان,圖廷', 42.9902800, 20.3313900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118402, 'Turija', 'Turija', 'Turija', 44.5227300, 21.6394500, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118403, 'Trstenik', 'Trstenik', 'Trstenik,Trustenik,te lei si ta ni ke,trstynk,Трстеник,Тръстеник,ترستینک,特雷斯塔尼克', 43.6169400, 21.0025000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118404, 'Trgovište', 'Trgoviste', 'Trgoviste,Trgovište', 42.3641700, 22.0825000, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118405, 'Torda', 'Torda', 'Jordan,Kistorda,Torda,Torontaltorda,Torontáltorda,Turda,Vujicevo,Vujićevo', 45.5842300, 20.4590000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118406, 'Topola', 'Topola', 'Topola,Topola Kragujevacka,Topola Kragujevačka', 44.2541700, 20.6825000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118407, 'Tomaševac', 'Tomasevac', 'Tamaslaka,Tamáslaka,Tomaschewatz,Tomasevac,Tomasevacz,Tomasevci,Tomasevácz,Tomasovacz,Tomassovacz,Tomaševac,Tomaševci', 45.2685500, 20.6227200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118408, 'Toba', 'Toba', 'Nagy-Toba,Nagy-Tóba,Toba,Tóba', 45.6894300, 20.5571400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118409, 'Titel', 'Titel', 'Tetol,Tetöl,Theisshugel,Theisshügel,Titel,Titol,Tittel,Titul,Titulium,Titöl,di tai er,tytal,Тител,تیتال,蒂泰爾', 45.2061100, 20.2944400, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118410, 'Taraš', 'Taras', 'Taras,Taraš,Tarras,Tiszatarros', 45.4673700, 20.1986700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118411, 'Svrljig', 'Svrljig', 'Opshtina Svrlig,Opstina Svrljig,Opština Svrljig,Sevrlink,Surljig,Svrljig,Svurlig,si fu er li ge,swrlyyg,Σεβρλίγκ,Општина Сврљиг,Свърлиг,سورلیئگ,斯夫爾利格', 43.4133300, 22.1211100, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118412, 'Svilajnac', 'Svilajnac', 'Svilajnac,Svilajuac,si wei la yi na ci,swylaynas,Свилајнац,سویلایناس,斯維拉伊納茨', 44.2337000, 21.1967000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118413, 'Sutjeska', 'Sutjeska', 'Deutsch-Sartscha,Nemet-Szarcsa,Nova Sarca,Nova Sarča,Német-Szárcsa,Roman-Szarcsa,Román-Szárcsa,Sarca,Sarča,Sutjeska,Szarcsa,Szarcsatelek,Szarcsia,Szárcsa,Szárcsatelek', 45.3831200, 20.6962000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118414, 'Surdulica', 'Surdulica', 'Sourntoulitsa,Surdulica,srdwlycha,su er du li cha,Σουρντούλιτσα,Сурдулица,سردولیچا,蘇爾杜利察', 42.6905600, 22.1708300, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118415, 'Surduk', 'Surduk', 'Rittium,Surduk,Szurdok', 45.0747400, 20.3189800, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118416, 'Surčin', 'Surcin', 'Gradska opshtina Surchin,Opstina Surcin,Opština Surčin,Surchin,Surcin,Surcsin,Surĉin,Surčin,Szurcsin,Szurcsin varosi koezseg,Szurcsin városi község,su er qin,suruchin,Градска општина Сурчин,Сурчин,სურჩინის მუნიციპალიტეტი,スルチン,蘇爾欽', 44.7930600, 20.2802800, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118417, 'Stubline', 'Stubline', 'Stublina,Stubline', 44.5747600, 20.1347700, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118418, 'Stepojevac', 'Stepojevac', 'Stepajevac,Stepojevac', 44.5127800, 20.2950000, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118419, 'Stari Lec', 'Stari Lec', 'Alt-Letz,Barachhaza,Barachháza,Baraczhaza,Baraczháza,Baráczháza,Olec,Olecz,Stari Lec,Óléc,Ólécz', 45.2840100, 20.9643300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118420, 'Stari Banovci', 'Stari Banovci', 'Stari Banovci', 44.9842000, 20.2838200, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118421, 'Stara Pazova', 'Stara Pazova', 'Alt-Pasua,Alt-Pazua,Opazova,Pazua,Stara Pazova,Stará Pazova,jiu pa zuo wa,stara pazwwa,Ópazova,Ópázova,Стара Пазова,ستارا پازووا,舊帕佐瓦', 44.9850000, 20.1608300, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118422, 'Stajićevo', 'Stajicevo', 'Alt-Etschka,Ecska,Oecska,Roman-Ecska,Román-Écska,Stajicevo,Stajićevo,Stara Ecka,Stara Ečka,Écska,Óécska', 45.2948900, 20.4584500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118423, 'Srpski Itebej', 'Srpski Itebej', 'Felsoittebe,Felsőittebe,Itebej,Itebo,Itebő,Ittebe,Racz-Ittebe,Rácz-Ittebe,Serbisch Itebe,Serbisch-Ittebe,Srpski Itebej,Szerbittabe,Szerbittabé,Szerbittebe', 45.5671500, 20.7135000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118424, 'Srpska Crnja', 'Srpska Crnja', 'Crnja,Csernye,Czernya,Deutsch -Tschernja,Nemacka-Crnja,Nemacske-Csernye,Nemačka-Crnja,Nemačske-Csernye,Nemetcsernye,Németcsernye,Racz-Czernya,Rácz-Czernya,Serbish Zerne,Srpska Crnja,Szerb-Csernya,Szerbcsernye', 45.7253800, 20.6900800, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118425, 'Sremčica', 'Sremcica', '', 44.6765300, 20.3923200, 'RS', '2013-10-30', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118426, 'Sopot', 'Sopot', 'Opstina Sopot,Opština Sopot,Sopot,Sopot Veligradiou,suo bo te,Σόποτ Βελιγραδίου,Сопот,索波特', 44.5197200, 20.5736100, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118427, 'Soko Banja', 'Soko Banja', 'Banja Aleksinacka,Soko Banja,Sokobanja,Сокобаня', 43.6433300, 21.8711100, 'RS', '2016-04-30', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118428, 'Smederevska Palanka', 'Smederevska Palanka', 'Palanka,Palanka Smederevska,Smederevska Palanka,Smederevska palanka,Smederevska-Palanka,asmdrfska planka,si mei dai lei wo pa lan ka,smydyrywska planka,Смедеревска Паланка,Смедеревска паланка,Смедеревска-Паланка,اسمدرفسکا پلانکا,سمیدیریوسکا پلانکا,سمێدێرێڤسکا پالانکا,斯梅代雷沃帕蘭卡', 44.3654800, 20.9588500, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118429, 'Smederevo', 'Smederevo', 'Gorad Smedarava,Semendire,Semendria,Semêndria,Smedere,Smederevas,Smedereve,Smederevo,Smederewo,Smenterevo,Szendro,Szendrő,asmdrfw,seumedelebo,si mei dai lei wo,smdrbw,smederevo,smydyryww,sumederevu~o,Σμεντέρεβο,Горад Смедарава,Смедереве,Смедерево,סמדרבו,اسمدرفو,سمیدیریوو,سمێدێرێفپڤو,სმედერევო,スメデレヴォ,斯梅代雷沃,스메데레보', 44.6627800, 20.9300000, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118430, 'Šimanovci', 'Simanovci', 'Simanovci,Šimanovci', 44.8739300, 20.0917500, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118431, 'Ševica', 'Sevica', 'Sevica,Ševica', 44.5088300, 21.7229600, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118432, 'Senta', 'Senta', 'Senta,Szenta,Szintarev,Szintarév,Szénta,Zenta,sen ta,snth,synta,Σέντα,Сента,זענטא,סנטה,سینتا,森塔', 45.9275000, 20.0772200, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118433, 'Seleuš', 'Seleus', 'Keviszollos,Keviszolos,Keviszőllős,Keviszőlős,Seleus,Seleuş,Seleuš,Selleush,Szelleus', 45.1277000, 20.9146100, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118434, 'Sefkerin', 'Sefkerin', 'Sefkerin,Sevkerin,Shefkerin,Szeffkerin,Szefkerin,Szekereny,Szekerény', 45.0050100, 20.4825600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118435, 'Sečanj', 'Secanj', 'Petersheim,Secanj,Seceani,Sechan,Secsan,Setschan,Seĉanj,Sečanj,Szecsany,Szecsen,Szécsány,Szécsén,Torontalszecsany,Torontálszécsány,sychany,Сечањ,سیچانی', 45.3666700, 20.7722200, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118436, 'Sanad', 'Sanad', 'Sanad,Szanad,Szanád,Zanad', 45.9759600, 20.1081600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118437, 'Samoš', 'Samos', 'Samos,Samosh,Samoš,Szamos,Számos', 45.2025500, 20.7739200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118438, 'Samoljica', 'Samoljica', 'Samoljica,Somaljice,Sumulice,Sumulicë', 42.3844500, 21.7370800, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118439, 'Sakule', 'Sakule', 'Sakula,Sakule,Sekulla,Szakula,Torontalsziget,Torontálsziget', 45.1466700, 20.4861900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118440, 'Šajkaš', 'Sajkas', 'Kovil-Szent-Ivan,Kovil-Szent-Iván,Kowil-Sankt-Iwan,Sajkas,Sajkaska,Sajkaski Sveti Ivan,Sajkasszentivan,Sajkaški Sveti Ivan,Sajkásszentiván,Schatzdorf,Szent-Ivany,Szent-Ivány,Šajkaš,Šajkaška', 45.2731500, 20.0905100, 'RS', '2012-08-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118441, 'Sajan', 'Sajan', 'Sajan,Szajan,Szaján,Zajan,Zaján', 45.8422700, 20.2781500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118442, 'Rušanj', 'Rusanj', 'Rusanj,Rushan'',Rušanj,Рушань', 44.6847700, 20.4499300, 'RS', '2010-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118443, 'Rekovac', 'Rekovac', 'Opshtina Rekovac,Opstina Rekovac,Opština Rekovac,Rekovac,rykwwach,Општина Рековац,Рековац,ریکوواچ,რეკოვაცის მუნიციპალიტეტი', 43.8630000, 21.0934500, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118444, 'Ražanj', 'Razanj', 'Razanj,Razhan,Ražanj,razany,Ражањ,رازانی', 43.6722200, 21.5494400, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118445, 'Ravni Topolovac', 'Ravni Topolovac', 'Katalinfalva,Katarina,Katarinenfeld,Katerina,Katharinenfeld,Kathereinfeld,Kathreinfeld,Ravni Topolovac,Topolovac', 45.4608200, 20.5693900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118446, 'Rakovica', 'Rakovica', 'Comuna Rakovica,Gradska opshtina Rakovica,Opstina Rakovica,Opština Rakovica,Rakovica,la ke wei cha,Градска општина Раковица,Раковица,რაკოვიცის მუნიციპალიტეტი,拉科維察', 44.7419400, 20.4413900, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118447, 'Rajince', 'Rajince', 'Raince,Raincë,Rajinca,Rajince,Rajnice,Velike Rajince', 42.3787000, 21.6959100, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118448, 'Radovnica', 'Radovnica', 'Radovnica', 42.4336400, 22.2286100, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118449, 'Radojevo', 'Radojevo', 'Horvatklari,Horvátklári,Hrvatska Klarija,Klari,Klarija,Klary,Klári,Peterd,Petyerda,Péterd,Radojevo,Srpska Klarija', 45.7461700, 20.7891700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118450, 'Radenka', 'Radenka', 'Radenka', 44.5834500, 21.7646900, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118451, 'Rača', 'Raca', 'Raca,Racha,Rača,racha,Рача,راچا', 44.2271200, 20.9775400, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118452, 'Prokuplje', 'Prokuplje', 'Prokuple,Prokuplje,peulokupeulle,prwkwplyh,pu luo ku pu lie,purokupurye,Прокупле,Прокупље,پروکرپلیئے,پروکوپلیه,پرۆکوپلێ,プロクプリェ,普羅庫普列,프로쿠플레', 43.2341700, 21.5880600, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118453, 'Preševo', 'Presevo', 'Presevo,Presheva,Presheve,Preshevo,Preshevë,Preševo,peulesyebo,pryshyww,pu lei she wo,pureshevu~o,Прешево,پریشیوو,プレシェヴォ,普雷舍沃,프레셰보', 42.3091700, 21.6491700, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118454, 'Požega', 'Pozega', 'Pozega,Pozega Uzicka,Pozhega,Pożega,Požega,Požega Užička,bo re jia,pwzhaga,Пожега,پوژاگا,波熱加', 43.8488900, 20.0363200, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118455, 'Požarevac', 'Pozarevac', 'Gorad Pazharavac,Pasarofca,Pasarofça,Pozarevac,Pozarevacas,Pozarevats,Pozarewac,Pozerevac,Pozharev''c'',Pozharevac,Pozharevac'',Pozsarevac,Pozsarevác,Pożarewac,Požarevac,Požarevacas,Požerevac,ZZP,bo zha lei wa ci,pojalebacheu,pojarevu~atsu,pwzarywach,pwzharfas,pwzharywats,pwzʼrwwʼz,Ποζάρεβατς,Горад Пажаравац,Пожаревац,Пожареваць,Пожарєвьць,פוזארוואץ,پوزاریواچ,پوژارفاس,پوژاریواتس,پۆژارێڤاتس,ポジャレヴァツ,波扎雷瓦茨,포자레바츠', 44.6213300, 21.1878200, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118456, 'Plandište', 'Plandiste', 'Mariolana,Plandishte,Plandiste,Plandiŝte,Plandište,Plandiște,Planduliste,Plandulişte,Zichidorf,Zichifalva,Zichihaza,Zichiháza,Zichydorf,Zichyfalva,Zichyhaz,Zichyház,Zicifalva,Zičifalva,Пландиште,پلاندیشتے', 45.2272200, 21.1216700, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118457, 'Pirot', 'Pirot', 'Pirot,pi luo te,piloteu,piroto,pyrwt,Πίροτ,Пирот,Пірот,פירוט,پیروت,پیرۆت,ピロト,皮罗特,피로트', 43.1530600, 22.5861100, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118458, 'Petrovac', 'Petrovac', 'Petrovac', 44.3769400, 21.4191700, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118459, 'Perlez', 'Perlez', 'Perlas,Perlasz,Perlaszvaros,Perlaszváros,Perlez', 45.2081300, 20.3819700, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118460, 'Pavliš', 'Pavlis', 'Pavlis,Pavliš,Temes-Paulis,Temespaulis,Temiski Pavlis,Temiški Pavliš,Vrsac-Pavlis,Vršac-Pavliš', 45.1056900, 21.2395200, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118461, 'Paraćin', 'Paracin', 'Parachin,Paracin,Paracinas,Parakin,Paraćin,Paračinas,pa la qin,palachin,parachin,parachyn,parasn,Парачин,Параћин,Параќин,پاراسن,پاراچین,パラチン,帕拉欽,파라친', 43.8608300, 21.4077800, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118462, 'Pančevo', 'Pancevo', 'Banstadt,Gorad Panchava,Hertelendyfalva,Marienfeld,Pancevas,Pancevo,Panchevo,Panciova,Pancsal,Pancsaly,Pancsova,Pantschowa,Pantsevo,Panĉevo,Pančevas,Pančevo,QBG,Vojlovica,Wojlowitz,Wojlowitza,pan qie wo,panchebo,panchevu~o,panchfw,panchyww,pnzbw,Πάντσεβο,Горад Панчава,Панчево,פנצבו,پانچفو,پانچیوو,پانچێڤۆ,パンチェヴォ,潘切沃,판체보', 44.8708300, 20.6402800, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118463, 'Padina', 'Padina', 'Lajosfalva,Ludwigsdorf,Naglajosfalva,Nagylajosfalva,Padina', 45.1198800, 20.7286000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118464, 'Padej', 'Padej', 'Magyarpade,Magyarpadé,Novi-Padej,Pade,Padej,Padé,Srpski Padej,Szerb-Pade,Szerb-Padé', 45.8275600, 20.1627900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118465, 'Ovča', 'Ovca', 'Baranyos,Bárányos,Gisellenhain,Ovcha,Ovcsa,Овча', 44.8834900, 20.5333600, 'RS', '2010-07-26', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118466, 'Ostružnica', 'Ostruznica', 'Ostruznica,Ostružnica', 44.7276900, 20.3184500, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118467, 'Ostojićevo', 'Ostojicevo', 'Klein Niklas,Klein Niklos,Ostojcevo,Ostojicevo,Ostojićevo,Ostojćevo,Ostrojcevo,Ostrojćevo,Potiski Sveti Nikola,Sankt Nikolaus an der Theiss,Tisa Sent Miklos,Tisa Sent Mikloš,Tisasentmiklus,Tisasentmikluš,Tiszaszentmiklos,Tiszaszentmiklós', 45.8886300, 20.1664200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118468, 'Orlovat', 'Orlovat', 'Barlad,Borlod,Orlod,Orlovat,Orlód', 45.2417100, 20.5808900, 'RS', '2016-10-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118469, 'Opovo', 'Opovo', 'Konisdorf,Könisdorf,Opava,Opovo,Oppova,Oppowa,ao bo wo,awpww,Ópáva,Опово,اوپوو,奧波沃', 45.0522200, 20.4302800, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118470, 'Obrenovac', 'Obrenovac', 'Obrenovac,Obrenovacas,Obrenovaç,Omprenovats,Opstina Obrenovac,Opština Obrenovac,ao bu lei nuo wa ci,awbrnwwas,awbrynwwas,Ομπρένοβατς,Обреновац,ئۆبرێنۆڤاتس,اوبرنوواس,اوبرینوواس,奧布雷諾瓦茨', 44.6548600, 20.2001700, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118471, 'Novo Miloševo', 'Novo Milosevo', 'Beodra,Beodra-Dragutinovo,Dragutinovo,Karlova,Karlovo,Milosevo,Miloševo,Novo Milosevo,Novo Miloševo', 45.7191600, 20.3036400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118472, 'Novi Slankamen', 'Novi Slankamen', 'Neu-Slankamen,Novi Slankamen,Slankamen,Slankamen Novi,Slankament,Ujzalankemen,Újzalánkemén', 45.1255400, 20.2391400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118473, 'Novi Pazar', 'Novi Pazar', 'Novi Pazar,Novi Pazaras,Novi pazar,Novi-Pazar,Pazari i Ri,Yeni Pazar,Yenipazar,nobipajaleu,novi pazar,nwfy bazar,nwwy pazar,xin pa zha er,Νόβι Παζάρ,Нови Пазар,Нови пазар,Нови-Пазар,נובי פאזאר,نوفي بازار,نووی پازار,نۆڤی پازار، سربیا,ノヴィ・パザル,新帕扎爾,노비파자르', 43.1366700, 20.5122200, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118474, 'Kozjak', 'Kozjak', 'Ferdin,Ferdinandfalva,Ferdinandsdorf,Ferdinándfalva,Kozjak,Novi Kozjak', 45.1826400, 20.8638100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118475, 'Novi Kozarci', 'Novi Kozarci', 'Hajfeld,Heufeld,Kistoszeg,Kistószeg,Kozarci,Massdorf,Mastort,Nagytoszeg,Nagytošzeg,Nagytószeg,Novi Kozarci,Toszeg,Tószeg,Veliki Teseg', 45.7824100, 20.6228900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118476, 'Novi Kneževac', 'Novi Knezevac', 'Josephova,Josephsdorf,Kanisa,Kanizsa,Kis-Kanizsa,Neukanischa,Nova Kanjiza,Nova Kanjiža,Novi Knejevac,Novi Knezevac,Novi Knezhevac,Novi Kneĵevac,Novi Kneževac,Novi-Knezhevac,Rev-Kanizsa,Rév-Kanizsa,Toeroekkanizsa,Torokkanizsa,Torontal-Jozseffalva,Torontál-Józseffalva,Turska Kanjiza,Turska Kanjiža,Törökkanizsa,nobikeunejebacheu,nwwy knyzhywach,xin ke nei re wa ci,Нови Кнежевац,Нови-Кнежевац,نووی کنیژیواچ,新克內熱瓦茨,노비크네제바츠', 46.0500000, 20.1000000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118477, 'Novi Karlovci', 'Novi Karlovci', 'Karlovicz,Neu-Karlowitz,Novi Karlovci,Novi Karlovec,Sase,Sassa,Ujkarloca,Újkarlóca', 45.0763600, 20.1794800, 'RS', '2016-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118478, 'Novi Itebej', 'Novi Itebej', 'Alsoittebe,Alsóittebe,Itebo,Itebő,Ittebe,Magyar-Ittebe,Magyarittabe,Magyarittabé,Neu-Itebe,Novi Itebej,Ungarisch-Ittebe', 45.5591800, 20.7003000, 'RS', '2016-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118479, 'Novi Beograd', 'Novi Beograd', 'Gradska opshtina Novi Beograd,New Belgrade,Nova Belgrado,Novbeogrado,Novi Belgrad,Novi Belgrade,Novi Beograd,Novi Beonkrant,Novi-Beograd,Novy Belehrad,Nový Bělehrad,Nowy Belgrad,Opstina Novi Beograd,Opština Novi Beograd,Yeni Belgrad,xin bei er ge lai de,Νόβι Μπέογκραντ,Градска општина Нови Београд,Нови Белград,Нови-Београд,ნოვი-ბეოგრადის მუნიციპალიტეტი,ノヴィ・ベオグラード,新贝尔格莱德', 44.8055600, 20.4241700, 'RS', '2016-04-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118480, 'Novi Bečej', 'Novi Becej', 'Arac,Aracs,Arać,Franiova,Neu-Betsche,Novi Bece,Novi Becej,Novi Bechej,Novi Beczej,Novi Beĉej,Novi Beče,Novi Bečej,Toeroekbecse,Torokbecse,Turkisch-Betsche,Turski Becej,Turski Bečej,Törökbecse,Türkisch-Betsche,Uj-Becse,Volosinovo,Vološinovo,Vranjevo,nwby bzyy,nwwy bychyy,xin bei qie yi,Нови Бечеј,נובי בציי,نووی بیچیی,新貝切伊', 45.5986100, 20.1355600, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118481, 'Novi Banovci', 'Novi Banovci', 'Novi Banovci', 44.9556100, 20.2802500, 'RS', '2016-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118482, 'Nova Pazova', 'Nova Pazova', 'Neu-Pasua,Nova Pazova,Ujpazova,Újpázova,Нова Пазова', 44.9436600, 20.2193100, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118483, 'Nova Crnja', 'Nova Crnja', 'Magyarcsernye,Nova Crna,Nova Crnja,nwwa chrnya,Нова Црња,نووا چرنیا', 45.6683300, 20.6050000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118484, 'Niš', 'Nis', 'INI,Nich,Nis,Nisch,Nish,Niso,Nissa,Nisz,Nix,Niŝo,Niš,Ниш', 43.3247200, 21.9033300, 'RS', '2016-12-05', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118485, 'Nikolinci', 'Nikolinci', 'Nikolince,Nikolinci,Nikolincze,Temes-Miklos,Temes-Miklós', 45.0524500, 21.0669500, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118486, 'Neuzina', 'Neuzina', 'Horvat-Neuzina,Horvát-Neuzina,Hrvatska Neuzina,Kisnezseny,Kisnezsény,Kroatisch-Neusin,Nagynezseny,Nagynezsény,Neuszina,Neuzina,Serbisch-Neusin,Srpska Neuzina,Szerb-Neuzina', 45.3446000, 20.7141800, 'RS', '2016-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118487, 'Negotin', 'Negotin', 'Negotin,Negotin Krajina,Negotin Krajinski,Nenkotin,negotin,nei ge ting,nygwtn,Νεγκοτίν,Неготин,نیگوتن,ნეგოტინი,內戈廷,네고틴', 44.2263900, 22.5308300, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118488, 'Nakovo', 'Nakovo', 'Nakodorf,Nakofalva,Nakovo,Nákófalva', 45.8750300, 20.5670900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118489, 'Adorjan', 'Adorjan', 'Adorjan,Adorján,Nadrljan,Адорјан', 46.0033300, 20.0400700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118490, 'Mošorin', 'Mosorin', 'Moschorin,Mosorin,Mozsor,Mošorin', 45.3019600, 20.1691900, 'RS', '2012-08-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118491, 'Mol', 'Mol', 'Mohol,Mohorreve,Mohorréve,Mol,Мол', 45.7645700, 20.1328600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118492, 'Mokrin', 'Mokrin', 'Homokrev,Homokrév,Mokrin', 45.9336200, 20.4121500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118493, 'Mladenovac', 'Mladenovac', 'Gradska opshtina Mladenovac,Mladenovac,Mladenovac Grad,Opstina Mladenovac,Opština Mladenovac,Selo-Mladenovac,mladnwwas,mu la dai nuo wa ci,Градска општина Младеновац,Младеновац,ملادنوواس,ملادێنۆڤاتس,მლადენოვაცის მუნიციპალიტეტი,姆拉代諾瓦茨', 44.4386100, 20.6991700, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118494, 'Miratovac', 'Miratovac', 'Miras,Miratoc,Miratovac,Miratovce,Miraš', 42.2584600, 21.6645600, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118495, 'Mionica', 'Mionica', 'Mionica,mywnycha,Мионица,میونیچا', 44.2519400, 20.0816700, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118496, 'Mihajlovo', 'Mihajlovo', 'Magyarszentmihaly,Magyarszentmihály,Mihajlovo,Szentmihaly,Szentmihály', 45.4708500, 20.4150800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118497, 'Merošina', 'Merosina', 'Meroshina,Merosina,Merošina,Мерошина', 43.2835800, 21.7204000, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118498, 'Melenci', 'Melenci', 'Meleanz,Melenci,Melencze,Melentz,Melenze', 45.5168000, 20.3196100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118499, 'Medveđa', 'Medvega', 'Medveda,Medvedja,Medvedzha,Medvegja,Medvegje,Medvegjë,Medveđa,Opstina Medvega,Opština Medveđa,medeubeja,medovu~eja,mei de wei gu,mydwyda,Медведжа,Медвеђа,میدویدا,メドヴェジャ,梅德韋賈,메드베자', 42.8430600, 21.5833300, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118500, 'Međa', 'Meda', 'Magyar-Pardany,Magyar-Párdány,Meda,Međa,Nemet-Pardany,Nincicevo,Ninčićevo,Német-Párdány,Pardan,Pardanj,Pardany,Párdány,Racz-Pardany,Rácz-Párdány,Szerb-Pardany,Szerb-Párdány', 45.5381500, 20.8067700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118501, 'Margita', 'Margita', 'Gross-Margit,Margita,Margitha,Margitta,Nagymargita,Nagymargitta', 45.2159800, 21.1752700, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118502, 'Malo Crniće', 'Malo Crnice', 'Malo Crnice,Malo Crniće,Malo Crnuce,Malo Crnuće,Мало Црниће,مالو چرنیسے', 44.5561100, 21.2855600, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118503, 'Mala Moštanica', 'Mala Mostanica', 'Mala Mostanica,Mala Moštanica', 44.6383400, 20.3060000, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118504, 'Majdanpek', 'Majdanpek', 'Maidan,Majdanpek,ma yi dan pei ke,mayydanpyk,Майданпек,Мајданпек,مائیدانپیک,馬伊丹佩克', 44.4277100, 21.9459600, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118505, 'Lukićevo', 'Lukicevo', 'Lukicevo,Lukićevo,Martinica,Sigmundsdorf,Sigmundsfeld,Zsigmondfalva', 45.3381500, 20.4989500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118506, 'Lugavčina', 'Lugavcina', 'Lugavcina,Lugavčina', 44.5231400, 21.0708300, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118507, 'Lučani', 'Lucani', 'Lucanai,Lucani,Luchani,Lučanai,Lučani,lwchany,ruchani,Лучани,لوچانی,ルチャニ', 43.8608300, 20.1380600, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118508, 'Lokve', 'Lokve', 'Lokve,Semijaj,Sent Mihai,Sveti Mihajl,Sveti Mihajlo,Szent-Mihaly,Szent-Mihály,Vegsent Mihalj,Vegszentmihaly,Végszentmihály', 45.1519800, 21.0307300, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118509, 'Lok', 'Lok', 'Lock,Lok,Look,Loók,Lók,Sajkaslak,Sajkáslak', 45.2158300, 20.2122200, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118510, 'Ljukovo', 'Ljukovo', 'Ljukovo,Lyukovo,Pustara Ljukovo', 45.0260400, 20.0273700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118511, 'Ljig', 'Ljig', 'Lig,Ljig,Opshtina LJig,Opstina Ljig,Opština Ljig,li ge,lyyg,Лиг,Општина Љиг,لیئگ,ლიგის მუნიციპალიტეტი,利格', 44.2300700, 20.2381900, 'RS', '2012-04-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118512, 'Leskovac', 'Leskovac', 'Gorad Leskovac,Leshkuqi,Leskofca,Leskofça,Leskovac,Leskovacas,Leskovats,lai si ke wa ci,leseukobacheu,lskwas,lsqwbz,lyskwfats,lyskwwach,lyskwwats,resukovu~atsu,Λέσκοβατς,Горад Лесковац,Лесковац,לסקובץ,لسکواس,ليسكوفاتس,لیسکوواتس,لیسکوواچ,لێسکۆڤاتس,レスコヴァツ,莱斯科瓦茨,레스코바츠', 42.9980600, 21.9461100, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118513, 'Lebane', 'Lebane', 'Lebana,Lebane,lai ba nei,Лебане,لیبانے,萊巴內', 42.9238900, 21.7375000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118514, 'Lazarevo', 'Lazarevo', 'Lasarfeld,Lazarevo,Lazarfold,Lázárföld', 45.3889300, 20.5399900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118515, 'Lazarevac', 'Lazarevac', 'Lazarevac,Lazarevacas,Lazarevats,Opstina Lazarevac,Opština Lazarevac,la zha lei wa ci,lazarwas,Λαζάρεβατς,Лазаревац,لازارواس,لازارێڤاتس,拉扎雷瓦茨', 44.3853400, 20.2557000, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118516, 'Lapovo', 'Lapovo', 'Lapovo,Лапово', 44.1842400, 21.0972700, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118517, 'Lajkovac', 'Lajkovac', 'Jabucje,Jabučje,Lajkovac,la yi ke wa ci,lajkwwak,layykwwach,Лајковац,لائیکوواچ,لاجکوواک,拉伊科瓦茨', 44.3694400, 20.1652800, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118518, 'Kuštilj', 'Kustilj', 'Costeiu,Coşteiu,Kustely,Kustil,Kustilj,Kustély,Kuštilj,Melykastely,Mélykastély', 45.0348700, 21.3798900, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118519, 'Kuršumlija', 'Kursumlija', 'Kurshumli,Kurshumlia,Kurshumlija,Kursumlija,Kursumlje,Kuršumlija,Kuršumlje,krshmlyya,ku er shu mu li ya,Куршумлия,Куршумлија,کرشملییا,庫爾舒姆利亞', 43.1382600, 21.2733900, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118520, 'Kupinovo', 'Kupinovo', 'Kelpeny,Kelpény,Kolpeny,Kupinovo,Kölpény', 44.7070800, 20.0495900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118521, 'Kumane', 'Kumane', 'Kuman,Kumand,Kumane,Kumani,Kumán,Kumánd', 45.5394600, 20.2290200, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118522, 'Kučevo', 'Kucevo', 'Kucevo,Kuchevo,Kučevo,ku qie wo,kwchyww,Кучево,کوچیوو,庫切沃', 44.4775000, 21.6700000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118523, 'Kruševac', 'Krusevac', 'Alacahisar,Gorad Krushavac,Krousevats,Krusevac,Krusevacas,Krushevac,Kruševac,Kruševacas,alajh hsar,ke lu she wa ci,keulusyebacheu,krwshwas,krwshyfats,krwshywach,krwshywats,kurushevu~atsu,qrwsbz,Κρούσεβατς,Горад Крушавац,Крушевац,קרושבץ,الاجه حصار,كروشيفاتس,کروشواس,کروشیواتس,کروشیواچ,کروشێڤاتس,クルシェヴァツ,克鲁舍瓦茨,크루셰바츠', 43.5800000, 21.3338900, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118524, 'Krčedin', 'Krcedin', 'Krcedin,Krčedin', 45.1387100, 20.1330800, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118525, 'Kraljevo', 'Kraljevo', 'Kralevas,Kralevo,Kralievo,Kraljevo,Rankovicevo,Rankovićevo,ke la lie wo,keulallebo,kralyfw,kralyyfw,kralyyww,kuraryevu~o,qrlywbw,Κράλιεβο,Кралево,Краљево,קרליובו,كرالييفو,کرالیئوو,کرالیفو,کرالێڤۆ,クラリェヴォ,克拉列沃,크랄레보', 43.7258300, 20.6894400, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118526, 'Krajišnik', 'Krajisnik', 'Istvanfold,Istvanfolde,Istvánföld,Istvánfölde,Krajisnik,Krajišnik,Schuplje,Stefanfold,Stefanifeld,Stefansfeld,Stefánföld,Stephansdorf,Supljaja,Šupljaja', 45.4528300, 20.7297600, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118527, 'Kragujevac', 'Kragujevac', 'Gorad Kraguevac,Krabujevac,Kragiyevac,Kraguevac,Kraguevac'',Kragujevac,Kragujevaca,Kragujevacas,Krankougievats,ke la gu ye wa ci,keulaguyebacheu,khra kuye wat s,kraghwyyfats,kragwywats,kragwywts,kragwyywach,kuragui~evu~atsu,qrgwyybz,Κραγκούγιεβατς,Горад Крагуевац,Крагоуѥвьць,Крагуевац,Крагуєваць,Крагујевац,קרגוייבץ,كراغوييفاتس,کراگوئیواچ,کراگویواتس,کراگویوتس,ครากูเยวัตส์,クラグイェヴァツ,克拉古耶瓦茨,크라구예바츠', 44.0166700, 20.9166700, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118528, 'Kovin', 'Kovin', 'Cubin,Cuvin,Kevevara,Kevevára,Kovin,Kubin,Temes-Kubin,Temeschkubin,ke wen,kwwyn,Ковин,کووین,科溫', 44.7475000, 20.9761100, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118764, 'Udomlya', 'Udomlya', 'Udomlja,Udomlya,Удомля', 57.8794400, 34.9925000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118765, 'Sosnovka', 'Sosnovka', 'Sosnovka,Sosnovo,Сосновка', 60.0166700, 30.3500000, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118766, 'Sasovo', 'Sasovo', 'Gorad Sasava,Sasovo,Sasowo,Sassovo,Sassowo,Saz,sa suo wo,sasobo,sasovu~o,saswfw,Горад Сасава,Саз,Сасово,Сасово балһсн,ساسوفو,サーソヴォ,薩索沃,사소보', 54.3536900, 41.9198600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118767, 'Novozavidovskiy', 'Novozavidovskiy', 'Novosavidovsk,Novozavidovskij,Novozavidovskiy,Poselok Novo-Zaridovskiy,Posëlok Novo-Zaridovskiy,Новозавидовский', 56.5500000, 36.4333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118768, 'Krasnolesnyy', 'Krasnolesnyy', 'Krasnolesny,Krasnolesnyj,Krasnolesnyy,Poselok Krasnolesnyy,Posëlok Krasnolesnyy,Краснолесный', 51.8807200, 39.5877200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118769, 'Kosterevo', 'Kosterevo', 'Kosterevo,Kosterovo,Костерево', 55.9299000, 39.6143800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118770, 'Zyuzino', 'Zyuzino', 'Zjuzino,Zyuzino,Зюзино', 55.6560800, 37.5684600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118771, 'Zyukayka', 'Zyukayka', 'Ziukajka,Zjukajka,Zyukayka,Зюкайка', 58.2041600, 54.7078400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118772, 'Zykovo', 'Zykovo', 'Zykovo,Зыково', 54.0685300, 45.0863300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118773, 'Zyablikovo', 'Zyablikovo', 'Zjablikovo,Zyablikovo,Зябликово', 55.6166700, 37.7666700, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118774, 'Zvony', 'Zvony', 'Zvony,Звоны', 56.6240900, 28.8160400, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118775, 'Zverevo', 'Zverevo', 'Gorad Zverava,Swerewo,Zverevo,Zvyereva,Zwieriewo,Zwjerjewo,ci wei lie wo,zfyryfw,zwrwfw,Горад Зверава,Зверево,Зверево балһсн,Звєрево,زفيريفو,زوروفو,兹韦列沃', 48.0210800, 40.1228200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118776, 'Zvenigovo', 'Zvenigovo', 'Chavash Utare,Gorad Zvjanigava,Provoj,Swenigowo,Zvenigovo,Zvenigovskiy Zaton,Zveniqovo,Zvenyigovo,Zwienigowo,Zwjenigowo,ci wei ni ge wo,jeubenigobo,zfynyghwfw,zwnygwfw,Горад Звянігава,Звенигово,Провой,Чăваш Утарĕ,زفينيغوفو,زونیگوفو,兹韦尼哥沃,즈베니고보', 55.9753900, 48.0130400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118777, 'Zvenigorod', 'Zvenigorod', 'Svenigorod,Swenigorod,Zvenigorod,Zveniqorod,Zvenígorod,Zwienigorod,Zwjenigorod,ci wei ni ge luo de,jeubenigolodeu,zfynyghwrwd,zuvu~enigorodo,zwnygwrwd,zwynygrwd,Звенигород,Звенигород балһсн,زفينيغورود,زونیگورود,زوینیگرود,ズヴェニゴロド,兹韦尼哥罗德,즈베니고로드', 55.7340100, 36.8591800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118778, 'Zuyevka', 'Zuyevka', 'Zuevka,Zujevka,Zuyevka,Зуевка', 58.4050300, 51.1335500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118779, 'Zubtsov', 'Zubtsov', 'Gorad Zubcou,Subzow,Zoebtsov,Zoubtsov,Zubcov,Zubcow,Zubtsov,Zupcov,jubchopeu,zu bu zuo fu,zubutsu~ofu,zwbtswf,Горад Зубцоў,Зубцов,Зупцов,زوبتسوف,ズブツォフ,祖布佐夫,줍초프', 56.1753300, 34.5893500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118780, 'Zubovo', 'Zubovo', 'Shol''skiy,Shola,Shol’skiy,Zubovo,Zuboyo,Зубово', 60.3181000, 36.9709000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118781, 'Zubova Polyana', 'Zubova Polyana', 'Zubova Poljana,Zubova Polyana,Zubovz Polyana,Zubu,Zupova Poljana,Зубова Поляна,Зубу', 54.0771000, 42.8372000, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118782, 'Zolotukhino', 'Zolotukhino', 'Zolotukhino,Золотухино', 52.0842000, 36.3777700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118783, 'Zolotkovo', 'Zolotkovo', 'Zolotkovo,Золотково', 55.5281000, 41.1053000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118784, 'Znamenskoye', 'Znamenskoye', 'Znamenskoe,Znamenskoje,Znamenskoye,Знаменское', 53.2786900, 35.6905500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118785, 'Znamenskoye', 'Znamenskoye', 'ChӀu''lga-Jurt,Mundar-Jurt,Mundar-Yurt,Znamenka,Znamenskoe,Znamenskoje,Znamenskoye,Знаменка,Знаменское,Мундар-Юрт,ЧӀуьлга-Юрт', 43.6789800, 45.1286700, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118786, 'Znamensk', 'Znamensk', 'Snamensk,Velau,Veluva,Vėluva,Wehlau,Znamensk,Znamenskas,Znamiensk,ci na mian si ke,znamynsk,Знаменск,زنامينسك,兹纳缅斯克', 54.6140300, 21.2272200, 'RU', '2016-02-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118787, 'Znamenka', 'Znamenka', 'Kukuyevka,Znamenka,Знаменка', 52.8978900, 35.9770300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118788, 'Znamenka', 'Znamenka', 'Znamenka,Знаменка', 52.4167000, 41.4310800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118789, 'Zmiyëvka', 'Zmiyevka', 'Zmievka,Zmijevka,Zmijovka,Zmiyevka,Zmiyëvka,Змиевка,Змиёвка', 52.6669700, 36.3742600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118790, 'Zmeyskaya', 'Zmeyskaya', 'Zmejskaja,Zmeyskaya,Змейская', 43.3361700, 44.1573300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118791, 'Zlynka', 'Zlynka', 'Gorad Zlynka,Slynka,Zlink,Zlinka,Zlonka,Zlynka,Zlõnka,Złynka,ci lun ka,jeullinka,zlynka,zlynqh,zuru~inka,Горад Злынка,Злинка,Злынка,Злынка балһсн,זלינקה,زلينكا,زلینکا,ズルィンカ,兹伦卡,즐린카', 52.4267000, 31.7378000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118792, 'Zlatoust', 'Zlatoust', 'Gorad Zlatavust,Slatoust,Zlato-oest,Zlatooust,Zlatoust,Zlatousta,Zlatoustas,Zlatoutsk,Złatoust,ci la tuo wu si te,jeullatouseuteu,zlatwst,zlatwwst,zuratousuto,Горад Златавуст,Златоуст,زلاتؤوست,زلاتوؤست,زلاتوست,ズラトウースト,兹拉托乌斯特,즐라토우스트', 55.1711100, 59.6508300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118793, 'Zirgan', 'Zirgan', 'Zirgan,Зирган', 53.2222000, 55.9185000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118794, 'Zimovniki', 'Zimovniki', 'Zimovniki,Зимовники', 47.1474000, 42.4721000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118795, 'Zilair', 'Zilair', 'Jylajyr,Zilair,zylayr,Зилаир,Зілаїр,Йылайыр,Җылаер,Զիլաիր,زيلاير', 52.2332000, 57.4392000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118796, 'Zhulebino', 'Zhulebino', 'Zhelyabino,Zhulebino,Жулебино', 55.7000000, 37.8500000, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118797, 'Zhukovskiy', 'Zhukovskiy', 'Otdykh,Stakhanovo,ZIA,Zhukovskij,Zhukovskiy,Zhukovskogo,Zjukovskij,Zukovski,Žukovski,Жуковский', 55.5952800, 38.1202800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118798, 'Zhukovo', 'Zhukovo', 'Ugodskiy Zavod,Zhukov,Zhukovo,Zjukovo,Жуков', 55.0317800, 36.7440200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118799, 'Zhukovka', 'Zhukovka', 'Zhukovka,Zjukovka,Жуковка', 56.4833300, 37.5166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118800, 'Zhukovka', 'Zhukovka', 'Zhukovka,Zjukovka,Жуковка', 53.5339500, 33.7279800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118801, 'Zhizdra', 'Zhizdra', 'Shisdra,Zhizdra,Zjizdra,Жиздра', 53.7459600, 34.7395100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118802, 'Zhiryatino', 'Zhiryatino', 'Zhirjatino,Zhiryatino,Zjirjatino,Жирятино', 53.2228000, 33.7306000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118803, 'Zhirnovsk', 'Zhirnovsk', 'Zhirnovoye,Zhirnovsk,Zhirnovskiy,Zhirnoye,Zjirnovsk,Жирновск', 50.9844800, 44.7734700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118804, 'Zhirnov', 'Zhirnov', 'Zhirnov,Zhirov,Zjirnov,Жирнов', 48.1708900, 41.1260800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118805, 'Zhilëvo', 'Zhilevo', 'Zhilevo,Zhilëvo,Zjilevo,Жилево', 55.0140800, 38.0110600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118806, 'Zhiletovo', 'Zhiletovo', 'Zhiletova,Zhiletovo,Zjiletovo,Жилетово', 54.6921600, 36.0222500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118807, 'Zhigulevsk', 'Zhigulevsk', 'Otvazhnoye,Otvazhnyy,Zhigulevsk,Zjigulevsk,Жигулевск', 53.3997200, 49.4952800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118808, 'Zheshart', 'Zheshart', 'Zhershart,Zheshart,Zheshert,Zjesjart,Жешарт', 62.0731400, 49.5733500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118809, 'Zherdevka', 'Zherdevka', 'Chibisovka,Chibizovka,Staraya Zherdevka,Zherdevka,Zjerdevka,Жердевка', 51.8486100, 41.4605600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118810, 'Zhemtala', 'Zhemtala', 'Zhemtala,Zjemtala,Жемтала', 43.2840800, 43.6558600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118811, 'Zheleznovodsk', 'Zheleznovodsk', 'Shelesnowodsk,Zheleznovodak,Zheleznovodsk,Zhelyednovodsk,Zjeleznovodsk,Железноводск', 44.1394400, 43.0197200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118812, 'Zheleznogorsk', 'Zheleznogorsk', 'Zeleznogorsk,Zheleznogorsk,Zjeleznogorsk,Železnogorsk,Железногорск', 52.3310000, 35.3711000, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118813, 'Zheleznodorozhnyy', 'Zheleznodorozhnyy', 'Obiralovka,Zheleznodorozhny,Zheleznodorozhnyj,Zheleznodorozhnyy,Zjeleznodorozjnyj,Железнодорожный', 55.7440000, 38.0168400, 'RU', '2016-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118814, 'Zheleznodorozhnyy', 'Zheleznodorozhnyy', 'Gerdauen,Gerdauyen,Girdava,Shelesnodoroshnys'',Shelesnodoroshnys’,Zeleznodoroznas,Zeleznodoroznyj,Zheleznodorozhnyj,Zheleznodorozhnyy,Zjeleznodorozjnyj,Železnodorožnas,Železnodorožnyj,Железнодорожный', 54.3601300, 21.3059700, 'RU', '2015-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118815, 'Zhdankovskiy', 'Zhdankovskiy', 'Zhdankovskij,Zhdankovskiy,Zhdanovka,Zjdankovskij,Жданковский', 53.7532100, 38.1795100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118816, 'Zhavoronki', 'Zhavoronki', 'Zhavoronki,Zjavoronki,Жаворонки', 55.6494300, 37.1010100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118817, 'Zharkovskiy', 'Zharkovskiy', 'Zharkovskij,Zharkovskiy,Zjarkovskij,Жарковский', 55.8490000, 32.2697000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118818, 'Zhankhoteko', 'Zhankhoteko', 'Lashkuta,Zhankhoteko,Zjankhoteko,Жанхотеко', 43.5641700, 43.2105600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118819, 'Zhadovka', 'Zhadovka', 'Zhadovka,Zjadovka,Жадовка', 53.5746400, 46.9498500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118820, 'Zernograd', 'Zernograd', 'Gorad Zernagrad,Sernograd,Zernograd,Zernoqrad,Zernovol,Zernovoy,Ziernograd,ze er nuo ge lei,zrnwgrad,zyrnwghrad,Горад Зернаград,Зерноград,Зерноград балһсн,Զերնոգրադ,زرنوگراد,زيرنوغراد,澤爾諾格勒', 46.8451800, 40.3083400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118821, 'Zenzeli', 'Zenzeli', 'Zenzeli,Зензели', 45.9240700, 47.0473900, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118822, 'Zemlyansk', 'Zemlyansk', 'Zemljansk,Zemlyansk,Землянск', 51.9041000, 38.7334000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118823, 'Zemetchino', 'Zemetchino', 'Semettschino,Zametchino,Zemetchino,Zemettsjino,Земетчино', 53.4973000, 42.6163200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118824, 'Zelyony Gorod', 'Zelyony Gorod', 'Zeljonyj gorod,Zelyony Gorod,Зелёный город', 56.1783300, 44.0744000, 'RU', '2016-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118825, 'Zelenokumsk', 'Zelenokumsk', 'Gorad Zelenakumsk,Selenokumsk,Sovetekoye,Sovetskoye,Vorontsovo-Aleksandrovskoye,Woronzowo-Alexandrowskoje,Zelenokoemsk,Zelenokoumsk,Zelenokums''k,Zelenokumsk,Zielenokumsk,ze lie nuo ku mu si ke,zlnwkwmsk,zylynwkwmsk,Горад Зеленакумск,Зеленокумск,Зеленокумск балһсн,Зеленокумськ,زلنوکومسک,زيلينوكومسك,澤列諾庫姆斯克', 44.4069400, 43.8805600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118826, 'Zelenogradskiy', 'Zelenogradskiy', 'Zelenogradskij,Zelenogradskiy,Зеленоградский', 56.1000000, 37.9166700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118827, 'Zelenogradsk', 'Zelenogradsk', 'Cranz,Grants,Krantas,Krants,Kranz,Selenogradsk,Zelenograds''k,Zelenogradsk,Zelenogradska,Zelenogradskas,Zelenogradszk,Zelenoqradsk,Zeļenogradska,Zielenogradsk,jellenogeulacheukeu,ze lie nuo ge la ci ke,zerenoguratsuku,zlnwgradsk,zlnwgrdsq,zylynwghradsk,Зеленоградск,Зеленоградськ,זלנוגרדסק,زلنوگرادسک,زيلينوغرادسك,ゼレノグラーツク,澤列諾格拉茨克,젤레노그라츠크', 54.9589300, 20.4766800, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118828, 'Zelenograd', 'Zelenograd', 'Zelenograd,Зеленоград', 55.9825000, 37.1813900, 'RU', '2010-03-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118829, 'Zelenogorsk', 'Zelenogorsk', 'Gorad Zelenagorsk,Poselok Terioki,Posëlok Terioki,Selenogorsk,Terijoki,Terioki,Teriyoki,Zelenogors''k,Zelenogorsk,Zelenogorsk i St. Petersburg,Zelenogorska,Zeļenogorska,Zielenogorsk,jellenogoleuseukeu,ze lie nuo ge er si ke,zlnwgwrsk  sn ptrzbwrg,zylynwghwrsk,Горад Зеленагорск,Зеленогорск,Зеленогорськ,Терийоки,Териоки,زلنوگورسک، سن پترزبورگ,زيلينوغورسك,ზელენოგორსკი,泽列诺戈尔斯克,젤레노고르스크', 60.1996800, 29.7018300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118830, 'Zelenodolsk', 'Zelenodolsk', 'Gorad Zelenadol''sk,Parat,Selenodolsk,Zelendol''sk,Zelendol’sk,Zelenodol''s''k,Zelenodol''sk,Zelenodoljsk,Zelenodolsk,Zelenodolsk i Russland,Zelenodolskas,Zielonodolsk,jellenodolseukeu,ze lie nuo duo er si ke,zerenodorisuku,zlnwdwlsk  rwsyh,zylynwdwlsk,Горад Зеленадольск,Зеленодольск,Зеленодольськ,Зеленодољск,Парат,Яшел Үзән,زلنودولسک، روسیه,زيلينودولسك,زیلینودولسک,ゼレノドリスク,泽列诺多尔斯克,젤레노돌스크', 55.8437600, 48.5178400, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118831, 'Zelenoborskiy', 'Zelenoborskiy', 'Lesobirzha,Poselok Lesobirzhi,Posëlok Lesobirzhi,Ruhtinanlahti,Zelenoborskij,Zelenoborskiy,Зеленоборский', 66.8450000, 32.3622200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118832, 'Zelenets', 'Zelenets', 'Zelenec,Zelenets,Зеленец', 61.8848500, 50.7489200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118833, 'Zelenchukskaya', 'Zelenchukskaya', 'Zelenchugskaya,Zelenchukskaja,Zelenchukskaya,Zelentsjukskaja,Зеленчукская', 43.8580400, 41.5894000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118834, 'Zayukovo', 'Zayukovo', 'Zajukovo,Zayukovo,Zayukovskoye,Zayunevski,Заюково', 43.6161100, 43.3338900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118835, 'Zaymishche', 'Zaymishche', 'Zajmishhe,Zajmisjtsje,Zaymishche,Займище', 52.7264000, 32.2334000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118836, 'Zavoronezhskoye', 'Zavoronezhskoye', 'Zavoronezhskoe,Zavoronezhskoye,Zavoronezjskoje,Zovoronezhskoye,Заворонежское', 52.8801000, 40.5526000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118837, 'Zavolzh’ye', 'Zavolzh''ye', 'Pestovo,Zavolzh''e,Zavolzh''ye,Zavolzh’ye,Zavolzje,Заволжье', 56.6405100, 43.3944600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118838, 'Zavolzhsk', 'Zavolzhsk', 'Gorad Zavolzhsk,Sawolschsk,Zavoljsk,Zavolshk,Zavolzh''ye,Zavolzhsk,Zavolzh’ye,Zavolzjsk,Zavolzsk,Zavolĵsk,Zavolžsk,Zawolzsk,Zawolžsk,jabolsiseukeu,zafwljsk,zavu~orushisuku,zawwlzhsk,zha wo er ri si ke,Горад Заволжск,Заволжск,Заволшк,زافولجسك,زاوولژسک,ザヴォルシスク,扎沃爾日斯克,자볼시스크', 57.4823000, 42.1377900, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118839, 'Masalovka', 'Masalovka', 'Kovalev,Masalovka,Mosolov,Zavodskoj,Zavodskoy,Заводской,Масаловка', 48.4037200, 40.2606400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118840, 'Zavidovo', 'Zavidovo', 'Zavidovo,Завидово', 56.5333300, 36.5333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118841, 'Zavetnoye', 'Zavetnoye', 'Amta,Zavetnoe,Zavetnoje,Zavetnoye,Заветное', 47.1194400, 43.8902800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118842, 'Zavetnoye', 'Zavetnoye', 'Rot Front,Zavetnoe,Zavetnoje,Zavetnoye,Zavetnyy,Заветное', 44.7492000, 41.5995000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118843, 'Zaterechnyy', 'Zaterechnyy', 'Zaterechnyj,Zaterechnyy,Zateretsjnyj,Затеречный', 44.7930600, 45.2097200, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118844, 'Zasosna', 'Zasosna', 'Zasosna,Засосна', 50.6307000, 38.3965000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118845, 'Zasechnoye', 'Zasechnoye', 'Zasechnoe,Zasechnoye,Zasetsjnoje,Zosechnoye,Засечное', 53.1092000, 45.0793600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118846, 'Zarubino', 'Zarubino', 'Zarubino,Зарубино', 58.7350000, 33.4755600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118847, 'Zarechnyy', 'Zarechnyy', 'Zarechnyj,Zarechnyy,Zaretsjnyj,Zvyagino,Заречный', 57.4693100, 42.2843100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118848, 'Zarechnyy', 'Zarechnyy', 'Pobedenka,Pobedinskiy,Zarechnyj,Zarechnyy,Zaretsjnyj,Заречный', 53.7306000, 39.5943700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118849, 'Zarechnyy', 'Zarechnyy', 'Zarechnyj,Zarechnyy,Zaretsjnyj,Заречный', 53.2035600, 45.1922700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118850, 'Zaraysk', 'Zaraysk', 'Zaraisk,Zarajsk,Zaraysk,Зарайск', 54.7605000, 38.8784100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118851, 'Zaprudnya', 'Zaprudnya', 'Gari,Zaprudnja,Zaprudnya,Запрудня', 56.5666700, 37.4333300, 'RU', '2015-09-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118852, 'Zapolyarnyy', 'Zapolyarnyy', 'Zapoljarnyj,Zapolyarnyy,Заполярный', 69.4154100, 30.8135500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118853, 'Zaplavnoye', 'Zaplavnoye', 'Zaplavnoe,Zaplavnoje,Zaplavnoye,Заплавное', 48.7048000, 45.0229000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118854, 'Zapadnaya Dvina', 'Zapadnaya Dvina', 'Zapadnaja Dvina,Zapadnaya Dvina,Западная Двина', 56.2590100, 32.0745400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118855, 'Zaokskiy', 'Zaokskiy', 'Poselok Zaokskiy,Posëlok Zaokskiy,Zaokskij,Zaokskiy,Zaokskoye,Заокский', 54.7322700, 37.4053900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118856, 'Zandak', 'Zandak', 'Dagbas,Dagbash,Dagbaş,Zandak,Zandaku,Zandakua,Zandaq,Zandaqa,Zandaq̇a,Дагбаш,Зандак,Зандакъ,Зандакъа', 43.0571000, 46.4556600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118857, 'Zamoskvorech’ye', 'Zamoskvorech''ye', 'Zamoskvorech''e,Zamoskvorech''ye,Zamoskvorech’ye,Замоскворечье', 55.7333300, 37.6333300, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118858, 'Zamishevo', 'Zamishevo', 'Zamishevo,Zamishjovo,Zamishëvo,Zamisjevo,Замишево,Замишёво', 52.5395000, 32.0129000, 'RU', '2013-08-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118859, 'Zalukokoazhe', 'Zalukokoazhe', 'Zalukokoazhe,Zalukokoazje,Залукокоаже', 43.9038900, 43.2155600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118860, 'Zalegoshch’', 'Zalegoshch''', 'Zalegoshch'',Zalegoshch’,Zalegoshh'',Zalegosjtsj,Залегощь', 52.8989000, 36.8909300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118861, 'Zakharovo', 'Zakharovo', 'Zakharovo,Zakharovo Pervoye,Захарово', 54.3660000, 39.2792000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118862, 'Zakan-Yurt', 'Zakan-Yurt', 'Prigorodnoe,Prigorodnoye,Romanovskaja,Romanovskaya,Sakan-Jurt,Zakan-Jurt,Zakan-Yurt,Zakan-Yurtovskaya,Zakin-Jurt,Zakin-Yurt,Закан-Юрт,Закин-Юрт,Пригородное,Романовская', 43.2597200, 45.4205600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118863, 'Zainsk', 'Zainsk', 'Gorad Zainsk,Sainsk,Seve,Zainsk,Zaínsk,Zaïnsk,Zəy,jainseukeu,zainsuku,zaynsk,zha yin si ke,Горад Заінск,Заинск,Зәй шәһәре,Сĕве,زاينسك,زاینسک,ザインスク,扎因斯克,자인스크', 55.3195000, 52.0694200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118864, 'Zagoryanskiy', 'Zagoryanskiy', 'Zagaryanskiy,Zagorjanskij,Zagoryanskiy,Zagoryanskoye,Загорянский', 55.9325000, 37.9580600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118865, 'Zadonsk', 'Zadonsk', 'Gorad Zadonsk,Sadonsk,Zadons''k,Zadonsk,zadwnsk,zha dong si ke,Горад Задонск,Задонск,Задонск балһсн,Задонськ,زادونسك,زادونسک,扎東斯克', 52.3904000, 38.9261000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118866, 'Zabolotovka', 'Zabolotovka', 'Zabolotovka,Заболотовка', 50.2736800, 39.3147000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118867, 'Yuzhnyy-Kospashskiy', 'Yuzhnyy-Kospashskiy', 'Juzhnyj Kospashskij,Juzhnyj-Kospashskij,Juzjnyj Kospasjskij,Yuzhnyy-Kospashskiy,Южный Коспашский,Южный-Коспашский', 58.9725000, 57.7590000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118868, 'Yuzhno-Sukhokumsk', 'Yuzhno-Sukhokumsk', 'Gorad Juzhna-Sukhakumsk,Ioujno-Soukhokoumsk,Jujno-Suhokumsk,Juschno-Suchokumsk,Juzhno-Sukhokums''k,Juzhno-Sukhokumsk,Juzjno-Suchokumsk,Juzjno-Sukhokumsk,Juzno-Suchokumsk,Juzno-Suhhokumsk,Juzno-Suhokumsk,Juĵno-Suĥokumsk,Južno-Suchokumsk,Južno-Suhhokumsk,Južno-Suhokumsk,K''ible-Sukhokumsk,Kantar Sukhokumsk,Suvisuhokumsk,Yuzhno-Sukhokumsk,nan su huo ku mu si ke,ywjnw-swkhwkwmsk,ywzhnw-swkhwkwmsk,Јужно-Сухокумск,Горад Южна-Сухакумск,Кăнтăр Сухокумск,Кьибле-Сухокумск,Южно-Сухокумск,Южно-Сухокумск балһсн,Южно-Сухокумськ,يوجنو-سوخوكومسك,یوژنو-سوخوکومسک,南蘇霍庫姆斯克', 44.6581100, 45.6436000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118869, 'Yuzha', 'Yuzha', 'Juzha,Juzja,Yuzha,Южа', 56.5830600, 42.0122200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118870, 'Yushkozero', 'Yushkozero', 'Jushkozero,Jusjkozero,Jyskyjaervi,Jyskyjarvi,Jyskyjärvi,Jyškyjärvi,Yushkozero,Юшкозеро', 64.7516200, 32.1025500, 'RU', '2015-12-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118871, 'Yuryuzan’', 'Yuryuzan''', 'Jurjuzan,Jurjuzan'',Yuryuzan'',Yuryuzan’,Юрюзань', 54.8633300, 58.4219400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118872, 'Yur’yev-Pol’skiy', 'Yur''yev-Pol''skiy', 'Jur''ev-Pol''skij,Jurjev-Polskij,Yur''yev-Pol''skiy,Yurev Polski,Yur’yev-Pol’skiy,Юрьев-Польский', 56.5033900, 39.6791100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118873, 'Yur’yevets', 'Yur''yevets', 'Jur''evec,Jurjevets,Yur''yevets,Yurevets,Yur’yevets,Юрьевец', 57.3200700, 43.1041000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118874, 'Yurovka', 'Yurovka', 'Jurovka,Pervomayskoye,Yur''yevka,Yurovka,Yur’yevka,Юровка', 45.1147000, 37.4188200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118875, 'Yurla', 'Yurla', 'Jurla,Yurla,Yurlya,Юрла', 59.3251000, 54.3278000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118876, 'Yurino', 'Yurino', 'Jurino,Yurino,Юрино', 56.2941700, 46.3039200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118877, 'Yumaguzino', 'Yumaguzino', 'Jumaguzino,Yumaguzino,Юмагузино', 52.9041200, 56.3932900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118878, 'Yukhnov', 'Yukhnov', 'Jukhnov,Yukhnov,Юхнов', 54.7444400, 35.2297200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118879, 'Yukamenskoye', 'Yukamenskoye', 'Jukamenskoe,Jukamenskoje,Yukamenskoye,Юкаменское', 57.8878000, 52.2450000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118880, 'Yugo-Kamskiy', 'Yugo-Kamskiy', 'Jugo-Kamskij,Yugo-Kamskiy,Юго-Камский', 57.7026000, 55.5904000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118881, 'Yuganets', 'Yuganets', 'Juganec,Juganets,Yuganets,Юганец', 56.2508000, 43.2306900, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118882, 'Yug', 'Yug', 'Jug,Yug,Yugovskiy,Yugovskoy,Yugovskoye,Юг', 57.7293000, 56.1720000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118883, 'Yubileynyy', 'Yubileynyy', 'Jubilejnyj,Yubileynyy,Юбилейный', 58.7794000, 57.7822000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118884, 'Yoshkar-Ola', 'Yoshkar-Ola', 'Iochkar-Ola,Ioshkar Ola,JOK,Joschkar-Ola,Joshkar-Ola,Josjkar-Ola,Joskar-Ola,Joszkar-Ola,Joszkar-Oła,Joŝkar-Ola,Joškar-Ola,Tsarevokokshaysk,Yoshkar-Ola,yosikaleuolla,Йошкaр-Ола,Йошкар-Ола,יושקר-אולה,ヨシュカル・オラ,요시카르올라', 56.6387700, 47.8907800, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118885, 'Yeyskoye Ukrepleniye', 'Yeyskoye Ukrepleniye', 'Ejskoe Ukreplenie,Yeyskoye Ukrepleniye,Ейское Укрепление', 46.7063000, 38.6121000, 'RU', '2012-05-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118886, 'Yeysk', 'Yeysk', 'EIK,Eisk,Ejs''k,Ejsk,Gorad Ejsk,Ieisk,Ieïsk,Jeisk,Jejsk,Jejsko,Yeisk,Yeysk,Yiesk,eisuku,ye yi si ke,yeiseukeu,yysk,yysm,Єйськ,Јејск,Горад Ейск,Ейск,ييسك,ییسم,ییسک,エイスク,葉伊斯克,예이스크', 46.7055000, 38.2739000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118887, 'Yessentukskaya', 'Yessentukskaya', 'Essentukskaja,Jessentukskaja,Yessentukskaya,Ессентукская', 44.0328000, 42.8813000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118888, 'Yessentuki', 'Yessentuki', 'Essentuki,Jessentuki,Yessentaki,Yessentuki,Ессентуки', 44.0444400, 42.8605600, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118889, 'Yertsevo', 'Yertsevo', 'Ercevo,Ertsevo,Jertsevo,Yertsevo,Ерцево', 60.7966000, 40.0860000, 'RU', '2013-06-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118890, 'Yershovo', 'Yershovo', 'Ershovo,Yershovo,Ершово', 55.7691100, 36.8592900, 'RU', '2012-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118891, 'Yershov', 'Yershov', 'Ershov,Ersov,Eršov,Gorad Jarshou,Ierchov,Ierxov,Jerschow,Jershov,Jersjov,Jersov,Jersow,Jerŝov,Jeršov,Jeršow,Yershov,Yershovo,Yersov,Yerşov,ye er shao fu,yrshwf,yyrshwf,Єршов,Јершов,Горад Яршоў,Ершов,Ершов балһсн,ييرشوف,یرشوف,葉爾紹夫', 51.3513000, 48.2766000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118892, 'Yershichi', 'Yershichi', 'Ershichi,Jersjitsji,Yershichi,Ершичи', 53.6725000, 32.7541700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118893, 'Yermolino', 'Yermolino', 'Ermolino,Opytnoye Khozyaystvo Yermolino,Poselok Opytno-Pokazatel''nogo Khozyaystva Yermolino,Posëlok Opytno-Pokazatel’nogo Khozyaystva Yermolino,Yermolino,Ермолино', 56.1488700, 37.4911200, 'RU', '2014-10-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118894, 'Yermolino', 'Yermolino', 'Ermolino,Jermolino,Yermolino,Ермолино', 55.1948900, 36.5951300, 'RU', '2012-02-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118895, 'Yermolayevo', 'Yermolayevo', 'Ermolaevo,Jermolajevo,Yermolayevka,Yermolayevo,Ермолаево', 52.7166700, 55.8000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118896, 'Yermish’', 'Yermish''', 'Ermish'',Jermisj,Yermish'',Yermish’,Ермишь', 54.7677800, 42.2711100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118897, 'Yermekeyevo', 'Yermekeyevo', 'Ermekeevo,Ermeneevo,Yermekeyevo,Yermikeyevo,yyrmykyyfw,Ермекеево,Ерменеево,Йәрмәкәй,Ярмәкәй,Երմեկեևո,ييرميكييفو', 54.0761400, 53.6712500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118898, 'Yepifan’', 'Yepifan''', 'Epifan'',Epufan,Jepifan,Yepifan'',Yepifan’,Yepinfan'',Yepinfan’,Епифань', 53.8252600, 38.5518100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118899, 'Yenotayevka', 'Yenotayevka', 'Ekataevsk,Enotaevka,Jenotajevka,Yenotayevka,Yenotayevsk,Енотаевка', 47.2455900, 47.0281400, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118900, 'Yemva', 'Yemva', 'Yemva,Zheleznodorozhnyj,Zheleznodorozhnyy,Zjeleznodorozjnyj,Железнодорожный', 62.5899900, 50.8593900, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118901, 'Yemtsa', 'Yemtsa', 'Emca,Jemtsa,Yemtsa,Емца', 63.0733700, 40.3328500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118902, 'Yemetsk', 'Yemetsk', 'Emeck,Yemetsk,Емецк', 63.4719100, 41.7802300, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118903, 'Yelshanka', 'Yelshanka', 'Elshanka,Jelsjanka,Yelshanka,Елшанка', 51.8138900, 46.3997200, 'RU', '2014-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118904, 'Yelovo', 'Yelovo', 'Elovo,Jelovo,Yelovo,Елово', 57.0538100, 54.9207000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118905, 'Yel’nya', 'Yel''nya', 'El''nja,Elna,Elnya,Jelnja,Yel''nya,Yel’nya,Ельня', 54.5786400, 33.1837300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118906, 'Yëlkino', 'Yelkino', 'Elkino,Jelkino,Yelkino,Yëlkino,Ëлкино,Елкино', 58.6922000, 59.8320000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118907, 'Yelkhovka', 'Yelkhovka', 'Elkhovka,Jelkhovka,Yelkhovka,Елховка', 53.8666800, 50.2831900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118908, 'Yelizavetinskoye', 'Yelizavetinskoye', 'Elizavetinskoe,Jelizavetinskoje,Yelizavetinskoye,Елизаветинское', 45.0072200, 43.3494400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118909, 'Yelizavetinskaya', 'Yelizavetinskaya', 'Elizavetinskaja,Jelisawetinskaja,Jelizavetinskaja,Yelizavetinskaya,Елизаветинская', 45.0461600, 38.7949100, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118910, 'Yelizavetino', 'Yelizavetino', 'Elizavetino,Jelisavettina,Jelizavetino,Yelizavetino,Елизаветино', 59.4917300, 29.7815300, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118911, 'Yelizavetinka', 'Yelizavetinka', 'Elizavetinka,Jelizavetinka,Yelizavetinka,Yelizavetinski,Yelizavetinskiy,Елизаветинка', 51.7722000, 59.7335000, 'RU', '2014-07-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118912, 'Yelets', 'Yelets', 'Elec,Elec'',Elecum,Elet,Eleț,Gorad Jalec,Ielets,Jelec,Jelecas,Jelets,Jelez,Yelets,eretsu,ye lie ci,yellecheu,ylts,yylyts,yylz,Єлець,Јелец,Горад Ялец,Елец,Елец балһсн,יילץ,ييليتس,یلتس,ییلیتس,エレツ,叶列茨,옐레츠', 52.6236600, 38.5016900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118913, 'Yel’digino', 'Yel''digino', 'El''digino,Shkol''nyy,Shkol’nyy,Yel''digino,Yel’digino,Ельдигино', 56.1166700, 37.8166700, 'RU', '2014-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118914, 'Yelat’ma', 'Yelat''ma', 'Elat''ma,Jelatma,Yelat''ma,Yelat’ma,Елатьма', 54.9675000, 41.7508300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118915, 'Yelan’-Kolenovskiy', 'Yelan''-Kolenovskiy', 'Elan''-Kolenovskij,Yelan''-Kolenovskiy,Yelan’-Kolenovskiy,Елань-Коленовский', 51.1632000, 41.1510000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118916, 'Yelan’-Koleno', 'Yelan''-Koleno', 'Elan''-Koleno,Yelan''-Koleno,Yelan’-Koleno,Елань-Колено', 51.1523000, 41.2306000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118917, 'Yelan’', 'Yelan''', 'Elan'',Jelan,Yelan'',Yelan’,Елань', 50.9490000, 43.7378100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118918, 'Yelabuga', 'Yelabuga', 'Alabuga,Elabuga,Jelaboega,Jelabuga,Yelabuga,Јелабуга,Алабуга,Елабуга', 55.7612700, 52.0649300, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118919, 'Yekimovichi', 'Yekimovichi', 'Ekimovichi,Jekimovitsji,Yekimovichi,Екимовичи', 54.1128500, 33.2964800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118920, 'Yekaterinovka', 'Yekaterinovka', 'Ekaterinovka,Jekaterinovka,Yekaterinovka,Екатериновка', 52.0508300, 44.3451500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118921, 'Yegor’yevsk', 'Yegor''yevsk', 'Egor''ev,Egor''evsk,Egorievsk,Egor’ev,Jegorjevsk,Jegorjewsk,Yegor''yevsk,Yegorevsk,Yegor’yevsk,Егорьевск', 55.3828300, 39.0323300, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118922, 'Yegorlykskaya', 'Yegorlykskaya', 'Egorlykskaja,Jegorlykskaja,Yegorlkskaya,Yegorlykskaya,Егорлыкская', 46.5656400, 40.6562100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118923, 'Yefremov', 'Yefremov', 'Efremov,Iefremov,Jefremov,Jefremow,Jefriemow,Yefremov,Yefrémov,i~efuremofu,ye fu lie mo fu,yepeulemopeu,yfrmwf,yyfrymwf,Ефремов,ييفريموف,یفرموف,イェフレーモフ,葉夫列莫夫,예프레모프', 53.1480600, 38.0992400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118924, 'Yefimovskiy', 'Yefimovskiy', 'Efimovskij,Jefimovskij,Jefimowskoje,Yefimova,Yefimovskaya,Yefimovskiy,Ефимовский', 59.4963900, 34.6722200, 'RU', '2016-08-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118925, 'Yedrovo', 'Yedrovo', 'Edrovo,Jedrovo,Jedrowo,Yedrovo,Едрово', 57.9130600, 33.6202800, 'RU', '2016-05-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118926, 'Yazykovo', 'Yazykovo', 'Jazykovo,Yazykovo,Языково', 55.2198800, 56.1353200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118927, 'Yazykovo', 'Yazykovo', 'Jazykovo,Yazykovo,Языково', 54.2922000, 47.3891000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118928, 'Yayva', 'Yayva', 'Jajva,Yayva,Яйва', 59.3347000, 57.2592000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118929, 'Yavas', 'Yavas', 'Javas,Yavas,Явас', 54.4159000, 42.8491000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118930, 'Yasnyy', 'Yasnyy', 'Jasnyj,Yasnyy,Ясный', 51.0333000, 59.8742000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118931, 'Yasnogorsk', 'Yasnogorsk', 'Jasnogorsk,Laptevo,Laptëvo,Yasnogorsk,Ясногорск', 54.4808200, 37.6985400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118932, 'Yashkul’', 'Yashkul''', 'Jaschkul,Jashkul'',Jasjkul,Peschanoye,Yashkul'',Yashkuly,Yashkul’,Яшкуль', 46.1711000, 45.3435000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118933, 'Yashalta', 'Yashalta', 'Esto-Khaginka,Esto-Khaginskoe,Jashalta,Jasjalta,Stepnoye,Yashalta,Яшалта', 46.3395000, 42.2762000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118934, 'Yasenskaya', 'Yasenskaya', 'Iasenskaia,Jasenskaja,Stanitsa Yasenskaya,Yasenka,Yasenskaya,Ясенская', 46.3592000, 38.2690000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118935, 'Yasenevo', 'Yasenevo', 'Jasenevo,Yasenevo,Ясенево', 55.6068600, 37.5199100, 'RU', '2014-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118936, 'Yartsevo', 'Yartsevo', 'Jarcevo,Jartsevo,Yartseva,Yartsevo,Ярцево', 55.0666700, 32.6963900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118937, 'Yaroslavskaya', 'Yaroslavskaya', 'Jaroslavskaja,Yaroslavskaya,Yaroslavskoye,Ярославская', 44.6105600, 40.4641700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118938, 'Yaroslavl', 'Yaroslavl', 'Giaroslavl,Gorad Jaraslaul'',IAR,Iaroslavia,Iaroslavl,Jaroslavelj,Jaroslavl,Jaroslavl'',Jaroslavl'' osh,Jaroslavla,Jaroslavlis,Jaroslavlj,Jaroslavul,Jaroslavļa,Jaroslavľ,Jaroslaw,Jaroslawl,Jaroszlavl,Jarosław,Yaroslavl,iaroslavli,ya luo si la fu er,ya ro sla fl,yaloseullabeul,yaroslava,yarosuravuri,yarwslafl,yarwslawl,yrwslbl,Γιαροσλάβλ,Јарослављ,Горад Яраслаўль,Ярославль,Ярославль ош,Ярославъл,Յարոսլավլ,ירוסלבל,ياروسلافل,یاروسلاول,यरोस्लाव,यारोस्लाव,ยาโรสลาฟล์,იაროსლავლი,ヤロスラヴリ,雅罗斯拉夫尔,야로슬라블', 57.6298700, 39.8736800, 'RU', '2016-12-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118939, 'Yaroslavichi', 'Yaroslavichi', 'Jaroslavichi,Vil''hal,Vilhala,Vil’hal,Yaroslavichi,Яросла́вичи', 60.4927500, 34.5080600, 'RU', '2017-02-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118940, 'Yaropolets', 'Yaropolets', 'Jaropolec,Jaropolets,Yaropolets,Ярополец', 56.1333300, 35.8331700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118941, 'Yarensk', 'Yarensk', 'Jarensk,Severnyy,Yarensk,Яренск', 62.1675500, 49.0916200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118942, 'Yarega', 'Yarega', 'Jarega,Yarega,Ярега', 63.4354300, 53.5765000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118943, 'Yaransk', 'Yaransk', 'Jaransk,Yaransk,Яранск', 57.3033100, 47.8861100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118944, 'Yar', 'Yar', 'Jar,Yar,Яр', 58.2458000, 52.1054000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118945, 'Yantikovo', 'Yantikovo', 'Jantikovo,Yantikovo,Янтиково', 55.8215800, 47.9103600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118946, 'Yanis’yarvi', 'Yanis''yarvi', 'Iyanisyarven,Jaenisjaervi,Janis"jarvi,Janisiarvi,Jänisjärvi,Yanis''yarvi,Yanis’yarvi,Янисъярви', 61.8912700, 30.9484900, 'RU', '2012-12-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118947, 'Yanishpole', 'Yanishpole', 'Jaenispelto,Jaenispuoli,Janishpole,Janisjpole,Jänispelto,Jänišpuoli,Yanezh-Pole,Yanishpole,Янишполе', 62.1109500, 34.2701300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118948, 'Yandyki', 'Yandyki', 'Jandyki,Yandyki,Яндыки', 45.7691300, 47.1257700, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118949, 'Yanaul', 'Yanaul', 'Janaul,Yanaul,Янаул', 56.2751000, 54.9338000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118950, 'Novaya Maka', 'Novaya Maka', 'Ashaga-Maka,Novaja Maka,Novaya Maka,Yanankala,Новая Мака', 41.7717300, 48.3614900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118951, 'Yamkino', 'Yamkino', 'Jamkino,Yamkino,Ямкино', 55.9208800, 38.4041700, 'RU', '2010-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118952, 'Yam', 'Yam', 'Jam,Starry Frolovskiy Yam,Stary Yam,Staryy Yam,Yam,Ям', 55.4878500, 37.7445800, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118953, 'Yalkhoy-Mokhk', 'Yalkhoy-Mokhk', 'Jalhoj-Mohk,Jalkhoj-Mokhk,Tlyadal,Yalkhoy-Mokhk,Ялхой-Мохк', 43.1052800, 46.1904500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118954, 'Yaksatovo', 'Yaksatovo', 'Jaksatovo,Yaksatovo,Яксатово', 46.2434300, 48.0151400, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118955, 'Yakovlevskoye', 'Yakovlevskoye', 'Jakovlevskoe,Jakovlevskoje,Yakovlevskaya,Yakovlevskoye,Yakovleyskoye,Яковлевское', 55.4419400, 37.9480600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118956, 'Yakovlevo', 'Yakovlevo', 'Jakovlevo,Mustamaeki,Mustamaki,Mustamyaki,Mustamäki,Yakovlevo,Яковлево', 60.2940900, 29.4880000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118957, 'Yakovlevo', 'Yakovlevo', 'Jakovlevo,Yakovlevo,Яковлево', 50.8603300, 36.4478400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118958, 'Yakhroma', 'Yakhroma', 'Jakhroma,Yakhroma,Яхрома', 56.3000000, 37.4833300, 'RU', '2014-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118959, 'Yagry', 'Yagry', 'Jagry,Yagry,Ягры', 64.5941700, 39.8102800, 'RU', '2015-06-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118960, 'Yadrin', 'Yadrin', 'Jadrin,Yadrin,Ядрин', 55.9405200, 46.2062200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118961, 'Yablonovskiy', 'Yablonovskiy', 'Jablonovskij,Yablonovskiy,Яблоновский', 44.9890100, 38.9432400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118962, 'Vyyezdnoye', 'Vyyezdnoye', 'Vyezdnoe,Vyezdnoje,Vyyezdnoye,Выездное', 55.3815400, 43.7863800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118963, 'Vytegra', 'Vytegra', 'Vitegr,Vitegra,Votegra,Vytegra,Võtegra,Wytegra,Wytiegra,fytyghra,wei jie ge la,wytgra,Витегра,Вытегра,فيتيغرا,ویتگرا,維捷格拉', 61.0063600, 36.4481100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118964, 'Vysotskoye', 'Vysotskoye', 'Visatskoe,Vysockoe,Vysotskoje,Vysotskoye,Высоцкое', 45.0250000, 42.9063900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118965, 'Vysotsk', 'Vysotsk', 'Gorad Vysock,Trangsund,Transund,Tranzund,Trongsund,Trongzund,Trångsund,Uras,Uras-Trongsund,Uuraa,Uuras,Visoc''k,Visock,Visocka,Visotsk,Vossotsk,Vysock,Vysotsk,Vyssotsk,Võssotsk,Vısotsk,Wysock,Wyssozk,bisocheukeu,fyswtsk,wei suo ci ke,wyswtsk,Висотск,Висоцк,Висоцьк,Высоцк,Горад Высоцк,Тронгзунд,Уурас,فيسوتسك,ویسوتسک,ვისოცკი,維索茨克,비소츠크', 60.6287900, 28.5704800, 'RU', '2016-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118966, 'Vysokovsk', 'Vysokovsk', 'Visokovs''k,Visokovsk,Vysokovsk,Vysokovskaj,Vysokovskiy,Vyssokovsk,Vısokovsk,Wysokowsk,Wyssokowsk,fyswkwfsk,wei suo ke fu si ke,wyswkwfsk,wyswkwwsk,Високовск,Високовськ,Высоковск,Высоковск балһсн,Высоковскай,فيسوكوفسك,ویسوکوفسک,ویسوکووسک,維索科夫斯克', 56.3166700, 36.5500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118967, 'Vysokinichi', 'Vysokinichi', 'Vysokinichi,Vysokinitsji,Высокиничи', 54.9092800, 36.9314800, 'RU', '2013-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118968, 'Vysokaya Gora', 'Vysokaya Gora', 'Vysokaja Gora,Vysokaya Gora,Высокая Гора', 55.9127800, 49.3016700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118969, 'Vyshniy Volochëk', 'Vyshniy Volochek', 'Vyshnij Volochek,Vyshniy Volochek,Vyshniy Volochëk,Vysjnij Volotsjek,Wyschni-Wolotschek,Вышний Волочек', 57.5912500, 34.5645300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118970, 'Vyshneye Dolgoye', 'Vyshneye Dolgoye', 'Dolgaja,Dolgaya,Dolgoye,Vyshnedolgoye,Vyshnee Dolgoe,Vyshneye Dolgoye,Vysjneje Dolgoje,Вышнее Долгое', 52.0630200, 37.4051800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118971, 'Vyshkov', 'Vyshkov', 'Vyshkov,Vysjkov,Вышков', 52.4764000, 31.6873000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118972, 'Vysha', 'Vysha', 'Vysha,Vysja,Выша', 53.8476800, 42.3776600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118973, 'Vyselki', 'Vyselki', 'Byselki,Novosuvorovskaya,Novosuvorovskoye,Vyselki,Выселки', 45.5812800, 39.6640900, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118974, 'Vyritsa', 'Vyritsa', 'Viiricca,Viiritsa,Viiričča,Virica,Voritsa,Vyrica,Vyritsa,Võritsa,Wyriza,fyrytsa,Вирица,Вырица,فيريتسا', 59.4077800, 30.3480600, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118975, 'Vypolzovo', 'Vypolzovo', 'Vypolzovo,Выползово', 57.8766700, 33.6986100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118976, 'Vyksa', 'Vyksa', 'Gorad Vyksa,Viksa,Vyksa,Vîksa,Vıksa,Wyksa,bigsa,fyksa,wei ke sa,wyksa,Викса,Выкса,Горад Выкса,فيكسا,ویکسا,維克薩,빅사', 55.3175000, 42.1744400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118977, 'Vykhino-Zhulebino', 'Vykhino-Zhulebino', 'Vykhino,Vykhino-Zhulebino,Выхино-Жулебино', 55.7019600, 37.8117800, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118978, 'Vygonichi', 'Vygonichi', 'Vygonichi,Vygonitsji,Выгоничи', 53.0985500, 34.0672800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118979, 'Vydropuzhsk', 'Vydropuzhsk', 'Vydropusk,Vydropuzhsk,Vydropuzjsk,Выдропужск', 57.3647000, 34.8428700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118980, 'Vychegodskiy', 'Vychegodskiy', 'Vychegodskij,Vychegodskiy,Vytsjegodskij,Вычегодский', 61.2470200, 46.8984200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118981, 'Vyborg', 'Vyborg', 'Gorad Vybarg,VBR,Viborg,Viborga,Viborgas,Viburgum,Viiburi,Viipuri,Vimpornk,Vioborg,Vipuri,Vyborg,Vyborg osh,Vyborgas,Víborg,Víobórg,Vîborg,Wiborg,Wyborg,biboleukeu,fybwrgh,viborgi,vu~iborugu,wei bao,wybwrg,Βίμποργκ,Виборг,Виипури,Выборг,Выборг ош,Вꙑборгъ,Горад Выбарг,ויבורג,فيبورغ,ویبورگ,ვიბორგი,ヴィボルグ,维堡,비보르크', 60.7076300, 28.7528300, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118982, 'Vybor', 'Vybor', 'Vybor,Выбор', 57.2271600, 29.1663000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118529, 'Kovilj', 'Kovilj', 'Alsokabol,Alsokovil,Alsókabol,Alsókovil,Dolnji Kovilj,Donji Kovilj,Felso-Kovil,Felsokabol,Felső-Kovil,Felsőkabol,Gornji-Kovil,Gornji-Kovilj,Kabol,Kovilj,Ober-Kovil,Unter-Kovil', 45.2342200, 20.0232700, 'RS', '2012-08-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118530, 'Kovačica', 'Kovacica', 'Antalfalva,Covacita,Covăcița,Kovachica,Kovacica,Kovacsica,Kovacsicza,Kovaĉica,Kovačica,Kowatschitza,ke wa qi cha,kwwachycha,Ковачица,کوواچیچا,科瓦契察', 45.1116700, 20.6213900, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118531, 'Konak', 'Konak', 'Conak,Kanak,Konak', 45.3157500, 20.9146800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118532, 'Knićanin', 'Knicanin', 'Knicanin,Knićanin', 45.1867500, 20.3190000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118533, 'Klek', 'Klek', 'Begafo,Bégafő,Kleck,Klek,Klekk', 45.4225400, 20.4804900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118534, 'Kladovo', 'Kladovo', 'Cladova,Fethulislam,Kladovo,ke la duo wo,kladwwa,Кладово,کلادووا,克拉多沃', 44.6066700, 22.6119400, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118535, 'Kikinda', 'Kikinda', 'Chichinda Mare,Gross-Kikinda,Kikinda,Kikinta,Kokend,Kökénd,Nagykikinda,Velika Kikinda,ji jin da,kikinda,kyknda,kykynda,qyqyndh,Κίκιντα,Кикинда,קיקינדה,کیکندا,کیکیندا,キキンダ,基金达,키킨다', 45.8297200, 20.4652800, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118536, 'Kanjiža', 'Kanjiza', 'Alt-Kanischa,Kanizha,Kanizsa,Kanjija,Kanjiza,Kanjiĵa,Kanjiža,Magyarkanizsa,Pavlovgrad,Stara Kanjiza,Stara Kanjiža,Ungarisch-Kanischa,Ungarische Kanischa,ka ni zha,kanyyzha,Канижа,Каніжа,Кањижа,קיניזשא,کانییژا,卡尼扎', 46.0666700, 20.0500000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118537, 'Jermenovci', 'Jermenovci', 'Irmenjhaza,Jermenovci,Urmenhausen,Urmenyhaza,Ürmenyhaza,Ürményháza', 45.1863500, 21.0455000, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118538, 'Jazovo', 'Jazovo', 'Hodegyhaz,Hodegyhaza,Hodics,Hódegyház,Hódegyháza,Jasowo,Jaszova,Jazova,Jazovo,Jászova,Jázova,Jázovó', 45.8987600, 20.2213000, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118539, 'Jaša Tomić', 'Jasa Tomic', 'Deutsch-Modos,Jasa Tomic,Jaša Tomić,Modos,Módos,Nemet-Modos,Német-Módos,Racz-Modos,Rácz-Módos,Serbish-Modos,Szerb-Modos,Szerb-Módos', 45.4472500, 20.8554600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118540, 'Jarkovac', 'Jarkovac', 'Arkod,Jarkovac,Jarkovacz,Jarkovácz,Jarkowatz,Árkod', 45.2698500, 20.7607800, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118541, 'Janošik', 'Janosik', 'Janosik,Janošik,Slovacki-Aleksandrovac,Slovački-Aleksandrovac,Ujsandorfalva,Újsándorfalva', 45.1714100, 21.0065800, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118542, 'Jagodina', 'Jagodina', 'Giankontina,Jagodina,Svetozarevo,ya ge ding na,yaghwdyna,yaghwdynh,yagodina,yagwdyna,Γιάγκοντινα,Јагодина,Ягодина,ياغودينا,یاغودینه,یاگودینا,یاگۆدینا,ヤゴディナ,雅戈丁那,야고디나', 43.9771300, 21.2612100, 'RS', '2013-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118543, 'Izbište', 'Izbiste', 'Isbischte,Izbiste,Izbište', 45.0225300, 21.1838800, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118544, 'Ivanjica', 'Ivanjica', 'Ivanica,Ivanjica,aywanycha,yi wan ni cha,Иваница,Ивањица,ایوانیچا,伊萬尼察', 43.5802800, 20.2311100, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118545, 'Inđija', 'Ingija', 'India,Indija,Indjija,Indzhija,Indzija,Indžija,Ingija,Ingyia,Inđija,Inĝija,andya,aynjyya,injiya,yin ji ya,yyndya,Інджія,Инджия,Инђија,Инѓија,ئیندیا,اندیا,اینجییا,インジヤ,因吉亚,인지야', 45.0481600, 20.0816500, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118546, 'Ilandža', 'Ilandza', 'Ilancsa,Ilandza,Ilandža,Ilangea,Illancs,Illancsa,Ilonc,Iloncz,Iláncsa', 45.1689700, 20.9200800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118547, 'Idvor', 'Idvor', 'Idvor,Torontaludvar,Torontáludvar', 45.1889500, 20.5144200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118548, 'Tiszahegyes', 'Tiszahegyes', 'Hegyes,Idjos,Idjoš,Idos,Iđoš,Tiszahegyes', 45.8264800, 20.3179100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118549, 'Hetin', 'Hetin', 'Heteny,Hetin,Hettin,Hetény,Tamasfalva,Tamásfalva,Tomsdorf', 45.6620200, 20.7913800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118550, 'Hajdučica', 'Hajducica', 'Ajducica,Ajdučica,Haiducita,Haiduciţa,Hajducica,Hajduschitza,Hajdusicz,Hajdusicza,Hajdučica,Heideschutz,Heideschütz,Istvanvolgy,Istvánvölgy', 45.2501000, 20.9601600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118551, 'Gudurica', 'Gudurica', 'Gudurica,Kudricz,Kutas,Kutrica,Temes-Kutas,Temiski Kutas', 45.1681600, 21.4426400, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118552, 'Grocka', 'Grocka', 'Gradska opshtina Grocka,Grocka,Nkrotska,Opstina Grocka,Opština Grocka,ge luo ci ka,ghrwtska,Γκρότσκα,Градска општина Гроцка,Гроцка,غروتسكا,გროცკის მუნიციპალიტეტი,格羅茨卡', 44.6722200, 20.7175000, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118553, 'Grabovac', 'Grabovac', 'Grabovac', 44.6004900, 20.0853900, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118554, 'Gornji Milanovac', 'Gornji Milanovac', 'Gorni Milanovac,Gorni Milanovacas,Gornji Milanovac,ghwrnyy mylanwfats,gwrny mylanwwach,gwrnyy mylanwwas,shang mi la nuo wa ci,Горни Милановац,Горњи Милановац,غورنيي ميلانوفاتس,گورنی میلانوواچ,گورنیی میلانوواس,گۆرنیی میلانۆڤاتس,上米拉諾瓦茨', 44.0260300, 20.4615200, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118555, 'Gornji Breg', 'Gornji Breg', 'Felsohegy,Felsőhegy,Gornji Breg', 45.9199500, 20.0176600, 'RS', '2016-12-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118556, 'Golubinci', 'Golubinci', 'Gollubincze,Golubince,Golubinci', 44.9853300, 20.0633900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118557, 'Golubac', 'Golubac', 'Galamboc,Galambóc,Golubac,Golubacki grad,Golubat,Golubats,Golubački grad,Golubăț,Guevercinlik,Güvercinlik,Nkoloumpats,ge lu bai ke,gwlwbach,Γκόλουμπατς,Голубац,گولوباچ,哥魯拜克', 44.6529600, 21.6319900, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118558, 'Gardinovci', 'Gardinovci', 'Dunagardony,Dunagárdony,Gardinovacz,Gardinovaz,Gardinovce,Gardinovci,Gardinovcze', 45.2035900, 20.1355800, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118559, 'Gadžin Han', 'Gadzin Han', 'Gadzhin khan,Gadzhin-Khan,Gadzin Han,Gadzin Khan,Gadžin Han,Opstina Gadzin Han,Opština Gadžin Han,Гаджин хан,Гаджин-Хан,Гаџин Хан,گادزن ہان,გაჯინ-ხანის მუნიციპალიტეტი', 43.2227800, 22.0319400, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118560, 'Farkaždin', 'Farkazdin', 'Farkasd,Farkasdhin,Farkazdin,Farkaždin', 45.1917200, 20.4723900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118561, 'Elemir', 'Elemir', 'Elemir,Felsoelemer,Felsőelemér,Nemacki Elemir,Nemački Elemir,Serbisch-Elemir,Srpski Elemir', 45.4426300, 20.3000300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118562, 'Ečka', 'Ecka', 'Deutsch Etschka,Ecka,Ecska,Ečka,Nemet-Ecska,Német-Écska,Pavlovo,Pavlovo Ecka,Pavlovo Ečka,Écska', 45.3232800, 20.4429400, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118563, 'Ðurđevo', 'Durdevo', 'Djurdjevo,Durdevo,Gjurgjevo,Gyurgyevo,Sajkasgyorgye,Sajkásgyörgye,Ðurđevo', 45.3259100, 20.0653200, 'RS', '2012-08-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118564, 'Duboka', 'Duboka', 'Donja Duboka,Duboka', 44.5222300, 21.7603000, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118565, 'Donji Milanovac', 'Donji Milanovac', 'Don''i Milovac,Donji Milanovac,Доньи Миловац', 44.4641700, 22.1521700, 'RS', '2016-08-03', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118566, 'Doljevac', 'Doljevac', 'Dolevac,Doljevac,Opstina Doljevac,Opština Doljevac,dwlywach,Долевац,Дољевац,دولیواچ,დოლევაცის მუნიციპალიტეტი', 43.1981700, 21.8325800, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118567, 'Dobrica', 'Dobrica', 'Dobrica,Dobricza,Dobritza,Kevedobra', 45.2133900, 20.8499500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118568, 'Dobanovci', 'Dobanovci', 'Dobanovce,Dobanovci,Dobanovcze,Dobanovçe,dwbanwchh,دوبانوچه', 44.8263100, 20.2248700, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118569, 'Dimitrovgrad', 'Dimitrovgrad', 'Caribrod,Dimitrovgrad,Opstina Dimitrovgrad,Opština Dimitrovgrad,Tsaribrod,dimiteulobeugeuladeu,dimitorovugurado,dymytrwfghrad,ji mi te luo fu ge lei,Димитровград,Цариброд,ديميتروفغراد,ディミトロヴグラード,季米特洛夫格勒,디미트로브그라드', 43.0141700, 22.7755600, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118570, 'Despotovac', 'Despotovac', 'Despotovac,Despotovats,dai si bo tuo wa ci,dspwtwwach,dysbwtwfats,Δεσπότοβατς,Деспотовац,دسپوتوواچ,ديسبوتوفاتس,代斯波托瓦茨', 44.0925000, 21.4469400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118571, 'Debeljača', 'Debeljaca', 'Debeljaca,Debeljača,Torontalvasarhely,Torontálvásárhely', 45.0707000, 20.6015300, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118572, 'Čurug', 'Curug', 'Csurog,Curug,Čurug', 45.4722100, 20.0686100, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118573, 'Ćuprija', 'Cuprija', 'Chuprija,Cuprija,Tsoupria,chwprya,qiu pu li ya,swpryya,Ćuprija,Τσούπρια,Ћуприја,Чуприя,سوپرئیا,چوپریا,丘普里亚', 43.9275000, 21.3700000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118574, 'Čukarica', 'Cukarica', 'Chukarica,Cukarica,Czukarica,Gradska opshtina Chukarica,Opstina Cukarica,Opština Čukarica,Tsoukaritsa,qiu ka li cha,Čukarica,Τσουκαρίτσα,Градска општина Чукарица,Чукарица,ჩუკარიცის მუნიციპალიტეტი,丘卡里察', 44.7825000, 20.4202800, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118575, 'Crna Trava', 'Crna Trava', 'Crna Trava,chrna trawa,Црна Трава,چرنا تراوا', 42.8098800, 22.2988100, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118576, 'Crepaja', 'Crepaja', 'Crepaja,Cserepalja,Cserépalja,Czrepaj,Czrepaja', 45.0098400, 20.6370200, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118577, 'Čortanovci', 'Cortanovci', 'Cortanovci,Čortanovci', 45.1546000, 20.0185100, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118578, 'Čoka', 'Coka', 'Choka,Coka,Csoka,Csóka,Tschoka,chwka,cuo ka,Ĉoka,Čoka,Чока,چوکا,措卡', 45.9425000, 20.1433300, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118579, 'Ćićevac', 'Cicevac', 'Cicevac,qi qie wa ci,sysywach,Ćićevac,Ћићевац,سیسیواچ,契切瓦茨', 43.7188200, 21.4408500, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118580, 'Čestereg', 'Cestereg', 'Cestereg,Cesterek,Cseszterek,Csosztelek,Csősztelek,Isterek,Neuhatzfeld,Tschestelek,Tschestereg,Čestereg,Česterek', 45.5636100, 20.5319400, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118581, 'Čenta', 'Centa', 'Centa,Csenta,Csentej,Leopoldova,Čenta', 45.1081400, 20.3894700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118582, 'Čačak', 'Cacak', 'Cacak,Cacakas,Chachak,Gorad Chachak,Tsatsak,cha cha ke,cha chak,chachak,chachakeu,chachaku,tshatshak,Čačak,Čačakas,Τσάτσακ,Горад Чачак,Чачак,צאצאק,تشاتشاك,چاچاک,ชาชัก,チャチャク,查查克,차차크', 43.8913900, 20.3497200, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118583, 'Bujanovac', 'Bujanovac', 'Bougianovats,Bujanoci,Bujanovac,Bujanovc,Bujanovce,Bujanovci,bu ya nuo wa ci,buyanobacheu,buyanovu~atsu,bwyanwfats,bwyanwwach,Μπουγιάνοβατς,Буяновац,Бујановац,بويانوفاتس,بویانوواچ,ブヤノヴァツ,布亞諾瓦茨,부야노바츠', 42.4591700, 21.7666700, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118584, 'Botoš', 'Botos', 'Botos,Botosch,Botosh,Botoš,Bottos,Bótos', 45.3083700, 20.6351400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118585, 'Bosilegrad', 'Bosilegrad', 'Bosilegrad,Bosiljgrad,Bosilov-Grad,bo xi lai ge lei,boshiregurado,bosillegeuladeu,bwsylyghrad,bwsylygrad,Босилеград,بوسيليغراد,بوسیلیگراد,ボシレグラード,博西萊格勒,보실레그라드', 42.5011000, 22.4723800, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118586, 'Bor', 'Bor', 'Bor,Boras,Gorad Bor,bo er,boleu,bori,boru,bwr,bwr  srbya,bwr  srbya,Μπορ,Бор,Горад Бор,בור,بور,بور ،سربیا,بور، سربیا,بۆر، سربیا,ბორი,ボル,博尔,보르', 44.0748800, 22.0959100, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118587, 'Boljevci', 'Boljevci', 'Boljevci', 44.7235500, 20.2234800, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118588, 'Boljevac', 'Boljevac', 'Bolevac,Boljevac,Opstina Boljevac,Opština Boljevac,bo lie wa ci,bwlyyfats,bwlyywach,Болевац,Бољевац,بولييفاتس,بولیئواچ,博列瓦茨', 43.8302800, 21.9530600, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118589, 'Boka', 'Boka', 'Boca,Boka,Bóka', 45.3554000, 20.8298700, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118590, 'Bojnik', 'Bojnik', 'Bojnik,bwyynk,Бојник,بوئینک', 43.0122400, 21.7210000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118591, 'Bočar', 'Bocar', 'Bocar,Bocsar,Bocsár,Botschar,Bočar', 45.7699400, 20.2839000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118592, 'Blace', 'Blace', 'Blace,Bllace,Bllacë,blatsy,bu la cai,Блаце,بلاتسي,بلاچے,布拉采', 43.2952800, 21.2858300, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118593, 'Biljača', 'Biljaca', 'Bilace,Bilaçë,Biljaca,Biljace,Biljača,Biljače', 42.3551800, 21.7478100, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118594, 'Beška', 'Beska', 'Beschka,Beska,Besska,Beška', 45.1309200, 20.0669800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118595, 'Belgrade', 'Belgrade', 'BEG,Belehrad,Belgrad,Belgrada,Belgradas,Belgrade,Belgrado,Belgradu,Belgrau,Belgrað,Belgrád,Belgráu,Beligradi,Belogradum,Belohrod,Beograd,Beogradi,Beogrado,Bèlgrade,Bělehrad,Běłohród,Nandorfehervar,Nándorfehérvár,Singidunum,be-ogeuladeu,bei er ge lai de,belgradi,beogurado,blghrad,blgrd,pelkiret,Βελιγράδι,Белград,Београд,Бѣлъ Градъ · Срьбїи,Բելգրադ,בלגרד,بلغراد,بېلگراد,பெல்கிறேட்,ბელგრადი,በልግራድ,ベオグラード,贝尔格莱德,베오그라드', 44.8040100, 20.4651300, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118596, 'Belo Blato', 'Belo Blato', 'Belo Blato,Elisenhain,Elisenheim,Erzsebetlak,Erzsébetlak,Nagyerzsebetlak,Nagyerzsébetlak', 45.2727800, 20.3750000, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118597, 'Belegiš', 'Belegis', 'Belegis,Belegiš', 45.0187300, 20.3321200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118598, 'Bela Palanka', 'Bela Palanka', 'Bela Palanka,Bela palanka,Bela-Palanka,bei la pa lan ka,byla balanka,byla planka,Бела Паланка,Бела паланка,Бела-Паланка,بيلا بالانكا,بیلا پلانکا,貝拉帕蘭卡', 43.2183300, 22.3111100, 'RS', '2012-04-17', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118599, 'Bela Crkva', 'Bela Crkva', 'Bela Crkva,Bela curkva,Bela-Crkva,Biserica Alba,Biserica Albă,Feheregyhaz,Fehertemplom,Fehéregyház,Fehértemplom,Fejeregyhaz,Fejéregyház,Ungarisch Weisskirchen,Weisskirchen,Weißkirchen,bei la ci er ke wa,blh zrqwwh,byla chrkwa,byla tsrkfa,Бела Црква,Бела църква,Бела-Црква,בלה צרקווה,بيلا تسركفا,بیلا چرکوا,貝拉茨爾克瓦', 44.8975000, 21.4172200, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118600, 'Torak', 'Torak', 'Begejci,Kis-Tarnok,Kis-Tárnok,Klein Torak,Mali-Torak,Nagy-Tarnok,Nagy-Tárnok,Torak,Veliki Torak', 45.5092800, 20.6090000, 'RS', '2016-11-03', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118601, 'Bečmen', 'Becmen', 'Becmen,Bečmen', 44.7798300, 20.2057700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118602, 'Bečej', 'Becej', 'Alt-Betsche,Bece,Becej,Becejus,Bechej,Becse,Becsej,Beçe,Beĉej,Bečejus,Obecse,Stari Becej,Stari Bečej,bchy,bechei,bei qie yi,bychyy,bytshy,bzyy,Óbecse,Бечей,Бечеј,בציי,بيتشي,بچی,بیچیی,بێچێی,贝切伊,베체이', 45.6163200, 20.0333100, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118603, 'Batočina', 'Batocina', 'Batochina,Batocina,Batočina,batwchyna,batwtshyna,Баточина,باتوتشينا,باتوچینا,ბატოჩინის მუნიციპალიტეტი', 44.1536100, 21.0816700, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118604, 'Bašaid', 'Basaid', 'Basahid,Basahíd,Basaid,Basajid,Baschaid,Bazsahida,Bazsalhida,Bašahid,Bašaid,Bašajid,Bikac,Bikatsch,Bikač,Bosorhida,Kikinda,Kiskikinda,Klein-Kikinda,Mala Kikinda', 45.6410200, 20.4143400, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118605, 'Barice', 'Barice', 'Barice,Borovice,Sankt Johan,Sveti Jovan,Szentjanos,Szentjános', 45.1818900, 21.0827900, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118606, 'Barič', 'Baric', 'Baric,Barič', 44.6507000, 20.2594100, 'RS', '2012-10-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118607, 'Baranda', 'Baranda', 'Baranda', 45.0845900, 20.4426400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118608, 'Barajevo', 'Barajevo', 'Barajevo', 44.5788900, 20.4158300, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118609, 'Banatsko Veliko Selo', 'Banatsko Veliko Selo', 'Banatsko Veliko Selo,Charleville,Karolyliget,Károlyliget,Saint-Hubert,Sank Hubert,Sarlevil,Sarlevit,Soltur,Sveti Hubert,Szent-Huberth,Szentborbala,Szentborbála,Szenthubert,Veliko Selo,Šarlevil,Šarlevit', 45.8196100, 20.6077200, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118610, 'Banatsko Karađorđevo', 'Banatsko Karadordevo', 'Banatsko Karadordevo,Banatsko Karađorđevo,Karadjordjevo,Karadordevo,Karađorđevo,Magyar-Czerna,Magyar-Czernya,Magyarcsernye,Neu-Zerne,Ungarisch Crnja', 45.5869300, 20.5642100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118611, 'Banatski Karlovac', 'Banatski Karlovac', 'Banat Karlovac,Banatski Karlovac,Banatsko Rankovicevo,Banatsko Rankovićevo,Dragutinovo,Karlovo Selo,Karlsdorf,Karoljfalva,Karolyfalva,Károlyfalva,Nagykarolyfalva,Nagykárolyfalva,Novo Milosevo,Novo Miloševo,Rankovicevo,Rankovićevo', 45.0498700, 21.0180000, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118612, 'Banatski Dvor', 'Banatski Dvor', 'Banater Hof,Banatski Dusanovac,Banatski Dušanovac,Banatski Dvor,Ittvarnok,Szollosudvarnok,Szolosudvarnok,Szőllősudvarnok,Szőlősudvarnok,Torzsudvarnok,Törzsudvarnok', 45.5186600, 20.5114600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118613, 'Banatski Despotovac', 'Banatski Despotovac', 'Banatski Despotovac,Ernesthausen,Erneszthaza,Ernesztháza,Ernohaza,Ernőháza', 45.3660600, 20.6640700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118614, 'Banatska Topola', 'Banatska Topola', 'Banatska Topla,Banatska Topola,Topolya,Toroktopolya,Töröktopolya', 45.6724800, 20.4653000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118615, 'Bačko Petrovo Selo', 'Backo Petrovo Selo', 'Backo Petrovo Selo,Bačko Petrovo Selo,Peterreve,Petrovosello,Petrovoszello,Petrovoszelló,Péterréve', 45.7068100, 20.0792800, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118616, 'Bačko Gradište', 'Backo Gradiste', 'Backo Gradiste,Bacsfoeldvar,Bacsfoldvar,Bačko Gradište,Bácsföldvár,Foeldvar,Foldvar,Földvár,Tisza-Foeldvar,Tisza-Foldvar,Tisza-Földvár', 45.5327100, 20.0308200, 'RS', '2016-10-21', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118617, 'Arilje', 'Arilje', 'Arile,Arilje,a li lie,arylyyh,Ариле,Ариље,آریلیئے,أريلييه,阿里列', 43.7530600, 20.0955600, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118618, 'Aranđelovac', 'Arangelovac', 'Arandzhelovac,Arangjelovac,a lan jie luo wa ci,arandjylwfats,arandylwwach,aranjlwwas,Аранджеловац,Аранђеловац,آرانجلوواس,أراندجيلوفاتس,ئاراندێلۆڤاتس,اراندیلوواچ,阿蘭傑洛瓦茨', 44.3069400, 20.5600000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118619, 'Aradac', 'Aradac', 'Alsoaradi,Alsóaradi,Andrejevac,Andrejevac Aradac,Aradac,Aradatz,Aradaz,Aradec,Aradi,Felsoaradi,Felsőaradi,Racz-Aradacz,Rácz-Aradácz,Slovacki Aradac,Slovački Aradac,Slowakisch-Aradatz,Srpski Aradac,Szerb-Aradacz,Szerb-Aradácz,Szerbaradacz,Szerbaradácz,Tot-Aradacz,Totaradacz,Tót-Aradácz,Tótaradácz', 45.3834600, 20.3013700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118620, 'Alibunar', 'Alibunar', 'Alibunar,Alibunár,Alisbrunn,Allibunar,a li bu nuo er,alybwnar,Алибунар,أليبونار,الیبونار,阿利布諾爾', 45.0808300, 20.9658300, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118621, 'Aleksinac', 'Aleksinac', 'Aleksinac,Alexinatz,a lai ke xi na ci,alksynak,alksynatsh,alyksynach,Алексинац,ألكسيناتش,الکسیناک,الیکسیناچ,阿萊克西納茨', 43.5416700, 21.7077800, 'RS', '2017-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118622, 'Aleksandrovac', 'Aleksandrovac', 'Aleksandrovac,alksandrawak,alyksandrwfats,alyksandrwwach,ya li shan de luo wa ci,Александровац,أليكساندروفاتس,الکساندراواک,الیکساندروواچ,亞歷山德羅瓦茨', 43.4586100, 21.0525000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118623, 'Ada', 'Ada', 'Ada,Asszonyfalva,Ostrova,a da,ada,ada  srbya,Ада,אדא,אדה,آدا,أدا,ادا، سربیا,アダ,阿達,아다', 45.8025000, 20.1258300, 'RS', '2016-01-03', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118624, 'Raška', 'Raska', 'Rashka,Rashke,Rashkë,Raska,Raška,la shen ka,rashka,Рашка,راشکا,拉什卡', 43.2872200, 20.6152800, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118625, 'Niška Banja', 'Niska Banja', 'Nishka Bana,Nishka Banja,ni shen kuang quan cun,Нишка Баня,Нишка Бања,尼什礦泉村', 43.2950700, 22.0057000, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118626, 'Sokolovica', 'Sokolovica', 'Sokolovica', 43.2152800, 20.3155600, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118627, 'Rusko Selo', 'Rusko Selo', 'Kis-Orosz,Kis-Oroszin,Klein-Orossin,Oroszin,Rusko Selo,Ruskodorf,Torontaloroszi,Torontáloroszi', 45.7629100, 20.5711700, 'RS', '2012-07-05', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118628, 'Voždovac', 'Vozdovac', 'Gradska opshtina Vozhdovac,Opstina Vozdovac,Opština Voždovac,Vozdivac,Vozdovac,Vozhdovac,Voždivac,Voždovac,wo ri duo wa ci,Вождовац,Градска општина Вождовац,ვოჟდოვაცის მუნიციპალიტეტი,沃日多瓦茨', 44.7783300, 20.4758300, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118629, 'Zvezdara', 'Zvezdara', 'Opstina Zvezdara,Opština Zvezdara,Zvezdara,zi wei zi da la,Звездара,ზვეზდარის მუნიციპალიტეტი,茲韋茲達拉', 44.7746500, 20.5320700, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118630, 'Prislonica', 'Prislonica', 'Prislonica', 43.9522300, 20.4352100, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118631, 'Knić', 'Knic', 'Knic,Knich,Knić,Opstina Knic,Opština Knić,knys,Книч,Кнић,کنیس,კნიჩის მუნიციპალიტეტი', 43.9269400, 20.7188900, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118632, 'Savski Venac', 'Savski Venac', 'Gradska opshtina Savski venac,Opstina Savski venac,Opština Savski venac,Savski Venac,Savski venac,Savski-Venac,Градска општина Савски венац,Савски Венац,Савски-Венац,სავსკი-ვენაცის მუნიციპალიტეტი', 44.7791700, 20.4538900, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118633, 'Palilula', 'Palilula', '', 44.8116700, 20.5161100, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118634, 'Stari Grad', 'Stari Grad', 'Gradska opshtina Stari grad,Opstina Stari Grad,Opština Stari Grad,Stari Grad,Stari Nkrant Veligradiou,Stari grad,Stari-Grad,jiu ge la de,Στάρι Γκραντ Βελιγραδίου,Градска општина Стари град,Стари град,Стари-Град,სტარი-გრადის მუნიციპალიტეტი,スタリ・グラード,舊格拉德', 44.8178900, 20.4618600, 'RS', '2014-08-01', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118635, 'Zminjak', 'Zminjak', 'Zminjak', 44.7571100, 19.4707000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118636, 'Zmajevo', 'Zmajevo', 'Alt-Keer,Alt-Ker,Altwiesen,Backa Dobra,Bačka Dobra,Gross-Ker,Oker,Pasicevo,Pašićevo,Stari Ker,Zmajevo,Ókér', 45.4540800, 19.6905000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118637, 'Vrdnik', 'Vrdnik', 'Rednek,Rednok,Rednök,Vrdnik,Vrdnik Prnjavor,Врдник', 45.1217400, 19.7922700, 'RS', '2013-05-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118638, 'Vrbas', 'Vrbas', 'Alt-Werbass,Neu-Werbass,Overbasz,Titov Vrbas,Ujverbasz,Verbas,Verbasz,Verbász,Vrbas,Weidenheim,beuleubaseu,frbas,fu er ba si,vrbas,wrbas,Óverbász,Újverbász,Вербас,Врбас,فرباس,ورباس,ڤرباس,弗爾巴斯,브르바스', 45.5713900, 19.6408300, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118639, 'Vladimirci', 'Vladimirci', 'Vladimirci,wladymyrchy,Владимирци,ولادیمیرچی', 44.6147200, 19.7852800, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118640, 'Višnjićevo', 'Visnjicevo', 'Grk,Visnjicevo,Višnjićevo', 44.9673100, 19.2899300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118641, 'Veternik', 'Veternik', 'Ofutak,Veternik,Ófutak', 45.2544600, 19.7588000, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118642, 'Varna', 'Varna', 'Varna', 44.6791400, 19.6515000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118643, 'Valjevo', 'Valjevo', 'QWV,Valevas,Valevo,Valievo,Valjevo,ballebo,falyfw,vu~aryevu~o,wa lie wo,walyfw,walyyww,wayyww,wlyybw,Βάλιεβο,Валево,Ваљево,ולייבו,فاليفو,والیئوو,والیفو,وایئوو,ڤالێڤۆ,ヴァリェヴォ,瓦列沃,발레보', 44.2751300, 19.8982100, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118644, 'Uzveće', 'Uzvece', 'Uzvece,Uzveće', 44.8786100, 19.6035600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118645, 'Užice', 'Uzice', 'Gorad Uzhycy,Oujiste,Ouzhice,Ouzitse,Titovo Uzice,Titovo Užice,UZC,Ussitza,Uzhice,Uzice,Užice,Užicė,awzhytsh,ujiche,ujitsu~e,wu ri ce,xu sit se,Ούζιτσε,Горад Ужыцы,Оужицє,Ужице,ئوژیتسێ,اوژیتسه,اوژیتسے,اوژیچے,อูซีตเซ,ウジツェ,乌日策,우지체', 43.8586100, 19.8487800, 'RS', '2017-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118646, 'Tršić', 'Trsic', 'Trsic,Tršić', 44.4950200, 19.2649000, 'RS', '2016-07-05', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118647, 'Temerin', 'Temerin', 'Temerin,Temerín,Theresienring,tai mei lin,tmryn,tymyrn,Темерин,تمرین,تیمیرن,تێمێرین,ტემერინი,泰梅林', 45.4086100, 19.8891700, 'RS', '2012-04-14', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118648, 'Tabanović', 'Tabanovic', 'Tabanovic,Tabanović', 44.8201800, 19.6412800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118649, 'Subotica', 'Subotica', 'Maria-Theresianopel,Maria-Theresiopel,Maria-Theresiopolis,Sawaditz,Subotica,Subotiza,Szabadka,Szent-Maria,Szent-Mária,Theresiopel,Zubotica,Суботица', 46.1000000, 19.6666700, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118650, 'Štitar', 'Stitar', 'Stitar,Stitor,Štitar', 44.7941500, 19.5952900, 'RS', '2016-12-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118651, 'Stepanovićevo', 'Stepanovicevo', 'Bacskahadikfalva,Bácskahadikfalva,Horthyvara,Horthyvára,Mariamajor,Máriamajor,Stepanovi,Stepanovicevo,Stepanovićevo', 45.4136900, 19.7000000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118652, 'Stanišić', 'Stanisic', 'Deutschwachenheim,Orszallas,Stanischitz,Stanisic,Stanišić,Steinsitz,Sztanisics,Tannenschutz,Tannenschütz,Wachenheim,Őrszállás', 45.9389500, 19.1670900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118653, 'Sremski Karlovci', 'Sremski Karlovci', 'Carlovit,Carloviț,Carolovicia,Gorad Srehmski-Karlaucy,Karloca,Karlocza,Karlofca,Karlofça,Karlovci,Karlovicz,Karloviczi,Karlowice,Karlowitz,Karlóca,Karlócza,Karom,Opstina Sremski Karlovci,Opština Sremski Karlovci,Sremski Karlovci,Sremski Karlovtsi,Sremski-Karlovci,Srijemski Karlovci,seulemseukikaleullobeuchi,si lei mu si ji ka er luo fu qi,srymsky karlwwchy,Σρέμσκι Καρλόβτσι,Горад Срэмскі-Карлаўцы,Сремски Карловци,Сремски-Карловци,سریمسکی کارلووچی,スレムスキ・カルロヴツィ,斯雷姆斯基卡尔洛夫奇,스렘스키카를로브치', 45.2025000, 19.9344400, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118654, 'Sremska Mitrovica', 'Sremska Mitrovica', 'Dimitrofce,Dimitrofçe,Mitraja,Mitrovic,Mitrovica,Mitrovicz,Mitrovicza,Mitrovitza,Mitrowitz,Opstina Sremska Mitrovica,Opština Sremska Mitrovica,Sirmijum,Sirmion,Sirmium,Srem. Mitrovica,Sremska Mitrovica,Srijemska Mitrovica,Strema Mitrovica,Syrmisch-Mitrowitz,Szavaszentdemeter,Szávaszentdemeter,dmtrwfchh,Сирмијум,دمتروفچه', 44.9763900, 19.6122200, 'RS', '2014-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118655, 'Srbobran', 'Srbobran', 'Bacs-Szenttamas,Bács-Szenttamás,Sankt Thomas,Srbobran,Surbobran,Sveti Tomo,Szenttamas,Szenttamás,Thomasberg,si er bo bu lan,srbwbran,Србобран,Сърбобран,سربوبران,斯爾博布蘭', 45.5538900, 19.8027800, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118656, 'Sonta', 'Sonta', 'Sonta,Szond,Szonta,Waldau an der Donau', 45.5942700, 19.0971900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118657, 'Sombor', 'Sombor', 'Coborszentmihaly,Coborszentmihály,Gorad Sombar,Kiszombor,Mezozombor,Mezőzombor,Nagy-Zombor,Opstina Sombor,Opština Sombor,Schomburg,Sombor,Sompor,Szentmihaly,Szentmihály,Zombor,somboleu,sonboru,song bo er,swmbwr,Σόμπορ,Горад Сомбар,Сомбор,סומבור,سومبور,سۆمبۆر,ソンボル,松博尔,솜보르', 45.7741700, 19.1122200, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118658, 'Sjenica', 'Sjenica', 'Senica,Senice,Seniçe,Sjenica,Sjenice,Sjenicë,syynycha,xie ni cha,Сеница,Сјеница,سیئنیچا,謝尼察', 43.2730600, 19.9994400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118659, 'Sinošević', 'Sinosevic', 'Sinosevic,Sinošević', 44.6150300, 19.6360100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118660, 'Šid', 'Sid', 'Shid,Sid,syd,xi de,Ŝid,Šid,Шид,שיד,希德', 45.1283300, 19.2263900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118661, 'Ševarice', 'Sevarice', 'Sevarice,Ševarice', 44.8670400, 19.6600600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118662, 'Šašinci', 'Sasinci', 'Sasinci,Šašinci', 44.9651400, 19.7415100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118663, 'Salaš Noćajski', 'Salas Nocajski', 'Nocajski Salas,Noćajski Salaš,Salas Nocajski,Salaš Noćajski', 44.9472200, 19.5861100, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118664, 'Salaš Crnobarski', 'Salas Crnobarski', 'Crnobarski Salas,Crnobarski Salaš,Salas Crnobarski,Salaš Crnobarski', 44.8284300, 19.3943700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118665, 'Šabac', 'Sabac', 'Boeguerdelen,Böğürdelen,Chabats,Sabac,Sampats,Shabac,Szabacs,Szabács,sha ba ci,shabach,shabas,shabats,shabatsu,syabacheu,Ŝabac,Šabac,Σάμπατς,Шабац,שאבאץ,شاباتس,شاباس,شاباچ,シャバツ,沙巴茨,샤바츠', 44.7466700, 19.6900000, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118666, 'Rumenka', 'Rumenka', 'Piros,Piross,Rumenka', 45.2940000, 19.7430600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118667, 'Ruma', 'Ruma', 'Arpatarlo,Gorad Ruma,Rouma,Ruma,lu ma,luma,ru ma,ruma,rwma,rwma  srbya,rwmh,Árpatarló,Ρούμα,Горад Рума,Рума,רומה,روما,روما ،سربیا,ڕوما,รูมา,ルマ,魯馬,루마', 45.0080600, 19.8222200, 'RS', '2014-10-20', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118668, 'Riđica', 'Ridica', 'Deutsch-Baja,Legin,Regoce,Regocze,Regőce,Regőcze,Ridica,Ridjica,Riedau,Rigicza,Rigyicza,Riđica', 45.9908800, 19.1063500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118669, 'Ribari', 'Ribari', 'Ribari', 44.7096100, 19.4247200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118670, 'Ravno Selo', 'Ravno Selo', 'Alt-Schowe,Nove Sve,Nove Šve,Osove,Ravno,Ravno Selo,Sove,Sové,Stare Sove,Stare Šove,Ujsove,Ósóvé,Újsóvé', 45.4496700, 19.6209700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118671, 'Ravnje', 'Ravnje', 'Ravnje', 44.9432600, 19.4228000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118672, 'Radenković', 'Radenkovic', 'Radenkovic,Radenković', 44.9219100, 19.4954300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118673, 'Putinci', 'Putinci', 'Putince,Putinci,Putincze', 44.9925900, 19.9710200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118674, 'Prnjavor', 'Prnjavor', 'Prnjavor', 44.7006100, 19.3869500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118675, 'Prijepolje', 'Prijepolje', 'Prijepolje', 43.3899600, 19.6487000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118676, 'Prigrevica', 'Prigrevica', 'Bacsszentivan,Batsch-Sentiwan,Bácsszentiván,Priglevicza-Szent-Ivan,Priglevicza-Szent-Iván,Priglewitz,Prigrevica,Prigrevica Sveti Ivan,Prigrevica Sveti Ivon,Sonnhofen,Szent-Ivany,Szent-Ivány', 45.6763600, 19.0880900, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118677, 'Priboj', 'Priboj', 'Opstina Priboj,Opština Priboj,Priboj,peuliboi,prybwyy,pu li bo ye,Прибой,Прибој,پریبوئی,普里波耶,프리보이', 43.5830600, 19.5251900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118678, 'Platičevo', 'Platicevo', 'Platicevo,Platicheva,Platics,Platicseva,Platičevo', 44.8221300, 19.7948700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118679, 'Petrovaradin', 'Petrovaradin', 'Petervarad,Petervaradin,Peterwardein,Petrovaradin,Petrovaradín,Pétervárad,bi de luo wa la ding,peteulobaladin,petorovu~aradin,Петроварадин,პეტროვარადინის მუნიციპალიტეტი,ペトロヴァラディン,彼得罗瓦拉丁,페트로바라딘', 45.2466700, 19.8794400, 'RS', '2015-11-13', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118680, 'Petkovica', 'Petkovica', 'Petkovica', 44.6662700, 19.4392300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118681, 'Pećinci', 'Pecinci', 'Opshtina Pecinci,Opstina Pecinci,Opština Pećinci,Pecinci,Pecinei,Pecjinci,Pecsince,Pećinci,Pećinei,bysnjy,pecinci,pysnchy,pzynzy,Општина Пећинци,פצינצי,بیسنجي,پیسنچی,पेcइन्cइ', 44.9088900, 19.9663900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118682, 'Osečina', 'Osecina', 'Osechina,Osecina,Osečina,awsychyna,Осечина,اوسیچینا,ოსეჩინის მუნიციპალიტეტი', 44.3730600, 19.6013900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118683, 'Odžaci', 'Odzaci', 'Hanfhausen,Hocsak,Hodsag,Hodschach,Hodschag,Hódság,Odjaci,Odzaci,Odzhaci,Odĵaci,Odžaci,ao zha qi,awdzhachy,Оджаці,Оџаци,اودژاچی,奧扎齊', 45.5066700, 19.2611100, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118684, 'Obrovac', 'Obrovac', 'Boroc,Borocz,Boroč,Boróc,Borócz,Obendorf,Obrovac,Obrovacz,Obrovácz,Obrowatz', 45.3210600, 19.3504800, 'RS', '2014-05-29', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118685, 'Novo Selo', 'Novo Selo', 'Novo Selo', 44.6704100, 19.3449500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118686, 'Novi Sad', 'Novi Sad', 'Gorad Novi-Sad,Neoplanta,Neusatz,Novi Sad,Novi Sadas,Novi Sant,Novi-Sad,Novi-Sad khot,Novij Sad,Novisada,Novu Sadu,Novy Sad,Novî Sad,Nový Sad,Nowy Sad,O-petervaradja,Petervarad,Pétervárad,QND,Ujvidek,Varadinum Petri,Vasaros-Varad,Vásáros-Várad,nobisadeu,novhi sada,novi-sadi,nuo wei sa,nwfy sad,nwwy sad,nx wi sad,Ó-péterváradja,Újvidék,Νόβι Σαντ,Горад Нові-Сад,Нови Сад,Нови-Сад,Нови-Сад хот,Новий Сад,Новъ Садъ,Նովի Սադ,נובי סאד,نوفي ساد,نووی ساد,नोव्ही साद,นอวีซาด,ნოვი-სადი,ノヴィ・サド,诺威萨,노비사드', 45.2516700, 19.8369400, 'RS', '2016-05-18', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118687, 'Nova Varoš', 'Nova Varos', 'Nova Varos,Nova Varosh,Nova Varoš,Yeni Varos,Yeni Varoş,xin wa luo shen,Нова Варош,新瓦羅什', 43.4605600, 19.8113900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118688, 'Nikinci', 'Nikinci', 'Nikinci', 44.8501700, 19.8232100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118689, 'Metković', 'Metkovic', 'Metkovic,Metković', 44.8561700, 19.5465400, 'RS', '2015-07-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118690, 'Mali Zvornik', 'Mali Zvornik', 'Mali Zvornik,Mali-Zvornik,Opstina Mali Zvornik,Opština Mali Zvornik,maly zwwrnk,xiao zi wo er ni ke,Мали Зворник,Мали-Зворник,مالی زوورنک,მალი-ზვორნიკის მუნიციპალიტეტი,小茲沃爾尼克', 44.3734400, 19.1065100, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118691, 'Mali Iđoš', 'Mali Igos', 'Kici Hedjes,Kis-Hegyes,Kiči Hedješ,Krivaja,Mali Hedjes,Mali Hedješ,Mali Idjos,Mali Idjoš,Mali Idos,Mali Iđoš', 45.7083300, 19.6652800, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118692, 'Majur', 'Majur', 'Majur', 44.7710500, 19.6551200, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118693, 'Maglić', 'Maglic', 'Buljkes,Bulkes,Bulkesz,Bulkeszi,Maglic,Maglić,Pfalzweiler,Ravno Selo', 45.3624800, 19.5321100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118694, 'Mačvanska Mitrovica', 'Macvanska Mitrovica', 'Macvanska Mitrovica,Mala Mitrovica,Mačvanska Mitrovica,Mitrovica,Srpski Mitrovica', 44.9673900, 19.5931400, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118695, 'Ljubovija', 'Ljubovija', 'Ljubovija,Opshtina LJubovija,Opstina Ljubovija,Opština Ljubovija,lywbwwyya,Любовия,Општина Љубовија,لیوبووئیا,ლიუბოვიის მუნიციპალიტეტი', 44.1894400, 19.3766700, 'RS', '2012-04-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118696, 'Lipolist', 'Lipolist', 'Lipolist', 44.6978300, 19.5010100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118697, 'Lipnički Šor', 'Lipnicki Sor', 'Lipnicki Sor,Lipnički Šor,Sor,Šor', 44.5805800, 19.2657200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118698, 'Lešnica', 'Lesnica', 'Lesnica,Lešnica,Ljesnica,Lješnica', 44.6525000, 19.3100000, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118699, 'Kupusina', 'Kupusina', 'Bacskertes,Bácskertes,Kupusina,Kupussina,Kupuszina', 45.7375900, 19.0108200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118700, 'Kulpin', 'Kulpin', 'Kolpeny,Kulpin,Kuplin,Kölpény', 45.4024000, 19.5881400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118701, 'Kula', 'Kula', 'Bacskula,Bácskula,Kula,Kulla,Kúla,Wolfsburg,ku la,kwla,Кула,کولا,庫拉', 45.6088900, 19.5263900, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118702, 'Krupanj', 'Krupanj', 'Krupan,Krupanj,ke lu pa ni,krwpanyy,Крупањ,کروپانیی,克魯帕尼', 44.3655600, 19.3619400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118703, 'Krivaja', 'Krivaja', 'Krivaja', 44.5502100, 19.5915300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118704, 'Kozjak', 'Kozjak', 'Kozjak', 44.5872700, 19.2841200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118705, 'Kosjerić', 'Kosjeric', 'Kosijerici,Kosijerići,Kosjeric,Kosjerici,Kosjerić,Kosjerići,ke xie li qi,kwsyrs,Косјерић,کوسیرس,科謝里奇', 43.9961100, 19.9069400, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118706, 'Kolut', 'Kolut', 'Kollut,Kolluth,Kolut,Kullod,Küllőd,Ringdorf', 45.8929200, 18.9276000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118707, 'Koceljeva', 'Koceljeva', 'Koceleva,Koceljeva,Koceljevo,Opshtina Koceleva,Opstina Koceljeva,Opština Koceljeva,kwchylyywa,Коцелева,Општина Коцељева,کوچیلیئوا,კოცელიევოს მუნიციპალიტეტი', 44.4736100, 19.8116700, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118708, 'Klenje', 'Klenje', 'Klenje', 44.8079400, 19.4350800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118709, 'Klenak', 'Klenak', 'Klenak', 44.7884600, 19.7100400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118710, 'Kisač', 'Kisac', 'Kisac,Kisač,Kiszacs,Kiszács,Kysac,Kysač', 45.3542100, 19.7297500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118711, 'Kamenica', 'Kamenica', 'Kamenica,Kamenjica,Ravno Brdo', 44.3430000, 19.7233300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118712, 'Joševa', 'Joseva', 'Joseva,Josevo,Joševa,Joševo', 44.5877200, 19.4096700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118713, 'Jevremovac', 'Jevremovac', 'Jevremovac', 44.7217200, 19.6636400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118714, 'Jelenča', 'Jelenca', 'Jelenca,Jelenča', 44.7270000, 19.7350000, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118715, 'Jarebice', 'Jarebice', 'Jarebice', 44.5399500, 19.4241800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118716, 'Jarak', 'Jarak', 'Jarak', 44.9184300, 19.7547700, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118717, 'Jadranska Lešnica', 'Jadranska Lesnica', 'Jadranska Lesnica,Jadranska Lešnica', 44.5973000, 19.3520900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118718, 'Irig', 'Irig', 'Ireg,Iregh,Irig,Irrig,Urog,Urogh,ayrng,yi li ge,Ürög,Ürögh,Ириг,ایرنگ,伊里格', 45.1011100, 19.8583300, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118719, 'Hrtkovci', 'Hrtkovci', 'Herkoca,Herkóca,Hrtkovci,Srbislavci', 44.8815500, 19.7637400, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118720, 'Grabovci', 'Grabovci', 'Grabovci', 44.7649600, 19.8448900, 'RS', '2013-08-13', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118721, 'Gornja Bukovica', 'Gornja Bukovica', 'Gornja Bukovica', 44.3398700, 19.8136800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118722, 'Glušci', 'Glusci', 'Glusci,Glusii,Glušci,Glušii', 44.8902100, 19.5491300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118723, 'Gložan', 'Glozan', 'Dunagalos,Dunagálos,Gloschein,Glozan,Glozani,Glozsan,Glozsán,Gložan,Gložani,Hlozany,Hložany', 45.2795400, 19.5683800, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118724, 'Gakovo', 'Gakovo', 'Gador,Gakovo,Gakowa,Gaumarkt,Gádor,Gákovo', 45.9007800, 19.0613800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118725, 'Dublje', 'Dublje', 'Dublje', 44.8011700, 19.5090200, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118726, 'Drenovac', 'Drenovac', 'Drenovac', 44.8664900, 19.7094300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118727, 'Draginje', 'Draginje', 'Draginja,Draginje', 44.5330200, 19.7625000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118728, 'Doroslovo', 'Doroslovo', 'Bacsdoroszlo,Bácsdoroszló,Doroslau,Doroslovo,Doroszlo,Doroszló', 45.6069900, 19.1886800, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118729, 'Donji Dobrić', 'Donji Dobric', 'Donji Dobric,Donji Dobrić', 44.6118300, 19.3310900, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118730, 'Dobrić', 'Dobric', 'Dobric,Dobrić', 44.7022400, 19.5793100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118731, 'Despotovo', 'Despotovo', 'Despot Sent Ivan,Despot Sveti Ivan,Despot- Szent-Ivan,Despot- Szent-Iván,Despot-Sankt-Iwan,Despotovo,Deszpot- Szent-Ivan,Deszpot- Szent-Iván,Urszentivan,Vasilevo,Vasiljevo,Úrszentiván', 45.4598300, 19.5265300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118732, 'Crna Bara', 'Crna Bara', 'Crna Bara', 44.8737400, 19.3948000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118733, 'Čokešina', 'Cokesina', 'Cokesina,Čokešina', 44.6531900, 19.3901600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118734, 'Čelarevo', 'Celarevo', 'Bac-Ceb,Bacs-Cseb,Bač-Čeb,Bleyersdorf,Bács-Cséb,Celarevo,Cib,Cseb,Cséb,Dunacseb,Dunacséb,Tscheb,Čelarevo,Čib', 45.2699900, 19.5248400, 'RS', '2016-10-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118735, 'Čajetina', 'Cajetina', 'Cajetina,Chaetina,Chajetina,chayytyna,Čajetina,Чаетина,Чајетина,چائیتینا', 43.7497700, 19.7127300, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118736, 'Bukor', 'Bukor', 'Bukor', 44.4952300, 19.5711600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118737, 'Buđanovci', 'Budanovci', 'Budanovci,Budjanovci,Buđanovci', 44.8938800, 19.8634400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118738, 'Brdarica', 'Brdarica', 'Brdarica,Brdarice', 44.5537600, 19.7715000, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118739, 'Bosut', 'Bosut', 'Bosut', 44.9297700, 19.3608600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118740, 'Bogosavac', 'Bogosavac', 'Bogosavac', 44.7179900, 19.5953300, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118741, 'Bogojevo', 'Bogojevo', 'Bogojeva,Bogojevo,Gombos,Gombosh', 45.5310600, 19.1320500, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118742, 'Bogatić', 'Bogatic', 'Bocatic,Bocatić,Bogatic,Bogatić,bwgats,bwghatytsh,Богатић,بوغاتيتش,بوگاتس', 44.8375000, 19.4805600, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118743, 'Beočin', 'Beocin', 'Belcseny,Belcsény,Beochin,Beocin,Beocsin,Beotschin,Beoĉin,Beočin,bei ao qin,bywchn,bywtshyn,Беочин,بيوتشين,بیوچن,貝奧欽', 45.2082900, 19.7206300, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118744, 'Belotić', 'Belotic', 'Belotic,Belotić', 44.8178200, 19.5480100, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118745, 'Banovo Polje', 'Banovo Polje', 'Banovo Polje', 44.9104000, 19.4491600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118746, 'Bajina Bašta', 'Bajina Basta', 'Baina Bashha,Baina-Bashta,Bajina Bashta,Bajina Basta,Bajina Bašta,ba yi na ba shen ta,bayyna bashta,Баина Баща,Баина-Башта,Бајина Башта,بايينا باشتا,بایینا باشتا,巴伊納巴什塔', 43.9708300, 19.5675000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118747, 'Badovinci', 'Badovinci', 'Badovinci', 44.7853400, 19.3714600, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118748, 'Bački Petrovac', 'Backi Petrovac', 'Bachki Petrovac,Bachki-Petrovac,Backi Petrovac,Bački Petrovac,Petroc,Petrocz,Petrovac,Petrovacz,Petrovec,Petrovácz,Petrowatz,Petrőc,Petrőcz,ba qi ji bi de luo wa ci,bachky pytrwwach,batshky bytrwfats,Бачки Петровац,Бачки-Петровац,באצקי פטרובאץ,باتشكي بيتروفاتس,باچکی پیتروواچ,巴奇基彼得羅瓦茨', 45.3605600, 19.5916700, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118749, 'Bački Breg', 'Backi Breg', 'Backi Breg,Bački Breg,Bereg,Beregh,Berg,Berg an der Donau,Béreg', 45.9203400, 18.9294400, 'RS', '2012-07-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118750, 'Bačka Topola', 'Backa Topola', 'Andrasfoldje,Andrásföldje,Bacstopolya,Batsch-Topola,Bácstopolya,Kisbelgrad,Kisbelgrád,Mali Beograd,Topolo,Topolya', 45.8151600, 19.6318000, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118751, 'Bačka Palanka', 'Backa Palanka', 'Alt-Palanka,Bachka Palanka,Bachka palanka,Bachka-Palanka,Backa Palanka,Bačka Palanka,Deutsch-Palanka,Gorad Bachka-Palanka,Nemet-Palanka,Nova Palanka,Német-Palánka,Opalanka,Palanka,Palánka,Plakenburg,Stara Palanka,Ujpalanka,ba qi ka pa lan ka,bachikapallanka,bachka palanka,bachka planka,batshka balanka,Ópalánka,Újpalánka,Бачка Паланка,Бачка паланка,Бачка-Паланка,Горад Бачка-Паланка,באצקה פאלאנקה,باتشكا بالانكا,باچکا پالانکا,باچکا پلانکا,巴奇卡帕兰卡,바치카팔란카', 45.2508300, 19.3919400, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118752, 'Bač', 'Bac', 'Baatsch,Bac,Bacas,Bach,Bacs,Batsch,Baç,Bač,Bačas,Bács,ba qi,bach,bachi,batsh,Бач,באץ,باتش,باچ,巴奇,바치', 45.3919400, 19.2366700, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118753, 'Apatin', 'Apatin', 'Abthausen,Apathin,Apati,Apatin,Apatinas,a pa ding,abatyn,apatn,Апатин,אפאטין,أباتين,اپاتن,阿帕丁', 45.6711100, 18.9847200, 'RS', '2012-04-12', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118754, 'Pocerski Pričinović', 'Pocerski Pricinovic', 'Pocerski Pricinovic,Pocerski Pričinović', 44.7222200, 19.7072200, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118755, 'Ðurići', 'Durici', 'Durici,Ðurići', 43.8253300, 19.4123300, 'RS', '2012-09-07', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118756, 'Zlatibor', 'Zlatibor', 'Kraljeva Voda,Kraljeve Vode,Partizanska Voda,Partizanske Vode,Partizanske Vode sa Palisadom,Zlatibor,zi la di bo er,zlatybwr,Златибор,زلاتيبور,茲拉蒂博爾', 43.7290000, 19.7002900, 'RS', '2012-04-15', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118757, 'Sokolovo Brdo', 'Sokolovo Brdo', 'Sokolovo Brdo', 43.1369400, 19.8055600, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118758, 'Osječenik', 'Osjecenik', 'Osjecenik,Osječenik', 43.1452800, 19.8588900, 'RS', '2012-01-19', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118759, 'Rumska', 'Rumska', 'Rumska', 44.5726100, 19.5898800, 'RS', '2012-07-05', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118760, 'Knjazevac', 'Knjazevac', '', 43.5663400, 22.2570100, 'RS', '2012-04-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118761, 'Sumulicë', 'Sumulice', 'Samojlica,Sumulic,Sumulice,Sumulicë', 42.3868200, 21.7340000, 'RS', '2010-11-04', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118762, 'Lagja e Poshtme', 'Lagja e Poshtme', '', 42.3885300, 21.7297100, 'RS', '2012-09-16', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118763, 'Irig', 'Irig', '', 45.0523000, 19.8444800, 'RS', '2015-06-24', 197);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118983, 'Vyazovaya', 'Vyazovaya', 'Vjazovaja,Vyazovaya,Вязовая', 54.9050000, 58.3561100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118984, 'Vyazniki', 'Vyazniki', 'Vjazniki,Vyaznika,Vyazniki,Wjasnik,Вязники', 56.2405700, 42.1556300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118985, 'Vyaz’ma', 'Vyaz''ma', 'Vjaz''ma,Vjazma,Vyasma,Vyaz''ma,Vyaz’ma,Вязьма', 55.2103900, 34.2950800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118986, 'Vyatskiye Polyany', 'Vyatskiye Polyany', 'Vjatskie Poljany,Vjatskije Poljany,Vyatskiye Polyany,Вятские Поляны', 56.2260200, 51.0655700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118987, 'Vyartsilya', 'Vyartsilya', 'Vaertsilae,Vjartsilja,Vyartsilya,Värtsilä,Вяртсиля', 62.1764500, 30.6929600, 'RU', '2016-09-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118988, 'Vurnary', 'Vurnary', 'Vunary,Vurnary,Vurnur,Вунары,Вурнары', 55.4904400, 46.9647900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118989, 'Vuktyl', 'Vuktyl', 'Gorad Vuktyl,Voektyl,Vouktyl,Vuktil,Vuktol,Vuktyl,Vuktõl,Vuktıl,Wuktyl,Wuktył,fwktyl,wu ke te er,wwktyl,Вуктил,Вуктыл,Вуктыл балһсн,Горад Вуктыл,فوكتيل,ووکتیل,武克特爾', 63.8566700, 57.3094400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118990, 'Vsevolozhsk', 'Vsevolozhsk', 'Gorad Usevalazhsk,Seuloskoi,Seuloškoi,V''sevolozh''sku,Vsevolojsk,Vsevoloshk,Vsevolozhs''k,Vsevolozhsk,Vsevolozhskiy,Vsevolozjsk,Vsevolozsk,Vsevolozska,Vsevoloĵsk,Vsevoložsk,Vsevoložska,Vsévolozhsk,Wsewoloschsk,Wsewolozsk,Wsewoložsk,Wsiewolozsk,Wsiewołożsk,beusebollosiseukeu,fsyfwlwjsk,fu xie wo luo ri si ke,wswwlwzhsk,Всеволожск,Всеволожськ,Всеволошк,Вьсєволожьскъ,Горад Усевалажск,فسيفولوجسك,وسوولوژسک,ვსევოლოჟსკი,弗謝沃洛日斯克,브세볼로시스크', 60.0151200, 30.6731400, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118991, 'Voznesen’ye', 'Voznesen''ye', 'Syvaerinniska,Syvärinniska,Voznesen''e,Voznesen''ye,Vozneseniye,Voznesenje,Voznesen’ye,Вознесенье', 61.0106000, 35.4781300, 'RU', '2016-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118992, 'Voznesenskoye', 'Voznesenskoye', 'Voznesenskoe,Voznesenskoje,Voznesenskoye,Вознесенское', 54.8900000, 42.7569400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118993, 'Voznesenskaya', 'Voznesenskaya', 'Voznesenskaia,Voznesenskaja,Voznesenskaya,Вознесенская', 44.5527000, 41.0318000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118994, 'Voznesenskaya', 'Voznesenskaya', 'Voznesensk,Voznesenskaja,Voznesenskaya,Вознесенская', 43.5437900, 44.7461400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118995, 'Vozhega', 'Vozhega', 'Vozhega,Vozjega,Вожега', 60.4724600, 40.2213400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118996, 'Voyvozh', 'Voyvozh', 'Vojvozh,Vojvozj,Voyvozh,Войвож', 62.8919800, 54.9634600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118997, 'Voyskovitsy', 'Voyskovitsy', 'Voiskovitsa,Vojskovicy,Vojskovitsy,Voyskovitsy,Войсковицы', 59.5326600, 29.9362000, 'RU', '2017-02-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118998, 'Votkinsk', 'Votkinsk', 'Gorad Votkinsk,Votka,Votkins''k,Votkinsk,Votkinszk,Vótkinsk,Wotkinsk,Wotkińsk,boskinseukeu,fwtkynsk,vu~otokinsuku,wo te jin si ke,wtkynsk,wwtknsk,Вотка,Воткинск,Воткінськ,Горад Воткінск,فوتكينسك,وتکینسک,ووتکنسک,ヴォトキンスク,沃特金斯克,봇킨스크', 57.0486500, 53.9871700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(118999, 'Vostryakovo', 'Vostryakovo', 'Vostrjakovo,Vostryakovo,Востряково', 55.6666700, 37.4500000, 'RU', '2014-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119000, 'Vostryakovo', 'Vostryakovo', 'Vostrjakovo,Vostryakovo,Востряково', 55.3993400, 37.8082900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119001, 'Vostochnyy', 'Vostochnyy', 'Filippovka,Vostochnyj,Vostochnyy,Vostotsjnyj,Восточный', 58.7881100, 52.2451300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119002, 'Vostochnyy', 'Vostochnyy', 'Stalinskiy,Vostochnyj,Vostochnyy,Восточный', 55.8166700, 37.8666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119003, 'Voskresenskoye', 'Voskresenskoye', 'Voskresenskoe,Voskresenskoje,Voskresenskoye,Воскресенское', 56.8380600, 45.4316700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119004, 'Voskresenskoye', 'Voskresenskoye', 'Voskresenskiy Zavod,Voskresenskoe,Voskresenskoje,Voskresenskoye,Воскресенское', 53.1233600, 56.1466400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119005, 'Voskresenskoye', 'Voskresenskoye', 'Voskresenskoe,Voskresenskoye,Воскресенское', 51.8247800, 46.9350800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119006, 'Voskresensk', 'Voskresensk', 'Voskresens''k,Voskresensk,Voskresenska,Voskresenskaj,Voskressensk,Woskressensk,Woskriesiensk,Woskrjesensk,boseukeulesenseukeu,fwskrysynsk,vu~osukuresensuku,wo si ke lie xian si ke,wwskrsnsk,wwskrysnsk,Воскресенск,Воскресенск балһсн,Воскресенскай,Воскресенськ,فوسكريسينسك,ووسکرسنسک,ووسکریسنسک,ヴォスクレセンスク,沃斯克列先斯克,보스크레센스크', 55.3173300, 38.6526400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119007, 'Vorsma', 'Vorsma', 'Gorad Vorsma,Vorsma,Vorzima,Worsma,fwrsma,wo er si ma,wwrsma,Ворсма,Горад Ворсма,فورسما,وورسما,沃爾斯馬', 55.9906200, 43.2724900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119008, 'Vorsha', 'Vorsha', 'Vorsha,Vorsja,Ворша', 56.0491000, 40.0796600, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119009, 'Vorotynets', 'Vorotynets', 'Vorotynec,Vorotynets,Воротынец', 56.0602800, 45.8633000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119010, 'Voroshnëvo', 'Voroshnevo', 'Voroshnevo,Voroshnëvo,Vorosjnevo,Ворошнево', 51.6527800, 36.0172200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119011, 'Vorontsovka', 'Vorontsovka', 'Voroncovka,Vorontsovka,Vorortsovka,Воронцовка', 50.6132000, 40.3549000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119012, 'Vorontsovka', 'Vorontsovka', 'Voroncovka,Vorontsovka,Vorontsovskoye,Воронцовка', 46.6529000, 38.0787000, 'RU', '2012-04-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119013, 'Voronezh', 'Voronezh', 'VOZ,Voronej,Voronez,Voroneza,Voronezas,Voronezh,Voronezhskaja oblast'',Voronezj,Voroneĵ,Voronež,Voronežas,Voroněž,Voroņeža,Woronesch,Woronesh,Woronez,Woroneż,bolonesi,vu~oroneji,Воронеж,Воронежская область,ヴォロネジ,보로네시', 51.6720400, 39.1843000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119014, 'Altuf’yevskiy', 'Altuf''yevskiy', 'Altuf''evskij,Altuf''yevskiy,Altuf’yevskiy,Vorob''yevskiy,Vorob’yëvskiy,Алтуфьевский', 55.8833300, 37.5833300, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119015, 'Vorob’yovo', 'Vorob''yovo', 'Vorob''evo,Воробьево', 55.7166700, 37.5333300, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119016, 'Volzhskiy', 'Volzhskiy', 'Bol''shaya Tsarevshchina,Bol’shaya Tsarëvshchina,Volzhskij,Volzhskiy,Volzjskij,Волжский', 53.4305800, 50.1190000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119017, 'Volzhskiy', 'Volzhskiy', 'Volzh Sky,Volzhskij,Volzhskiy,Volzjskij,Volzski,Volžski,Волжский', 48.7858300, 44.7797300, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119018, 'Volzhsk', 'Volzhsk', 'Julser-Ola,Lopatin,Lopatino,Volzhsk,Volzjsk,Volzsk,Volžsk,Волжск,Юлсер-Ола', 55.8663800, 48.3594000, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119019, 'Volya', 'Volya', 'Volja,Volya,Воля', 51.7651000, 39.5404000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119020, 'Vol’sk', 'Vol''sk', 'Vol''sk,Volsk,Vol’sk,Wolsk,Вольск', 52.0454100, 47.3799300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119021, 'Volovo', 'Volovo', 'Valova,Volovo,Волово', 52.0265900, 37.8854000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119022, 'Volot', 'Volot', 'Volot,Волот', 57.9277800, 30.7025000, 'RU', '2010-08-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119023, 'Volosovo', 'Volosovo', 'Gorad Volasava,Volosova,Volosovo,Volossova,Volossovo,Vólosovo,Wolosowo,Wolossowo,Wołosowo,bollosobo,fwlwswfw,volosovo,wo luo suo wo,wwlwswfw,Волосово,Горад Воласава,فولوسوفو,وولوسوفو,ვოლოსოვო,沃洛索沃,볼로소보', 59.4452500, 29.4891100, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119024, 'Voloshka', 'Voloshka', 'Voloshka,Volosjka,Волошка', 61.3313900, 40.0858300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119025, 'Volokonovka', 'Volokonovka', 'Volokonovka,Wolokonowka,Волоконовка', 50.4827000, 37.8563000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119026, 'Volokolamsk', 'Volokolamsk', 'Gorad Valakalamsk,Volokolams''k,Volokolamsk,Volokolamskaj,Volokolamskas,Wolokolamsk,Wołokołamsk,bollokollamseukeu,fwlwkwlamsk,vu~orokoramusuku,wo luo ke la mu si ke,wwlwkwlamsk,Волоколамск,Волоколамск балһсн,Волоколамскай,Волоколамськ,Горад Валакаламск,فولوكولامسك,وولوکولامسک,ヴォロコラムスク,沃洛科拉姆斯克,볼로콜람스크', 56.0336100, 35.9694400, 'RU', '2016-07-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119027, 'Vologda', 'Vologda', 'Bologda,Bологда,Gorad Volagda,VGD,Vologd,Vologda,Vologdae,Vologdo,Vólogda,Wologda,Wołogda,bollogeuda,fwlwghda,vologda,vu~oroguda,wlwgda,wo luo ge da,wo lxk da,wwlwgda,wwlwgdh,Вологдæ,Вологда,Вологдо,Волоґда,Вӧлӧгда,Горад Волагда,Վոլոգդա,וולוגדה,فولوغدا,ولوگدا,وولوگدا,โวลอกดา,ვოლოგდა,ヴォログダ,沃洛格达,볼로그다', 59.2239000, 39.8839800, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119028, 'Volodarskogo', 'Volodarskogo', 'Poselok Volodarskogo,Posëlok Volodarskogo,Stalino,Volodarskij,Volodarskiy,Volodarskogo,Володарский', 55.5034900, 37.9417400, 'RU', '2015-06-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119029, 'Volodarskiy', 'Volodarskiy', 'Volodarovka,Volodarskij,Volodarskiy,Володарский', 46.4013400, 48.5409300, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119030, 'Volodarsk', 'Volodarsk', 'Gorad Valadarsk,Volodarsk,Volodarskas,Volodary,Wolodarsk,Wołodarsk,Zolodary,fwlwdarsk,wo luo da er si ke,wwlwdarsk  rwsyh,Володарск,Горад Валадарск,فولودارسك,وولودارسک، روسیه,沃洛達爾斯克', 56.2310500, 43.1876700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119031, 'Volochayevskoye', 'Volochayevskoye', 'Marschenen,Marshenen,Volochaevskoe,Volochayevskoye,Волочаевское', 54.7003400, 20.2196600, 'RU', '2014-10-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119032, 'Vol’nyy Aul', 'Vol''nyy Aul', '', 43.4786100, 43.6275000, 'RU', '2012-09-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119033, 'Volkhovskiy', 'Volkhovskiy', 'Volkhovskij,Volkhovskiy,Волховский', 58.5800000, 31.3164100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119034, 'Volkhov', 'Volkhov', 'Gorad Volkhau,Olhava,Volchov,Volchovas,Volhov,Volhova,Voljov,Volkhov,Volkhovstroy,Volxov,Volĥov,Vóljov,Vólkhov,Wolchow,Wołchow,Zvanka,bolhopeu,fwlkhwf,volkhovi,vu~oruhofu,wo er huo fu,wwlkhwf,Волхов,Волховъ · градъ,Горад Волхаў,Վոլխով,فولخوف,وولخوف,ვოლხოვი,ヴォルホフ,沃爾霍夫,볼호프', 59.9258000, 32.3381900, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119035, 'Nagornyy', 'Nagornyy', 'Nagornyj,Nagornyy,Volkhonka,Нагорный', 55.6500000, 37.6166700, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119036, 'Volgorechensk', 'Volgorechensk', 'Volgorechensk,Volgoretsjensk,Волгореченск', 57.4393100, 41.1555300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119037, 'Volgo-Kaspiyskiy', 'Volgo-Kaspiyskiy', 'Volgo-Kaspijskij,Volgo-Kaspiyskiy,Волго-Каспийский', 46.2030600, 47.9186900, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119038, 'Volgograd', 'Volgograd', 'Caricyn,Estalingrado,Gorad Valgagrad,Stalingrad,Stalingrado,Tsaritsyn,VOG,Vl''gogradu,Volgograd,Volgograda,Volgogradas,Volgogrado,Volgogradum,Volgográd,Volnkonkrant,Volqoqrad,Wolgograd,Wołgograd,Zarizyn,bolgogeuladeu,fu er jia ge lei,fwlghwghrad,fwljwjrad,volagagarata,volgograda,volgogradi,volkokirat,vu~orugogurado,wlgwgrad,wwlgw grad,wwlgwgrad,wwlgwgrd,wxl kok rad,Βόλγκογκραντ,Аһш балһсн,Вльгоградъ,Волгоград,Горад Валгаград,Сталинград,Царицын,Վոլգոգրադ,וולגוגרד,فولجوجراد,فولغوغراد,ولگوگراد,وولگو گراد,وولگوگراد,ڤۆڵگۆگراد,वोल्गोग्राद,ਵੋਲਗਾਗਰਾਤ,வோல்கோகிராட்,වොල්ගාග්‍රාද්,วอลโกกราด,စတာလင်ဂရက်မြို့,ვოლგოგრადი,ヴォルゴグラード,伏尔加格勒,伏爾加格勒,볼고그라드', 48.7193900, 44.5018300, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119039, 'Volgodonsk', 'Volgodonsk', 'Gorad Valgadonsk,VLK,Volgodons''k,Volgodonsk,Volgodonska,Volgodonskas,Volqodonsk,Wolgodonsk,Wołgodońsk,bolgodonseukeu,fu er jia dun si ke,fwlghwdwnsk,vu~orugodonsuku,wlgwdwnsk,wwlgwdwnsk,wwlgwdwnsq,Волгодонск,Волгодонск балһсн,Волгодонськ,Горад Валгадонск,וולגודונסק,فولغودونسك,ولگودونسک,وولگودونسک,ヴォルゴドンスク,伏尔加顿斯克,볼고돈스크', 47.5136100, 42.1513900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119040, 'Volga', 'Volga', 'Volga,Волга', 57.9515700, 38.3878500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119041, 'Vokhtoga', 'Vokhtoga', 'Vakhtoga,Vokhtoga,Вохтога', 58.8094900, 41.0624500, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119042, 'Vokhma', 'Vokhma', 'Vokhma,Вохма', 58.9303000, 46.7585900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119043, 'Vodstroy', 'Vodstroy', 'Vodstroi,Vodstroj,Vodstroy,Водстрой', 48.8416500, 44.5579300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119044, 'Yutsa', 'Yutsa', 'Dzhutskiy,Juca,Jutsa,Vodopadskiy,Vodopadskoye,Yutsa,Юца', 43.9563900, 43.0127800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119045, 'Vodnyy', 'Vodnyy', 'Vodnyj,Vodnyy,Водный', 63.5046400, 53.4094700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119046, 'Novovladykino', 'Novovladykino', 'Novovladykino,Vladykino,Нововладыкино', 55.8500000, 37.5833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119047, 'Vladimirskoye', 'Vladimirskoye', 'Vladimirskoe,Vladimirskoje,Vladimirskoye,Владимирское', 56.8200200, 45.1184300, 'RU', '2012-06-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119048, 'Vladimirskaya', 'Vladimirskaya', 'Vladimirovskaya,Vladimirskaja,Vladimirskaya,Wladimirskaja,Владимирская', 44.5455000, 40.7933000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119049, 'Vladimir', 'Vladimir', 'Blantimir,Gorad Uladzimir,Ulatimer,Vladimir,Vladimir khot,Vladimir shaary,Vladimira,Vladimiras,Vladimír,Vladímir,Vladîmîr,Vlagyimir,Volodimir,Volodimiria,Wladimir,Wladymir,Wlodzimierz,Władymir,Włodzimierz,beulladimileu,fladymyr,fu la ji mi er,urajimiru,vladimiri,wladymyr,wldymyr,Βλαντίμιρ,Владимир,Владимир хот,Владимир шаары,Володимир,Горад Уладзімір,Улатимĕр,ולדימיר,فلاديمير,ولادیمیر,ვლადიმირი,ウラジーミル,弗拉基米尔,블라디미르', 56.1365500, 40.3965800, 'RU', '2016-07-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119050, 'Vladikavkaz', 'Vladikavkaz', 'Dzaeudzhykhuaeu,Dzhaudzhikau,Gorad Uladzikaukaz,OGZ,Ordshonikidse,Ordzhonikidve,Ordzhonikidze,Orjonikidze,Tehrchkualeh,Vladicaucaso,Vladicáucaso,Vladikaukaza,Vladikaukazas,Vladikaukāza,Vladikavkaz,Vladiqafqaz,Vlantikavkaz,Wladikafkaz,Wladikawkas,Wladikawkaz,Wladykaukaz,Władykaukaz,beulladikabkaseu,fladyqwqaz,fu la ji gao jia suo,urajikafukasu,wladyqfqaz,wldyqwwqz,Βλαντικαβκάζ,Буро-ГӀала,Владикавказ,Владикавказ балһсн,Горад Уладзікаўказ,Дзæуджыхъæу,КӀапӀкӀай,Орджоникидзе,Тэрчкъалэ,Վլադիկավկազ,ולדיקווקז,فلاديقوقاز,ولادیقفقاز,ولادی‌قفقاز,ვლადიკავკაზი,ウラジカフカス,弗拉季高加索,블라디캅카스', 43.0366700, 44.6677800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119051, 'Vizinga', 'Vizinga', 'Vizenga,Vizinga,Vizingo,Визинга', 61.0749300, 50.1031100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119052, 'Vityazevo', 'Vityazevo', 'Vitjazevo,Vityazevo,Vityazevskaya,Витязево', 45.0013000, 37.2821100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119053, 'Vistino', 'Vistino', 'Viistinae,Viistinä,Vistina,Vistino,Вистино', 59.7755800, 28.4770800, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119054, 'Visim', 'Visim', 'Visim,Visimo-Shaytansk,Visimo-Shaytanskiy Zanod,Висим', 57.6488000, 59.5014000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119055, 'Vishnyakovskiye Dachi', 'Vishnyakovskiye Dachi', 'Vishnjakovskie Dachi,Vishnyakovskiye Dachi,Visjnjakovskije Datsji,Вишняковские Дачи', 55.7647000, 38.1333400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119056, 'Vinsady', 'Vinsady', 'Vinogradnyye-Sady,Vinsady,Винсады', 44.0808300, 42.9652800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119057, 'Vinogradovo', 'Vinogradovo', 'Vinogradovo,Виноградово', 56.9333300, 37.5500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119058, 'Vinogradnyy', 'Vinogradnyy', 'Gastagayka,Gostagayka,Vinogradnyj,Vinogradnyy,Виноградный', 45.0561000, 37.3212500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119059, 'Vinnitsy', 'Vinnitsy', 'Andronovskaya,Andronovskoye,Davydovskaya,Maksimovskaya,Vidla,Vingl,Vinnicy,Vinnitsa,Vinnitsy,Vinnitsy-Andronovskoye,Винницы', 60.6286700, 34.7730200, 'RU', '2017-02-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119060, 'Vilya', 'Vilya', 'Vilja,Vilya,Виля', 55.2455600, 42.2088900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119061, 'Vilovatovo', 'Vilovatovo', 'Vilovatovo,Виловатово', 56.1724000, 46.6013400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119062, 'Vilenka', 'Vilenka', 'Vilenka,Vilenki,Vilinka,Виленка', 54.2693000, 38.9166300, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119063, 'Vidyayevo', 'Vidyayevo', 'Uritsa,Vidjaevo,Vidyayevo,Видяево', 68.8833300, 33.0166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119064, 'Vidnoye', 'Vidnoye', 'Poselok Vidnoye,Posëlok Vidnoye,Vidnoe,Vidnoje,Vidnoye,Видное', 55.5523900, 37.7096700, 'RU', '2016-07-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119065, 'Vichuga', 'Vichuga', 'Bichuga,Vichuga,Vitsjuga,Вичуга', 57.2127600, 41.9301200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119066, 'Veydelevka', 'Veydelevka', 'Veidelovka,Vejdelevka,Veydelevka,Вейделевка', 50.1521000, 38.4492000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119067, 'Vetluzhskiy', 'Vetluzhskiy', 'Golyshi,Vetluzhskij,Vetluzhskiy,Vetluzjskij,Ветлужский', 58.3901600, 45.4654300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119068, 'Vetluzhskiy', 'Vetluzhskiy', 'Vetluzhskij,Vetluzhskiy,Vetluzjskij,Ветлужский', 57.1735500, 45.1227200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119069, 'Vetluga', 'Vetluga', 'Gorad Vjatluga,Jur,Vetlouga,Vetluga,Vetlugae,Vetluqa,Wetluga,Wjetluga,fytlwgha,wei te lu jia,wtlwga,Ветлугæ,Ветлуга,Горад Вятлуга,Юр,فيتلوغا,وتلوگا,韋特盧加', 57.8557400, 45.7810200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119070, 'Ves’yegonsk', 'Ves''yegonsk', 'Ves''egonsk,Ves''yegonsk,Vesiegonsk,Ves’yegonsk,Весьегонск', 58.6639800, 37.2604000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119071, 'Veshnyaki', 'Veshnyaki', 'Veshnjaki,Veshnyaki,Вешняки', 55.7239300, 37.8195200, 'RU', '2016-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119072, 'Veshkayma', 'Veshkayma', 'Sorokovoy,Veshkajma,Veshkayma,Vesjkajma,Вешкайма', 54.0472000, 47.1300000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119073, 'Veshenskaya', 'Veshenskaya', 'Veshenskaja,Veshenskaya,Vesjenskaja,Вешенская', 49.6303300, 41.7334000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119074, 'Veshchevo', 'Veshchevo', 'Heinijoki,Heinjoki,Kheynioki,Kheynyoki,Veshchevo,Veshhevo,Vesjtsjevo,Вещево', 60.7310700, 29.1830500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119075, 'Vesëlyy', 'Veselyy', 'Vesely,Veselyj,Veselyy,Veselyy Khutor,Vesëlyy,Весëлый,Веселый', 47.0933800, 40.7422000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119076, 'Verkhozim', 'Verkhozim', 'Verkhozim,Верхозим', 52.7122100, 45.4180300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119077, 'Verkhov’ye', 'Verkhov''ye', 'Verkhov''e,Verkhov''ye,Verkhove,Verkhovje,Verkhov’ye,Верховье', 52.8116500, 37.2421500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119078, 'Verkhovazh’ye', 'Verkhovazh''ye', 'Verkhovazh''e,Verkhovazh''ye,Verkhovazh’ye,Verkhovazje,Верховажье', 60.7471700, 42.0465200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119079, 'Verkhoshizhem’ye', 'Verkhoshizhem''ye', 'Verkhoshizhem''e,Verkhoshizhem''ye,Verkhoshizhem’ye,Verkhosjizjemje,Верхошижемье', 58.0109700, 49.1038400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119080, 'Verkhnyaya Tura', 'Verkhnyaya Tura', 'Aukstutine Tura,Aukštutinė Tura,Gorad Verkhnjaja Tura,Turi Tura,Verchniagia Toura,Verchnjaja Toera,Verchnjaja Tura,Verhnjaja Tura,Verjniaya Tura,Verkhnaja Tura,Verkhniaia Toura,Verkhniaïa Toura,Verkhnja Tura,Verkhnjaja Tura,Verkhnyaya Tura,Verxnyaya Tura,Verĥnjaja Tura,Vérjniaya Turá,Werchnjaja Tura,Wjerchnjaja Tura,fyrkhnyaya twra,shang tu la,wrkhnyaya twra,Βέρχνιαγια Τουρά,Верхня Тура,Верхняя Тура,Верхњаја Тура,Горад Верхняя Тура,Тури Турă,Югары Түре,فيرخنيايا تورا,ورخنیایا تورا,上圖拉', 58.3608300, 59.8066700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119081, 'Verkhnyaya Toyma', 'Verkhnyaya Toyma', 'Verkhnjaja Tojma,Verkhnyaya Toyma,Верхняя Тойма', 62.2347000, 45.0009000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119082, 'Verkhnyaya Tishanka', 'Verkhnyaya Tishanka', 'Staraya Tishanka,Tishanka,Verkhnjaja Tishanka,Verkhnjaja Tisjanka,Verkhnyaya Tishanka,Verkho-Tishanka,Верхняя Тишанка', 51.3238900, 40.5327800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119083, 'Verkhnyaya Maksakovka', 'Verkhnyaya Maksakovka', 'Verkhnyaya Maksakovka,Verkhnyaya Maksatovka', 61.6350400, 50.9674000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119084, 'Kishcha', 'Kishcha', 'Kishali,Kishcha,Kishcha-Makhi,Kishha,Kisjtsja,Verkhnyaya Kishcha,Кища', 42.1767700, 47.5811700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119085, 'Verkhnyaya Khava', 'Verkhnyaya Khava', 'Verkhne Khava,Verkhnjaja Khava,Verkhnyaya Khava,Верхняя Хава', 51.8404500, 39.9413400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119086, 'Verkhnyaya Balkariya', 'Verkhnyaya Balkariya', 'Verkhnjaja Balkaria,Verkhnjaja Balkarija,Verkhnyaya Balkariya,Верхняя Балкария', 43.1278500, 43.4573200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119087, 'Verkhniy Uslon', 'Verkhniy Uslon', 'Verkhnij Ulson,Verkhnij Uslon,Verkhniy Uslon,Верхний Улсон,Верхний Услон', 55.7701000, 48.9823000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119088, 'Verkhniy Tagil', 'Verkhniy Tagil', 'Verkh.Tagil,Verkhnij Tagil,Verkhniy Tagil,Верх.Тагил,Верхний Тагил', 57.3733000, 59.9556000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119089, 'Lakkha Nëvre', 'Lakkha Nevre', 'Lakkha Nevre,Lakkha Njovre,Lakkha Nëvre,Verkhnij Naur,Verkhniy Naur,Verxnii Naur,Верхний Наур,Лакха Нёвре', 43.6103300, 45.2454200, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119090, 'Verkhniy Mamon', 'Verkhniy Mamon', 'Verkhne Mamon,Verkhnij Mamon,Verkhniy Mamon,Верхний Мамон', 50.1635000, 40.3832000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119091, 'Verkhniy Lomov', 'Verkhniy Lomov', 'Verkh.Lomov,Verkhnij Lomov,Verkhniy Lomov,Верх.Ломов,Верхний Ломов', 53.4677800, 43.5511100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119092, 'Verkhniy Landekh', 'Verkhniy Landekh', 'Verkh.Landekh,Verkhnij Landekh,Verkhniy Landekh,Верх.Ландех,Верхний Ландех', 56.8397100, 42.5973000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119093, 'Verkhniy Kurkuzhin', 'Verkhniy Kurkuzhin', 'Kurguzhin,Kurkuzhin,Verkhnij Kurkuzhin,Verkhniy Kurkuzhin,Верхний Куркужин,Куркужин', 43.6955600, 43.2747200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119094, 'Verkhniy Fiagdon', 'Verkhniy Fiagdon', 'Verkhnij Fiagdon,Verkhniy Fiagdon,Верхний Фиагдон', 42.8332300, 44.3065700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119095, 'Verkhniye Tatyshly', 'Verkhniye Tatyshly', 'Nizhniye Tatyshly,Verkhnie Tatyshly,Verkhnije Tatysjly,Verkhniye Tatyshly,Verxnie Tatisli,fyrkhnyy tatyshly,Верхние Татышлы,Югары Тәтешле,Үрге Тәтешле,Վերխնիե Տատիշլի,فيرخنيي تاتيشلي', 56.2911700, 55.8575000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119096, 'Verkhniye Sergi', 'Verkhniye Sergi', 'Verkhnie Sergi,Verkhnije Sergi,Verkhniye Sergi,Верхние Серги', 56.6469400, 59.5555600, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119097, 'Verkhniye Osel’ki', 'Verkhniye Osel''ki', 'Verkhnie Osel''ki,Ylae Osselki,Ylä Osselki,Верхние Осельки', 60.2494800, 30.4493800, 'RU', '2016-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119098, 'Verkhniye Kigi', 'Verkhniye Kigi', 'Jugary Kyjgy,Verkhnie Kigi,Verkhnije Kigi,Verkhniye Kigi,Verxnie Kigi,fyrkhnyy kyghy,Верхние Киги,Югары Кыйгы,Үрге Ҡыйғы,Վերխնիե Կիգի,فيرخنيي كيغي', 55.4083300, 58.6044400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119099, 'Verkhniye Achaluki', 'Verkhniye Achaluki', 'Achaluk,Atsylyk,Verkhne-Atsylyk,Verkhnie Achaluki,Verkhnije Atsjaluki,Verkhniy Atsylyk,Verkhniye Achaluki,Verkhnye Achaluki,Верхние Ачалуки,Верхные Ачалуки', 43.3469400, 44.6975000, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119100, 'Verkhniy Baskunchak', 'Verkhniy Baskunchak', 'Verhkniy Baskunchak,Verhniy Baskunchak,Verkh.Baskunchak,Verkhne Baskunchak,Verkhnij Baskunchak,Verkhniy Baskunchak,Верх.Баскунчак,Верхний Баскунчак', 48.2256400, 46.7216900, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119101, 'Verkhniy Avzyan', 'Verkhniy Avzyan', 'Avzyano Petrovsk,Avzyanopetrovsky,Verkhne-Avzyan,Verkhnij Avzian,Verkhnij Avzjan,Verkhniy Avzyah,Verkhniy Avzyan,Verkhniy Avzyano-Petrovsk,Верхний Авзян', 53.5288900, 57.5372200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119102, 'Verkhneye Kazanishche', 'Verkhneye Kazanishche', 'Verkhnee-Kazanishhe,Verkhneje-Kazanisjtsje,Verkhneye Kazanishche,Verkhniye Kazanishche,Verkhniye Kazanishchi,Верхнее-Казанище', 42.7354700, 47.1378000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119103, 'Verkhneyarkeyevo', 'Verkhneyarkeyevo', 'Jarkejewa,Verkhnejarkeevo,Verkhnejarkejevo,Verkhneyarkeyevo,Verxneyarkeevo,Yarkeyevo,fyrknyarkyyfw,Верхнеяркеево,Үрге Йәркәй,Վերխնեյարկեևո,فيركنياركييفو', 55.4504600, 54.3145500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119104, 'Verkhneural’sk', 'Verkhneural''sk', 'Verkhneural''sk,Verkhneuralsk,Verkhneural’sk,Верхнеуральск', 53.8769400, 59.2105600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119105, 'Verkhnetulomskiy', 'Verkhnetulomskiy', 'Verkhnetulomskij,Verkhnetulomskiy,Ylae-Tuuloma,Ylä-Tuuloma,Верхнетуломский', 68.6072700, 31.7962100, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119106, 'Verkhnedneprovskiy', 'Verkhnedneprovskiy', 'Verkhnedneprovskij,Verkhnedneprovskiy,Верхнеднепровский', 54.9813100, 33.3457300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119107, 'Verkhnechusovskiye Gorodki', 'Verkhnechusovskiye Gorodki', 'Chusovski Gorodki,Gorodki,Verkhne Chusovsk,Verkhnechusovskie Gorodki,Verkhnechusovskiye Gorodki,Verkhnetsjusovskije Gorodki,Верхнечусовские Городки', 58.1671000, 57.1086000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119108, 'Vereya', 'Vereya', 'Vereja,Vereya,Верея', 55.7737300, 39.0976600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119109, 'Vereya', 'Vereya', 'Vereja,Vereya,Верея', 55.6147200, 38.0391700, 'RU', '2014-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119110, 'Vereya', 'Vereya', 'Vereja,Vereya,Верея', 55.3447200, 36.1719400, 'RU', '2016-07-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119111, 'Vereshchagino', 'Vereshchagino', 'Bereshchagino,Bereshchangino,Vereshchagino,Vereshhagino,Veresjtsjagino,Верещагино', 58.0789400, 54.6557000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119112, 'Verbilki', 'Verbilki', 'Verbilki,Вербилки', 56.5333300, 37.6000000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119113, 'Ventsy', 'Ventsy', 'Vency,Ventsy,Ventsy-Zarya,Венцы', 45.3763900, 40.8358300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119114, 'Venëv', 'Venev', 'Venev,Venjov,Venëv,Венёв', 54.3553300, 38.2684300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119115, 'Vel’ye', 'Vel''ye', 'Vel''e,Vel''ye,Velje,Vel’ye,Велье', 56.9700500, 28.5788300, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119116, 'Vel’sk', 'Vel''sk', 'Bel''sk,Bel’sk,Vel''s''k,Vel''sk,Velsk,Vel’sk,Вельск,Вельськ', 61.0700600, 42.0983000, 'RU', '2015-06-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119117, 'Velizh', 'Velizh', 'Gorad Velizh,Velij,Veliz,Velizas,Velizh,Velizj,Veliĵ,Veliž,Veližas,Welisch,Wieliz,Wieliż,bellisi,fylyj,vu~eriji,wei li ri,wlyzh,Велиж,Веліж,Горад Веліж,فيليج,ولیژ,ヴェリジ,韦利日,벨리시', 55.6056400, 31.1967300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119118, 'Velikovechnoye', 'Velikovechnoye', 'Velikovechnoe,Velikovechnoye,Velikovetsjnoje,Velikoye,Великовечное', 44.9340200, 39.7549900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119119, 'Velikooktyabr’skiy', 'Velikooktyabr''skiy', 'Velikiy Oktyabr'',Velikiy Oktyabr’,Velikooktjabr''skij,Velikooktjabrskij,Velikooktyabr''skiy,Velikooktyabr’skiy,Великооктябрьский', 57.4333300, 33.8159500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119120, 'Velikodvorskiy', 'Velikodvorskiy', 'Velikodvorskij,Velikodvorskiy,Великодворский', 55.2499600, 40.6678000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119121, 'Velikiy Ustyug', 'Velikiy Ustyug', 'Usting Velikii,Usting Velikiĭ,VUS,Veliki Ustjug,Veliki Ustyug,Velikij Ustjug,Velikiy Ustyug,Veliky Ustyug,Великий Устюг', 60.7618600, 46.3135200, 'RU', '2017-04-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119122, 'Velikiye Luki', 'Velikiye Luki', 'VLU,Velikie Luki,Velikije Loeki,Velikije Luki,Velikiye Luki,Welikije Luki,Wielkie Luki,Wielkie Łuki,bellikiyeluki,Великие Луки,벨리키예루키', 56.3400000, 30.5451700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119123, 'Velikent', 'Velikent', 'Velikent,Великент', 42.1862600, 48.0628500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119124, 'Vedeno', 'Vedeno', 'Vedana,Vedeno,Vedenó,fydynw,vedeno,vu~ejeno,Ведана,Ведено,فيدينو,ვედენო,ヴェジェノ', 42.9689200, 46.0961100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119125, 'Vazhiny', 'Vazhiny', 'Skuratovo,Vaaseni,Vazhina,Vazhiny,Vazjiny,Важины', 60.9644400, 34.0222200, 'RU', '2016-09-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119126, 'Vavozh', 'Vavozh', 'Vavozh,Vavozj,Вавож', 56.7751300, 51.9309800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119127, 'Vatutino', 'Vatutino', 'Vatutine,Vatutino,Ватутино,Ватутіне', 55.8844100, 37.6905500, 'RU', '2016-07-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119128, 'Vatutinki', 'Vatutinki', 'Poselok Vatutinki,Posëlok Vatutinki,Vatutinki,Ватутинки', 55.4965000, 37.3298800, 'RU', '2015-09-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119129, 'Vasyurinskaya', 'Vasyurinskaya', 'Vasiurinskaja,Vasjurinskaja,Vasyurinskaya,Васюринская', 45.1180900, 39.4239900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119130, 'Vaskelovo', 'Vaskelovo', 'Troitskoye,Vaskela,Vaskelovo,Васкелово', 60.3957100, 30.3541900, 'RU', '2013-06-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119131, 'Vasil’yevskiy Mokh', 'Vasil''yevskiy Mokh', 'Tsentral''ny,Tsentral''nyy,Tsentral’ny,Tsentral’nyy,Vasil''evskij Mokh,Vasil''yevskiy Mokh,Vasilevski-Makh,Vasiljevskij Mokh,Vasil’yevskiy Mokh,Васильевский Мох', 57.0131600, 35.9189700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119132, 'Varygino', 'Varygino', 'Varygino,Варыгино', 56.7603400, 28.5351100, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119133, 'Varnavino', 'Varnavino', 'Varnavino,Варнавино', 57.4035100, 45.0916400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119134, 'Varlamovo', 'Varlamovo', 'Varlamovo,Варламово', 53.1897000, 48.4226000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119135, 'Varenikovskaya', 'Varenikovskaya', 'Varenikovo,Varenikovskaja,Varenikovskaya,Warenikowskaja,Варениковская', 45.1208500, 37.6417100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119136, 'Vardane', 'Vardane', 'Vardane,Вардане', 43.7317900, 39.5542800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119137, 'Valuyki', 'Valuyki', 'Valujki,Valuyki,Waluiki,Валуйки', 50.2035000, 38.1067000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119138, 'Valerik', 'Valerik', 'Valarg,Valarg Xi,Valarg khi,Valarg-Jurt,Valarg-Yurt,ValargtIe,Valargthe,Valerak,Valerik,Валарг,Валарг хи,Валарг-Юрт,ВаларгтІе,Валерик', 43.1797200, 45.4080600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119139, 'Valerianovsk', 'Valerianovsk', 'Valerianovsk,Валериановск', 58.7608000, 59.5596000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119140, 'Valday', 'Valday', 'Valdai,Valdaj,Valday,Waldai,baldai,Валдай,발다이', 57.9747200, 33.2525000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119141, 'Vakhtan', 'Vakhtan', 'Vakhtan,Valkhtan,Вахтан', 57.9659200, 46.6888600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119142, 'Vakhrushi', 'Vakhrushi', 'Vakhrushevo,Vakhrushi,Vakhrusji,Вахруши', 58.6847200, 50.0261100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119143, 'Vagonoremont', 'Vagonoremont', 'Vagonoremont,Вагоноремонт', 55.9000000, 37.5500000, 'RU', '2015-01-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119144, 'Vadinsk', 'Vadinsk', 'Kerensk,Vadinsk,Вадинск', 53.6915700, 43.0574400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119145, 'Vad', 'Vad', 'Vad,Вад', 55.5300900, 44.2113700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119146, 'Vacha', 'Vacha', 'Vacha,Vatsja,Вача', 55.8035000, 42.7709000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119147, 'Uzunovo', 'Uzunovo', 'Uzunovo,Узуново', 54.5385800, 38.6173400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119148, 'Uzlovaya', 'Uzlovaya', 'Ouzlovaia,Ouzlovaïa,Uslowaja,Uzlovaia,Uzlovaja,Uzlovaya,Uzlowaja,Uzłowaja,awzlwfaya,awzlwwaya,ujeullobaya,uzurovu~aya,wu zi luo wa ya,Узловая,Узловаја,أوزلوفايا,اوزلووایا,ウズロヴァヤ,烏茲洛瓦亞,우즐로바야', 53.9817900, 38.1711800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119149, 'Uyemskiy', 'Uyemskiy', 'Uemskij,Ujemskij,Uyemskiy,Uyma,Уемский', 64.4743000, 40.8524000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119150, 'Uvary', 'Uvary', 'Uvary,Увары', 46.0457500, 48.0355800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119151, 'Uvarovo', 'Uvarovo', 'Uvarovo,Уварово', 51.9848600, 42.2614700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119152, 'Uvarovka', 'Uvarovka', 'Uvarovka,Uvarovo,Уваровка', 55.5277800, 35.6061100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119153, 'Uva', 'Uva', 'Uva,Uya,Ува', 56.9908100, 52.1851700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119154, 'Utsmiyurt', 'Utsmiyurt', 'Ucmijurt,Utsmijurt,Utsmiyurt,Utsmu-Yurt,Уцмиюрт', 43.5348100, 46.4695200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119155, 'Utorgosh', 'Utorgosh', 'Utorgosh,Utorgosj,Уторгош', 58.2812700, 30.2534400, 'RU', '2012-06-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119156, 'Utevka', 'Utevka', 'Utevka,Утевка', 52.9035000, 50.9495000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119157, 'Utamysh', 'Utamysh', 'Utamysh,Utamysj,Утамыш', 42.4071800, 47.7510900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119158, 'Usvyaty', 'Usvyaty', 'Usvjaty,Usvyat,Usvyaty,Усвяты', 55.7455600, 30.7533300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119159, 'Usukhchay', 'Usukhchay', 'Usukhchaj,Usukhchay,Usukhtsjaj,Усухчай', 41.4224500, 47.9131800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119160, 'Ustyuzhna', 'Ustyuzhna', 'Gorad Uscjuzhna,Oustioujna,Ustiuzhna,Ustiuzna,Ustiużna,Ustjujna,Ustjuschna,Ustjushna,Ustjuzhna,Ustjuzjna,Ustjuzna,Ustjuĵna,Ustjužna,Ustuezn,Ustyuzhna,Ustüžn,awstywjna,awstywzhna,wu si qiu ri na,Горад Усцюжна,Устюжна,أوستيوجنا,اوستیوژنا,烏斯秋日納', 58.8394000, 36.4321000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119161, 'Ust’ye', 'Ust''ye', 'Ust''e,Ust''ye,Ust''ye-Kubinskoye,Ustje,Ust’ye,Ust’ye-Kubinskoye,Устье', 59.6304300, 39.7359600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119162, 'Ust-Tsilma', 'Ust-Tsilma', 'Chilimdin,UTS,Ust''-Cil''ma,Ust''-Tsil''ma,Ust-Cilma,Ust-Tsilma,Ust-Zilma,Ust’-Tsil’ma,Uszty-Cilma,Усть-Цильма,Чилимдiн,Ուստ-Ցիլմա', 65.4410400, 52.1497800, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119163, 'Ust’-Shonosha', 'Ust''-Shonosha', 'Ust''-Shenosha,Ust''-Shenovskaya,Ust''-Shonosha,Ust-Sjonosja,Ust’-Shenosha,Ust’-Shenovskaya,Ust’-Shonosha,Усть-Шоноша', 61.1531000, 41.3430000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119164, 'Ust’-Luga', 'Ust''-Luga', 'Laukaansuu,Lujski,Ust''-Luga,Ust-Luga,Ust’-Luga,Усть-Луга', 59.6675500, 28.2871300, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119165, 'Ust’-Labinsk', 'Ust''-Labinsk', 'Stanitsa Ust''-Labinskaya,Stanitsa Ust’-Labinskaya,Ust Labinskaja,Ust''-Labinsk,Ust''-Labinskaya,Ust-Labinsk,Ust’-Labinsk,Ust’-Labinskaya,Усть-Лабинск', 45.2107700, 39.6891400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119166, 'Ust’-Kulom', 'Ust''-Kulom', 'Ust''-Kulom,Ust-Kulom,Ust’-Kulom,Усть-Кулом', 61.6863600, 53.6902000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119167, 'Ust’-Kishert’', 'Ust''-Kishert''', 'Ust''-Kishert'',Ust-Kisjert,Ust’-Kishert’,Усть-Кишерть', 57.3654000, 57.2495000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119168, 'Ust’-Katav', 'Ust''-Katav', 'Ust''-Katav,Ust''-Katavskiy,Ust-Katav,Ust’-Katav,Ust’-Katavskiy,Усть-Катав', 54.9366000, 58.1757000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119169, 'Ust’-Kachka', 'Ust''-Kachka', 'Ust''-Kachka,Ust-Katsjka,Ust’-Kachka,Усть-Качка', 58.0038000, 55.6721000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119170, 'Ust’-Izhora', 'Ust''-Izhora', 'Inkereensuu,Inkerehensuu,Inkerehenšuu,Izhora,Izhorski,Ust''-Izhora,Ust-Izjora,Ust’-Izhora,Усть-Ижора', 59.8119400, 30.5813900, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119171, 'Ust’-Dzheguta', 'Ust''-Dzheguta', 'Dzhjogetej Ajaguy,Ust''-Dzh''gvaty,Ust''-Dzheguta,Ust''-Dzhegutinskaya,Ust''-Zhehguehteh,Ust-Dzekuta,Ust-Dzjeguta,Ust-Džekuta,Uste Dzhegutinskaya,Ust’-Dzheguta,Ust’-Dzhegutinskaya,Джёгетей Аягъы,Усть-Джегута,Усть-Джьгваты,Усть-Жэгуэтэ', 44.0834000, 41.9763000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119172, 'Ust’-Donetskiy', 'Ust''-Donetskiy', 'Kreslovskiy,Krestovskiy,Ust''-Doneckij,Ust''-Donetskiy,Ust-Donetskij,Ust’-Donetskiy,Усть-Донецкий', 47.6418900, 40.8718200, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119173, 'Uspenskoye', 'Uspenskoye', 'Uspenskaja,Uspenskaya,Uspenskoe,Uspenskoye,Успенская,Успенское', 44.8311000, 41.3927000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119174, 'Uspenskaya', 'Uspenskaya', 'Uspenskaja,Uspenskaya,Успенская', 45.7644800, 41.0669600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119175, 'Usol’ye', 'Usol''ye', 'Usol''e,Usol''ye,Usolje,Usol’ye,Усолье', 59.4219000, 56.6862000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119176, 'Usogorsk', 'Usogorsk', 'Usogorsk,Uzogorsk,Усогорск', 63.4106400, 48.6872200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119177, 'Usman’', 'Usman''', 'Usman,Usman'',Usman’,Усмань', 52.0466200, 39.7288000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119178, 'Usisha', 'Usisha', 'Usisha,Usisja,Усиша', 42.2511100, 47.3927800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119179, 'Urzhum', 'Urzhum', 'Urzhum,Urzjum,Уржум', 57.1141200, 49.9995600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119180, 'Uryv-Pokrovka', 'Uryv-Pokrovka', 'Uryv,Uryv-Pokovka,Uryv-Pokrovka,Uryvo-Pokrovskoye,Урыв,Урыв-Покровка', 51.1159000, 39.1639400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119181, 'Uryupinsk', 'Uryupinsk', 'Urjupinsk,Uryupinsk,Vrjupinsk,Урюпинск', 50.8047000, 42.0138000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119182, 'Urvan’', 'Urvan''', 'Urvan,Urvan'',Urvan’,Урвань', 43.4922200, 43.7605600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119183, 'Urussu', 'Urussu', 'Urussu,Уруссу', 54.5981200, 53.4631300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119184, 'Urus-Martan', 'Urus-Martan', 'Gorad Urus-Martan,Kh''alkha-Marta,Krasnoarmejskoe,Krasnoarmeyskoye,Oeroes-Martan,Ourous-Martan,Urus Martan,Urus-Martan,Urys-Martan,Urús-Martan,Urús-Martán,Xalxa-Marta,awrws-martan,uluseumaleutan,wu lu si-ma er tan,Горад Урус-Мартан,Красноармейское,Урус-Мартан,Урус-Мартан балһсн,Урыс-Мартан,Хьалха-Марта,ХӀахӀа-Марта,أوروس-مارتان,اوروس-مارتان,Ẋalxa-Marta,ウルス・マルタン,烏魯斯-馬爾坦,우루스마르탄', 43.1305300, 45.5379100, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119185, 'Urukh', 'Urukh', 'Urukh,Урух', 43.2933500, 44.0264700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119186, 'Urshel’skiy', 'Urshel''skiy', 'Rabochiy Poselok Urshel,Rabochiy Posëlok Urshel,Urshel'',Urshel''skij,Urshel''skiy,Urshel’,Urshel’skiy,Urshetskiy,Ursjelskij,Уршельский', 55.6783300, 40.2169200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119187, 'Urozhaynoye', 'Urozhaynoye', 'Urozhajnoe,Urozhaynoye,Urozjajnoje,Урожайное', 44.7883300, 44.9227800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119188, 'Urmary', 'Urmary', 'Urmary,Урмары', 55.6789400, 47.9439600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119189, 'Urman', 'Urman', 'Urman,Урман', 54.8831400, 56.8741700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119190, 'Urma', 'Urma', 'Urma,Урма', 42.5389400, 47.2863900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119191, 'Urkarakh', 'Urkarakh', 'Urkarakh,Уркарах', 42.1629700, 47.6306800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119192, 'Uritsk', 'Uritsk', 'Urick,Uritsk,Урицк', 59.8388900, 30.1752800, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119193, 'Uren’', 'Uren''', 'Uren,Uren'',Uren’,Урень', 57.4551600, 45.7852200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119194, 'Urdoma', 'Urdoma', 'Nyanda,Urdoma,Урдома', 61.7533500, 48.5442000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119195, 'Urazovo', 'Urazovo', 'Urazov,Urazova,Urazovo,Уразово', 50.0836000, 38.0395000, 'RU', '2011-04-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119196, 'Urazovka', 'Urazovka', 'Aptyarovka,Urazovka,Уразовка', 55.4012600, 45.6186000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119197, 'Uralets', 'Uralets', 'Krasny Priisk,Krasnyy Ural,Krasnyy Ural Priisk,Uralec,Uraleis,Uralets,Уралец', 57.6614000, 59.6497000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119198, 'Upornaya', 'Upornaya', 'Upornaja,Upornaya,Упорная', 44.3914000, 41.0196000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119199, 'Untsukul’', 'Untsukul''', 'Uncukl'',Uncukul'',Untsukul,Untsukul'',Untsukuli,Untsukul’,Унцукль,Унцукуль', 42.7114900, 46.7866300, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119200, 'Uni', 'Uni', 'Uni,Уни', 57.7510000, 51.4913000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119201, 'Undory', 'Undory', 'Bol''shiye Undory,Bol’shiye Undory,Undory,Ундоры', 54.6084900, 48.3927600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119202, 'Unecha', 'Unecha', 'Uncha,Unecha,Unetscha,Unetsja,Унеча', 52.8459100, 32.6739400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119203, 'Umet', 'Umet', 'Umet,Umjot,Умет,Умёт', 54.1161100, 42.6975000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119204, 'Umba', 'Umba', 'Lesnoi,Lesnoy,Lessnoi,Poselok Lesnoy,Posëlok Lesnoy,Umba,Умба', 66.6870600, 34.3429100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119205, 'Ulyanovsk', 'Ulyanovsk', 'Chemper,Gorad Ul''janausk,Oeljanofsk,Oeljanovsk,Oulianofsk,Oulianovsk,Oulyanovsk,Owlyanovsk,Sember,Simbir,Simbirsk,Sinbirsk,ULY,Ul''janon'' osh,Ul''janovs''k,Ul''janovsk,Ul''yanovsk,Ulanovsk,Ulianovsk,Uliànovsk,Uliánovsk,Uljanovsk,Uljanovska,Uljanovskas,Uljanovsko,Uljanovszk,Uljanowsk,Uljanowska am Wolga,Ulyanovsk,Ul’yanovsk,Uļjanovska,alyanwwsk,awlyanwfsk,awlyanwwsk,uliyanobhaska,ulliyanobseukeu,ulyanovska,uriyanofusuku,wu li yang nuo fu si ke,Ουλιάνοφσκ,Горад Ульянаўск,Оулиꙗновьскъ,Сембер,Синбирск,Сімбір,Ульяновск,Ульяновськ,Ульянонь ош,Уляновск,Улјановск,Уљановск,Чĕмпĕр,Ուլյանովսկ,אוליאנובסק,أوليانوفسك,الیانووسک,اولیانوفسک,اولیانووسک,उल्यानोव्स्क,উলিয়ানোভস্ক,ウリヤノフスク,乌里扬诺夫斯克,울리야놉스크', 54.3282400, 48.3865700, 'RU', '2016-05-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119206, 'Ul’yanovka', 'Ul''yanovka', 'Possyelok Ulyanovka,Ul''janovka,Ul''l''ana,Ul''yanovka,Uljana,Uljanovka,Ul’yanovka,Ульяновка', 59.6394400, 30.7647200, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119207, 'Ulu-Telyak', 'Ulu-Telyak', 'Ulu-Teljak,Ulu-Telyak,Улу-Теляк', 54.9157000, 56.9827000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119208, 'Ulukulevo', 'Ulukulevo', 'Ulukulevo,Улукулево', 54.4355000, 56.3221000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119209, 'Ullubiyaul', 'Ullubiyaul', 'Ullubij-Aul,Ullubijaul,Ullubiyaul,Уллубий-Аул,Уллубийаул', 42.5968900, 47.7182500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119210, 'Ulluaya', 'Ulluaya', 'Ullu-Aja,Ulluaja,Ulluaya,Уллу-Ая,Уллуая', 42.3737700, 47.3745100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119211, 'Ukhta', 'Ukhta', 'Chib''yu,Chib’yu,Gorad Ukhta,Oechta,Oukhta,UCT,Uchta,Uht,Uhta,Ujta,Ujtá,Ukhta,Ukhtà,Ukva,Uĥta,awkhta,uheuta,wu he ta,Горад Ухта,Уква,Ухта,أوختا,اوختا,乌赫塔,우흐타', 63.5670500, 53.6834800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119212, 'Ukholovo', 'Ukholovo', 'Ukholovo,Ухолово', 53.7929000, 40.4892000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119213, 'Uinskoye', 'Uinskoye', 'Uinskoe,Uinskoje,Uinskoye,Уинское', 56.8817400, 56.5813500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119214, 'Ugra', 'Ugra', 'Ugra,Угра', 54.7777500, 34.3267400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119215, 'Uglyanets', 'Uglyanets', 'Ugljanec,Ugljanets,Uglyanets,Углянец', 51.8190800, 39.5960600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119216, 'Uglovka', 'Uglovka', 'Owglovka,Uglovka,Угловка,Ուգլովկա', 58.2391700, 33.5108300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119217, 'Uglich', 'Uglich', 'Oeglitsj,Ouglitch,Ugich,Uglic,Uglich,Uglicz,Uglitsch,Ugliĉ,ugeullichi,Угич,Углич,우글리치', 57.5275000, 38.3316700, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119218, 'Ugleural’skiy', 'Ugleural''skiy', 'Polovinda,Polovinka,Polovinskiy,Ugeural''skiy,Ugeural’skiy,Ugleural''sk,Ugleural''skij,Ugleural''skiy,Ugleuralskij,Ugleural’sk,Ugleural’skiy,Voroshilovskiy,Половинка,Углеуральский', 58.9443000, 57.5937000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119219, 'Uglerodovskiy', 'Uglerodovskiy', 'Poselok Shakhty Uglerod,Roseta,Rozeta,Uglerod,Uglerodovs''kyy,Uglerodovsij,Uglerodovskij,Uglerodovskiy,Uglerodovs’kyy,Углеродовсий,Углеродовский', 48.1455800, 40.0635200, 'RU', '2014-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119220, 'Uglegorskiy', 'Uglegorskiy', 'Uglegorskij,Uglegorskiy,Углегорский', 48.2427400, 41.2531000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119221, 'Ufimskiy', 'Ufimskiy', 'Ufimka,Ufimskij,Ufimskiy,Уфимский', 56.7084000, 58.0517000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119222, 'Ufa', 'Ufa', 'Ephu,Gorad Ufa,Oefa,Oufa,Owfa,UFA,Uf,Ufa,Ufà,Ufá,Ufа,Upo,awfa,ufa,upa,wu fa,Ĕпхӳ,Горад Уфа,Оуфа,Уфа,Үфі,Өфө,Ӱпӧ,Ուֆա,אופה,أوفا,اوفا,ऊफ़ा,უფა,ウファ,烏法,우파', 54.7430600, 55.9677900, 'RU', '2014-01-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119223, 'Udobnaya', 'Udobnaya', 'Udobnaja,Udobnaya,Удобная', 44.1932000, 41.5529000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119224, 'Udimskiy', 'Udimskiy', 'Udimskij,Udimskiy,Удимский', 61.1417100, 45.9144300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119225, 'Udel’naya', 'Udel''naya', 'Prigorod Udel''naya,Prigorod Udel’naya,Udel''naja,Udel''naya,Udel’naya,Удельная', 60.0163600, 30.3181500, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119226, 'Udel’naya', 'Udel''naya', 'Udel''naja,Udel''naya,Udel''noye,Udel’naya,Udel’noye,Удельная', 55.6253600, 38.0028500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119227, 'Uchkulan', 'Uchkulan', 'Madniskhevi,Uchkulan,Uchkulon,Utschkulon,Utsjkulan,Учкулан', 43.4570500, 42.0964300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119228, 'Uchkeken', 'Uchkeken', 'Uchkeken,Utsjkeken,Учкекен', 43.9377800, 42.5116700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119229, 'Uchaly', 'Uchaly', 'Uchaly,Utsjaly,Учалы', 54.3580600, 59.4361100, 'RU', '2013-08-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119230, 'Uchaly', 'Uchaly', 'Uchaly,Utsjaly,Учалы', 54.2996000, 59.4521000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119231, 'Tyulyachi', 'Tyulyachi', 'Tjuljachi,Tjuljatsji,Tyulyachi,Тюлячи', 55.8912500, 50.2399200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119232, 'Tyul’gan', 'Tyul''gan', 'Tjul''gan,Tjulgan,Tyul''gan,Tyul’gan,Тюльган', 52.3404900, 56.1660400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119233, 'Tyrnyauz', 'Tyrnyauz', 'Gorad Tyrnyauz,Kuruukuueh,Tirniauz,Tirnijauz,Tyrny-Aus,Tyrnyaoez,Tyrnyaouz,Tyrnyaus,Tyrnyauz,Tyrnyavyz,te er nei ao zi,tyrnyawz,tyrnyaywz,Горад Тырныауз,Къруукъуэ,Тирниауз,Тирнијауз,Тырныавыз,Тырныауз,Тырныауз балһсн,تيرنياوز,تیرنیائوز,特爾內奧茲', 43.3827800, 42.9183300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119234, 'Tyarlevo', 'Tyarlevo', 'Taeroelae,Tjarlevo,Tyarlevo,Tärölä,Тярлево', 59.7077700, 30.4454300, 'RU', '2017-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119235, 'Tver', 'Tver', 'Gorad Cver,KLD,Kalinin,Tueria,Tver,Tver'',Tvera,Tvere,Tverj,Tverė,Tver’,Twer,t weiyr,tbr,te wei er,teubeli,tfyr,tibhera,tiver,tovu~eri,twr,twwr,Горад Цвер,Калинин,Твер,Тверь,Տվեր,טבר,تفير,تور,توور,তিভের,திவெர்,ตเวียร์,ტვერი,トヴェリ,特维尔,트베리', 56.8583600, 35.9005700, 'RU', '2016-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119236, 'Tuzha', 'Tuzha', 'Tuzha,Tuzja,Тужа', 57.6061500, 47.9359700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119237, 'Tuymazy', 'Tuymazy', 'Tuimasa,Tuimazy,Tujmazi,Tujmazy,Tuymaza,Tuymazy,Туймазы', 54.6066600, 53.7097000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119238, 'Tutayev', 'Tutayev', 'Romanovo-Borisoglebsk,Tutaev,Tutajev,Tutamev,Tutayev,Tutayevo,Тутаев', 57.8852900, 39.5406000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119239, 'Turki', 'Turki', 'Turki,Турки', 51.9870300, 43.2731000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119240, 'Turgenevo', 'Turgenevo', 'Turgenevo,Тургенево', 54.8455500, 46.3296800, 'RU', '2016-07-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119241, 'Tunoshna', 'Tunoshna', 'IAR,Tunoshna,Tunoshnoye,Tunosjna,Туношна', 57.5458900, 40.1254300, 'RU', '2013-07-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119242, 'Tumak', 'Tumak', 'Tumak,Тумак', 46.2343600, 48.5062700, 'RU', '2017-03-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119243, 'Tuma', 'Tuma', 'Tuma,Тума', 55.1479800, 40.5537400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119244, 'Tul’skiy', 'Tul''skiy', 'Tul''skaya,Tul''skij,Tul''skiy,Tulskij,Tul’skaya,Tul’skiy,Тульский', 44.5136100, 40.1788900, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119245, 'Tula', 'Tula', 'Gorad Tula,TYA,Toela,Toula,Tul,Tula,Tula i Russland,Tulae,Tulo,Tuła,Tûla,to~ura,tu la,tulla,twla,twla  rws,twlh,Τούλα,Горад Тула,Тулæ,Тулă,Тула,Туло,Տուլա,טולה,تولا,تولا، روس,ٹولا,ტულა,トゥーラ,圖拉,툴라', 54.1960900, 37.6182200, 'RU', '2013-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119246, 'Tukan', 'Tukan', 'Tukan,Тукан', 53.8409000, 57.4552000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119247, 'Tugolesskiy Bor', 'Tugolesskiy Bor', 'Tugolesskij Bor,Tugolesskiy Bor,Туголесский Бор', 55.5505100, 39.8242200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119248, 'Tuchkovo', 'Tuchkovo', 'Tuchkovo,Tutsjkovo,Тучково', 55.6011100, 36.4680600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119249, 'Tubinskiy', 'Tubinskiy', 'Tubinskij,Tubinskiy,Tubinskiy Rudnik,Тубинский', 52.8891700, 58.2225000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119250, 'Tuapse', 'Tuapse', 'Gorad Tuapseh,Toeapse,Touapse,Touapsé,Tuapse,Tuapseo,Tuapsse,Tuapsé,to~uapuse,tu a pu xie,tu''apse,tuabse,twabsy,twapsh,Горад Туапсэ,Туапсе,Туапсе балһсн,ТӀуапсы,Տուապսե,توآپسے,توابسي,تواپسه,टुआप्से,ტუაფსე,トゥアプセ,圖阿普謝,투압세', 44.1053000, 39.0802000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119251, 'Tsurib', 'Tsurib', 'Curib,Tsurib,Цуриб', 42.2368000, 46.8307300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119252, 'Tsivil’sk', 'Tsivil''sk', 'Civil''sk,Tsibil''sk,Tsibil’sk,Tsivil''sk,Tsivilsk,Tsivil’sk,Цивильск', 55.8697400, 47.4787400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119253, 'Tsimlyansk', 'Tsimlyansk', 'Cimljansk,Tsimljansk,Tsimlyansk,Tsimlyanskaya,Tsimlyanskiy,Tsymlyanskaya,Zymljanskaja,Цимлянск', 47.6461100, 42.1019400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119254, 'Tsil’na', 'Tsil''na', 'Cil''na,Tsil''na,Tsil''ninskiy,Tsilna,Tsil’na,Tsil’ninskiy,Цильна', 54.5953300, 48.1414000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119255, 'Tsentoroy', 'Tsentoroy', 'Catanyh,Catanykh,Centaroj,Centaroy,Centoroj,Tsatani,Tsatanikh,Tsatanykh,Tsentoroj,Tsentoroy,Tsontoroy,Цатаных,Центарой,Центорой', 43.0065800, 46.2223500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119256, 'Tselina', 'Tselina', 'Celina,Tselina,Zelina,Целина', 46.5338100, 41.0328400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119257, 'Tsagan Aman', 'Tsagan Aman', 'Burunnyy,Burunskiy,Cagan Aman,Stavka,Tsagan Aman,Цаган Аман', 47.5639000, 46.7218000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119258, 'Trunovskoye', 'Trunovskoye', 'Ternovka,Ternovskoye,Trunovskoe,Trunovskoje,Trunovskoye,Труновское', 45.4877800, 42.1358300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119259, 'Trudobelikovskiy', 'Trudobelikovskiy', 'Trudobelikovskij,Trudobelikovskiy,Трудобеликовский', 45.2685300, 38.1537600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119260, 'Trudfront', 'Trudfront', 'Trudfront,Трудфронт', 45.9346000, 47.6692900, 'RU', '2017-03-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119261, 'Trubchevsk', 'Trubchevsk', 'Trubchevsk,Trubchëvsk,Trubtschewsk,Trubtsjevsk,Трубчевск', 52.5798000, 33.7644000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119262, 'Trosna', 'Trosna', 'Efratovo,Trosna,Yefratovo,Тросна', 52.4446000, 35.7791000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119263, 'Troparëvo', 'Troparevo', 'Troparevo,Troparjovo,Troparëvo,Тропарёво', 55.6562500, 37.4849600, 'RU', '2016-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119264, 'Troitskoye', 'Troitskoye', '', 55.3000000, 38.5333300, 'RU', '2006-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119265, 'Troitskoye', 'Troitskoye', 'Bulgn selaen,Bulgun,Bulğn selän,Bulһn selən,Troickoe,Troitskoje,Troitskoye,Булһн селән,Троицкое', 46.4206000, 44.2591000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119266, 'Troitskoye', 'Troitskoye', 'Troickoe,Troitskiy,Troitskoje,Troitskoye,Троицкое', 43.7621900, 44.6841500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119267, 'Troitsko-Pechorsk', 'Troitsko-Pechorsk', 'Troicko Pechorsk,Troitsko Petsjorsk,Troitsko-Pechorsk,Troitsko-Pechorskoye,Троицко Печорск', 62.7083600, 56.1964300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119268, 'Troitskiy', 'Troitskiy', 'Troickij,Troitskiy,Троицкий', 51.3588000, 37.5253000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119269, 'Troitskaya', 'Troitskaya', 'Troickaja,Troitskaja,Troitskaya,Троицкая', 45.1349300, 38.1254400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119270, 'Troitskaya', 'Troitskaya', 'Troickaja,Troitskaja,Troitskaya,Троицкая', 43.3066400, 44.9839500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119271, 'Troitsk', 'Troitsk', 'Troick,Troickaj,Troitsk,Troitsk i Moskva oblast,Troizk,Troïtsk,te luo yi ci ke,trwytsk,trwytsk  awblast mskw,Троицк,Троицкай,تروئتسک,ترويتسك,ترویتسک، اوبلاست مسکو,特羅伊茨克', 55.4849800, 37.3073600, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119272, 'Tpig', 'Tpig', 'Tpig,Тпиг', 41.7800700, 47.5889600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119273, 'Tovarkovskiy', 'Tovarkovskiy', 'Imeni Kaganovicha,Kaganovich,Tovarkovo,Tovarkovskij,Tovarkovskiy,Товарково,Товарковский', 53.6821700, 38.2092000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119274, 'Tovarkovo', 'Tovarkovo', 'Tovarkovo,Товарково', 54.6761700, 35.9386000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119275, 'Totskoye', 'Totskoye', 'Tockoe,Totskaya,Totskoje,Totskoye,Tozkoje,Тоцкое', 52.5247800, 52.7622800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119276, 'Tot’ma', 'Tot''ma', 'Tot''ma,Totma,Tot’ma,Тотьма', 59.9737500, 42.7648700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119277, 'Tosno', 'Tosno', 'Gorad Tosna,Tosno,Tusina,tuo si nuo,twsnw,Горад Тосна,Тосно,توسنو,ტოსნო,托斯諾', 59.5400000, 30.8775000, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119278, 'Torzhok', 'Torzhok', 'Gorad Tarzhok,Torjok,Torschok,Torshok,Torzhok,Torzjok,Torzok,Torĵok,Torżok,Toržok,toleujokeu,torujoku,tuo er ruo ke,twrjwk,twrzhwk,Горад Таржок,Торжок,تورجوك,تورژوک,トルジョーク,托爾若克,토르조크', 57.0436000, 34.9622100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119279, 'Toropets', 'Toropets', 'Gorad Taropec,Toropec,Toropec'',Toropetia,Toropets,Toropez,Toropiec,Toropjec,Torópets,tolopecheu,toropetsu,tuo luo pei ci,twrwbts,twrwpts,Горад Таропец,Торопетс,Торопец,Торопець,توروبتس,توروپتس,トロペツ,托羅佩茨,토로페츠', 56.4977900, 31.6352800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119280, 'Torfyanoy', 'Torfyanoy', 'Torfjanoj,Torfyanoy,Торфяной', 58.4916000, 49.1978600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119281, 'Torbeyevo', 'Torbeyevo', 'Torbeevo,Torbejevo,Torbeyevo,Торбеево', 54.0797200, 43.2473200, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119282, 'Tonshayevo', 'Tonshayevo', 'Tonshaevo,Tonshayevo,Tonsjajevo,Тоншаево', 57.7359800, 47.0126500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119283, 'Tonkino', 'Tonkino', 'Tonkino,Тонкино', 57.3725700, 46.4629400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119284, 'Tomsino', 'Tomsino', 'Tomeino,Tomsino,Томсино', 56.4506700, 28.5390500, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119285, 'Tomilino', 'Tomilino', 'Tomilino,Томилино', 55.6561900, 37.9471300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119286, 'Tomarovka', 'Tomarovka', 'Tomarovka,Томаровка', 50.6833800, 36.2330900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119287, 'Tol’yatti', 'Tol''yatti', 'Stavropol'',Stavropol’,Stawropol,Togliatti,Togliatti-on-the-Volga,Togliattigrad,Tol''jatti,Tol''yatti,Tolati,Toliatti,Toljati,Toljatti,Tolyatti,Tol’yatti,tolliyati,toriyatchi,Ставрополь,Тольятти,Тољати,トリヤッチ,톨리야티', 53.5303000, 49.3461000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119288, 'Tolstoy-Yurt', 'Tolstoy-Yurt', 'Stari Yurt,Staryy Yurt,Tolstoj-Jurt,Tolstov-Jurt,Tolstov-Yurt,Tolstovo,Tolstoy-Yurt,Толстов-Юрт,Толстой-Юрт', 43.4454800, 45.7790100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119289, 'Tolstopal’tsevo', 'Tolstopal''tsevo', 'Poselok Tolstopal''tsevo,Posëlok Tolstopal’tsevo,Tolstopal''cevo,Tolstopal''tsevo,Tolstopal’tsevo,Толстопальцево', 55.6102600, 37.2183400, 'RU', '2014-09-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119290, 'Tolmachevo', 'Tolmachevo', 'Tolmachevo,Tolmatsjevo,Толмачево', 58.8597300, 29.9109100, 'RU', '2015-09-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119291, 'Tolbazy', 'Tolbazy', 'Tolbazy,Толбазы', 54.0240800, 55.8824800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119292, 'Toksovo', 'Toksovo', 'Toksova,Toksovo,Toksowo,Токсово', 60.1532300, 30.5164600, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119293, 'Tlyustenkhabl’', 'Tlyustenkhabl''', 'Tljustenchablj,Tljustenkhabl'',Tljustinkhabl'',Tlyustenkhabl'',Tlyustenkhabl’,Тлюстенхабль,Тлюстинхабль', 44.9820000, 39.0977300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119294, 'Tlyarata', 'Tlyarata', 'Tljarata,Tlyarata,Tlyarota,Тлярата', 42.1040800, 46.3559000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119295, 'Tishchenskoye', 'Tishchenskoye', 'Gishchenskoye,Tishchenskoye,Tishhenskoe,Tisjtsjenskoje,Тищенское', 45.4605600, 41.6738200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119296, 'Tirlyanskiy', 'Tirlyanskiy', 'Tirljanskij,Tirlyanskiy,Tirlyanskiy Zavod,Тирлянский', 54.2109000, 58.5806000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119297, 'Timashëvsk', 'Timashevsk', 'Timashevsk,Timashevskaya,Timashjovsk,Timashëvsk,Timashëvskaya,Timasjevsk,Timoschewskaja,Timoshevskaya,Тимашёвск', 45.6169400, 38.9452800, 'RU', '2011-11-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119298, 'Tim', 'Tim', 'Tim,Тим', 51.6222200, 37.1244400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119299, 'Tikhvin', 'Tikhvin', 'Gorad Cikhvin,Tichvin,Tichvina,Tichwin,Tihvin,Tihvina,Tihvinae,Tihvinä,Tijvin,Tikhvin,Tikhvine,Tikhvinu,Tiĥvin,chifuvu~in,ji he wen,tiheubin,tikhvin,tykhfyn,tykhwyn,Горад Ціхвін,Тихвин,Тихвинъ,Тихвін,تيخفين,تیخوین,ტიხვინი,チフヴィン,季赫溫,티흐빈', 59.6451100, 33.5293700, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119300, 'Tikhoretsk', 'Tikhoretsk', 'Gorad Cikharehck,Tichoreck,Tichoretsk,Tichorezk,Tichorieck,Tihhoretsk,Tihoreck,Tihoretk,Tihorețk,Tijoretsk,Tikhorec''k,Tikhoreck,Tikhoretsk,Tixoretsk,Tiĥoreck,ji huo lie ci ke,tykhwrtsk,tykhwrytsk,Горад Ціхарэцк,Тихоретск,Тихорецк,Тихорецк балһсн,Тихорєцьк,Տիխորեցկ,تيخورتسك,تیخورتسک,تیخوریتسک,季霍列茨克', 45.8547200, 40.1252800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119301, 'Teykovo', 'Teykovo', 'Teikovo,Teikowo,Tejkovo,Tejkowo,Teykovo,Teïkovo,Téikovo,jie yi ke wo,tykwfw,Тейково,Тејково,تيكوفو,تیکوفو,捷伊科沃', 56.8579600, 40.5369200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119302, 'Adygeysk', 'Adygeysk', 'Adigejsk,Adigeysk,Adygeisk,Adygeiskas,Adygejsk,Adygeysk,Teuchezhsk,adigeiseukeu,adigejsk,adygejsk,Адигејск,Адыгейск,아디게이스크', 44.8841400, 39.1907100, 'RU', '2016-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119303, 'Tetyushi', 'Tetyushi', 'Tetjushi,Tetjusji,Tetyushi,Тетюши', 54.9382100, 48.8365600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119304, 'Teryayevo', 'Teryayevo', 'Terjaevo,Teryayeva Sloboda,Teryayevo,Теряево', 56.1697400, 36.1254500, 'RU', '2010-06-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119305, 'Terskol', 'Terskol', 'Terskol,Терскол', 43.2552800, 42.5152800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119306, 'Terskaya', 'Terskaya', 'Terskaja,Terskaya,Терская', 43.7237600, 44.7244200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119307, 'Tersa', 'Tersa', 'Tersa,Терса', 52.0867100, 47.5393600, 'RU', '2014-10-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119308, 'Ternevskaya', 'Ternevskaya', 'Ternevskaja,Ternevskaya,Ternovskaja,Ternovskaya,Терневская,Терновская', 45.8513000, 40.4125000, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119309, 'Ternovka', 'Ternovka', 'Ternovka,Терновка', 51.6780300, 41.6375000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119310, 'Teribërka', 'Teriberka', 'Teriberka,Teribërka,Териберка', 69.1608800, 35.1452700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119311, 'Tereze', 'Tereze', 'Tereze,Терезе', 43.9360800, 42.4434000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119312, 'Terekli-Mekteb', 'Terekli-Mekteb', 'Terekli-Mekteb,Терекли-Мектеб', 44.1671000, 45.8697500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119313, 'Terek', 'Terek', 'Terek,Терек', 43.4833300, 44.1361100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119314, 'Terbuny', 'Terbuny', 'Terbuny,Тербуны', 52.1493000, 38.2834000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119315, 'Tyoply Stan', 'Tyoply Stan', 'Nizhniy Teplyy Stan,Tjoplyj Stan,Тёплый Стан', 55.6204700, 37.4933800, 'RU', '2016-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119316, 'Tëploye', 'Teploye', 'Teploe,Teploje,Teploye,Tëploye,Теплое', 53.6202200, 37.5902600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119317, 'Tëplaya Gora', 'Teplaya Gora', 'Teplaja Gora,Teplaya Gora,Tjoplaja Gora,Tëplaya Gora,Теплая Гора,Тёплая Гора', 58.5244400, 59.0727800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119318, 'Ten’gushevo', 'Ten''gushevo', 'Ten''gushevo,Tengusjevo,Ten’gushevo,Теньгушево', 54.7686100, 42.7188900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119319, 'Temyasovo', 'Temyasovo', 'Temjasovo,Temyasovo,Темясово', 52.9933300, 58.1013900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119320, 'Temryuk', 'Temryuk', 'Temrjuk,Temryuk,Tyemryuk,Темрюк', 45.2705500, 37.3871600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119321, 'Temnikov', 'Temnikov', 'Chopolt osh,Gorad Cemnikau,Temnikav,Temnikov,Temnikow,Tiemnikow,Tyemnyikov,jie mu ni ke fu,tmnykwf,Горад Цемнікаў,Темникав,Темников,Темников балһсн,Төмән,Чополт ош,تمنيكوف,تمنیکوف,捷姆尼科夫', 54.6302300, 43.2148300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119322, 'Tëmkino', 'Temkino', 'Temkino,Tjomkino,Tëmkino,Тёмкино', 55.1091700, 35.0138900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119323, 'Temizhbekskaya', 'Temizhbekskaya', 'Temizhbekskaja,Temizhbekskaya,Temizhbekskij,Temizhbekskiy,Temizjbekskij,Темижбекская,Темижбекский', 45.4507800, 41.0386600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119324, 'Temizhbekskaya', 'Temizhbekskaya', 'Temizhbekskaja,Temizhbekskaya,Temizjbekskaja,Tyemizhbekskaya,Темижбекская', 45.4455600, 40.8450000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119325, 'Temirgoyevskaya', 'Temirgoyevskaya', 'Temirgoevskaja,Temirgofewskaja,Temirgojevskaja,Temirgoyevskaya,Темиргоевская', 45.1141400, 40.2802700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119326, 'Temiraul', 'Temiraul', 'Temir-Aul,Temiraul,Темир-Аул,Темираул', 43.2532200, 46.8254000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119327, 'Tekstil’shchiki', 'Tekstil''shchiki', 'Poselok Tekstil''shchiki,Poselok Tekstil’shchiki,Sadki,Tekstil''shchiki,Tekstil''shhiki,Tekstil’shchiki,Текстильщики', 55.7003300, 37.7427100, 'RU', '2016-04-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119328, 'Teberda', 'Teberda', 'Gorad Cebjarda,Kuabardea,Teberd,Teberda,Teberdi,jie bie er da,tbrda,Горад Цебярда,Къабардеа,Теберда,Теберда балһсн,Теберди,تبردا,捷別爾達', 43.4456500, 41.7448000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119329, 'Tbilisskaya', 'Tbilisskaya', 'Tbilisskaja,Tbilisskaya,Tiflisskaya,Тбилисская', 45.3633300, 40.1900000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119330, 'Taytsy', 'Taytsy', 'Taaitsa,Taitsyb,Tajcy,Tajtsy,Taytsy,Тайцы', 59.6644400, 30.1147200, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119331, 'Tatsinskiy', 'Tatsinskiy', 'Tacinskaja,Tacinskij,Tatsinskaya,Tatsinskiy,Tazinskaja,Тацинская,Тацинский', 48.1967700, 41.2755800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119332, 'Tatishchevo', 'Tatishchevo', 'Tatishchev,Tatishchevo,Tatishhevo,Tatutsevo,Татищево', 51.6702800, 45.5952800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119333, 'Tatarskaya Pishlya', 'Tatarskaya Pishlya', 'Tatarskaja Pishlja,Tatarskaja Pisjlja,Tatarskaya Pishlya,Татарская Пишля', 54.0608500, 44.8997800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119334, 'Tatarskaya Kargala', 'Tatarskaya Kargala', 'Kagalinski,Kargala,Kargalinskiy,Tatarskaja Kargala,Tatarskaya Kargala,Каргала,Татарская Каргала', 51.9495200, 55.1731400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119335, 'Tatarka', 'Tatarka', 'Tatarka,Tatarskoye,Татарка', 44.9588900, 41.9517100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119336, 'Tashla', 'Tashla', 'Tasala,Tashla,Tasjla,Ташла', 51.7715700, 52.7427000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119337, 'Tarusa', 'Tarusa', 'Gorad Tarusa,Taroussa,Tarusa,Taruso,Tarussa,ta lu sa,talusa,tarusa,tarwsa,tarywsa,Горад Таруса,Таруса,Тарусо,تاروسا,تاريوسا,タルーサ,塔魯薩,타루사', 54.7243600, 37.1727200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119338, 'Tarumovka', 'Tarumovka', 'Tarumovka,Тарумовка', 44.0760600, 46.5361300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119339, 'Tarskoye', 'Tarskoye', 'Angusht,Angushty,Tarskoe,Tarskoje,Tarskoye,Тарское', 42.9669900, 44.7711400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119340, 'Tarnogskiy Gorodok', 'Tarnogskiy Gorodok', 'Tarnogskij-Gorodok,Tarnogskiy Gorodok,Тарногский-Городок', 60.4997200, 43.5761100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119341, 'Tarki', 'Tarki', 'Tarki,Тарки', 42.9442300, 47.4952700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119342, 'Tarkhovka', 'Tarkhovka', 'Tarhovka,Tarkhovka,Тарховка', 60.0668700, 29.9743500, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119343, 'Taremskoye', 'Taremskoye', 'Taremskoe,Taremskoje,Taremskoye,Таремское', 55.9288900, 43.0443300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119344, 'Tarasovskiy', 'Tarasovskiy', 'Tarasovka,Tarasovskij,Tarasovskiy,Verkhne-Tarasovka,Тарасовский', 48.7272700, 40.3626700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119345, 'Tarasovka', 'Tarasovka', 'Tarasovka,Тарасовка', 55.9572200, 37.8433300, 'RU', '2017-03-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119346, 'Tambovka', 'Tambovka', 'Tambovka,Tambowskoje,Тамбовка', 47.3152800, 47.3777300, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119347, 'Tambov', 'Tambov', 'Gorad Tambou,TBW,Tambof,Tambov,Tambova,Tambovas,Tambovia,Tambow,Tombu,tambopeu,tambwf,tan bo fu,tanbofu,tmbwb,Горад Тамбоў,Тамбов,Томбу,טמבוב,تامبوف,ტამბოვი,タンボフ,坦波夫,탐보프', 52.7316900, 41.4432600, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119348, 'Taman’', 'Taman''', 'Taman,Taman'',Tamanskaja,Tamanskaya,Taman’,Тамань', 45.2117000, 36.7160900, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119349, 'Tamala', 'Tamala', 'Tamala,Тамала', 52.5409700, 43.2514500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119350, 'Talovyy', 'Talovyy', 'Talovyj,Talovyy,Таловый', 47.8076500, 40.1094300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119351, 'Talovaya', 'Talovaya', 'Talovaja,Talovaya,Talowaja,Таловая', 51.1144400, 40.7300000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119352, 'Talitsy', 'Talitsy', 'Talicy,Talitsa,Talitsy,Талицы', 56.5280100, 42.3323000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119353, 'Taldom', 'Taldom', 'Gorad Taldam,Taldom,Tałdom,Tàldom,Táldom,ta er duo mu,taldwm,Горад Талдам,Талдом,Талдом балһсн,تالدوم,塔爾多姆', 56.7333300, 37.5333300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119354, 'Talashkino', 'Talashkino', 'Talashkino,Talasjkino,Талашкино', 54.6547100, 32.1832500, 'RU', '2012-06-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119355, 'Agidel’', 'Agidel''', 'Aghidhel,Agidel,Agidel'',Agideli,Agidelis,Agidelj,Agidel’,Takmalachuk,agidel,Агидель,Агидељ,아기델', 55.9077000, 53.9355000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119356, 'Taganrog', 'Taganrog', 'Gorad Taganrog,TGK,Taganrog,Taganroga,Taganrogas,Tankanronk,Taqanroq,ta gan luo ge,taganlokeu,taganrogu,taganrwg,taghanrwgh,Ταγκανρόγκ,Горад Таганрог,Таганрог,تاغانروغ,تاگانروگ,ტაგანროგი,タガンログ,塔甘羅格,타간로크', 47.2361700, 38.8968800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119357, 'Taganskiy', 'Taganskiy', 'Taganka,Taganskij,Taganskiy,Таганский', 55.7333300, 37.6666700, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119358, 'Syzran’', 'Syzran''', 'Sysran,Syzran,Syzran'',Syzran’,Сызрань', 53.1585000, 48.4681000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119359, 'Syumsi', 'Syumsi', 'Siumsi,Sjumsi,Syumsi,Сюмси', 57.1110800, 51.6149400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119360, 'Syrtych', 'Syrtych', 'Sirtich,Sirtitsj,Syrtych,Сиртич,Сыртыч', 41.8338800, 48.2290100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119361, 'Syrskoye', 'Syrskoye', 'Sirskaya,Surskoe,Syrskaya,Syrskij,Syrskoe,Syrskoye,Сурское,Сырский,Сырское', 52.5743700, 39.4966000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119362, 'Syrostan', 'Syrostan', 'Syrostan,Сыростан', 55.0634000, 59.9002000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119363, 'Syntul', 'Syntul', 'Syntu,Syntul,Сынтул', 55.0032700, 41.2971100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119364, 'Synya', 'Synya', 'Syna,Synja,Synya,Сыня', 65.3718500, 58.0387400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119365, 'Sylva', 'Sylva', 'Sylva,Сылва', 58.0327000, 56.7713000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119366, 'Sylva', 'Sylva', 'Sylva,Sylvinskiy Zavod,Сылва', 57.3092000, 58.7734000, 'RU', '2012-07-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119367, 'Syktyvkar', 'Syktyvkar', 'Gorad Syktyukar,SCW,Siktifkar,Siktivkar,Siktivkara,Soktovkar,Syktyvkar,Syktyvkaras,Syktywkar,Sziktivkar,Sîktîvkar,Sõktõvkar,Sıktıvkar,Ust''-Sysol''sk,Ust’-Sysol’sk,se ke te fu ka er,sigtibkaleu,sukh tuf khar,su~ikutifukaru,syktyfkar,syktywkar,syqtybqr,Горад Сыктыўкар,Сиктивкар,Сыктывкар,Сыктывкар балһсн,Усть-Сысольск,Սիկտիվկար,סיקטיבקר,سيكتيفكار,سیکتیوکار,ซึคตึฟคาร์,スィクティフカル,瑟克特夫卡爾,식팁카르', 61.6764200, 50.8099400, 'RU', '2012-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119368, 'Sychëvo', 'Sychevo', 'Sychevo,Sychi,Sychëvo,Sytsjevo,Сычево', 55.9577100, 36.2278500, 'RU', '2016-10-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119369, 'Sychëvo', 'Sychevo', '', 55.0619600, 38.7138400, 'RU', '2011-06-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119370, 'Sychëvka', 'Sychevka', 'Sychevka,Sychëvka,Sytsjevka,Сычевка', 55.8251500, 34.2736100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119371, 'Syava', 'Syava', 'Siava,Sjava,Syava,Сява', 58.0145700, 46.3221600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119372, 'Syas’stroy', 'Syas''stroy', 'Saes''joki,Saesjoki,Siasstroj,Sjas''stroj,Syas''stroy,Syas’stroy,Säs''joki,Säsjoki,Сясьстрой', 60.1366900, 32.5690600, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119373, 'Syamzha', 'Syamzha', 'D''yakovskaya,D''yakovskaya Gorka,D’yakovskaya,D’yakovskaya Gorka,Siamzja,Sjamzha,Syamza,Syamzha,Сямжа,Սյամժա', 60.0157700, 41.0613900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119374, 'Svobody', 'Svobody', 'Poselok Svobody,Poselok-Seobody,Posëlok Svobody,Svobody,Свободы', 44.0255600, 43.0502800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119375, 'Svobodnyy', 'Svobodnyy', 'Svobodnyj,Svobodnyy,Свободный', 52.3303900, 46.3712200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119376, 'Sviyazhsk', 'Sviyazhsk', 'Svijazhsk,Svijazjsk,Sviyazhsk,Свияжск', 55.7732900, 48.6605100, 'RU', '2016-08-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119377, 'Sviblovo', 'Sviblovo', 'Estacao Sviblovo,Estação Sviblovo,Sviblovo,Swiblowo,Swibłowo,Свиблово,Свіблово', 55.8500000, 37.6333300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119378, 'Svetogorsk', 'Svetogorsk', 'Enso,Enšo,Esno,Gorad Svetagorsk,Svetogors''k,Svetogorsk,Svetogorska,Světogorsk,Swetogorsk,Swietogorsk,Swjetogorsk,aswtwgwrsk,sftwghwrsk,si wei tuo ge er si ke,Горад Светагорск,Светогорск,Свєтогорськ,اسوتوگورسک,سفتوغورسك,სვეტოგორსკი,斯韋托戈爾斯克', 61.1121300, 28.8632100, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119379, 'Svetlyy Yar', 'Svetlyy Yar', 'Svetly Yar,Svetlyj Jar,Svetlyy Yar,Светлый Яр', 48.4748000, 44.7809600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119380, 'Svetlyy', 'Svetlyy', 'Cimerbude,Cimerbūdė,Svetlas,Svetlyj,Svetlyy,Tsimmerbude,Zimmerbude,Светлый', 54.6750100, 20.1347300, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119381, 'Svetlograd', 'Svetlograd', 'Gorad Svetlagrad,Petrovskoe,Petrovskoye,Petrowskoje,Svetlograd,Svetloqrad,Svitlograd,Swetlograd,Swietlograd,Swietłograd,Swjetlograd,asltlwgrad,sftlwghrad,si wei te luo ge lei,Горад Светлаград,Светлоград,Светлоград балһсн,Світлоград,اسلتلوگراد,سفتلوغراد,斯韋特洛格勒', 45.3352800, 42.8547200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119382, 'Svetlogorsk', 'Svetlogorsk', 'Gorad Svetlagorsk,Rauschen,Raushed,Rausiai,Raušiai,Svetlogors''k,Svetlogorsk,Svetlogorsk i Kaliningrad oblast,Svetlogorska,Svetlogorskas,Svetloqorsk,Swetlogorsk,Swietlogorsk,Swietłogorsk,seubeteullogoleuseukeu,sftlwghwrsk,si wei te luo ge er si ke,suvu~etorogorusuku,swtlwgwrsk  kalynyngrad,Горад Светлагорск,Светлогорск,Свєтлогорськ,سفتلوغورسك,سوتلوگورسک، کالینینگراد,スヴェトロゴルスク,斯韋特洛戈爾斯克,스베틀로고르스크', 54.9398700, 20.1547900, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119383, 'Sverdlovskiy', 'Sverdlovskiy', 'Sverdlovskij,Sverdlovskiy,Свердловский', 55.9096800, 38.1497800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119384, 'Sven’', 'Sven''', 'Sven,Sven'',Sven’,Свень', 53.1822200, 34.5511100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119385, 'Svecha', 'Svecha', 'Suuechiya,Svecha,Svetsja,Свеча', 58.2784900, 47.5163600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119386, 'Svatkovo', 'Svatkovo', 'Svatkovo,Сватково', 56.3833300, 38.2166700, 'RU', '2015-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119387, 'Suzëmka', 'Suzemka', 'Susemka,Suzemka,Suzëmka,Суземка', 52.3183400, 34.0789900, 'RU', '2010-06-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119388, 'Suzdal’', 'Suzdal''', 'Soezdal,Souzdal,Souzntal,Susdal,Suzdal,Suzdal'',Suzdal’,Súzdal,su zi da er,sujeudal,suzdali,Σούζνταλ,Суздаль,სუზდალი,苏兹达尔,수즈달', 56.4227400, 40.4466800, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119389, 'Suvorovskaya', 'Suvorovskaya', 'Suvorovskaja,Suvorovskaya,Суворовская', 44.1901000, 42.6595000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119390, 'Suvorov', 'Suvorov', 'Suvorov,Suvorovskiy,Суворов', 54.1223000, 36.4965700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119391, 'Suslonger', 'Suslonger', 'Suslonger,Суслонгер', 56.3155600, 48.2530600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119392, 'Susanino', 'Susanino', 'Molvitino,Susanino,Сусанино', 58.1488100, 41.5948300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119393, 'Surskoye', 'Surskoye', 'Surskoe,Surskoje,Surskoye,Сурское', 54.4821000, 46.7214000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119394, 'Sursk', 'Sursk', 'Nikol''skiy Khutor,Nikol’skiy Khutor,Sursk,Сурск', 53.0754200, 45.6846100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119395, 'Surovikino', 'Surovikino', 'Gorad Suravikina,Sourovikino,Surovikino,Surowikino,su luo wei ji nuo,swrwfykynw,swrwwykynw,Горад Суравікіна,Суровикино,Суровикино балһсн,Суровікіно,سوروفيكينو,سوروویکینو,蘇羅維基諾', 48.6073400, 42.8462100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119396, 'Surovatikha', 'Surovatikha', 'Surova,Surovatikha,Суроватиха', 55.7651600, 43.8984500, 'RU', '2013-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119397, 'Surkhakhi', 'Surkhakhi', 'Mamison,Surkhakhi,Surkhokhi,Syrkhokh,Сурхахи', 43.1875000, 44.9019400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119398, 'Surgut', 'Surgut', 'Surgut,Сургут', 53.9249800, 51.2034800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119399, 'Surazh', 'Surazh', 'Surazh,Surazj,Сураж', 53.0174700, 32.3917800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119400, 'Sura', 'Sura', 'Chirkovo,Sura,Сура', 53.8878600, 45.7419200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119401, 'Suponevo', 'Suponevo', 'Suponevo,Супонево', 53.2049200, 34.2959700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119402, 'Suoyarvi', 'Suoyarvi', 'Suojaervi,Suojarvi,Suojärvi,Suoyarvi,Suvilahti,Suvilakhta,Šuojärvi,Суоярви', 62.0833300, 32.3500000, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119403, 'Sunzha', 'Sunzha', 'Sunzha,Sunzja,Сунжа', 43.0586200, 44.8228100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119404, 'Suna', 'Suna', 'Suna,Суна', 57.8337900, 50.0588400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119405, 'Sulak', 'Sulak', 'Glavnyy Sulak,Khizrayevskiy,Khizroyevka,Khizroyevskiy,Sulak,Vataga Sulakskaya,Сулак', 43.2734200, 47.5146300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119406, 'Suksun', 'Suksun', 'Suksun,Суксун', 57.1431000, 57.3949000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119407, 'Sukkozero', 'Sukkozero', 'Sukkajaervi,Sukkajärvi,Sukkozero,Суккозеро', 63.1701800, 32.3443600, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119408, 'Sukko', 'Sukko', 'Sukko,Сукко', 44.7994500, 37.4214500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119409, 'Sukhodol', 'Sukhodol', 'Sukhodol,Суходол', 53.9006300, 51.2117000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119410, 'Sukhobezvodnoye', 'Sukhobezvodnoye', 'Sukhobezvodnoe,Sukhobezvodnoje,Sukhobezvodnoye,Сухобезводное', 57.0491300, 44.8890900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119411, 'Sukhinichi', 'Sukhinichi', 'Gorad Sukhinichy,Soukhinitchi,Suchinici,Suchiniczi,Suchinitschi,Suchiniči,Suhinici,Suhinitsi,Suhinitši,Sukhinichi,Sukhinitsji,Suĥiniĉi,su xi ni qi,suhinichi,swkhynychy,swkhynytshy,Горад Сухінічы,Сухиничи,سوخينيتشي,سوخینیچی,スヒーニチ,蘇希尼奇,수히니치', 54.0998900, 35.3425400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119412, 'Sukhaya Buyvola', 'Sukhaya Buyvola', 'Sukhaja Bujvola,Sukhaya Buivola,Sukhaya Buyvola,Сухая Буйвола', 45.1533300, 42.9955600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119413, 'Sudzha', 'Sudzha', 'Ssudsha Vtoraya,Sudsha,Sudzha,Sudzja,Суджа', 51.1976000, 35.2726000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119414, 'Sudogda', 'Sudogda', 'Gorad Sudagda,Soudogda,Sudogd,Sudogda,Súdogda,su duo ge da,sudogeuda,sudoguda,swdwgda,swdwghda,Горад Судагда,Судогда,سودوغدا,سودوگدا,スドグダ,蘇多格達,수도그다', 55.9539400, 40.8629100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119415, 'Sudislavl’', 'Sudislavl''', 'Sudislavl,Sudislavl'',Sudislavl’,Судиславль', 57.8817500, 41.7082900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119416, 'Suda', 'Suda', 'Suda,Суда', 59.1525400, 37.5582000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119417, 'Subkhankulovo', 'Subkhankulovo', 'Subkhankulovo,Subkhanulova,Субханкулово', 54.5574100, 53.8115300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119418, 'Stupino', 'Stupino', 'Elektrovoz,Gorad Stupina,Stoepino,Stoupino,Stupino,Stúpino,astwpynw,si tu pi nuo,stwbynw,stwpynw,Горад Ступіна,Ступино,Ступино балһсн,Ступіно,استوپینو,ستوبينو,ستوپینو,斯图皮诺', 54.9008300, 38.0708300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119419, 'Stulovo', 'Stulovo', 'Nizhniye Kropachi,Stulovo,Стулово', 58.7225000, 50.1438900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119420, 'Strunino', 'Strunino', 'Gorad Strunina,Strounino,Strunino,astrwnynw,seuteulunino,si te lu ni nuo,strwnynw,sutorunino,Горад Струніна,Струнино,استرونینو,سترونينو,ストルニノ,斯特魯尼諾,스트루니노', 56.3732800, 38.5832100, 'RU', '2014-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119421, 'Strugi-Krasnyye', 'Strugi-Krasnyye', 'Belaya,Strugi-Krasnye,Strugi-Krasnyye,Струги-Красные', 58.2675400, 29.1113700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119422, 'Stromyn’', 'Stromyn''', 'Stromyn,Stromyn'',Stromyn’,Стромынь', 56.0434700, 38.4831800, 'RU', '2015-05-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119423, 'Stroitel’', 'Stroitel''', 'Stroitel,Stroitel'',Stroitel’,Строитель', 50.7854300, 36.4831000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119424, 'Strogino', 'Strogino', 'Strogino,Строгино', 55.8183800, 37.4122400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119425, 'Strizhi', 'Strizhi', 'Strizhi,Strizhi Pervyye,Strizji,Stryzhi,Стрижи', 58.4575800, 49.2866700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119426, 'Strel''na', 'Strel''na', 'Nuolijoki,Strel''na,Strelna,Stryelna,Стрельна', 59.8518900, 30.0361100, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119427, 'Strelka', 'Strelka', 'Krasnaya Strela,Krasnaya Strelka,Strelka,Стрелка', 45.2063300, 37.2865000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119428, 'Strelitsa', 'Strelitsa', 'Strelica,Strelitsa,Стрелица', 51.6083000, 38.9102000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119429, 'Storozhevaya', 'Storozhevaya', 'Storozhevaja,Storozhevaya,Storozjevaja,Storzhevaya,Сторожевая', 43.8788600, 41.4514300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119430, 'Stolbovaya', 'Stolbovaya', 'Stolbovaja,Stolbovaya,Столбовая', 55.2502100, 37.4924900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119431, 'Stolbishchi', 'Stolbishchi', 'Stolbishche,Stolbishchi,Stolbishhi,Stolbisjtsje,Столбищи', 55.6467900, 49.2159500, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119432, 'Stodolishche', 'Stodolishche', 'Stodolishche,Stodolishe,Stodolishhe,Stodolisjtsje,Стодолище', 54.1859400, 32.6492500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119433, 'Sterlitamak', 'Sterlitamak', 'Cterle,Gorad Stehrlitamak,Staerletamaq,Sterlitamak,Sterlitamaka,Sterlitamakas,Sterļitamaka,Stärletamaq,Sztyerlitamak,astrlytamak,seuteleullitamakeu,si jie er li ta ma ke,strlytamak,suteruritamaku,Çтерлĕ,Горад Стэрлітамак,Стерлитамак,Стерлитамак балһсн,Стерлітамак,Стәрлетамак,Стәрлетамаҡ,Ստեռլիտամակ,استرلیتاماک,سترليتاماك,سترلیتاماک,ステルリタマク,斯捷尔利塔马克,스테를리타마크', 53.6246200, 55.9501500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119434, 'Sterlibashevo', 'Sterlibashevo', 'Sterlibashevo,Sterlibasjevo,Стерлибашево', 53.4375500, 55.2578000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119435, 'Stepnoye', 'Stepnoye', 'Luy,Otrogovo,Stepnoe,Stepnoje,Stepnoye,Степное', 51.3797200, 46.8491700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119436, 'Stepantsevo', 'Stepantsevo', 'Stepancevo,Stepantsevo,Степанцево', 56.1314300, 41.7032000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119437, 'Stavrovo', 'Stavrovo', 'Stavrovo,Ставрово', 56.1331100, 40.0129500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119438, 'Stavropol’', 'Stavropol''', 'STW,Stavropol,Stavropol'',Stavropol’,Stawropol,Voroshilovsk,Ставрополь', 45.0428000, 41.9734000, 'RU', '2017-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119439, 'Staryy Urukh', 'Staryy Urukh', 'Staryj Urukh,Staryy Urukh,Старый Урух', 43.3404100, 44.0186800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119440, 'Staryy Oskol', 'Staryy Oskol', 'Starij Oskol,Stary Oskol,Staryi Oskol,Staryj Oskol,Staryy Oskol,seutalioseukol,Старий Оскол,Старый Оскол,스타리오스콜', 51.2966700, 37.8416700, 'RU', '2016-12-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119441, 'Staryye Atagi', 'Staryye Atagi', 'Caxker-Yurt,Chakhker-Jurt,Jokkkha-Atagla,Predgornoe,Predgornoye,Sax-Giriyn-Evla,Saxgiri-Evl,Sekh''a AtagIa,Sexa Ataga,Seẋa Ataġa,Shakh''-Girijn-Ehvla,Shakh''giri-Ehvl,Staraya Ataga,Starye Atagi,Starye Otagi,Staryy Atagi,Staryye Atagi,Vozdvijenskaia,Vozdvizenskaja,Vozdvizenskoe ukreplenie,Vozdvizhenskaja,Vozdvizhenskaya,Vozdvizhenskoe ukreplenie,Vozdviženskaja,Vozdviženskoe ukreplenie,Çaxker-Yurt,Şaẋ-Giriyn-Evla,Şaẋgiri-Evl,Воздвиженская,Воздвиженское укрепление,Йоккха-Атагlа,Предгорное,Сехьа АтагІа,Старые Атаги,Старые Отаги,Чахкер-Юрт,Шахь-Гирийн-Эвла,Шахьгири-Эвл', 43.1202800, 45.7405600, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119442, 'Staryy Cherek', 'Staryy Cherek', 'Staryj Cherek,Staryj Tsjerek,Staryy Cherek,Staryy Cheren,Старый Черек', 43.4713900, 43.8469400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119443, 'Starozhilovo', 'Starozhilovo', 'Starozhilovo,Starozjilovo,Старожилово', 54.2254000, 39.9160000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119444, 'Staroyur’yevo', 'Staroyur''yevo', 'Starojur''evo,Starojurjevo,Staroye Yur''yevo,Staroye Yur’yevo,Staroyur''yevo,Staroyur’yevo,Староюрьево', 53.3161100, 40.7080600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119445, 'Staroye Drozhzhanoye', 'Staroye Drozhzhanoye', 'Drozhzhannoye,Drozhzhanovo,Drozhzhanoye,Staroe Drozhzhanoe,Staroje Drozjzjanoje,Staroye Drozhzhanoye,Старое Дрожжаное', 54.7265700, 47.5676600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119446, 'Starovelichkovskaya', 'Starovelichkovskaya', 'Starovelichkovskaja,Starovelichkovskaya,Starovelitsjkovskaja,Starowelitschkowskaja,Старовеличковская', 45.4288400, 38.7326100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119447, 'Staroutkinsk', 'Staroutkinsk', 'Staraya Utka,Staro-Utkinskiy Zavod,Staroutkinsk,Староуткинск', 57.2301700, 59.3348300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119448, 'Starotitarovskaya', 'Starotitarovskaya', 'Starotitarovskaja,Starotitarovskaya,Starotitarowskaja,Starotitorovskaya,Titarovskaya,Старотитаровская', 45.2193800, 37.1547600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119449, 'Starotimoshkino', 'Starotimoshkino', 'Starotimoshkino,Starotimosjkino,Staroye Timoshkino,Timoshkino,Старотимошкино', 53.7190800, 47.5311600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119450, 'Starosubkhangulovo', 'Starosubkhangulovo', 'Starosubkhangulovo,Subkhankulova,Старосубхангулово', 53.1031000, 57.4423000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119451, 'Staroshcherbinovskaya', 'Staroshcherbinovskaya', 'Staro Schtscherbinowskaja,Staro-Scherbinowskaja,Staroshcherbinovskaya,Starosherbinovskaya,Staroshherbinovskaja,Starosjtsjerbinovskaja,Старощербиновская', 46.6311000, 38.6742000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119452, 'Staropavlovskaya', 'Staropavlovskaya', 'Staropavlovskaja,Staropavlovskaya,Старопавловская', 43.8488900, 43.6327800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119453, 'Staronizhestebliyevskaya', 'Staronizhestebliyevskaya', 'Staro Nizhesteblievskaya,Staro-Nizhne-Stebliyevskaya,Staronishesteblijewskaja,Staronizhesteblievskaja,Staronizhestebliyevskaya,Staronizjesteblijevskaja,Старонижестеблиевская', 45.3831500, 38.4430400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119454, 'Staromyshastovskaya', 'Staromyshastovskaya', 'Staromishastovskaya,Staromyshastovskaja,Staromyshastovskaya,Staromysjastovskaja,Старомышастовская', 45.3432900, 39.0760800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119455, 'Starominskaya', 'Starominskaya', 'Starominskaja,Starominskaya,Староминская', 46.5300000, 39.0497200, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119456, 'Staroleushkovskaya', 'Staroleushkovskaya', 'Staroleushkoskaya,Staroleushkovskaja,Staroleushkovskaya,Staroleusjkovskaja,Stavroleushkovskaya,Старолеушковская', 45.9866600, 39.7598700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119457, 'Starokucherganovka', 'Starokucherganovka', 'Starokucherganovka,Starokutsjerganovka,Старокучергановка', 46.3247600, 47.9555000, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119458, 'Starokorsunskaya', 'Starokorsunskaya', 'Starakorsunskaya,Starokorsunskaja,Starokorsunskaya,Старокорсунская', 45.0572700, 39.3161100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119459, 'Starodzhereliyevskaya', 'Starodzhereliyevskaya', 'Staraya Dzhereliyevskaya,Starodzherelievskaja,Starodzhereliyevskaya,Starodzjerelijevskaja,Староджерелиевская', 45.4759900, 38.2968000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119460, 'Starodubskoye', 'Starodubskoye', 'Starodubskoe,Starodubskoje,Starodubskoye,Стародубское', 44.5630600, 44.0152800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119461, 'Starodub', 'Starodub', 'Gorad Staradub,Starodoub,Starodub,Staroduba,Starodubas,Starodubum,astarwdwb,seutalodupeu,si ta luo du bu,starwdwb,sutarodo~ubu,Горад Старадуб,Стародуб,Стародуб балһсн,סטארודוב,استارودوب,ستارودوب,スタロドゥーブ,斯塔羅杜布,스타로두프', 52.5844400, 32.7633300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119462, 'Staroderevyankovskaya', 'Staroderevyankovskaya', 'Staroderevjankovskaja,Staroderevyankovskaya,Стародеревянковская', 46.1276000, 38.9674000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119463, 'Starocherkasskaya', 'Starocherkasskaya', 'Starocherkassk,Starocherkasskaja,Starocherkasskaya,Starotsjerkasskaja,Старочеркасская', 47.2407700, 40.0418600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119464, 'Starobaltachevo', 'Starobaltachevo', 'Starobaltachevo,Starobaltatsjevo,Старобалтачево', 56.0017000, 55.9280000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119465, 'Staritsa', 'Staritsa', 'Gorad Staryca,Staric,Starica,Starice,Staricja,Staritsa,Stariza,Stáritsa,astarytsa,seutalicha,si ta li cha,starytsa,sutaritsu~a,Горад Старыца,Старица,Старице,Стариця,استاریتسا,ستاريتسا,スターリツァ,斯塔里察,스타리차', 56.5075200, 34.9354400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119466, 'Staraya Vichuga', 'Staraya Vichuga', 'Staraja Vichuga,Staraja Vitsjuga,Staraya Vichuga,Vichuga,Старая Вичуга', 57.2683300, 41.8787300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119467, 'Staraya Toropa', 'Staraya Toropa', 'Staraja Toropa,Staraya Toropa,Toropa,Старая Торопа', 56.2801200, 31.6701800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119468, 'Staraya Sunzha', 'Staraya Sunzha', 'So''lzhe,Staraja Sunza,Staraja Sunzha,Staraja Sunzja,Staraja Sunža,Staraya Sunzha,Staro-Ssunshenskaje,Starosunzhenskoye,Sölƶe,Соьлже,Старая Сунжа', 43.3354200, 45.7437700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119469, 'Staraya Stanitsa', 'Staraya Stanitsa', 'Staraja Stanica,Staraja Stanitsa,Staraya Stanitsa,Старая Станица', 48.3363300, 40.2958800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119470, 'Staraya Stanitsa', 'Staraya Stanitsa', 'Staraja Stancija,Staraja Stanitsa,Staraya Stanitsa,Старая Станция', 45.0098000, 41.1512000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119471, 'Staraya Russa', 'Staraya Russa', 'Staraja Roessa,Staraja Russa,Staraya Russa,seutalayalusa,Старая Русса,스타라야루사', 57.9943900, 31.3608100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119472, 'Staraya Poltavka', 'Staraya Poltavka', 'Star.Poltavka,Staraja Poltavka,Staraya Poltavka,Стар.Полтавка,Старая Полтавка', 50.4771500, 46.4814400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119473, 'Staraya Mayna', 'Staraya Mayna', 'Staraja Majna,Staraya Mayna,Старая Майна', 54.6041700, 48.9305600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119474, 'Staraya Ladoga', 'Staraya Ladoga', 'Laatokankaupunki,Ladoga,Star.Ladoga,Stara Ladoga,Stara Ładoga,Staragia Lantonka,Staraja Ladoga,Staraya Ladoga,Στάραγια Λάντογκα,Стар.Ладога,Старая Ладога', 59.9987200, 32.2941300, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119475, 'Staraya Kupavna', 'Staraya Kupavna', 'Kupavna,Staraja Kupavna,Staraya Kupavna,Купавна,Старая Купавна', 55.8079900, 38.1805000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119476, 'Staraya Kulatka', 'Staraya Kulatka', 'Star.Kulatka,Staraja Kulatka,Staraya Kulatka,Стар.Кулатка,Старая Кулатка', 52.7277800, 47.6178800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119477, 'Staraya Derevnya', 'Staraya Derevnya', 'Staraja Derevnja,Staraya Derevnya,Vanhakylae,Vanhakylä,Старая Деревня', 59.9883400, 30.2429600, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119478, 'Staraya', 'Staraya', 'Staraja,Staraya,Vanhakylae,Vanhakylä,Старая', 59.9274900, 30.6276500, 'RU', '2012-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119479, 'Star’', 'Star''', 'Star,Star'',Star’,Старь', 53.6236200, 34.1518300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119480, 'Stanovoye', 'Stanovoye', 'Ploskoe,Ploskoye,Stanovoe,Stanovoye,Плоское,Становое', 52.7638400, 38.3581800, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119481, 'Srednyaya Yelyuzan’', 'Srednyaya Yelyuzan''', 'Srednjaja Eljuzan'',Srednjaja Jeljuzan,Srednyaya Yelyuzan'',Srednyaya Yelyuzan’,Средняя Елюзань', 53.0241000, 45.9529000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119482, 'Srednyaya Akhtuba', 'Srednyaya Akhtuba', 'Srednjaja Akhtuba,Srednyaya Akhtuba,Средняя Ахтуба', 48.7099800, 44.8672400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119483, 'Sredniy Ikorets', 'Sredniy Ikorets', 'Sredne Ikorets,Srednij Ikorec,Srednij Ikorets,Sredniy Ikorets,Средний Икорец', 51.0674900, 39.7583800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119484, 'Spokoynaya', 'Spokoynaya', 'Spokoinaya,Spokojnaja,Spokoynaya,Спокойная', 44.2468000, 41.4015000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119485, 'Spitsevka', 'Spitsevka', 'Spicevka,Spitsevka,Spitsevskoye,Спицевка', 45.1230600, 42.5125000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119486, 'Spirovo', 'Spirovo', 'Spirovo,Спирово', 57.4190500, 34.9765800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119487, 'Spiridonovka', 'Spiridonovka', 'Spiridonovka,Спиридоновка', 53.0924800, 50.6462100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119488, 'Spas-Zaulok', 'Spas-Zaulok', 'Spas-Zaulok,Spas-Zavlok,Спас-Заулок', 56.4833300, 36.5666700, 'RU', '2014-08-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119489, 'Spassk-Ryazanskiy', 'Spassk-Ryazanskiy', 'Spassk,Spassk-Rjasanski,Spassk-Rjazanskij,Spassk-Ryazanskiy,Спасск-Рязанский', 54.4040000, 40.3762000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119490, 'Spasskoye-Lutovinovo', 'Spasskoye-Lutovinovo', 'Spass-Lutovinovskoye,Spassko-Lutovinovskoye,Spasskoe-Lutovinovo,Spasskoje-Lutovinovo,Spasskoye-Lutovinovo,Spassnoye-Lutovinovo,Спасское-Лутовиново', 53.3701200, 36.6229700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119491, 'Spasskoye', 'Spasskoye', 'Spasskoe,Spasskoje,Spasskoye,Спасское', 55.8604800, 45.6969500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119492, 'Spas-Klepiki', 'Spas-Klepiki', 'Gorad Spas-Klepiki,Spas-Klepiki,Spas-Klépiki,Spass-Klepiki,aspas-klpyky,sbas-klbyky,seupaseukeullepiki,si pa si-ke lie pi ji,supasu=kurepiki,Горад Спас-Клепікі,Спас-Клепики,اسپاس-کلپیکی,سباس-كلبيكي,スパス＝クレピキ,斯帕斯-克列皮基,스파스클레피키', 55.1347200, 40.1767300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119493, 'Spas-Demensk', 'Spas-Demensk', 'Gorad Spas-Dzemensk,Spas Demensko,Spas-Demensk,Spas-Demjensk,Spas-Diemiensk,Spas-Diemieńsk,aspas-dmnsk,sbas-dmynsk,seupaseudemenseukeu,si pa si-jie mian si ke,supasu=jemensuku,Горад Спас-Дземенск,Спас-Деменск,اسپاس-دمنسک,سباس-دمينسك,スパス＝ジェメンスク,斯帕斯-傑緬斯克,스파스데멘스크', 54.4122200, 34.0225700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119494, 'Sozimskiy', 'Sozimskiy', 'Sozimskij,Sozimskiy,Созимский', 59.7417800, 52.2482100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119495, 'Sovetskoye', 'Sovetskoye', 'Mariental,Mariyental'',Mariyental’,Pfannenstiel,Sovetskoe,Sovetskoje,Sovetskoye,Советское', 51.4425500, 46.7424000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119496, 'Sovetskoye', 'Sovetskoye', 'Ketchener-Shebener,Ketchener-Shebenery,Ketchenerovskiy,Ketchenery,Ketchenery-Shebenery,Sovetskoe,Sovetskoye,Sukhotinskiy,Кетченеры,Советское', 47.3086800, 44.5216200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119497, 'Kashkhatau', 'Kashkhatau', 'Kashkatau,Kashkhatau,Kasjkhatau,Sovetskoye,Кашхатау', 43.3184800, 43.6080400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119498, 'Shatoy', 'Shatoy', 'Satoi,Satoj,Schatai,Shatoi,Shatoj,Shatoy,Shu''jta,Shu''jta-GIala,Sovetskoe,Sovetskoye,Sueyta-Gala,Xatoi,syatoi,Şüyta-Ġala,Šatoj,Șatoi,Советское,Шатой,Шуьйта,Шуьйта-ГІала,샤토이', 42.8714300, 45.6886500, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119499, 'Khebda', 'Khebda', 'Khebda,Sovetskoe,Sovetskoye,Советское,Хебда', 42.4442300, 46.5517200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119500, 'Sovetskiy', 'Sovetskiy', 'Iogannes,Iokhannes,Johannes,Kakis-kurka,Sankt Johannes,Sovetskij,Sovetskiy,Советский', 60.5394500, 28.6775600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119501, 'Sovetskiy', 'Sovetskiy', 'Sovetskij,Sovetskiy,Советский', 56.7583300, 48.4761100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119502, 'Sovetskaya', 'Sovetskaya', 'Chernyshevskaya,Sovetskaja,Sovetskaya,Советская', 49.0091200, 42.1217800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119503, 'Sovetskaya', 'Sovetskaya', 'Sovetskaja,Sovetskaya,Sowjetskaya,Urupskaya,Советская', 44.7769400, 41.1722200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119504, 'Sovetskaya', 'Sovetskaya', 'Sovetskaja,Sovetskaya,Советская', 44.0266700, 44.0500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119505, 'Sovetsk', 'Sovetsk', 'Gorad Saveck,Kukarka,Soveck,Sovetsk,Sovetsk i Kirov oblast,Sovjetsk,Sowetsk,Sowjetsk,Szovjetszk,sobecheukeu,su wei ai ci ke,swbtsq,swftsk,swwtsk  awblast kyrwf,Горад Савецк,Кукарка,Советск,Совецк,Совјетск,סובטסק,سوفتسك,سووتسک، اوبلاست کیروف,苏维埃茨克,소베츠크', 57.5847500, 48.9584400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119506, 'Sovetsk', 'Sovetsk', 'Gorad Saveck,Sovetk,Sovets''k,Sovetsk,Sovetsk i Kaliningrad oblast,Sovetska,Sovetskas,Sovețk,Sovietsk,Sovjetsk,Sovyetsk,Sowetsk,Sowieck,Sowjetsk,Szovjetszk,Til''zit,Tilsa,Tilsit,Tilze,Tilžė,Til’zit,sobecheukeu,sovu~i~etsuku,su wei ai ci ke,swbtsq,swftsk,swwtsk  kalynyngrad,Горад Савецк,Советск,Совєтськ,Совјетск,סובטסק,سوفتسك,سووتسک، کالینینگراد,ソヴィェツク,苏维埃茨克,소베츠크', 55.0839200, 21.8785100, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119507, 'Sotnikovskoye', 'Sotnikovskoye', 'Sotnikovskoe,Sotnikovskoje,Sotnikovskoye,Сотниковское', 45.0038900, 43.7772200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119508, 'Sosnovyy Bor', 'Sosnovyy Bor', 'Sosnovyj Bor,Sosnovyy Bor,Uustia,Сосновый Бор', 59.8996000, 29.0857400, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119509, 'Sosnovoborsk', 'Sosnovoborsk', 'Litvino,Litvinovo,Sosnovoborsk,Сосновоборск', 53.2906600, 46.2484900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119510, 'Sosnovo', 'Sosnovo', 'Rautu,Sosnovo,Сосново', 60.5514500, 30.2144100, 'RU', '2012-11-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119511, 'Sosnovka', 'Sosnovka', 'Gorad Sasnouka,Sosnovka,Sosnovka i Kirov oblast,Sosnowka,Szosznovka,suo si nuo fu ka,swsnwfka,Горад Сасноўка,Сосновка,سوسنوفكا,سوسنوفکا,索斯諾夫卡', 56.2549600, 51.2841900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119512, 'Sosnovka', 'Sosnovka', 'Sosnovka,Сосновка', 54.7116100, 43.2977400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119513, 'Sosnovka', 'Sosnovka', 'Sosnovka,Сосновка', 53.2359300, 41.3685900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119514, 'Sosnovaya Polyana', 'Sosnovaya Polyana', 'Sosnovaja Poljana,Sosnovaya Polyana,Vahvaisi,Сосновая Поляна', 59.8352800, 30.1466700, 'RU', '2015-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119515, 'Sosnogorsk', 'Sosnogorsk', 'Gorad Sasnagorsk,Izhma,Sosnagort,Sosnogorsk,Szosznogorszk,suo si nuo ge er si ke,swsnghwrsk,swsnwgwrsk,Горад Саснагорск,Сосногорск,Сосногорск балһсн,Сӧснагорт,سوسنغورسك,سوسنوگورسک,索斯諾戈爾斯克', 63.6022900, 53.8817500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119516, 'Soskovo', 'Soskovo', 'Soskovo,Сосково', 52.7475200, 35.3827700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119517, 'Sosenskiy', 'Sosenskiy', 'Sosenskij,Sosenskiy,Сосенский', 54.0589900, 35.9622800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119518, 'Sortavala', 'Sortavala', 'Gorad Sortavala,Sordavala,Sordovala,Sorravala,Sortaval,Sortavala,Sortavalae,Sortawala,Sortawała,Szortavala,soleutaballa,sorutavu~ara,suo er ta wa la,swrtafala,swrtawala,Горад Сортавала,Сортавалæ,Сортавала,سورتافالا,سورتاوالا,ソルタヴァラ,索爾塔瓦拉,소르타발라', 61.7123300, 30.7095300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119519, 'Sorochinsk', 'Sorochinsk', 'Sorochinsk,Sorotsjinsk,Сорочинск', 52.4338000, 53.1583000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119520, 'Sonkovo', 'Sonkovo', 'Sonkovo,Сонково', 57.7781600, 37.1570700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119521, 'Somovo', 'Somovo', 'Somovo,Сомово', 51.7409800, 39.3665500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119522, 'Solyanka', 'Solyanka', 'Saljanka,Soljanka,Solyanka,Солянка', 46.3889000, 48.0175500, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119523, 'Sol’vychegodsk', 'Sol''vychegodsk', 'Sol''vychegodsk,Solvytsjegodsk,Sol’vychegodsk,Сольвычегодск', 61.3304600, 46.9155900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119524, 'Soluno-Dmitriyevskoye', 'Soluno-Dmitriyevskoye', 'Soluno-Dmitrievskoe,Soluno-Dmitrijevskoje,Soluno-Dmitriyevskoye,Солуно-Дмитриевское', 44.4074000, 42.7240000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119525, 'Sol’tsy', 'Sol''tsy', 'Sol''cy,Sol''tsy,Soltsy,Solzy,Sol’tsy,Сольцы', 58.1238700, 30.3237700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119526, 'Solotcha', 'Solotcha', 'Solodcha,Solotcha,Solottsja,Солотча', 54.7897000, 39.8333600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119527, 'Solomenskoye', 'Solomenskoye', 'Solomenskoe,Solomenskoje,Solomenskoye,Соломенское', 44.2166700, 44.3527800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119528, 'Solntsevo', 'Solntsevo', 'Solncevo,Solntsevo,Солнцево', 55.6371100, 37.3811500, 'RU', '2012-09-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119529, 'Solntsevo', 'Solntsevo', 'Korovino,Solncevo,Solntsevo,Солнцево', 51.4185300, 36.7499000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119530, 'Solnechnoye', 'Solnechnoye', 'Ollila,Solnechnoe,Solnechnoye,Solnetsjnoje,Солнечное', 60.1561200, 29.9475300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119531, 'Solnechnogorsk', 'Solnechnogorsk', 'Solnechangorski,Solnechnogors''k,Solnechnogorsk,Solnechnogorski,Solnechnogorskiy,Solnecinogorsk,Solnecnogorsk,Solnecnoqorsk,Solnetchnogorsk,Solnetschnogorsk,Solnetsjnogorsk,Solnetsnogorsk,Solnetšnogorsk,Solneçnoqorsk,Solneĉnogorsk,Solnečnogorsk,Solniecznogorsk,Solnjecnogorsk,Solnječnogorsk,Solněčnogorsk,Sołniecznogorsk,suo er nie qi nuo ge er si ke,swlnchnwgwrsk,swlntshnwghwrsk,swlnychnwgwrsk,Солнечногорск,Солнечногорск балһсн,Солнечногорськ,سولنتشنوغورسك,سولنچنوگورسک,سولنیچنوگورسک,索爾涅奇諾戈爾斯克', 56.1833300, 36.9833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119532, 'Sol’-Iletsk', 'Sol''-Iletsk', 'Iletsk,Iletskaya,Iletskaya Zashchita,Iletskaya Zashkta,Ilezk,Sol''-Ileck,Sol''-Iletsk,Sol-Iletsk,Sol’-Iletsk,Соль-Илецк', 51.1631000, 54.9917600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119533, 'Solikamsk', 'Solikamsk', 'Gorad Salikamsk,Solikamsk,Solikamskas,Sovkar,Szolikamszk,suo li ka mu si ke,swlkamsk,swlykamsk,Горад Салікамск,Совкар,Соликамск,Սոլիկամսկ,سولكامسك,سولیکامسک,索利卡姆斯克', 59.6316000, 56.7685000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119534, 'Soligalich', 'Soligalich', 'Soligalic,Soligalich,Soligalicz,Soligalitch,Soligalits,Soligalitsch,Soligalitsj,Soligalitx,Soligalitš,Soligaliĉ,Soligalič,Soligàlitx,Soligálich,solligallichi,sorigarichi,suo li jia li qi,swlghaltsh,swlygalych,Солигалич,سولغالتش,سولیگالیچ,ソリガリチ,索利加利奇,솔리갈리치', 59.0796000, 42.2852600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119535, 'Solginskiy', 'Solginskiy', 'Soglinskiy,Solginskij,Solginskiy,Солгинский', 61.0500000, 41.3427800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119536, 'Soldatskaya', 'Soldatskaya', 'Soldatskaja,Soldatskaya,Солдатская', 43.8180600, 43.8158300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119537, 'Soldato-Aleksandrovskoye', 'Soldato-Aleksandrovskoye', 'Soldato-Aleksandrovskoe,Soldato-Aleksandrovskoje,Soldato-Aleksandrovskoye,Soldatsko-Aleksandrovskoye,Солдато-Александровское', 44.2652800, 43.7561100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119538, 'Sokol’skoye', 'Sokol''skoye', 'Sokol''skoe,Sokol''skoye,Sokolskoje,Sokol’skoye,Сокольское', 57.1412200, 43.1589500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119539, 'Sokolovyy', 'Sokolovyy', 'Razboyshchina,Razboyshehina,Sokolovyj,Sokolovyy,Соколовый', 51.5685700, 45.8331200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119540, 'Sokolovskoye', 'Sokolovskoye', 'Sokolovskiy,Sokolovskoe,Sokolovskoje,Sokolovskoye,Соколовское', 45.2583300, 40.6797200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119541, 'Sokolovo-Kundryuchenskiy', 'Sokolovo-Kundryuchenskiy', 'Sokolovo-Kundrjuchenskij,Sokolovo-Kundrjutsjenskij,Sokolovo-Kundryuchens''kyy,Sokolovo-Kundryuchenskiy,Sokolovo-Kundryuchenskoye,Sokolovo-Kundryuchens’kyy,Sokolovskiy,Соколово-Кундрюченский', 47.8353600, 39.9471100, 'RU', '2014-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119542, 'Sokol’niki', 'Sokol''niki', 'Sokol''niki,Sokol’niki,Сокольники', 55.8020200, 37.6715900, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119543, 'Sokol', 'Sokol', 'Sokol,Сокол', 55.8000000, 37.5166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119544, 'Sokol', 'Sokol', 'Gorad Sokal,Sokol,Sokoł,sokol,sokoru,suo ke er,swkwl,swkwl  awblast wlwgda,Горад Сокал,Сокол,سوكول,سوکول، اوبلاست ولوگدا,ソコル,索科爾,소콜', 59.4616700, 40.1205600, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119545, 'Sofrino', 'Sofrino', 'Sofrino,Софрино', 56.1500000, 37.9333300, 'RU', '2014-09-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119546, 'Sochi', 'Sochi', 'AER,Sochi,Sochi - Soci,Sochi - Со́чи,Soci,Soczi,Sotchi,Sotji,Sotschi,Sotsi,Sotsji,Sotši,Soĉi,Ssotschi,sochi,soci,suo qi,Сочи,Сочі,सोची,სოჭი,ソチ,索契,소치', 43.5991700, 39.7256900, 'RU', '2014-01-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119547, 'Sobinka', 'Sobinka', 'Gorad Sobinka,Rabochiy Poselok Sobinka,Rabochiy Posëlok Sobinka,Sobink,Sobinka,sobinka,suo bin ka,swbynka,Горад Собінка,Собинка,Собінка,سوبينكا,سوبینکا,ソビンカ,索賓卡,소빈카', 55.9855300, 40.0111100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119548, 'Snegiri', 'Snegiri', 'Snegiri,Snigiri,Снегири', 55.8886700, 37.0242100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119549, 'Smyshlyayevka', 'Smyshlyayevka', 'Kuibyschew-Smyschljajewka,Smyshljaevka,Smyshlyayevka,Smysjljaevka,Смышляевка', 53.2391300, 50.3907200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119550, 'Smolino', 'Smolino', 'Smolino,Смолино', 56.2752600, 43.0910900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119551, 'Smolenskaya', 'Smolenskaya', 'Smolenskaja,Smolenskaya,Смоленская', 44.7863600, 38.8033300, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119552, 'Smolensk', 'Smolensk', 'Gorad Smalensk,LNX,Smol''n''sku,Smolen''sk,Smolens''k,Smolenscum,Smolensk,Smolenska,Smolenskaj,Smolenskas,Smoleńsk,Smoļenska,Smulen,Szmolenszk,asmwlnsk,s mo len skh,seumollenseukeu,si mo leng si ke,smolenska,smwlnsk,smwlnsq,smwlynsk,sumorensuku,Σμολένσκ,Горад Смаленск,Смоленск,Смоленскай,Смоленськ,Смоленьск,Смольньскъ,Смулен,Սմոլենսկ,סמאלענסק,סמולנסק,اسمولنسک,سمولنسک,سمولينسك,स्मोलेन्स्क,สโมเลนสค์,სმოლენსკი,スモレンスク,斯摩棱斯克,스몰렌스크', 54.7818000, 32.0401000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119553, 'Slobodskoy', 'Slobodskoy', 'Slobodskoj,Slobodskoy,Slovodskoi,Слободской', 58.7322200, 50.1772200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119554, 'Slobodka', 'Slobodka', 'Slobodka,Слободка', 55.8666700, 37.5833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119555, 'Sloboda', 'Sloboda', 'Sloboda,Slovoda,Слобода', 51.1421000, 40.3021000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119556, 'Slavyansk-na-Kubani', 'Slavyansk-na-Kubani', 'Slavanskaya,Slavjansk Na Kubani,Slavjansk-na-Kubani,Slavyansk-na-Kubani,Slavyanskaya,Slawjanskaja,Slov''jans''k na Kubani,Sslawjanskaja,seullabyanseukeunakubani,Славянск На Кубани,Славянск-на-Кубани,Слов''янськ на Кубані,슬라뱐스크나쿠바니', 45.2558000, 38.1256000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119557, 'Slavsk', 'Slavsk', 'Gastos,Genrikhsval''de,Genrikhsval’de,Gorad Slausk,Heinrichswalde,Khaynrikhsval''de,Khaynrikhsval’de,Khayrikhsval''de,Khayrikhsval’de,Slavsk,Slavska,Slavskas,Slawsk,Sławsk,aslawsk,seullabseukeu,si la fu si ke,slafsk,surafusuku,Горад Слаўск,Славск,اسلاوسک,سلافسك,スラフスク,斯拉夫斯克,슬랍스크', 55.0425000, 21.6770400, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119558, 'Slashchevskaya', 'Slashchevskaya', 'Slashchevskaya,Slashhevskaja,Slasjtsjevskaja,Слащевская', 49.8599000, 42.3362000, 'RU', '2015-03-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119559, 'Slantsy', 'Slantsy', 'Olantsy,Slancai,Slancci,Slanci,Slancy,Slantsi,Slantso,Slantsy,Slantsõ,Slanzy,Slančči,Slántsy,Słancy,aslantsy,si lan qi,slantsi,slantsy,surantsu~i,Слантси,Сланци,Сланцы,Сланці,اسلانتسی,سلانتسي,სლანცი,スランツィ,斯蘭齊', 59.1181700, 28.0913700, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119560, 'Skuratovskiy', 'Skuratovskiy', 'Skuratovka,Skuratovo,Skuratovskij,Skuratovskiy,Yuzhnyy,Скуратовский', 54.1015200, 37.6038400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119561, 'Skoropuskovskiy', 'Skoropuskovskiy', 'Skoropuskovskij,Skoropuskovskiy,Скоропусковский', 56.3666700, 38.1666700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119562, 'Skorodnoye', 'Skorodnoye', 'Skorodnoe,Skorodnoje,Skorodnoye,Скородное', 51.0710100, 37.2275600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119563, 'Skopin', 'Skopin', 'Gorad Skopin,Skopin,Skopine,askwpyn,seukopin,si ke ping,skwbyn,sukopin,Горад Скопін,Скопин,اسکوپین,سكوبين,スコピン,斯科平,스코핀', 53.8248600, 39.5505300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119564, 'Skolkovo', 'Skolkovo', 'Skolkovo,Сколково', 55.6878400, 37.3683600, 'RU', '2014-09-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119565, 'Skhodnya', 'Skhodnya', 'Skhodnja,Skhodnya,Сходня', 55.9480600, 37.2977800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119566, 'Sizyy Bugor', 'Sizyy Bugor', 'Sizyj Bugor,Sizyy Bugor,Syzyy Bugor,Сизый Бугор', 46.2134300, 48.5046200, 'RU', '2017-03-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119567, 'Siverskiy', 'Siverskiy', 'Dernovskiy,Siiverska,Siverskij,Siverskiy,Сиверский', 59.3544400, 30.0783300, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119568, 'Siva', 'Siva', 'Siva,Сива', 58.3820400, 54.3803700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119569, 'Siukh', 'Siukh', 'Siukh,Сиух', 42.5999000, 46.5446200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119570, 'Sitniki', 'Sitniki', 'Kozlikha,Sitniki,Sitnikovo,Ситники', 56.4552900, 44.0665800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119571, 'Sista-Palkino', 'Sista-Palkino', 'Siesta-Palkkina,Sista-Palkino,Sisto-Palkino,Систа-Палкино', 59.8004200, 28.9104900, 'RU', '2013-11-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119572, 'Sinyavskoye', 'Sinyavskoye', 'Sinjavskoe,Sinjavskoje,Sinyavka,Sinyavskoye,Синявское', 47.2770300, 39.2788800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119573, 'Sinyavino', 'Sinyavino', 'Sinjavino,Sinyavino,Sinyavino Nomer Pervyy,Vahriselkae,Vahriselkä,Синявино', 59.9078100, 31.0711000, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119574, 'Sinodskoye', 'Sinodskoye', 'Sinodskoe,Sinodskoje,Sinodskoye,Синодское', 51.9918000, 46.6700900, 'RU', '2014-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119575, 'Novosin’kovo', 'Novosin''kovo', 'Novosin''kovo,Novosinkovo,Новосиньково', 56.3773700, 37.3287100, 'RU', '2014-08-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119576, 'Sinegorskiy', 'Sinegorskiy', 'Sinegorskij,Sinegorskiy,Синегорский', 48.0138900, 40.8446800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119577, 'Sindor', 'Sindor', 'Sindor,Sindorskaya,Синдор', 62.8628600, 51.8905100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119578, 'Sim', 'Sim', 'Sim,Simski Zavod,Сим', 54.9930000, 57.6982000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119579, 'Silikatnyy', 'Silikatnyy', 'Silikatnyj,Silikatnyy,Силикатный', 53.9895700, 48.3274900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119580, 'Sigayevo', 'Sigayevo', 'Sigaevo,Sigajevo,Sigayevo,Сигаево', 56.4216300, 53.7756600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119581, 'Sibay', 'Sibay', 'Sibai,Sibaj,Sibay,sibai,Сибай,시바이', 52.7180600, 58.6658300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119582, 'Shvartsevskiy', 'Shvartsevskiy', 'Poselok Imeni Shvartsa,Posëlok Imeni Shvartsa,Shvarcevskij,Shvartsevskiy,Sjvartsevskij,Шварцевский', 54.0917400, 37.9905300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119583, 'Shuyskoye', 'Shuyskoye', 'Shayskoye,Shuiskoe,Shujskoe,Shuyskoye,Sjujskoje,Шуйское', 59.3735600, 41.0304700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119584, 'Shuya', 'Shuya', 'Shuja,Shuya,Sjuja,Suoju,Šuoju,Шуя', 61.9525100, 34.2327100, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119585, 'Shuya', 'Shuya', 'Chouia,Chouïa,Schuja,Shuja,Shuya,Sjuja,Suia,Suja,Suya,Szuja,Xuia,Xúia,shu ya,shuya,shwaya,shwya,syuya,Ŝuja,Şuya,Šuja,Șuia,Шуя,Шуја,شوايا,شویا,シューヤ,舒亚,슈야', 56.8486500, 41.3883300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119586, 'Shuvalovo', 'Shuvalovo', 'Schuwalowo,Shuvalovo,Shuvalovo-Ozerki,Shuvalovskiy Park,Suvala,Шувалово', 60.0490300, 30.2936000, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119587, 'Shushary', 'Shushary', 'Shushary,Sjusjary,Suosaari,Suosuari,Šuošuari,Шушары', 59.8091700, 30.3816700, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119588, 'Shun’ga', 'Shun''ga', 'Shun''ga,Shun’ga,Sjunga,Sun''ga,Šun''ga,Шуньга', 62.6026300, 34.9468000, 'RU', '2015-12-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119589, 'Shumyachi', 'Shumyachi', 'Shumjachi,Shumyachi,Sjumjatsji,Шумячи', 53.8583300, 32.4241700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119590, 'Shumikhinskiy', 'Shumikhinskiy', 'Goreloye,Shumikhinskij,Shumikhinskiy,Sjumikhinskij,Шумихинский', 58.7448000, 57.6926000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119591, 'Shumeyka', 'Shumeyka', 'Shumejka,Shumeyka,Shumeykovka,Sjumejka,Шумейка', 51.5636100, 46.2483300, 'RU', '2014-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119592, 'Shumerlya', 'Shumerlya', 'Cemerle,Choumerlia,Gorad Shumerlja,Schumerlja,Shumerla,Shumerlja,Shumerlya,Sjoemerlja,Sjumerlja,Sumerl,Sumerla,Sumerlja,Szumerla,Xumerlia,Xumerlya,Xúmerlia,shu mei er li ya,shwmrlaya,shwmrlya,syumeleullya,Çĕмĕрле,Ŝumerla,Šumerl,Šumerlja,Горад Шумерля,Шумерля,Шумерља,Шөмерле,شومرلايا,شومرلیا,舒梅爾利亞,슈메를랴', 55.5005000, 46.4128800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119593, 'Shugurovo', 'Shugurovo', 'Shugurovo,Sjugurovo,Шугурово', 54.5082800, 52.1326500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119594, 'Shudayag', 'Shudayag', 'Sangorodok,Shudajag,Shudayag,Сангородок,Шудаяг', 63.5266500, 53.6058200, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119595, 'Mikhaylovsk', 'Mikhaylovsk', 'Mihajlovsk,Mikhajlovsk,Mikhaylovsk,Mikhaylovska,Mikhaylovskoye,Shpakovskoe,Shpakovskoye,Sjpakovskoje,Михайловск,Шпаковское', 45.1283300, 42.0255600, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119596, 'Shovgenovskiy', 'Shovgenovskiy', 'Khakurinokhabl'',Khakurinokhabl’,Shovgenovskij,Shovgenovskiy,Sjovgenovskij,Шовгеновский', 45.0102800, 40.2250000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119597, 'Shonguy', 'Shonguy', 'Khutora Shonguy,Schongui,Shongui,Shonguj,Shonguy,Sjonguj,Шонгуй', 68.7526100, 33.1459500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119598, 'Sholokhovskiy', 'Sholokhovskiy', 'Sholokhovka,Sholokhovskij,Sholokhovskiy,Sjolokhovskij,Шолоховский', 48.2807100, 41.0459200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119599, 'Kvartsitnyy', 'Kvartsitnyy', 'Karelgranit,Kvarcitnyj,Kvartsitni,Poselok Karelgranita,Posëlok Karelgranita,Soksunranta,Кварцитный', 61.4932100, 35.0288800, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119600, 'Shlissel’burg', 'Shlissel''burg', 'Lyyssinlinna,Noeteborg,Noteburg,Nöteborg,Paehkinaelinna,Petrokrepost'',Petrokrepost’,Pähkinälinna,Schliisselburg,Schluselburg,Schlusselburg,Schlüselburg,Schlüsselburg,Shlissel''burg,Shlissel’burg,Sjlisselburg,Нотебург,Петрокрепость,Шлиссельбург', 59.9473000, 31.0384500, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119601, 'Shkurinskaya', 'Shkurinskaya', 'Schkurinskaja,Shkurinskaja,Shkurinskaya,Sjkurinskaja,Шкуринская', 46.5858000, 39.3599000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119602, 'Shirokovskiy', 'Shirokovskiy', 'Shirokovo,Shirokovskij,Shirokovskiy,Shirokoye,Sjirokovskij,Широковский', 58.8411000, 57.7850000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119603, 'Shirochanka', 'Shirochanka', 'Shirochanka,Shirochanskoye,Sjirotsjanka,Широчанка', 46.6496800, 38.3978200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119604, 'Shiringushi', 'Shiringushi', 'Shiringushi,Sjiringusji,Ширингуши', 53.8485100, 42.7675900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119605, 'Shipitsyno', 'Shipitsyno', 'Shchipitsyno,Shipicyno,Shipitsino,Shipitsyno,Sjipitsyno,Шипицыно', 61.2805600, 46.5208300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119606, 'Shimsk', 'Shimsk', 'Shimsk,Shimskaya,Sjimsk,Шимск', 58.2120100, 30.7126900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119607, 'Shimorskoye', 'Shimorskoye', 'Gryaznovka,Shimorskoe,Shimorskoye,Sjimorskoje,Zhimorskoye,Шиморское', 55.3281000, 42.0256000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119608, 'Shilovo', 'Shilovo', 'Schilowo,Shilovo,Sjilovo,Шилово', 54.3204000, 40.8740000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119609, 'Shilovo', 'Shilovo', 'Shilovo,Шилово', 51.5458300, 39.0891700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119610, 'Shil’da', 'Shil''da', 'Shil''da,Shil’da,Sjilda,Шильда', 51.8143000, 59.7744000, 'RU', '2014-07-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119611, 'Shikhazany', 'Shikhazany', 'Shikhazany,Sjikhazany,Шихазаны', 55.5604700, 47.3929700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119612, 'Shikhany', 'Shikhany', 'Shikhany,Sjikhany,Шиханы', 52.1177600, 47.1986000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119613, 'Shigony', 'Shigony', 'Shigony,Sjigony,Шигоны', 53.3875000, 48.6777000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119614, 'Sheremet’yevskiy', 'Sheremet''yevskiy', 'Sheremet''evskij,Sheremet''yevskiy,Sheremet’yevskiy,Shermet''yevo,Shermet’yevo,Sjeremetjevskij,Шереметьевский', 55.9758300, 37.4941700, 'RU', '2012-05-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119615, 'Shepsi', 'Shepsi', 'Shepsi,Sjepsi,Шепси', 44.0355000, 39.1474000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119616, 'Shentala', 'Shentala', 'Shentala,Sjentala,Шентала', 54.4500000, 51.4833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119617, 'Shenkursk', 'Shenkursk', 'Chenkoursk,Gorad Shehnkursk,Schenkursk,Senkursk,Shengkar,Shenkursk,Shénkursk,Sjenkoersk,Sjenkursk,Szenkursk,shen ku er si ke,shnkwrsk,Ŝenkursk,Šenkursk,Горад Шэнкурск,Шенгкар,Шенкурск,شنكورسك,شنکورسک,申库尔斯克', 62.1091000, 42.8959500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119618, 'Shemysheyka', 'Shemysheyka', 'Shemyshejka,Shemysheyka,Shemyshleyka,Sjemysjejka,Шемышейка', 52.8919600, 45.3928200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119619, 'Shemursha', 'Shemursha', 'Shemursha,Sjemursja,Шемурша', 54.8866300, 47.5189300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119620, 'Shemordan', 'Shemordan', 'Shemordan,Sjemordan,Шемордан', 56.1856000, 50.3972000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119621, 'Shemëtovo', 'Shemetovo', 'Shemetovo,Shemjotovo,Shemëtovo,Шемётово', 56.5276400, 38.0751800, 'RU', '2014-11-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119622, 'Sheltozero', 'Sheltozero', 'Sheltozero,Sheltozerskiy,Shjoltozero,Sjeltozero,Soutjaervi,Soutjärvi,Šoutjärvi,Šoutjärv´,Шелтозеро,Шёлтозеро', 61.3666700, 35.3666700, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119623, 'Shelkovskaya', 'Shelkovskaya', 'Sarapan,Schelkowskaja,Selkovskaja,Selkovski,Shelkovs''ka,Shelkovskaja,Shelkovskaya,Shelkovski,Sjelkovskaja,syelkobseukaya,Şelkovski,Šelkovskaja,Сарапан,Шелковская,Шелковски,Шелковська,셸콥스카야', 43.5080400, 46.3401600, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119624, 'Sheksna', 'Sheksna', 'Nikol''skoye,Nikol’skoye,Sheksna,Sjeksna,Шексна', 59.2099800, 38.5106600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119625, 'Shedok', 'Shedok', 'Shchedok,Shedok,Sjedok,Шедок', 44.2179000, 40.8487000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119626, 'Shebekino', 'Shebekino', 'Shebekino,Sjebekino,Шебекино', 50.4096700, 36.9136000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119627, 'Shchukino', 'Shchukino', 'Shchukino,Shhukino,Щукино', 55.8000000, 37.4500000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119628, 'Shchigry', 'Shchigry', 'Chtchigry,Gorad Shchygry,Schtschigry,Scigri,Scigry,Shchigary,Shchigri,Shchigry,Shhigri,Shhigry,Shigri,Sjtsjigry,Stsigro,Stsigry,Suchigry,Szczigry,shchygry,shigri,shtshyghry,xi ge lei,Ŝĉigri,Štšigry,Štšigrõ,Šćigry,Ščigry,Горад Шчыгры,Шигри,Шчигри,Щигри,Щигры,Щигры балһсн,شتشيغري,شچیگری,შიგრი,希格雷', 51.8755500, 36.9043200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119629, 'Shcherbinka', 'Shcherbinka', 'Shcherbinka,Shcherbinki,Shherbinka,Sjtsjerbinka,Щербинка', 55.4997200, 37.5597200, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119630, 'Shchelkovo', 'Shchelkovo', 'Shchelkovo,Shchyolkovo,Shhelkovo,Shhjolkovo,Щелково,Щёлково', 55.9249700, 37.9721800, 'RU', '2016-05-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119631, 'Shchëkino', 'Shchekino', 'Schekino,Shchekino,Shchëkino,Shehekino,Shhekino,Shhjokino,Щекино,Щёкино', 54.0051300, 37.5219400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119632, 'Shcheglovo', 'Shcheglovo', 'Shcheglovo,Shheglovo,Sieklova,Sjtsjeglovo,Щеглово', 60.0283900, 30.7528900, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119633, 'Shaygino', 'Shaygino', 'Shajgino,Shaygino,Sjajgino,Шайгино', 57.7675100, 46.8618100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119634, 'Shaturtorf', 'Shaturtorf', 'Poselok Tsentral''nyy,Posëlok Tsentral’nyy,Shaturtorf,Sjaturtorf,Tsentral''ny,Tsentral’ny,Шатурторф', 55.5671100, 39.4212900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119635, 'Shatura', 'Shatura', 'Chatoura,Gorad Shatura,Satura,Schatura,Shatura,Shatúra,Sjatura,Szatura,sha tu la,shatwra,Ŝatura,Şatura,Šatura,Горад Шатура,Шатура,شاتورا,沙圖拉', 55.5725300, 39.5368200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119636, 'Shatsk', 'Shatsk', 'Chatsk,Gorad Shack,Sack,Satsk,Schazk,Shac''k,Shack,Shatsk,Sjatsk,Sjatsk i Russland,sha ci ke,shatsk,shatsk  rwsyh,shatsuku,syacheukeu,Ŝack,Šack,Šatsk,Горад Шацк,Шацк,Шацьк,Շացկ,شاتسك,شاتسک، روسیه,シャーツク,沙茨克,샤츠크', 54.0257600, 41.7119100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119637, 'Shatki', 'Shatki', 'Shatki,Sjatki,Шатки', 55.1887400, 44.1248600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119638, 'Shatalovo', 'Shatalovo', 'Shatalovo,Sjatalovo,Шаталово', 54.3340000, 32.4465000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119639, 'Shar’ya', 'Shar''ya', 'Shar''ja,Shar''ya,Shar’ya,Sjarja,Шарья', 58.3690900, 45.5155800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119640, 'Sharlyk', 'Sharlyk', 'Sharlyk,Sjarlyk,Шарлык', 52.9166700, 54.7500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119641, 'Sharkan', 'Sharkan', 'Sharkan,Sjarkan,Шаркан', 57.2988500, 53.8712200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119642, 'Sharanga', 'Sharanga', 'Sharanga,Sjaranga,Шаранга', 57.1774900, 46.5395600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119643, 'Sharan', 'Sharan', 'Sharan,Sjaran,Шаран', 54.8166700, 54.0000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119644, 'Shamkhal-Termen', 'Shamkhal-Termen', 'Shamkhal-Termen,Sjamkhal-Termen,Шамхал-Термен', 43.0338900, 47.3105300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119645, 'Shamkhal', 'Shamkhal', 'Shamkal,Shamkhal,Sjamkhal,Шамхал', 43.0595800, 47.3373200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119646, 'Shamary', 'Shamary', 'Shamary,Sjamary,Шамары', 57.3434000, 58.2198800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119647, 'Shalya', 'Shalya', 'Shalja,Shalya,Shiyariya,Sjalja,Шаля', 57.2471000, 58.7298000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119648, 'Shalushka', 'Shalushka', 'Shalushka,Sjalusjka,Шалушка', 43.5325000, 43.5661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119649, 'Shal’skiy', 'Shal''skiy', 'Sala,Shal''skij,Shal''skiy,Shala,Shal’skiy,Sjalskij,Шальский', 61.7969800, 36.0168000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119650, 'Shali', 'Shali', 'Chali,Gorad Shali,Mezhdurech''e,Mezhdurech''ye,Mezhdurech’ye,Meƶdurece,Meƶdureçe,Sali,Schali,Sela,Shak,Shali,Shalí,Shela,Sjali,Szali,Xali,Xalí,sha li,shaly,shaly  chchnstan,Ŝali,Şela,Šali,Горад Шалі,Междуречье,Шали,Шали балһсн,Шалі,Шела,شالي,شالی، چچنستان,沙里', 43.1480600, 45.9019400, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119651, 'Shalazhi', 'Shalazhi', 'Konev,Konjov,Konëv,Makane-KIotar,Makane-Khotar,Podgornoe,Podgornoye,Shalazha,Shalazhi,Sjalazji,Şalaƶa,Şalaƶi,Конёв,Макане-КІотар,Подгорное,Шалажа,Шалажи', 43.0947600, 45.3589800, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119652, 'Shalakusha', 'Shalakusha', 'Shalakusha,Sjalakusja,Шалакуша', 62.2247200, 40.2538900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119653, 'Shakhun’ya', 'Shakhun''ya', 'Shakhun''ja,Shakhun''ya,Shakhun’ya,Sjakhunja,Шахунья', 57.6757900, 46.6113600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119654, 'Shakhty', 'Shakhty', 'Aleksandrovsk-Grushevskiy,Aleksandrovsk-Grushevskoy,Chakhty,Gorad Shakhty,Sachtos,Sachty,Sahti,Sahto,Sahty,Saxti,Schachty,Shajty,Shakhti,Shakhty,Sjachty,Sjakhty,Szachty,sha he te,shakhtay,shakhty,syaheuti,Ŝaĥti,Şahti,Şaxtı,Šachtos,Šachty,Šahti,Šahty,Šahtõ,Șahtî,Горад Шахты,Шахти,Шахты,شاختاي,شاختی,沙赫特,샤흐티', 47.7091100, 40.2144300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119655, 'Shakhta', 'Shakhta', 'Poselok Shakhta Nomer Shestoy,Posëlok Shakhta Nomer Shestoy,Shakhta,Sjakhta,Шахта', 59.0905000, 57.6575000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119656, 'Shakhovskaya', 'Shakhovskaya', 'Shakhovskaja,Shakhovskaya,Sjakhovskaja,Шаховская', 56.0314700, 35.5069700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119657, 'Shafranovo', 'Shafranovo', 'Shafranovo,Sjafranovo,Шафраново', 53.9666700, 54.7666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119658, 'Shaburnovo', 'Shaburnovo', 'Shaburnovo,Sjaburnovo,Шабурново', 56.5500000, 37.9333300, 'RU', '2014-11-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119659, 'Shablykino', 'Shablykino', 'Shablykino,Sjablykino,Шаблыкино', 52.8566100, 35.1963700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119660, 'Shabel’skoye', 'Shabel''skoye', 'Shabei''sk,Shabei’sk,Shabel''sk,Shabel''skoe,Shabel''skoye,Shabel’sk,Shabel’skoye,Sjabelskoje,Шабельское', 46.8527500, 38.4727800, 'RU', '2012-05-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119661, 'Shaami-Yurt', 'Shaami-Yurt', 'Saami-Jurt,Saman-Yurt,Sawmin-Yurt,ShaImin-Jurt,Shaami-Jurt,Shaami-Yurt,Shama-Yurt,Shaman-Jurt,Shaman-Yurt,Sjaami-Jurt,Zelenaja Rosca,Zelenaya Rosha,Zelenaya Roshcha,Zeljonaja Roshha,Zelënaja Rošča,Zelënaya Roshcha,Şaman-Yurt,Şawmin-Yurt,Šaami-Jurt,Зелёная Роща,ШаІмин-Юрт,Шаами-Юрт,Шаман-Юрт', 43.2263200, 45.3920300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119662, 'Sevsk', 'Sevsk', 'Sevsk,Syevsk,Севск', 52.1491000, 34.4926000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119663, 'Severskaya', 'Severskaya', 'Severs''ka,Severskaia,Severskaja,Severskaya,Severskaïa,Sewerskaja,Séverskaya,Северская,Сєверська', 44.8540700, 38.6768600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119664, 'Severo-Zadonsk', 'Severo-Zadonsk', 'Severo-Zadonsk,Северо-Задонск', 54.0348100, 38.4017200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119665, 'Severoural’sk', 'Severoural''sk', 'Petropavlovsk,Petropavlovski,Petropavlovskiy,Petropavlovskoye,Severoural''sk,Severouralsk,Severoural’sk,Североуральск', 60.1532800, 59.9520500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119666, 'Severomorsk', 'Severomorsk', 'Gorad Severamorsk,Severomors''k,Severomorsk,Severomorskas,Seweromorsk,Sewjeromorsk,Siewieromorsk,Szeveromorszk,Vaenga,Vaenka,Vayenga,bei mo er si ke,sebelomoleuseukeu,sevu~eromorusuku,sfyrwmwrsk,swrwmwrsk,sywrwmwrsk,Горад Севераморск,Североморск,Сєвєроморськ,سفيرومورسك,سورومورسک,سیورومورسک,セヴェロモルスク,北莫爾斯克,세베로모르스크', 69.0688900, 33.4162200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119667, 'Severodvinsk', 'Severodvinsk', 'Gorad Severadzvinsk,Molotovsk,Molotowsk,Severodvins''k,Severodvinsk,Severodvinska,Severodvinskas,Sewerodwinsk,Sewjerodwinsk,Siewierodwinsk,Siewierodwińsk,Sudostroy,bei de wen si ke,sebelodeubinseukeu,sevu~erodovu~insuku,sfrwdfnsk,swrwdwynsk,sywrwdwnsk,Горад Северадзвінск,Северодвинск,Сєверодвінськ,سفرودفنسك,سورودوینسک,سیورودونسک,სევეროდვინსკი,セヴェロドヴィンスク,北德文斯克,세베로드빈스크', 64.5635000, 39.8302000, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119668, 'Tretiy Severnyy', 'Tretiy Severnyy', 'Severnyy Tretiy,Tretij severnyj,Tretiy Severnyy,Третий северный', 60.2086100, 59.9611100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119669, 'Severnyy-Kospashskiy', 'Severnyy-Kospashskiy', 'Severnyj-Kospashskij,Severnyj-Kospasjskij,Severnyy-Kospashskiy,Северный-Коспашский', 59.0897000, 57.8039000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119670, 'Severnyy', 'Severnyy', 'Severnyj,Severnyy,Северный', 56.7333300, 37.6500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119671, 'Severnyy', 'Severnyy', 'Severnyj,Severnyy,Северный', 55.9358300, 37.5488900, 'RU', '2013-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119672, 'Severnyy', 'Severnyy', 'Severnyj,Severnyy,Северный', 50.6770400, 36.5532400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119673, 'Severnyy', 'Severnyy', 'Severny,Severnyj zh/m,Северный ж/м', 47.2893600, 39.7124900, 'RU', '2009-12-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119674, 'Severnoye', 'Severnoye', 'Severnoe,Severnoje,Severnoye,Sok-Karmalinsk,Северное', 54.0934700, 52.5439300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119675, 'Severnoye', 'Severnoye', 'Severnoe,Severnoje,Severnoye,Северное', 44.8319400, 42.8583300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119676, 'Setun’', 'Setun''', 'Setun'',Setun’,Сетунь', 55.7166700, 37.4166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119677, 'Sestroretsk', 'Sestroretsk', 'Gorad Sestrarehck,Sestrorec''k,Sestroreck,Sestrorecka,Sestroreckas,Sestroretk,Sestroretsk,Sestrorezk,Sestrorețk,Sestrorjeck,Siestarjoki,Systerbaeck,Systerbäck,Systerpekki,seseuteulolecheukeu,sstrwrtsk,xie si de luo lie ci ke,Горад Сестрарэцк,Сестроретск,Сестрорецк,Сестрорецьк,سسترورتسك,سسترورتسک,სესტრორეცკი,謝斯得羅列茨克,세스트로레츠크', 60.0980100, 29.9637800, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119678, 'Seshcha', 'Seshcha', 'Seshcha,Seshchinskiy,Seshha,Sesjtsja,Сеща', 53.7361000, 33.3387000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119679, 'Serzhen’-Yurt', 'Serzhen''-Yurt', 'Podlesnoe,Podlesnoye,Serzen''-Jurt,Serzhen''-Jurt,Serzhen''-Yurt,Serzhen’-Yurt,Serzjen-Jurt,Seržen’-Jurt,Sirzh-Ehvla,Sirzha-Ehvl,Sirzha-Ehvla,Sirƶ-Evla,Sirƶa-Evl,Sirƶa-Evla,Подлесное,Сержень-Юрт,Сирж-Эвла,Сиржа-Эвл,Сиржа-Эвла', 43.1226500, 45.9858300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119680, 'Sertolovo', 'Sertolovo', 'Sertolova,Sertolovo,Sertolovo Pervoye,Sertolowo,Sierattala,Siertolowo,Siertołowo,Sértolovo,serutorovu~o,srtwlwfw,xie er tuo luo fu,Сертолово,Сєртолово,سرتولوفو,სერტოლოვო,セルトロヴォ,謝爾托洛夫', 60.1444000, 30.2016500, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119681, 'Serpukhov', 'Serpukhov', 'Serpoechov,Serpuchov,Serpuchow,Serpuhhov,Serpuhov,Serpukhov,Serpuĥov,Sierpuchow,Sierpukhovo,seleupuhopeu,Серпухов,세르푸호프', 54.9157800, 37.4111400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119682, 'Sernur', 'Sernur', 'Sernur,Сернур', 56.9333300, 49.1536100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119683, 'Sernovodsk', 'Sernovodsk', 'Aslambekovskoe,Aslambekovskoye,Aslanbek,Ehnakhishka,Enaxiska,Enaxişka,Mikhailovskaya,Mikhajlovskaja,Mikhaylovskaya,Mixaylovskaya,Sernovodsk,Sernovodskoe,Sernovodskoye,Асламбековское,Асланбек,Михайловская,Серноводск,Серноводское,Энахишка', 43.3117200, 45.1593900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119684, 'Sernovodsk', 'Sernovodsk', 'Sernovodsk,Серноводск', 53.9229300, 51.2570400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119685, 'Sergokala', 'Sergokala', 'Sergokala,Sergokalkh,Сергокала', 42.4546800, 47.6611900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119686, 'Sergiyev Posad', 'Sergiyev Posad', 'Sergiev Posad,Sergijev Posad,Sergijev Possad,Sergijew Possad,Sergiyev,Sergiyev Posad,Sergiyevskiy Posad,Siergijew Posad,Zagorsk,Сергиев Посад,Сергијев Посад', 56.3000000, 38.1333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119687, 'Sergach', 'Sergach', 'Sergach,Sergatsj,Сергач', 55.5307900, 45.4661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119688, 'Serëdka', 'Seredka', 'Seredka,Serjodka,Serëdka,Серёдка', 58.1583800, 28.1857600, 'RU', '2017-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119689, 'Seredeyskiy', 'Seredeyskiy', 'Seredejskij,Seredeyskiy,Yermolovo,Середейский', 54.0507100, 35.2318300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119690, 'Serebryanyye Prudy', 'Serebryanyye Prudy', 'Serebrenne-Prudi,Serebrjanye Prudy,Serebryanyye Prudy,Серебряные Пруды', 54.4692300, 38.7209500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119691, 'Serdobsk', 'Serdobsk', 'Bol''shaya Serdoba,Bol’shaya Serdoba,Gorad Sjardobsk,Serdobsk,Sierdobsk,Sjerdobsk,srdwbsk,xie er duo bu si ke,Горад Сярдобск,Сердобск,Сердобск балһсн,سردوبسك,سردوبسک,謝爾多布斯克', 52.4586100, 44.2168900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119692, 'Serafimovskiy', 'Serafimovskiy', 'Serafimovka,Serafimovskij,Serafimovskiy,Серафимовский', 54.4240800, 53.7964000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119693, 'Serafimovich', 'Serafimovich', 'Gorad Serafimovich,Serafimovic,Serafimovich,Serafimovitch,Serafimovitch Pristan,Serafimovits,Serafimovitsj,Serafimovitx,Serafimovitš,Serafimoviĉ,Serafimovič,Serafimowic,Serafimowitsch,Serafimowič,Serafimóvitx,Ust''-Medveditskaya,Ust’-Medveditskaya,srafymwftsh,srafymwwych,sui la fei mo wei qi,Горад Серафімовіч,Серафимович,Серафимович балһсн,سرافيموفتش,سرافیموویچ,綏拉菲莫維奇', 49.5786000, 42.7360000, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119694, 'Sennoy', 'Sennoy', 'Sennoj,Sennoy,Сенной', 52.1509000, 46.9630900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119695, 'Sengiley', 'Sengiley', 'Sengelei,Sengilej,Sengiley,Сенгилей', 53.9622200, 48.7944400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119696, 'Semkhoz', 'Semkhoz', 'Semkhoz,Семхоз', 56.2833300, 38.0666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119697, 'Semiluki', 'Semiluki', 'Gorad Sjamiluki,Semilouki,Semiluki,Siemiluki,Siemiłuki,semilluki,smylwky,smylywky,xie mi lu ji,Горад Сямілукі,Семилуки,Семилуки балһсн,سميليوكي,سمیلوکی,謝米盧基,세밀루키', 51.6852500, 39.0278700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119698, 'Semiletka', 'Semiletka', 'Semiletka,Семилетка', 55.3602800, 54.6152800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119699, 'Semikarakorsk', 'Semikarakorsk', 'Gorad Semikarakorsk,Semikarakors''k,Semikarakorsk,Semikarakorskaya,Semikarakorskiy,Semikarakovskaya,smykarakwrsk,xie mi ka la ke er si ke,Горад Семікаракорск,Семикаракорск,Семикаракорск балһсн,Семикаракорськ,Սեմիկարակորսկ,سميكاراكورسك,سمیکاراکورسک,謝米卡拉科爾斯克', 47.5194300, 40.8112000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119700, 'Semibratovo', 'Semibratovo', 'Isady,Semibratovo,Семибратово', 57.3046100, 39.5368800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119701, 'Semënovskoye', 'Semenovskoye', 'Semenovskoye,Semjonovskoe,Semënovskoye,Семёновское', 55.6833300, 37.5500000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119702, 'Semënov', 'Semenov', 'Semenov,Semenow,Semenowo,Semjonov,Semyonov,Semënov,Семенов,Семёнов', 56.7874900, 44.4929700, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119703, 'Selyatino', 'Selyatino', 'Seljatino,Selyatino,Селятино', 55.5151400, 36.9774600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119704, 'Selty', 'Selty', 'Selty,Селты', 57.3132000, 52.1345000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119705, 'Sel’tso', 'Sel''tso', 'Sel''co,Sel''tso,Sel’tso,Сельцо', 53.3683100, 34.1032800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119706, 'Selizharovo', 'Selizharovo', 'Selijarovo,Selizharovo,Selizjarovo,Селижарово', 56.8518800, 33.4486900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119707, 'Selishche', 'Selishche', 'Selishche,Selishhe,Selisjtsje,Селище', 56.8879400, 33.2691400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119708, 'Selezni', 'Selezni', 'Selezni,Селезни', 52.8041500, 41.2396100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119709, 'Segezha', 'Segezha', 'Poselok Segezha,Posëlok Segezha,Segesha,Segeza,Segezha,Segezja,Segeža,Sekee,Сегежа', 63.7414700, 34.3221800, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119710, 'Sedkyrkeshch', 'Sedkyrkeshch', 'Sedkyrkeshch,Sedkyrkeshh,Sedkyrkesjtsj,Седкыркещ', 61.7500000, 50.9166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119711, 'Sechenovo', 'Sechenovo', 'Sechenovo,Setsjenovo,Teply Stan,Teplyy Stan,Tëply Stan,Tëplyy Stan,Сеченово', 55.2244400, 45.8905600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119712, 'Sebrovo', 'Sebrovo', 'Sebrovo,Себрово', 50.0981000, 43.2976000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119713, 'Sebezh', 'Sebezh', 'Gorad Sebezh,Sebej,Sebesch,Sebez,Sebezas,Sebezh,Sebezj,Sebeĵ,Sebež,Sebežas,Siebiez,Siebież,sbj,sbzh,sebeji,sebesi,xie bie ri,Горад Себеж,Себеж,سبج,سبژ,セーベジ,謝別日,세베시', 56.2954600, 28.4653800, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119714, 'Sazonovo', 'Sazonovo', 'Belyye Kresty,Sazonovo,Сазоново', 59.0919000, 35.2268000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119715, 'Savino', 'Savino', 'Savina,Savino,Савино', 56.5928500, 41.2181400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119716, 'Savinka', 'Savinka', 'Savinka,Савинка', 50.0784800, 47.0993600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119717, 'Savasleyka', 'Savasleyka', 'Savaslejka,Savasleyka,Savostleyka,Саваслейка', 55.4606000, 42.3207000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119718, 'Satka', 'Satka', 'Chatky,Gorad Satka,Satka,sa te ka,satka,Горад Сатка,Сатка,Чаткы,ساتكا,ساتکا,薩特卡', 55.0425000, 59.0400000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119719, 'Satis', 'Satis', 'Satis,Сатис', 54.9229000, 43.2297700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119720, 'Satinka', 'Satinka', 'Satinka,Сатинка', 52.3792300, 41.6819200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119721, 'Sasykoli', 'Sasykoli', 'Sasykoli,Сасыколи', 47.5515300, 46.9967900, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119722, 'Sary-Tyuz', 'Sary-Tyuz', 'Prikubanskoye,Sary-Tjuz,Sary-Tyuz,Сары-Тюз', 43.9018100, 41.8952300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119723, 'Sars', 'Sars', 'Sars,Сарс', 56.5501700, 57.1365800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119724, 'Sarov', 'Sarov', 'Arzamas-16,Gorad Sarou,Kremlev,Kremlëv,Sarov,Sarova,Sarow,Sarykylych,Szarov,sa luo fu,salopeu,sarofu,sarwf,Горад Сароў,Саров,Сарыкылыч,ساروف,サロフ,薩羅夫,사로프', 54.9358300, 43.3235200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119725, 'Sarmanovo', 'Sarmanovo', 'Sarmanovo,Sarmany,Сарманово', 55.2552900, 52.5890700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119726, 'Sarmakovo', 'Sarmakovo', 'Sarlyukovo,Sarmakovo,Сармаково', 43.7455600, 43.2002800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119727, 'Saratovskaya', 'Saratovskaya', 'Saratovskaja,Saratovskaya,Саратовская', 44.7075200, 39.2215600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119728, 'Saratov', 'Saratov', 'Gorad Saratau,ISaratov,RTW,Saratof,Saratov,Saratov osh,Saratova,Saratovas,Saratovia,Saratovu,Saratow,Saratu,Saratuovs,Saratów,Saretow,Sarytau,Saràtov,Sarátov,Szaratov,sa la tuo fu,salatopeu,saratofu,saratova,saratwf,srʼtwb,Σαράτοφ,Горад Саратаў,Сарăту,Саратов,Саратов балһсн,Саратов ош,Саратовъ,Сарытау,Һарытау,Սարատով,סראטוב,ساراتوف,ساراٹوف,सारातोव,სარატოვი,サラトフ,薩拉托夫,사라토프', 51.5405600, 46.0086100, 'RU', '2012-12-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119729, 'Sarapul', 'Sarapul', 'Gorad Sarapul,Sarapoel,Sarapoul,Sarapul,Sarapulas,Sarapuł,Szarapul,sa la pu er,sarabwl,sarapl,sarapuru,sarapwl,Горад Сарапул,Сарапул,سارابول,ساراپل,ساراپول,サラプル,萨拉普尔', 56.4763300, 53.7978200, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119730, 'Sarany', 'Sarany', 'Saranovskiy,Sarany,Сараны', 58.5000000, 58.8833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119731, 'Saransk', 'Saransk', 'Gorad Saransk,SKX,Saran,Saran osh,Saranosh,Sarans''k,Saransk,Saranska,Saranskas,Saransko,Sarańsk,Szaranszk,sa lan si ke,sa ran skh,salanseukeu,saransk,saranska,saransuku,sransk,srnsq,Горад Саранск,Саран,Саран ош,Саранош,Саранск,Саранск балһсн,Саранськ,סרנסק,سارانسك,سارانسک,سرانسک,सारान्स्क,ซารันสค์,サランスク,萨兰斯克,사란스크', 54.1838000, 45.1749000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119732, 'Sarana', 'Sarana', 'Nizhnyaya Sarana,Sarana,Сарана', 56.4772800, 57.7258600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119733, 'Saraktash', 'Saraktash', 'Saraktash,Saraktasj,Саракташ', 51.7877100, 56.3609100, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119734, 'Sarai', 'Sarai', 'Sarai,Сараи', 53.7457700, 41.0212600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119735, 'Sapozhok', 'Sapozhok', 'Sapozhok,Sapozjok,Сапожок', 53.9419400, 40.6805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119736, 'Sapërnyy', 'Sapernyy', 'Sap''orni,Sapernyj,Sapernyy,Sapjornyj,Sapërnyy,Саперный,Сапёрный', 59.7761100, 30.6613900, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119737, 'Sapernoye', 'Sapernoye', 'Kasarmila,Sapernoe,Sapernoje,Sapernoye,Саперное', 60.7141800, 29.9552500, 'RU', '2012-11-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119738, 'Saint Petersburg', 'Saint Petersburg', 'Agia Petroupole,Betuyrbukh,LED,Leningrad,Leningrado,Lungsod ng Sankt-Peterburg,Peterburg,Peterburgo,Peterburi,Petersburg,Petrapilis,Petrograd,Petrogrado,Petrohrad,Petropolis,Petursborg,Pietari,Piiteri,Piter,Pétursborg,SPb,Saint Petersbourg,Saint Petersburg,Saint Pétersbourg,Saint-Petersbourg,Saint-Pétersbourg,San Petersburgo,San Pietroburgo,San Pietruburgu,Sankt Peitersbuerg,Sankt Peterburg,Sankt Peterburgas,Sankt Petersborg,Sankt Petersburg,Sankt Peterzburg,Sankt Péitersbuerg,Sankt-Peterburg,Sankt-Peterburgo,Sankt-Petersburg,Sankti Petursborg,Sankti Pétursborg,Sanktpeterburga,Sanktpēterburga,Sant Petersburg,Sant Petersburgo,Sant-Petersbourg,Santa Peterburg,Sao Petersburgo,Sint Petersbork,Sint-Petersburg,St Petersburg,St. Petersburg,St.-Petersburg,Szentpetervar,Szentpétervár,São Petersburgo,leningeuladeu,sangteupeteleubuleukeu,sankt. peterburg,sankutopeteruburuku,sant btrsbrgh,seinteupiteojeubeogeu,sent pi te xrs beirk,sheng bi de bao,sn ptrzbwrg,snqt ptrbwrg,Αγία Πετρούπολη,Бетъырбух,Ленинград,Петербург,Петроград,Питер,СПб,Санкт Петербург,Санкт Петерзбург,Санкт-Петербург,Սանկտ Պետերբուրգ,סנקט פטרבורג,سانت بطرسبرغ,سن پترزبورگ,เซนต์ปีเตอร์สเบิร์ก,სანკტ-პეტერბურგი,სანქტ-პეტერბურგი,サンクトペテルブルク,圣彼得堡,레닌그라드,상트페테르부르크,세인트피터즈버그', 59.9386300, 30.3141300, 'RU', '2017-07-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119739, 'Sandovo', 'Sandovo', 'Bandovo,Sandovo,Сандово', 58.4602200, 36.4127700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119740, 'Sandata', 'Sandata', 'Sandata,Сандата', 46.2708100, 41.7583400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119741, 'Sanchursk', 'Sanchursk', 'Sanchursk,Santsjursk,Санчурск', 56.9412500, 47.2498700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119742, 'Samur', 'Samur', 'Samur,Самур', 41.8252700, 48.4859700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119743, 'Samoylovka', 'Samoylovka', 'Imeni Samilovoi Promysel,Samoilovka,Samoilovoi,Samojlovka,Samoylovka,Самойловка', 51.1840000, 43.7081000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119744, 'Samoded', 'Samoded', 'Samoded,Самодед', 63.6083000, 40.5111000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119745, 'Sambek', 'Sambek', 'Sambek,Самбек', 47.7430600, 39.8308300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119746, 'Samashki', 'Samashki', 'Samashki,Samashkinskaja,Samashkinskaya,Samashkinskoye,Samasjki,Samaski,Samaskinskaya,Samaşki,Samaşkinskaya,SemaIashka,Semajaska,Semajaşka,Semashki,Самашки,Самашкинская,СемаІашка', 43.2905600, 45.3013900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119747, 'Samarskoye', 'Samarskoye', 'Samarskoe,Samarskoje,Samarskoye,Sanarskoye,Самарское', 46.9370000, 39.6881000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119748, 'Samara', 'Samara', 'Gorad Samara,KUF,Kuibyschew,Kuibyshev,Kujbyshev,Kuybyshev,Samar,Samar khot,Samar osh,Samara,Samarae,Samare,Samarga,Samāra,Szamara,sa ma la,sa ma ra,samala,samara,smara,smara  rws,smrh,Σαμάρα,Горад Самара,Куйбышев,Самар,Самар ош,Самар хот,Самарæ,Самара,Самаре,Самарҕа,Һамар,Սամարա,סמרה,سامارا,سامارہ,سمارا,سمارا، روس,समारा,ซามารา,სამარა,サマーラ,薩馬拉,사마라', 53.2000700, 50.1500000, 'RU', '2014-01-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119749, 'Saltykovka', 'Saltykovka', 'Saltykovka,Салтыковка', 55.7667900, 37.9353300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119750, 'Sal’sk', 'Sal''sk', 'Sal''sk,Salsk,Sal’sk,Ssalsk,Torgovyy,Сальск', 46.4747000, 41.5411400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119751, 'Salmi', 'Salmi', 'Salmi,Salmis,Салми', 61.3697100, 31.8518500, 'RU', '2016-09-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119752, 'Salavat', 'Salavat', 'Gorad Salavat,Salauat,Salavat,Salavat i Russland,Salavata,Salavatas,Salawat,Saławat,Szalavat,sa la wa te,salafat,salawat,salawat  rwsyh,saravu~ato,Горад Салават,Салават,Салават балһсн,Салауат,سالافات,سالاوات,سالاوات، روسیه,サラヴァト,薩拉瓦特', 53.3836500, 55.9077300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119753, 'Sakmara', 'Sakmara', 'Sakmara,Sakmora,Сакмара', 51.9843800, 55.3338000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119754, 'Sakharovo', 'Sakharovo', 'Sakharovo,Сахарово', 56.8994900, 36.0501500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119755, 'Sagopshi', 'Sagopshi', 'Nogtsard,Sagopsh,Sagopshi,Sagopshin,Sagopsji,Сагопши', 43.4851500, 44.5906300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119756, 'Safonovo', 'Safonovo', 'Grjasnaja Guba,Gryaznaya,Gryaznaya Guba,Gryaznyy,Safonovo,Сафоново', 69.0604300, 33.2952300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119757, 'Safonovo', 'Safonovo', 'Safonovo,Сафоново', 55.1500000, 33.2166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119758, 'Sadovoye', 'Sadovoye', 'Pervoye Sadovoye,Sadovoe,Sadovoje,Sadovoye,Sadovoye Pervoye,Sadovoye Vtoroye,Садовое', 51.5311100, 40.5019400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119759, 'Sadovoye', 'Sadovoye', 'Sadovoe,Sadovoje,Sadovoye,Sadowoje,Садовое', 47.7772000, 44.5208000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119760, 'Sachkovichi', 'Sachkovichi', 'Sachkovichi,Satsjkovitsji,Сачковичи', 52.3459000, 32.2246000, 'RU', '2014-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119761, 'Sabnova', 'Sabnova', 'Sabnova,Сабнова', 42.0761700, 48.2479600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119762, 'Rzhev', 'Rzhev', 'Gorad Rzhehu,Raesevae,Rescovia,Rjev,Rjov,Rschew,Rshew,Rzev,Rzew,Rzhev,Rzjev,Räsevä,Rĵev,Rżew,Ržev,lei re fu,leujepeu,rjyf,rujefu,rzb,rzhf,rzhyf,Горад Ржэў,Ржев,רזב,رجيف,رژف,رژیف,ルジェフ,勒熱夫,르제프', 56.2624100, 34.3281700, 'RU', '2012-09-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119763, 'Rzhavki', 'Rzhavki', 'Rzhavki,Rzjavki,Ржавки', 56.0000000, 37.2500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119764, 'Rzhanitsa', 'Rzhanitsa', 'Rzhanica,Rzhanitsa,Rzjanitsa,Ржаница', 53.4284400, 33.9229700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119765, 'Rzhaksa', 'Rzhaksa', 'Rshaksa,Rzhaksa,Rzjaksa,Ржакса', 52.1338400, 42.0264000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119766, 'Ryzdvyanyy', 'Ryzdvyanyy', 'Ryzdvjanyj,Ryzdvyannyy,Ryzdvyanyy,Рыздвяный', 45.2656000, 41.8389000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119767, 'Rybnoye', 'Rybnoye', 'Rybnoe,Rybnoje,Rybnoye,Рыбное', 54.7277400, 39.5173100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119768, 'Rybnaya Sloboda', 'Rybnaya Sloboda', 'Rybnaja Sloboda,Rybnaya Sloboda,Рыбная Слобода', 55.4612900, 50.1409000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119769, 'Rybinsk', 'Rybinsk', 'Andropov,Gorad Rybinsk,RYB,Ribins''k,Ribinsk,Ribinska,Ribinsko,Robinsk,Rybinsk,Rybinskas,Rybińsk,Ríbinsk,Rîbinsk,Rõbinsk,Rýbinsk,Rıbinsk,Shcherbakov,lei bin si ke,libinseukeu,raybansk,ruibinsuku,rybnsk,rybynsk,Горад Рыбінск,Рибинск,Рибінськ,Рыбинск,رايبانسك,ریبنسک,ریبینسک,ルイビンスク,雷宾斯克,리빈스크', 58.0446000, 38.8425900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119770, 'Rybatskoye', 'Rybatskoye', 'Rybackoe,Rybatskoye,Rybazkoje,Рыбацкое', 59.8393000, 30.4987300, 'RU', '2016-08-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119771, 'Ryazhsk', 'Ryazhsk', 'Gorad Razhsk,Riajsk,Riazhsk,Rjajsk,Rjaschsk,Rjazhsk,Rjazjsk,Rjazsk,Rjaĵsk,Rjažsk,Ryazhsk,li ya ri si ke,lyasiseukeu,rayajsk,ryajisuku,ryazhsk,Горад Ражск,Ряжск,راياجسك,ریاژسک,リャジスク,里亞日斯克,랴시스크', 53.7038000, 40.1109000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119772, 'Ryazanskaya', 'Ryazanskaya', 'Rayazanskaya,Riazanskaia,Rjazanskaja,Ryazanskaya,Ryazanskoye,Рязанская', 44.9552800, 39.5889400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119773, 'Ryazan’', 'Ryazan''', 'RZN,Resania,Riazan,Riazań,Rjasan,Rjazan,Rjazan'',Rjazaň,Ryazan,Ryazan'',Ryazan’,liang zan,lyajan,ryazan,Рязань,リャザン,梁赞,랴잔', 54.6269000, 39.6916000, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119774, 'Ryabovo', 'Ryabovo', 'Raeaepyae,Rjabovo,Ryabovo,Rääpyä,Рябово', 59.4000000, 31.1333300, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119775, 'Ruzayevka', 'Ruzayevka', 'Orazaj osh,Orozay,Rusaevka,Ruzaevka,Ruzajevka,Ruzayevka,Оразай ош,Рузаевка', 54.0638700, 44.9509000, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119776, 'Ruza', 'Ruza', 'Gorad Ruza,Rouza,Rusa,Ruza,Ruzae,lu zha,luja,ruza,rwza,Горад Руза,Рузæ,Руза,Руза балһсн,روزا,ルザ,魯扎,루자', 55.6989800, 36.1952200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119777, 'Rutul', 'Rutul', 'Rutul,Рутул', 41.5356600, 47.4239100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119778, 'Russko-Vysotskoye', 'Russko-Vysotskoye', 'Russko-Vysockoe,Russko-Vysotskoje,Russko-Vysotskoye,Vennaein-Vuissakka,Vennäin-Vuissakka,Vysotskoye,Русско-Высоцкое', 59.6996300, 29.9440400, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119779, 'Russkiy Kameshkir', 'Russkiy Kameshkir', 'Kameshkir Russkiy,Russkij Kameshkir,Russkij Kamesjkir,Russkiy Kameshkir,Russkiy Kameskir,Русский Камешкир', 52.8595500, 46.0886100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119780, 'Ruskeala', 'Ruskeala', 'Ruskeala,Рускеала', 61.9333300, 30.5833300, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119781, 'Rumyantsevo', 'Rumyantsevo', 'Rumjancevo,Rumjantsevo,Rumyantseva,Rumyantsevo,Румянцево', 55.9727800, 36.5341700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119782, 'Rudnya', 'Rudnya', 'Rudnja,Rudnya,Рудня', 54.9469800, 31.0934000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119783, 'Rudnya', 'Rudnya', 'Rudnja,Rudnya,Рудня', 50.7989800, 44.5585600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119784, 'Rudnichnyy', 'Rudnichnyy', 'Averbakhovskoye,Rudnichnyj,Rudnichnyy,Rudnitsjnyj,Рудничный', 59.6170200, 52.4703300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119785, 'Rublëvo', 'Rublevo', 'Rublevo,Rubljovo,Rublëvo,Рублево,Рублёво', 55.7851400, 37.3548100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119786, 'Rtishchevo', 'Rtishchevo', 'Gorad Rcishchava,Rtichtchevo,Rtiscevas,Rtiscevo,Rtiscewo,Rtischtschewo,Rtisevo,Rtishchevo,Rtishevo,Rtishhevo,Rtisjtjevo,Rtisjtsjevo,Rtistsevo,Rtisxevo,Rtiszczewo,Rtiŝĉevo,Rtişevo,Rtištševo,Rtišćewo,Rtiščevas,Rtiščevo,Rtișcevo,Rtíshchevo,Rtísxevo,lei ji xie wo,rtyshchfw,rtyshtshyfw,Горад Рцішчава,Ртишево,Ртишчево,Ртищево,Ртищево балһсн,رتيشتشيفو,رتیشچفو,勒季謝沃', 52.2604100, 43.7874500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119787, 'Rozhdestveno', 'Rozhdestveno', 'Possata,Rozhdestveno,Rozjdestveno,Рождествено', 59.3181200, 29.9459400, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119788, 'Rozhdestveno', 'Rozhdestveno', 'Rozhdestveno,Rozhdestvino,Рождествено', 55.8544400, 37.0493500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119789, 'Rozhdestveno', 'Rozhdestveno', 'Rozhdestveno,Rozjdestveno,Рождествено', 53.2374500, 50.0597100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119790, 'Rovnoye', 'Rovnoye', 'Rovnoe,Rovnoje,Rovnoye,Zel''man,Zel’man,Ровное', 50.7765000, 46.0508500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119791, 'Rostov-na-Donu', 'Rostov-na-Donu', 'Don umbalne Rostov,Dondaguy Rostov,Dondagy Rostov,Dondokhi Rostov,Doni Rostov,Donyn Rostov,Gorad Rastou-na-Done,ROV,Rostof aan die Don,Rostof epi tou Nton,Rostov,Rostov Don,Rostov Donal,Rostov Doni aeaeres,Rostov Doni ääres,Rostov aan de Don,Rostov de Don,Rostov del Don,Rostov do Don,Rostov na Don,Rostov na Donu,Rostov nad Donom,Rostov sopra-u-Donu,Rostov sul Don,Rostov tren song GJong,Rostov trên sông Đông,Rostov ved Don,Rostov-Don,Rostov-Donyl,Rostov-Tan-cinchi,Rostov-an-Don,Rostov-ar-Ddon,Rostov-na-Donu,Rostov-on-Don,Rostov-pe-Don,Rostov-sur-le-Don,Rostova pie Donas,Rostovas prie Dono,Rostovia ad Tanaim,Rostow,Rostow Am Don,Rostow am Don,Rostow na Donu,Rostow nad Donem,Rostow nad Donom,Rostòv de Dòn,Rostóv na Donú,Rostów nad Donem,Rosztov-na-Donu,Tyndagy Rostov,dun he pan luo si tuo fu,loseutopeunadonu,rastov-an-dan,rostova dona,rwstwf-na-dwnw,rwstww na danw,Ροστόφ επί του Ντον,Горад Растоў-на-Доне,Дон ӱмбалне Ростов,Дон-тӀера-Ростов,Дондагъы Ростов,Дондағы Ростов,Дондохи Ростов,Донын Ростов,Растовъ на Донѣ,Ростов,Ростов на Дон,Ростов на Дону,Ростов-Доныл,Ростов-Тан-çинчи,Ростов-на-Дону,Ростов-на-Дону балһсн,Тындагы Ростов,Դոնի Ռոստով,רוסטוב על הדון,روستوف-نا-دونو,روستوو نا دانو,रोस्तोव दॉन,ರಾಸ್ಟೊವ್-ಆನ್-ಡಾನ್,დონის როსტოვი,დონიშ როსტოვი,ロストフ・ナ・ドヌ,顿河畔罗斯托夫,로스토프나도누', 47.2313500, 39.7232800, 'RU', '2013-03-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119792, 'Rostov', 'Rostov', 'Gorad Rastou,Rastovu,Rostoph,Rostov,Rostov Veliki,Rostov Velikij,Rostov Velikiy,Rostov-Yaroslavskiy,Rostova,Rostovas,Rostovia,Rostow,Rostów,Rosztov,Styr Rostov,loseutopeu,luo si tuo fu,rostova,rosutofu,rwstwb,rwstwf,Ροστόφ,Горад Растоў,Растовъ,Ростов,Стыр Ростов,רוסטוב,روستوف,रोस्तोव,ロストフ,罗斯托夫,로스토프', 57.1914000, 39.4139400, 'RU', '2013-03-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119793, 'Rostokino', 'Rostokino', 'Rostckino,Rostokino,Ростокино', 55.8333300, 37.6666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119794, 'Rossosh’', 'Rossosh''', 'Pervaya Rossosh'',Pervaya Rossosh’,Rossosh'',Rossosh'' Pervaya,Rossoshi,Rossosh’,Rossosh’ Pervaya,Rossosji,Россошь', 51.1209000, 38.5116000, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119795, 'Rossosh’', 'Rossosh''', 'Rossoh'',Rossos,Rossosch,Rossosh'',Rossosh’,Rossosj,Rossoš,Россошь', 50.1982800, 39.5672600, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119796, 'Roslyakovo', 'Roslyakovo', 'Rosljakova,Rosljakovo,Roslyakova,Roslyakovo,Росляково', 69.0430300, 33.1990600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119797, 'Roslavl’', 'Roslavl''', 'Raslawl,Roslavl,Roslavl'',Roslavl’,Roslawl,Рославль', 53.9527800, 32.8638900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119798, 'Roshni-Chu', 'Roshni-Chu', 'Lesnoe,Lesnoye,Roshni-Chu,Rosjni-Tsju,Rosni-Cu,Rosnicu,Roşni-Çu,Roşniçu,Лесное,Рошни-Чу', 43.0895400, 45.4543500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119799, 'Roshchino', 'Roshchino', 'Raivola,Rayvola,Roshchino,Roshhino,Rosjtsjino,Рощино', 60.2519100, 29.6085000, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119800, 'Mariyenburg', 'Mariyenburg', 'Imeni Roshalya,Marienburg,Mariyenburg,Poselok Roshalya,Posëlok Roshalya,Roshalya,Sahanmylly,Мариенбург', 59.5713900, 30.0647200, 'RU', '2017-02-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119801, 'Roshal’', 'Roshal''', 'Krestov Brod,Roshal'',Roshal’,Rosjal,Рошаль', 55.6685300, 39.8748800, 'RU', '2015-06-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119802, 'Romodanovo', 'Romodanovo', 'Romodanovo,Ромоданово', 54.4275300, 45.3296200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119803, 'Romanovskaya', 'Romanovskaya', 'Romanovskaja,Romanovskaya,Romanovskaya-na-Donu,Rynok-Romanovskiy,Романовская', 47.5426000, 42.0285000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119804, 'Romanovka', 'Romanovka', 'Romanaisi,Romanovka,Романовка', 60.0443000, 30.7140000, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119805, 'Romanovka', 'Romanovka', 'Romanovka,Romanowka,Романовка', 51.7442700, 42.7527000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119806, 'Rogovskaya', 'Rogovskaya', 'Ragovskaya,Rogovskaja,Rogovskaya,Rogovskoye,Rogowskaja,Stanitsa Rogovskaya,Роговская', 45.7311700, 38.7396000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119807, 'Rogovatoye', 'Rogovatoye', 'Pervoye Rogovatoye,Rogovato-Pogoreloye,Rogovatoe,Rogovatoje,Rogovatoye,Роговатое', 51.2300000, 38.3818000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119808, 'Rognedino', 'Rognedino', 'Rognedino,Рогнедино', 53.8014700, 33.5576000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119809, 'Rogachëvo', 'Rogachevo', 'Rogachevo,Rogachjovo,Rogachëvo,Rogatsjevo,Рогачево,Рогачёво', 56.4333300, 37.1666700, 'RU', '2014-07-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119810, 'Rodnikovskaya', 'Rodnikovskaya', 'Rodnikovskaja,Rodnikovskaya,Родниковская', 44.7644400, 40.6655600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119811, 'Rodniki', 'Rodniki', 'Gorad Radniki,Rodniki,Rodnikí,luo de ni ji,rwdnyky,rwdnyky  awblast aywanwf,Горад Раднікі,Родники,رودنيكي,رودنیکی، اوبلاست ایوانوف,羅德尼基', 57.1051300, 41.7304800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119812, 'Rodniki', 'Rodniki', 'Ovrazhki-Vyalki,Rodniki,Родники', 55.6520400, 38.0668500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119813, 'Rodionovo-Nesvetayskaya', 'Rodionovo-Nesvetayskaya', 'Rodionoff,Rodionovo-Nesvetajskaja,Rodionovo-Nesvetayskaya,Rodionovo-Nesvetayskiy,Rodionovo-Nesvetayskoye,Родионово-Несветайская', 47.6103300, 39.7121200, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119814, 'Rodionovo-Nesvetaiskoye', 'Rodionovo-Nesvetaiskoye', 'Rodionovo-Nesvetaiskoe,Rodionovo-Nesvetaiskoye,Rodionovo-Nesvetajskaja,Родионово-Несветаиское', 47.6000000, 39.7000000, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119815, 'Rochegda', 'Rochegda', 'Rochegda,Rotsjegda,Рочегда', 62.6678000, 43.4133000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119816, 'Revyakino', 'Revyakino', 'Revjakino,Revyakino,Rewjakino,Ревякино', 54.3651700, 37.6624900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119817, 'Revda', 'Revda', 'Revda,Ревда', 67.9371000, 34.5614900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119818, 'Revda', 'Revda', 'Gorad Rehuda,Revda,Revda i Sverdlovsk oblast,Revnta,Rewda,lie fu da,rfda  awblast swrdlwfsk,ryfda,rywda,Ρεβντά,Горад Рэўда,Ревда,Рәүде,رفدا، اوبلاست سوردلوفسک,ريفدا,ریودا,列夫達', 56.8009700, 59.9302800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119819, 'Reutov', 'Reutov', 'Reoutov,Reutov,Reutova,Reutovas,Reutovo,Reutow,Rieutow,Rjeutov,Rjeutow,Réutov,lie wu tuo fu,rywtwf,Реутов,Реутов балһсн,Рјеутов,رئوتوف,ريوتوف,ریوتوف,列烏托夫', 55.7611100, 37.8575000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119820, 'Reshetnikovo', 'Reshetnikovo', 'Reshetnikovo,Resjetnikovo,Решетниково', 56.4500000, 36.5666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119821, 'Reshetikha', 'Reshetikha', 'Reshetikha,Resjetikha,Решетиха', 56.2156600, 43.2880200, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119822, 'Repnoye', 'Repnoye', 'Repnoe,Repnoje,Repnoye,Репное', 51.5921000, 43.1861000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119823, 'Repino', 'Repino', 'Kuokkala,Repino,Репино', 60.1721700, 29.8690800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119824, 'Remontnoye', 'Remontnoye', 'Dzhurak,Remontnoe,Remontnoje,Remontnoye,Ремонтное', 46.5614000, 43.6501000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119825, 'Redkino', 'Redkino', 'Redkino,Редкино', 56.6475400, 36.2967400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119826, 'Rechitsy', 'Rechitsy', 'Rechicy,Rechitsy,Retsjitsy,Речицы', 55.5975400, 38.4713400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119827, 'Razumnoye', 'Razumnoye', 'Razumnoe,Razumnoje,Razumnoye,Rozumnoye,Разумное', 50.5343900, 36.6846200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119828, 'Razliv', 'Razliv', 'Razliv,Rosliva,Разлив', 60.0791900, 29.9720600, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119829, 'Rayevskiy', 'Rayevskiy', 'Al''sheevo,Raevka,Raevskij,Rajevskij,Rayevskiy,Əl''shəj,Альшеево,Раевка,Раевский,Әльшәй', 54.0658000, 54.9468000, 'RU', '2014-02-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119830, 'Rayevskaya', 'Rayevskaya', 'Krasnaya Medvedovskaya,Krasno-Medvedovskaya,Raevskaja,Rajevskaja,Rayevskaya,Раевская', 44.8357100, 37.5557700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119831, 'Rassvet', 'Rassvet', 'Rassvet,Рассвет', 46.8333300, 40.7500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119832, 'Rasskazovo', 'Rasskazovo', 'Gorad Raskazava,Raskazovo,Rasskasowo,Rasskazovo,Rasskazowo,la si ka zuo wo,raskazwfw,Горад Расказава,Расказово,Рассказово,Рассказово балһсн,راسكازوفو,راسکازوفو,拉斯卡佐沃', 52.6559900, 41.8846100, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119833, 'Rasshevatskaya', 'Rasshevatskaya', 'Rasshevatskaja,Rasshevatskaya,Rasshevatskoye,Rassjevatskaja,Расшеватская', 45.5748000, 41.0349600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119834, 'Ramon’', 'Ramon''', 'Ramon,Ramon'',Ramon’,Рамонь', 51.9156900, 39.3360900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119835, 'Rameshki', 'Rameshki', 'Rameshki,Ramesjki,Рамешки', 57.3439000, 36.0453500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119836, 'Ramenskoye', 'Ramenskoye', 'Gorad Ramenskae,Ramenska,Ramenskoe,Ramenskoie,Ramenskoje,Ramenskojė,Ramenskoye,Ramenskoïe,Ramienskoje,Rámenskoye,la mian si ke ye,lamenseukoye,ramensukoe,ramnskwy,ramnskwyh,Горад Раменскае,Раменское,Раменскоје,رامنسكوي,رامنسکوئے,رامنسکویه,ラメンスコエ,拉緬斯科耶,라멘스코예', 55.5669400, 38.2302800, 'RU', '2016-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119837, 'Ramenki', 'Ramenki', 'Ramenka,Ramenki,Раменки', 55.7000000, 37.5000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119838, 'Rakitnoye', 'Rakitnoye', 'Rakitnoe,Rakitnoje,Rakitnoye,Ракитное', 50.8389000, 35.8515000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119839, 'Rakhmanovo', 'Rakhmanovo', 'Rakhmanovo,Рахманово', 55.7440100, 38.6112400, 'RU', '2013-10-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119840, 'Radovitskiy', 'Radovitskiy', 'Radovickij,Radovitskij,Radovitskiy,Tsentral''nyy,Tsentral’nyy,Радовитский,Радовицкий', 55.1282000, 39.7956000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119841, 'Radumlya', 'Radumlya', 'Radomlya,Radumlja,Radumlya,Радумля', 56.0690100, 37.1497900, 'RU', '2014-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119842, 'Raditsa-Krylovka', 'Raditsa-Krylovka', 'Krylovka,Radica-Krylovka,Raditsa-Krylovka,Samara Raditsa,Радица-Крыловка', 53.3171200, 34.3574200, 'RU', '2012-02-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119843, 'Radishchevo', 'Radishchevo', 'Radishchevo,Radishhevo,Radisjtsjevo,Радищево', 52.8545900, 47.8764400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119844, 'Radchenko', 'Radchenko', 'Radchenko,Radtsjenko,Tos,Радченко', 56.6802700, 36.3717800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119845, 'Pytalovo', 'Pytalovo', 'Abrene,Gorad Pytalava,Jaunlatgale,Pitalova,Pitalovo,Potalovo,Pyatalovo,Pytalovas,Pytalovo,Pytalowo,Pytałowo,Põtalovo,Yaunlatgale,bytalwfw,pei ta luo wo,pitallobo,pu~itarovu~o,pyatalwfw,Горад Пыталава,Питалово,Пыталово,بيتالوفو,پیاتالوفو,プィタロヴォ,佩塔洛沃,피탈로보', 57.0679100, 27.9138400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119846, 'Pyshchug', 'Pyshchug', 'Pyshchug,Pyshhug,Pysjtsjug,Пыщуг', 58.8872600, 45.7134100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119847, 'Pyra', 'Pyra', 'Poselok Pyrskiy,Posëlok Pyrskiy,Pyra,Пыра', 56.2952700, 43.3527400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119848, 'Pychas', 'Pychas', 'Pychas,Pytsjas,Пычас', 56.5033200, 52.4408800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119849, 'Pyatovskiy', 'Pyatovskiy', 'Pjatovskij,Pyatovskiy,Пятовский', 54.6890800, 36.0563400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119850, 'Pyatnitskoye', 'Pyatnitskoye', 'Pjatnickoe,Pjatnitskoje,Pyatnitskoye,Пятницкое', 50.4233000, 37.8273000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119851, 'Pyatigorskiy', 'Pyatigorskiy', 'Myassovkhoz Pyatigorskiy,Pjatigorskij,Pyatigorskiy,Пятигорский', 43.9741700, 43.2583300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119852, 'Pyatigorsk', 'Pyatigorsk', 'Five Mountains,Piatigorsk,Pjatigors''k,Pjatigorsk,Pyatigorsk,pyachigorusuku,pyatigoleuseukeu,wu shan cheng,Пятигорск,Пятигорськ,פיאטיגורסק,ピャチゴルスク,五山城,퍄티고르스크', 44.0486100, 43.0594400, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119853, 'Pyaozerskiy', 'Pyaozerskiy', 'Paeaejaervi,Piaejaervi,Piäjärvi,Pjaozerskij,Pääjärvi,Пяозерский', 65.7687000, 31.0892500, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119854, 'Putyatino', 'Putyatino', 'Putjanino,Putjatino,Putyatino,Путянино,Путятино', 54.1599800, 41.1169000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119855, 'Puteyets', 'Puteyets', 'Puteec,Putejets,Puteyets,Путеец', 65.1715700, 57.0910100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119856, 'Pustoshka', 'Pustoshka', 'Gorad Pustoshka,Poestosjka,Poustochka,Pustoschka,Pustoshka,Pustosjka,Pustosk,Pustoska,Pustoŝka,Pustošk,Pustoška,bwstwshka,pu si tuo shen ka,puseutosika,pusutoshika,pwstwshka,Горад Пустошка,Пустошка,بوستوشكا,پوستوشکا,プストシカ,普斯托什卡,푸스토시카', 56.3354700, 29.3690100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119857, 'Pushkinskiye Gory', 'Pushkinskiye Gory', 'Pushkinskie Gory,Pushkinskiy,Pushkinskiye Gory,Pusjkinskije Gory,Puskinskie Gory,Puskinskije Goro,Puskinskije Gory,Puškinskie Gory,Puškinskije Gory,Puškinskije Gorõ,Пушкинские Горы', 57.0208500, 28.9103000, 'RU', '2015-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119858, 'Pushkino', 'Pushkino', 'Poesjkino,Pouchkino,Puschkino,Pushkino,Pusjkino,Puskino,Puszkino,Puŝkino,Puşkino,Puškino,Púshkino,bwshkynw,pu xi jin nuo,pwshkynw,pwshkynw  astan mskw,Пушкино,Пушкіно,بوشكينو,پوشکینو,پوشکینو، استان مسکو,普希金諾', 56.0172200, 37.8666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119859, 'Pushkino', 'Pushkino', 'Pushkino,Pusjkino,Urbakh,Пушкино', 51.2350000, 46.9741700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119860, 'Pushkin', 'Pushkin', 'Detskoye Selo,Puschkin,Pushkin,Pusjkin,Saari,Suari,Tsarskoye Selo,Šuari,Пушкин', 59.7141700, 30.3964200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119861, 'Pushchino', 'Pushchino', 'Gorad Pushchyna,Pouchtchino,Puschtschino,Puscino,Pushchino,Pushchino-na-Oke,Pushhino,Pushino,Pusjtsjino,Pustsino,Pusxino,Puszczino,Puŝĉino,Puštšino,Pušćino,Puščino,Púsxino,bwshtshynw,pu xi nuo,pushichino,pusichino,pwshchynw,pwshynw,Горад Пушчына,Пушино,Пушчино,Пущино,Пущино балһсн,بوشتشينو,پوشچینو,پوشینو,プーシチノ,普希諾,푸시치노', 54.8337300, 37.6113800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119862, 'Purshevo', 'Purshevo', 'Purshevo,Пуршево', 55.7212400, 38.0327700, 'RU', '2016-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119863, 'Purekh', 'Purekh', 'Purekh,Пурех', 56.6468400, 43.0677200, 'RU', '2013-06-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119864, 'Puksoozero', 'Puksoozero', 'Puksoozero,Пуксоозеро', 62.5903000, 40.6066000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119865, 'Pugachev', 'Pugachev', 'Nikolayevsk,Pugachev,Pugatschew,Pugatsjev,Пугачев', 52.0133300, 48.8025000, 'RU', '2015-03-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119866, 'Pudozh', 'Pudozh', 'Gorad Pudazh,Poedozj,Poudoj,Pudoj,Pudosch,Pudosh,Pudoz,Pudozh,Pudozj,Pudoĵ,Pudoż,Pudož,Puudogu,Puudosi,Puudozi,Puudoži,Puutosi,Puutoši,bwdwj,pu duo ri,pudosi,pwdwzh,Горад Пудаж,Пудож,بودوج,پودوژ,普多日,푸도시', 61.8041500, 36.5277000, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119867, 'Pudem', 'Pudem', 'Pudem,Пудем', 58.3047000, 52.1673000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119868, 'Puchezh', 'Puchezh', 'Poutchej,Pucej,Pucez,Puchezh,Putschesch,Putsez,Putsjezj,Putxej,Putšež,Puĉeĵ,Pučež,Púchezh,Pútxej,bwtshyj,pu qie ri,pwchzh,Пучеж,بوتشيج,پوچژ,普切日', 56.9787800, 43.1676100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119869, 'Psyzh', 'Psyzh', 'Psyzh,Psyzj,Псыж', 44.2330600, 42.0183300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119870, 'Psygansu', 'Psygansu', 'Psygansu,Psygasu,Псыгансу', 43.4194400, 43.7936100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119871, 'Pskov', 'Pskov', 'Gorad Pskou,PKV,Pihkova,Pihkva,Pleskau,Pleskava,Pscovia,Pskof,Pskov,Pskov osh,Pskovas,Pskovo,Pskow,Psków,Pszkov,bskwf,pas khxf,peuseukopeu,pskwf,psqwb,pu si ke fu,pusukofu,Горад Пскоў,Пльсковъ · Рѡсїи,Псков,Псков ош,Պսկով,פסקוב,بسكوف,پسکوف,ปัสคอฟ,ფსკოვი,プスコフ,普斯科夫,프스코프', 57.8136000, 28.3496000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119872, 'Pshekhskaya', 'Pshekhskaya', 'Pshekhskaja,Pshekhskaya,Psjekhskaja,Пшехская', 44.6959700, 39.7966500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119873, 'Pshada', 'Pshada', 'Pshada,Psjada,Пшада', 44.4700000, 38.3996000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119874, 'Psedakh', 'Psedakh', 'Alanskoye,Alonskoye,Psedakh,Пседах', 43.4672200, 44.5691700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119875, 'Psebay', 'Psebay', 'Isebay,Psebaj,Psebay,Psebayskaya,Псебай', 44.1234000, 40.8107000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119876, 'Pryazha', 'Pryazha', 'Krasnaya Pryazha,Praeaesae,Priaezy,Priaza,Priaża,Priäžy,Prjascha,Prjaza,Prjazha,Prjazja,Prjaža,Pryaza,Pryazha,Prääsä,Teru,Пряжа,Պրյաժա', 61.6925800, 33.6215900, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119877, 'Pryamitsyno', 'Pryamitsyno', 'Prjamicyno,Prjamitsyno,Pryamitsino,Pryamitsyno,Прямицыно', 51.6561000, 35.9314000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119878, 'Prudy', 'Prudy', 'Prudy,Sobakino,Пруды', 57.5738000, 46.2717600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119879, 'Protvino', 'Protvino', 'Protvino,Protwino,brwtfynw,prwtwynw,pu luo te wei nuo,Протвино,Протвино балһсн,Протвіно,بروتفينو,پروتوینو,普羅特維諾', 54.8682100, 37.2158300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119880, 'Pronsk', 'Pronsk', 'Pronsk,Пронск', 54.1048000, 39.6092000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119881, 'Proletarskiy', 'Proletarskiy', 'Proletarskij,Proletarskiy,Пролетарский', 55.0221900, 37.3901900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119882, 'Proletarskiy', 'Proletarskiy', 'Gotnya,Proletarskij,Proletarskiy,Пролетарский', 50.7913900, 35.7730600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119883, 'Proletarsk', 'Proletarsk', 'Gorad Praletarsk,Proletars''k,Proletarsk,Proletarskaja,Proletarskaya,brwlytarsk,prwltarsk,pu luo lie ta er si ke,Горад Пралетарск,Пролетарск,Пролетарск балһсн,Пролетарськ,Պրոլետարսկ,بروليتارسك,پرولتارسک,普羅列塔爾斯克', 46.7028900, 41.7271700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119884, 'Proletariy', 'Proletariy', 'Proletarij,Proletariy,Пролетарий', 58.4342300, 31.7046200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119885, 'Kipen’', 'Kipen''', 'Kipen,Kipen'',Kipen’,Kuippina,Prokovsino,Verkhnyaya Kipen'',Verkhnyaya Kipen’,Кипень', 59.6740700, 29.8497700, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119886, 'Prokhorovka', 'Prokhorovka', 'Aleksandrovskij,Aleksandrovskiy,Prochorovka,Prochorowka,Prohorovka,Prokhorovka,brwkhwrwfka,pu luo huo luo fu ka,purohorofuka,Александровский,Прохоровка,بروخوروفكا,プロホロフカ,普洛霍羅夫卡', 51.0374100, 36.7325200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119887, 'Prokhladnyy', 'Prokhladnyy', 'Prochladnaja,Prochladnyj,Prohladnyi,Prokhladneh,Prokhladnyj,Prokhladnyy,Прохладный,Прохладнэ', 43.7574100, 44.0297000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119888, 'Prochnookopskaya', 'Prochnookopskaya', 'Prochnookopskaja,Prochnookopskaya,Protchanokopskaya,Protchnokopskaya,Protsjnookopskaja,Прочноокопская', 45.0666000, 41.1175000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119889, 'Priyutovo', 'Priyutovo', 'Prijutovo,Priyutovo,Приютово', 53.9000000, 53.9333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119890, 'Priyutnoye', 'Priyutnoye', 'Antanur,Prijutnoe,Prijutnoje,Priyutnoye,Приютное', 46.1011100, 43.5072200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119891, 'Privolzhskoye', 'Privolzhskoye', 'Boregardt,Privolzhskoe,Privolzhskoye,Privolzjskoje,Приволжское', 51.6919400, 46.7236100, 'RU', '2014-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119892, 'Privolzhskiy', 'Privolzhskiy', 'Privolzhskij,Privolzhskiy,Privolzjskij,Приволжский', 51.4094400, 46.0483300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119893, 'Privolzhsk', 'Privolzhsk', 'Privoljsk,Privolshk,Privolzhsk,Privolzjsk,Privolzsk,Privolĵsk,Privolžsk,Priwolschsk,Priwolzsk,Priwolžsk,Yakovlevskoye,bryfwljsk,prywwlzhsk,pu li wo er ri si ke,Приволжск,Приволшк,بريفولجسك,پریوولژسک,普里沃爾日斯克', 57.3869800, 41.2866600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119894, 'Privodino', 'Privodino', 'Privodino,Приводино', 61.0759900, 46.5023800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119895, 'Priupskiy', 'Priupskiy', 'Priupskij,Priupskiy,Приупский', 53.9096000, 37.7360000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119896, 'Pristen’', 'Pristen''', 'Mar''ino,Mar’ino,Pristen,Pristen'',Pristen’,Пристень', 51.2355100, 36.6959400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119897, 'Priozërsk', 'Priozersk', 'Kaegoeisalmi,Kaekisalmi,Kakisalmi,Keksgol''m,Keksgol’m,Keksholm,Kexholm,Kjakisalmi,Korela,Kyakisalmi,Kägöisalmi,Käkisalmi,Käkišalmi,Priozersk,Priozjorsk,Priozërsk,Yeksgol''m,Yeksgol’m,Кексгольм,Корела,Кякисалми,Приозерск,Приозёрск', 61.0392800, 30.1290700, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119898, 'Primorka', 'Primorka', 'Kosa Kuryacha,Primorka,Primorskoye,Приморка', 47.2839500, 39.0640800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119899, 'Primorsko-Akhtarsk', 'Primorsko-Akhtarsk', 'Akhtari,Gorad Prymorska-Akhtarsk,Primors''ko-Akhtars''k,Primorsko-Achidrskaja,Primorsko-Achtarsk,Primorsko-Ahtarsk,Primorsko-Ajtarsk,Primorsko-Akhtarsk,Primorsko-Akhtarskaya,Primorsko-Axtarsk,Primorsko-Aĥtarsk,Stantsiya Primorsko-Akhtarskaya,bin hai a he ta er si ke,brymwrskw-akhtarsk,prymwrskw-akhtarsk,Горад Прыморска-Ахтарск,Приморско-Ахтарск,Приморско-Ахтарск балһсн,Приморсько-Ахтарськ,بريمورسكو-أختارسك,پریمورسکو-آختارسک,濱海阿赫塔爾斯克', 46.0497000, 38.1747000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119900, 'Primorsk', 'Primorsk', 'B''yerke,Bjoerkoe,Bjorko,Björkö,B’yërkë,Gorad Prymorsk,Koivisto,Koyvisto,Primors''k,Primorsk,Primorska,Primorskas,brymwrsk,peulimoleuseukeu,prymwrsk  awblast lnyngrad,pu li mo er si ke,Горад Прыморск,Приморск,Приморськ,بريمورسك,پریمورسک، اوبلاست لنینگراد,პრიმორსკი,普里莫爾斯克,프리모르스크', 60.3659300, 28.6073700, 'RU', '2012-03-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119901, 'Primorsk', 'Primorsk', 'Fischhausen,Fishgauzen,Fishhausen,Fishkhauzen,Gorad Prymorsk,Primors''k,Primorsk,Primorska,Primorskas,Skanavikas,Zuvininkai,Žuvininkai,Горад Прыморск,Приморск,Приморськ', 54.7390500, 20.0055300, 'RU', '2017-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119902, 'Primorsk', 'Primorsk', 'Lugo-Vodyanoye,Lugo-Vodyanskoye,Primorsk,Vodyanoe,Vodyanoye,Приморск', 49.2653200, 45.0288900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119903, 'Primalkinskoye', 'Primalkinskoye', 'Primalkinskoe,Primalkinskoje,Primalkinskoye,Прималкинское', 43.7466700, 44.0083300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119904, 'Prikubanskiy', 'Prikubanskiy', 'Prikubanskij,Prikubanskiy,Прикубанский', 45.0015000, 41.1795000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119905, 'Prigorodnyy', 'Prigorodnyy', 'Prigorodnyj,Prigorodnyy,Пригородный', 51.7660800, 55.2664800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119906, 'Prigorodnoye', 'Prigorodnoye', 'Komsomol''skij,Komsomol''skiy,Komsomol’skij,Komsomol’skiy,Prigorodnoe,Prigorodnoje,Prigorodnoye,Shina-Su''jran-Juku,Sina-Sueyran-Yuq,Şina-Süyran-Yuq̇,Комсомольский,Пригородное,Шина-Суьйран-Юкъ', 43.2530300, 45.7580800, 'RU', '2012-02-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119907, 'Prigorodka', 'Prigorodka', 'Prigorodka,Prigorodnaya,Пригородка', 52.0447200, 39.7123800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119908, 'Pridonskoy', 'Pridonskoy', 'Pridonskoj,Pridonskoy,Придонской', 51.6840600, 39.0727000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119909, 'Pregradnoye', 'Pregradnoye', 'Pregradnaya,Pregradnoe,Pregradnoje,Pregradnoye,Преградное', 45.8218300, 41.7469200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119910, 'Pregradnaya', 'Pregradnaya', 'Pregradnaja,Pregradnaya,Преградная', 43.9539500, 41.1891000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119911, 'Prechistoye', 'Prechistoye', 'Prechiskoe,Prechistoe,Prechistoye,Pretsjistoje,Пречистое', 58.4206800, 40.3401700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119912, 'Pravokumskoye', 'Pravokumskoye', 'Pravokumskoe,Pravokumskoje,Pravokumskoye,Правокумское', 44.7694400, 44.6472200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119913, 'Pravdinskiy', 'Pravdinskiy', 'Pravda,Pravdinskij,Pravdinskiy,Правдинский', 56.0603400, 37.8626600, 'RU', '2014-11-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119914, 'Pravdinsk', 'Pravdinsk', 'Bartu Romuva,Bartų Romuva,Fridland,Fridlyand,Friedland,Gorad Praudzinsk,Pravdins''k,Pravdinsk,Pravdinska,Pravdinskas,Pravdisk,Prawdinsk,brafdynsk,peulabeudinseukeu,prawdynsk,pu la fu jin si ke,puravujinsuku,Горад Праўдзінск,Правдинск,Правдинськ,برافدينسك,پراودینسک,プラヴジンスク,普拉夫金斯克,프라브딘스크', 54.4428900, 21.0178500, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119915, 'Praskoveya', 'Praskoveya', 'Praskoveja,Praskoveya,Praskoveyskoye,Proskoveya,Прасковея', 44.7444400, 44.2030600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119916, 'Pozhva', 'Pozhva', 'Pozhva,Pozjva,Пожва', 59.0912000, 56.0901000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119917, 'Poyakonda', 'Poyakonda', 'Pajakanta,Pojakonda,Pojakontu,Poyakonda,Пояконда', 66.5942800, 32.8208800, 'RU', '2013-02-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119918, 'Povorino', 'Povorino', 'Gorad Pavoryna,Povorino,Povórino,Poworino,Proverino,bo wo li nuo,bwfwrynw,pwwwrynw,Горад Паворына,Поворино,Поворино балһсн,بوفورينو,پووورینو,波沃里諾', 51.1945000, 42.2457000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119919, 'Povenets', 'Povenets', 'Povenec,Povenets,Poventsa,Powonez,Повенец', 62.8487000, 34.8262100, 'RU', '2016-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119920, 'Povarovo', 'Povarovo', 'Pavarovo,Povarovo,Povorovo,Поварово', 56.0666700, 37.0500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119921, 'Poshekhon’ye', 'Poshekhon''ye', 'Poshekhon''e,Poshekhon''ye,Poshekhon''ye-Volodarsk,Poshekhone,Poshekhonic,Poshekhon’ye,Poshekhon’ye-Volodarsk,Posjekhonje,Пошехонье', 58.4992800, 39.1353100, 'RU', '2013-11-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119922, 'Kotlovka', 'Kotlovka', 'Imeni Likhacheva,Imeni Likhachëva,Kotlovka,Poselok ZIL,Posëlok ZIL,Котловка', 55.6592800, 37.6040400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119923, 'Annino', 'Annino', 'Anino,Annino,Estacao Annino,Estação Annino,Poselok Annin,Posëlok Annin,annino yeog,Аннино,Анніно,안니노 역', 55.5833300, 37.6000000, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119924, 'Poselki', 'Poselki', 'Poselki,Поселки', 53.1323600, 46.5030700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119925, 'Port-Katon', 'Port-Katon', 'Port-Katon,Порт-Катон', 46.8790000, 38.7560000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119926, 'Porosozero', 'Porosozero', 'Akan"yarvi,Akan”yarvi,Porajaervi,Porajärvi,Porosozero,Поросозеро', 62.7191200, 32.7270300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119927, 'Porkhov', 'Porkhov', 'Gorad Porkhau,Porchov,Porchow,Porhov,Porhova,Porjov,Porkhov,Porĥov,Pórjov,bo er huo fu,bwrkhwf,poleuhopeu,poruhofu,pwrkhwf,Горад Порхаў,Порхов,بورخوف,پورخوف,ポルホフ,波爾霍夫,포르호프', 57.7650200, 29.5561200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119928, 'Poretskoye', 'Poretskoye', 'Poreckoe,Poretskoe,Poretskoje,Poretskoye,Поретское,Порецкое', 55.1974200, 46.3290800, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119929, 'Porech’ye-Rybnoye', 'Porech''ye-Rybnoye', 'Porech''e-Rybnoe,Porech''ye,Porech''ye-Rybnoye,Porech’ye,Porech’ye-Rybnoye,Poretsje-Rybnoje,Poryeche,Поречье-Рыбное', 57.0980500, 39.3835400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119930, 'Poputnaya', 'Poputnaya', 'Poputnaja,Poputnaya,Попутная', 44.5125000, 41.4392000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119931, 'Popovo', 'Popovo', 'Popovo,Попово', 55.0752300, 37.6672700, 'RU', '2014-06-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119932, 'Ponyri Vtoryye', 'Ponyri Vtoryye', 'Ponyri Vtorye,Ponyri Vtoryye,Vtoryye Ponyri,Поныри Вторые', 52.2799400, 36.2246100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119933, 'Pontonnyy', 'Pontonnyy', 'Pontonni,Pontonnyj,Pontonnyy,Понтонный', 59.7866700, 30.6152800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119934, 'Ponezhukay', 'Ponezhukay', 'Ponezhukaj,Ponezhukay,Ponezjukaj,Понежукай', 44.8876100, 39.3855100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119935, 'Ponazyrevo', 'Ponazyrevo', 'Ponazyrevo,Поназырево', 58.3578400, 46.3142100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119936, 'Pomary', 'Pomary', 'Pomary,Помары', 55.9681500, 48.3507200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119937, 'Polyarnyye Zori', 'Polyarnyye Zori', 'Poljarnye Zori,Poljarnyje Zori,Polyarnyye Zori,Полярные Зори', 67.3661100, 32.4980600, 'RU', '2012-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119938, 'Polyarnyy', 'Polyarnyy', 'Aleksandrovsk,Alexandrovsk,Poliarny,Poljarnyj,Polyarnoye,Polyarnyy,Port Alexandrovsk,Полярный', 69.1988900, 33.4477800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119939, 'Polyane', 'Polyane', 'Poljane,Polyane,Polyany,Полянe', 56.8769900, 28.8875200, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119940, 'Polyany', 'Polyany', 'Poljany,Polyany,Поляны', 54.7180100, 39.8293200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119941, 'Polotnyanyy Zavod', 'Polotnyanyy Zavod', 'Polotnjanyj Zavod,Polotnyani Zavod,Polotnyany Zavod,Polotnyanyy,Polotnyanyy Zavod,Полотняный Завод', 54.7213900, 35.9661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119942, 'Polessk', 'Polessk', 'Labguva,Labiau,Loebau,Polesk,Poleska,Poleskas,Polessk,Poļeska,bo lie si ke,bwlysk,polleseukeu,poressuku,pwlsk,Полесск,Пољеск,بوليسك,پولسک,ポレッスク,波列斯克,폴레스크', 54.8620500, 21.1027900, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119943, 'Poldnëvoye', 'Poldnevoye', 'Poldnevkoye,Poldnevoe,Poldnevoje,Poldnevoye,Poldnjovoe,Poldnëvoye,Полдневое,Полднёвое', 45.8556800, 47.9524100, 'RU', '2017-02-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119944, 'Polazna', 'Polazna', 'Polasna,Polazna,Полазна', 58.2922000, 56.4156000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119945, 'Pokrovskoye-Streshnëvo', 'Pokrovskoye-Streshnevo', 'Bsatsevo,Pokrovsk-Streshnevo,Pokrovsk-Streshnëvo,Pokrovsko-Streshnevo,Pokrovsko-Streshnëvo,Pokrovskoe-Streshnjovo,Pokrovskoye-Streshnevo,Pokrovskoye-Streshnëvo,Покровское-Стрешнёво', 55.8079700, 37.4581400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119946, 'Pokrovskoye', 'Pokrovskoye', 'Novopokrovskoye,Pokrovskoe,Pokrovskoje,Pokrovskoye,Staropokrovskoye,Stodolishche,Покровское', 56.6897200, 28.2548300, 'RU', '2017-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119947, 'Pokrovskoye', 'Pokrovskoye', 'Pokrovskoe,Pokrovskoje,Pokrovskoye,Pokrovskoye Lintsy,Покровское', 52.6096800, 36.8712400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119948, 'Pokrovskoye', 'Pokrovskoye', 'Pokrovskoe,Pokrovskoje,Pokrovskoye,Pokrowskoje,Покровское', 47.4157000, 38.8970600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119949, 'Pokrovskoye', 'Pokrovskoye', 'Pokrovskiy,Pokrovskoe,Pokrovskoye,Покровское', 43.2887200, 46.6652700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119950, 'Pokrovo-Prigorodnoye', 'Pokrovo-Prigorodnoye', 'Pokrovo-Prigorodnoe,Pokrovo-Prigorodnoje,Pokrovo-Prigorodnoye,Pokrovsko-Prigorodnoye,Покрово-Пригородное', 52.6840500, 41.4175200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119951, 'Pokrov', 'Pokrov', 'Gorad Pakrou,Pokrov,Pokrow,bo ke luo fu,bwkrwf,pokeulopeu,pwkrwf,Горад Пакроў,Покров,بوكروف,پوکروف,波克羅夫,포크로프', 55.9179700, 39.1724200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119952, 'Pokoynoye', 'Pokoynoye', 'Pokoinoe,Pokoinoje,Pokojnoe,Pokojnoje,Pokoynoye,Покойное', 44.8097200, 44.2516700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119953, 'Pokhvistnevo', 'Pokhvistnevo', 'Gorad Pakhvistneva,Pochvistnevo,Pochwistnewo,Pochwistniewo,Pochwistnjewo,Pohvistnevo,Pohvisztnyevo,Pojvistnevo,Pokhvicne,Pokhvistnevo,Poĥvistnevo,Pójvistnevo,Pókhvistnevo,bo he wei si te nie wo,bwkhfystnyfw,pwkhwystnfw,Горад Пахвістнева,Похвиçнĕ,Похвистнево,بوخفيستنيفو,پوخویستنفو,波赫維斯特涅沃', 53.6523700, 52.1273800, 'RU', '2011-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119954, 'Poim', 'Poim', 'Poim,Поим', 53.0263900, 43.1872100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119955, 'Pogar', 'Pogar', 'Pogar,Погар', 52.5539900, 33.2590700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119956, 'Podyuga', 'Podyuga', 'Podjuga,Podyuga,Подюга', 61.0950000, 40.8647200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119957, 'Podstepki', 'Podstepki', 'Podstepki,Podstepnoye,Подстепки', 53.5151000, 49.1355000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119958, 'Podsolnechnoye', 'Podsolnechnoye', 'Podsolnechnoe,Podsolnechnoye,Podsolnetsjnoje,Подсолнечное', 53.1500000, 52.0191000, 'RU', '2016-01-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119959, 'Podporozh’ye', 'Podporozh''ye', 'Kosenala,Koskenala,Košenala,Podporoshje,Podporozh''e,Podporozh''ye,Podporozh''ye-Verkhneye,Podporozh’ye,Podporozh’ye-Verkhneye,Podporozje,Подпорожье', 60.9112400, 34.1706400, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119960, 'Podosinovets', 'Podosinovets', 'Podosinovec,Podosinovets,Podosinovskiy,Подосиновец', 60.2775800, 47.0658700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119961, 'Podolsk', 'Podolsk', 'OSF,Podol''sk,Podolsk,Подольск', 55.4241900, 37.5547200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119962, 'Podlesnyy', 'Podlesnyy', 'Lesnoy,Pervomayskiy,Podlesnyj,Podlesnyy,Подлесный', 53.9400300, 38.2687200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119963, 'Podlesnoye', 'Podlesnoye', 'Podlesnoe,Podlesnoje,Podlesnoye,Unterval''den,Unterval’den,Подлесное', 51.8161000, 47.0090000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119964, 'Podkumskiy', 'Podkumskiy', 'Podkumok,Podkumsk', 44.0755600, 43.2102800, 'RU', '2007-05-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119965, 'Podkletnoye', 'Podkletnoye', 'Pervoye Parusnoye,Podkletnoe,Podkletnoje,Podkletnoye,Подклетное', 51.5899300, 39.4623000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119966, 'Podgorodnyaya Pokrovka', 'Podgorodnyaya Pokrovka', 'Podgornaja Pokrovka,Podgornaya Pokrovka,Podgorodnjaja Pokrovka,Podgorodnyaya Pokrovka,Подгорная Покровка,Подгородняя Покровка', 51.8280800, 54.9874000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119967, 'Podgornoye', 'Podgornoye', 'Podgornoe,Podgornoje,Podgornoye,Подгорное', 51.7350400, 39.1496100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119968, 'Podgornoye', 'Podgornoye', 'Podgornaya,Podgornoe,Podgornoje,Podgornoye,Подгорное', 50.4143000, 39.6163900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119969, 'Podgornaya', 'Podgornaya', 'Podgornaja,Podgornaya,Подгорная', 44.2030600, 43.4297200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119970, 'Podgorenskiy', 'Podgorenskiy', 'Podgorenskij,Podgorenskiy,Подгоренский', 50.4049800, 39.6429500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119971, 'Poddor’ye', 'Poddor''ye', 'Poddor''e,Poddor''ye,Poddorje,Poddor’ye,Поддорье', 57.4694700, 31.1156100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119972, 'Pochinok', 'Pochinok', 'Gorad Pachynak,Pochinok,Pocinok,Poczinok,Potchinok,Potschinok,Potsinok,Potsjinok,Potšinok,Poçinok,Poĉinok,Počinok,bo qi nuo ke,bwtshynwk,pochinokeu,pochinoku,pwchynwk  awblast asmalnsk,Горад Пачынак,Починок,بوتشينوك,پوچینوک، اوبلاست اسمالنسک,ポチノク,波奇諾克,포치노크', 54.4068500, 32.4406700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119973, 'Pochinki', 'Pochinki', 'Pochinki,Pochinki-Arzamasskiye,Potsjinki,Починки', 54.6987500, 44.8667800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119974, 'Pochep', 'Pochep', 'Pochep,Potsjep,Почеп', 52.9336000, 33.4464000, 'RU', '2014-05-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119975, 'Plyussa', 'Plyussa', 'Pljussa,Plyusa,Plyussa,Плюсса', 58.4307800, 29.3653700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119976, 'Ryazanskiy', 'Ryazanskiy', 'Plyushchevo,Plyushchëvo,Rjazanskij,Ryazanskiy,Рязанский', 55.7333300, 37.7666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119977, 'Pleshanovo', 'Pleshanovo', 'Pleshanovo,Pleshhanovo,Плешаново,Плещаново', 52.8333300, 53.4833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119978, 'Plesetsk', 'Plesetsk', 'Pleseck,Plesetsk,Pleszeck,Pljeseck,Плесецк', 62.7080400, 40.2915900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119979, 'Plës', 'Ples', 'Ples,Pljos,Plës,Плес,Плёс', 57.4586200, 41.5157900, 'RU', '2013-01-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119980, 'Plekhanovo', 'Plekhanovo', 'Plekhanovo,Semenovskoye,Плеханово', 52.6382200, 39.8472900, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119981, 'Plavsk', 'Plavsk', 'Gorad Plausk,Plavsk,Plavskiy,Plavskoye,Plawsk,Pławsk,blafsk,peullabseukeu,plafsk,pu la fu si ke,purafusuku,Горад Плаўск,Плавск,بلافسك,پلافسک,プラフスク,普拉夫斯克,플랍스크', 53.7094400, 37.2919400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119982, 'Platonovka', 'Platonovka', 'Platonovka,Платоновка', 52.7105800, 41.9519900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119983, 'Platnirovskaya', 'Platnirovskaya', 'Platnirovskaja,Platnirovskaya,Платнировская', 45.3953100, 39.3842000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119984, 'Plastunovskaya', 'Plastunovskaya', 'Plastunovskaja,Plastunovskaya,Plastunowskaja,Пластуновская', 45.2943200, 39.2650500, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119985, 'Planovskoye', 'Planovskoye', 'Planovskaya,Planovskoe,Planovskoje,Planovskoye,Плановское', 43.3984600, 44.1949000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119986, 'Pizhma', 'Pizhma', 'Pizhma,Pizjma,Пижма', 57.8641800, 47.1171400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119987, 'Pizhanka', 'Pizhanka', 'Pizhanka,Pizjanka,Пижанка', 57.4604200, 48.5420000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119988, 'Pitkyaranta', 'Pitkyaranta', 'Pitkaeranta,Pitkaranta,Pitkjaranta,Pitkyaranta,Pitkyrandu,Pitkäranta,Питкяранта', 61.5734000, 31.4791500, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119989, 'Piterka', 'Piterka', 'Piterka,Питерка', 50.6803000, 47.4453900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119990, 'Pitelino', 'Pitelino', 'Petelino,Pitelino,Пителино', 54.5776800, 41.8144800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119991, 'Pistsovo', 'Pistsovo', 'Piscovo,Pistsovo,Писцово', 57.1790400, 40.5298300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119992, 'Pirogovskiy', 'Pirogovskiy', 'Pirogovskij,Pirogovskiy,Пироговский', 55.9780600, 37.7336100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119993, 'Pirogovo', 'Pirogovo', 'Pirogovo,Пирогово', 56.7795900, 53.1495400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119994, 'Pionerskiy', 'Pionerskiy', 'Naujieji Kursiai,Naujieji Kuršiai,Neukuhren,New-Kuhren,Noy Kuren,Pionerskij,Pionerskis,Pionerskiy,Пионерский', 54.9508300, 20.2274800, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119995, 'Pinyug', 'Pinyug', 'Pinjug,Pinyug,Пинюг', 60.2509500, 47.7842500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119996, 'Pinerovka', 'Pinerovka', 'Pinerovka,Pionerovka,Пинеровка', 51.5620000, 43.0689000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119997, 'Pinega', 'Pinega', 'Pinega,Пинега', 64.6996900, 43.3901600, 'RU', '2013-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119998, 'Pindushi', 'Pindushi', 'Pinduinen,Pindushi,Pindusi,Pindusji,Pinduši,Пиндуши', 62.9151900, 34.5799600, 'RU', '2016-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(119999, 'Pil’na', 'Pil''na', 'Pil''na,Pilna,Pil’na,Пильна', 55.5539400, 45.9219400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120000, 'Pikalëvo', 'Pikalevo', 'Pikal''ovo,Pikalevo,Pikaljovo,Pikalyovo,Pikalëvo,Пикалево,Пикалёво', 59.5183300, 34.1663900, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120001, 'Pichayevo', 'Pichayevo', 'Pichaevo,Pichayevo,Pichayevo Pervoye,Pitsjajevo,Пичаево', 53.2362700, 42.2032300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120002, 'Petushki', 'Petushki', 'Gorad Petushki,Novyye Petushki,Petoesjki,Petouchki,Petuixki,Petuixkí,Petuschki,Petushki,Petushkí,Petusjki,Petuskad,Petuski,Petuŝki,Petuškad,Petuški,Pietuszki,bytwshky,pei tu shen ji,peto~ushiki,petusiki,ptwshky,Горад Петушкі,Петушки,بيتوشكي,پتوشکی,ペトゥシキ,佩圖什基,페투시키', 55.9263900, 39.4610400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120003, 'Petrozavodsk', 'Petrozavodsk', 'AEaenislinna,Gorad Petrazavodsk,PES,Petrosavodsk,Petrosawodsk,Petroskoi,Petroskoj,Petroskoj osh,Petrozavods''k,Petrozavodsk,Petrozavodska,Petrozavodskas,Petrozavodszk,Petrozavontsk,Petrozawodsk,Petrozawodzk,Pietrozawodsk,Pjetrozawodsk,bi de luo zha wo ci ke,bytrwzwfwdsk,peteulojabocheukeu,petorozavu~otsuku,petrozavodska,ptrwzawdsk,ptrwzbwdsq,pytrwzawwdsk,Äänislinna,Πετροζαβόντσκ,Горад Петразаводск,Петрозаводск,Петрозаводськ,Петроской,Петроской ош,Петроскӧй,פטרוזבודסק,بيتروزوفودسك,پتروزاودسک,پیتروزاوودسک,پیٹروزاودسک,पेत्रोज़ावोद्स्क,პეტროზავოდსკი,ペトロザヴォーツク,彼得罗扎沃茨克,페트로자보츠크,', 61.7849100, 34.3469100, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120004, 'Petrov Val', 'Petrov Val', 'Gorad Pjatrou Val,Petrov Val,Petrow Wal,Pietrow Wal,Pietrow Wał,Pjetrow Wal,bi de luo fu wa er,bytrwf fal,ptrwf wal,Горад Пятроў Вал,Петров Вал,Петров Вал балһсн,بيتروف فال,پتروف وال,彼得羅夫瓦爾', 50.1433700, 45.2095800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120005, 'Petrovsk', 'Petrovsk', 'Petrovsk,Petrovskoe,Petrovskoje,Petrovskoye,Петровск,Петровское', 57.0103900, 39.2692800, 'RU', '2015-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120006, 'Petrovskiy', 'Petrovskiy', 'Petrovskaya,Petrovskii,Petrovskij,Petrovskiy,Петровский', 56.6421000, 40.3202600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120007, 'Petrovskaya', 'Petrovskaya', 'Petrovskaja,Petrovskaya,Петровская', 55.5500000, 37.7833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120008, 'Petrovskaya', 'Petrovskaya', 'Petrovskaja,Petrovskaya,Петровская', 45.4313900, 37.9550000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120009, 'Petrovsk', 'Petrovsk', 'Gorad Pjatrousk,Petrovs''k,Petrovsk,Petrovsk i Saratov oblast,Petrowsk,Pjetrowsk,bi de luo fu si ke,bytrwfsk,ptrwfsk  awblast saratwf,Горад Пятроўск,Петровск,Петровск балһсн,Петровськ,بيتروفسك,پتروفسک، اوبلاست ساراتوف,彼得羅夫斯克', 52.3063900, 45.3916700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120010, 'Petrovo-Dal’neye', 'Petrovo-Dal''neye', 'Petrovo-Dal''nee,Petrovo-Dal''neye,Petrovo-Dalneje,Petrovo-Dal’neye,Petrovskoye,Petrovskoye-Dal''neye,Petrovskoye-Dal’neye,Петрово-Дальнее', 55.7467900, 37.1734700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120011, 'Petro-Slavyanka', 'Petro-Slavyanka', 'Petro-Slav''anka,Petro-Slavjanka,Petro-Slavyanka,Петро-Славянка', 59.8022200, 30.5069400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120012, 'Petropavlovskaya', 'Petropavlovskaya', 'Petropavlovskaja,Petropavlovskaya,Петропавловская', 45.0818900, 40.4512500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120013, 'Petropavlovskaya', 'Petropavlovskaya', 'Chur-TogIe,ChurttogIe,ChurttogIi,Cur-Toge,Curttoge,Curttogi,GIoj-GIala,Goy-Gala,Petropavlovskaja,Petropavlovskaya,Çur-Toġe,Çurttoġe,Çurttoġi,Ġoy-Ġala,ГІой-ГІала,Петропавловская,Чур-ТогІе,ЧурттогІе,ЧурттогІи', 43.3794400, 45.8261100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120014, 'Petrodvorets', 'Petrodvorets', 'Petergof,Petrodvorec,Petrodvorets,Петродворец', 59.8956500, 29.8014500, 'RU', '2016-10-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120015, 'Peterhof', 'Peterhof', 'Gorad Pecjargof,Paleizencomplex in Peterhof,Peterchof,Petergof,Peterhof,Peterhofa,Peterhofium,Peterkhof,Petrodvorec,Petrodvorets,Petěrgof,Pietarhovi,Pjetergof,Pēterhofa,bi de gong cheng,bytyrhwf,peteleugopeu,peterugofu,ptrgwf,pʼetʼergopi,Πέτερχοφ,Горад Пецяргоф,Петергоф,Петерхоф,Петродворец,بيتيرهوف,پترگوف,პეტერგოფი,ペテルゴフ,彼得宮城,페테르고프', 59.8833300, 29.9000000, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120016, 'Pestyaki', 'Pestyaki', 'Pestjaki,Pestyaki,Пестяки', 56.7086000, 42.6695400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120017, 'Pestretsy', 'Pestretsy', 'Pestrecy,Pestretsy,Пестрецы', 55.7531300, 49.6545400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120018, 'Pestravka', 'Pestravka', 'Pestravka,Пестравка', 52.3982000, 49.9610000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120019, 'Pestovo', 'Pestovo', 'Pestovo,Pestowo,Piestowo,Pjestowo,bystwfw,pei si tuo wo,peseutobo,pesutovu~o,pstwfw,Пестово,بيستوفو,پستوفو,ペストヴォ,佩斯托沃,페스토보', 58.5938200, 35.8024400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120020, 'Pesochnyy', 'Pesochnyy', 'Hiekka,Pesochnaya,Pesochnoye,Pesochnyj,Pesochnyy,Pesotsjnyj,Ruavski,Песочный', 60.1229500, 30.1640400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120021, 'Pesochnoye', 'Pesochnoye', 'Pesochnoe,Pesochnoye,Pesotsjnoje,Песочное', 58.0059700, 39.1771700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120022, 'Peskovka', 'Peskovka', 'Peskovka,Peskovski Zavod,Shlakovaya,Песковка', 59.0447800, 52.3605700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120023, 'Peski', 'Peski', 'Peski,Пески', 55.2162600, 38.7626200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120024, 'Peshkovo', 'Peshkovo', 'Pashkovo,Peshkovo,Пешково', 47.0186700, 39.3884500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120025, 'Peshki', 'Peshki', 'Peshki,Pesjki,Пешки', 56.1333300, 37.0666700, 'RU', '2014-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120026, 'Peschanokopskoye', 'Peschanokopskoye', 'Peschanokopskaya,Peschanokopskoe,Peschanokopskoye,Pestsjanokopskoje,Песчанокопское', 46.1951700, 41.0814300, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120027, 'Pervoural’sk', 'Pervoural''sk', 'Pervoural''sk,Pervoural''skiy,Pervouralsk,Pervoural’sk,Pervoural’skiy,byrfwralsk,di yi wu la er si ke,Первоуральск,بيرفورالسك,第一烏拉爾斯克', 56.9052800, 59.9436100, 'RU', '2013-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120028, 'Pervomayskoye', 'Pervomayskoye', 'Kivenapa,Kivenn''apa,Kivennapa,Kivinebb,Pervomajskoe,Pervomajskoje,Pervomayskiy,Pervomayskoye,Первомайское', 60.3592200, 29.7424000, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120029, 'Pervomayskoye', 'Pervomayskoye', 'Pervomajskoe,Pervomayskiy,Pervomayskoye,Первомайское', 43.9384700, 42.4760000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120030, 'Pervomayskiy', 'Pervomayskiy', 'Pervomajskij,Pervomayskiy,Первомайский', 56.6147400, 43.3582500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120031, 'Pervomayskiy', 'Pervomayskiy', 'Pervomajskij,Pervomayskiy,Verob''yevka,Verob’yevka,Первомайский', 54.0448200, 37.5087500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120032, 'Pervomayskiy', 'Pervomayskiy', 'Bogoyavelenskoye,Bogoyavlenskoye,Pervomajskij,Pervomayskiy,Первомайский', 53.2485000, 40.2871000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120033, 'Bakhchivandzhi', 'Bakhchivandzhi', 'Bahchivandzhi,Bakhchivandzhi,Shhelkovo-4,Shhjolkovo-4,Бахчиванджи,Щелково-4,Щёлково-4', 55.8833300, 38.0833300, 'RU', '2015-02-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120034, 'Pervomayskaya', 'Pervomayskaya', 'MamakIin KIotar,Mamakhin Khotar,Mamakkhaj-Jurt,Mamakkhin kIotar,Mamaqay-Yurt,Mamaqin khotar,Pervomajskaja,Pervomayskaya,Pervomayskoye,Perwomaiskaja,Perwomaiskoje,МамакІин КІотар,Мамакхай-Юрт,Мамакхин кІотар,Первомайская', 43.4033100, 45.5234300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120035, 'Pervomaysk', 'Pervomaysk', 'Pervomajsk,Pervomaysk,Tashino,Первомайск', 54.8689000, 43.8027200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120036, 'Pervoavgustovskiy', 'Pervoavgustovskiy', 'Pervoavgustovskij,Pervoavgustovskiy,Первоавгустовский', 52.2264000, 35.0552000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120037, 'Perm', 'Perm', 'Gorad Perm,Molotov,PEE,Perem,Perm,Perm'',Perma,Perme,Permia,Permjo,Permė,Perym,bi er mu,byrm,parma,peiy rm,peleum,perumi,prm,pyrm,Περμ,Горад Перм,Молотов,Перĕм,Перем,Перм,Пермь,Перым,Пєрмь,Պերմ,פרם,بيرم,پرم,پیرم,पर्म,เปียร์ม,პერმი,ペルミ,彼尔姆,페름', 58.0104600, 56.2501700, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120038, 'Pereyaslovskaya', 'Pereyaslovskaya', 'Perejaslovskaja,Pereyaslavskaya,Pereyaslovskaya,Переясловская', 45.8412100, 39.0237900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120039, 'Perevoz', 'Perevoz', 'P''yanskiy Perevoz,P''yany Perevoz,P''yanyy Perevoz,Perevoz,P’yanskiy Perevoz,P’yany Perevoz,P’yanyy Perevoz,Перевоз', 55.5961300, 44.5446100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120040, 'Perevolotskiy', 'Perevolotskiy', 'Perevolockij,Perevolotsk,Perevolotskaya,Perevolotski,Perevolotskij,Perevolotskiy,Perevolotskoye,Переволотский,Переволоцкий', 51.8763300, 54.1937800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120041, 'Pereslavl’-Zalesskiy', 'Pereslavl''-Zalesskiy', 'Pereslavl''-Zalesskij,Pereslavl''-Zalesskiy,Pereslavl-Zalesskij,Pereslavl’-Zalesskiy,Pereslawl-Saleski,Переславль-Залесский', 56.7393400, 38.8562600, 'RU', '2014-09-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120042, 'Perepravnaya', 'Perepravnaya', 'Perepravnaja,Perepravnaya,Переправная', 44.3366000, 40.7849000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120043, 'Peremyshl’', 'Peremyshl''', 'Peremishl,Peremyschl,Peremyshl'',Peremyshl’,Peremysjl,Перемышль', 54.2631300, 36.1606300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120044, 'Perelyub', 'Perelyub', 'Pereljub,Perelyub,Перелюб', 51.8629200, 50.3541200, 'RU', '2013-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120045, 'Pereleshinskiy', 'Pereleshinskiy', 'Pereleshinskij,Pereleshinskiy,Perelesjinskij,Перелешинский', 51.7148000, 40.1953000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120046, 'Pereleshino', 'Pereleshino', 'Pereleshino,Perelesjino,Перелешино', 51.7376000, 40.1388000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120047, 'Peredovaya', 'Peredovaya', 'Peredovaja,Peredovaya,Передовая', 44.1172200, 41.4755600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120048, 'Novo-Peredelkino', 'Novo-Peredelkino', 'Novo-Peredelkino,Peredelkino,Ново-Переделкино', 55.6452800, 37.3358300, 'RU', '2014-06-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120049, 'Penza', 'Penza', 'Gorad Penza,PEZ,Pensa,Penz,Penza,Penza osh,Penzae,Penze,ben sa,bynza,penja,penza,pnza,pnzh,pynza,Πένζα,Горад Пенза,Пензæ,Пенза,Пенза балһсн,Пенза ош,Пензе,Պենզա,פנזה,بينزا,پنزا,پینزا,ペンザ,奔萨,펜자', 53.2006600, 45.0046400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120050, 'Peno', 'Peno', 'Peno,Пено', 56.9262400, 32.7426200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120051, 'Pelagiada', 'Pelagiada', 'Palagiada,Pelagiada,Пелагиада', 45.2063900, 42.0236100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120052, 'Pechory', 'Pechory', 'Gorad Pjachory,Pechery,Pechori,Pechory,Pecori,Pecory,Petchory,Petschory,Petseri,Petsjory,Petzuria,Peĉori,Pečori,Pečory,Pieczory,Pjecory,Pječory,Vyru Pechory,bytshwry,pchwry,pecholi,pechoru~i,pu qiao lei,pzwry,Горад Пячоры,Печори,Печоры,פצורי,بيتشوري,پچوری,ペチョールィ,普喬雷,페초리', 57.8164200, 27.6119000, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120053, 'Pechora', 'Pechora', 'Byen Petsjora,Gorad Pjachora,PEX,Pechora,Pecor,Pecora,Peczora,Petchora,Petjora,Petschora,Petsjora,Petsora,Petxora,Petšora,Peĉora,Pečor,Pečora,bo chao la,bytshwra,pchwra,pechola,pechora,Горад Пячора,Печора,Печӧра,بيتشورا,پچورا,ペチョラ,伯朝拉,페초라', 65.1471700, 57.2243900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120054, 'Pechersk', 'Pechersk', 'Pechersk,Pecherskoye,Petsjersk,Печерск', 54.8535500, 32.0315400, 'RU', '2013-08-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120055, 'Pechenga', 'Pechenga', 'Pechenga,Petsamo,Petschenga,Petsjenga,Pieczenga,Печенга', 69.5258700, 31.1702700, 'RU', '2016-09-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120056, 'Pavshino', 'Pavshino', 'Pavshino,Pavshuno,Pavsjino,Павшино', 55.8166700, 37.3500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120057, 'Pavlovskiy Posad', 'Pavlovskiy Posad', 'Pavloro Pasad,Pavlov-Posad,Pavlovo-Posad,Pavlovski Posad,Pavlovskij Posad,Pavlovskiy Posad,Павловский Посад', 55.7818700, 38.6502500, 'RU', '2014-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120058, 'Pavlovskiy', 'Pavlovskiy', 'Pavlovskij,Pavlovskiy,Павловский', 57.8424000, 54.8435700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120059, 'Pavlovskaya Sloboda', 'Pavlovskaya Sloboda', 'Pavlovskaja Sloboda,Pavlovskaja-Sloboda,Pavlovskaya Sloboda,Павловская Слобода', 55.8151700, 37.0824600, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120060, 'Pavlovskaya', 'Pavlovskaya', 'Pavlivs''ka,Pavlovskaia,Pavlovskaja,Pavlovskaya,Pawlowskaja,Pàvlovskaia,Pávlovskaya,Павловская,Павлівська', 46.1377000, 39.7832000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120061, 'Pavlovsk', 'Pavlovsk', 'Gorad Paulausk,Palacio de Pavlovsk,Palácio de Pavlovsk,Pauluskoi,Paviosk,Pavlovsk,Pavlovska,Pavlovszk,Pawlowsk,Pawłowsk,Pávlovsk,Slutsk,ba fu luo fu si ke,baflwfsk,pabeullobseukeu,pavurofusuku,pawlwfsk,Горад Паўлаўск,Павловск,بافلوفسك,پاولوفسک,პავლოვსკი,パヴロフスク,巴甫洛夫斯克,파블롭스크', 59.6833300, 30.4347200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120062, 'Pavlovsk', 'Pavlovsk', 'Gorad Paulausk,Pavlovs''k,Pavlovsk,Pavlovsk i Voronezj oblast,Pawlowsk,Pawłowsk,Pàvlovsk,ba fu luo fu si ke,baflwfsk,pabeullobseukeu,pawlwfsk  awblast wwrwnzh,Горад Паўлаўск,Павловск,Павловск балһсн,Павловськ,بافلوفسك,پاولوفسک، اوبلاست وورونژ,巴甫洛夫斯克,파블롭스크', 50.4577800, 40.1080600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120063, 'Pavlovo', 'Pavlovo', 'Paulova,Pavlovo,Павлово', 59.8086100, 30.8966700, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120064, 'Pavlovka', 'Pavlovka', 'Pavlovka,Павловка', 55.4209400, 56.5542600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120065, 'Pavlovka', 'Pavlovka', 'Pavlovka,Павловка', 53.5956900, 46.7663100, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120066, 'Pavlovka', 'Pavlovka', 'Pavlovka,Павловка', 52.6896600, 47.1404600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120067, 'Pavlodol’skaya', 'Pavlodol''skaya', 'Pavlodol''skaja,Pavlodol''skaya,Pavlodolskaja,Pavlodol’skaya,Павлодольская', 43.7192300, 44.4781500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120068, 'Pavino', 'Pavino', 'Pavino,Павино', 59.1139000, 46.1414200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120069, 'Pavelets', 'Pavelets', 'Pavelec,Pavelets,Paveletskiy,Павелец', 53.7883300, 39.2460100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120070, 'Pashkovskiy', 'Pashkovskiy', 'Pachksowskaja,Paschkowskaja,Pashkovskaya,Pashkovskij,Pashkovskiy,Pasjkovskij,Пашковский', 45.0236600, 39.1043600, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120071, 'Pashiya', 'Pashiya', 'Pashija,Pashiya,Pasjia,Пашия', 58.4324000, 58.2562000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120072, 'Pasegovo', 'Pasegovo', 'Pasegovo,Пасегово', 58.5060200, 49.5138300, 'RU', '2016-02-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120073, 'Partizan', 'Partizan', 'Partizan,Партизан', 53.9501700, 38.0980100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120074, 'Parma', 'Parma', 'Parma,Парма', 66.0000000, 57.7000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120075, 'Parkovyy', 'Parkovyy', 'Parkovyj,Parkovyy,Tikhoreck,Tikhoretskiy,Парковый,Тихорецк', 45.8330600, 40.1455600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120076, 'Pargolovo', 'Pargolovo', 'Pargalovo,Pargolovo,Parkala,Parkola,Парголово', 60.0812000, 30.2762600, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120077, 'Parfino', 'Parfino', 'Parfino,Zhereslo,Парфино', 57.9730600, 31.6480600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120078, 'Parfen’yevo', 'Parfen''yevo', 'Parfen''evo,Parfen''yevo,Parfenjevo,Parfen’yevo,Парфеньево', 58.4839600, 43.4087600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120079, 'Paraul', 'Paraul', 'Paraul,Параул', 42.7419300, 47.3553100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120080, 'Paran’ga', 'Paran''ga', 'Paran''ga,Paranga,Paran’ga,Параньга', 56.7038900, 49.4047200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120081, 'Pankovka', 'Pankovka', 'Pankovka,Панковка', 58.5000400, 31.1999000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120082, 'Panino', 'Panino', 'Panino,Панино', 51.6467000, 40.1346000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120083, 'Pamyat’ Parizhskoy Kommuny', 'Pamyat'' Parizhskoy Kommuny', 'Pamjat Parizjskoj Kommuny,Pamjat'' Parizhskoj Kommuny,Pamyat'' Parizhskoy Kommuny,Pamyat’ Parizhskoy Kommuny,Parizhskaya Kommuna,Parizhskoy Kommuny,Память Парижской Коммуны', 56.1048000, 44.4952000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120084, 'Pallasovka', 'Pallasovka', 'Bulbin,Gorad Palasauka,Ney-Galka,Palasovka,Palassovka,Pallasovk,Pallasovka,Pallasowka,Pallassovka,Pallassowka,Pal·làssovka,Palásovka,balaswfka,pa la suo fu ka,palaswfka,Горад Паласаўка,Паласовка,Палласовка,Палласовка балһсн,بالاسوفكا,پالاسوفکا,帕拉索夫卡', 50.0500000, 46.8833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120085, 'Palkino', 'Palkino', 'Palkino,Палкино,Պալկինո', 57.5408900, 28.0125700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120086, 'Palekh', 'Palekh', 'Paleg,Palekh,Палех', 56.8025600, 41.8550800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120087, 'Pachelma', 'Pachelma', 'Pachelma,Patsjelma,Пачелма', 53.2442600, 43.3520500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120088, 'Staryye Ozinki', 'Staryye Ozinki', 'Osinki,Ozinkhi,Ozinki,Starye Ozinki,Staryye Ozinki,Озинки,Старые Озинки', 51.1786000, 49.6769000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120089, 'Ozherel’ye', 'Ozherel''ye', 'Ozherel''e,Ozherel''ye,Ozherel’ye,Ozjerelje,Ожерелье', 54.7919700, 38.2655900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120090, 'Ozëry', 'Ozery', 'Ozeri,Ozery,Ozjory,Ozyory,Ozëry,[ɐˈzʲɵrɨ],Озеры,Озёры', 54.8599800, 38.5506200, 'RU', '2016-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120091, 'Ozërsk', 'Ozersk', 'Angerapp,Darkehmen,Darkemen,Darkiemis,Ozersk,Oziorskas,Ozjorsk,Ozërsk,Озерск,Озёрск', 54.4105600, 22.0116700, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120092, 'Ozërnyy', 'Ozernyy', 'Ozernyy,Ozjornyj,Ozërnyy,Озёрный', 55.5802000, 32.4127000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120093, 'Ozerki', 'Ozerki', 'Estacao Oserki,Estação Oserki,Ozerki,Ozierki,Stancyja metro Azjarki,Озерки,Станцыя метро Азяркі', 60.0394700, 30.3112800, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120094, 'Overyata', 'Overyata', 'Overjata,Overyata,Оверята', 58.0841700, 55.8669400, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120095, 'Otrado-Kubanskoye', 'Otrado-Kubanskoye', 'Otradno-Kubanskoe,Otrado-Kubanskoe,Otrado-Kubanskoye,Otradokubanskiy,Отрадно-Кубанское,Отрадо-Кубанское', 45.2441700, 40.8408300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120096, 'Otradnyy', 'Otradnyy', 'Otradnoye,Otradny,Otradnyj,Otradnyy,Отрадный', 53.3759600, 51.3452000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120097, 'Otradnoye', 'Otradnoye', 'Otradnoe,Otradnoye,Отрадное', 55.8666700, 37.6000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120098, 'Otradnoye', 'Otradnoye', 'Otradnoe,Otradnoje,Otradnoye,Pella,Отрадное', 59.7775000, 30.8180600, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120099, 'Otradnaya', 'Otradnaya', 'Otradnaja,Otradnaya,Отрадная', 44.3933300, 41.5205600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120100, 'Otkaznoye', 'Otkaznoye', 'Otkaznoe,Otkaznoje,Otkaznoye,Отказное', 44.3263900, 43.8608300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120101, 'Osyno', 'Osyno', 'Osyna,Osyno,Осыно', 56.1505300, 28.6758000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120102, 'Ostrovtsy', 'Ostrovtsy', 'Ostrovcy,Ostrovtsy,Островцы', 55.5875000, 38.0055600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120103, 'Ostrovskoye', 'Ostrovskoye', 'Ostrovskoe,Ostrovskoje,Ostrovskoye,Semenovskoye,Островское', 57.8057400, 42.2433200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120104, 'Ostrov', 'Ostrov', 'Gorad Ostrau,Ostrov,Ostrova,Ostrovia,Ostrow,ao si te luo fu,awstrwf,awstrwf  awblast pskwf,oseuteulopeu,osutorofu,Горад Остраў,Остров,أوستروف,اوستروف، اوبلاست پسکوف,オストロフ,奧斯特羅夫,오스트로프', 57.3439500, 28.3536800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120105, 'Ostrogozhsk', 'Ostrogozhsk', 'Gorad Astragozhsk,Ostrogojsk,Ostrogoschsk,Ostrogoshk,Ostrogoshsk,Ostrogoz''k,Ostrogozhsk,Ostrogozjsk,Ostrogozsk,Ostrogoĵsk,Ostrogożsk,Ostrogožsk,ao si te luo ge ri si ke,awstrwghwjsk,awstrwgwzhsk,Горад Астрагожск,Острогожск,Острогожск балһсн,Острогозьк,Острогошк,أوستروغوجسك,اوستروگوژسک,奧斯特羅戈日斯克', 50.8664000, 39.0756100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120106, 'Oster', 'Oster', 'Oster,Остер', 54.0170000, 32.8019000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120107, 'Ostashkov', 'Ostashkov', 'Gorad Astashkau,Ostachkov,Ostaschkow,Ostashkov,Ostasjkov,Ostaskov,Ostaszkow,Ostaszków,Ostaxkov,Ostaŝkov,Ostaşkov,Ostaškov,ao si ta shen ke fu,awstashkwf,oseutasikopeu,osutashikofu,Горад Асташкаў,Осташков,أوستاشكوف,اوستاشکوف,ოსტაშკოვი,オスタシコフ,奧斯塔什科夫,오스타시코프', 57.1466700, 33.1075300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120108, 'Ostashëvo', 'Ostashevo', 'Ostaschowo,Ostashevo,Ostashjovo,Ostashovo,Ostashëvo,Ostasjevo,Осташево,Осташёво', 55.8589600, 35.8694800, 'RU', '2016-11-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120109, 'Ostankinskiy', 'Ostankinskiy', 'Novoostankino,Ostankino,Ostankinskij,Ostankinskiy,Pushkinskoye,Останкинский', 55.8295700, 37.6160400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120110, 'Osinovo', 'Osinovo', 'Osinovo,Осиново', 55.8809000, 48.8810000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120111, 'Osinki', 'Osinki', 'Osinki,Осинки', 52.8432000, 49.5132000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120112, 'Osel’ki', 'Osel''ki', 'Osel''ki,Osel’ki,Osselki,Осельки', 60.2050300, 30.4966700, 'RU', '2016-08-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120113, 'Osa', 'Osa', 'Gorad Asa,Os,Osa,Osa i Perm kraj,Ossa,Osza,ao sa,awsa,awsa  prm,Горад Аса,Оса,أوسا,اوسا، پرم,奧薩', 57.2830000, 55.4589000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120114, 'Orud’yevo', 'Orud''yevo', 'Orud''evo,Orud''yevo,Orudjevo,Orud’yevo,Орудьево', 56.4333300, 37.5333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120115, 'Orsk', 'Orsk', 'Gorad Orsk,OSW,Ors''k,Orsk,Orska,Orskas,Orski,Orsko,ao er si ke,awrsk,oleuseukeu,orusuku,Горад Орск,Орск,Орски,Орськ,أورسك,اورسک,オルスク,奧爾斯克,오르스크', 51.2048700, 58.5668500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120116, 'Orshanka', 'Orshanka', 'Orshanka,Orsjanka,Оршанка', 56.9160700, 47.8933500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120117, 'Orsha', 'Orsha', 'Orsha,Orsha Pervaya,Orsja,Орша', 56.9119600, 36.2286200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120118, 'Orlovskiy', 'Orlovskiy', 'Orlovka,Orlovskaya,Orlovskij,Orlovskiy,Орловский', 46.8713900, 42.0591700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120119, 'Orlovo', 'Orlovo', 'Orlovo,Орлово', 51.7539700, 39.5873100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120120, 'Orlovka', 'Orlovka', 'Orlovka,Орловка', 44.6913900, 44.1744400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120121, 'Orichi', 'Orichi', 'Orichi,Oritsji,Оричи', 58.4035600, 49.0571900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120122, 'Orgtrud', 'Orgtrud', 'Lemeshenskiy,Orgtrud,Poselok Lemeshki,Posëlok Lemeshki,Оргтруд', 56.1832000, 40.6149000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120123, 'Orenburg', 'Orenburg', 'Arenpur,Chkalov,Gorad Arehnburg,Oremburgo,Orenbourg,Orenburg,Orenburg osh,Orenburga,Orenburgas,Orenburgo,Orenburgum,Orenburq,Orynbor,REN,Tschkalow,ao lun bao,awrnbrg,awrnbrgh,awrnbwrg,awrynbwrgh,olenbuleukeu,orenabarga,orenburgi,orenburuku,xo re nburk,yrymbur,yrynbur,Ăренпур,Горад Арэнбург,Оренбург,Оренбург ош,Орынбор,Чкалов,Ырымбур,Ырынбур,Օրենբուրգ,אורנבורג,أورنبرغ,أورينبورغ,اورنبرگ,اورنبورگ,ओरेनबर्ग,โอเรนบุร์ก,ორენბურგი,オレンブルク,奥伦堡,오렌부르크', 51.7727000, 55.0988000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120124, 'Orël', 'Orel', 'OEL,Orel,Oriol,Oriolas,Orjol,Oryol,Orzel,Orzeł,Orël,olyol,oryoru,Орел,Орёл,オリョール,오룔', 52.9650800, 36.0784900, 'RU', '2017-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120125, 'Orekhovo-Zuyevo', 'Orekhovo-Zuyevo', 'Gorad Arehkhava-Zueva,Orechovas-Zujevas,Orechovo-Zoejevo,Orechovo-Zuevo,Orechovo-Zujevo,Orechowo-Sujewo,Orehhovo-Zujevo,Orehovo-Zuevo,Orehovo-Zujevo,Orehovo-Zuyevo,Orehovozujeva,Orejovo-Zuyevo,Orekhovo,Orekhovo-Zouievo,Orekhovo-Zouïevo,Orekhovo-Zuevo,Orekhovo-Zujevo,Orekhovo-Zuyevo,Orexovo-Zuyevo,Oreĥovo-Zujevo,Oriechowo-Zujewo,Orjechowo Sujewo,Oryekhovo,Oréjovo-Zúyevo,ao lie huo wo-zu ye wo,arykhwfw-zwyfw,awrkhwfw-zwyfw,awrykhwfw-zwyfw,awrykhww zwyyww,olehobojuyebo,orehovu~o=zuevu~o,Горад Арэхава-Зуева,Орехово-Зуево,Орехово-Зујево,Орєхово-Зуєво,أوريخوفو-زويفو,اريخوفو-زويفو,اورخوفو-زویفو,اوریخوو زوئیوو,オレホヴォ＝ズエヴォ,奧列霍沃-祖耶沃,오레호보주예보', 55.8067200, 38.9617800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120126, 'Orekhovo-Borisovo Severnoye', 'Orekhovo-Borisovo Severnoye', 'Orekhovo,Orekhovo-Borisovo Severnoe,Orekhovo-Borisovo Severnoye,Орехово-Борисово Северное', 55.6166700, 37.6833300, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120127, 'Ordzhonikidzevskiy', 'Ordzhonikidzevskiy', 'Ordzhonikidzevskij,Ordzhonikidzevskiy,Ordzjonikidzevskij,Орджоникидзевский', 43.8423300, 41.8963600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120128, 'Sunzha', 'Sunzha', 'Ordshonikidsewskaja,Ordzhonikidzevskaja,Ordzhonikidzevskaya,Ordzhonikidzevskoye,Ordzjonikidzevskaja,Sipsoj-gӀala,Sleptsovskaya,Slyeptsovskaya,Sunza,Sunzha,Sunzja,Sunža,Орджоникидзевская,Сипсой-гӀала,Сунжа', 43.3195000, 45.0491100, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120129, 'Orda', 'Orda', 'Orda,Орда', 57.1950900, 56.9090800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120130, 'Oranzherei', 'Oranzherei', 'Oranjereinyi Promysel,Oranzherei,Oranzherey,Oranzhereynoye,Oranzjerei,Оранжереи', 45.8475600, 47.5663500, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120131, 'Opochka', 'Opochka', 'Opochka,Opotschka,Opotsjka,Pechka,Опочка', 56.7104800, 28.6617400, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120132, 'Opechenskiy Posad', 'Opechenskiy Posad', 'Opechenskij Posad,Opechenskiy Posad,Opetsjenskij Posad,Opochinskoi,Opochinskoi Posad,Опеченский Посад', 58.2751000, 34.1173100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120133, 'Oparino', 'Oparino', 'Oparino,Опарино', 59.8517900, 48.2782600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120134, 'Opalikha', 'Opalikha', 'Opalikha,Опалиха', 55.8259300, 37.2527800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120135, 'Onega', 'Onega', 'AEaeninen,Onega,Ääninen,Онега', 63.9069200, 38.1111200, 'RU', '2013-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120136, 'Omutninsk', 'Omutninsk', 'Gorad Amutninsk,Omoutninsk,Omutinisk,Omutninsk,Omutnyinszk,ao mu te ning si ke,awmwtnynsk,Горад Амутнінск,Омутнинск,Омутњинск,أوموتنينسك,اوموتنینسک,奧穆特寧斯克', 58.6700100, 52.1932000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120137, 'Olym', 'Olym', 'Olym,Olymskij,Olymskiy,Олым,Олымский', 51.6798000, 38.1758000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120138, 'Olonets', 'Olonets', 'Anuksenlinnu,Anus,Aunuksenlinna,Aunus,Gorad Alonec,Olonec,Olonets,Olonez,Oloniec,Olonjec,Ołoniec,ao luo nie ci,awlwnts,ollonecheu,oronetsu,Горад Алонец,Олонец,Олоњец,أولونتس,اولونتس,オロネツ,奧洛涅茨,올로네츠', 60.9847500, 32.9697600, 'RU', '2016-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120139, 'Ol’khovatka', 'Ol''khovatka', 'Ol''khovatka,Olchowatka-marjewka,Olkhovatka,Ol’khovatka,Ольховатка', 50.2830800, 39.2871500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120140, 'Ol’gino', 'Ol''gino', 'Ol''gino,Olgino,Olino,Ol’gino,Ristikylae,Ristikylä,Ольгино', 59.8370200, 29.9226600, 'RU', '2017-01-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120141, 'Ol’ginskaya', 'Ol''ginskaya', 'Ol''ginskaja,Ol''ginskaya,Olginskaja,Olginskaya,Ol’ginskaya,Ольгинская', 47.1879400, 39.9492500, 'RU', '2013-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120142, 'Ol’ginskaya', 'Ol''ginskaya', 'Ol''ginskaja,Ol''ginskaya,Olginskaja,Ol’ginskaya,Stanitsa Ol''ginskaya,Stanitsa Ol’ginskaya,Ольгинская', 45.9461000, 38.5486400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120143, 'Ol’gino', 'Ol''gino', 'Ol''gino,Olgino,Olkino,Ol’gino,Ольгино', 60.0092800, 30.1155900, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120144, 'Ol’ginka', 'Ol''ginka', 'Ol''ginka,Olginka,Ol’ginka,Ольгинка', 44.2075000, 38.8911100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120145, 'Olenino', 'Olenino', 'Olenino,Oljenin,Оленино,Олењино,Օլենինո', 56.2091700, 33.4888800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120146, 'Olenegorsk', 'Olenegorsk', 'Gorad Alenjagorsk,Olenegors''k,Olenegorsk,Olenegorsk i Murmansk oblast,Olenegorskas,Oleneqorsk,Oleniegorsk,Olenjegorsk,ao lie nie ge er si ke,awlnghwrsk,awlngwrsk  awblast mwrmansk,Горад Аленягорск,Оленегорск,Оленєгорськ,أولنغورسك,اولنگورسک، اوبلاست مورمانسک,奧列涅戈爾斯克', 68.1432000, 33.2528700, 'RU', '2014-03-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120147, 'Okulovka', 'Okulovka', 'Gorad Akulauka,Okoelovka,Okoulovka,Okulovka,Okulowka,Okułowka,Okúlovka,ao ku luo fu ka,awkwlwfka,awkylwfka,okullobka,okurofuka,Горад Акулаўка,Окуловка,أوكيلوفكا,اوکولوفکا,オクロフカ,奧庫洛夫卡,오쿨롭카', 58.4008300, 33.2908300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120148, 'Tsotsin-Yurt', 'Tsotsin-Yurt', 'Cacan-Jurt,Cacan-Yurt,Chochin-Jurt,Coci-Jurt,Coci-Yurt,Cocin-Avl,Cocin-Avla,Cocin-Ehvl,Cocin-Evl,Cocin-Jurt,Cocin-Əvl,Cocin-Əvla,Oktjabr''skoe,Oktjabr’skoe,Oktyabr''skoye,Oktyabr’skoye,Tsatsan-Yurt,Tsotsin-Yurt,Çaçan-Yurt,Çoçi-Yurt,Октябрьское,Цацан-Юрт,Цоци-Юрт,Цоцин-Эвл,Цоцин-Юрт,Чочин-Юрт', 43.2420600, 46.0001300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120149, 'Oktyabr’skiy', 'Oktyabr''skiy', 'Oktjabr''skij,Oktyabr''skiy,Oktyabr’skiy,Октябрьский', 56.2188700, 42.0406900, 'RU', '2015-06-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120150, 'Oktyabr’skiy', 'Oktyabr''skiy', 'Oktjabr''skij,Oktyabr''skiy,Oktyabrsky,Oktyabr’skiy,Октябрьский', 55.6080600, 37.9773800, 'RU', '2015-06-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120151, 'Oktyabr’skiy', 'Oktyabr''skiy', 'OKT,Oktiabr''skil,Oktiabr’skil,Oktjabr''skij,Oktjabrskij,Oktyabr''skiy,Oktyabrsk,Oktyabr’skiy,Октябрьский', 54.4814700, 53.4710300, 'RU', '2017-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120152, 'Oktyabr’skiy', 'Oktyabr''skiy', 'Oktjabr''skij,Oktjabrskij,Oktyabr''skiy,Oktyabr’skiy,Sapronovo,Октябрьский', 54.2267500, 38.8940200, 'RU', '2013-08-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120153, 'Takhtamukay', 'Takhtamukay', 'Khakurate,Oktyabr''skiy,Oktyabr’skiy,Tahtamukai,Takhtamukaj,Takhtamukay,Tehkhuutehmykuuaj,Tokhtamukay,Тахтамукай,Тэхъутэмыкъуай', 44.9215000, 38.9958300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120154, 'Oksovskiy', 'Oksovskiy', 'Navolok,Oksovskij,Oksovskiy,Оксовский', 62.6062300, 39.8984500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120155, 'Okhansk', 'Okhansk', 'Gorad Akhansk,Ochansk,Ohansk,Ohanszk,Okhannoj,Okhansk,Oxansk,Oĥansk,ao han si ke,awkhansk,Горад Аханск,Оханнӧй,Оханск,أوخانسك,اوخانسک,奧漢斯克', 57.7203000, 55.3882000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120156, 'Odoyev', 'Odoyev', 'Odoev,Odojev,Odoyev,Odoyevo,Одоев', 53.9393300, 36.6863900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120157, 'Odintsovo', 'Odintsovo', 'Gorad Adzincova,Odincova,Odincovas,Odincovo,Odincowo,Odintovo,Odintsovo,Odinzowo,Odințovo,ao jin zuo wo,awdynstww,awdyntswfw,odinchobo,ojintsu~obo,xo din t so wo,Горад Адзінцова,Одинтсово,Одинцово,Одинцово балһсн,أودينتسوفو,اودینتسوفو,اودینستوو,โอดินต์โซโว,オジンツォボ,奧金佐沃,오딘초보', 55.6779800, 37.2777300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120158, 'Ochër', 'Ocher', 'Ocher,Ochjor,Ochër,Otsjer,Очер,Очёр', 57.8903500, 54.7201900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120159, 'Ochakovo-Matveyevskoye', 'Ochakovo-Matveyevskoye', 'Ochakovo,Ochakovo-Matveevskoe,Ochakovo-Matveyevskoye,Очаково-Матвеевское', 55.6843200, 37.4465400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120160, 'Obukhovo', 'Obukhovo', 'Obukhovo,Обухово', 55.8327800, 38.2725000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120161, 'Obsharovka', 'Obsharovka', 'Obsharovka,Obsjarovka,Обшаровка', 53.1250000, 48.8530600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120162, 'Oboyan’', 'Oboyan''', 'Obojan,Obojan'',Obojany,Oboyan'',Oboyan’,Обоянь', 51.2098100, 36.2791900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120163, 'Obninsk', 'Obninsk', 'Gorad Obninsk,Obnins''k,Obninsk,Obninskas,Obnińsk,ao bu ning si ke,awbnynsk,obeuninseukeu,obuninsuku,Óbninsk,Горад Обнінск,Обнинск,Обнінськ,أوبنينسك,اوبنینسک,ობნინსკი,オブニンスク,奥布宁斯克,오브닌스크', 55.0968100, 36.6100600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120164, 'Oblivskaya', 'Oblivskaya', 'Obliswskaja,Oblivskaja,Oblivskaya,Обливская', 48.5361600, 42.5013800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120165, 'Nyuksenitsa', 'Nyuksenitsa', 'Njuksenica,Njuksenitsa,Nyuksenitsa,Нюксеница', 60.4115900, 44.2330900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120166, 'Nytva', 'Nytva', 'Gorad Nytva,Nitv,Nitva,Nytva,Nytwa,Nıtva,nei te wa,nytfa,nytwa,Горад Нытва,Нитва,Нытва,نيتفا,نیتوا,內特瓦', 57.9437000, 55.3396000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120167, 'Nyrob', 'Nyrob', 'Nyrob,Ныроб', 60.7330000, 56.7202400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120168, 'Nyazepetrovsk', 'Nyazepetrovsk', 'Knyazepetrovski,Njazepetrovsk,Nyazepetrovsk,Нязепетровск', 56.0530600, 59.6027800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120169, 'Nyandoma', 'Nyandoma', 'Njandoma,Nyandoma,Няндома', 61.6656000, 40.2013000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120170, 'Nurma', 'Nurma', 'Nurma,Nurmi,Нурма', 59.5500000, 31.0166700, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120171, 'Nurlat', 'Nurlat', 'Gorad Nurlat,Noerlat,Norlat,Nourlat,Nurlat,Nurłat,nu er la te,nuleullateu,nururato,nwrlat,Горад Нурлат,Норлат,Нурлат,نورلات,ヌルラト,努爾拉特,누를라트', 54.4276600, 50.8051100, 'RU', '2016-04-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120172, 'Nuradilovo', 'Nuradilovo', 'Daud-Otar,Daut,Nuradilovo,Нурадилово', 43.2844700, 46.4576300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120173, 'Nudol’', 'Nudol''', 'Nudol,Nudol'',Nudol''-Sharino,Nudol’,Nudol’-Sharino,Spas-Nudel'',Spas-Nudel’,Spas-Nudol'',Spas-Nudol’,Нудоль', 56.1000000, 36.5166700, 'RU', '2015-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120174, 'Nozhay-Yurt', 'Nozhay-Yurt', 'Andalaly,Andalely,Nazhin-Jurt,Nazin-Yurt,Nozaj-Jurt,Nozhaj-Jurt,Nozhay-Yurt,Nozhayt-Yurt,Nozhin-Jurt,Nozjaj-Jurt,Nożaj-Jurt,Nožaj-Jurt,Андалалы,Нажин-Юрт,Ножай-Юрт,Ножин-Юрт', 43.0929000, 46.3786800, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120175, 'Novyy Yegorlyk', 'Novyy Yegorlyk', 'Nov.Egorlyk,Novy-Yegorlyk,Novyj Egorlyk,Novyy Yegorlyk,Нов.Егорлык,Новый Егорлык', 46.3927000, 41.8716200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120176, 'Novyy Ropsk', 'Novyy Ropsk', 'Nov.Ropsk,Novy Ropsk,Novyj Ropsk,Novyy Ropsk,Ropsk,Новый Ропск', 52.2978100, 32.3120600, 'RU', '2014-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120177, 'Novyy Rogachik', 'Novyy Rogachik', 'Nov.Rogachik,Novy Rogachik,Novyj Rogachik,Novyy Rogachik,Нов.Рогачик,Новый Рогачик', 48.6768500, 44.0608100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120178, 'Novyy Oskol', 'Novyy Oskol', 'Novo Oskol,Novy Oskol,Novyj Oskol,Novyy Oskol,Новый Оскол', 50.7633000, 37.8640200, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120179, 'Novyy Nekouz', 'Novyy Nekouz', 'Nekouz,Novyj Nekouz,Novyy Nekouz,Новый Некоуз', 57.9028600, 38.0700400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120180, 'Novyy Karachay', 'Novyy Karachay', 'Novo-Karachayevskiy,Novyj Karachaj,Novyj Karatsjaj,Novyy Karachay,Pravoberezhnoye,Новый Карачай', 43.8207600, 41.9032200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120181, 'Novyye Lyady', 'Novyye Lyady', 'Novye Ljady,Novyye Lyady,Новые Ляды', 58.0552000, 56.6104000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120182, 'Novyye Kuz’minki', 'Novyye Kuz''minki', 'Novye Kuz''minki,Novyye Kuz''minki,Novyye Kuz’minki,Новые Кузьминки', 55.7000000, 37.7500000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120183, 'Novyye Gorki', 'Novyye Gorki', 'Nov.Gorki,Novye Gorki,Novyye Gorki,Нов.Горки,Новые Горки', 56.7253500, 41.0601400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120184, 'Novyye Cherëmushki', 'Novyye Cheremushki', 'Novye Cherjomushki,Novyye Cheremushki,Novyye Cherëmushki,Новые Черёмушки', 55.7000000, 37.5833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120185, 'Novyye Burasy', 'Novyye Burasy', 'Nov.Burasy,Novye Burasy,Novyye Burassy,Novyye Burasy,Нов.Бурасы,Новые Бурасы', 52.1323600, 46.0714400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120186, 'Novyye Atagi', 'Novyye Atagi', 'Ataga,Ataki,Dekh''a AtagIa,Dexa Ataga,Deẋa Ataġa,Majskij,Majskoe,Mayskii,Mayskoe,Mayskoye,Novaya Ataga,Novye Atagi,Novyy Atagi,Novyye Atagi,Zhima AtagIa,Ƶima Ataġa,Дехьа АтагІа,Жима АтагІа,Майский,Майское,Новые Атаги', 43.1352800, 45.7730600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120187, 'Novyy Byt', 'Novyy Byt', 'Novyj Byt,Novyy Byt,Sovkhoz Novyy Byt,Новый Быт', 55.0585700, 37.6134800, 'RU', '2014-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120188, 'Novyy Buyan', 'Novyy Buyan', 'Nov. Bujan,Novy Buyan,Novyj Bujan,Novyy Buyan,Нов. Буян,Новый Буян', 53.6861100, 50.0469100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120189, 'Novozybkov', 'Novozybkov', 'Gorad Navazybkau,Novozibkov,Novozibkova,Novozipkov,Novozobkov,Novozybkov,Novozybkovas,Novozõbkov,Nowosybkoff,Nowosybkow,Nowozybkow,nobojibkopeu,novu~ozu~ipukofu,nwfwzaybkwf,nwwzybkwf,xin ji bu ke fu,Горад Навазыбкаў,Новозибков,Новозипков,Новозыбков,Новозыбков балһсн,Яңа Зыбков,نوفوزايبكوف,نووزیبکوف,ノヴォズィプコフ,新濟布科夫,노보집코프', 52.5396000, 31.9275000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120190, 'Novozhivotinnoye', 'Novozhivotinnoye', 'Novozhivotinnoe,Novozhivotinnoye,Новоживотинное', 51.8877000, 39.1689400, 'RU', '2017-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120191, 'Novozavedennoye', 'Novozavedennoye', 'Kasayevo,Novozavedennoe,Novozavedennoje,Novozavedennoye,Novozavedenskoye,Новозаведенное', 44.2627800, 43.6380600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120192, 'Novoye Leushino', 'Novoye Leushino', 'Nov.Leushino,Novoe Leushino,Novoye Leushino,Нов.Леушино,Новое Леушино', 56.8073200, 40.5144300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120193, 'Novoye Devyatkino', 'Novoye Devyatkino', 'Novoe Devjatkino,Novoje Devjatkino,Novoye Devyatkino,Uusi Miina,Uusi-Miina,Uuši Miina,Новое Девяткино', 60.0636400, 30.4832800, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120194, 'Novoye', 'Novoye', 'Novaya,Novoe,Novoye,Новое', 55.6310400, 38.9200100, 'RU', '2015-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120195, 'Novovyazniki', 'Novovyazniki', 'Novovjazniki,Novovyazniki,Нововязники', 56.1975000, 42.1711100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120196, 'Novovoronezh', 'Novovoronezh', 'Novovoionezhskiy,Novovoronezh,Novovoronezhskiy,Novovoronezj,Нововоронеж', 51.3071900, 39.2173200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120197, 'Novovelichkovskaya', 'Novovelichkovskaya', 'Novovelichkovskaja,Novovelichkovskaya,Novovelitsjkovskaja,Nowowelitschkowskaja,Нововеличковская', 45.2763800, 38.8416500, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120198, 'Novouzensk', 'Novouzensk', 'Gorad Navauzensk,Novoouzensk,Novouzens''k,Novouzensk,Nowousensk,Nowouzensk,Nowouziensk,nwfwywznsk,nwwznsk,xin wu jin si ke,Горад Наваузенск,Новоузенск,Новоузенск балһсн,Новоузенськ,Яңа Үзән,نوفويوزنسك,نووزنسک,新乌津斯克', 50.4591700, 48.1430600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120199, 'Novoutkinsk', 'Novoutkinsk', 'Novaya Utka,Novoutkinsk,Новоуткинск', 56.9929500, 59.5571400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120200, 'Novoul’yanovsk', 'Novoul''yanovsk', 'Novoul''janovsk,Novoul''yanovsk,Novouljanovsk,Novoul’yanovsk,Новоульяновск', 54.1496100, 48.3890700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120201, 'Novoukrainskoye', 'Novoukrainskoye', 'Novoukrainskiy,Novoukrainskoe,Novoukrainskoje,Novoukrainskoye,Новоукраинское', 45.3783300, 40.5297200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120202, 'Novoukrainskiy', 'Novoukrainskiy', 'Novoukrainka,Novoukrainskij,Novoukrainskiy,Ukrainskiy,Новоукраинка,Новоукраинский', 44.8942000, 38.0488600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120203, 'Novotroitskaya', 'Novotroitskaya', 'Novotroickaja,Novotroitskaja,Novotroitskaya,Novotroitskoye,Новотроитская,Новотроицкая', 45.3266700, 41.5252800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120204, 'Novotroitsk', 'Novotroitsk', 'Gorad Navatroick,Novo-Troitskiy,Novotroic''k,Novotroick,Novotroickas,Novotroitc,Novotroitsk,Novotroițc,Novotroytsk,Novotroïtsk,Nowotroick,Nowotroizk,nwfwtrwytsk,nwwtrwyytsk,nwwwtrwysk,xin te luo yi ci ke,Горад Наватроіцк,Новотроитск,Новотроицк,Новотроїцьк,Яңа Троицк,نوفوترويتسك,نوووترویسک,نوّوتروئیتسک,新特羅伊茨克', 51.2030100, 58.3266500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120205, 'Novotitarovskaya', 'Novotitarovskaya', 'Novotitarovskaja,Novotitarovskaya,Nowo-titarowskaja,Новотитаровская', 45.2375600, 38.9805900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120206, 'Novo-Talitsy', 'Novo-Talitsy', 'Novo-Talicy,Ново-Талицы', 57.0039200, 40.8593600, 'RU', '2015-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120207, 'Novospasskoye', 'Novospasskoye', 'Novospasskoe,Novospasskoje,Novospasskoye,Новоспасское', 53.1468300, 47.7513800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120208, 'Novosokol’niki', 'Novosokol''niki', 'Novosokol''niki,Novosokolniki,Novosokol’niki,Nowo Sokolniki,Новосокольники', 56.3463400, 30.1577800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120209, 'Novosmolinskiy', 'Novosmolinskiy', 'Novosmolinskij,Novosmolinskiy,Smolino Vtoroye,Новосмолинский', 56.2841000, 43.0507100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120210, 'Novosil’', 'Novosil''', 'Novosil,Novosil'',Novosil’,Новосиль', 52.9738700, 37.0404800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120211, 'Novosheshminsk', 'Novosheshminsk', 'Novosheshminsk,Novosjesjminsk,Новошешминск', 55.0651300, 51.2337600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120212, 'Novoshcherbinovskaya', 'Novoshcherbinovskaya', 'Novoshcherbinovskaya,Novoshherbinovskaja,Novosjtsjerbinovskaja,Nowoschtscherbinowskaja,Stanitsa Novo-Shcherbinovskaya,Новощербиновская', 46.4766900, 38.6475700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120213, 'Novoshakhtinsk', 'Novoshakhtinsk', 'Komintern,Kominternovskiy,Molotovskiy,Novosahtinsk,Novoshakhtinsk,Novoŝaĥtinsk,Novošahtinsk,Nowoschachtinsk,Nowoszachtynsk,Nowoszachtyńsk,Новошахтинск', 47.7603700, 39.9333500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120214, 'Novosergiyevka', 'Novosergiyevka', 'Novosergeyevka,Novosergeyevskoye,Novosergievka,Novosergijevka,Novosergiyevka,Новосергиевка', 52.0934000, 53.6528000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120215, 'Novosemeykino', 'Novosemeykino', 'Novosemejkino,Novosemeykino,Novoye Semeykino,Новосемейкино', 53.3705600, 50.3542800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120216, 'Novoselitskoye', 'Novoselitskoye', 'Novoseletskoye,Novoselickoe,Novoselitskoe,Novoselitskoje,Novoselitskoye,Новоселитское,Новоселицкое', 44.7508300, 43.4369400, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120217, 'Novorzhev', 'Novorzhev', 'Gorad Navarzhehu,Novorjev,Novorzev,Novorzhev,Novorzjev,Novorĵev,Novoržev,Noworschew,Noworshew,Noworzew,Noworżew,noboleujepeu,novu~orujefu,nwfwrjf,nwwwrzhf,xin lei re fu,Горад Наваржэў,Новоржев,نوفورجف,نووورژف,ノヴォルジェフ,新勒熱夫,노보르제프', 57.0294200, 29.3337800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120218, 'Novorudnyy', 'Novorudnyy', 'Novorudnyj,Novorudnyy,Новорудный', 51.5026000, 58.1873000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120219, 'Novorozhdestvenskaya', 'Novorozhdestvenskaya', 'Novorozhdestvenskaja,Novorozhdestvenskaya,Novorozjdestvenskaja,Новорождественская', 45.8605700, 39.9496800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120220, 'Novorossiysk', 'Novorossiysk', 'NOI,Noborosisk,Novorosijsk,Novorossiejsk,Novorossiisk,Novorossijsk,Novorossisk,Novorossiysk,Noworossiisk,Noworossijsk,Noworosyjsk,nobolosiseukeu,Νοβορωσίσκ,Новоросијск,Новороссийск,노보로시스크', 44.7243900, 37.7675200, 'RU', '2017-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120221, 'Novopokrovskaya', 'Novopokrovskaya', 'Novopokrovs''ka,Novopokrovskaia,Novopokrovskaja,Novopokrovskaya,Novopokróvskaia,Novopokróvskaya,Nowopokrowskaja,Новопокровская,Новопокровська', 45.9513900, 40.7005600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120222, 'Novopokrovka', 'Novopokrovka', 'Novo-Pokrovskiy,Novopokrovka,Novopokrovskoye,Новопокровка', 52.1331000, 40.8783000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120223, 'Novopodrezkovo', 'Novopodrezkovo', 'Novopodrezkovo,Новоподрезково', 55.9397200, 37.3441700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120224, 'Novoplatnirovskaya', 'Novoplatnirovskaya', 'Novoplatnikovskaya,Novoplatnirovskaja,Novoplatnirovskaya,Новоплатнировская', 46.1065000, 39.4191000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120225, 'Novopistsovo', 'Novopistsovo', 'Novopiscovo,Novopistsovo,Новописцово', 57.3217700, 41.8531000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120226, 'Novopetrovskoye', 'Novopetrovskoye', 'Novopetrovskoe,Novopetrovskoje,Novopetrovskoye,Новопетровское', 55.9927800, 36.4719400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120227, 'Novopavlovsk', 'Novopavlovsk', 'Gorad Navapaulausk,Novopavloskaya,Novopavlovs''k,Novopavlovsk,Novopavlovskaya,Novopavoskaya,Nowopawlowsk,Nowopawłowsk,nwfwbaflwfsk,nwwwpawlwfsk,xin ba fu luo fu si ke,Горад Навапаўлаўск,Новопавловск,Новопавловск балһсн,Новопавловськ,Яңа Павловск,نوفوبافلوفسك,نوووپاولوفسک,新巴甫洛夫斯克', 43.9622200, 43.6341700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120228, 'Novoorsk', 'Novoorsk', 'Novoorsk,Новоорск', 51.3810000, 58.9813000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120229, 'Novo-Nikol’skoye', 'Novo-Nikol''skoye', 'Novo-Nikol''skoe,Novo-Nikol''skoye,Novo-Nikol’skoye,Ново-Никольское', 56.5666700, 37.5333300, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120230, 'Novonikolayevskiy', 'Novonikolayevskiy', 'Novo-Nikolayevskaya,Novonikolaevskij,Novonikolajevskij,Novonikolayevskiy,Новониколаевский', 50.9738000, 42.3649000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120231, 'Novomyshastovskaya', 'Novomyshastovskaya', 'Novomishastovski,Novomyshastovskaja,Novomyshastovskaya,Novomysjastovskaja,Nowomyschastowskaja,Новомышастовская', 45.1990900, 38.5827200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120232, 'Novomoskovsk', 'Novomoskovsk', 'Bobriki,Gorad Novamaskousk,Novomoskovs''k,Novomoskovsk,Novomoskovsk i Russland,Novomoskovskas,Nowomoskowsk,Stalinogorsk,Stalinogorsk Pervyy,Stalinogorsk Severnyy,Stalinogorsk Vtoroy,Stalinogorsk Yuzhnyy,nobomoseukobseukeu,novu~omosukofusuku,nwfwmwskwfyk,nwwmaskwwsk,nwwwmwskwfsk  rwsyh,xin mo si ke si ke,Горад Новамаскоўск,Новомосковск,Новомосковськ,Яңа Мәскәү,نوفوموسكوفيك,نووماسکووسک,نوووموسکوفسک، روسیه,ノヴォモスコフスク,新莫斯科斯克,노보모스콥스크', 54.0105000, 38.2846000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120233, 'Novominskaya', 'Novominskaya', 'Novominskaja,Novominskaya,Novominskoye,Nowominskaja,Stanitsa-Novominskaya,Новоминская', 46.3163000, 38.9586000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120234, 'Novomikhaylovskiy', 'Novomikhaylovskiy', 'Novo-Mikhaylovka,Novo-Mikhaylovskaya,Novomikhajlovskij,Novomikhaylovskiy,Novomikhaylovskoye,Новомихайловский', 44.2626000, 38.8585000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120235, 'Novomichurinsk', 'Novomichurinsk', 'Novomichurinsk,Novomikhurinsk,Novomitsjurinsk,Новомичуринск', 54.0384000, 39.7479000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120236, 'Novaya Malykla', 'Novaya Malykla', 'Nov.Malykla,Novaja Malykla,Novaya Malykla,Novomalykla,Нов.Малыкла,Новая Малыкла', 54.2000000, 49.9500000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120237, 'Novomalorossiyskaya', 'Novomalorossiyskaya', 'Grazhdanskaya,Novomalorossijskaja,Novomalorossiskaya,Novomalorossiyskaya,Novomyshastovskaya,Новомалороссийская', 45.6348300, 39.8948100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120238, 'Novoleushkovskaya', 'Novoleushkovskaya', 'Novo-Leushkovskoye,Novoleushkovskaja,Novoleushkovskaya,Novoleusjkovskaja,Новолеушковская', 45.9956000, 39.9921000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120239, 'Novolakskoye', 'Novolakskoye', 'Banay-Aul,Kishen''-Aukh,Kishen’-Aukh,Novolakskoe,Novolakskoje,Novolakskoye,Новолакское', 43.1195200, 46.4828100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120240, 'Novolabinskaya', 'Novolabinskaya', 'Novolabinskaja,Novolabinskaya,Новолабинская', 45.1095600, 39.8939900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120241, 'Novokuz’minki', 'Novokuz''minki', 'Novokuz''minki,Novokuz’minki,Новокузьминки', 55.7166700, 37.7833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120242, 'Novokuybyshevsk', 'Novokuybyshevsk', 'Gorad Navakujbyshehusk,Novo-Kuybuyshev,Novo-Kuybyshevskiy,Novokoejbysjevsk,Novokouibychevsk,Novokouïbychevsk,Novokuibisevsk,Novokuibiševsk,Novokuibosevsk,Novokuibysevsk,Novokuibysevskas,Novokuibyshevsk,Novokuibyševsk,Novokuibyševskas,Novokuibîșevsk,Novokuibõševsk,Novokujbisevsk,Novokujbisevszk,Novokujbishevs''k,Novokujbishevsk,Novokujbiŝevsk,Novokujbiševsk,Novokujbysevsk,Novokujbyshevsk,Novokujbysjevsk,Novokujbyševsk,Novokuybyshevsk,Novokúibyshevsk,Nowokuibyschewsk,Nowokujbysewsk,Nowokujbyszewsk,Nowokujbyšewsk,nwfwkwybyshfsk,nwwkwybyshfsk,nwwkwyybyshywsk,xin gu bi xue fu si ke,Горад Навакуйбышэўск,Новокуйбишевск,Новокуйбишевськ,Новокуйбышевск,Новокујбишевск,Яңа Куйбышев,نوفوكويبيشفسك,نووکویبیشفسک,نوّوکوئیبیشیوسک,新古比雪夫斯克', 53.0959000, 49.9462000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120243, 'Novokubansk', 'Novokubansk', 'Gorad Novakubansk,Khutorok,Novo-Kubanskaya,Novokoubansk,Novokubans''k,Novokubansk,Novokubanskiy,Novokubanskoe,Novokubanskoye,Nowokubansk,Nowokubańsk,nwfwkywbansk,nwwkwbansk,xin ku ban si ke,Горад Новакубанск,Новокубанск,Новокубанск балһсн,Новокубанськ,Яңа Кубанск,نوفوكيوبانسك,نووکوبانسک,新庫班斯克', 45.1170000, 41.0267000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120244, 'Novokorsunskaya', 'Novokorsunskaya', 'Novokorsunskaja,Novokorsunskaya,Новокорсунская', 45.6408000, 39.1464100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120245, 'Novokhovrino', 'Novokhovrino', 'Khovrino,Novokhovrino,Novoye Khovrino,Новоховрино', 55.8666700, 37.5000000, 'RU', '2016-07-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120246, 'Novokhopërsk', 'Novokhopersk', 'Novokhoperk,Novokhopersk,Novokhopjorsk,Novokhopyorsk,Novokhopërsk,Nowochopersk,Новохоперск,Новохопёрск', 51.0969000, 41.6252000, 'RU', '2014-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120247, 'Novokayakent', 'Novokayakent', 'Novokajakent,Novokayakent,Новокаякент', 42.3936800, 47.9860800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120248, 'Novoivanovskoye', 'Novoivanovskoye', 'Novoivanovskoe,Novoivanovskoye,Новоивановское', 55.7038100, 37.3651000, 'RU', '2014-09-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120249, 'Novogurovskiy', 'Novogurovskiy', 'Novogurovskij,Novogurovskiy,Новогуровский', 54.4678200, 37.3370900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120250, 'Oyskhara', 'Oyskhara', 'New Groznyy,Novogroznenskii,Novogroznenskij,Novogroznenskiy,Ojsangur,Ojshara,Ojskhar,Ojskhara,Ojssungur,Ojsungur,Oysangur,Oyskhara,Oysungur,Oysungurskoye,Oysxar,Новогрозненский,Ойсангур,Ойсунгур,Ойсхар,Ойсхара', 43.2640200, 46.2480300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120251, 'Grebnevo', 'Grebnevo', 'Grebnevo,Гребнево', 55.9507400, 38.0797300, 'RU', '2012-05-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120252, 'Novogireyevo', 'Novogireyevo', 'Novogireevo,Novogireyevo,Новогиреево', 55.7537800, 37.8188500, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120253, 'Novogagatli', 'Novogagatli', 'Aksay,Novogagatli,Novogagatlinskoe,Novogagatlinskoye,Новогагатли,Новогагатлинское', 43.4567700, 46.4817500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120254, 'Novodzhereliyevskaya', 'Novodzhereliyevskaya', 'Novaya Dzhereliyevskaya,Novodzherelievskaja,Novodzherelievskaya,Novodzhereliyevskaya,Novodzjerelijevskaja,Novozhareliyevskaya,Новоджерелиевская', 45.7737300, 38.6722700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120255, 'Novodvinsk', 'Novodvinsk', 'Gorad Navadzvinsk,Mechkastroy,Novodvinsk,Nowodwinsk,Pervomayskiy,Voroshilovskiy,nobodeubinseukeu,novu~odovu~insuku,nwfwdfynsk,nwwwdwynsk,xin de wen si ke,Горад Навадзвінск,Новодвинск,Яңа Двинск,نوفودفينسك,نووودوینسک,ノヴォドヴィンスク,新德文斯克,노보드빈스크', 64.4165000, 40.8122000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120256, 'Novodugino', 'Novodugino', 'Novodugino,Novoduginskaya,Новодугино', 55.6305200, 34.2842300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120257, 'Novodmitriyevskaya', 'Novodmitriyevskaya', 'Novaya Dmitriyevskaya,Novodmitrievskaja,Novodmitrijevskaja,Novodmitriyevskaya,Новодмитриевская', 44.8327600, 38.8784700, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120258, 'Novoderevyankovskaya', 'Novoderevyankovskaya', 'Novoderevjankovskaja,Novoderevyankovskaya,Новодеревянковская', 46.3231200, 38.7472400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120259, 'Novocherkassk', 'Novocherkassk', 'Gorad Novacharkask,Novocerkask,Novocerkaska,Novocerkaskas,Novocerkassk,Novocherkas''k,Novocherkask,Novocherkassk,Novocserkasszk,Novotcherkassk,Novotjerkassk,Novotserkassk,Novotsjerkassk,Novotšerkassk,Novoçerkassk,Novoĉerkassk,Novočerkask,Novočerkaska,Novočerkaskas,Novočerkassk,Nowoczerkask,Nowotscherkask,Nowotscherkassk,Nowotsjerkassk,nobocheleukaseukeu,novu~ocherukassuku,nwbwzrqsq,nwfwtshrkask,nwwchrkask,nwwchrkysk,xin qie er ka si ke,Горад Новачаркаск,Новочеркаск,Новочеркасск,Новочеркаськ,נובוצרקסק,نوفوتشركاسك,نووچرکاسک,نووچرکیسک,ნოვოჩერკასკი,ノヴォチェルカッスク,新切爾卡斯克,노보체르카스크', 47.4201800, 40.0913200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120260, 'Novocheremshansk', 'Novocheremshansk', 'Novocheremshansk,Novotsjeremsjansk,Stantsiya Salavan,Staryy Salavan,Staryy Salaven,Новочеремшанск', 54.3571400, 50.1666200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120261, 'Novocheboksarsk', 'Novocheboksarsk', 'Cene Shupashkar,Novoceboksarsk,Novocheboksarsk,Novotseboksarsk,Novotsjeboksarsk,Novotšeboksarsk,Novoĉeboksarsk,Novočeboksarsk,Nowotscheboksarsk,nobochebogsaleuseukeu,novu~ochebokusarusuku,Çĕнĕ Шупашкар,Новочебоксарск,ノヴォチェボクサルスク,노보체복사르스크', 56.1109500, 47.4775500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120262, 'Novoblagodarnoye', 'Novoblagodarnoye', 'Novoblagodarnoe,Novoblagodarnoje,Novoblagodarnoye,Новоблагодарное', 44.1433300, 42.8750000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120263, 'Novobeysugskaya', 'Novobeysugskaya', 'Beysugskaya,Novobejsugskaja,Novobeysugskaya,Новобейсугская', 45.4719500, 39.8861400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120264, 'Novobessergenovka', 'Novobessergenovka', 'Novobessergenevka,Novobessergenovka,Новобессергеневка,Новобессергеновка', 47.1846500, 38.8462500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120265, 'Novobelokatay', 'Novobelokatay', 'Novobelokataj,Novobelokatay,Novyy Belokatay,Новобелокатай', 55.7062000, 58.9549000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120266, 'Novobataysk', 'Novobataysk', 'Novobatajsk,Novobataysk,Новобатайск', 46.8980600, 39.7819400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120267, 'Novoanninskiy', 'Novoanninskiy', 'Annenskiy,Novaya Annenskaya,Novo-Annenskiy,Novoannenka,Novoannenskaya,Novoanninskij,Novoanninskiy,Новоаннинский', 50.5287000, 42.6747000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120268, 'Novoalekseyevskaya', 'Novoalekseyevskaya', 'Novoalekseevskaja,Novoaleksejevskaja,Novoalekseyevskaya,Новоалексеевская', 44.8188900, 40.9338900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120269, 'Novoaleksandrovsk', 'Novoaleksandrovsk', 'Gorad Novaaljaksandrausk,Novoaleksandrovsk,Novoaleksandrovskaya,Novoalexandrovsk,Nowo Aleksandrowskaja,Nowo-Alexandrowskaja,Nowoaleksandrowsk,Nowoalexandrowsk,nwfwalksndrwfsk,nwwalksandrwfsk,xin ya li shan de luo fu si ke,Горад Новааляксандраўск,Новоалександровск,Новоалександровск балһсн,Яңа Александровск,نوفوالكسندروفسك,نووالکساندروفسک,新亞歷山德羅夫斯克', 45.4948000, 41.2207500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120270, 'Novki', 'Novki', 'Noviki,Novki,Новки', 56.3638600, 41.0865500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120271, 'Velikiy Novgorod', 'Velikiy Novgorod', 'Holmgardur,Hólmgarður,NVR,Naugard,Naugardas,Nobnkoront,Nov" Grad",Nov"grad",Novgorod,Novogardia Magna,Nowgorod,Nowogrod Wielki,Nowogród Wielki,Suuri Novgorodi,Veliki Novgorod,Veliki Nóvgorod,Velikij Novgorod,Velikiy Novgorod,Veliky Novgorod,Weliki Nowgorod,bellikinobeugolodeu,da nuo fu ge luo de,didi novgorodi,novugorodo,nwbgwrwd,Šuuri Novgorodi,Νόβγκοροντ,Велики Новгород,Великий Новгород,Новгород,Новъ Градъ,Новъградъ,נובגורוד,დიდი ნოვგოროდი,ノヴゴロド,大诺夫哥罗德,벨리키노브고로드', 58.5213100, 31.2710400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120272, 'Novaya Usman’', 'Novaya Usman''', 'Nov.Usman'',Novaja Usman'',Novaya Usman'',Novaya Usman’,Novo-Usman'',Novo-Usman’,Sobakino,Usman,Usman'' Sobakino,Usman’ Sobakino,Нов.Усмань,Новая Усмань', 51.6417700, 39.4086300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120273, 'Novaya Tavolzhanka', 'Novaya Tavolzhanka', 'Nov.Tavolzhanka,Novaja Tavolzhanka,Novaya Tavolzhanka,Novotavolzhanka,Нов.Таволжанка,Новая Таволжанка', 50.3512300, 36.8298000, 'RU', '2014-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120274, 'Novaya Mayna', 'Novaya Mayna', 'Novaja Majna,Novaya Mayna,Новая Майна', 54.1500000, 49.7500000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120275, 'Novaya Lyada', 'Novaya Lyada', 'Novaja Ljada,Novaya Lyada,Новая Ляда', 52.7130900, 41.6387200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120276, 'Novaya Ladoga', 'Novaya Ladoga', 'Novaja Ladoga,Novaya Ladoga,Nowoja-Ladoga,Uusi Laatokka,Новая Ладога', 60.1024600, 32.3019100, 'RU', '2012-09-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120277, 'Novaya Derevnya', 'Novaya Derevnya', 'Novaja derevnja,Uusikylae,Uusikylä,Новая деревня', 59.9874800, 30.2868200, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120278, 'Novaya Chigla', 'Novaya Chigla', 'Nov.Chigla,Novaja Chigla,Novaya Chigla,Nowo-Tschigla,Нов.Чигла,Новая Чигла', 51.2233300, 40.4780600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120279, 'Nolinsk', 'Nolinsk', 'Gorad Nolinsk,Molotovsk,Nol''o,Nolinsk,Nolinszk,nuo lin si ke,nwlynsk,Горад Нолінск,Нолинск,Нольо,نولينسك,نولینسک,諾林斯克', 57.5596200, 49.9362900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120280, 'Nogir', 'Nogir', 'Nogir,Ногир', 43.0816200, 44.6365000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120281, 'Noginsk', 'Noginsk', 'Gorad Naginsk,Noghinsk,Nogins''k,Noginsk,Noginska,Noginskas,Nogińsk,Noguinsk,Noqinsk,noginseukeu,noginsuku,nuo jin si ke,nwgnsk,nwgynsk,nwjynsk,Горад Нагінск,Ногинск,Ногинск балһсн,Ногінськ,نوجينسك,نوگنسک,نوگینسک,ノギンスク,諾金斯克,노긴스크', 55.8664700, 38.4438000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120282, 'Nizhnyaya Tura', 'Nizhnyaya Tura', 'Anatri Tura,Gorad Nizhnjaja Tura,Nijniaia Toura,Nijniaïa Toura,Nijnjaja Tura,Nijnyaya Tura,Nischnjaja Tura,Nizhnaja Tura,Nizhnaya Tura,Nizhniaya Tura,Nizhnja Tura,Nizhnjaja Tura,Nizhnyaya Tura,Nizjnjaja Toera,Nizjnjaja Tura,Nizniagia Toura,Nizniaja Tura,Niznjaja Tura,Niĵnjaja Tura,Niżniaja Tura,Nižnjaja Tura,Nižnjaja Тurа,Nízhniaya Turá,nyjnyaya twra,nyzhnyaya twra,xia tu la,Νίζνιαγια Τουρά,Анатри Турă,Горад Ніжняя Тура,Нижня Тура,Нижняя Тура,Нижњаја Тура,Түбән Түре,نيجنيايا تورا,نیژنیایا تورا,下圖拉', 58.6293000, 59.8118000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120283, 'Nizhnepavlovka', 'Nizhnepavlovka', 'Nizhne-Pavlovskaya,Nizhnepavlovka,Nizhnjaja Pavlovka,Nizhnyaya Pavlovka,Pavlovskaya,Нижнепавловка,Нижняя Павловка', 51.7132400, 54.8014600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120284, 'Nizhnyaya Maktama', 'Nizhnyaya Maktama', 'Nizhnjaja Maktama,Nizhnyaya Maktama,Nizjnjaja Maktama,Нижняя Мактама', 54.8635600, 52.4281000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120285, 'Nizhnyaya Irga', 'Nizhnyaya Irga', 'Nizhneigrinskoye,Nizhneirginskoe,Nizhnjaja Irga,Nizhnyaya Irga,Nizhnyaya Irta,Nizjneirginskoje,Нижнеиргинское,Нижняя Ирга', 56.8669000, 57.4220000, 'RU', '2015-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120286, 'Nizhniy Ufaley', 'Nizhniy Ufaley', 'Nizhnij Ufalej,Nizhniy Ufaley,Nizjnij Ufalej,Ufalei,Ufaley,Нижний Уфалей', 55.9152800, 59.9841700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120287, 'Nizhniy Tagil', 'Nizhniy Tagil', 'Nizhne-Tagil''skiy,Nizhne-Tagil’skiy,Nizhni Tagil,Nizhnii Tagil,Nizhnij Tagil,Nizhniy Tagil,Nizjnij Tagil,Нижний Тагил', 57.9194400, 59.9650000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120288, 'Nizhniy Odes', 'Nizhniy Odes', 'Nizh.Odes,Nizhnij Odes,Nizhniy Odes,Ниж.Одес,Нижний Одес', 63.6445100, 54.8559800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120289, 'Nizhniy Novgorod', 'Nizhniy Novgorod', 'GOJ,Gor''kij,Gor''kiy,Gorkey,Gorki,Gorkii,Gorkij,Gorky,Nijni Novgorod,Nijnii Novgorod,Nischni Nowgorod,Nishni-Nowgorod,Nishnii Nowgorod,Nishnij Nowgorod,Nizhni Novgorod,Nizhnii Novgorod,Nizhnij Novgorod,Nizhniy Novgorod,Nizhny Novgorod,Nizjnij Novgorod,Nizni Novgorod,Niznij Nowgorod,Nižni Novgorod,Nižnij Nowgorod,Горький,Нижний Новгород', 56.3286700, 44.0020500, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120290, 'Nizhniy Mamon', 'Nizhniy Mamon', 'Nizhnij Mamon,Nizhniy Mamon,Nizjnij Mamon,Novoe Mamon,Нижний Мамон', 50.1937000, 40.5083000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120291, 'Nizhniy Lomov', 'Nizhniy Lomov', 'Nizhni Lamov,Nizhnij Lomov,Nizhniy Lomov,Нижний Ломов', 53.5304100, 43.6766300, 'RU', '2014-07-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120292, 'Nizhniy Kislyay', 'Nizhniy Kislyay', 'Nizhnij Kisljaj,Nizhniy Kislyay,Nizjnij Kisljaj,Нижний Кисляй', 50.8497000, 40.1719000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120293, 'Nizhniye Vyazovyye', 'Nizhniye Vyazovyye', 'Nizhne-Vyazovyye,Nizhneye Vyazov''ye,Nizhneye Vyazov’ye,Nizhnie Vjazovye,Nizhniye Vyazovyye,Nizjnije Vjazovye,Нижние Вязовые', 55.7987700, 48.5247600, 'RU', '2014-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120294, 'Nizhniye Sergi', 'Nizhniye Sergi', 'Gorad Nizhnija Sergi,Nijnie Sergui,Nijnije Sergi,Nijniye Serqi,Nischnije Sergi,Nizhni Sergi,Nizhnie Sergi,Nizhnije Sergi,Nizhniye Sergi,Nizjnieje Sergi,Nizjnije Sergi,Niznie Sergi,Niznie Sernki,Niznije Sergi,Niĵnije Sergi,Nižnie Sergi,Nižnije Sergi,nyjny srjy,nyzhnyh srgy,xia xie er ji,Νίζνιε Σέργκι,Горад Ніжнія Сергі,Нижни Серги,Нижние Серги,Нижні Серги,Нижњије Серги,Түбән Сырга,نيجني سرجي,نیژنیه سرگی,下謝爾吉', 56.6613900, 59.3033300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120295, 'Nizhniye Achaluki', 'Nizhniye Achaluki', 'Nizhne-Atsylyk,Nizhnie Achaluki,Nizhniy Atsylyk,Nizhniye Achaluki,Nizjnije Atsjaluki,Нижние Ачалуки', 43.4028000, 44.7590800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120296, 'Nizhniy Dzhengutay', 'Nizhniy Dzhengutay', 'Nizhnij Dzhengutaj,Nizhniy Dzhengutay,Nizjnij Dzjengutaj,Нижний Дженгутай', 42.7000800, 47.2448800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120297, 'Nizhniy Chir', 'Nizhniy Chir', 'Churki,Nishne-Tschirskaja,Nizh.Chir,Nizhne-Chirskaya,Nizhnij Chir,Nizhniy Chir,Ниж.Чир,Нижний Чир', 48.3597300, 43.0865000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120298, 'Nizhniy Cherek', 'Nizhniy Cherek', 'Nizhnij Cherek,Nizhniy Cherek,Nizjnij Tsjerek,Нижний Черек', 43.5130600, 43.9138900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120299, 'Nizhniy Baskunchak', 'Nizhniy Baskunchak', 'Nizh.Baskunchak,Nizhni Baskunchak,Nizhnij Baskunchak,Nizhniy Baskunchak,Ниж.Баскунчак,Нижний Баскунчак', 48.2197800, 46.8310500, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120300, 'Nizhniy Arkhyz', 'Nizhniy Arkhyz', 'Nizhnij Arkhyz,Nizhniy Arkhyz,Nizjnij Arkhyz,Zelenchuk,Нижний Архыз', 43.6763300, 41.4555600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120301, 'Nizhneye Kazanishche', 'Nizhneye Kazanishche', 'Nizhnee Kazanishhe,Nizhneye Kazanishche,Nizhniye Kazanishche,Nizhniye Kazanishchi,Nizjneje-Kazanisjtsje,Нижнее Казанище', 42.7636900, 47.1602700, 'RU', '2014-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120302, 'Nizhnetroitskiy', 'Nizhnetroitskiy', 'Nizhne Troitskiy Zavod,Nizhnetroickij,Nizhnetroitskij,Nizhnetroitskiy,Nizjnetroitskij,Нижнетроитский,Нижнетроицкий', 54.3385200, 53.6832900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120303, 'Nizhnekamsk', 'Nizhnekamsk', 'Anat Kama,Gorad Nizhnjakamsk,NBC,Nijnekamsk,Nischnekamsk,Nizhn''okams''k,Nizhnekamsk,Nizhnekamskiy,Nizjnekamsk,Niznekamsk,Niznekamska,Niznekamskas,Nizniekamsk,Niznjekamsk,Niĵnekamsk,Niżniekamsk,Nižnekamsk,Nižnekamskas,Nižnjekamsk,Nižněkamsk,Tuebaen Kama,Tuebenkama,Tübenkama,Tübän Kama,nijeunekamseukeu,nijinekamusuku,nyjnkamsk,nyzhnkamsk,nyzhnykamsk,xia ka mu si ke,Ņižņekamska,Анат Кама,Горад Ніжнякамск,Нижнекамск,Нижньокамськ,Нижњекамск,Түбән Кама,نيجنكامسك,نیژنکامسک,نیژنیکامسک,ニジネカムスク,下卡姆斯克,니즈네캄스크', 55.6365700, 51.8244700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120304, 'Nizhneivkino', 'Nizhneivkino', 'Nizhneivkino,Nizhneye Ivkino,Nizjneivkino,Нижнеивкино', 58.1939800, 49.5213700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120305, 'Nizhnedevitsk', 'Nizhnedevitsk', 'Nishnedewizk,Nizhnedevick,Nizhnedevitsic,Nizhnedevitsk,Nizjnedevitsk,Нижнедевицк', 51.5419000, 38.3657000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120306, 'Niny', 'Niny', 'Niny,Нины', 44.4877800, 43.9488900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120307, 'Nikulino', 'Nikulino', 'Nikulino,Никулино', 55.6694300, 37.4659800, 'RU', '2016-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120308, 'Nikol’skoye', 'Nikol''skoye', 'Nikol''skoe,Nikol''skoye,Nikolskiy,Nikol’skoye,Никольское', 55.6833300, 37.4833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120309, 'Nikol’skoye', 'Nikol''skoye', 'Lomkka,Nikol''skoe,Nikol''skoye,Nikolskoje,Nikol’skoye,Никольское', 59.7005600, 30.7847200, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120310, 'Nikol’sk', 'Nikol''sk', 'Nikol''sk,Nikol’sk,Никольск', 59.5353100, 45.4574300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120311, 'Nikol’sk', 'Nikol''sk', 'Nikol''sk,Nikol''skaya Pestravka,Nikolsk,Nikol’sk,Nikol’skaya Pestravka,Никольск', 53.7188600, 46.0711800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120312, 'Nikologory', 'Nikologory', 'Nikologory,Никологоры', 56.1413000, 41.9921800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120313, 'Nikolo-Berëzovka', 'Nikolo-Berezovka', 'Nikolo-Berezovka,Nikolo-Berezovskoye,Nikolo-Berëzovka,Николо-Березовка', 56.1242200, 54.1557300, 'RU', '2010-06-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120314, 'Nikolina Gora', 'Nikolina Gora', 'Nikolina Gora,Николина Гора', 55.7343300, 37.0436400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120315, 'Nikolayevskaya', 'Nikolayevskaya', 'Nikolaevskaja,Nikolajevskaja,Nikolayevskaya,Николаевская', 47.6139100, 41.5023000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120316, 'Nikolayevsk', 'Nikolayevsk', 'Nikolaevs''k,Nikolaevsk,Nikolaevskaya,Nikolaevski,Nikolajevsk,Nikolajevska,Nikolayevka,Nikolayevsk,Nikolayevskaya,Nikolayevskiy,Николаевск,Ніколаєвськ', 50.0282400, 45.4595300, 'RU', '2016-09-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120317, 'Nikolayevka', 'Nikolayevka', 'Nikolaevka,Nikolajevka,Nikolayevka,Николаевка', 54.1451000, 45.1444000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120318, 'Nikolayevka', 'Nikolayevka', 'Nikolaevka,Nikolajevka,Nikolayevka,Николаевка', 53.1257000, 47.2041000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120319, 'Nikola-Lenivets', 'Nikola-Lenivets', 'Nikola Lenivets,Nikola-Lenivec,Nikola-Lennvets,Nikolo-Lenivec,Nikolo-Lenivets,Никола-Ленивец,Николо-Ленивец', 54.7494300, 35.6013300, 'RU', '2014-12-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120320, 'Nikel', 'Nikel', 'Kolosjoki,Kolosjokki,Nikel,Nikel'',Nikkeli,Никель', 69.4128500, 30.2219800, 'RU', '2016-09-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120321, 'Nezlobnaya', 'Nezlobnaya', 'Nezlobnaja,Nezlobnaya,Незлобная', 44.1180600, 43.4027800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120322, 'Nezhinka', 'Nezhinka', 'Nezhenka,Nezhinka,Nezjinka,Нежинка', 51.7676000, 55.3694000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120323, 'Neya', 'Neya', 'Neja,Neya,Нея', 58.2971900, 43.8680800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120324, 'Nevinnomyssk', 'Nevinnomyssk', 'Gorad Njavinnamysk,Nevinnomis''k,Nevinnomissk,Nevinnomossk,Nevinnomyskaya,Nevinnomyssk,Nevinnomysskaya,Nevinnomîssk,Nevinnomõssk,Nevinnomıssk,Nevinnonyssk,Nevinomisk,Nevinomysk,Nevinomyskas,Nevinomısk,Newinnomyssaja,Newinnomyssk,Newinnomysskaja,Niewinnomyssk,Njewinnomyssk,Něvinnomyssk,nafynwmysk,nebinomiseukeu,nevu~in''nomuisuku,nie wen nuo mei si ke,nwynwmysk,nywynwmysk,Горад Нявіннамыск,Невинномисск,Невинномиськ,Невинномысск,Невинномысск балһсн,Невиномиск,Նեվինոմիսկ,نافينوميسك,نوینومیسک,نیوینومیسک,ネヴィンノムイスク,涅溫諾梅斯克,네비노미스크', 44.6333000, 41.9444000, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120325, 'Neverkino', 'Neverkino', 'Neverkino,Неверкино', 52.7854100, 46.7417400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120326, 'Nevel’', 'Nevel''', 'Nevel,Nevel'',Nevel’,Newel,Невель', 56.0209400, 29.9284400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120327, 'Nesterovskaya', 'Nesterovskaya', 'Nesterovskaja,Nesterovskaya,Nesterowskaja,Нестеровская', 43.2386100, 45.0502800, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120328, 'Nesterov', 'Nesterov', 'Ebenrode,Gorad Nescerau,Nesterov,Nesterova,Nesterovas,Nesterow,Nestěrov,Niestierow,Njesterow,Shtallupenen,Shtallupënen,Stallupenen,Stallupoenen,Stalluponen,Stallupönen,Stalupenai,Stalupėnai,neseutelopeu,nesuterofu,nie si jie luo fu,nstrwf,Ņesterova,Горад Несцераў,Нестеров,نستروف,ネステロフ,涅斯捷羅夫,네스테로프', 54.6305600, 22.5713900, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120329, 'Nerl’', 'Nerl''', 'Nerl,Nerl'',Nerl’,Нерль', 56.6628500, 40.3893100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120330, 'Nerekhta', 'Nerekhta', 'Nerechta,Nerehta,Nerekhta,Nereĥta,Nieriechta,Njerjechta,Nyerehta,Nérekhta,neleheuta,nerefuta,nie lie he ta,nrkhta,Нерехта,نرختا,ネレフタ,涅列赫塔,네레흐타', 57.4588100, 40.5747100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120331, 'Nemchinovka', 'Nemchinovka', 'Nemchinovka,Nemchinovo,Nemtsjinovka,Немчиновка', 55.7228800, 37.3608600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120332, 'Neman', 'Neman', 'Byen Neman,Neman,Nemana,Nemanas,Nieman,Niman,Njeman,Ragaine,Ragainė,Ragnit,neman,nie man,nman,Ņemana,Неман,Німан,نمان,ネマン,涅曼,네만', 55.0311100, 22.0263900, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120333, 'Nema', 'Nema', 'Nema,Нема', 57.5067500, 50.5011500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120334, 'Nelidovo', 'Nelidovo', 'Gorad Njalidava,Nelidovo,Nelidowo,Nielidowo,Njelidowo,Poselok Delidovo,Poselok Nelidovo,Posëlok Delidovo,Posëlok Nelidovo,nellidobo,neridovu~o,nie li duo wo,nlydwfw,Горад Нялідава,Нелидово,Нелідово,نليدوفو,نلیدوفو,ネリドヴォ,涅利多沃,넬리도보', 56.2210700, 32.7773800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120335, 'Nelazskoye', 'Nelazskoye', 'Nelazskoe,Nelazskoje,Nelazskoye,Нелазское', 59.1891900, 37.6396300, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120336, 'Nekrasovskoye', 'Nekrasovskoye', 'Bol''shiye Soli,Bol’shiye Soli,Nekrasovskiy,Nekrasovskoe,Nekrasovskoje,Nekrasovskoye,Некрасовское', 57.6766300, 40.3656700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120337, 'Nekrasovskiy', 'Nekrasovskiy', 'Nekrasovskij,Nekrasovskiy,Некрасовский', 56.0934900, 37.4993400, 'RU', '2016-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120338, 'Nekrasovskaya', 'Nekrasovskaya', 'Nekrasovskaja,Nekrasovskaya,Некрасовская', 45.1446800, 39.7486800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120339, 'Nekrasovka', 'Nekrasovka', 'Nekrasovka,Некрасовка', 55.6932800, 37.9114800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120340, 'Neklyudovo', 'Neklyudovo', 'Nekljudovo,Neklyudovo,Неклюдово', 56.4142100, 43.9772100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120341, 'Nekhayevskiy', 'Nekhayevskiy', 'Nekhaevskij,Nekhajevskij,Nekhayevskaya,Nekhayevskiy,Нехаевский', 50.4106000, 41.7561000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120342, 'Neftekamsk', 'Neftekamsk', 'Gorad Nefcjakamsk,Kasevo,Kaseyevo,NEF,Neftekama,Neftekams''k,Neftekamsk,Neftekamska,Neftekamskas,Nieftiekamsk,Njeftekamsk,Nyeftyekamszk,Něftěkamsk,nebtekamseukeu,nftkamsk,nie fu jie ka mu si ke,nyftykamsk,Ņeftekamska,Горад Нефцякамск,Нефтекама,Нефтекамск,Нефтекамск балһсн,Нефтекамськ,نفتكامسك,نفتکامسک,نیفتیکامسک,涅夫捷卡姆斯克,넵테캄스크', 56.0920000, 54.2661000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120343, 'Neftegorsk', 'Neftegorsk', 'Neftegorsk,Нефтегорск', 52.8020000, 51.1660000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120344, 'Neftegorsk', 'Neftegorsk', 'Neftegorsk,Neftegorskaya,Нефтегорск', 44.3658000, 39.7078000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120345, 'Nedvigovka', 'Nedvigovka', 'Nedvigovka,Nedvigovskiy,Недвиговка', 47.2687300, 39.3488000, 'RU', '2017-05-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120346, 'Nebug', 'Nebug', 'Nebug,Nebugskaya,Nebugskiy,Небуг', 44.1717000, 39.0026000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120347, 'Nebolchi', 'Nebolchi', 'Nebolchi,Neboltsji,Неболчи', 59.1239300, 33.3453700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120348, 'Nazran’', 'Nazran''', 'Imeni Kost-Khetagurova,Kazran,Kosta-Khetagurovo,Nana-Na''sare,Nasran,Nazran,Nazran'',Nazrane,Nazranj,Nazrano,Nazranė,Nazran’,Nazrań,Poselok Nazran'',Posëlok Nazran’,najeulan,Назрань,Нана-Наьсаре,나즈란', 43.2259700, 44.7732300, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120349, 'Nazar''yevo', 'Nazar''yevo', 'Nazar''evo,Nazar’yevo,posjolok Nazar''evo,Назарьево,посёлок Назарьево', 55.6741700, 37.0402800, 'RU', '2014-09-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120350, 'Navoloki', 'Navoloki', 'Navoloki,Novoloki,Наволоки', 57.4657200, 41.9634400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120351, 'Navlya', 'Navlya', 'Navlja,Navlya,Novlya,Навля', 52.8254400, 34.4996000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120352, 'Navashino', 'Navashino', 'Navashino,Navasjino,Навашино', 55.5441000, 42.1968000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120353, 'Naurskaya', 'Naurskaya', 'Naurskaja,Naurskaya,Naursko-Mekenskaja,Naursko-Mekenskaya,Nauskaya,Nevr-GIala,Nevr-Gala,Nevr-Ġala,Nevre,Novr-GIala,Novr-Gala,Novr-Ġala,Наурская,Наурско-Мекенская,Невр-ГІала,Невре,Новр-ГІала', 43.6507500, 45.3117300, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120354, 'Alpatovo', 'Alpatovo', 'Alpatov,Alpatovo,Naurskiy,Алпатово', 43.7028000, 45.2415400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120355, 'Natyrbovo', 'Natyrbovo', 'Natyrbovo,Натырбово', 44.7300000, 40.6263900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120356, 'Naryshkino', 'Naryshkino', 'Bolshoye Naryschkino,Naryschkino,Naryshkino,Narysjkino,Нарышкино', 52.9677800, 35.7267700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120357, 'Nar''yan-Mar', 'Nar''yan-Mar', 'Dzerzhinskiy,NNM,Nar''yan-Mar,Narjan Mar,Narjan-Mar,Naryan-Mar,naliyanmaleu,nar''jan-mar,Нарьян-Мар,נריין-מאר,ナリヤン・マル,나리얀마르', 67.6386900, 53.0037100, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120358, 'Nartkala', 'Nartkala', 'Dokshukino,Doshukino,Gorad Nartkala,Nartkal,Nartkala,Nartkała,Nartkualeh,na er te ka la,nart kala,nartkala,Горад Нарткала,Нарткала,Нарткала балһсн,Нарткъалэ,نارت كالا,نارتکالا,納爾特卡拉', 43.5575000, 43.8508300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120359, 'Nartan', 'Nartan', 'Nartan,Нартан', 43.5108300, 43.6994400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120360, 'Narovchat', 'Narovchat', 'Narovchat,Narovtsjat,Наровчат', 53.8765400, 43.6945800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120361, 'Naro-Fominsk', 'Naro-Fominsk', 'Gorad Nara-Faminsk,Naro-Fomins''k,Naro-Fominsk,Naro-Fomińsk,Narofominska,na luo-fu ming si ke,nalopominseukeu,naro=fominsuku,narw-fwmynsk,narwfwmnsk,Горад Нара-Фамінск,Наро-Фоминск,Наро-Фоминск балһсн,Наро-Фомінськ,Նարո-Ֆոմինսկ,نارو-فومينسك,نارو-فومینسک,ناروفومنسک,ナロ＝フォミンスク,納羅-福明斯克,나로포민스크', 55.3875200, 36.7330700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120362, 'Narimanov', 'Narimanov', 'Gorad Narymanau,Nariman,Narimanov,Narimanow,Nizhnevolzhsk,Nizhnevolzhskoye,Nərimanov,na li ma nuo fu,narymanwf,narymanwf  awblast astrakhan,Горад Нарыманаў,Нариман,Нариманов,Нариманов балһсн,Наріманов,Нижневолжск,ناريمانوف,ناریمانوف، اوبلاست آستراخان,納里馬諾夫', 46.6927000, 47.8498000, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120363, 'Nal’chik', 'Nal''chik', 'NAL,Nal''chik,Nalshyk,Naltschik,Naltsik,Naltšik,Nal’chik,Налшык,Нальчик', 43.4980600, 43.6188900, 'RU', '2017-07-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120364, 'Nakhabino', 'Nakhabino', 'Nakhabino,Нахабино', 55.8485400, 37.1778900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120365, 'Nagutskoye', 'Nagutskoye', 'Nagutsk,Nagutskaja,Nagutskoe,Nagutskoje,Nagutskoye,Нагутское', 44.4415000, 42.8762000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120366, 'Nagorsk', 'Nagorsk', 'Nagorsk,Nagorskoe,Nagorskoye,Нагорск', 59.3172200, 50.8077800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120367, 'Lakha Nëvre', 'Lakha Nevre', 'Lakha Nevre,Lakha Njovre,Lakha Nëvre,Nadterechnaya,Nadterechnoe,Nadterechnoye,Nadterecnoe,Nadteretsjnoje,Nadtereçnoe,Nizhniy Naur,Лаха Нёвре,Надтеречное', 43.6227100, 45.3396900, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120368, 'Nadvoitsy', 'Nadvoitsy', 'Nadovitsy,Nadvoicy,Nadvoitsy,Nadvoytsy,Nadvoyzi,Otvet Kulaku,Vojatsu,Надвоицы', 63.8666700, 34.3166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120369, 'Nadezhda', 'Nadezhda', 'Nadezhda,Nadezjda,Надежда', 44.1000000, 44.6000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120370, 'Nachalovo', 'Nachalovo', 'Nachalo,Nachalovo,Natsjalo,Начало,Началово', 46.3380000, 48.2012800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120371, 'Naberezhnyye Chelny', 'Naberezhnyye Chelny', 'Brezhnev,Jar Chally,Naberejnije Celni,Naberejnye Chelny,Nabereschnyje Tschelny,Naberezhnye Chelny,Naberezhnyye Chelny,Naberezjnye Tsjelny,Nabereznije Celni,Nabereznoje Tselno,Nabereznye Celny,Nabereznyje Celny,Nabereznyje Tselny,Nabereĵnije Ĉelni,Naberežnije Čelni,Naberežnye Čelny,Naberežnyje Tšelny,Naberežnyje Čelny,Naberežnõje Tšelnõ,nabelejeuniyechelni,nabelejuniyechelni,Брежнев,Набережные Челны,Яр Чаллы,나베레주니예첼니,나베레즈니예첼니', 55.7254500, 52.4112200, 'RU', '2014-03-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120372, 'Myurego', 'Myurego', 'Mjurego,Myuregi,Myurego,Мюрего', 42.4108700, 47.6930400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120373, 'Mytishchi', 'Mytishchi', 'Gorad Mycishchy,Mitischi,Mitisci,Mitishchi,Mitishhi,Mitisi,Mitisxi,Mitiŝĉi,Mitišči,Mityiscsi,Miytisci,Motistsi,Mytichtchi,Mytischtschi,Mytisci,Mytisciai,Mytishchi,Mytishhi,Mytishi,Mytisjtji,Mytisjtsji,Mytistsi,Mytiszczi,Mytištši,Mytišći,Mytišči,Mytiščiai,Mîtișci,Mõtištši,Mıtişi,Mıytişçi,maytshy,mei ji xi,mitisi,mitisichi,muy thich chi,mu~itishi,mytyshchy,Горад Мыцішчы,Митишчи,Митищі,Мытищи,Мытищи балһсн,مايتشي,میتیشچی,มืยทิชชี,ムィティシ,梅季希,미티시,미티시치', 55.9116300, 37.7307600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120374, 'Myshkin', 'Myshkin', 'Gorad Myshkin,Mishkin,Miskin,Miŝkin,Miškin,Moskin,Mychkine,Myschkin,Myshkin,Myshkino,Mysjkin,Myskin,Myszkin,Myškin,Mõškin,Mışkin,mayshkyn,mei shen jin,misikin,mu~ishukin,myshkyn,Горад Мышкін,Мишкин,Мышкин,مايشكين,میشکین,ムィシュキン,梅什金,미시킨', 57.7897300, 38.4544800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120375, 'Myatlevo', 'Myatlevo', 'Mjatlevo,Mjatlewo,Myatlevo,Мятлево', 54.8969300, 35.6761900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120376, 'Myaksa', 'Myaksa', 'Mjaksa,Myaksa,Мякса', 58.8889000, 38.1938000, 'RU', '2016-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120377, 'Muyezerskiy', 'Muyezerskiy', 'Muezerskij,Mujejaervi,Mujejärvi,Mujezerskij,Muujarvi,Muyezero,Muyezerskiy,Muyozero,Muyëzero,Муезерский', 63.9575800, 31.9873800, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120378, 'Mutsalaul', 'Mutsalaul', 'Mucal-Aul,Mucalaul,Mutsalaul,Муцал-Аул,Муцалаул', 43.2754800, 46.7307800, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120379, 'Muslyumovo', 'Muslyumovo', 'Musljumovo,Muslyumovo,Муслюмово', 55.3033300, 53.1947200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120380, 'Murygino', 'Murygino', 'Murygino,Мурыгино', 58.7383100, 49.4582200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120381, 'Murom', 'Murom', 'Gorad Muram,Moerom,Mourom,Murom,Murom am Oka,Muromas,Muromum,Múrom,mu luo mu,mulom,muromu,mwrwm,Горад Мурам,Муром,Мөрәм,موروم,ムーロム,穆罗姆,무롬', 55.5750000, 42.0426000, 'RU', '2016-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120382, 'Murmino', 'Murmino', 'Murmino,Мурмино', 54.6043000, 40.0549000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120383, 'Murmashi', 'Murmashi', 'Murmashi,Murmasji,Murmaski,Мурмаши', 68.8154200, 32.8114700, 'RU', '2013-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120384, 'Murmansk', 'Murmansk', 'Gorad Murmansk,Gorod Murmansk,MMK,Moermansk,Mourmansk,Murmans''k,Murmansk,Murmansk osh,Murmanska,Murmanskas,Murmanski,Murmansko,Murmanszk,Murmańsk,Murmánska,Muurmanni,Muurmanski,Múrmansk,Mûrmansk,mo er man si ke,muleumanseukeu,muramanska,murmanska,murumansuku,mwrmansk,mwrmnsq,Μούρμανσκ,Горад Мурманск,Мурманск,Мурманск ош,Мурманськ,Մուրմանսկ,מורמנסק,مورمانسك,مورمانسک,मुर्मान्स्क,मूरमान्स्क,მურმანსკი,ムルマンスク,摩爾曼斯克,무르만스크', 68.9791700, 33.0925100, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120385, 'Murino', 'Murino', 'Murino,Muurola,Мурино', 60.0479600, 30.4520400, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120386, 'Murashi', 'Murashi', 'Murashi,Murasji,Мураши', 59.3999000, 48.9615000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120387, 'Muranovo', 'Muranovo', 'Muranovo,Мураново', 56.1833300, 37.9000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120388, 'Mullovka', 'Mullovka', 'Mullovka,Mullovki,Мулловка', 54.2000000, 49.4000000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120389, 'Mulino', 'Mulino', 'Mulina,Mulino,Мулино', 56.2892300, 42.9200500, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120390, 'Mukhtolovo', 'Mukhtolovo', 'Mukhtolovo,Мухтолово', 55.4675100, 43.1997300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120391, 'Mugi', 'Mugi', 'Mugi,Муги', 42.2994400, 47.4207700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120392, 'Muchkapskiy', 'Muchkapskiy', 'Muchkan,Muchkap,Muchkapskij,Muchkapskiy,Mutschap,Mutsjkapskij,Мучкапский', 51.8513300, 42.4717500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120393, 'Mtsensk', 'Mtsensk', 'Gorad Mcehnsk,Mcens''k,Mcensk,Mceńsk,Misensk,Mscenscum,Mtsensk,Mzensk,meuchenseukeu,mtsnsk,mu cen si ke,mutsu~ensuku,Горад Мцэнск,Мтсенск,Мценск,Мценск балһсн,Мценськ,متسنسك,متسنسک,ムツェンスク,姆岑斯克,므첸스크', 53.2765700, 36.5733400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120394, 'Mstikhino', 'Mstikhino', 'Mstikhino,Мстихино', 54.5594700, 36.1277700, 'RU', '2010-08-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120395, 'Mstera', 'Mstera', 'Mstera,Мстера', 56.3788900, 41.9200000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120396, 'Mrakovo', 'Mrakovo', 'Mrakovo,Мраково', 52.7161100, 56.6244400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120397, 'Mozhga', 'Mozhga', 'Krasnyy,Moshga,Mozga,Mozhga,Mozjga,Možga,Syuginskaya,Syuginskiy,Можга', 56.4446900, 52.2276300, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120398, 'Mozhaysk', 'Mozhaysk', 'Gorad Mazhajsk,Mojaisk,Mojajsk,Mojaysk,Mojaïsk,Mosaiscum,Moschaisk,Mozaisk,Mozaiskas,Mozajsk,Mozhaisk,Mozhajsk,Mozhajskaj,Mozhaysk,Mozjajsk,Moĵajsk,Możajsk,Možaisk,Možaiskas,Možajsk,mo zha yi si ke,mojaiseukeu,mojaisuku,mwjaysk,mwzhaysk,mwzhayysk,Горад Мажайск,Можайск,Можайскай,موجايسك,موژائیسک,موژایسک,モジャイスク,莫扎伊斯克,모자이스크', 55.5019400, 36.0272200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120399, 'Mozdok', 'Mozdok', 'Gorad Mazdok,Maezdaeg,Masdok,Mehzdehgu,Mosdok,Mozdok,Mozdoko,mo ci duo ke,mojeudokeu,mozudoku,mwzdwk,Горад Маздок,Мæздæг,Моздок,Моздок балһсн,Мэздэгу,Մոզդոկ,موزدوك,موزدوک,მოზდოკი,モズドク,莫兹多克,모즈도크', 43.7435900, 44.6517700, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120400, 'Mostovskoy', 'Mostovskoy', 'Mostovoye,Mostovskoj,Mostovskoy,Mostovskoye,Мостовской', 44.4122200, 40.7936100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120401, 'Mostishche', 'Mostishche', 'Mostishche,Mostishchi,Mostishhe,Mostisjtsje,Мостище', 56.2912300, 28.7642000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120402, 'Moscow', 'Moscow', 'Gorad Maskva,MOW,Maeskuy,Maskav,Maskava,Maskva,Mat-xco-va,Matxcova,Matxcơva,Mosca,Moscfa,Moscha,Mosco,Moscou,Moscova,Moscovo,Moscow,Moscoƿ,Moscu,Moscua,Moscòu,Moscó,Moscù,Moscú,Mosk"va,Moska,Moskau,Mosko,Moskokh,Moskou,Moskov,Moskova,Moskovu,Moskow,Moskowa,Mosku,Moskuas,Moskva,Moskvo,Moskwa,Moszkva,Muskav,Musko,Mát-xcơ-va,Mòskwa,Məskəү,masko,maskw,mo si ke,moseukeuba,mosko,mosukuwa,mskw,mwskva,mwskw,mwsqbh,mx s ko,Μόσχα,Горад Масква,Мæскуы,Маскав,Москва,Москова,Москох,Москъва,Мускав,Муско,Мәскәү,Մոսկվա,מאָסקװע,מאסקווע,מוסקבה,ماسکو,مسکو,موسكو,موسكۋا,ܡܘܣܩܒܐ,मास्को,मॉस्को,মস্কো,மாஸ்கோ,มอสโก,མོ་སི་ཁོ།,მოსკოვი,ሞስኮ,モスクワ,莫斯科,모스크바', 55.7522200, 37.6155600, 'RU', '2016-04-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120403, 'Moskovskoye', 'Moskovskoye', 'Moskovskaya,Moskovskoe,Moskovskoje,Moskovskoye,Московское', 45.2842000, 41.9103000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120404, 'Moshenskoye', 'Moshenskoye', 'Moshenskoe,Moshenskoye,Mosjenskoje,Nikolo-Moshenskoye,Мошенское', 58.5101600, 34.5910800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120405, 'Mosal’sk', 'Mosal''sk', 'Mosal''sk,Mosalsk,Mosal’sk,Мосальск', 54.4880600, 34.9816700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120406, 'Morshansk', 'Morshansk', 'Morschansk,Morshansk,Morsjansk,Моршанск', 53.4435400, 41.8106500, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120407, 'Morozovsk', 'Morozovsk', 'Gorad Marozausk,Morosowsk,Morosowski,Morosowskij,Morozovs''k,Morozovsk,Morozovskaya,Morozovskiy,Morozowsk,Morózovsk,Mrozowsk,mo luo zuo fu si ke,mwrwzwfsk,Горад Марозаўск,Морозовск,Морозовск балһсн,Морозовськ,Մորոզովսկ,موروزوفسك,موروزوفسک,莫羅佐夫斯克', 48.3550200, 41.8262700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120408, 'Morki', 'Morki', 'Morki,Морки', 56.4302800, 48.9947200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120409, 'Morgaushi', 'Morgaushi', 'Morgaushi,Morgausji,Моргауши', 55.9643000, 46.7743000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120410, 'Mordovo', 'Mordovo', 'Mordovo,Murdovo,Мордово', 52.0834000, 40.7700000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120411, 'Mordino', 'Mordino', 'Mordino,Мордино', 61.3532700, 51.8957400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120412, 'Monino', 'Monino', 'Monin,Monino,Монино', 55.8424400, 38.1936200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120413, 'Monchegorsk', 'Monchegorsk', 'Gorad Manchagorsk,Moncegorsk,Moncegorskas,Moncegorski,Monceqorsk,Moncha Guba,Monchagorsk,Monchegors''k,Monchegorsk,Monczegorsk,Montchegorsk,Montjegorsk,Montschegorsk,Montsegorsk,Montsjegorsk,Montxegorsk,Montšegorsk,Monçeqorsk,Monĉegorsk,Mončegorsk,Mončegorskas,Mončegorski,meng qie ge er si ke,monchegoleuseukeu,monchegorusuku,mwnchgwrsk,mwnchygwrsk,mwntshyghwrsk,Горад Манчагорск,Мончегорск,Мончегорськ,مونتشيغورسك,مونچگورسک,مونچیگورسک,モンチェゴルスク,蒙切戈爾斯克,몬체고르스크', 67.9397200, 32.8738900, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120414, 'Monastyrshchina', 'Monastyrshchina', 'Monastirshchina,Monastyrshchina,Monastyrshhina,Monastyrsjtsjina,Монастырщина', 54.3496100, 31.8379500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120415, 'Molokovo', 'Molokovo', 'Molokovo,Молоково', 58.1661100, 36.7627800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120416, 'Molokovo', 'Molokovo', 'Irininskoye,Molokovo,Молоково', 55.5618600, 37.8649200, 'RU', '2013-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120417, 'Molodezhnoye', 'Molodezhnoye', 'Meccaekylae,Metsaekylae,Metsyakyulya,Metsäkylä,Meččäkylä,Molodezhnoye,Molodezjnoje,Molodjozhnoe,Molodëzhnoye,Myatsyakyulya,Молодёжное', 60.1980300, 29.5159700, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120418, 'Molochnoye', 'Molochnoye', 'Molochnoe,Molochnoye,Molotsjnoje,Молочное', 59.2916600, 39.6786800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120419, 'Mokshan', 'Mokshan', 'Mokshan,Moksjan,Мокшан', 53.4365000, 44.6132200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120420, 'Mokrous', 'Mokrous', 'Mokrous,Мокроус', 51.2373000, 47.5137000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120421, 'Mochalishche', 'Mochalishche', 'Mochalishche,Mochalishhe,Motsjalisjtsje,Мочалище', 56.3306000, 48.3547000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120422, 'Mshinskaya', 'Mshinskaya', 'Mshinskaja,Мшинская', 59.0150000, 29.9433300, 'RU', '2010-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120423, 'Mizur', 'Mizur', 'Mizur,Mizurskiy,Мизур', 42.8537600, 44.0639300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120424, 'Mitrofanovka', 'Mitrofanovka', 'Mitrofanovka,Митрофановка', 49.9708300, 39.6938900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120425, 'Miskindzha', 'Miskindzha', 'Miskidzha,Miskindzha,Miskindzhi,Мискинджа,Мискинджи', 41.4240200, 47.8466900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120426, 'Mishkino', 'Mishkino', 'Mishkino,Мишкино', 53.9997000, 59.1064000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120427, 'Misheronskiy', 'Misheronskiy', 'Misherevki,Misheronskij,Misheronskiy,Misjeronskij,Мишеронский', 55.7192700, 39.7383500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120428, 'Mirskoy', 'Mirskoy', 'Imeni Kaganovicha,Mirskoj,Mirskoy,Мирской', 45.5439000, 40.3998000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120429, 'Mirnyy', 'Mirnyy', 'Mirnyj,Mirnyy,Мирный', 61.3328900, 44.5359800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120430, 'Mirnyy', 'Mirnyy', 'Mirnyj,Mirnyy,Мирный', 58.4933300, 47.6538900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120431, 'Mirnyy', 'Mirnyy', 'Mirnyj,Mirnyy,Мирный', 54.3660700, 48.7293900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120432, 'Mirnyy', 'Mirnyy', 'Mirnyj,Mirnyy,Мирный', 53.5064200, 50.2765800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120433, 'Mineralnye Vody', 'Mineralnye Vody', 'Gorad Mineral''nyja Vody,MRV,Mineral Waters,Mineral''ni Vodi,Mineral''nye Vody,Mineral''nyye Vody,Mineralized Veded,Mineraližed Veded,Mineralne Wody,Mineralnie Vodi,Mineralnie Vody,Mineralnie vodi,Mineralnije Vodi,Mineralniye Vodi,Mineralnoje Vodo,Mineralnye Vody,Mineralnyje Vody,Mineralnyje Wody,Mineralnyye Vody,Mineralnîe Vodî,Mineralnõje Vodõ,Mineralnıye Vodı,Mineral’nyye Vody,Minjeralnyje Wody,Minvod,kuang shui cheng,minelalniyebodi,minerarinu~ie・vu~odo~i,mnralny fwdy,mynralnyh wwdy,mynrlnyyh wwdy,mynyralnayy fwdy,Горад Мінеральныя Воды,Минвод,Минералние води,Минералније Води,Минеральные Воды,Минеральные Воды балһсн,Мінеральні Води,Միներալնիե Վոդի,מינרלנייה וודי,منرالني فودي,منرالنیئے وودی,مينيرالنايي فودي,مینرالنیه وودی,ミネラーリヌィエ・ヴォードィ,礦水城,미네랄니예보디', 44.2102800, 43.1352800, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120434, 'Mindyak', 'Mindyak', 'Mindjak,Mindyak,Миндяк', 54.0231000, 58.7891000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120435, 'Milyutinskaya', 'Milyutinskaya', 'Miljutinskaja,Milyutinskaya,Милютинская', 48.6278800, 41.6678800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120436, 'Miloslavskoye', 'Miloslavskoye', 'Miloslavskoe,Miloslavskoje,Miloslavskoye,Милославское', 53.5815200, 39.4399200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120437, 'Millerovo', 'Millerovo', 'Gorad Milerava,Milerovo,Millerovo,Millerowo,mi lie luo wo,millelobo,mylrwfw,mylyrwfw,Горад Мілерава,Милерово,Миллерово,Миллерово балһсн,Міллерово,Միլլերովո,ميليروفو,میلروفو,米列羅沃,밀레로보', 48.9226500, 40.3967300, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120438, 'Mikun’', 'Mikun''', 'Mikun,Mikun'',Mikun’,Микунь', 62.3547200, 50.0771400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120439, 'Mikulino', 'Mikulino', 'Mikulino,Mikulino-Gorodischtsche,Mikulino-Gorodishche,Mikulino-Nagornoye,Микулино', 56.4518800, 35.6068500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120440, 'Mikhnëvo', 'Mikhnevo', 'Mikhnevo,Mikhnjovo,Mikhnëvo,Михнево,Михнёво', 55.1274700, 37.9545100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120441, 'Mikhnëvo', 'Mikhnevo', 'Mikhievo,Mikhnevo,Mikhnjovo,Mikhnëvo,Михнево,Михнёво', 55.1339600, 37.9442500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120442, 'Mikhaylovskoye', 'Mikhaylovskoye', 'Mikhajlovskoe,Mikhaylovskaya,Mikhaylovskoye,Михайловское', 43.0997200, 44.6316400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120443, 'Mikhaylovskaya', 'Mikhaylovskaya', 'Mikhajlovskaja,Mikhaylovskaya,Mikhaylovskoye,Михайловская', 44.9947200, 40.5963900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120444, 'Mikhaylovsk', 'Mikhaylovsk', 'Mikhajlovsk,Mikhalovskiy,Mikhaylovka,Mikhaylovsk,Mikhaylovskiy,Михайловск', 56.4358300, 59.1200000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120445, 'Mikhaylovka', 'Mikhaylovka', 'Mikhajlovka,Mikhaylovka,Михайловка', 54.8050000, 55.8919300, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120446, 'Mikhaylovka', 'Mikhaylovka', 'Mikhailovka,Mikhajlovka,Mikhaylovka,Михайловка', 52.2317000, 35.3767000, 'RU', '2013-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120447, 'Mikhaylovka', 'Mikhaylovka', 'Gorad Mikhajlauka,Michailowka,Michajlovka,Michajlowka,Michajłowka,Michalowka,Mihailovk,Mihailovka,Mihajlovka,Mihhailovka,Mikhailovka,Mikhajlovka,Mikhaylovka,Mikhaïlovka,Miĥajlovka,mi ha yi luo fu ka,mykhaylwfka,mykhayylwfka  awblast wlgwgrad,mykhayylwka,Горад Міхайлаўка,Михайловка,Михайловка балһсн,Михајловка,ميخايلوفكا,میخائیلوفکا، اوبلاست ولگوگراد,میخائیلوکا,米哈伊洛夫卡', 50.0600000, 43.2379000, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120448, 'Mikhaylov', 'Mikhaylov', 'Mikhailov,Mikhajlov,Mikhaylov,Mizailov,Михайлов', 54.2298000, 39.0269000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120449, 'Mikhalkovo', 'Mikhalkovo', 'Mikhalkovo,Михалково', 55.6833300, 37.4333300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120450, 'Michurinskoye', 'Michurinskoye', 'Michurinskoe,Michurinskoye,Mitsjurinskoje,Valk"yarvi,Valkjaervi,Valkjärvi,Valkujarvi,Valk”yarvi,Валкъярви,Мичуринское', 60.5642000, 29.8623200, 'RU', '2016-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120451, 'Michurinsk', 'Michurinsk', 'Gorad Michurynsk,Koslov,Kozlov,Michurins''k,Michurinsk,Michúrinsk,Miciurinsk,Micurinsk,Miczurynsk,Miczuryńsk,Mitchourinsk,Mitjurinsk,Mitschurinsk,Mitschurnisk,Mitsjoerinsk,Mitsjurinsk,Mitsurinsk,Mitxurinsk,Mitxúrinsk,Mitšurinsk,Miçurinsk,Miĉurinsk,Mičurinsk,mi qiu lin si ke,michulinseukeu,michurinsuku,mychwrnsk,mychwrynsk,mytshwrynsk,Горад Мічурынск,Мичуринск,Мічурінськ,ميتشورينسك,میچورنسک,میچورینسک,ミチュリンスク,米丘林斯克,미추린스크', 52.8978000, 40.4907000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120452, 'Miatli', 'Miatli', 'Miatli,Miatly,Miyatly,Staroye-Miatli,Миатли', 43.0817300, 46.8286000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120453, 'Mglin', 'Mglin', 'Gorad Mglin,Mglin,Mglina,Mgline,Mgļina,meugeullin,mghlyn,mglyn,mu ge lin,mugurin,Горад Мглін,Мглин,Мглин балһсн,מגלין,مغلين,مگلین,ムグリン,姆格林,므글린', 53.0590700, 32.8475300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120454, 'Mga', 'Mga', 'Mga,Muja,Namkku,mgha,Мга,Մգա,مغا', 59.7500000, 31.0666700, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120455, 'Mezinovskiy', 'Mezinovskiy', 'Mezinovskij,Mezinovskiy,Poselok Mezinovka,Posëlok Mezinovka,Мезиновский', 55.5042000, 40.3593200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120456, 'Mezhevoy', 'Mezhevoy', 'Mezhevoj,Mezhevoy,Suleja,Suleya,Межевой,Сулея', 55.1711100, 58.7813900, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120457, 'Mezhdurechensk', 'Mezhdurechensk', 'Mezhdurechensk,Междуреченск', 63.2455600, 48.5533300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120458, 'Mezhdurechensk', 'Mezhdurechensk', 'Mezhdurechensk,Mezjduretsjensk,Междуреченск', 53.2665000, 49.1116000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120459, 'Mezen’', 'Mezen''', 'Mezen,Mezen'',Mezen’,Мезень', 65.8401000, 44.2542000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120460, 'Metallostroy', 'Metallostroy', 'Metallostroi,Metallostroj,Metallostroy,Металлострой', 59.8008300, 30.5477800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120461, 'Mesyagutovo', 'Mesyagutovo', 'Mesiagutovo,Mesjagutovo,Mesyagutovo,Месягутово', 55.5302800, 58.2527800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120462, 'Mesker-Yurt', 'Mesker-Yurt', 'Meskar-Ehvl,Meskar-Evl,Mesker-Ehvla,Mesker-Evla,Mesker-Jurt,Mesker-Yurt,Rubezhnoe,Rubezhnoye,Rubeƶnoe,Мескар-Эвл,Мескер-Эвла,Мескер-Юрт,Рубежное', 43.2514700, 45.9071600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120463, 'Meshchovsk', 'Meshchovsk', 'Mechtchovsk,Meschtschowsk,Mescovsk,Meshchovsk,Meshhovs''k,Meshhovsk,Meshovsk,Mesjtsjovsk,Mestsovsk,Meŝĉovsk,Meštšovsk,Meščovsk,Mieszczowsk,Mjescowsk,Mješćowsk,mei xiao fu si ke,meshichofusuku,mesyobseukeu,mshchwfsk,myshtshwfsk,Мешовск,Мешчовск,Мещовск,Мещовськ,مشچوفسک,ميشتشوفسك,メシチョフスク,梅曉夫斯克,메숍스크', 54.3244400, 35.2808300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120464, 'Meshcherino', 'Meshcherino', 'Meshcherino,Meshherino,Mesjtsjerino,Мещерино', 55.1956700, 38.3600200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120465, 'Menzelinsk', 'Menzelinsk', 'Gorad Mjanzelinsk,Menselinsk,Menzela,Menzelinsk,Mienzielinsk,Minzele,Minzələ,menjellinseukeu,menzerinsuku,mian ze lin si ke,mnzlynsk,mnzylynsk,Горад Мянзелінск,Мензела,Мензелинск,Минзәлә,منزلینسک,منزيلينسك,メンゼリンスク,緬澤林斯克,멘젤린스크', 55.7270600, 53.1025800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120466, 'Mendeleyevskiy', 'Mendeleyevskiy', 'Mendeleevskij,Mendelejevskij,Mendeleyevskiy,Poselok Mendeleyevskiy,Posëlok Mendeleyevskiy,Менделеевский', 54.1374500, 37.5874200, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120467, 'Mendeleyevsk', 'Mendeleyevsk', 'Bondyushskiy Zavod,Bondyuzhski Zavod,Bondyuzhskiy,Bondyuzhskiy Zavod,Mendeleevsk,Mendelejevsk,Mendeleyevsk,Менделеевск', 55.9081900, 52.2904700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120468, 'Mendeleyevo', 'Mendeleyevo', 'Mendeleevo,Mendelejevo,Mendeleyevo,Менделеево', 58.1697600, 54.9963400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120469, 'Mendeleyevo', 'Mendeleyevo', 'Mendeleevo,Mendelejevo,Mendeleyevo,Менделеево', 56.0333300, 37.2166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120470, 'Melikhovo', 'Melikhovo', 'Melekhovo,Melikhovo,Мелихово', 55.1144000, 37.6482700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120471, 'Meleuz', 'Meleuz', 'Gorad Meljauz,Meleouz,Meleus,Meleuz,Mieleuz,mei lie wu zi,mlywz,mylywz,Горад Меляўз,Мелеуз,Мәләвез,Мәләүез,ملئوز,مليوز,میلیؤز,梅列烏茲', 52.9646700, 55.9327700, 'RU', '2013-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120472, 'Melenki', 'Melenki', 'Gorad Melenki,Melenkad,Melenki,Mielenki,Mjelenki,mei lian ji,mellenki,merenki,mlnky,mlynky,Горад Меленкі,Меленки,ملنکی,ملينكي,メレンキ,梅連基,멜렌키', 55.3343000, 41.6295000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120473, 'Melikhovskaya', 'Melikhovskaya', 'Melekhovskaya,Melikhovskaja,Melikhovskaya,Мелиховская', 47.4810600, 40.4866900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120474, 'Melekhovo', 'Melekhovo', 'Melekhova,Melekhovo,Мелехово', 56.2773000, 41.2934600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120475, 'Medyn’', 'Medyn''', 'Medin,Medyn,Medyn'',Medyn’,Медынь', 54.9691700, 35.8586100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120476, 'Medvezh’yegorsk', 'Medvezh''yegorsk', 'Karhumaegi,Karhumaeki,Karhumägi,Karhumäki,Kondimaegi,Kondimägi,Medvesh''va Gora,Medvesh’va Gora,Medvezh''egorsk,Medvezh''yegorsk,Medvezhegorsk,Medvezhogorsk,Medvezhya Gora,Medvezh’yegorsk,Medvezjegorsk,Medweshegorsk,Медвежьегорск', 62.9171300, 34.4568900, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120477, 'Medvezh’i Ozëra', 'Medvezh''i Ozera', 'Medvezh''i Ozera,Medvezh''i Ozjora,Medvezh''l Ozera,Medvezh’i Ozëra,Medvezh’l Ozera,Медвежьи Озёра', 55.8693500, 37.9861300, 'RU', '2014-11-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120478, 'Medvedovskaya', 'Medvedovskaya', 'Medvedevskaya,Medvedovskaja,Medvedovskaya,Medvyedovskaya,Медведовская', 45.4515100, 39.0248500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120479, 'Medvedok', 'Medvedok', 'Medvedka,Medvedok,Медведок', 57.3891300, 50.0351000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120480, 'Medveditskiy', 'Medveditskiy', 'Medvedickij,Medveditskij,Medveditskiy,Медведитский,Медведицкий', 50.7852100, 44.7128700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120481, 'Medvedevo', 'Medvedevo', 'Maskasola,Medvedevo,Маскасола,Медведево', 56.6338800, 47.8040500, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120482, 'Mednogorsk', 'Mednogorsk', 'Gorad Mednagorsk,Mednogorsk,Mednoqorsk,Miednogorsk,Mjednogorsk,mdnwghwrsk,mdnwgwrsk,mei de nuo ge er si ke,Горад Меднагорск,Медногорск,مدنوغورسك,مدنوگورسک,梅德諾戈爾斯克', 51.4128000, 57.5950000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120483, 'Mechetinskaya', 'Mechetinskaya', 'Mechetinskaja,Mechetinskaya,Metschetinskaja,Metsjetinskaja,Мечетинская', 46.7713000, 40.4559700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120484, 'Mayskoye', 'Mayskoye', 'Majskoe,Majskoje,Mayskiy,Mayskoye,Pervomayskiy,Майское', 52.2724400, 50.0338300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120485, 'Mayskiy', 'Mayskiy', 'Devyatogo Maya,Majskij,Mayskiy,Майский', 53.9621600, 38.2116500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120486, 'Mayskiy', 'Mayskiy', 'Majskij,Mayskiy,Майский', 50.5198800, 36.4587800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120487, 'Mayskiy', 'Mayskiy', 'Majskij,Mayskiy,Майский', 47.6960000, 40.1025900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120488, 'Mayskiy', 'Mayskiy', 'Majskij,Mayskiy,Mayskoye,Майский', 43.6414000, 44.0385100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120489, 'Mayrtup', 'Mayrtup', 'Majrtup,Mayortun,Mayrtun,Mayrtup,Sulebkent,Майртуп,Сулебкент', 43.2034800, 46.1321500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120490, 'Mayna', 'Mayna', 'Majna,Mayna,Майна', 54.1135000, 47.6231000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120491, 'Maykor', 'Maykor', 'Majkor,Maykor,Maykorskiy,Майкор', 59.0047000, 55.8784000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120492, 'Maykopskoye', 'Maykopskoye', 'Majkopskoe,Majkopskoje,Maykopskiy,Maykopskoye,Майкопское', 45.3936100, 40.7658300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120493, 'Maykop', 'Maykop', 'Maikop,Maikopas,Majkop,Majkopo,Majkuop,Maykop,Maïkop,Myekuuapeh,maikopeu,maikopu,myyqwp,Майкоп,Майкъоп,Мајкоп,Мыекъуапэ,מייקופ,マイコープ,마이코프', 44.6077800, 40.1058300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120494, 'Mayachnyy', 'Mayachnyy', 'Majachnyj,Majatsjnyj,Mayachnyy,Маячный', 52.6839000, 55.6850000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120495, 'Matyushkino', 'Matyushkino', 'Matjushkino,Matjusjkino,Matyushino,Matyushkino,Матюшкино', 56.8632500, 28.6250800, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120496, 'Matveyevskoye', 'Matveyevskoye', 'Matveevskoe,Matveyevskoye,Матвеевское', 55.7111200, 37.4750200, 'RU', '2017-03-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120497, 'Matveyev Kurgan', 'Matveyev Kurgan', 'Matveev Kurgan,Matvejev Kurgan,Matveyev Kurgan,Matveyev-Kurgah,Matwejew-Kurgan,Motveyev Kurgan,Матвеев Курган', 47.5645000, 38.8694700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120498, 'Matveyevka', 'Matveyevka', 'Matveevka,Matveyevka,Matveyevskiy,Матвеевка', 52.1500000, 56.1833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120499, 'Matrosy', 'Matrosy', 'Matrosi,Matrossa,Matrossu,Matrosy,Матросы', 61.7804200, 33.8128300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120500, 'Maslovka', 'Maslovka', 'Maslovka,Масловка', 51.5534600, 39.2357300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120501, 'Maslova Pristan’', 'Maslova Pristan''', 'Maslova,Maslova Pristan'',Maslova Pristan’,Maslova-Pristan,Маслова Пристань', 50.4587400, 36.7408100, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120502, 'Maromitsa', 'Maromitsa', 'Maromica,Maromitsa,Маромица', 59.8682800, 48.0122700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120503, 'Marks', 'Marks', 'Baronsk,Gorad Marks,Marks,Marksshtadt,Marksstadt,Marx,Yekaterinenshtadt,ma ke si zhen,marks,marks  rwsyh,Горад Маркс,Маркс,Маркс балһсн,ماركس,مارکس، روسیه,馬克思鎮', 51.7111100, 46.7486100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120504, 'Markovo', 'Markovo', 'Markov,Markovo,Markovo-Sbornoye,Марково', 57.0185000, 40.4946500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120505, 'Mari-Turek', 'Mari-Turek', 'Mari-Turek,Мари-Турек', 56.7894600, 49.6234900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120506, 'Mar’ino', 'Mar''ino', 'Mar''ina,Mar''ino,Mar’ina,Mar’ino,Марьино', 55.6500000, 37.7166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120507, 'Mariinskiy Posad', 'Mariinskiy Posad', 'Mariinskij Posad,Mariinskiy Posad,Мариинский Посад', 56.1149700, 47.7180500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120508, 'Marfino', 'Marfino', 'Marfino,Марфино', 56.0723700, 37.5589900, 'RU', '2016-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120509, 'Marfino', 'Marfino', 'Marfino,Марфино', 55.7026700, 37.3832200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120510, 'Marfino', 'Marfino', 'Marfino,Марфино', 46.4085200, 48.7139800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120511, 'Marevo', 'Marevo', 'Marevo,Марево', 57.3146100, 32.0804500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120512, 'Manturovo', 'Manturovo', 'Mantourovo,Manturovo,Manturowo,Mànturovo,Mánturovo,man tu luo wo,manto~urovu~o,mantrwfw,mantulobo,mantyrwfw,Мантурово,مانتروفو,مانتيروفو,マントゥロヴォ,曼圖羅沃,만투로보', 58.3288900, 44.7640600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120513, 'Manturovo', 'Manturovo', 'Manturovo,Мантурово', 51.4547000, 37.1282000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120514, 'Manaskent', 'Manaskent', 'Manaskent,Manass-Kent,Манаскент', 42.7402000, 47.6914000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120515, 'Manas', 'Manas', 'Manas,Manaskent,Манас,Манаскент', 42.7274900, 47.6784600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120516, 'Mamontovka', 'Mamontovka', 'Mamontovka,Мамонтовка', 55.9808300, 37.8197200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120517, 'Mamedkala', 'Mamedkala', 'Khan-Mamed-Kala,Mamedkala,Мамедкала', 42.1677300, 48.1198800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120518, 'Mamadysh', 'Mamadysh', 'Gorad Mamadysh,Mamadis,Mamadish,Mamadix,Mamadiŝ,Mamadiš,Mamadych,Mamadys,Mamadysch,Mamadysh,Mamadysj,Mamadyš,Mamadış,Mamatash,ma ma de shen,mamadishu,mamadisi,mamadysh,Горад Мамадыш,Мамадиш,Мамадыш,Маматăш,ماماديش,مامادیش,ママディシュ,馬馬德什,마마디시', 55.7152500, 51.4079700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120519, 'Yaroslavskiy', 'Yaroslavskiy', 'Jaroslavskij,Malyye Mytishchi,Yaroslavskiy,Ярославский', 55.8833300, 37.7166700, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120520, 'Malyye Derbety', 'Malyye Derbety', 'Malye Derbety,Malyye Derbety,Малые Дербеты', 47.9547200, 44.6808300, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120521, 'Malyshevo', 'Malyshevo', 'Malyshevo,Малышево', 55.4945000, 38.3535600, 'RU', '2014-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120522, 'Maloye Verevo', 'Maloye Verevo', 'Maloe Verevo,Maloje Verevo,Maloye Verevo,Pieni-Verevae,Pieni-Verevä,Малое Верево', 59.6136100, 30.1727800, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120523, 'Maloyaroslavets', 'Maloyaroslavets', 'Gorad Malajaraslavec,Maloiaroslavets,Malojaroslavec,Malojaroslavets,Malojaroslawez,Malojaroslawiec,Malojaroslawjec,Maloyaroslavets,Maloïaroslavets,Małojarosławiec,malloyaloseullabecheu,malwyarwslawts,malwyarwslfts,maroyarosuravu~etsu,xiao ya luo si la fu wei ci,Горад Малаяраславец,Малоярославетс,Малоярославец,Малојарославец,Մալոյարոսլավեց,مالوياروسلفتس,مالویاروسلاوتس,マロヤロスラヴェツ,小雅羅斯拉夫韋茨,말로야로슬라베츠', 55.0145700, 36.4718500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120524, 'Maloarkhangel’sk', 'Maloarkhangel''sk', 'Maloarkhangel''sk,Maloarkhangelsk,Maloarkhangel’sk,Малоархангельск', 52.4002400, 36.5033200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120525, 'Malmyzh', 'Malmyzh', 'Malmyzh,Malmyzj,Малмыж', 56.5205000, 50.6818000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120526, 'Malka', 'Malka', 'Ashabovo,Malka,Малка', 43.8038900, 43.3241700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120527, 'Malino', 'Malino', 'Malino,Малино', 55.1119500, 38.1738400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120528, 'Malgobek', 'Malgobek', 'Gorad Malgabek,Maelguaevaeg,Malgobek,Malgobeko,Malgobjek,Malgobək,Malkhabek,Małgobek,Mehlguehbehg,ma er ge bie ke,malghwbk,malgobeg,malgwbk,marugobeku,Горад Малгабек,Мæлгъæвæг,Малгобек,Малгобек балһсн,Малгобәк,Малхабек,Мэлгъэбэг,مالغوبك,مالگوبک,マルゴベク,馬爾戈別克,말고벡', 43.5111800, 44.5882100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120529, 'Malaya Vishera', 'Malaya Vishera', 'Malaia Vichera,Malaja Vishera,Malaja Visjera,Malaja Wischera,Malaya Vishera,Малая Вишера', 58.8453800, 32.2221800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120530, 'Malaya Serdoba', 'Malaya Serdoba', 'Mal.Serdoba,Malaja Serdoba,Malaya Serdoba,Мал.Сердоба,Малая Сердоба', 52.4661000, 44.9512000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120531, 'Malaya Purga', 'Malaya Purga', 'Malaja Purga,Malaya Purga,Pichi Purga,Малая Пурга,Пичи Пурга', 56.5566600, 53.0043400, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120532, 'Malaya Dubna', 'Malaya Dubna', 'Dubna,Mal.Dubna,Malaja Dubna,Malaya Dubna,Мал.Дубна,Малая Дубна', 55.8778300, 38.9542300, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120533, 'Malakhovka', 'Malakhovka', 'Malakhovka,Малаховка', 55.6477600, 38.0248600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120534, 'Makushino', 'Makushino', 'Makushino,Makusjino,Макушино', 56.6880200, 28.4720700, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120535, 'Maksatikha', 'Maksatikha', 'Maksatikha,Максатиха', 57.7969500, 35.8825400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120536, 'Makhalino', 'Makhalino', 'Makhalino,Novyy Kryazhim,Махалино', 53.0854300, 46.2210800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120537, 'Makhachkala', 'Makhachkala', 'Anzhi,GIjanzhi-Kuala,MCX,Machackala,Machaczkala,Machaczkała,Machatjkala,Machatsch-Kala,Machatschkala,Machatsjkala,Machačkala,Mag''achkuala,Mahackala,Mahackalao,Mahacqala,Mahatskala,Mahatškala,Mahaçqala,Mahačkala,Mahhatskala,Mahhatškala,MakhIachkhuala,Makhachkala,Makhatchkala,Makhatsjkala,Makhatxkala,Makhatxkalà,Maĥaĉkalao,Petrovsk,Petrovsk-Port,mahachikalla,mahachikara,mhzqlh,Анжи,ГIянжи-Къала,Магьачкъала,МахIачхъала,МахІачхъала,Махачкала,מחצקלה,マハチカラ,마하치칼라', 42.9763800, 47.5023600, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120538, 'Makar’yev', 'Makar''yev', 'Makar''ev,Makar''yev,Makarjev,Makarowo,Makar’yev,Макарьев', 57.8850100, 43.8049000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120539, 'Magnitogorsk', 'Magnitogorsk', 'Gorad Magnitagorsk,MQF,Magnetogorsk,Magnitogors''k,Magnitogorsk,Magnitogorska,Magnitogorskas,Magņitogorska,Manknitonkorsk,ma ge ni tuo ge er si ke,mageunitogoleuseukeu,magnytwgwrsk,magunitogorusuku,mak ni to kxskh,mghnytaghwrsk,mgnytwgwrsq,Μαγκνιτογκόρσκ,Горад Магнітагорск,Магнитогорск,Магнітогорськ,Մագնիտոգորսկ,מגניטוגורסק,ماگنیتوگورسک,ماگنیٹوگورس,مغنيتاغورسك,มักนีโตกอสค์,マグニトゴルスク,马格尼托哥尔斯克,마그니토고르스크', 53.4186100, 59.0472200, 'RU', '2012-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120540, 'Magnitka', 'Magnitka', 'Magnitka,Titanogorsk,Магнитка', 55.3475000, 59.6961100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120541, 'Maginsk', 'Maginsk', 'Maginsk,Магинск', 55.7633800, 56.9658300, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120542, 'Magaramkent', 'Magaramkent', 'Magaramkent,Maharamkand,Məhərəmkənd,Магарамкент', 41.6158600, 48.3479700, 'RU', '2013-10-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120543, 'Madzhalis', 'Madzhalis', 'Madzhales,Madzhalis,Madzjalis,Маджалис', 42.1216700, 47.8333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120544, 'Lyudinovo', 'Lyudinovo', 'Ljudinovo,Lyudinovo,Людиново', 53.8663900, 34.4477800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120545, 'Lyubytino', 'Lyubytino', 'Beloye,Ljubytino,Lyubytino,Любытино', 58.8122200, 33.3922200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120546, 'Lyubuchany', 'Lyubuchany', 'Ljubuchany,Ljubutsjany,Lyubuchany,Любучаны', 55.2508800, 37.5498800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120547, 'Lyubovsho', 'Lyubovsho', 'Ljubovsho,Ljubovsja,Lyubavsho,Lyubovsha,Lyubovsho,Любовшо', 52.9851000, 31.5422000, 'RU', '2014-09-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120548, 'Lyubokhna', 'Lyubokhna', 'Ljubokhna,Lyubokhna,Любохна', 53.5033200, 34.3884700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120549, 'Lyublino', 'Lyublino', 'Ljublino,Lublino,Lyublino,Lyublino-Dachnoye,Люблино', 55.6792300, 37.7525000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120550, 'Lyubim', 'Lyubim', 'Ljubim,Lyubim,Любим', 58.3625000, 40.6843300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120551, 'Lyubertsy', 'Lyubertsy', 'Gorad Ljubercy,Lioubertsy,Liubercai,Liuberti,Liubertsi,Liubertsy,Liuberțî,Liúbertsy,Ljoebertsy,Ljuberci,Ljubercy,Ljubertso,Ljubertsy,Ljubertsõ,Ljuberzy,Luberci,Lubertsi,Lubiercy,Lyubertsi,Lyubertsy,Lyubertsı,liu bie er qi,liubertsi,lyubeleuchi,lywbartsy,lywbrtsy,lywbyrtsy,ryuberutsu~i,Ļuberci,Љуберци,Горад Люберцы,Люберци,Люберцы,Люберці,ليوبارتسي,لیوبرتسی,لیوبیرتسی,ლიუბერცი,リュベルツィ,柳別爾齊,류베르치', 55.6771900, 37.8932200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120552, 'Lyuban’', 'Lyuban''', 'Ljuban,Ljuban'',Lyuban'',Lyuban’,Любань', 59.3500000, 31.2166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120553, 'Lytkarino', 'Lytkarino', 'Gorad Lytkaryna,Litkarino,Lytkarino,Lytkorino,Lîtkarino,Lıtkarino,lei te ka li nuo,lytkarynw,lytkrynw,Łytkarino,Горад Лыткарына,Литкарино,Литкаріно,Лыткарино,Лыткарино балһсн,ليتكرينو,لیتکارینو,雷特卡里諾', 55.5827100, 37.9051600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120554, 'Lysyye Gory', 'Lysyye Gory', 'Lisiya Gori,Lysye Gory,Lysyye Gory,Лысые Горы', 51.5506300, 44.8414400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120555, 'Lys’va', 'Lys''va', 'Lys''va,Lysva,Lys’va,Лысьва', 58.1086100, 57.8052800, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120556, 'Lysogorskaya', 'Lysogorskaya', 'Lysagorskaya,Lysogorskaja,Lysogorskaya,Лысогорская', 44.1063900, 43.2755600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120557, 'Lyskovo', 'Lyskovo', 'Gorad Lyskava,Liskovo,Lyskovo,Lyskowo,Sendevud,lei si ke wo,lyskwfw,Горад Лыскава,Лисково,Лысково,Сендевӱд,ليسكوفو,لیسکوفو,雷斯科沃', 56.0328200, 45.0422000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120558, 'Lyaskelya', 'Lyaskelya', 'Laeskelae,Ljaskelja,Lyaskelya,Läskelä,Ляскеля', 61.7632200, 31.0061600, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120559, 'Lyangasovo', 'Lyangasovo', 'Ljangasovo,Lyangasovo,Лянгасово', 58.5175900, 49.4471800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120560, 'Lyamino', 'Lyamino', 'Ljamino,Lyamino,Лямино', 58.2839000, 57.7250000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120561, 'Lyambir’', 'Lyambir''', 'Ljambir,Ljambir'',Lyambir'',Lyambir’,Лямбирь', 54.2817200, 45.1249400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120562, 'L’vovskiy', 'L''vovskiy', 'L''vovskaya,L''vovskij,L''vovskiy,L''vovskoye,Lvovskij,L’vovskaya,L’vovskiy,L’vovskoye,Львовский', 55.3187200, 37.5233700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120563, 'Luzhniki', 'Luzhniki', 'Luzhniki,Лужники', 55.7159900, 37.5537600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120564, 'Luza', 'Luza', 'Luza,Луза', 60.6308100, 47.2511800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120565, 'Luppolovo', 'Luppolovo', 'Luppolovo,Luuppola,Лупполово', 60.1540200, 30.2803400, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120566, 'Lunino', 'Lunino', 'Lunino,Лунино', 53.5917600, 45.2270900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120567, 'Lukoyanov', 'Lukoyanov', 'Lukojanov,Lukoyanov,Lukozanov,Лукоянов', 55.0277200, 44.4786500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120568, 'Lukovetskiy', 'Lukovetskiy', 'Lukoveckij,Lukovetskij,Lukovetskiy,Луковецкий', 64.2956000, 41.9211000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120569, 'Luknovo', 'Luknovo', 'Luknovo,Лукново', 56.1804500, 42.0398700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120570, 'Lukino', 'Lukino', 'Lukino,Лукино', 56.8593300, 28.4642600, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120571, 'Lukino', 'Lukino', 'Lukino,Лукино', 56.4418300, 43.6293200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120572, 'Lukhovka', 'Lukhovka', 'Lukhovka,Луховка', 54.1484400, 45.2572800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120573, 'Lukhovitsy', 'Lukhovitsy', 'Loukhovitsy,Luchovicy,Luchowicy,Luchowizy,Luhovici,Luhoviti,Luhovitsy,Luhovițî,Lujovitsy,Lukhovici,Lukhovicy,Lukhovitsi,Lukhovitsy,Luxovitsi,Luxovitsı,Luĥovici,lu huo wei qi,luhobichi,lwkhwfaytsy,lwkhwwytsy,ruhovu~itsu~i,Łuchowicy,Луховитси,Луховици,Луховицы,Луховицы балһсн,Луховиці,لوخوفايتسي,لوخوویتسی,ルホヴィツィ,盧霍維齊,루호비치', 54.9766100, 39.0444000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120574, 'Lukh', 'Lukh', 'Lukh,Лух', 57.0124200, 42.2583800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120575, 'Lugovaya', 'Lugovaya', 'Lugovaja,Lugovaya,Lugovoy,Луговая', 56.0500000, 37.4833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120576, 'Luga', 'Luga', 'Gorad Luga,Laukaa,Laukua,Loega,Louga,Luga,Luga i Leningrad oblast,Luqa,lu jia,luga,lwga  awblast lnyngrad,lwgha,ruga,Ługa,Горад Луга,Лоуга · Рѡсїи,Луга,لوغا,لوگا، اوبلاست لنینگراد,ლუგა,ルーガ,盧加,루가', 58.7372200, 29.8452800, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120577, 'Lubyany', 'Lubyany', 'Lubjany,Lubyany,Лубяны', 56.0378000, 51.4000100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120578, 'Lozhki', 'Lozhki', 'Loshki,Lozhki,Lozjki,Ложки', 56.0938700, 37.1087300, 'RU', '2014-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120579, 'Loyga', 'Loyga', 'Lojga,Loyga,Лойга', 61.0784500, 44.6075000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120580, 'Lovozero', 'Lovozero', 'Lovozeras,Lovozero,Lovozerskiy Pogost,Lowosero,Lowozero,Lujavri,Lujavvr,Lujávri,Luovasjaervi,Luovasjärvi,Luujaervi,Luujärvi,Ловозеро,Луяввр', 68.0063800, 35.0158900, 'RU', '2015-01-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120581, 'Loukhi', 'Loukhi', 'Louchi,Louhi,Loukhi,Лоухи', 66.0761600, 33.0474500, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120582, 'Lotoshino', 'Lotoshino', 'Latashino,Lotoshino,Lotosino,Lotosjino,Lotošino,lwtwshynw,Лотошино,لوتوشینو', 56.2348900, 35.6427300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120583, 'Losino-Petrovskiy', 'Losino-Petrovskiy', 'Losino-Petrovskij,Losino-Petrovskiy,Лосино-Петровский', 55.8695900, 38.2006500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120584, 'Losevo', 'Losevo', 'Losevo,Losewo,Лосево', 50.6766700, 40.0450000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120585, 'Lopatinskiy', 'Lopatinskiy', 'Dvoriki,Lopatinskij,Lopatinskiy,Lopatinskiy Rudnik,Лопатинский', 55.3410100, 38.7236600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120586, 'Lopatino', 'Lopatino', 'Lopatino,Лопатино', 52.6194900, 45.8118400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120587, 'Lopandino', 'Lopandino', 'Lopandin,Lopandino,Лопандино', 52.4666000, 34.8163000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120588, 'Lomovka', 'Lomovka', 'Lomovka,Ломовка', 53.9194400, 58.3672200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120589, 'Lomonosov', 'Lomonosov', 'Gorad Lamanosau,Kaarosta,Kuarasta,Kuarašta,Lomonosof,Lomonosov,Lomonosov i Russland,Lomonosov shaary,Lomonosova,Lomonosow,Lomonossov,Lomonossow,Lomonoszov,Lomonósov,Oranienbaum,Oraniyenbaum,lomonosopeu,lomonosovi,luo meng nuo suo fu,lwmwnwswf,romonosofu,Łomonosow,Λομονόσοφ,Горад Ламаносаў,Ломоносов,Ломоносов шаары,لومونوسوف,ლომონოსოვი,ロモノソフ,羅蒙諾索夫,로모노소프', 59.9061200, 29.7725300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120590, 'Lomintsevskiy', 'Lomintsevskiy', 'Lomincevskij,Lomintsevskij,Lomintsevskiy,Ломинцевский', 53.9854800, 37.6647100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120591, 'Lokot’', 'Lokot''', 'Lokot,Lokot'',Lokot’,Локоть', 52.5650000, 34.5776000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120592, 'Loknya', 'Loknya', 'Loknja,Loknya,Локня', 56.8299800, 30.1466500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120593, 'Log', 'Log', 'Log,Logovskiy,Лог', 49.4843700, 43.8612500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120594, 'Lodeynoye Pole', 'Lodeynoye Pole', 'Lodeinoje Pole,Lodejnoe Pole,Lodejnoje Pole,Lodeyana,Lodeynoye Pole,Lotinapelto,Pellonlinna,Лодейное Поле', 60.7260000, 33.5530600, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120595, 'Lobnya', 'Lobnya', 'Krasnaya Polyana,Lobnja,Lobnya,Лобня', 56.0097200, 37.4819400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120596, 'Lobanovo', 'Lobanovo', 'Lobanovo,Лобаново', 57.8595000, 56.3026000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120597, 'Livny', 'Livny', 'Gorad Liuny,Livni,Livno,Livny,Livnî,Livnõ,Liwny,li fu nei,libeuni,lyfny,rivunu~i,Горад Ліўны,Ливни,Ливны,Ливны балһсн,Лівни,ليفني,لیفنی,リーヴヌィ,利夫內,리브니', 52.4253400, 37.6068900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120598, 'Livenka', 'Livenka', 'Livenka,Ливенка', 50.4491000, 38.2959000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120599, 'Liski', 'Liski', 'Georgiu-Dezh,Gorad Liski,Liski,Novopokrovka,Svoboda,li si ji,lysky,Горад Ліскі,Лиски,Лиски балһсн,ليسكي,لیسکی,利斯基', 50.9840500, 39.5154500, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120600, 'Lisiy Nos', 'Lisiy Nos', 'Lisij Nos,Lisiy Nos,Lissijnos,Revonnenae,Revonnenä,Valdimirovka,Vladimirovka,Лисий Нос', 60.0168600, 30.0200800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120601, 'Lipin Bor', 'Lipin Bor', 'Lipin Bor,Липин Бор', 60.2630000, 37.9785000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120602, 'Lipetsk', 'Lipetsk', 'Gorad Lipeck,LPK,Lipec''k,Lipeck,Lipeck shaary,Lipecka,Lipeckas,Lipetk,Lipetsk,Lipezk,Lipețk,Lipieck,Lipjeck,Lípetsk,li pei ci ke,li pet skh,lipecheukeu,lybytsk,lyptsk,ripetsuku,Ļipecka,Горад Ліпецк,Липецк,Липецк балһсн,Липецк шаары,Липецьк,ليبيتسك,لپٹسک,لیپتسک,لیپٹسک,ลีเปตสค์,リペツク,利佩茨克,리페츠크', 52.6031100, 39.5707600, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120603, 'Linda', 'Linda', 'Linda,Линда', 56.6157100, 44.0954400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120604, 'Liman', 'Liman', 'Dolban,Liman,Лиман', 45.7845700, 47.2240500, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120605, 'Likino-Dulevo', 'Likino-Dulevo', 'Dulevo,Likino-Dulevo,Ликино-Дулево', 55.7083000, 38.9542000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120606, 'Likhoy', 'Likhoy', 'Likhoj,Likhoy,Лихой', 48.1266200, 40.2055600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120607, 'Likhovskoy', 'Likhovskoy', 'Lichaja,Likhaya,Likhovskiy,Likhovskoj,Likhovskoy,Likhoy,Лиховской', 48.1518800, 40.1792500, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120608, 'Likhoslavl’', 'Likhoslavl''', 'Likhoslavl,Likhoslavl'',Likhoslavl’,Лихославль', 57.1274700, 35.4640400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120609, 'Likhobory', 'Likhobory', 'Likhobory,Лихоборы', 55.8500000, 37.5666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120610, 'Lianozovo', 'Lianozovo', 'Lianozovo,Lyanosovo,Lyanozovo,Лианозово', 55.8978300, 37.5868000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120611, 'L’govskiy', 'L''govskiy', 'L''gov,L''govskij,L''govskiy,Lgov,L’govskiy,Льгов,Льговский', 51.6306900, 35.2775000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120612, 'Lezhnevo', 'Lezhnevo', 'Lezhnevo,Lezjnevo,Лежнево', 56.7750800, 40.8917400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120613, 'Lev Tolstoy', 'Lev Tolstoy', 'Astapovo,Lev Tolstoi,Lev Tolstoj,Lev Tolstoy,Лев Толстой', 53.2134400, 39.4460400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120614, 'Levokumskoye', 'Levokumskoye', 'Levokumskoe,Levokumskoje,Levokumskoye,Левокумское', 44.8219400, 44.6605600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120615, 'Levokumka', 'Levokumka', 'Levokumka,Levokumskiy,Левокумка', 44.2316700, 43.1500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120616, 'Levikha', 'Levikha', 'Levikha,Левиха', 57.5836100, 59.9002800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120617, 'Levashevo', 'Levashevo', 'Levasheva,Levashevo,Levashovo,Levasjovo,Левашово', 57.6445100, 40.5240100, 'RU', '2015-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120618, 'Levashi', 'Levashi', 'Levashi,Levasji,Леваши', 42.4303600, 47.3214800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120619, 'Levashovo', 'Levashovo', 'Levashevo,Levashovo,Levasjovo,Levassova,Levaššova,Levshovo,Lewaschewo,Левашово', 60.1036900, 30.2068300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120620, 'Letnyaya Stavka', 'Letnyaya Stavka', 'Letnjaja Stavka,Letnyaya Stavka,Летняя Ставка', 45.4305600, 43.4472200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120621, 'Letnik', 'Letnik', 'Letnik,Letniki,Letnitskoye,Letnytskoye,Летник', 46.0110000, 41.2657000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120622, 'Letka', 'Letka', 'Letka,Летка', 59.6011100, 49.4232100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120623, 'Lesogorskiy', 'Lesogorskiy', 'Iaski,Jaaski,Jaeaeski,Jääski,Lesogorskij,Lesogorskiy,Yaski,Yayaski,Лесогорский', 61.0454900, 28.9293800, 'RU', '2013-10-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120624, 'Lesogorsk', 'Lesogorsk', 'Lesogorsk,Лесогорск', 55.0979000, 43.9355200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120625, 'Lesnyye Polyany', 'Lesnyye Polyany', 'Lesnye Poljany,Lesnyye Polyany,Лесные Поляны', 59.0031400, 52.4180200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120626, 'Lesnyye Polyany', 'Lesnyye Polyany', 'Lesnye Poljany,Lesnyye Polyany,Лесные Поляны', 55.9666700, 37.8666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120627, 'Lesnoy Gorodok', 'Lesnoy Gorodok', 'Lesnoj Gorodok,Lesnoy Gorodok,Лесной Городок', 55.6389300, 37.2082900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120628, 'Lesnoye', 'Lesnoye', 'Lesnoe,Lesnoje,Lesnoye,Лесное', 58.2840600, 35.5158400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120629, 'Komendantsky aerodrom', 'Komendantsky aerodrom', 'Komendantskij aehrodrom,Комендантский аэродром', 60.0044800, 30.2752300, 'RU', '2013-03-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120630, 'Lesnoy', 'Lesnoy', 'Lesnoj,Lesnoy,Lesnoye,Лесной', 59.7810000, 52.1283800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120631, 'Lesnoy', 'Lesnoy', 'Lesnoj,Lesnoy,Лесной', 56.0666700, 37.9166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120632, 'Lesnoy', 'Lesnoy', 'Lesnoj,Lesnoy,Лесной', 54.2125000, 40.4713000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120633, 'Leskolovo', 'Leskolovo', 'Leskolovo,Lieskula,Лесколово', 60.2634100, 30.4546200, 'RU', '2016-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120634, 'Leshukonskoye', 'Leshukonskoye', 'LDG,Leschukonskaja,Leshukonskoe,Leshukonskoye,Lesjukonskoje,Лешуконское', 64.8977000, 45.7655000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120635, 'Lermontovo', 'Lermontovo', 'Lermontovo,Tarkhany,Лермонтово,Тарханы', 52.9927700, 43.6614100, 'RU', '2013-10-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120636, 'Lermontov', 'Lermontov', 'Gorad Lermantau,Lermontov,Lermontovskiy,Lermontow,Ljermontov,Lumontov,lai meng tuo fu,lrmwntwf,lrmwntwf  rwsyh,Љермонтов,Горад Лермантаў,Лермонтов,Лермонтов балһсн,لرمونتوف,لرمونتوف، روسیه,萊蒙托夫', 44.1066700, 42.9733300, 'RU', '2011-06-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120637, 'Leonovo', 'Leonovo', 'Leonovo,Леоново', 55.8500000, 37.6500000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120638, 'Leninskoye', 'Leninskoye', 'Haapala,Khapala,Leninskoe,Leninskoje,Leninskoye,Ленинское', 60.2202100, 29.8471100, 'RU', '2013-10-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120639, 'Leninskoye', 'Leninskoye', 'Leninskiy,Leninskoe,Leninskoje,Leninskoye,Ленинское', 58.3163700, 47.0885600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120640, 'Leninskiye Gory', 'Leninskiye Gory', 'Leninskie gory,Ленинские горы', 55.7000000, 37.5666700, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120641, 'Leninskiy', 'Leninskiy', 'Leninskij,Leninskiy,Ленинский', 54.2876800, 37.4592600, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120642, 'Leninsk', 'Leninsk', 'Leninsk,Leninskiy,Ленинск', 54.9030600, 59.8675000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120643, 'Leninsk', 'Leninsk', 'Gorad Leninsk,Leninsk,Leninsk i Volgograd oblast,Leninskiy,Leninskoje,Léninsk,lie ning si ke,lnynsk,lnynsk  awblast wlgwgrad,Горад Ленінск,Ленинск,Ленинск балһсн,Лењинск,لنينسك,لنینسک، اوبلاست ولگوگراد,列寧斯克', 48.7023300, 45.1979800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120644, 'Leninogorsk', 'Leninogorsk', 'Gorad Leninagorsk,Leninogorsk,Leninogorsk i Russland,Leninoqorsk,Novaya Pis''menka,Novaya Pis''myanka,Novaya Pis’menka,Novaya Pis’myanka,Novopis''myanka,Novopis’myanka,leninogoleuseukeu,lie ning nuo ge er si ke,lnynwghwrsk,lnynwgwrsk  rwsyh,lynynwgrsk,reninogorusuku,Горад Ленінагорск,Лениногорск,Лењиногорск,لنينوغورسك,لنینوگورسک، روسیه,لینینوگرسک,レニノゴルスク,列寧諾戈爾斯克,레니노고르스크', 54.6025600, 52.4608700, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120645, 'Tsaritsyno', 'Tsaritsyno', 'Caricino,Imeni Chkalova V.P.,Imeni V.P. Chkalova,Lenino,Sartino,Tsaritsyno,Tsaritsyno-Dachnoye,Tsartino,Царицино', 55.6254000, 37.6503200, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120646, 'Leninkent', 'Leninkent', 'Leninkent,Ленинкент', 42.9689500, 47.3520200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120647, 'Leningradskaya', 'Leningradskaya', 'Leningradskaja,Leningradskaya,Umanskaya,Ленинградская', 46.3214000, 39.3877000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120648, 'Yubileyny', 'Yubileyny', 'Gorad Jubilejny,Ioubileiny,Ioubileïny,Iubileini,Jubileiny,Jubileinyi,Jubilejnaj,Jubilejni,Jubilejnij,Jubilejnyj,Jubilejnyj i Moskva oblast,Yubileyniy,Yubileynıy,you bi lie yi nei,ywbylyny,ywbylyny  awblast mskw,ywbylyyny,Јубиљејни,Горад Юбілейны,Юбилейнай,Юбилейный,Юбілейний,يوبيلييني,یوبیلینی,یوبیلینی، اوبلاست مسکو,尤比列伊內', 55.9333300, 37.8333300, 'RU', '2011-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120649, 'Leninaul', 'Leninaul', 'Aktash-Aukh,Aktash-Aul,Lenin-Aul,Leninaul,Stalinaul,Ленин-Аул,Ленинаул', 43.0913800, 46.5743400, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120650, 'Lenina', 'Lenina', 'Imeni Lenina,Lenina,Ленина', 46.0666700, 39.7833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120651, 'Lefortovo', 'Lefortovo', 'Lefortovo,Лефортово', 55.7666700, 37.7000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120652, 'Ledmozero', 'Ledmozero', 'Ledmozero,Liedmajaervi,Liedmajärvi,Lietmajaervi,Lietmajärvi,Ледмозеро', 64.2544400, 32.0278900, 'RU', '2016-12-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120653, 'Lechinkay', 'Lechinkay', 'Lechinkaj,Lechinkay,Lechinkaya,Letsjinkaj,Лечинкай', 43.5647200, 43.4327800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120654, 'Lebyazh’ye', 'Lebyazh''ye', 'Lebjashe,Lebjazh''e,Lebyazh''ye,Lebyazh’ye,Lepaesi,Lepäsi,Лебяжье', 59.9612400, 29.4148700, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120655, 'Lebedyan’', 'Lebedyan''', 'Lebedjan,Lebedjan'',Lebedyan'',Lebedyan’,Лебедянь', 53.0194200, 39.1663900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120656, 'Lazarevskoye', 'Lazarevskoye', 'Lasarewskaja,Lazarevskaya,Lazarevskoe,Lazarevskoje,Lazarevskoye,Лазаревское', 43.9088600, 39.3313700, 'RU', '2012-12-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120657, 'Latnaya', 'Latnaya', 'Latnaja,Latnaya,Латная', 51.6586000, 38.9011000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120658, 'Lashma', 'Lashma', 'Lashma,Lasjma,Лашма', 54.9321000, 41.1437900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120659, 'Laptëvo', 'Laptevo', 'Lapteva,Laptevo,Laptjovo,Laptëvo,Лаптево,Лаптёво', 56.7407400, 28.8336100, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120660, 'Lal’sk', 'Lal''sk', 'Lal''sk,Lalsk,Lal’sk,Лальск', 60.7414600, 47.5861700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120661, 'Lakinsk', 'Lakinsk', 'Gorad Lakinsk,Lakinsk,Lakinskiy,la jin si ke,lakinseukeu,lakynsk,rakinsuku,Łakinsk,Горад Лакінск,Лакинск,لاكينسك,لاکینسک,ラキンスク,拉金斯克,라킨스크', 56.0193100, 39.9484800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120662, 'Lakhtinskiy', 'Lakhtinskiy', 'Lahti,Lakhta,Lakhtinskij,Lakhtinskiy,Лахтинский', 59.9952100, 30.1471700, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120663, 'Lakhdenpokh’ya', 'Lakhdenpokh''ya', 'Lahdenpohja,Lahdenpohju,Lakhdenpokh''ja,Lakhdenpokh''ya,Lakhdenpokhja,Lakhdenpokh’ya,Лахденпохья', 61.5198100, 30.1991700, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120664, 'Laishevo', 'Laishevo', 'Gorad Laishava,Laesh,Laichevo,Laischewo,Laisevo,Laisewo,Laishev,Laishevo,Laisjevo,Laixevo,Laiševo,Laišewo,Lalshevo,Lapshevo,Laíxevo,Laïchevo,la yi she wo,laisyebo,layshfw,layshyfw,raishevu~o,Горад Лаішава,Лаеш,Лаишево,لايشيفو,لایشفو,ライシェヴォ,拉伊舍沃,라이셰보', 55.4046400, 49.5503700, 'RU', '2015-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120665, 'Ladushkin', 'Ladushkin', 'Ladushkin,Ladusjkin,Laduskin,Laduskinas,Laduŝkin,Laduškin,Laduškinas,Liudvigsortas,Ludwigsort,Lyudvigsort,Ладушкин', 54.5702500, 20.1709900, 'RU', '2015-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120666, 'Ladozhskaya', 'Ladozhskaya', 'Ladoshskaja,Ladozhskaja,Ladozhskaya,Ladozjskaja,Ладожская', 45.3090200, 39.9380300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120667, 'Ladovskaya Balka', 'Ladovskaya Balka', 'Lad-Balka,Ladovskaja Balka,Ladovskaya Balka,Ladovsko-Balkovskoye,Ладовская Балка', 45.6296500, 41.4023100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120668, 'Labinsk', 'Labinsk', 'Gorad Labinsk,Labins''k,Labinsk,Labinskaja,Labinskaya,la bin si ke,labaynsk,labinseukeu,labnsk,labynsk,Łabińsk,Горад Лабінск,Лабинск,Лабинск балһсн,Лабінськ,لاباينسك,لابنسک,لابینسک,拉賓斯克,라빈스크', 44.6341700, 40.7355600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120669, 'Kyzyl-Oktyabr’skiy', 'Kyzyl-Oktyabr''skiy', 'Krasnyy Oktyabr'',Krasnyy Oktyabr’,Kyzyl-Oktyabr'',Kyzyl-Oktyabr''skiy,Kyzyl-Oktyabr’,Kyzyl-Oktyabr’skiy', 43.8257000, 41.7860500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120670, 'Islamey', 'Islamey', 'Islamej,Islamey,Kyzburun Vtoroy,Исламей', 43.6755600, 43.4550000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120671, 'Dugulubgey', 'Dugulubgey', 'Dugulubgej,Dugulubgey,Kyzburun Tretiy,Дугулубгей', 43.6625000, 43.5369400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120672, 'Kyzburun Pervyy', 'Kyzburun Pervyy', 'Kysburun,Kyzburun Pervyj,Kyzburun Pervyy,Кызбурун Первый', 43.6516700, 43.3950000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120673, 'Kyakhulay', 'Kyakhulay', 'Kjakhulaj,Kyakhulay,Кяхулай', 42.9683900, 47.4830100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120674, 'Kvarkeno', 'Kvarkeno', 'Kvarkeno,Кваркено', 52.0833300, 59.7250000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120675, 'Kuzovatovo', 'Kuzovatovo', 'Kuzovatovo,Vtoroye Kuzovatovo,Кузоватово', 53.5468100, 47.6865900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120676, 'Kuznetsk', 'Kuznetsk', 'Gorad Kuzneck,Kouznetsk,Kusnezk,Kuznec''k,Kuzneck,Kuzneckas,Kuznetk,Kuznetsk,Kuznețk,Kuznieck,Kuznjeck,Kuźnieck,ku zi nie ci ke,kwzntsk,kwznytsk,Горад Кузнецк,Кузнецк,Кузнецк балһсн,Кузнецьк,Кузњецк,كوزنتسك,کوزنتسک,کوزنیتسک,庫茲涅茨克', 53.1167500, 46.6003700, 'RU', '2015-06-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120677, 'Kuznechnoye', 'Kuznechnoye', 'Kaarlahti,Kaarlakhti,Karlakhti,Kuznechnoe,Kuznechnoye,Kuznetsjnoje,Кузнечное', 61.1153000, 29.8753500, 'RU', '2012-11-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120678, 'Kuznechikha', 'Kuznechikha', 'Kuznechikha,Kuznetsjikha,Кузнечиха', 57.2160700, 42.3347700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120679, 'Kuz’minskiye Otverzhki', 'Kuz''minskiye Otverzhki', 'Kuz''mino-Otverzhki,Kuz''minskie Otverzhki,Kuz''minskiye Otverzhki,Kuz’mino-Otverzhki,Kuz’minskiye Otverzhki,Кузьминские Отвержки', 52.6957400, 39.4703600, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120680, 'Kuz’minki', 'Kuz''minki', 'Kuz''minki,Kuz’minki,Кузьминки', 55.7000000, 37.8000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120681, 'Kuzino', 'Kuzino', 'Kuzino,Кузино', 59.7766500, 38.3104000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120682, 'Kuzino', 'Kuzino', 'Kuzino,Кузино', 57.0224000, 59.4412000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120683, 'Kuzhorskaya', 'Kuzhorskaya', 'Kuzhorskaja,Kuzhorskaya,Kuzjorskaja,Кужорская', 44.6751200, 40.3103200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120684, 'Kuzhenkino', 'Kuzhenkino', 'Kuzhenkino,Куженкино', 57.7611100, 33.9508300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120685, 'Kuzhener', 'Kuzhener', 'Kuzhener,Kuzjener,Куженер', 56.8111100, 48.9127800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120686, 'Kuyeda', 'Kuyeda', 'Kueda,Kujeda,Kuyeda,Куеда', 56.4311000, 55.5886100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120687, 'Kuybyshevskiy Zaton', 'Kuybyshevskiy Zaton', 'Kujbyshevskij Zaton,Kujbysjevskij-Zaton,Kuybyshev-Zaton,Kuybyshevskiy Zaton,Spasskin Zaton,Spasskiy Zaton,Куйбышевский Затон', 55.1593000, 49.1701000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120688, 'Kuybyshevo', 'Kuybyshevo', 'Golodayevka,Golodayevskoye,Kujbyshevo,Kujbysjevo,Kuybyshevo,Куйбышево', 47.8122800, 38.9073100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120689, 'Kuvshinovo', 'Kuvshinovo', 'Kamenka,Kuvshinovo,Kuvsjinovo,Kuwschinowo,Кувшиново', 57.0295300, 34.1725200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120690, 'Kuvandyk', 'Kuvandyk', 'Gorad Kuvandyk,Kouvandyk,Kuandyk,Kuvandik,Kuvandyk,Kuvandık,Kuwandyk,ku wan de ke,kwandyk,kwfandyk,Горад Кувандык,Куандык,Кувандик,Кувандык,Ҡыуандыҡ,كوفانديك,کواندیک,庫萬德克', 51.4781000, 57.3552000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120691, 'Kuskovo', 'Kuskovo', 'Kuskovo,Кусково', 55.7342300, 37.8261600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120692, 'Kushva', 'Kushva', 'Gorad Kushva,Koesjva,Koshva,Kouchva,Kousva,Kuschwa,Kushva,Kusjva,Kusva,Kuswa,Kuszwa,Kuŝva,Kuşva,Kušva,Kušwa,ku shen wa,kusiba,kwshfa,kwshwa,Κούσβα,Горад Кушва,Кошва,Кушва,كوشفا,کوشوا,庫什瓦,쿠시바', 58.2905600, 59.7591700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120693, 'Kushnarënkovo', 'Kushnarenkovo', 'Kusharenkovo,Kushnarenkovo,Kushnarjonkovo,Kushnarënkovo,Kusjnarenkovo,Topornino,Кушнаренково,Кушнарёнково', 55.1050000, 55.3508300, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120694, 'Kushelevka', 'Kushelevka', 'Kushelevka,Кушелевка', 59.9933300, 30.3638900, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120695, 'Kushchëvskaya', 'Kushchevskaya', 'Kuschewskaja,Kuschtschewskaja,Kushchevskaya,Kushchëvskaya,Kushhjovskaja,Kusjtsjevskaja,Кущёвская', 46.5599000, 39.6321000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120696, 'Kusa', 'Kusa', 'Kusa,Куса', 55.3383300, 59.4405600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120697, 'Kur’yanovo', 'Kur''yanovo', 'Kur''janovo,Kur''yanova,Kur''yanovo,Kur’yanova,Kur’yanovo,Курьяново', 55.6500000, 37.7000000, 'RU', '2016-08-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120698, 'Kurush', 'Kurush', 'Kaler,Kurush,Kurusj,Куруш', 41.2841300, 47.8345400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120699, 'Kurumoch', 'Kurumoch', 'Kurumoch,Kurumotsj,Курумоч', 53.4896300, 50.0374800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120700, 'Kurskaya', 'Kurskaya', 'Kurskaja,Kurskaya,Курская', 44.0500000, 44.4500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120701, 'Kursk', 'Kursk', 'Koersk,Koursk,Kurs''k,Kursk,Kurskas,Kúrsk,URS,ku er si ke,kuleuseukeu,kurusuku,Курск,Курськ,クルスク,库尔斯克,庫爾斯克,쿠르스크', 51.7373300, 36.1873500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120702, 'Kursavka', 'Kursavka', 'Kursavka,Kurshava,Kurshavka,Курсавка,Куршава', 44.4564000, 42.5093000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120703, 'Kurovskoye', 'Kurovskoye', 'Kourovskoie,Kourovskoïe,Kuovskaya,Kurovs''ke,Kurovskaya,Kurovskoe,Kurovskoje,Kurovskoye,Kurowskoje,ku luo fu si ke ye,kwrwfskwy,kwrwfskwyh,Куровское,Куровское балһсн,Куровскоје,Куровське,كوروفسكوي,کوروفسکویه,کورووسکوئے,庫羅夫斯科耶', 55.5818300, 38.9199400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120704, 'Kurmanayevka', 'Kurmanayevka', 'Kurmanaevka,Kurmanajevka,Kurmanayevka,Kurmanayevo,Курманаевка', 52.5093000, 52.0675000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120705, 'Kurlovo', 'Kurlovo', 'Kurlovo,Курлово', 55.4325200, 40.4853900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120706, 'Nizhniy Kurkuzhin', 'Nizhniy Kurkuzhin', 'Kurkuzhin,Nizhnij Kurkuzhin,Nizhniy Kurkuzhin,Nizjnij Kurkuzjin,Нижний Куркужин', 43.7483300, 43.3497200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120707, 'Kurkino', 'Kurkino', 'Kourkino,Kurkino,Куркино', 53.4256700, 38.6582400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120708, 'Kurkent', 'Kurkent', 'Kurkent,Куркент', 41.7119900, 48.1153100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120709, 'Kurganinsk', 'Kurganinsk', 'Gorad Kurganinsk,Koerganinsk,Kourganinsk,Kurganins''k,Kurganinsk,Kurganińsk,Kurgannaja,Kurgannaya,Kurgàninsk,Kurgáninsk,Kurqaninsk,ku er jia ning si ke,kwrganynsk,kwrghannsk,Горад Курганінск,Курганинск,Курганинск балһсн,Курганинськ,كورغاننسك,کورگانینسک,庫爾加寧斯克', 44.8800000, 40.5986100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120710, 'Kurdzhinovo', 'Kurdzhinovo', 'Kurdzhinovo,Kurdzjinovo,Курджиново', 43.9883800, 40.9551900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120711, 'Kurchatov', 'Kurchatov', 'Kurchatov,Kurtsjatov,Курчатов', 51.6601000, 35.6521000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120712, 'Kurchaloy', 'Kurchaloy', 'Chkalovo,Ckalovo,Kurcala,Kurcaloj,Kurcaloy,Kurcaloyn-Avla,Kurcaloyn-Evla,Kurchala,Kurchaloj,Kurchalojn-Ehvla,Kurchaloy,Kurchloj-Ehvl,Kurcloy-Evl,Kurcula,Kurshloj,Kursloy,Kurtsjaloj,Kurçala,Kurçaloy,Kurçaloyn-Evla,Kurçaloyn-Əvla,Kurçloy-Evl,Kurçula,Kurčaloj,Kurşloy,Çkalovo,Курчала,Курчалой,Курчалойн-Эвла,Курчлой-Эвл,Куршлой,Чкалово', 43.2018400, 46.0881000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120713, 'Kurba', 'Kurba', 'Kurba,Курба', 57.5609700, 39.4981000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120714, 'Kurakh', 'Kurakh', 'Kurakh,Курах', 41.5849100, 47.7830600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120715, 'Kupchino', 'Kupchino', 'Kupchi,Kupchino,Kupsila,Купчино', 59.8527800, 30.3566700, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120716, 'Kupavna', 'Kupavna', 'Kupavna,Купавна', 55.7457600, 38.1313600, 'RU', '2012-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120717, 'Kungur', 'Kungur', 'Gorad Kungur,Koengoer,Koungour,Kungur,Kunqur,kun gu er,kung-guleu,kunguleu,kwnghwr,kwngwr,Горад Кунгур,Кунгур,Кӧҥгыр,Көңгер,كونغور,کونگور,昆古爾,쿤구르,쿵구르', 57.4368000, 56.9593000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120718, 'Kumysh', 'Kumysh', 'Kumysh,Kumysj,Podgornoye,Кумыш', 43.8833400, 41.8932300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120719, 'Kumylzhenskaya', 'Kumylzhenskaya', 'Kumilzhenskaya,Kumylzhenskaja,Kumylzhenskaya,Kumylzjenskaja,Кумылженская', 49.8809000, 42.5898000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120720, 'Kumukh', 'Kumukh', 'Kumukh,Кумух', 42.1703600, 47.1160600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120721, 'Kumertau', 'Kumertau', 'Gorad Kumjartau,Koumertaou,Kumertau,Kumiertau,Kumjertau,ku mei er tao,kwmrtaw,Горад Кумяртаў,Кумертау,Кумертау балһсн,Күмертау,كومرتاو,کومرتاؤ,کومرتاو,庫梅爾套', 52.7666700, 55.7833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120722, 'Kumëny', 'Kumeny', 'Kumeny,Kumjony,Kumëny,Кумены,Кумёны', 58.1088700, 49.9161400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120723, 'Kultayevo', 'Kultayevo', 'Kultaevo,Kultajevo,Kultayevo,Култаево', 57.8948000, 55.9378000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120724, 'Kuloy', 'Kuloy', 'Kuloj,Kuloy,Кулой', 61.0304900, 42.4925200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120725, 'Kulotino', 'Kulotino', 'Kulotino,Кулотино', 58.4500000, 33.3833300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120726, 'Kuli', 'Kuli', 'Kuli,Kuly,Кули', 42.0184500, 47.2434200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120727, 'Kuleshovka', 'Kuleshovka', 'Kuleshovka,Kulesjovka,Kulischewka,Кулешовка', 47.0780200, 39.5579400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120728, 'Kulebaki', 'Kulebaki', 'Gorad Kuljabaki,Koelebaki,Koulebaki,Kulebaki,ku lie ba ji,kwlbaky,Горад Кулябакі,Кулебаки,كولباكي,کولباکی,庫列巴基', 55.4133300, 42.5325000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120729, 'Kulary', 'Kulary', 'GIulare,GIulari,Gulare,Gulari,Kulari,Kulary,Naberezhnoe,Naberezhnoye,Nabereƶnoe,Ġulare,Ġulari,ГІуларе,ГІулари,Кулары,Набережное', 43.2397200, 45.5041700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120730, 'Kukushtan', 'Kukushtan', 'Kukushtan,Kukusjtan,Кукуштан', 57.6464000, 56.4952000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120731, 'Kukoboy', 'Kukoboy', 'Bukoboy,Kukoboj,Kukoboy,Кукобой', 58.7008900, 39.9142700, 'RU', '2010-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120732, 'Kukmor', 'Kukmor', 'Bol.Kukmor,Kukmor,Бол.Кукмор,Кукмор', 56.1855000, 50.8944000, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120733, 'Kugesi', 'Kugesi', 'Kugesi,Кугеси', 56.0289500, 47.2925500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120734, 'Kudymkar', 'Kudymkar', 'Gorad Kudymkar,Koedymkar,Koudymkar,Kudimkar,Kudomkar,Kudymkar,Kudymkaras,Kudymkarskoye,Kudímkar,Kudõmkar,Kudımkar,ku de mu ka er,kudimkaleu,kudimukaru,kwdymkar,Горад Кудымкар,Кудимкар,Кудымкар,كوديمكار,کودیمکار,クディムカル,庫德姆卡爾,쿠딤카르', 59.0130600, 54.6555600, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120735, 'Kudinovo', 'Kudinovo', 'Kudinovo,Кудиново', 54.9993900, 36.2533100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120736, 'Kudeyevskiy', 'Kudeyevskiy', 'Kudeevskij,Kudejevskij,Kudeyevskiy,Кудеевский', 54.8758300, 56.7566700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120737, 'Kudepsta', 'Kudepsta', 'Kudepsta,Кудепста', 43.4954700, 39.8929400, 'RU', '2012-06-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120738, 'Kuchugury', 'Kuchugury', 'Kuchugury,Kutsjugury,Кучугуры', 45.4070200, 36.9558600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120739, 'Kubinka', 'Kubinka', 'Gorad Kubinka,Koubinka,Kubinka,ku bin ka,kwbynka,Горад Кубінка,Кубинка,Кубинка балһсн,كوبينكا,کوبینکا,庫賓卡', 55.5795700, 36.7039200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120740, 'Kuba-Taba', 'Kuba-Taba', 'Kuba-Taba,Kuba-Tapa,Куба-Таба', 43.7761100, 43.4427800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120741, 'Kubanskiy', 'Kubanskiy', 'Kubanskij,Kubanskiy,Кубанский', 45.9291700, 40.5805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120742, 'Kubachi', 'Kubachi', 'Kubachi,Kubatsji,Кубачи', 42.0859800, 47.6033800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120743, 'Kstovo', 'Kstovo', 'Gorad Kstova,Kostova,Kstovo,Kstowo,ke si tuo wo,keuseutobo,kstwfw,kstww,kusutovu~o,Горад Кстова,Кстово,كستوفو,کستوفو,کستوو,クストヴォ,克斯托沃,크스토보', 56.1473300, 44.1978700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120744, 'Kshenskiy', 'Kshenskiy', 'Kshen'',Kshenskij,Kshenskiy,Kshen’,Ksjenskij,Lipovchik,Sovetskiy,Sovetskoye,Кшенский', 51.8408300, 37.7136100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120745, 'Krymsk', 'Krymsk', 'Gorad Krymsk,Krims''k,Krimsk,Krimskaja,Krimskaya,Kromsk,Krymasko,Krymsk,Krymskaja,Krymskaya,Krîmsk,Krõmsk,Krımsk,ke lei mu si ke,keulimseukeu,krymsk,Горад Крымск,Кримск,Кримськ,Крымск,Крымск балһсн,كريمسك,کریمسک,克雷姆斯克,크림스크', 44.9293400, 37.9911700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120746, 'Krym', 'Krym', 'Krym,Крым', 47.3002500, 39.5163700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120747, 'Krylovskaya', 'Krylovskaya', 'Jekaterinowskaja,Krylovskaja,Krylovskaya,Yekaterinovskaya,Крыловская', 46.3194400, 39.9711100, 'RU', '2016-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120748, 'Krylovskaya', 'Krylovskaya', 'Krylovskaja,Krylovskaya,Крыловская', 46.1097000, 39.3035000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120749, 'Kruglolesskoye', 'Kruglolesskoye', 'Kruglolesskoe,Kruglolesskoje,Kruglolesskoye,Kruglolyesskoe,Круглолесское', 44.6588900, 42.8141700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120750, 'Krotovka', 'Krotovka', 'Krotovka,Krowtowka,Кротовка', 53.2858000, 51.1686000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120751, 'Kropotkin', 'Kropotkin', 'Gorad Krapotkin,Krapotkin,Kropotkin,Kropotkin i Krasnodar kraj,Kropotkine,Romanovskiy Khutor,ke lu pao te jin,krwbwtkyn,krwptkyn  krasnwdar,krwpwtkn,Горад Крапоткін,Кропоткин,Кропоткин балһсн,Кропоткін,كروبوتكين,کروپتکین، کراسنودار,کروپوتکن,克魯泡特金', 45.4375000, 40.5755600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120752, 'Kropachëvo', 'Kropachevo', 'Kropachevo,Kropachjovo,Kropachëvo,Kropatsjevo,Кропачево,Кропачёво', 55.0112000, 57.9896000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120753, 'Kronshtadt', 'Kronshtadt', 'Cronstadt,Kronshtadt,Kronsjtadt,Kronstadt,Kronstatti,Kronštatti,Kroonlinn,Кронштадт', 59.9954100, 29.7666800, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120754, 'Kromy', 'Kromy', 'Kromy,Кромы', 52.6876200, 35.7666500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120755, 'Krivyanskaya', 'Krivyanskaya', 'Krivjanskaja,Krivyanskaya,Кривянская', 47.3962500, 40.1662000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120756, 'Kresty', 'Kresty', 'Kresty,Palkina,Кресты', 56.7759500, 28.0908300, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120757, 'Kresttsy', 'Kresttsy', 'Krestci,Krestcy,Krestsy,Kresttsey,Kresttso,Kresttsy,Kresttsõ,Krestzy,Крестци,Крестцы', 58.2452000, 32.5164700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120758, 'Kremenki', 'Kremenki', 'Kremenki,Кременки', 54.8862600, 37.1195500, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120759, 'Krechevitsy', 'Krechevitsy', 'Krechevicy,Krechevitsy,Kretsjevitsy,Кречевицы', 58.6170300, 31.4010100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120760, 'Kratovo', 'Kratovo', 'Kratovo,Кратово', 55.5972800, 38.1774300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120761, 'Krasyukovskaya', 'Krasyukovskaya', 'Krasiukovskaja,Krasjukovskaja,Krasyukovskaya,Красюковская', 47.5522200, 40.1088500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120762, 'Krasnyy Yar', 'Krasnyy Yar', 'Kransy-Yar,Krasny Yar,Krasnyj Jar,Krasnyy Yar,Красный Яр', 53.4998800, 50.3931200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120763, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasn.Jar,Krasni-Yar,Krasnyj Jar,Krasnyy Yar,Красн.Яр,Красный Яр', 51.6291700, 46.4216700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120764, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasn.Jar,Krasny Jar,Krasnyj Jar,Krasnyy Yar,Красн.Яр,Красный Яр', 50.6965200, 44.7279200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120765, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasnyj Jar,Krasnyj_jar,Krasnyy Yar,Krassnyj-Jar,Красный Яр', 46.5331400, 48.3455900, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120766, 'Krasnyy Tkach', 'Krasnyy Tkach', 'Krasn.Tkach,Krasniy Tkach,Krasnyj Tkach,Krasnyy Tkach,Красн.Ткач,Красный Ткач', 55.4721000, 39.0801700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120767, 'Krasnyy Sulin', 'Krasnyy Sulin', 'Krasny-Sulin,Krasnyj Sulin,Krasnyy Sulin,Krassnyj Ssulin,Красный Сулин', 47.8922100, 40.0703700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120768, 'Biryulëvo Zapadnoye', 'Biryulevo Zapadnoye', 'Biryulevo Zapadnoye,Biryulëvo Zapadnoye,Krasny Stroitel'',Krasny Stroitel’,Krasnyj Stroitel'',Krasnyy Stroitel'',Krasnyy Stroitel’,Красный Строитель', 55.5876600, 37.6428200, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120769, 'Krasnyy Profintern', 'Krasnyy Profintern', 'Guzitsino,Krasny Profintern,Krasnyj Profintern,Krasnyy Profintern,Красный Профинтерн', 57.7445900, 40.4350100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120770, 'Krasnyy Oktyabr’', 'Krasnyy Oktyabr''', 'Krasnyj Oktjabr,Krasnyj Oktjabr'',Krasnyy Oktyabr'',Krasnyy Oktyabr’,Красный Октябрь', 56.1166700, 38.8833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120771, 'Krasnyy Oktyabr’', 'Krasnyy Oktyabr''', 'Krasnyj Oktjabr,Krasnyj Oktjabr'',Krasnyy Oktyabr'',Krasnyy Oktyabr’,Poselok Krasnyy Oktyabr'',Posëlok Krasnyy Oktyabr’,Красный Октябрь', 56.1034700, 41.3839500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120772, 'Krasnyy Oktyabr’', 'Krasnyy Oktyabr''', 'Krasn.Oktjabr,Krasn.Oktjabr'',Krasnyj Oktjabr'',Krasnyy Oktyabr'',Krasnyy Oktyabr’,Красн.Октябрь,Красный Октябрь', 51.5401800, 45.7038200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120773, 'Krasnyy Luch', 'Krasnyy Luch', 'Krasnyj Luch,Krasnyj Lutsj,Krasnyy Luch,Luzha,Novy Svet,Novyy Svet,Красный Луч', 57.0667600, 30.0903200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120774, 'Krasnyy Kut', 'Krasnyy Kut', 'Krasn.Kut,Krasny Kut,Krasnyj Kut,Krasnyy Kut,Красн.Кут,Красный Кут', 50.9500000, 46.9666700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120775, 'Krasnyy Kurgan', 'Krasnyy Kurgan', 'Krasnyj Kurgan,Krasnyy Kurgan,Красный Курган', 43.9422200, 42.6108300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120776, 'Krasnyy Klyuch', 'Krasnyy Klyuch', 'Krasnyj Kljuch,Krasnyy Klyuch,Красный Ключ', 55.3862500, 56.6528700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120777, 'Krasnyy Kholm', 'Krasnyy Kholm', 'Krasny Cholm,Krasny Kholm,Krasnyj Kholm,Krasnyy Kholm,Красный Холм', 58.0607000, 37.1203200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120778, 'Krasnyy Gulyay', 'Krasnyy Gulyay', 'Krasnyj Guljaj,Krasnyy Gulyay,Красный Гуляй', 54.0282100, 48.3332700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120779, 'Krasnyye Tkachi', 'Krasnyye Tkachi', 'Krasnye Tkachi,Krasnye Tkatsji,Krasnyye Tkachi,Красные Ткачи', 57.4925900, 39.7562900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120780, 'Krasnyye Chetai', 'Krasnyye Chetai', 'Krasn.Chetai,Krasny Chetay,Krasnye Chetai,Krasnyye Chetai,Krasnyye Chetay,Красн.Четаи,Красные Четаи', 55.6887100, 46.1386500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120781, 'Krasnyye Barrikady', 'Krasnyye Barrikady', 'Bertyul'',Bertyul’,Krasnye Barrikady,Krasnyye Barrikady,Красные Баррикады', 46.2045000, 47.8535000, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120782, 'Krasnyye Baki', 'Krasnyye Baki', 'Krasnye Baki,Krasnyje Baki,Krasnyye Baki,Красные Баки', 57.1310000, 45.1599200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120783, 'Krasnyy Bor', 'Krasnyy Bor', 'Krasny Bor,Krasnyj Bor,Krasnyy Bor,Punaporu,Красный Бор', 59.6819400, 30.6680600, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120784, 'Krasnyy Bogatyr’', 'Krasnyy Bogatyr''', 'Krasnyj Bogatyr,Krasnyj Bogatyr'',Krasnyy Bogatyr'',Krasnyy Bogatyr’,Красный Богатырь', 56.0145300, 41.1295800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120785, 'Krasnoznamensk', 'Krasnoznamensk', 'Haselberg,Krasnosnamensk,Krasnoznamens''k,Krasnoznamensk,Krasnoznamensk i Kaliningrad oblast,Krasnoznamenska,Krasnoznamenskas,Krasnoznamiensk,Krasnoznamjensk,Krasnoznamyonsk,Lasdehen,Lasdehnen,Lasdenen,Lazdenay,Lazdenen,Lazdynai,hong zi na mian si ke,keulaseunojeunamenseukeu,krasnwznamnsk  kalynyngrad,krasnwznamynsk,kurasunozunamensuku,Краснознаменск,Краснознаменськ,كراسنوزنامينسك,کراسنوزنامنسک، کالینینگراد,クラスノズナメンスク,紅茲納緬斯克,크라스노즈나멘스크', 54.9422200, 22.4897200, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120786, 'Krasnozavodsk', 'Krasnozavodsk', 'Krasnosawodsk,Krasnozavods''k,Krasnozavodsk,Krasnozavodskiy,Krasnozawodsk,Zagorskiy,ke la si nuo zha wo ci ke,krasnwzafwdsk,krasnwzawwdsk,kurasunozavu~otsuku,Краснозаводск,Краснозаводск балһсн,Краснозаводськ,كراسنوزافودسك,کراسنوزاوودسک,クラスノザヴォツク,克拉斯諾扎沃茨克', 56.4500000, 38.2166700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120787, 'Krasnoye Selo', 'Krasnoye Selo', 'Kraassela,Krasnoe Selo,Krasnoje Selo,Krasnoye Selo,Krasnyy,Kruassela,Красное Село', 59.7383300, 30.0894400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120788, 'Krasnoye-na-Volge', 'Krasnoye-na-Volge', 'Krasnoe,Krasnoe-na-Volge,Krasnoje-Na-Volge,Krasnoye,Krasnoye-na-Volge,Krasnyi Volgar,Красное-на-Волге', 57.5148300, 41.2390000, 'RU', '2016-11-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120789, 'Krasnoye', 'Krasnoye', 'Krasnoe,Krasnoje,Krasnoye,Красное', 52.8644900, 38.7935300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120790, 'Krasnoye', 'Krasnoye', 'Krasnaya,Krasnoe,Krasnoje,Krasnoye,Krasnoye Ukolovskoye,Красное', 50.9297000, 38.6817000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120791, 'Krasnoye', 'Krasnoye', 'Krasnoe,Krasnoje,Krasnoye,Красное', 46.7373000, 39.5645000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120792, 'Krasnoyarskiy', 'Krasnoyarskiy', 'Krasnojarskij,Krasnoyarskiy,Красноярский', 51.9650000, 59.8966700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120793, 'Krasnoyarskaya', 'Krasnoyarskaya', 'Krasnojarskaja,Krasnoyarskaya,Krasnoyarskiy,Красноярская', 47.6501000, 42.0443000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120794, 'Krasnovka', 'Krasnovka', 'Donskoy,Krasnovka,Красновка', 48.8176900, 40.0922600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120795, 'Krasnovishersk', 'Krasnovishersk', 'Krasnovishersk,Krasnovisjersk,Красновишерск', 60.4078300, 57.0819900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120796, 'Krasnoufimsk', 'Krasnoufimsk', 'Gorad Krasnaufimsk,Krasno-oefimsk,Krasnooufimsk,Krasnoufims''k,Krasnoufimsk,Krasnoutimsk,ke la si nuo wu fei mu si ke,krasnwfaymsk,krasnwfymsk,Κρασνοουφίμσκ,Горад Краснаўфімск,Красноуфимск,Красноуфимськ,كراسنوفايمسك,کراسنوفیمسک,克拉斯諾烏菲姆斯克', 56.6058500, 57.7668600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120797, 'Krasnoslobodsk', 'Krasnoslobodsk', 'Gorad Krasnaslabodsk,Krasnoslobodsk,Krasnoslobodsk i Mordovia,Krasnosłobodsk,Krasznoszlobodszk,Osh,ke la si nuo si luo bo ci ke,krasnwlwbdsk,krasnwslwbwdsk  mwrdwwya,Горад Краснаслабодск,Краснослободск,Краснослободск балһсн,Ош,كراسنولوبدسك,کراسنوسلوبودسک، موردوویا,克拉斯諾斯洛博茨克', 54.4253000, 43.7896300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120798, 'Krasnoslobodsk', 'Krasnoslobodsk', 'Gorad Krasnaslabodsk,Krasnaya Sloboda,Krasnoslobodsk,Krasnoslobodsk i Volgograd oblast,Krasnosłobodsk,Sloboda,ke la si nuo si luo bo ci ke,krasnwlwbdsk,krasnwslwbwdsk  awblast wlgwgrad,Горад Краснаслабодск,Краснослободск,Краснослободск балһсн,كراسنولوبدسك,کراسنوسلوبودسک، اوبلاست ولگوگراد,克拉斯諾斯洛博茨克', 48.7070800, 44.5770200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120799, 'Golovinskiy', 'Golovinskiy', 'Golovinskiy,Krasnooktjabr''skij,Krasnooktyabr''skiy,Krasnooktyabr’skiy,Краснооктябрьский', 55.8538100, 37.4960400, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120800, 'Krasnomayskiy', 'Krasnomayskiy', 'Klyuchino,Klyuchinskiy,Klyuchinskoy,Krasnoarmeyskiy,Krasnomajskij,Krasnomayskiy,Красномайский', 57.6194100, 34.4098700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120801, 'Krasnokumskoye', 'Krasnokumskoye', 'Krasnaya Slobodka,Krasnokumskoe,Krasnokumskoje,Krasnokumskoye,Краснокумское', 44.1780600, 43.5019400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120802, 'Krasnokholm', 'Krasnokholm', 'Krasnokholm,Krasnokholnskaya,Krasny-Kholm,Krasnyy Kholm,Краснохолм', 51.5978700, 54.1567000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120803, 'Krasnokamsk', 'Krasnokamsk', 'Gorad Krasnakamsk,Krasnokamsk,Krasznokamszk,ke la si nuo ka mu si ke,krasnwkamsk,Горад Краснакамск,Краснокамск,كراسنوكامسك,کراسنوکامسک,克拉斯諾卡姆斯克', 58.0796000, 55.7552000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120804, 'Krasnogvardeyskoye', 'Krasnogvardeyskoye', 'Biryuch,Budennoye,Budennyy,Krasnogvardejskoe,Krasnogvardejskoje,Krasnogvardeyskoye,Красногвардейское', 50.6492000, 38.4036000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120805, 'Krasnogvardeyskoye', 'Krasnogvardeyskoye', 'Krasnogvardejskoe,Krasnogvardejskoje,Krasnogvardeyskoye,Medvezh''ye,Medvezh’ye,Medweshe,Molotovskoye,Molotowskoje,Moltovskoye,Yevdokimovskoye,Красногвардейское', 45.8460400, 41.5188500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120806, 'Krasnogvardeyskoye', 'Krasnogvardeyskoye', 'Krasnogvardejskoe,Krasnogvardeyskoye,Nikolayevka,Nikolayevskoye,Красногвардейское', 45.1278000, 39.5724600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120807, 'Krasnogvardeyets', 'Krasnogvardeyets', 'Krasnogvardeec,Krasnogvardejets,Krasnogvardeyets,Umnovskiy,Красногвардеец', 52.6804000, 52.3635000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120808, 'Krasnogorskoye', 'Krasnogorskoye', 'Baryshnikovo,Krasnogorskoe,Krasnogorskoje,Krasnogorskoye,Красногорское', 57.7047000, 52.4999000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120809, 'Krasnogorskiy', 'Krasnogorskiy', 'Ilet'',Ilet’,Krasnogorskij,Krasnogorskiy,Krasnogorskoye,Илеть,Красногорский', 56.1525000, 48.3258300, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120810, 'Krasnogorsk', 'Krasnogorsk', 'Ban''ki,Ban’ki,Krasnogors''k,Krasnogorsk,Krasnogorsk i Moskva oblast,Krasnogorska,Krasnoqorsk,ke la si nuo ge er si ke,keulaseunogoleuseukeu,krasnwghwrsk,krasnwgwrsk,krasnwgwrsk  mskw,kurasunogorusuku,Красногорск,Красногорск балһсн,Красногорськ,كراسنوغورسك,کراسنوگورسک,کراسنوگورسک، مسکو,クラスノゴルスク,克拉斯諾戈爾斯克,크라스노고르스크', 55.8203600, 37.3301700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120811, 'Krasnogorodsk', 'Krasnogorodsk', 'Krasnogorodsk,Krasnogorodskoe,Krasnogorodskoye,Krasny,Krasnyy,Prigorod Krasnyy,Красногородск,Красногородское', 56.8356800, 28.2822400, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120812, 'Krasnofarfornyy', 'Krasnofarfornyy', 'Krasnofarforny,Krasnofarfornyj,Krasnofarfornyy,Краснофарфорный', 59.1364000, 31.8502300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120813, 'Krasnodar', 'Krasnodar', 'Ekaterinodar,KRR,Krasnodar,Krasnodara,Yekaterinodar,ke la si nuo da er,keulaseunodaleu,kurasunodaru,qrsnwdr,Краснодар,קרסנודר,クラスノダル,克拉斯诺达尔,크라스노다르', 45.0448400, 38.9760300, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120814, 'Krasnoborsk', 'Krasnoborsk', 'Krasnoborsk,Krasznoborszk,Красноборск,Կրասնոբորսկ', 61.5597800, 45.9339600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120815, 'Krasnoarmeyskoye', 'Krasnoarmeyskoye', 'Krasnoarmejskoe,Krasnoarmejskoje,Krasnoarmeyskoye,Peredniye Traki,Красноармейское', 55.7681300, 47.1724400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120816, 'Krasnoarmeyskoye', 'Krasnoarmeyskoye', 'Krasnoarmejskoe,Krasnoarmejskoje,Krasnoarmeyskoye,Красноармейское', 52.7199400, 50.0312200, 'RU', '2017-07-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120817, 'Krasnoarmeyskiy', 'Krasnoarmeyskiy', 'Krasnoarmejskij,Krasnoarmeyskiy,Tokmatskiy,Красноармейский', 47.0114000, 42.2072000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120818, 'Krasnoarmeyskaya', 'Krasnoarmeyskaya', 'Krasnoarmejskaja,Krasnoarmeyskaya,Krasnoarmeyskoye,Poltavskaja,Poltavskaya,Красноармейская,Полтавская', 45.3661400, 38.2117100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120819, 'Krasnoarmeysk', 'Krasnoarmeysk', 'Krasnoarmeisk,Krasnoarmejsk,Krasnoarmejsk i Moskva oblast,Krasnoarmeysk,Krasnoarmeyskiy,Krasnoarmeïsk,Krasnoarmiejsk,Krasnoarmijs''k,hong jun cheng,keulaseunoaleumeiseukeu,krasnwarmysk,krasnwarmysk  astan mskw,krasnwarmyysk,kurasunoarumeisuku,Красноармейск,Красноармейск балһсн,Красноармејск,Красноармійськ,كراسنوارميسك,کراسنوآرمیئسک,کراسنوارمیسک، استان مسکو,クラスノアルメイスク,紅軍城,크라스노아르메이스크', 56.1000000, 38.1333300, 'RU', '2012-04-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120820, 'Krasnoarmeysk', 'Krasnoarmeysk', 'Bal''tser,Bal’tser,Golyy Karamysh,Gorad Krasnaarmejsk,Krasnoarmeisk,Krasnoarmejsk,Krasnoarmejsk i Saratov oblast,Krasnoarmeysk,Krasnoarmeïsk,Krasnoarmijs''k,Pantsir,hong jun cheng,keulaseunoaleumeiseukeu,krasnwarmysk,krasnwarmysk  awblast saratwf,Горад Краснаармейск,Красноармейск,Красноармейск балһсн,Красноармејск,Красноармійськ,كراسنوارميسك,کراسنوارمیسک، اوبلاست ساراتوف,红军城,크라스노아르메이스크', 51.0238900, 45.6969400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120821, 'Krasnaya Zarya', 'Krasnaya Zarya', 'Krasnaja Zarja,Krasnaya Zarya,Volna,Красная Заря', 52.7825000, 37.6805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120822, 'Krasnaya Yaruga', 'Krasnaya Yaruga', 'Krasnaja Jaruga,Krasnaya Yaruga,Красная Яруга', 50.8008300, 35.6583300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120823, 'Presnenskiy', 'Presnenskiy', 'Krasnaja Presnja,Krasnaya Presnya,Presnenskij,Presnenskiy,Красная Пресня,Пресненский', 55.7500000, 37.5500000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120824, 'Krasnaya Poyma', 'Krasnaya Poyma', 'Krasnaja Pojma,Krasnaya Poyma,Красная Пойма', 55.0013800, 39.0799700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120825, 'Krasnaya Polyana', 'Krasnaya Polyana', 'Krasnaja Poljana,Krasnaya Polyana,Красная Поляна', 56.2420400, 51.1442500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120826, 'Krasnaya Polyana', 'Krasnaya Polyana', 'Krasnaja Poljana,Krasnaya,Krasnaya Polyana,Красная Поляна', 46.1129300, 41.5015700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120827, 'Krasnaya Polyana', 'Krasnaya Polyana', 'Krasnaja Poljana,Krasnaya Polyana,Красная Поляна', 45.0548000, 41.1031000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120828, 'Krasnaya Polyana', 'Krasnaya Polyana', 'Krasnaia Poliana,Krasnaja Poljana,Krasnaya Polyana,Krasnaïa Poliana,Krassnaja Poljana,Punase Lageda,Красная Поляна', 43.6795200, 40.2040300, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120829, 'Krasnaya Gorka', 'Krasnaya Gorka', 'Krasn.Gorka,Krasnaja Gorka,Krasnaya Gorka,Ostrov,Sobachiy Ostrov,Красн.Горка,Красная Горка', 55.3866600, 46.1092500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120830, 'Krasnaya Gorka', 'Krasnaya Gorka', 'Krasnaja Gorka,Krasnaya Gorka,Красная Горка', 55.1961700, 56.6672700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120831, 'Krasnaya Gorbatka', 'Krasnaya Gorbatka', 'Gorbatka,Krasn.Gorbatka,Krasnaja Gorbatka,Krasnaya Gorbatka,Красн.Горбатка,Красная Горбатка', 55.8703000, 41.7641000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120832, 'Krasnaya Gora', 'Krasnaya Gora', 'Krasnaja Gora,Krasnaya Gora,Красная Гора', 52.9995000, 31.6023000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120833, 'Kraskovo', 'Kraskovo', 'Kraskovo,Красково', 55.6497200, 37.9877800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120834, 'Krasavino', 'Krasavino', 'Gorad Krasavina,Krasavino,Krasawino,Krassavino,Krassawino,ke la sa wei nuo,krasafynw,krasawynw,Горад Красавіна,Красавино,كراسافينو,کراساوینو,克拉薩維諾', 60.9622500, 46.4832100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120835, 'Krapivna', 'Krapivna', 'Krapivna,Krepiwna,Крапивна', 53.9423500, 37.1574400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120836, 'Krasnokholmskiy', 'Krasnokholmskiy', 'Kranokholmskiy,Krasnokholmskij,Krasnokholmskiy,Краснохолмский', 55.9872900, 55.0465900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120837, 'Koz’modem’yansk', 'Koz''modem''yansk', 'Chykma,Cikma,Koz''modem''jansk,Koz''modem''yansk,Kozmedemyansk,Kozmodemjansk,Koz’modem’yansk,Козьмодемьянск,Цикмӓ,Чыкма', 56.3419000, 46.5635300, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120838, 'Kozlovo', 'Kozlovo', 'Kozlovo,Козлово', 56.5097700, 36.2732600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120839, 'Kozlovka', 'Kozlovka', 'Kozlovka,Козловка', 55.8428400, 48.2492000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120840, 'Kozlovka', 'Kozlovka', 'Kozlovka,Козловка', 50.8622200, 40.4555600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120841, 'Kozhva', 'Kozhva', 'Koshwa,Kozhva,Kozjva,Ust''-Kozhva,Ust’-Kozhva,Кожва', 65.1072700, 57.0459000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120842, 'Kozhukhovo', 'Kozhukhovo', 'Kozhukhovo,Кожухово', 55.7000000, 37.6666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120843, 'Kozeyevo', 'Kozeyevo', 'Kozeevo,Kozeyevo,Козеево', 55.8666700, 37.6166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120844, 'Kozel’sk', 'Kozel''sk', 'Kozel''sk,Kozelsk,Kozel’sk,Козельск', 54.0374600, 35.7715900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120845, 'Koygorodok', 'Koygorodok', 'Kaygorod,Kaygorodok,Kojgorodok,Koygorodok,Койгородок', 60.4449800, 50.9968000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120846, 'Kovylkino', 'Kovylkino', 'Gorad Kavylkina,Kovilkino,Kovjol osh,Kovykino,Kovylkino,Kowylkino,Kowyłkino,Lashma,ke wei er ji nuo,kwfylkynw,kwwylkynw,Горад Кавылкіна,Ковилкино,Ковилкіно,Ковылкино,Ковылкино балһсн,Ковёл ош,Лашма,كوفيلكينو,کوویلکینو,科維爾基諾', 54.0387600, 43.9138500, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120847, 'Kovrov', 'Kovrov', 'Gorad Kaurou,Kovrov,Kovrova,Kovrovas,Kowrow,kawrww,ke fu luo fu,kobeulopeu,kovurofu,kwfrwf,kwwrwf,Горад Каўроў,Ковров,كوفروف,کاوروو,کووروف,コヴロフ,科夫罗夫,코브로프', 56.3572200, 41.3191700, 'RU', '2016-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120848, 'Kovernino', 'Kovernino', 'Kovernino,Ковернино', 57.1281800, 43.8135000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120849, 'Kovdor', 'Kovdor', 'Gorad Kaudor,Kouteri,Koutero,Kovdor,Kovdoras,Kowdor,ke fu duo er,kwfdwr,kwwdwr,Горад Каўдор,Ковдор,كوفدور,کوودور,科夫多爾', 67.5661600, 30.4757600, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120850, 'Kotovsk', 'Kotovsk', 'Gorad Katousk,Kotovsk,Kotovsk i Russland,Kotowsk,ke tuo fu si ke,kwtwfsk,kwtwfsk  rwsyh,Горад Катоўск,Котовск,Котовск балһсн,كوتوفسك,کوتوفسک، روسیه,科托夫斯克', 52.5866600, 41.5021000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120851, 'Kotovo', 'Kotovo', 'Gorad Kotava,Katovo,Kotovo,Kotowo,Kótovo,ke tuo wo,kwtwfw,kwtwfw  awblast wlgwgrad,Горад Котава,Котово,Котово балһсн,كوتوفو,کوتوفو، اوبلاست ولگوگراد,科托沃', 50.3211300, 44.8011900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120852, 'Kotlyarevskaya', 'Kotlyarevskaya', 'Kotljarevskaja,Kotlyarevskaya,Kotlyareyskaya,Котляревская', 43.5734400, 44.0613400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120853, 'Kotlas', 'Kotlas', 'Gorad Kotlas,KSZ,Kotlas,Kotlass,Kotlasz,Kotłas,ke te la si,koteullaseu,kotorasu,kwtlas,Горад Котлас,Котлас,كوتلاس,کوتلاس,コトラス,科特拉斯,코틀라스', 61.2574500, 46.6496300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120854, 'Kotel’nikovo', 'Kotel''nikovo', 'Kotel''nikovo,Kotel''nikovskiy,Kotelnikowo,Kotelnikowskij,Kotel’nikovo,Kotel’nikovskiy,Котельниково', 47.6300900, 43.1406800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120855, 'Kotel’niki', 'Kotel''niki', 'Kotel''niki,Kotel`nika,Kotelniki,Kotel’niki,Котельники', 55.6354600, 37.8445000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120856, 'Kotel’nich', 'Kotel''nich', 'Kotel''nich,Kotelnitsj,Kotel’nich,Котельнич', 58.3089000, 48.3480000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120857, 'Kostrovo', 'Kostrovo', 'Kostrovo,Кострово', 55.8942900, 36.6949100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120858, 'Kostroma', 'Kostroma', 'Costroma,Gorad Kastrama,KMW,Kostrom,Kostroma,Kostromna,Kostromà,Kostromá,Kosztroma,ke si te luo ma,koseuteuloma,kosutoroma,kwstrwma,qwstrwmh,Горад Кастрама,Кострома,Կոստրոմա,קוסטרומה,كوستروما,کوستروما,კოსტრომა,コストロマ,科斯特羅馬,코스트로마', 57.7664700, 40.9268600, 'RU', '2012-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120859, 'Kostomuksha', 'Kostomuksha', 'Kostamus,Kostamuš,Kostomuksa,Kostomukscha,Kostomuksha,Kostomuksja,Kostomuksza,Kostomukŝa,Koštamuš,koseutomugsya,Костомукша,코스토묵샤', 64.5710000, 30.5766700, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120860, 'Kostino', 'Kostino', 'Kostino,Костино', 58.9096600, 53.2690700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120861, 'Kostino', 'Kostino', 'Kostino,Костино', 56.0333300, 37.9166700, 'RU', '2012-07-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120862, 'Kostek', 'Kostek', 'Keslek,Kestek,Kostek,Костек', 43.3438700, 46.8541100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120863, 'Kosmynino', 'Kosmynino', 'Kosminino,Kosmynino,Космынино', 57.5818300, 40.7643400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120864, 'Koslan', 'Koslan', 'Koslan,Кослан', 63.4564100, 48.8989100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120865, 'Kosino', 'Kosino', 'Kosino,Косино', 58.4127200, 51.2781900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120866, 'Koshki', 'Koshki', 'Koshki,Kosjki,Кошки', 54.2091400, 50.4676700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120867, 'Koshekhabl’', 'Koshekhabl''', 'Koshekhabl'',Koshekhabl’,Kosjekhabl,Кошехабль', 44.8972200, 40.5119400, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120868, 'Kosaya Gora', 'Kosaya Gora', 'Kosaja Gora,Kosaya Gora,Poselok Kosaya Gora,Posëlok Kosaya Gora,Косая Гора', 54.1189600, 37.5445900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120869, 'Kosa', 'Kosa', 'Kosa,Коса', 59.9449000, 54.9895000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120870, 'Korzhovka-Golubovka', 'Korzhovka-Golubovka', 'Korzhov-Golubovka,Korzhovka-Golubovka,Korzjovo-Golubovka,Polustanok Robchik,Коржов-Голубовка,Коржовка-Голубовка', 52.7674200, 32.3536200, 'RU', '2015-12-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120871, 'Korzhevskiy', 'Korzhevskiy', 'Korzhevskij,Korzhevskiy,Korzjevskij,Коржевский', 45.1941400, 37.7194900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120872, 'Koryazhma', 'Koryazhma', 'Korjazhma,Korjazjma,Koryazhemka,Koryazhemskaya,Koryazhma,Koryazma,Коряжма', 61.3143300, 47.1691400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120873, 'Kortkeros', 'Kortkeros', 'Kortker,Kortkeres,Kortkeros,Kortkerës,Kortkores,Корткерос', 61.8105600, 51.5805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120874, 'Korsakovo', 'Korsakovo', 'Korsakovo,Корсаково', 53.2676700, 37.3568900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120875, 'Korotoyak', 'Korotoyak', 'Korotojak,Korotoyak,Коротояк', 50.9866500, 39.1767700, 'RU', '2015-09-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120876, 'Korocha', 'Korocha', 'Koracha,Korocha,Korotsja,Короча', 50.8132000, 37.1859800, 'RU', '2017-01-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120877, 'Korobitsyno', 'Korobitsyno', 'Korobicyno,Korobitsyno,Paeivilae,Päivilä,Коробицыно', 60.5152300, 29.7243700, 'RU', '2016-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120878, 'Kormëzhka', 'Kormezhka', 'Kormezhka,Kormezjka,Kormjozhka,Kormëzhka,Кормежка,Кормёжка', 51.9005000, 48.0163000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120879, 'Korenovsk', 'Korenovsk', 'Gorad Karanousk,Korenivs''k,Korenovsk,Korenovskaya,Korenowsk,Korenowskaja,Korienowsk,Korjenowsk,ke lie nuo fu si ke,kwrnwfsk,Горад Караноўск,Кореновск,Кореновск балһсн,Коренівськ,كورنوفسك,کورنوفسک,科列諾夫斯克', 45.4689900, 39.4513600, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120880, 'Korenëvo', 'Korenevo', 'Korenevo,Korenjovo,Korenëvo,Коренёво', 55.6719400, 38.0077800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120881, 'Korenëvo', 'Korenevo', 'Korenevo,Korenewo,Korenjovo,Korenëvo,Коренево,Коренёво', 51.4119000, 34.9080000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120882, 'Korablino', 'Korablino', 'Gorad Karablina,Korablino,Korablinó,ke la bu li nuo,kolabeullino,koraburino,kwrablynw,Горад Карабліна,Кораблино,Кораблино балһсн,كورابلينو,کورابلینو,コラブリノ,科拉布利諾,코라블리노', 53.9163900, 40.0133300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120883, 'Koptëvo', 'Koptevo', 'Koptevo,Koptjovo,Koptëvo,Коптёво', 55.8166700, 37.5166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120884, 'Kopor’ye', 'Kopor''ye', 'Kabrio,Kaprio,Kopor''e,Kopor''ye,Koporje,Kopor’e,Kopor’ye,Копорье', 59.7106700, 29.0348800, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120885, 'Kopanskaya', 'Kopanskaya', 'Kopanskaja,Kopanskaya,Копанская', 46.2778500, 38.4795500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120886, 'Konyshevka', 'Konyshevka', 'Konishevka,Konyshevka,Konysjevka,Конышевка', 51.8418000, 35.2941000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120887, 'Konstantinovskoye', 'Konstantinovskoye', 'Konstaninovka,Konstantinovka,Konstantinovskoe,Konstantinovskoje,Konstantinovskoye,Константиновское', 45.2991700, 42.6366700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120888, 'Konstantinovskiy', 'Konstantinovskiy', 'Konstantinovo,Konstantinovskij,Konstantinovskiy,Константиновский', 57.8300500, 39.5898900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120889, 'Konstantinovskaya', 'Konstantinovskaya', 'Konstantinovskaja,Konstantinovskaya,Konstantinowskaja,Константиновская', 44.8352800, 40.7269400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120890, 'Konstantinovskaya', 'Konstantinovskaya', 'Konstantinovskaja,Konstantinovskaya,Константиновская', 44.0455600, 43.1583300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120891, 'Konstantinovsk', 'Konstantinovsk', 'Gorad Kanstancinausk,Konstantinovs''k,Konstantinovsk,Konstantinovskaja,Konstantinovskaya,Konstantinovskiy,Konstantinowsk,Konstantinowskaja,Konstantinowskoje,kang si tan ding nuo fu si ke,knstantynwfsk,kwnstantynwfsk,Горад Канстанцінаўск,Константиновск,Константиновск балһсн,Константиновская,Константиновськ,Կոնստանտինովսկ,كونستانتينوفسك,کنستانتینوفسک,康斯坦丁諾夫斯克', 47.5827800, 41.0922200, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120892, 'Konstantinovo', 'Konstantinovo', 'Konstantinovo,Константиново', 56.5500000, 38.0333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120893, 'Konosha', 'Konosha', 'Konosha,Konosja,Коноша', 60.9736000, 40.2570000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120894, 'Konokovo', 'Konokovo', 'Kanokovo,Konokovo,Коноково', 44.8616000, 41.3266000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120895, 'Konobeyevo', 'Konobeyevo', 'Konobeevo,Konobejevo,Konobeyevo,Конобеево', 55.4077600, 38.6626100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120896, 'Konëvo', 'Konevo', 'Konevo,Konjovo,Konëvo,Конево,Конёво', 62.1174500, 39.3313100, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120897, 'Kondrovo', 'Kondrovo', 'Kondrova,Kondrovo,Kondrowo,Kóndrovo,Troitskoye,kondeulobo,kondorovu~o,kong de luo wo,kwndrwfw,Кондрово,كوندروفو,کوندروفو,コンドロヴォ,孔德羅沃,콘드로보', 54.8063900, 35.9277800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120898, 'Kondopoga', 'Kondopoga', 'Gorad Kandapoga,Kondopog,Kondopoga,Kondupohju,Kontupohja,Tonopoga,kondopoga,kong duo bo jia,kwndwbwgha,kwndwpwga,Горад Кандапога,Кондопога,كوندوبوغا,کوندوپوگا,コンドポガ,孔多波加,콘도포가', 62.2056500, 34.2613800, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120899, 'Kondol’', 'Kondol''', 'Kondol,Kondol'',Kondol’,Кондоль', 52.8188900, 45.0579800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120900, 'Konakovo', 'Konakovo', 'Gorad Kanakova,Konakovo,Konakowo,Kuznetsova,Kuznetsovo,ke na ke wo,konakobo,konakovu~o,kwnakwfw,Горад Канакова,Конаково,كوناكوفو,کوناکوفو,コナコヴォ,科納科沃,코나코보', 56.7000000, 36.7666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120901, 'Komsomol''skoye', 'Komsomol''skoye', 'Bol''shiye Koshelei,Bol''shoy Kosheley,Komsomol''skoe,Komsomol''skoye,Komsomolskoje,Kosheley,Комсомольское', 55.2566700, 47.5460800, 'RU', '2010-01-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120902, 'Komsomol’skiy', 'Komsomol''skiy', 'Komsomol''skij,Komsomol''skiy,Komsomolskij,Komsomol’skiy,Krasnyy Kamyshanik,Комсомольский', 45.3300000, 46.0428000, 'RU', '2016-05-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120903, 'Komsomol’skiy', 'Komsomol''skiy', 'Komsomol''skij,Komsomol''skiy,Komsomolskij,Komsomol’skiy,Комсомольский', 43.9783300, 46.6985200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120904, 'Komsomol’sk', 'Komsomol''sk', 'Komsomol''sk,Komsomol’sk,Комсомольск', 57.0291300, 40.3726600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120905, 'Komsomolets', 'Komsomolets', 'Komsomolec,Komsomolets,Sovkhoz Komsomolets,Комсомолец', 52.7686000, 41.2868300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120906, 'Komsomolets', 'Komsomolets', 'Komsomolec,Komsomolets,Комсомолец', 44.0197200, 43.5697200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120907, 'Kommunarka', 'Kommunarka', 'Kommunarka,Sovkhoz Kommunarka,Коммунарка', 55.5695200, 37.4893200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120908, 'Kommunar', 'Kommunar', 'Gorad Kamunar,Kommoenar,Kommounar,Kommunar,Kommunar i Leningrad oblast,Komunar,Komunara,ke mu na er,komunaru,kwmwnar,kwmwnar  awblast lnyngrad,Горад Камунар,Коммунар,Комунар,كومونار,کومونار، اوبلاست لنینگراد,კომუნარი,コムナル,科穆納爾', 59.6205600, 30.3900000, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120909, 'Kommunar', 'Kommunar', 'Kommunar,Коммунар', 56.1122200, 40.4466600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120910, 'Komarovo', 'Komarovo', 'Kellomaeki,Kellomaki,Kellomayki,Kellomäki,Kelomyaki,Kelomyakki,Komarovo,Komarowo,Комарово', 60.1866000, 29.8086500, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120911, 'Komarikhinskiy', 'Komarikhinskiy', 'Komarikha,Komarikhinskaya,Komarikhinskij,Komarikhinskiy,Комарихинский', 58.0979000, 57.1163000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120912, 'Komarichi', 'Komarichi', 'Komarich,Komarichi,Komaritschi,Komaritsji,Комаричи', 52.4151000, 34.7905000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120913, 'Kolyubakino', 'Kolyubakino', 'Koljubakino,Kolyubakino,Kolyubakovo,Колюбакино', 55.6680000, 36.5323400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120914, 'Kolyshley', 'Kolyshley', 'Kolishlei,Kolyshlej,Kolyshley,Kolysjlej,Колышлей', 52.7005000, 44.5367000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120915, 'Koltushi', 'Koltushi', 'Keltto,Koltushi,Колтуши', 59.9296900, 30.6446500, 'RU', '2012-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120916, 'Koltubanovskiy', 'Koltubanovskiy', 'Koltubanka,Koltubanovskij,Koltubanovskiy,Kotlubanka,Колтубановский', 52.9407000, 52.0269000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120917, 'Kolpny', 'Kolpny', 'Kolpna,Kolpny,Колпны', 52.2282300, 37.0368300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120918, 'Kolpino', 'Kolpino', 'Gorad Kolpina,Koljpino,Kolpina,Kolpinas,Kolpino,Kolppina,Kołpino,ke er pi nuo,kolpino,kwlbynw,kwlpynw,Горад Колпіна,Колпино,كولبينو,کولپینو,კოლპინო,科爾皮諾,콜피노', 59.7506900, 30.5885600, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120919, 'Yanino-1', 'Yanino-1', 'Jaanila,Janino-1,Koloniya Yanina,Koloniya Yanino,Nikol''skoe,Nikol''skoye,Nikol’skoye,Saksan Jaanila,Yanino Pervoye,Никольское,Янино-1', 59.9480800, 30.5591400, 'RU', '2016-08-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120920, 'Kolomyagi', 'Kolomyagi', 'Kolomaeki,Kolomjagi,Kolomyagi,Kolomäki,Коломяги', 60.0242700, 30.2849100, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120921, 'Kolomna', 'Kolomna', 'Columna,Gorad Kalomna,Kolom''na,Kolomna,Kolomnae,Kolomno,Kołomna,ke luo mu na,kollomna,koromuna,kwlwmna,qwlwmnh,Горад Каломна,Коломнæ,Коломна,Коломна балһсн,Коломно,Коломьна,Կոլոմնա,קולומנה,كولومنا,کولومنا,コロムナ,科洛姆纳,콜롬나', 55.0794400, 38.7783300, 'RU', '2016-10-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120922, 'Kolomenskoye', 'Kolomenskoye', 'Kolomenskoe,Kolomenskoye,Коломенское', 55.6666700, 37.6833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120923, 'Kologriv', 'Kologriv', 'Kologriv,Kologriw,Kołogriw,ke luo ge li fu,kollogeulipeu,korogurifu,kwlwghryf,kwlwgryf,Кологрив,كولوغريف,کولوگریف,コログリフ,科洛格里夫,콜로그리프', 58.8274800, 44.3177700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120924, 'Kolodeznyy', 'Kolodeznyy', 'Kolodeznyj,Kolodeznyy,Колодезный', 51.3333300, 39.1833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120925, 'Kolobovo', 'Kolobovo', 'Kolobovo,Колобово', 56.7019900, 41.3417300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120926, 'Kol’chugino', 'Kol''chugino', 'Kellerovo,Kol''chugino,Koltschugino,Koltsjugino,Kol’chugino,Кольчугино', 56.2992900, 39.3830400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120927, 'Kolchanovo', 'Kolchanovo', 'Kolchanovo,Koltsjanovo,Колчаново', 60.0164700, 32.5883700, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120928, 'Kola', 'Kola', 'Cola,Gorad Kola,Gorod Kola,Guoladat,Guoládat,Kol,Kola,Kolo,Kualok,Kuola,Kuâlõk,ke la,kola,kolla,kora,kwla,Горад Кола,Кола,Коло,كولا,کولا,कोला,コラ,科拉,콜라', 68.8806200, 33.0184200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120929, 'Koksovyy', 'Koksovyy', 'Koksovyj,Koksovyy,Коксовый', 48.2005800, 40.6508900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120930, 'Kokoshkino', 'Kokoshkino', 'Kokoshkino,Кокошкино', 55.5976900, 37.1695000, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120931, 'Kokorevka', 'Kokorevka', 'Kokorevka,Кокоревка', 52.5874000, 34.2692000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120932, 'Kokino', 'Kokino', 'Kokina,Kokino,Кокино', 52.4964000, 34.7808000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120933, 'Kokhma', 'Kokhma', 'Kochma,Kohma,Kokhma,Koxma,Koĥma,ke he ma,kwkhma,Кохма,كوخما,کوخما,科赫馬', 56.9348700, 41.0915000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120934, 'Kodino', 'Kodino', 'Kodino,Кодино', 63.7197600, 39.6446500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120935, 'Kochkurovo', 'Kochkurovo', 'Kochkurovo,Kotsjkurovo,Кочкурово', 54.0357600, 45.4184500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120936, 'Kochevo', 'Kochevo', 'Kochevo,Kotsjevo,Кочево', 59.5974000, 54.3147000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120937, 'Kobrinskoye', 'Kobrinskoye', 'Kobrino,Kobrinskoe,Kobrinskoje,Kobrinskoye,Кобринское', 59.4225000, 30.1238900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120938, 'Knyaginino', 'Knyaginino', 'Knjaginino,Knyaginin,Knyaginino,Knyayinino,Княгинино', 55.8227800, 45.0348900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120939, 'Klyavlino', 'Klyavlino', 'Kljavlino,Klyavlino,Клявлино', 54.2649100, 52.0267400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120940, 'Klintsy', 'Klintsy', 'Gorad Klincy,Klincad,Klince,Klinci,Klincy,Klinti,Klintsi,Klintso,Klintsy,Klintsõ,Klinzy,Klințî,Klińce,Kļinci,ke lin qi,keullinchi,klntsy,klyntsy,kurintsu~i,qlynzy,Горад Клінцы,Клинтси,Клинци,Клинцы,Клинцы балһсн,Клинці,קלינצי,كلينتسي,کلنتسی,کلینتسی,クリンツィ,克林齊,클린치', 52.7601900, 32.2393500, 'RU', '2016-12-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120941, 'Klin', 'Klin', 'Gorad Klin,Klin,Klina,Kline,Kļina,Ulin,ke lin,keullin,kln,klyn,kurin,Горад Клін,Клин,Клин балһсн,كلين,کلن,کلین,クリン,克林,클린', 56.3333300, 36.7333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120942, 'Klimovsk', 'Klimovsk', 'Gorad Klimausk,Klimovs''k,Klimovsk,Klimovska,Klimovskaj,Klimovskas,Klimovskiy,Klimowsk,Kļimovska,ke li mo fu si ke,klymwfsk,klymwwsk,kurimofusuku,Горад Клімаўск,Климовск,Климовск балһсн,Климовскай,Климовськ,كليموفسك,کلیموفسک,کلیمووسک,クリモフスク,克利莫夫斯克', 55.3635200, 37.5298400, 'RU', '2015-09-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120943, 'Klimovo', 'Klimovo', 'Klimov,Klimovo,Климово', 52.3805300, 32.1923300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120944, 'Kletskaya', 'Kletskaya', 'Kletskaja,Kletskaya,Kletskij,Kletskiy,Klyetskaya,Клетская,Клетский', 49.3145500, 43.0584400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120945, 'Kletnya', 'Kletnya', 'Kletnja,Kletnya,Lyudinka,Клетня', 53.3896700, 33.2171400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120946, 'Kizner', 'Kizner', 'Kizner,Кизнер', 56.2748900, 51.5080000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120947, 'Kizlyar', 'Kizlyar', 'Kisljar,Kizilyar,Kizlar,Kizljar,Kizlyar,kijeullyaleu,kizljar,Кизляр,키즐랴르', 43.8471200, 46.7144500, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120948, 'Kizlyar', 'Kizlyar', 'Kizljar,Kizlyar,Kizlyarskoye,Кизляр', 43.7037900, 44.5944000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120949, 'Kizilyurt', 'Kizilyurt', 'Chir-Yurt,Kiziljurt,Kizilyurt,Kizyl-Yurt,Tschir-jurt,Кизилюрт', 43.2069700, 46.8679000, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120950, 'Kizema', 'Kizema', 'Kizema,Kizima,Кизема', 61.1130400, 44.8301700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120951, 'Kizel', 'Kizel', 'Gorad Kizel,Kisel,Kizel,Kiziel,Kizieł,Kydzol,Kydzol'',Kízel,ji ze er,kyzl,Горад Кізел,Кизел,Кыдзоль,Кыдзӧл,Кізел,كيزل,کیزل,基澤爾', 59.0470900, 57.6476700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120952, 'Kiyevskoye', 'Kiyevskoye', 'Kievskaya,Kievskoe,Kievskoi,Kiewskoje,Kijevskoje,Kiyevskoye,Киевское', 45.0382900, 37.8882900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120953, 'Kiyasovo', 'Kiyasovo', 'Kijasovo,Kiyasovo,Киясово', 56.3490700, 53.1243900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120954, 'Kitskovo', 'Kitskovo', 'Kickovo,Kitskovo,Кицково', 56.4107700, 28.7980100, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120955, 'Kitovo', 'Kitovo', 'Kitovo,Китово', 56.8658600, 41.2824600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120956, 'Kislyakovskaya', 'Kislyakovskaya', 'Kishakovskaya,Kisljakovskaja,Kislyakovskaya,Kizlyakovskaya,Кисляковская', 46.4417000, 39.6750000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120957, 'Kislovodsk', 'Kislovodsk', 'Gorad Kislavodsk,Kislovods''k,Kislovodsk,Kislovodsk - Kislovodsk,Kislovodsk - Кисловодск,Kislovodskas,Kislowodsk,Kislowodzk,Kisslowodsk,Kisłowodzk,Nartsaneh,ji ci luo wo ci ke,kiseullobocheukeu,kisurovu~otsuku,kslwwwdsk,kyslwfwdsk,qyslwbwdsq,Горад Кіславодск,Кисловодск,Кисловодск балһсн,Кисловодськ,Нартсанэ,Կիսլովոդսկ,קיסלובודסק,كيسلوفودسك,کسلووودسک,کیسلوفودسک,キスロヴォツク,基兹洛沃茨克,키슬로보츠크', 43.9133300, 42.7208300, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120958, 'Kishpek', 'Kishpek', 'Kishpek,Kisjpek,Кишпек', 43.6550000, 43.6408300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120959, 'Kirzhach', 'Kirzhach', 'Gorad Kirzhach,Kirjac,Kirjatch,Kirjatx,Kirschatsch,Kirshatsch,Kirzac,Kirzacz,Kirzats,Kirzhach,Kirzjatj,Kirzjatsj,Kirĵaĉ,Kirżacz,Kiržatš,Kiržač,ji er zha qi,kileujachi,kirujachi,kyrjatsh,kyrzhach,Горад Кіржач,Киржач,Кіржач,كيرجاتش,کیرژاچ,キルジャチ,基爾扎奇,키르자치', 56.1527300, 38.8550900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120960, 'Kirya', 'Kirya', 'Kirja,Kirya,Киря', 55.0810200, 46.8609100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120961, 'Kirsanov', 'Kirsanov', 'Gorad Kirsanau,Kirsanov,Kirsanow,Kirsànov,Kirsánov,ji er sa nuo fu,kyrsanwf,Горад Кірсанаў,Кирсанов,Кирсанов балһсн,كيرسانوف,کیرسانوف,基爾薩諾夫', 52.6549400, 42.7223600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120962, 'Kirs', 'Kirs', 'Gorad Kirs,Kirs,Kirsinskiy,Kirsz,ji er si,kyrs,kyrs  rwsyh,Горад Кірс,Кирс,كيرس,کیرس، روسیه,基爾斯', 59.3388200, 52.2446700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120963, 'Kirovskiy', 'Kirovskiy', 'Kirovskij,Kirovskiy,Кировский', 51.4166700, 36.6666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120964, 'Kirovskiy', 'Kirovskiy', 'Bol''shaya Pavlova,Bol’shaya Pavlova,Kirovskij,Kirovskiy,Кировский', 45.8463900, 48.1247200, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120965, 'Kirovskaya', 'Kirovskaya', 'Kirovskaja,Kirovskaya,Кировская', 46.9748000, 40.0402000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120966, 'Kirovsk', 'Kirovsk', 'Gorad Kirausk,Hiipina,Hiipinae,Hiipinä,KVK,Khibinogorsk,Kirovs''k,Kirovsk,Kirovskas,Kirowsk,Kírovsk,ji luo fu si ke,kilobseukeu,kirofusuku,kyrwfsk,kyrwfsk  awblast mwrmansk,Горад Кіраўск,Кировск,Кіровськ,كيروفسك,کیروفسک، اوبلاست مورمانسک,キロフスク,基洛夫斯克,키롭스크', 67.6147500, 33.6727400, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120967, 'Kirovsk', 'Kirovsk', 'Gorad Kirausk,Imeni Kirova,Kirovs''k,Kirovsk,Kirovsk i Leningrad oblast,Kirovska,Kirowsk,Korotka,Kírovsk,Pervoye Gorodok,Vtoroy Gorodok,ji luo fu si ke,kilobseukeu,kyrwfsk,kyrwfsk  awblast lnyngrad,Горад Кіраўск,Кировск,Кіровськ,كيروفسك,کیروفسک، اوبلاست لنینگراد,კიროვსკი,基洛夫斯克,키롭스크', 59.8810100, 30.9950700, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120968, 'Kirovo-Chepetsk', 'Kirovo-Chepetsk', 'Chepets,Chepetsk,Cheptsa,Gorad Kirava-Chapeck,Kirovo Chepetsk,Kirovo-Cepeck,Kirovo-Cepetsk,Kirovo-Chepec''k,Kirovo-Chepeck,Kirovo-Chepetsk,Kirovo-Chepetskiy,Kirovo-Tchepetsk,Kirovo-Tsepetsk,Kirovo-Tsjepetsk,Kirovo-Tšepetsk,Kirovo-Çepetsk,Kirovo-Ĉepeck,Kirovo-Čepeck,Kirowo-Czepieck,Kirowo-Tschepezk,Ust''-Chepetskoye,Ust''-Cheptsa,Ust’-Chepetskoye,Ust’-Cheptsa,ji luo wo-qie pei ci ke,kilobochepecheukeu,kyrwfw-chptsk,kyrwfw-tshybytsk,kyrww chpytsk,Горад Кірава-Чапецк,Кирово-Чепетск,Кирово-Чепецк,Кірово-Чепецьк,كيروفو-تشيبيتسك,کیروفو-چپتسک,کیروّو چپیتسک,基洛沃-切佩茨克,키로보체페츠크', 58.5538600, 50.0398600, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120969, 'Kirov', 'Kirov', 'Gorad Kirau,KVX,Khlynov,Kirof,Kirov,Kirov i Kirov oblast,Kirova,Kirovas,Kirow,Kírov,Viatka,Vyatka,Wjatka,ji luo fu,kilopeu,kirofu,kirova,kyrwf,kyrwf  kyrwf awblast,kyrww,qyrwb,Горад Кіраў,Киров,Кіров,Կիրով,קירוב,كيروف,کیروف,کیروف، کیروف اوبلاست,کیروو,किरोव,კიროვი,キーロフ,基洛夫,키로프', 58.5966500, 49.6600700, 'RU', '2013-10-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120970, 'Kirov', 'Kirov', 'Kirov,Kirov i Kaluga oblast,Kirovo,Kirow,Kírov,Pesochnaya,Pesochnya,ji luo fu,kilopeu,kirofu,kyrwf,kyrwf  awblast kalwga,Киров,كيروف,کیروف، اوبلاست کالوگا,キーロフ,基洛夫,키로프', 54.0668600, 34.2995500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120971, 'Kiritsy', 'Kiritsy', 'Kiricy,Kiritsy,Кирицы', 54.2862000, 40.3572000, 'RU', '2014-10-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120972, 'Kirishi', 'Kirishi', 'Gorad Kiryshy,Kirichi,Kirisai,Kirischi,Kirishi,Kirisi,Kirisji,Kiriszy,Kiriŝi,Kirišai,Kiriši,Kiriși,Kírishi,ji li xi,kilisi,kyryshy,Горад Кірышы,Кириши,Кіріши,كيريشي,کیریشی,კირიში,基里希,키리시', 59.4471200, 32.0204900, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120973, 'Kirillov', 'Kirillov', 'Kirillov,Кириллов', 59.8629900, 38.3812800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120974, 'Kirgiz-Miyaki', 'Kirgiz-Miyaki', 'Kirgiz-Mayaki,Kirgiz-Mijaki,Kirgiz-Miyaki,Киргиз-Мияки,Киргиз-Міяки,Кыргыз-Миякә,Ҡырғыҙ-Миәкә,Կիրգիզ-Միյակի', 53.6324000, 54.7979000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120975, 'Kireyevsk', 'Kireyevsk', 'Kireevsk,Kireievsk,Kirejevsk,Kirejewsk,Kireyevka,Kireyevsk,Kireïevsk,Kiriejewsk,Kirjejewsk,Kiréyevsk,ji lie ye fu si ke,kileyebseukeu,kireefusuku,kyryfsk,kyryyfsk,Киреевск,Кирејевск,كيرييفسك,کیریفسک,キレーエフスク,基列耶夫斯克,키레옙스크', 53.9336100, 37.9279200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120976, 'Kingisepp', 'Kingisepp', 'Gorad Kingisep,Jaama,Jamburg,Juama,Kinghisepp,Kingisep,Kingisepa,Kingisepp,Kingiseppu,Kingissepp,Kinguissepp,Yamburg,jin ji xie pu,king-gisepeu,kingisepeu,kingiseppu,kynghysyb,kyngysp,kyngysyp,qyngysp,Горад Кінгісеп,Кингисеп,Кингисепп,Кингисєппъ,Кінгісепп,קינגיספ,كينغيسيب,کینگیسپ,کینگیسیپ,კინგისეპი,キンギセップ,金吉谢普,킨기세프,킹기세프', 59.3733100, 28.6134300, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120977, 'Kineshma', 'Kineshma', 'Gorad Kineshma,Kinechma,Kineixma,Kineschma,Kineshima,Kineshma,Kineshme,Kinesjma,Kinesma,Kineszma,Kineŝma,Kineşma,Kinešma,Kineșma,Kiněšma,Kíneixma,Kíneshma,ji nie shen ma,kineshima,kinesima,kinesyuma,kynshma,kynyshma,Горад Кінешма,Кинешма,Кинешме,Киңәшмә,Кінешма,كينيشما,کینشما,کینیشما,キネシマ,基涅什马,키네슈마,키네시마', 57.4391400, 42.1289400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120978, 'Kinel’-Cherkassy', 'Kinel''-Cherkassy', 'Kinel''-Cherkassy,Kinel''-Cherkasy,Kinel’-Cherkassy,Kinel’-Cherkasy,Кинель-Черкассы', 53.4706000, 51.4743100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120979, 'Kinel’', 'Kinel''', 'Kinel,Kinel'',Kinel’,Кинель', 53.2257100, 50.6290700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120980, 'Kimry', 'Kimry', 'Gorad Kimry,Kimrai,Kimri,Kimro,Kimry,Kimrî,Kimrõ,Kimrı,ji mu lei,kimli,kimuru~i,kymry,Горад Кімры,Кимри,Кимры,Кімри,كيمري,کیمری,キームルィ,基姆雷,킴리', 56.8666700, 37.3500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120981, 'Kimovsk', 'Kimovsk', 'Bol''shaya Mikhaylovka,Bol’shaya Mikhaylovka,Gorad Kimausk,Kimovsk,Kimowsk,Kímovsk,Mikhaylovka,ji mo fu si ke,kimobseukeu,kimofusuku,kymwfsk,Горад Кімаўск,Кимовск,كيموفسك,کیموفسک,キモフスク,基莫夫斯克,키몹스크', 53.9716400, 38.5318600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120982, 'Kil’mez’', 'Kil''mez''', 'Kil''ma,Kil''mez'',Kil’ma,Kil’mez’,Кильмезь', 56.9438900, 51.0650000, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120983, 'Kilemary', 'Kilemary', 'Kilemary,Килемары', 56.7782500, 46.8659400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120984, 'Kikvidze', 'Kikvidze', 'Kikvidse,Kikvidze,Preobrazhenka,Preobrazhenskaja,Preobrazhenskaya,Киквидзе,Преображенская', 50.7416100, 43.0518000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120985, 'Kiknur', 'Kiknur', 'Kiknur,Кикнур', 57.3034100, 47.2010500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120986, 'Kikerino', 'Kikerino', 'Kikerino,Kikkeri,Кикерино', 59.4646600, 29.6272900, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120987, 'Kideksha', 'Kideksha', 'Kideksha,Кидекша', 56.4238100, 40.5214600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120988, 'Kichmengskiy Gorodok', 'Kichmengskiy Gorodok', 'Kichmengskij Gorodok,Kichmengskiy Gorodok,Kichmenskiy Gorodok,Kitsjmengskij Gorodok,Кичменгский Городок', 59.9816400, 45.7854300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120989, 'Khvoynaya', 'Khvoynaya', 'Chwoinaja,Khvojnaja,Khvoynaya,Хвойная', 58.9000000, 34.5333300, 'RU', '2015-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120990, 'Khvorostyanka', 'Khvorostyanka', 'Khvorostjanka,Khvorostyahka,Khvorostyanka,Хворостянка', 52.6096000, 48.9597000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120991, 'Khvatovka', 'Khvatovka', 'Khvatovka,Хватовка', 52.3523600, 46.5628200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120992, 'Khvastovichi', 'Khvastovichi', 'Khastovichi,Khvastovichi,Khvastovitsji,Хвастовичи', 53.4694200, 35.0940900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120993, 'Khvalynsk', 'Khvalynsk', 'Chvalynsk,Chwalynsk,Chwałyńsk,Gorad Khvalynsk,Hvalinsk,Hvalynsk,Jvalynsk,Khvalins''k,Khvalinsk,Khvalynsk,Xvalinsk,Xvalınsk,he wa lun si ke,heuballinseukeu,khfalynsk,khwalynsk,Ĥvalinsk,Горад Хвалынск,Хвалинск,Хвалинськ,Хвалынск,Хвалынск балһсн,خفالينسك,خوالینسک,赫瓦倫斯克,흐발린스크', 52.4906000, 48.1058000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120994, 'Khvalovo', 'Khvalovo', 'Khvalovo,Хвалово', 59.9477400, 32.7372300, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120995, 'Khunzakh', 'Khunzakh', 'Khumsakh,Khunzakh,Хунзах', 42.5424000, 46.7068900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120996, 'Khumalag', 'Khumalag', 'Khumalag,Хумалаг', 43.2403100, 44.4752100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120997, 'Khuchni', 'Khuchni', 'Khuchni,Khunchi,Khutsjni,Хучни', 41.9498600, 47.9485400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120998, 'Khryashchevka', 'Khryashchevka', 'Khrjashhevka,Khrjasjtsjevka,Khryashchevka,Khryashcheyevka,Хрящевка', 53.8119000, 49.0916000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(120999, 'Khrenovoye', 'Khrenovoye', 'Chernowje,Chrenowje,Khrenovo,Khrenovoe,Khrenovoje,Khrenovoye,Хреновое', 51.1200000, 40.2888900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121000, 'Khrabrovo', 'Khrabrovo', 'Chrabroe,Hrabrovo,Khrabrovo,Povunden,Powanden,Powunden,Powuneen,Храброво', 54.8970900, 20.5803500, 'RU', '2016-10-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121001, 'Khotynets', 'Khotynets', 'Khotinets,Khotynec,Khotynets,Хотынец', 53.1286000, 35.3966000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121002, 'Khot''kovo', 'Khot''kovo', 'Khot''kovo,Хотьково', 56.2569900, 37.9954400, 'RU', '2008-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121003, 'Khosta', 'Khosta', 'Khosta,Хоста', 43.5148400, 39.8682500, 'RU', '2013-01-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121004, 'Khoroshëvo-Mnevniki', 'Khoroshevo-Mnevniki', 'Khoroshevo,Khoroshevo-Mnevniki,Khoroshjovo,Khoroshëvo,Khoroshëvo-Mnevniki,Хорошёво', 55.7836300, 37.4713700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121005, 'Khorlovo', 'Khorlovo', 'Khorlovo,Хорлово', 55.3327000, 38.8136500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121006, 'Khomutovo', 'Khomutovo', 'Khomutovo,Khomutovskiy,Хомутово', 52.8538600, 37.4388000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121007, 'Khomutovka', 'Khomutovka', 'Khomutovka,Хомутовка', 51.9207000, 34.5619000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121008, 'Kholm-Zhirkovskiy', 'Kholm-Zhirkovskiy', 'Kholm,Kholm Zhirkovskij,Kholm Zjirkovskij,Kholm-Zhirkovskij,Kholm-Zhirkovskiy,Zhirkovskiy,Холм Жирковский,Холм-Жирковский', 55.5188900, 33.4730600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121009, 'Kholmskiy', 'Kholmskiy', 'Cholmskaja,Kholmskaja,Kholmskaya,Kholmskij,Kholmskiy,Холмская,Холмский', 44.8469400, 38.3850000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121010, 'Kholmogory', 'Kholmogory', 'Cholmogory,Kholmogory,Холмогоры', 64.2229000, 41.6560000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121011, 'Kholm', 'Kholm', 'Kholm,Холм', 59.2666700, 32.8500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121012, 'Kholm', 'Kholm', 'Cholm,Chołm,Holm,Jolm,Kholm,Kholm  Kholmsky,Xolm,holleum,horumu,huo er mu,khwlm,khwlm  bkhsh khwlmsky  awblast nwwgwrwd,Ĥolm,Холм,خولم,خولم، بخش خولمسکی، اوبلاست نووگورود,ホルム,霍爾姆,홀름', 57.1454300, 31.1778000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121013, 'Khokhryaki', 'Khokhryaki', 'Khokhrjaki,Khokhryaki,Хохряки', 56.9156100, 53.3221000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121014, 'Khokhlovo', 'Khokhlovo', 'Khokhlova,Khokhlovo,Хохлово', 59.1492300, 37.3997800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121015, 'Khodz’', 'Khodz''', 'Khodz,Khodz'',Khodz’,Ходзь', 44.5102000, 40.7142000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121016, 'Khlevnoye', 'Khlevnoye', 'Khlebnoye,Khlevnoe,Khlevnoje,Khlevnoye,Хлевное', 52.1951200, 39.0931600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121017, 'Khiv', 'Khiv', 'Khiv,Хив', 41.7542800, 47.9306300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121018, 'Khislavichi', 'Khislavichi', 'Khislavichi,Khislavitsji,Khoslavichi,Хиславичи', 54.1871400, 32.1581700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121019, 'Khimki', 'Khimki', 'Chimkai,Chimki,Gorad Khimki,Himki,Jimki,Khimki,Moskau-Chimki,Ximki,himki,himuki,hymqy,khymky,xi mu ji,Ĥimki,Горад Хімкі,Химки,Химки балһсн,Хімки,Խիմկի,חימקי,خيمكي,خیمکی,ヒムキ,希姆基,힘키', 55.8970400, 37.4296900, 'RU', '2016-07-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121020, 'Khelyulya', 'Khelyulya', 'Helylae,Helylä,Kheljulja,Khelyulya,Хелюля', 61.7490000, 30.6647300, 'RU', '2012-12-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121021, 'Khatukay', 'Khatukay', 'Khatukaj,Khatukay,Хатукай', 45.1907400, 39.6632000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121022, 'Khasavyurt', 'Khasavyurt', 'Chassaw-Jurt,Hasavjurt,Khasav,Khasav-jurt,Khasavjurt,Khasavyurt,Staro Khasav-Yurt,Xasavyurt,Хасав,Хасав-юрт,Хасавюрт', 43.2509000, 46.5876600, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121023, 'Kharovsk', 'Kharovsk', 'Charovsk,Charowsk,Harovsk,Karovsk,Kharovs''k,Kharovsk,ha luo fu si ke,kharwfsk,Ĥarovsk,Харовск,Харовськ,خاروفسك,خاروفسک,ხაროვსკი,哈羅夫斯克', 59.9642500, 40.1912100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121024, 'Kharlu', 'Kharlu', 'Harlu,Kharlu,Харлу', 61.8000000, 30.9500000, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121025, 'Kharitonovo', 'Kharitonovo', 'Charitonovo,Kharitonovo,Khiritonovo,Харитоново', 61.4009200, 47.4977900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121026, 'Kharabali', 'Kharabali', 'Charabali,Charabalinskoje,Gorad Kharabali,Harabali,Jarabali,Kharabali,Kharabalí,ha la ba li,kharabaly,Ĥarabali,Горад Харабалі,Харабали,Харабали балһсн,Харабалі,Хәрәбәле,خارابالي,خارابالی,哈拉巴利', 47.4195800, 47.2567800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121027, 'Khanskaya', 'Khanskaya', 'Chanskaja,Khanskaja,Khanskaya,Ханская', 44.6770200, 39.9616000, 'RU', '2016-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121028, 'Khanino', 'Khanino', 'Khanino,Ханино', 54.2110000, 36.6229200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121029, 'Khamamatyurt', 'Khamamatyurt', 'Khamamat-Jurt,Khamamatjurt,Khamamatyurt,Khamamayurt,Хамамат-Юрт,Хамаматюрт', 43.6080900, 46.5006000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121030, 'Orlov', 'Orlov', 'Gorad Arlou,Khalturin,Orlov,Orlov i Russland,Orlow,ao er luo fu,awrlwf,awrlwf  rwsyh,Горад Арлоў,Орлов,أورلوف,اورلوف، روسیه,奧爾洛夫', 58.5394600, 48.8917300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121031, 'Khadzhalmakhi', 'Khadzhalmakhi', 'Khadzhalmakhi,Khajal-Makhi,Khodzhal-Makhinskskoye,Хаджалмахи', 42.4200000, 47.1820600, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121032, 'Khadyzhensk', 'Khadyzhensk', 'Chadyschensk,Chadyzensk,Chadyżensk,Chadyžensk,Gorad Khadyzhehnsk,Hadijensk,Hadizensk,Hadižensk,Hadyzensk,Hadyžensk,Jadyzhensk,Khadijensk,Khadizhens''k,Khadizhensk,Khadyjensk,Khadyzhensk,Khadyzhenskaya,Khadyzhenskiy,Khadyzhensky,Khadyzhy,Khadyzjensk,Khadíjensk,Khuydyzhuy,Xadijensk,Xadıjensk,ha de ren si ke,khadyjynsk,khadyzhnsk,Ĥadiĵensk,Горад Хадыжэнск,Хадиженск,Хадиженськ,Хадыженск,Хадыженск балһсн,Хъыдыжъы,خاديجينسك,خادیژنسک,哈德任斯克', 44.4258000, 39.5362000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121033, 'Khabez', 'Khabez', 'Khabez,Хабез', 44.0434000, 41.7720000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121034, 'Kez', 'Kez', 'Kez,Кез', 57.8957000, 53.7132000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121035, 'Kevsala', 'Kevsala', 'Kevsala,Кевсала', 45.7983300, 42.6902800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121036, 'Kesova Gora', 'Kesova Gora', 'Kesova Gora,Kesova-Gora,Кесова Гора', 57.5836100, 37.2922200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121037, 'Kerva', 'Kerva', 'Kerva,Керва', 55.6116700, 39.5766500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121038, 'Kerchevskiy', 'Kerchevskiy', 'Kercheva,Kerchevo,Kerchevskij,Kerchevskiy,Kertsjevskij,Керчевский', 59.9456000, 56.2959000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121039, 'Kenzhe', 'Kenzhe', 'Kenzhe,Kenzje,Кенже', 43.5016700, 43.5572200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121040, 'Kemlya', 'Kemlya', 'Kemlja,Kemlya,Кемля', 54.6963000, 45.2424000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121041, 'Kem’', 'Kem''', 'Kem,Kem'',Kemi,Kem’,Ken,Vienan Kemi,Кемь', 64.9554600, 34.5792900, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121042, 'Kazinka', 'Kazinka', 'Kasinka,Kazinka,Казинка', 52.5381700, 39.8216400, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121043, 'Kazanskaya', 'Kazanskaya', 'Kasanskaja,Kazanskaja,Kazanskaya,Казанская', 49.7933300, 41.1466700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121044, 'Kazanskaya', 'Kazanskaya', 'Kazanskaja,Kazanskaya,Казанская', 45.4106000, 40.4361000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121045, 'Kazan', 'Kazan', 'Casanum,Caza,Cazã,Gorad Kazan'',KZN,Kaasan,Kasa,Kasan,Kasã,Kazan,Kazan'',Kazan'' osh,Kazana,Kazane,Kazani,Kazanj,Kazano,Kazanė,Kazan’,Kazań,Kazaņa,Kazaň,Kazán,Khuazan,Khusan,Kozan'',Kuazan,Kuzon,Qazan,Qozon,ka shan,kajan,kajhana,kazan,kazana,kha san,qazan,Καζάν,Горад Казань,Казан,Казань,Казань ош,Казањ,Каꙁанъ,Козань,Кузон,Къазан,Озаҥ,Хусан,Хъазан,Қазан,Ҡazan,Ҡазан,Կազան,קאזאן,قازان,كازان,کازان,कझान,काज़ान,คาซาน,ყაზანი,カザン,喀山,카잔', 55.7887400, 49.1221400, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121046, 'Kazaki', 'Kazaki', 'Kagaki,Kasaki,Kazaki,Казаки', 52.6248400, 38.2648800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121047, 'Kayasula', 'Kayasula', 'Kajasula,Kayasula,Kayasulu,Terek-bay,Каясула', 44.3250000, 45.0000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121048, 'Kayakent', 'Kayakent', 'Kaja-Ken,Kajakent,Kaya Kend,Kayakent,Каякент', 42.3873600, 47.9030100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121049, 'Kavkazskiy', 'Kavkazskiy', 'Karkazskiy,Kavkazskij,Kavkazskiy,Кавказский', 44.2672000, 42.2347000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121050, 'Kavkazskaya', 'Kavkazskaya', 'Kavkazskaja,Kavkazskaya,Kawkaskaja,Кавказская', 45.4453000, 40.6765000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121051, 'Katyr-Yurt', 'Katyr-Yurt', 'Katar-Jurt,Katar-Yurt,Katyr-Jurt,Katyr-Yurt,Kotar-Jurt,Kotar-Yurt,Kotarin-Jurt,Kotarin-Yurt,Tutovo,Катар-Юрт,Катыр-Юрт,Котар-Юрт,Котарин-Юрт', 43.1700700, 45.3711400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121052, 'Katyn''', 'Katyn''', 'Katyn'',Катынь', 54.7745500, 31.6904100, 'RU', '2010-06-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121053, 'Katunino', 'Katunino', 'Katunino,Lakhta,Катунино', 64.3862000, 40.6298000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121054, 'Katav-Ivanovsk', 'Katav-Ivanovsk', 'Gorad Katau-Ivanausk,Katav-Ivanovs''k,Katav-Ivanovsk,Katav-Ivanovskiy,Katav-Ivànovsk,Katav-Ivánovsk,Kataw-Iwanowsk,Kytau-Ivanovsk,ka ta fu-yi wan nuo fu si ke,kataf-ayfanwfsk,kataf-aywanwfsk,Горад Катаў-Іванаўск,Катав-Івановськ,Катав-Ивановск,Кытау-Ивановск,كاتاف-آيفانوفسك,کاتاف-ایوانوفسک,卡塔夫-伊萬諾夫斯克', 54.7530600, 58.1955600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121055, 'Kasumkent', 'Kasumkent', 'Kasumkent,Касумкент', 41.6772500, 48.1460100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121056, 'Kastornoye', 'Kastornoye', 'Kastornoe,Kastornoje,Kastornoye,Касторное', 51.8334000, 38.1302000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121057, 'Kastanayevo', 'Kastanayevo', 'Kastanaevo,Kastanayevo,Кастанаево', 55.7166700, 37.5000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121058, 'Kaspiyskiy', 'Kaspiyskiy', 'Kaspijskij,Kaspiyskiy,Lagan,Lagan'',Lagan’,Logan'',Logan’,Каспийский,Лагань', 45.3928800, 47.3707300, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121059, 'Kaspiysk', 'Kaspiysk', 'Dvigatel''stroy,Dvigatel’stroy,Kaspijsk,Kaspiysk,Sotsgorod,kaseupiseukeu,Каспийск,카스피스크', 42.8816500, 47.6391900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121060, 'Kasimov', 'Kasimov', 'Cassim,Gorad Kasimau,Kasimov,Kasimova,Kasimow,Kassimov,Kassimow,Kassímov,Kasímov,ka xi mo fu,kashimofu,kasimopeu,kasymwf,qasymwf,Горад Касімаў,Касимов,Касимов балһсн,Ханкирмән,قاسیموف,كاسيموف,کاسیموف,カシモフ,卡西莫夫,카시모프', 54.9411100, 41.3952800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121061, 'Kashirskoye', 'Kashirskoye', 'Kashirskoe,Kashirskoye,Kasjirskoje,Каширское', 51.4194500, 39.6124800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121062, 'Kashira', 'Kashira', 'Gorad Kashyra,Kachira,Kaschira,Kashira,Kasira,Kasjira,Kaszyra,Kaŝira,Kaşira,Kašira,Kașira,ka xi la,kashira,kashyra,kasila,Горад Кашыра,Кашира,كاشيرا,کاشیرا,カシーラ,卡希拉,카시라', 54.8444400, 38.1669400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121063, 'Kashin', 'Kashin', 'Gorad Kashyn,Kachine,Kaschin,Kashin,Kasin,Kasjin,Kaszyn,Kaŝin,Kaşin,Kašin,ka shen,kashin,kashyn,kasin,Горад Кашын,Кашин,كاشين,کاشین,カシン,卡申,카신', 57.3591700, 37.6080600, 'RU', '2008-11-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121064, 'Kashary', 'Kashary', 'Kashary,Kasjary,Кашары', 49.0400100, 41.0055700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121065, 'Karsun', 'Karsun', 'Karsun,Карсун', 54.1994100, 46.9827000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121066, 'Karpushikha', 'Karpushikha', 'Karpushikha,Karpusjikha,Карпушиха', 57.5016700, 59.8955600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121067, 'Karpogory', 'Karpogory', 'Karpogori,Karpogory,Карпогоры,Կարպոգորի', 64.0018900, 44.4451300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121068, 'Karmaskaly', 'Karmaskaly', 'Karmakaly,Karmaskaly,Кармаскалы', 54.3709000, 56.1837000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121069, 'Karinskoye', 'Karinskoye', 'Karinskoe,Karinskoye,Каринское', 55.7096900, 36.6890300, 'RU', '2013-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121070, 'Kargopol’', 'Kargopol''', 'Kargopol,Kargopol'',Kargopol’,Каргополь', 61.5035900, 38.9486000, 'RU', '2013-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121071, 'Kargalinskaya', 'Kargalinskaya', 'Kargalinskaja,Kargalinskaya,Kargalinski,Karginskaja,Karginskaya,Karpalinskaya,Каргалинская,Каргалински,Каргинская', 43.7438100, 46.4782100, 'RU', '2014-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121072, 'Kardzhin', 'Kardzhin', 'Kardzhin,Kardzjin,Карджин', 43.2736800, 44.2907500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121073, 'Kardymovo', 'Kardymovo', 'Kardymoro,Kardymovo,Кардымово', 54.8901600, 32.4311100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121074, 'Kardonikskaya', 'Kardonikskaya', 'Kardonikskaja,Kardonikskaya,Кардоникская', 43.8657700, 41.7143200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121075, 'Kardailovo', 'Kardailovo', 'Kapoailovskaya,Kardailovo,Kardailovskaya,Kardailovskiy,Кардаилово', 51.5386100, 53.9041700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121076, 'Karata', 'Karata', 'Karata,Карата', 42.5948600, 46.3393000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121077, 'Karalat', 'Karalat', 'Karalat,Каралат', 45.9155500, 48.3068300, 'RU', '2017-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121078, 'Karakulino', 'Karakulino', 'Karakulino,Каракулино', 56.0120000, 53.7066900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121079, 'Karaidel’', 'Karaidel''', 'Karaidel,Karaidel'',Karaidel’,Караидель', 55.8337300, 56.9069200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121080, 'Karagay', 'Karagay', 'Karagaj,Karagay,Карагай', 58.2666900, 54.9367800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121081, 'Karagach', 'Karagach', 'Inalov,Karagach,Karagachevo,Karagatsj,Карагач', 43.8052800, 43.7750000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121082, 'Karachev', 'Karachev', 'Karachev,Karatschew,Karatsjev,Карачев', 53.1229200, 34.9851700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121083, 'Karachayevsk', 'Karachayevsk', 'Karachaevsk,Karachayevsk,Karatsajevsk,Karatsjajevsk,Karatšajevsk,Klukhori,Kuarachaj shakhar,Kuarcha kuala,Mikojan-Schachar,Mikopi Shakhar,Mikoyan-Shakhar,Карачаевск,Къарачай шахар,Къарча къала', 43.7739900, 41.9141900, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121084, 'Karabulak', 'Karabulak', 'Gorad Karabulak,Karaboelak,Karabolak,Karaboulak,Karabulak,Karabulak i Ingusjetia,Karabulako,Karabulakskaya,Karabułak,ka la bu la ke,kalabullakeu,karaburaku,karabwlak,karabwlak  ayngwshtya,Горад Карабулак,Караболак,Карабулак,Карабулак балһсн,Элдархан-ГӀала,كارابولاك,کارابولاک، اینگوشتیا,カラブラク,卡拉布拉克,카라불라크', 43.3051300, 44.8994900, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121085, 'Karabudakhkent', 'Karabudakhkent', 'Karabudachkent,Karabudakhkent,Karabudukh,Karabulakh-Kend,Карабудахкент', 42.7087000, 47.5673500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121086, 'Karabash', 'Karabash', 'Karabash,Karabasj,Карабаш', 54.6930000, 52.5835900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121087, 'Karabanovo', 'Karabanovo', 'Gorad Karabanava,Karabanovo,Karabanowo,ka la ba nuo wo,kalabanobo,karabanovu~o,karabanwfw,Горад Карабанава,Карабаново,كارابانوفو,کارابانوفو,カラバノヴォ,卡拉巴諾沃,카라바노보', 56.3166700, 38.7000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121088, 'Kapustin Yar', 'Kapustin Yar', 'Kapustin Jar,Kapustin Yar,Капустин Яр', 48.5817500, 45.7448100, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121089, 'Kapotnya', 'Kapotnya', 'Kapotnja,Kapotnya,Капотня', 55.6380600, 37.7930600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121090, 'Kantyshevo', 'Kantyshevo', 'Kantyshevo,Kantysjevo,Nartovo,Nartovskoya,Кантышево', 43.2282400, 44.6332200, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121091, 'Kantemirovka', 'Kantemirovka', 'Kantemirovka,Kantemirowka,Кантемировка', 49.7088700, 39.8592200, 'RU', '2014-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121092, 'Kangly', 'Kangly', 'Kangly,Канглы', 44.2544400, 43.0308300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121093, 'Kanevskaya', 'Kanevskaya', 'Kanevskaia,Kanevskaja,Kanevskaya,Kanewskaja,Kanivs''ka,Каневская,Канівська', 46.0849000, 38.9596000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121094, 'Kanelovskaya', 'Kanelovskaya', 'Kanelovskaja,Kanelovskaya,Konelovskaya,Krasnopolyanka,Канеловская', 46.5896000, 39.1944000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121095, 'Kandry', 'Kandry', 'Kandry,Kandry-Amineva,Кандры', 54.5666700, 54.1166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121096, 'Kandalaksha', 'Kandalaksha', 'Kaeddluhtt,Kandalaksa,Kandalakscha,Kandalaksha,Kandalaksja,Kandalaksza,Kandalakŝa,Kandalakša,Kandałaksza,Kannanlahti,Kannanlaksi,Kannanlakši,Kantalahti,Käddluhtt,kandallagsya,kandarakusha,Кандалакша,カンダラクシャ,칸달락샤', 67.1620000, 32.4122900, 'RU', '2012-12-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121097, 'Kanash', 'Kanash', 'Gorad Kanash,Kanach,Kanas,Kanasch,Kanash,Kanasj,Kanasz,Kanax,Kanaŝ,Kanaş,Kanaš,Shikhrany,ka na shen,kanash,kanasi,Горад Канаш,Канаш,Каҥаш,كاناش,کاناش,卡納什,카나시', 55.5096200, 47.4912700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121098, 'Kanadey', 'Kanadey', 'Kanadej,Kanadey,Канадей', 53.1678600, 47.5264400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121099, 'Kamyzyak', 'Kamyzyak', 'Kamysjak,Kamyziak,Kamyzjak,Kamyzyak,Камызяк', 46.1099500, 48.0736400, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121100, 'Kamyshla', 'Kamyshla', 'Kamyshla,Kamysjla,Камышла', 54.1169300, 52.1426200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121101, 'Kamyshin', 'Kamyshin', 'Gorad Kamyshyn,Kamishin,Kamisin,Kamixin,Kamiŝin,Kamišin,Kamosin,Kamychine,Kamyschin,Kamyshin,Kamysin,Kamysinas,Kamysjin,Kamyszyn,Kamyšin,Kamyšinas,Kamîșin,Kamõšin,ka mei shen,kamisin,kamuishin,kamyshn,kamyshyn,Горад Камышын,Камишин,Камышин,Камышин балһсн,Կամիշին,كاميشين,کامیشن,کامیشین,カムイシン,卡梅申,카미신', 50.0983300, 45.4160100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121102, 'Kamyshevatskaya', 'Kamyshevatskaya', 'Kamishevatskaya,Kamuishevat,Kamyschewatkaja,Kamyshevatka,Kamyshevatskaja,Kamyshevatskaya,Kamyshyevat,Kamysjevatskaja,Камышеватская', 46.4131600, 37.9563200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121103, 'Kaminskiy', 'Kaminskiy', 'Gorki-Pavlovo,Gorki-Pavlovy,Kaminskij,Kaminskiy,Kaminsky,Каминский', 57.1515900, 41.4731800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121104, 'Kameshkovo', 'Kameshkovo', 'Kameshkovo,Kamesjkovo,Камешково', 56.3530500, 41.0094100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121105, 'Kamensk-Shakhtinskiy', 'Kamensk-Shakhtinskiy', 'Kamensk,Kamensk Shakhtinski,Kamensk-Schachtinskij,Kamensk-Schachtiuski,Kamensk-Shakhtinskij,Kamensk-Shakhtinskiy,Kamenskaya,Каменск,Каменск-Шахтинский', 48.3177900, 40.2594800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121106, 'Kamenskiy', 'Kamenskiy', 'Grimm,Kamenskij,Kamenskiy,Lesnoy Karamysh,Каменский', 50.8854700, 45.4880100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121107, 'Kamenolomni', 'Kamenolomni', 'Kamenolomni,Kamenolomnya,Каменоломни', 47.6685300, 40.2051000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121108, 'Kamennomostskoye', 'Kamennomostskoye', 'Kamennomostskoe,Kamennomostskoje,Kamennomostskoye,Kamenomostskoye,Karmovo,Каменномостское', 43.7372200, 43.0513900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121109, 'Kamennomostskiy', 'Kamennomostskiy', 'Kamennomostskaja,Kamennomostskaya,Kamennomostskij,Kamennomostskiy,Каменномостский', 44.2891000, 40.1880000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121110, 'Kamennogorsk', 'Kamennogorsk', 'Antrea,Kamennogors''k,Kamennogorsk,Kamennogorska,Kamenogorsk,Kamiennogorsk,Kamjennogorsk,Kammenogorsk,Sankt Andree,ka mian nuo ge er si ke,kamennogoleuseukeu,kamnwgwrsk,kamynwghwrsk,Антреа,Каменногорск,Каменногорськ,Каменогорск,كامينوغورسك,کامنوگورسک,卡緬諾戈爾斯克,카멘노고르스크', 60.9545100, 29.1339100, 'RU', '2016-08-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121111, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 65.8835000, 44.1272000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121112, 'Kamenka', 'Kamenka', 'Kamenka,Kaukjaervi,Kaukjarvi,Kaukjärvi,Kelola,Каменка', 60.4463900, 29.0829000, 'RU', '2016-08-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121113, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 57.3921400, 41.7938300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121114, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 51.3223000, 42.7678000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121115, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 50.7149900, 39.4218900, 'RU', '2015-09-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121116, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 43.5333300, 43.5166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121117, 'Kamenetskiy', 'Kamenetskiy', 'Kameneckij,Kamenetskij,Kamenetskiy,Каменецкий', 54.0135300, 38.2211500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121118, 'Kambileyevskoye', 'Kambileyevskoye', 'Kambileevskoe,Kambilejevskoje,Kambileyevskoye,Nizhniy Dzherakh,Verkhne-Kambileyevskoye,Камбилеевское', 43.0785800, 44.7521600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121119, 'Kambarka', 'Kambarka', 'Gorad Kambarka,Kamarka,Kambark,Kambarka,Kambarskiy,kambaleuka,kambarka,kan ba er ka,Горад Камбарка,Камбарка,كامباركا,کامبارکا,坎巴爾卡,캄바르카', 56.2666000, 54.2056000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121120, 'Kama', 'Kama', 'Butysh,Kama,Кама', 56.3051200, 54.0936100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121121, 'Kalyazin', 'Kalyazin', 'Kaliazin,Kaljazin,Kalyazin,Калязин', 57.2402800, 37.8433300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121122, 'Kaluga', 'Kaluga', 'Caluga,Gorad Kaluga,KLF,Kaloega,Kalouga,Kalug,Kaluga,Kalugae,Kalugo,Kaluqa,Kalyga,Kaługa,ka lu jia,kalluga,kaluga,kalwga,kalwgha,karuga,klwga,qlwgh,Горад Калуга,Калугæ,Калуга,Калуго,Կալուգա,קלוגה,كالوغا,کالوگا,کلوگا,कालुगा,ಕಲೂಗಾ,カルーガ,卡盧加,칼루가', 54.5293000, 36.2754200, 'RU', '2013-04-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121123, 'Kaltasy', 'Kaltasy', 'Kaltasy,Калтасы', 55.9692600, 54.8032100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121124, 'Kalnibolotskaya', 'Kalnibolotskaya', 'Kainibolotskaya,Kalnibolotskaja,Kalnibolotskaya,Kanibolotskaya,Калниболотская', 46.0058300, 40.4568200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121125, 'Kalinovskoye', 'Kalinovskoye', 'Kalinovskoe,Kalinovskoje,Kalinovskoye,Kalivo,Калиновское', 44.8635000, 42.9622000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121126, 'Kalinovskaya', 'Kalinovskaya', 'Gal-GIala,Gal-Gala,Gal-Ġala,Galne,Kahnoyakaya,Kalinovskaja,Kalinovskaya,Kalinovski,Kalinovskoe,Kalinovskoye,Гал-ГІала,Галне,Калиновская,Калиновски,Калиновское', 43.5738300, 45.5209000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121127, 'Kalino', 'Kalino', 'Kalino,Калино', 58.2504000, 57.6085000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121128, 'Kalininskaya', 'Kalininskaya', 'Kalininskaja,Kalininskaya,Kalininskyaya,Popovicheskaya,Popovichevskaya,Popovichskaya,Popoviehskaya,Popowitscheskaja,Калининская', 45.4844000, 38.6622100, 'RU', '2016-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121129, 'Kalininsk', 'Kalininsk', 'Balanda,Gorad Kalininsk,Kalinins''k,Kalininsk,Kalíninsk,jia li ning si ke,kalynynsk,kalynynsk  awblast saratwf,Горад Калінінск,Калининск,Калининск балһсн,Калињинск,Калінінськ,كالينينسك,کالینینسک، اوبلاست ساراتوف,加里寧斯克', 51.5000000, 44.4758000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121130, 'Korolev', 'Korolev', 'Kaliningrad,Kalininskiy,Korolev,Koroljov,Королев,Королёв', 55.9141700, 37.8255600, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121131, 'Kaliningrad', 'Kaliningrad', 'Calininopolis,Gorad Kaliningrad,KGD,Kalinin''nkrant,Kaliningrad,Kaliningrada,Kaliningradas,Kaliningrado,Kaliningradum,Kaliningrau,Kaliningráu,Kalininqrad,Kalinjingrad,Kalinyingrad,Kalinyingrád,Kalińingrad,Kalíníngrad,Karaliaucios,Karaliaucius,Karaliaučios,Karaliaučius,Kaļiņingrada,Kenisberg,Koenigsbarg,Koenigsberg,Koenigsberg in Preussen,Korigsberg,Krolewiec,Królewiec,Kënisberg,Königsbarg,Königsberg,Königsberg in Preußen,Körigsberg,jia li ning ge lei,kalininagrada,kalliningeuladeu,kalynynghrad,kalynyngrad,kariningurado,qlynyngrd,Καλίνινγκραντ,Горад Калінінград,Калининград,Калињинград,Калінінград,Կալինինգրադ,קלינינגרד,كالينينغراد,کالیننگراڈ,کالینینگراد,کیلننگراڈ,कालिनिनग्राद,ಕಲಿನಿನ್‍ಗ್ರಾಡ್,კალინინგრადი,カリーニングラード,加里寧格勒,칼리닌그라드', 54.7064900, 20.5109500, 'RU', '2017-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121132, 'Kalininaul', 'Kalininaul', 'Kalininaoul,Kalininaul,Shircha-Ehvla,Yurt-Aukh,klynn awl,Калининаул,Ширча-Эвла,كلينن أؤل', 43.0712100, 46.5667900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121133, 'Kalinin', 'Kalinin', 'Kalinin,Калинин', 47.2467800, 39.5108800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121134, 'Kalikino', 'Kalikino', 'Kadikino,Kalikino,Каликино', 52.9493000, 39.8269000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121135, 'Kalevala', 'Kalevala', 'Kalevala,Uchtinskaja,Uhtua,Ukhta,Калевала', 65.1987300, 31.1899900, 'RU', '2015-12-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121136, 'Kalashnikovo', 'Kalashnikovo', 'Kalashnikovo,Kalasjnikovo,Калашниково', 57.2823700, 35.2261700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121137, 'Kalach-na-Donu', 'Kalach-na-Donu', 'Gorad Kalach-na-Done,Kalac Donal,Kalac na Donu,Kalac nad Donom,Kalac-na-Donu,Kalach,Kalach na Don,Kalach na Donu,Kalach-na-Donu,Kalacz-na-Donu,Kalatch-na-Donou,Kalats-na-Donu,Kalatsch,Kalatsch am Don,Kalatsj-Na-Donu,Kalatsj-na-Donu,Kalatx-na-Donu,Kalatx-na-Donú,Kalatš-na-Donu,Kalaĉ-na-Donu,Kalač Donal,Kalač na Donu,Kalač nad Donom,Kalač-na-Donu,Kałacz-na-Donu,dun he pan ka la qi,kalach-na-dwnw,kalatsh-na-dwnw,kallachinadonu,Горад Калач-на-Доне,Калач на Дон,Калач на Дону,Калач-на-Дону,Калач-на-Дону балһсн,كالاتش-نا-دونو,کالاچ-نا-دونو,頓河畔卡拉奇,칼라치나도누', 48.6909900, 43.5263800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121138, 'Kalach', 'Kalach', 'Kalach,Kalatsch,Kalatsj,Калач', 50.4258000, 41.0261000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121139, 'Kakhun', 'Kakhun', 'Kakhun,Кахун', 43.5430600, 43.8763900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121140, 'Kagal’nitskaya', 'Kagal''nitskaya', 'Kagal''nickaja,Kagal''nik,Kagal''nitskaya,Kagalnitskaja,Kagalnizkaja,Kagal’nik,Kagal’nitskaya,Kagolnitskaya,Кагальницкая', 46.8805600, 40.1465700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121141, 'Kafyr-Kumukh', 'Kafyr-Kumukh', 'Kafyr-Kumuch,Kafyr-Kumukh,Kafyrkumyk'',Kafyrkumyk’,Кафыр-Кумух', 42.8375400, 47.1541200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121142, 'Kadyy', 'Kadyy', 'Kady,Kadyj,Kadyy,Кадый', 57.7870400, 43.1902900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121143, 'Kaduy', 'Kaduy', 'Kadui,Kaduj,Kaduy,Teplova,Кадуй', 59.2000000, 37.1500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121144, 'Kadoshkino', 'Kadoshkino', 'Kadoshkino,Kadosjkino,Кадошкино', 54.0257000, 44.4191000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121145, 'Kadom', 'Kadom', 'Kadom,Кадом', 54.5591700, 42.4675000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121146, 'Kadnikov', 'Kadnikov', 'Gorad Kadnikau,Kadnikov,Kadnikow,Kádnikov,ka de ni ke fu,kadnykwf,Горад Каднікаў,Кадников,كادنيكوف,کادنیکوف,卡德尼科夫', 59.5021800, 40.3380300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121147, 'Kachkanar', 'Kachkanar', 'Kachkanar,Katsjkanar,Качканар', 58.7002000, 59.4839000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121148, 'Kabardinka', 'Kabardinka', 'Kabardinka,Kabardinskaya,Kabardinskiy Poselok,Kaberdinka,Кабардинка', 44.6513900, 37.9427800, 'RU', '2015-10-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121149, 'Kabanovo', 'Kabanovo', 'Kabanova,Kabanovo,Кабаново', 55.7481500, 38.9351100, 'RU', '2015-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121150, 'Kabakovo', 'Kabakovo', 'Kabakovo,Kabanovo,Кабаково', 54.5369000, 56.1517000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121151, 'Izoplit', 'Izoplit', 'Izoplit,Изоплит', 56.6255800, 36.2219800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121152, 'Izobil’nyy', 'Izobil''nyy', 'Izobil''no-Tishchenskiy,Izobil''noye,Izobil''nyj,Izobil''nyy,Izobilnyj,Izobil’no-Tishchenskiy,Izobil’noye,Izobil’nyy,Изобильный', 45.3709200, 41.7083900, 'RU', '2014-07-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121153, 'Iznoski', 'Iznoski', 'Izhoski,Iznoski,Износки', 54.9880600, 35.3108300, 'RU', '2016-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121154, 'Izmaylovo', 'Izmaylovo', 'Izmajlovo,Izmaylovo,Измайлово', 55.7867700, 37.8016500, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121155, 'Izmaylovo', 'Izmaylovo', 'Izmajlovo,Izmaylovo,Измайлово', 53.7211400, 47.2458100, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121156, 'Izmalkovo', 'Izmalkovo', 'Izmalkovo,Измалково', 52.6887000, 37.9639800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121157, 'Izhma', 'Izhma', 'Ishma,Iz''va,Izhma,Izjma,Iz’va,Ижма', 65.0083300, 53.9112800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121158, 'Izhevskoye', 'Izhevskoye', 'Izhevskoe,Izhevskoye,Izjevskoje,Ижевское', 54.5570000, 40.8753000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121159, 'Izhevsk', 'Izhevsk', 'Gorad Izhehusk,IJK,Ijevsk,Ischewsk,Ishewsk,Izevsk,Izevska,Izevskas,Izewsk,Izh,Izhau,Izhevs''k,Izhevsk,Izhkar,Izjefsk,Izjevsk,Izsevszk,Iĵevsk,Iżewsk,Iževsk,Iževska,Iževskas,Ustinov,ayjyfsk,ayzhwsk,azwsk,ijebseukeu,ijefusuku,yi re fu si ke,İjevsk,ʼyzbsq,Ιζέβσκ,Іжевськ,Горад Іжэўск,Иж,Ижау,Ижевск,Ижкар,איזבסק,إيجيفسك,ازوسک,ایژوسک,იჟევსკი,イジェフスク,伊熱夫斯克,이젭스크', 56.8497600, 53.2044800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121160, 'Izborsk', 'Izborsk', 'Irboska,Izborsk,Staroizborsk,Vana-Irboska,Изборск', 57.7075700, 27.8629100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121161, 'Izberbash', 'Izberbash', 'Izbarbash,Izberbash,Izberbasj,Izberg,Izerbash,Избербаш,Изберг', 42.5695500, 47.8644700, 'RU', '2015-04-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121162, 'Ivot', 'Ivot', 'Ivot,Ивот', 53.6755600, 34.1872200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121163, 'Ivnya', 'Ivnya', 'Ivnja,Ivnya,Ивня', 51.0629400, 36.1342600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121164, 'Ivanteyevka', 'Ivanteyevka', 'Ivanteevka,Ivantejevka,Ivanteyevka,Ivanteyevskiy,Ивантеевка', 55.9711100, 37.9208300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121165, 'Ivanteyevka', 'Ivanteyevka', 'Ivanteevka,Ivantejevka,Ivanteyevka,Ивантеевка', 52.2667000, 49.1055000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121166, 'Ivanovskoye', 'Ivanovskoye', 'Ivanovskoe,Ivanovskoye,Ивановское', 55.7666700, 37.8333300, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121167, 'Ivanovskoye', 'Ivanovskoye', 'Ivanovskoe,Ivanovskoje,Ivanovskoye,Ивановское', 44.5795000, 41.8764000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121168, 'Ivanovo', 'Ivanovo', 'Gorad Ivanava,IWA,Ivanova,Ivanovas,Ivanovo,Ivanovo shaary,Ivanovo-Voznesensk,Ivànovo,Ivánovo,Iwanowo,ayfanwfw,aywanwfw,aywanww,ibanobo,ivu~anovu~o,xi wa no wo,yi wan nuo wo,İvanovo,ʼywwʼnwbw,Іваново,Горад Іванава,Иваново,Иваново шаары,Իվանովո,איוואנובו,إيفانوفو,ایوانوفو,ایوانوو,อีวาโนโว,イヴァノヴォ,伊万诺沃,이바노보', 56.9971900, 40.9713900, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121169, 'Ivanishchi', 'Ivanishchi', 'Ivanishchevskiy,Ivanishchi,Ivanishhi,Ivanisjtsji,Rabochiy Poselok Ivanishchvskiy,Rabochiy Posëlok Ivanishchvskiy,Иванищи', 55.7741700, 40.4273100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121170, 'Ivanino', 'Ivanino', 'Ivanino,Иванино', 51.6434000, 35.5769000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121171, 'Ivangorod', 'Ivangorod', 'Gorad Ivangarad,Iban''nkoront,Iivananlinna,Ivangorod,Ivangoroda,Ivangorodas,Ivángorod,Iwangorod,Jaanilinn,ayangwrwd,ayfanghwrwd,ibangolodeu,ibangoloteu,ivangorodi,ivu~angorodo,yi wan ge luo de,Ιβάνγκοροντ,Івангород,Горад Івангарад,Ивангород,آيفانغورود,ایانگورود,ივანგოროდი,イヴァンゴロド,伊万哥罗德,이반고로드,이반고로트', 59.3715500, 28.2162500, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121172, 'Itum-Kali', 'Itum-Kali', 'Akhalkhevi,Axalhevi,Iton-Kkha''lla,Iton-Kkhelli,Iton-Qalla,Iton-Qelli,Iton-Qälla,Itum-Kale,Itum-Kali,Itumkale,Ахалхеви,Итон-Кхаьлла,Итон-Кхелли,Итум-Кале,Итум-Кали', 42.7355700, 45.5757600, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121173, 'Isyangulovo', 'Isyangulovo', 'Isiangulovo,Isjangulovo,Isyangulovo,Исянгулово', 52.1858400, 56.5804300, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121174, 'Istra', 'Istra', 'Istra,Voskresensk,iseuteula,yi si te la,Истра,伊斯特拉,이스트라', 55.9199700, 36.8686700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121175, 'Issad', 'Issad', 'Isad-Sel''tso,Isad-Sel’tso,Issad,Izsad,Иссад', 60.0674300, 32.3433100, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121176, 'Issa', 'Issa', 'Issa,Исса', 53.8704900, 44.8578100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121177, 'Ispravnaya', 'Ispravnaya', 'Ispravnaja,Ispravnaya,Исправная', 44.0682000, 41.6102000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121178, 'Ishnya', 'Ishnya', 'Ishnja,Ishnya,Isjnja,Ишня', 57.1907000, 39.3600400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121179, 'Ishley', 'Ishley', 'Ishlei,Ishlej,Ishley,Ishley-Pokrovskoye,Isjlej,Ишлей', 56.0231700, 47.0505400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121180, 'Ishkhoy-Yurt', 'Ishkhoy-Yurt', 'Balc-Evl,Balch-Ehvl,Balç-Evl,Ishkhoj-Jurt,Ishkhojn-Ehvla,Ishkhojn-Jurt,Ishkhoy-Yurt,Ishoj-Jurt,Isjkhoj-Jurt,Isxoyn-Avla,Isxoyn-Evla,Isxoyn-Yurt,Işxoyn-Evla,Işxoyn-Yurt,Işxoyn-Əvla,Išhoj-Jurt,Tanty,Балч-Эвл,Ишхой-Юрт,Ишхойн-Эвла,Ишхойн-Юрт,Танты', 43.2127800, 46.3893600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121181, 'Ishimbay', 'Ishimbay', 'Isembai,Ishimbaj,Ishimbay,Isimbai,Isimbaj,Iszymbaj,Iŝimbaj,Išembai,Išimbai,Išimbaj,isimbai,Ишимбай,Ишимбај,이심바이', 53.4544600, 56.0414900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121182, 'Isheyevka', 'Isheyevka', 'Isheevka,Isheyevka,Laisjevka,Ишеевка', 54.4278900, 48.2667500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121183, 'Ishcherskaya', 'Ishcherskaya', 'Ishcherskaya,Isherskaya,Ishherskaja,Isjtsjerskaja,Ищерская', 43.7135900, 45.1337100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121184, 'Isakly', 'Isakly', 'Isakly,Исаклы', 54.1333300, 51.5333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121185, 'Is', 'Is', 'Fedino,Is,Is Poselok,Sverdlovskiy Priisk,Ис', 58.7909000, 59.7179000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121186, 'Irkliyevskaya', 'Irkliyevskaya', 'Irklievskaja,Irklievskaya,Irklijevskaja,Irkliyevskaya,Ирклиевская', 45.8563500, 39.6538100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121187, 'Irganay', 'Irganay', 'Irganaj,Irganay,Ирганай', 42.6465000, 46.9115400, 'RU', '2015-06-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121188, 'Irgakly', 'Irgakly', 'Irgakli,Irgakly,Иргаклы', 44.3611100, 44.7555600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121189, 'Ipatovo', 'Ipatovo', 'Gorad Ipatava,Ipatovo,Ipatowo,Spatowo,Vinodel''noye,Vinodel’noye,aybatwfw,aypatwfw,yi pa tuo wo,İpatovo,Іпатово,Горад Іпатава,Ипатово,Ипатово балһсн,إيباتوفو,ایپاتوفو,伊帕托沃', 45.7180600, 42.9036100, 'RU', '2013-08-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121190, 'Ostrovnoy', 'Ostrovnoy', 'Ekonga,Gorad Astraunoj,Iokanga,Iokanka,Murmansk-140,Ostrovnij,Ostrovnoi,Ostrovnoj,Ostrovnojus,Ostrovnoy,Ostrownoj,Osztrovnoj,Yokan''ga,Yokan’ga,awstrfwnwy,awstrwnwfnwy  awblast mwrmansk,Горад Астраўной,Иоканга,Островний,Островной,Островној,أوسترفونوي,اوسترونوفنوی، اوبلاست مورمانسک', 68.0530600, 39.5130600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121191, 'Inzhavino', 'Inzhavino', 'Inshawino,Inzhavino,Inzjavino,Инжавино', 52.3184700, 42.4936900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121192, 'Inzer', 'Inzer', 'Inzer,Inzerskiy Zavod,Инзер', 54.2167000, 57.5556000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121193, 'Inza', 'Inza', 'Gorad Inza,Insa,Inza,Inzej osh,anza,aynza,yin zha,İnza,Горад Інза,Инза,Инзей ош,إنزا,اینزا,因扎', 53.8567200, 46.3562200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121194, 'Insar', 'Insar', 'Gorad Insar,Insar,Insar osh,Inszar,Inzara,ansar,aynsar,yin sa er,Горад Інсар,Инзара,Инсар,Инсар балһсн,Инсар ош,إنسار,اینسار,因薩爾', 53.8653100, 44.3738200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121195, 'Inozemtsevo', 'Inozemtsevo', 'Inozemcevo,Inozemtsevo,Иноземцево', 44.0926400, 43.0911300, 'RU', '2010-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121196, 'Inderka', 'Inderka', 'Inderka,Индерка', 53.2484600, 46.2582300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121197, 'Imeni Zhelyabova', 'Imeni Zhelyabova', 'Im. Zheljabova,Imeni Zheljabova,Imeni Zhelyabova,Sudoverf'',Sudoverf’,Им. Желябова,Имени Желябова', 58.9544000, 36.5956000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121198, 'Imeni Vorovskogo', 'Imeni Vorovskogo', 'Im.Vorovskogo,Imeni Vorovskogo,Poselok Imeni Vorovskogo,Posëlok Imeni Vorovskogo,imeni Vorovskogo,Им.Воровского,Имени Воровского,имени Воровского', 55.7237000, 41.1190000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121199, 'Imeni Vorovskogo', 'Imeni Vorovskogo', 'Im.Vorovskogo,Imeni Vorovskogo,Poselok Vorovskogo,Posëlok Vorovskogo,imeni Vorovskogo,Им.Воровского,Имени Воровского,имени Воровского', 55.7319000, 38.3236800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121200, 'Imeni Vladimira Il’icha Lenina', 'Imeni Vladimira Il''icha Lenina', 'Fabrika Imeni Lenina,Imeni V.I. Lenina,Imeni Vladimira Il''icha Lenina,Imeni Vladimira Il’icha Lenina,Leninskiy,Pri Fabrike Imeni Vladimira Il''ich Lenina,Pri Fabrike Imeni Vladimira Il’ich Lenina,Имени Владимира Ильича Ленина', 53.5642200, 46.9801000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121201, 'Imeni Tsyurupy', 'Imeni Tsyurupy', 'Imeni Cjurupy,Imeni Tsyurupy,Poselok Imeni Tsyurupy,Posëlok Imeni Tsyurupy,Vanilovo,imeni Cjurupy,imeni Tsjurupy,Имени Цюрупы,имени Цюрупы', 55.4956700, 38.6506400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121202, 'Imeni Sverdlova', 'Imeni Sverdlova', 'Imeni Sverdlova,Posjolok imeni Sverdlova,Sverdlova,Sverdlovleva Varosh,imeni Sverdlova,imeni-sverdlova,Имени Свердлова,Посёлок имени Свердлова,Свердлова,Свердловљева Варош,имени Свердлова,Իմենի Սվերդլովա,იმენი-სვერდლოვა', 59.7961100, 30.6658300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121203, 'Imeni Stepana Razina', 'Imeni Stepana Razina', 'Im.Stepana Razina,Imeni Stepana Razina,Stepana Razina,imeni Stepana Razina,Им.Степана Разина,Имени Степана Разина,имени Степана Разина', 54.8932000, 44.2962700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121204, 'Imeni Morozova', 'Imeni Morozova', 'Im.Morozova,Imeni Morozova,Morozova,Morozovleva Varosh,Paehkinaen Ruuttehas,Posjolok imeni Morozova,Possjolok imeni Morosowa,Pähkinän Ruuttehas,Pähkinän Ruuttehaš,Shlissel''burgskiy Zavod,Shlissel’burgskiy Zavod,imeni Morozova,imeni-morozova,Им.Морозова,Имени Морозова,Морозова,Морозовљева Варош,Посёлок имени Морозова,имени Морозова,Իմենի Մորոզովա,იმენი-მოროზოვა', 59.9757200, 31.0376200, 'RU', '2016-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121205, 'Gereykhanovskoye', 'Gereykhanovskoye', 'Gerejkhanovskij,Gerejkhanovskoe,Gereykhanova,Gereykhanovskiy,Gereykhanovskoye,Imeni Geredkhanova,Sovkhoz Imeni Gereykhanova,Герейхановский,Герейхановское', 41.7011000, 48.2811300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121206, 'Imeni Babushkina', 'Imeni Babushkina', 'Imeni Babushkina,Ledengsk,Ledengskoye,Ledengskoye Kurort,im.Babushkina,imeni Babushkina,Имени Бабушкина,им.Бабушкина,имени Бабушкина', 59.7572700, 43.1284700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121207, 'Il’skiy', 'Il''skiy', 'Il''skaya,Il''skij,Il''skiy,Ilskij,Il’skaya,Il’skiy,Ильский', 44.8422200, 38.5668600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121208, 'Ilovlya', 'Ilovlya', 'Ilovlinska,Ilovlinskaya,Ilovlja,Ilovlya,Иловля', 49.3033400, 43.9796500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121209, 'Ilovka', 'Ilovka', 'Ilovka,Ilovskoye,Иловка', 50.7053000, 38.6370000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121210, 'Il’inskoye-Khovanskoye', 'Il''inskoye-Khovanskoye', 'Il''inskoe-Khovanskoe,Il''inskoye-Khovanskoye,Ilinskoje-Khovanskoje,Il’inskoye-Khovanskoye,Ильинское-Хованское', 56.9718000, 39.7684000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121211, 'Il’inskoye', 'Il''inskoye', 'Il''inskoe,Il''inskoye,Ilinskoje,Il’inskoye,Ильинское', 56.9666700, 37.1833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121212, 'Il’inskoye', 'Il''inskoye', 'Il''inskoe,Il''inskoye,Il’inskoye,Patrenkha,Ильинское', 56.9225000, 28.5353000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121213, 'Il’insko-Podomskoye', 'Il''insko-Podomskoye', 'Il''insko-Podomskoe,Il''insko-Podomskoye,Il''inskoye,Iliinoe-Podomskoe,Ilino Podomskoe,Ilinsko-Podomskoje,Il’insko-Podomskoye,Il’inskoye,Ильинско-Подомское', 61.1144400, 47.9786100, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121214, 'Il’inskiy Pogost', 'Il''inskiy Pogost', 'Il''inskij Pogost,Il''inskiy Pogost,Ilinskij Pogost,Il’inskiy Pogost,Ильинский Погост', 55.4778500, 38.9090600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121215, 'Il’inskiy', 'Il''inskiy', 'Il''inskij,Il''inskiy,Il''inskoye,Il’inskiy,Il’inskoye,Ильинский', 55.6190200, 38.1181800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121216, 'Il’ichëvo', 'Il''ichevo', 'Il''ichevo,Il''ichjovo,Il''ichëvo,Ilitsjevo,Il’ichëvo,Jalkala,Yalkala,Ильичево,Ильичёво,Ялкала', 60.2680800, 29.7523000, 'RU', '2014-07-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121217, 'Il’ich', 'Il''ich', 'Il''ich,Ilitsj,Il’ich,Poselok Il''icha,Posëlok Il’icha,Ильич', 45.4248800, 36.7740200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121218, 'Ilek', 'Ilek', 'Ilek,Ilen-Gorodok,Iletski Gordok,Илек', 51.5270900, 53.3830600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121219, 'Iksha', 'Iksha', 'Iksha,Iksja,Икша', 56.1720400, 37.4984200, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121220, 'Ikryanoye', 'Ikryanoye', 'Ikrjanoe,Ikrjanoje,Ikryanov,Ikryanoye,Икряное', 46.0932300, 47.7307800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121221, 'Ikon-Khalk', 'Ikon-Khalk', 'Ikon-Khalk,Икон-Халк', 44.3051000, 41.9142000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121222, 'Iki-Burul', 'Iki-Burul', 'Chonin-Sala,Ikhbuural,Iki-Burul,Ики-Бурул,Ихбуурал', 45.8208300, 44.6472200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121223, 'Igra', 'Igra', 'Igra,Игра', 57.5549000, 53.0544000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121224, 'Ignatovka', 'Ignatovka', 'Ignatovka,Игнатовка', 53.9478700, 47.6536000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121225, 'Iglino', 'Iglino', 'Iglino,Иглино', 54.8324400, 56.4126400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121226, 'Idritsa', 'Idritsa', 'Idrica,Idritsa,Idriza,Идрица', 56.3315700, 28.8988400, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121227, 'Ibresi', 'Ibresi', 'Ibresi,Ибреси', 55.3011000, 47.0380000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121228, 'Gzhel’', 'Gzhel''', 'Gzhel'',Gzhel’,Gzjel,Гжель', 55.6100800, 38.3939900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121229, 'Elin-Yurt', 'Elin-Yurt', 'Ali-Jurt,Ali-Yurt,Ehlin-Jurt,Elin-Jurt,Elin-Yurt,Gvardejskoe,Gvardejskoje,Gvardeyskoe,Gvardeyskoye,Ielin-Jurt,Yelin-Yurt,Èlin-Jurt,Іелин-Юрт,Али-Юрт,Гвардейское,Элин-Юрт', 43.6730600, 44.9588900, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121230, 'Gvardeysk', 'Gvardeysk', 'Gvardeiskas,Gvardejsk,Gvardeysk,Gwardeisk,Gwardiejsk,Tapiau,Tapyau,Tepliava,geubaleudeiseukeu,gvardejsk,Гвардейск,Гвардејск,그바르데이스크', 54.6477200, 21.0651300, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121231, 'Gus’-Zheleznyy', 'Gus''-Zheleznyy', 'Gus''-Zhelezny,Gus''-Zheleznyj,Gus''-Zheleznyy,Gus-Zjeleznyj,Gus’-Zhelezny,Gus’-Zheleznyy,Гусь-Железный', 55.0581100, 41.1655600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121232, 'Gus’-Khrustal’nyy', 'Gus''-Khrustal''nyy', 'Gus''-Khrustal''ny,Gus''-Khrustal''nyj,Gus''-Khrustal''nyy,Gus-Hrustalnyi,Gus-Khrustalnyi,Gus-Khrustalnyj,Gus’-Khrustal’ny,Gus’-Khrustal’nyy,Гусь-Хрустальный', 55.6111300, 40.6518600, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121233, 'Gusevskiy', 'Gusevskiy', 'Gusevskij,Gusevskiy,Гусевский', 55.6619900, 40.5626700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121234, 'Gusev', 'Gusev', 'Gabin,Goesev,Gorad Guseu,Goussev,Gumbine,Gumbinen,Gumbinnen,Gumbinė,Gusayev,Gusev,Guseva,Gusevas,Gusevsk,Gusew,Gusiew,Gussev,Gussew,Qusev,ghwsyf,gu xie fu,gusefu,gusepeu,gusev,gwsb,gwsf,Горад Гусеў,Гусев,Гусєв,גוסב,غوسيف,گوسف,グセフ,古謝夫,구세프', 54.5922200, 22.1997200, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121235, 'Gur’yevsk', 'Gur''yevsk', 'Gur''evsk,Gur''yevsk,Gurjevsk,Gurjevskas,Gur’yevsk,Naykhauzeh,Neuhausen,Noykhauzen,Sembu Romuva,Sembų Romuva,Гурьевск', 54.7732300, 20.6052100, 'RU', '2016-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121236, 'Gurbuki', 'Gurbuki', 'Gurbuki,Urbuke,Гурбуки', 42.6112800, 47.6006700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121237, 'Gunib', 'Gunib', 'Gunib,Гуниб', 42.3875800, 46.9650900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121238, 'Gundorovskiy', 'Gundorovskiy', 'Gundorov,Gundorovskij,Gundorovskiy,Гундоровский', 46.7804700, 41.8968000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121239, 'Gundelen', 'Gundelen', 'Gundelen,Гунделен', 43.5975000, 43.1719400, 'RU', '2014-06-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121240, 'Gumrak', 'Gumrak', 'Gumrak,Gumrik,Гумрак', 48.7825500, 44.3824000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121241, 'Gul’kevichi', 'Gul''kevichi', 'Gul''kevichi,Gulkevitsji,Gul’kevichi,Гулькевичи', 45.3538300, 40.6946500, 'RU', '2010-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121242, 'Gukovo', 'Gukovo', 'Gukova,Gukovo,Gukowo,Гуково', 48.0621200, 39.9355000, 'RU', '2014-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121243, 'Gudermes', 'Gudermes', 'Belaja,Belaya,Belka,Goedermes,Gorad Gudehrmes,Goudermes,Gu''mse,Gu''msekh,Gudermes,Gudermeso,Gudermess,Gudermès,Gudermés,Guemse,Guemsex,Gums,Guudehmehz,Gümse,Gümsex,ghwdyrmys,gu jie er mei si,gudeleumeseu,gudermesi,guderumesu,gwdrms,Белая,Белка,Горад Гудэрмес,Гудермес,Гудермес балһсн,Гумс,Гуьмсе,Гуьмсех,Гъудэмэз,גודרמס,غوديرميس,گودرمس,გუდერმესი,グデルメス,古傑爾梅斯,구데르메스', 43.3507100, 46.1092500, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121244, 'Gubskaya', 'Gubskaya', 'Gubskaja,Gubskaya,Губская', 44.3163900, 40.6358300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121245, 'Gubkin', 'Gubkin', 'Gorad Gubkin,Goubkine,Gubkin,Gupkin,Qubkin,Rabochiy Poselok Imeni Gubkina,ghwbkyn,gu bu jin,gubkin,gwbkyn,gwbnk,Горад Губкін,Губкин,Губкін,Гупкин,غوبكين,گوبنک,گوبکین,古布金,굽킨', 51.2816700, 37.5458300, 'RU', '2016-12-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121246, 'Gubden', 'Gubden', 'Gubden,Губден', 42.5680800, 47.5657900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121247, 'Gubakha', 'Gubakha', 'Goebacha,Gorad Gubakha,Goubakha,Gubacha,Gubah,Gubaha,Gubaja,Gubakha,Gubaĥa,Qubaxa,ghwbakha,gu ba ha,gwbakha,Горад Губаха,Губаха,غوباخا,گوباخا,古巴哈', 58.8386200, 57.5532500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121248, 'Gryazovets', 'Gryazovets', 'Grjazovec,Grjazovets,Gryazovets,Грязовец', 58.8800000, 40.2525000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121249, 'Gryazi', 'Gryazi', 'Grjazi,Gryasi,Gryazi,Грязи', 52.4965700, 39.9359300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121250, 'Grushevskaya', 'Grushevskaya', 'Grushevskaja,Grusjevskaja,Грушевская', 47.4405600, 39.9511100, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121251, 'Martan-Chu', 'Martan-Chu', 'Grusevoe,Grushevoe,Grushevoye,Gruşevoe,Martan-Chu,Martan-Tsju,Martancu,Martançu,Грушевое,Мартан-Чу', 43.0636600, 45.5621700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121252, 'Groznyy', 'Groznyy', 'Dzhokhar,Dzhokhar-Gala,Dzhokhar-Geala,Dzhokhar-Ghala,Dzhokhargala,Dzhovkhar-GӀala,Dzohar,Dzohhar,Džohar,Džohhar,Dƶohargala,Dƶoxar,GRV,Grosni,Grosnij,Grosny,Grosnyi,Grosnyj,Grosní,Grosnî,Groznai,Groznas,Grozni,Groznii,Grozno,Groznoi,Grozny,Groznyi,Groznyj,Groznyy,Groznâi,Groznîi,Groznõi,Grózni,Nasongi,Nkrozny,Novyj Hutor,So''lzh-GIala,So''lzha-GIala,So''lzha-GӀala,Soelz-Ghala,Soelƶ-Gala,Soelƶa-Gala,Sölž-Ghala,Sölƶ-Ġala,Sölƶa-Ġala,geulojeuni,grozno,grwzny,gurozunui,Ƶovhar-Gala,Ƶovhar-Ġala,Γκρόζνυ,Грозни,Грозный,Джовхар-ГӀала,Джохар,Джохаргала,Соьлж-ГІала,Соьлжа-ГІала,Соьлжа-ГӀала,גרוזני,გროზნო,グロズヌイ,그로즈니', 43.3119500, 45.6889500, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121253, 'Grivenskaya', 'Grivenskaya', 'Grivenskaja,Grivenskaya,Гривенская', 45.6473000, 38.1759700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121254, 'Gritsovskiy', 'Gritsovskiy', 'Gricovskij,Gritsovskij,Gritsovskiy,Грицовский', 54.1376100, 38.1604300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121255, 'Grigoropolisskaya', 'Grigoropolisskaya', 'Grigoripolisskaya,Grigoripolisskiy,Grigoropolisskaja,Grigoropolisskaya,Grigoropolisskiy,Григорополисская', 45.2972200, 41.0566700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121256, 'Gribanovskiy', 'Gribanovskiy', 'Bol''shaya Gribanovka,Bol’shaya Gribanovka,Gribanovskij,Gribanovskiy,Gribanowka,Грибановский', 51.4579200, 41.9763700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121257, 'Gremyachinsk', 'Gremyachinsk', 'Baskaya,Gremjachinsk,Gremjatsjinsk,Gremyachinsk,Gremyachinskiy,Vaskaya,Гремячинск', 58.5603000, 57.8510000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121258, 'Grecheskoye', 'Grecheskoye', 'Grecheskoe,Grecheskoye,Gretsjeskoje,Греческое', 44.4305300, 43.0083000, 'RU', '2010-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121259, 'Grebenskaya', 'Grebenskaya', 'Grebenskaja,Grebenskaya,Grebenski,Гребенская,Гребенски', 43.5308600, 46.3717400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121260, 'Grazhdanskoye', 'Grazhdanskoye', 'Grazhdanskiy,Grazhdanskiy Pervyy,Grazhdanskiy Vtoroy,Grazhdanskoe,Grazhdanskoye,Grazhdanskoye Pervoye,Grazhdanskoye Pervyy,Grazhdanskoye Vtoroye,Гражданское', 44.2300000, 42.7698000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121261, 'Grazhdanka', 'Grazhdanka', 'Grazhdanka,Гражданка', 60.0358700, 30.4051800, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121262, 'Grayvoron', 'Grayvoron', 'Grajvoron,Grayvoron,Грайворон', 50.4767000, 35.6773000, 'RU', '2014-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121263, 'Grakhovo', 'Grakhovo', 'Grakhovo,Грахово', 56.0501700, 51.9675800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121264, 'Grabovo', 'Grabovo', 'Grabovo,Грабово', 53.3875100, 45.0639500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121265, 'Goyty', 'Goyty', 'GIojtIa,GIojtIe,Goity,Gojty,Goytha,Goythe,Goyty,Svobodnoe,Svobodnoye,Ġoytha,Ġoythe,ГІойтІа,ГІойтІе,Гойты,Свободное', 43.1641700, 45.6227800, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121266, 'Gostilitsy', 'Gostilitsy', 'Gostilicy,Gostilitsy,Kosteritsa,Krasnaya Baltika,Гостилицы', 59.7483200, 29.6220500, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121267, 'Gostagayevskaya', 'Gostagayevskaya', 'Gastagayevskaya,Gostagaevskaja,Gostagajevskaja,Gostagajewskaja,Gostagayevskaya,Гостагаевская', 45.0228400, 37.5051100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121268, 'Goryachiy Klyuch', 'Goryachiy Klyuch', 'Gorjachij Kljuch,Gorjatschi-Kljutsch,Gorjatsjij Kljutsj,Goryachiy Klyuch,Goyyachi Klyuch,Горячий Ключ', 44.6308300, 39.1300000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121269, 'Goryachevodskiy', 'Goryachevodskiy', 'Gorjachevodskij,Gorjatsjevodskij,Goryachevodskaya,Goryachevodskiy,Горячеводский', 44.0236100, 43.0922200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121270, 'Abram Mys', 'Abram Mys', 'Abram Mys,Abram-Mys,Goryacheva,Goryachëva,Poselok Goryacheva,Posëlok Goryacheva,Varjazhskij Ruchej,Абрам Мыс,Абрам-Мыс,Варяжский Ручей', 68.9783900, 33.0192600, 'RU', '2016-08-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121271, 'Gorskaya', 'Gorskaya', 'Gorskaja,Gorskaya,Горская', 60.0464000, 29.9713700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121272, 'Gorshechnoye', 'Gorshechnoye', 'Gorschetschnoje,Gorshechnoe,Gorshechnoye,Gorsjetsjnoje,Горшечное', 51.5244000, 38.0365000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121273, 'Gorokhovets', 'Gorokhovets', 'Gorad Garakhavec,Gorochovec,Gorochovets,Gorochowez,Gorochowiec,Gorochowjec,Gorohkovets,Gorohovec,Gorohovets,Gorojovets,Gorokhovec,Gorokhovec'',Gorokhovets,Goroxovets,Goroĥovec,ge luo huo wei ci,ghwrwkhwfyts,golohobecheu,gorohovu~etsu,gwrwkhwfts,Горад Гарахавец,Гороховец,Гороховець,غوروخوفيتس,گوروخوفتس,ゴロホヴェツ,戈羅霍韋茨,고로호베츠', 56.2015200, 42.6935100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121274, 'Gorodovikovsk', 'Gorodovikovsk', 'Bachanta,Bajshintaj,Bashanta,Bashnta,Gorad Garadavikousk,Gorodovikovs''k,Gorodovikovsk,Gorodovikovszk,Gorodowikowsk,Zapadnyy,ge luo duo wei ke fu si ke,ghwrwdwfykwfsk,grwdwwykwfsk,Байшинтай,Башнта,Горад Гарадавікоўск,Городовиковск,Городовиковськ,غورودوفيكوفسك,گرودوویکوفسک,戈羅多維科夫斯克', 46.0878500, 41.9335300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121275, 'Gorodoviki', 'Gorodoviki', 'Gorodoviki,Gorodovikov,Gorodovikovsk,Городовики', 46.1352800, 41.9655600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121276, 'Gorodnya', 'Gorodnya', 'Gorodnja,Gorodnya,Городня', 56.7055000, 36.3179300, 'RU', '2013-08-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121277, 'Gorodishche', 'Gorodishche', 'Gorodishche,Gorodishhe,Gorodisjtsje,Городище', 53.2775000, 45.7017000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121278, 'Gorodishche', 'Gorodishche', 'Gorodishche,Gorodishhe,Gorodisjtsje,Городище', 48.8045400, 44.4743900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121279, 'Gorodets', 'Gorodets', 'Gorad Garadzec,Gorodec,Gorodec'',Gorodet,Gorodets,Gorodez,Gorodeț,Gorodéts,Qorodets,ge luo jie ci,ghwrwdyts,golodecheu,gorojettsu,gwrwdts,Горад Гарадзец,Городец,Городець,غوروديتس,گورودتس,ゴロジェッツ,戈羅傑茨,고로데츠', 56.6549300, 43.4727300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121280, 'Gornyy', 'Gornyy', 'Gornyj,Gornyy,Горный', 51.7578000, 48.5413000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121281, 'Gornyy', 'Gornyy', 'Gornaya,Gornaya Shoriya,Gorny,Gornyj,Gornyy,Горный', 47.8159200, 40.2036300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121282, 'Gornyatskiy', 'Gornyatskiy', 'Gornjackij,Gornjatskij,Gornyatskiy,Gornyatskiy Rudnik,Горнятский,Горняцкий', 48.2914700, 40.9575000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121283, 'Gornozavodsk', 'Gornozavodsk', 'Gorad Gornazavodsk,Gornazavodsk,Gornosawodsk,Gornozavods''k,Gornozavodsk,Gornozavodsk i Perm kraj,Gornozavodszk,Gornozawodsk,Novo-Pashkyskiy,Novopashiyskiy,Qornozavodsk,Vil''pashija,ge er nuo zha wo ci ke,ghwrnwzafwdsk,gwrnwzawwdsk  prm,Вильпашия,Горад Горназаводск,Горнозаводск,Горнозаводськ,غورنوزافودسك,گورنوزاوودسک، پرم,戈爾諾扎沃茨克', 58.3758300, 58.3211100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121284, 'Gorki Vtoryye', 'Gorki Vtoryye', 'Gorki Vtorye,Gorki Vtoryye,Gorki-2,Горки Вторые,Горки-2', 55.7256500, 37.1635000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121285, 'Gorki-Leninskiye', 'Gorki-Leninskiye', 'Gorki Leninskie,Gorki Leninskije,Gorki-Leninskie,Gorki-Leninskiye,Leninskiye Gorki,Sovkhoz Gorki-Leninskiye,Горки Ленинские,Горки-Ленинские', 55.5085500, 37.7761800, 'RU', '2017-04-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121286, 'Goritsy', 'Goritsy', 'Goricy,Goritsy,Горицы', 59.8694900, 38.2601600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121287, 'Goreloye', 'Goreloye', 'Goreloe,Goreloje,Goreloye,Горелое', 52.9369700, 41.5043500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121288, 'Gorelovo', 'Gorelovo', 'Gorelovo,Roetsaensilta,Rötsänsilta,Горелово', 59.7723400, 30.1345500, 'RU', '2017-01-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121289, 'Gorelki', 'Gorelki', 'Gorelki,Poseiok Gorelki,Posëiok Gorelki,Горелки', 54.2561700, 37.6108000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121290, 'Gordeyevka', 'Gordeyevka', 'Gordeevka,Gordejevka,Gordeyevka,Gordeyevo,Гордеевка', 52.9569000, 31.9703000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121291, 'Gorbunki', 'Gorbunki', 'Gorbunki,Korpunoi,Горбунки', 59.8130700, 29.9847800, 'RU', '2017-01-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121292, 'Gorbatovka', 'Gorbatovka', 'Gorbatovka,Горбатовка', 56.2571600, 43.7457700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121293, 'Gorbatov', 'Gorbatov', 'Gorad Garbatau,Gorbatov,Gorbatow,Qorbatov,ge er ba tuo fu,ghwrbatwf,goleubatopeu,gwrbatwf,Горад Гарбатаў,Горбатов,غورباتوف,گورباتوف,戈爾巴托夫,고르바토프', 56.1311000, 43.0636300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121294, 'Goragorskiy', 'Goragorskiy', 'Goragorskaya,Goragorskij,Goragorskiy,Gorskiy,Горагорский', 43.5002000, 45.0857400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121295, 'Golynki', 'Golynki', 'Golinki,Golynki,Голынки', 54.8696400, 31.3860900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121296, 'Gol’yanovo', 'Gol''yanovo', 'Gol''janovo,Gol''yanovo,Gol’yanovo,Гольяново', 55.8229900, 37.8130600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121297, 'Golubitskaya', 'Golubitskaya', 'Golubickaja,Golubinskaya,Golubitskaja,Golubitskaya,Голубицкая', 45.3256600, 37.2702000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121298, 'Golovino', 'Golovino', 'Golovino,Головино', 55.9612800, 40.4251100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121299, 'Golovchino', 'Golovchino', 'Golovchino,Golovtsjino,Spasskaya,Головчино', 50.5341000, 35.7970000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121300, 'Golitsyno', 'Golitsyno', 'Golicino,Golicyno,Golitino,Golitsino,Golitsyno,Golizyno,Golițîno,Golytsyno,Gorad Galicyna,ge li qi nuo,ghwlytsynw,gollichino,gwltsynw,gwlytsynw,Голитсино,Голицино,Голицыно,Голіцино,Горад Галіцына,غوليتسينو,گولتسینو,گولیتسینو,戈利齊諾,골리치노', 55.6092800, 36.9821200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121301, 'Gagatli', 'Gagatli', 'Gagatl'',Gagatli,Gagatl’,Gogatl'',Gogatl’,Гагатли', 42.8013000, 46.2916200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121302, 'Gofitskoye', 'Gofitskoye', 'Gofickoe,Gofitskiy,Gofitskoe,Gofitskoje,Gofitskoye,Medvedka,Medvedskoye,Гофитское,Гофицкое', 45.0791700, 43.0463900, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121303, 'Glushkovo', 'Glushkovo', 'Glushkova,Glushkovo,Glusjkovo,Глушково', 51.3391700, 34.6327800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121304, 'Glubokoye', 'Glubokoye', 'Glubokoe,Glubokoje,Glubokoye,Глубокое', 56.6089000, 29.0206600, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121305, 'Glubokiy', 'Glubokiy', 'Glubokaja,Glubokij,Glubokiy,Глубокий', 48.5275900, 40.3279200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121306, 'Glubokiy', 'Glubokiy', 'Glubokij,Glubokiy,Глубокий', 44.9467300, 41.0184500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121307, 'Glotovka', 'Glotovka', 'Glotovka,Глотовка', 53.9490600, 46.7042200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121308, 'Glinka', 'Glinka', 'Glinka,Глинка', 54.6404300, 32.8781100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121309, 'Glinishchevo', 'Glinishchevo', 'Glinishchevo,Glinishhe,Glinishhevo,Глинище,Глинищево', 53.3041600, 34.0652300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121310, 'Glembochino', 'Glembochino', 'Glembochino,Glembotsjino,Глембочино', 56.1875800, 28.3785000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121311, 'Glebychevo', 'Glebychevo', 'Glebychevo,Glebytsevo,Glebytsjevo,Glebytševo,Makslahti,Makslakhti,Rompotti,Sprengtporten,Глебычево,Макслахти', 60.4386800, 28.7182600, 'RU', '2016-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121312, 'Glazunovka', 'Glazunovka', 'Glasunovka,Glazunovka,Глазуновка', 52.5005700, 36.3199700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121313, 'Glazov', 'Glazov', 'Glasow,Glaz,Glazov,Glazovas,Glazow,Glázov,Gorad Glazau,Głazow,ge la zuo fu,geullajopeu,glazwf,gurazofu,jlazwf,Глаз,Глазов,Горад Глазаў,جلازوف,گلازوف,グラゾフ,格拉佐夫,글라조프', 58.1393000, 52.6580000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121314, 'Glafirovka', 'Glafirovka', 'Glafirovka,Глафировка', 46.7637800, 38.4078500, 'RU', '2012-05-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121315, 'Gizel’', 'Gizel''', 'Gizel,Gizel'',Gizel’,Гизель', 43.0400000, 44.5708300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121316, 'Girvas', 'Girvas', 'Girvas,Hirvas,Гирвас', 62.4796200, 33.6848200, 'RU', '2015-12-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121317, 'Girey', 'Girey', 'Girej,Giren,Girey,Гирей', 45.4012000, 40.6587000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121318, 'Gimry', 'Gimry', 'Genub,Gimra,Gimri,Gimry,Guimry,Sjalo Gimry,ghymry,gimri,Генуб,Гимра,Гимри,Гимры,Гімри,Сяло Гімры,Գիմրի,غيمري,გიმრი', 42.7597400, 46.8395900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121319, 'Gigant', 'Gigant', 'Gigant,Гигант', 46.5066500, 41.3418500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121320, 'Gidrotorf', 'Gidrotorf', 'Gidrotorf,Гидроторф', 56.4756200, 43.5381300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121321, 'Giaginskaya', 'Giaginskaya', 'Ghiaghinskayai,Giaginskaja,Giaginskaya,Гиагинская', 44.8620800, 40.0719500, 'RU', '2016-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121322, 'Gerzel’-Aul', 'Gerzel''-Aul', 'Gerzel''-Aul,Gerzel’-Aul,Verkhniy Gerzel'',Verkhniy Gerzel’,Герзель-Аул', 43.2472800, 46.4024900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121323, 'Germenchuk', 'Germenchuk', 'Germachig,Germachik,Germacig,Germacik,Germaçig,Germaçik,Germchiga,Germciga,Germenchak,Germenchik,Germenchuk,Germencuk,Germentsjuk,Germenčuk,Germçiga,Mostovoe,Mostovoye,Гермачиг,Гермачик,Герменчук,Гермчига,Мостовое', 43.1857000, 45.9210000, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121324, 'Germenchik', 'Germenchik', 'Germenchik,Герменчик', 43.5938900, 43.7661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121325, 'Gergebil’', 'Gergebil''', 'Geregebil'',Geregebil’,Gergebel'',Gergebel’,Gergebil,Gergebil'',Gergebil’,Гергебиль', 42.5047200, 47.0661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121326, 'Georgiyevskoye', 'Georgiyevskoye', 'Georgievskoe,Georgijevskoje,Georgiyevskoye,Георгиевское', 58.7310100, 45.0240400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121327, 'Georgiyevskaya', 'Georgiyevskaya', 'Churekovo,Georgievskaja,Georgijevskaja,Georgiyevskaya,Sergeyevskoye,Георгиевская', 44.1113900, 43.4922200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121328, 'Georgiyevsk', 'Georgiyevsk', 'Georgievsk,Georgiewsk,Georgijevsk,Georgijewsk,Georgiyevsk,Георгиевск', 44.1519400, 43.4697200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121329, 'Georgiyevka', 'Georgiyevka', 'Georgievka,Georgijevka,Georgiyevka,Георгиевка', 53.2743800, 50.9984800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121330, 'Gelendzhik', 'Gelendzhik', 'GDZ,Gelendjik,Gelendschik,Gelendshik,Gelendzhik,Gelendzik,Gelendzjik,Gelendzyk,Gelendĵik,Gelendżyk,Gelendžik,Gelenjir,Gelenzhik,Gelyendzhik,Ghelenjik,Gorad Gelendzhyk,Guelendjik,Gyelyendzhik,Khyluehzh''yj,Nkelentzik,Qelencik,ge lian ji ke,gellenjikeu,gerenjiku,ghylynjyk,gln dzhyk,glndzhyk,Γκελεντζίκ,Геленджик,Геленџик,Горад Геленджык,Хылъэжьый,غيلينجيك,گلن دژیک,گلندژیک,ゲレンジーク,格連吉克,겔렌지크', 44.5622000, 38.0848000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121331, 'Gekhi', 'Gekhi', 'Blagodatnoe,Blagodatnoye,Gehi,Gekhi,Gikhi,GikhtIa,GikhtIe,Gixi,Gixtha,Gixthe,Благодатное,Гехи,Гихи,ГихтІа,ГихтІе', 43.1635400, 45.4723800, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121332, 'Gdov', 'Gdov', 'Gdov,Gdova,Gdovas,Gdow,Gorad Gdou,Oudova,Outova,Qdov,gdwf,ge duo fu,geudopeu,ghdwf,gudofu,Гдов,Горад Гдоў,غدوف,گدوف,グドフ,格多夫,그도프', 58.7442400, 27.8197700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121333, 'Gayny', 'Gayny', 'Gainskoje,Gainy,Gajny,Gayny,Гаины,Гайны', 60.3070700, 54.3241200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121334, 'Gayduk', 'Gayduk', 'Gaiduk,Gajduk,Gayduk,Гайдук', 44.7848900, 37.7005000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121335, 'Gay', 'Gay', 'Gai,Gaj,Gay,Гай', 51.4666000, 58.4552000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121336, 'Gavrilov-Yam', 'Gavrilov-Yam', 'Gavrilov-Jam,Gavrilov-Yam,Гаврилов-Ям', 57.3018500, 39.8533100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121337, 'Gavrilov Posad', 'Gavrilov Posad', 'Gavrilov Posad,Gavrilov-Posad,Gavrilovski-Posad,Гаврилов Посад', 56.5593000, 40.1210000, 'RU', '2014-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121338, 'Gavrilovka Vtoraya', 'Gavrilovka Vtoraya', 'Gavrilovka Vtoraja,Gavrilovka Vtoraya,Гавриловка Вторая', 52.8769700, 42.7663300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121339, 'Gatchina', 'Gatchina', 'Gatchina,Gatcina,Gatcsina,Gatczyna,Gatschina,Gatsjina,Gattjina,Gattschina,Gattsina,Gattsjina,Gattšina,Gatçina,Gatĉina,Gatčina,Gorad Gatchyna,Gátchina,Hatcina,Hatsina,Hatčina,Krasnogvardeysk,Krasnogwardeisk,Nkatsina,gachina,gatchina,gatchyna,ghattshyna,jia te qi na,Γκάτσινα,Гатчина,Горад Гатчына,غاتتشينا,گاتچینا,გატჩინა,ガッチナ,加特契纳,가치나', 59.5763900, 30.1283300, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121340, 'Garbolovo', 'Garbolovo', 'Garbolovo,Seppaelaenmaeki,Seppälänmäki,Гарболово', 60.3412700, 30.4955100, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121341, 'Gaptsakh', 'Gaptsakh', 'Gapcakh,Gaptsakh,Goptsikh,Гапцах', 41.4517400, 47.9302700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121342, 'Gamovo', 'Gamovo', 'Gamovo,Gamy,Гамово', 57.8652000, 56.1056000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121343, 'Galyugayevskaya', 'Galyugayevskaya', 'Galjugaevskaja,Galjugajevskaja,Galjugajewskaja,Galyugayevskaya,Galyugayevskiy,Галюгаевская', 43.6969400, 44.9344400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121344, 'Galitsy', 'Galitsy', 'Galicy,Galitsy,Галицы', 56.1775900, 42.8458800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121345, 'Galich', 'Galich', 'Galic,Galich,Galics,Galicz,Galitch,Galits,Galitsch,Galitsj,Galitx,Galitš,Galiĉ,Galič,Gorad Galich,Gàlitx,Gálich,Noro,Umar'' osh,gallichi,galych  rwsyh,garichi,ghalytsh,jia li qi,Галич,Горад Галіч,Нӧрӧ,Умарь ош,غاليتش,گالیچ، روسیه,ガーリチ,加利奇,갈리치', 58.3788400, 42.3463300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121346, 'Gagino', 'Gagino', 'Gagino,Гагино', 55.2314200, 45.0338600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121347, 'Gagarin', 'Gagarin', 'Gagarin,Gagarin i Russland,Gagarine,Gagaringrad,Gorad Gagaryn,Gshatsk,Gzhatsk,Qaqarin,gagalin,gagarin,gagaryn,ghagharyn,jia jia lin,Гагарин,Гагарін,Горад Гагарын,غاغارين,گاگارین,ガガーリン,加加林,가가린', 55.5529100, 34.9953700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121348, 'Gadzhiyevo', 'Gadzhiyevo', 'Gadjievo,Gadjijevo,Gadjiyevo,Gadjíevo,Gadschijewo,Gadzhievo,Gadzhijevo,Gadzhiyevo,Gadzievo,Gadzijevas,Gadzijevo,Gadzijewo,Gadzjijevo,Gadzyjewo,Gadĵijevo,Gadżyjewo,Gadžievo,Gadžijevas,Gadžijevo,Gadžijewo,Gorad Gadzhyeva,Haciyevo,Hacıyevo,Murmansk-130,Sayda Guba Base,Skalistyy,Yagel''naya Guba,Yagel’naya Guba,gadzhyyfw,gajiyebo,ghadjyyfw,jia ji ye wo,Гаджиево,Гаджієво,Гаџијево,Гаҗиево,Горад Гаджыева,غادجييفو,گادژییفو,加吉耶沃,가지예보', 69.2550600, 33.3361600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121349, 'Furmanov', 'Furmanov', 'Fourmanov,Furmanov,Furmanow,Fúrmanov,Sereda,fu er ma nuo fu,furumanofu,fwrmanwf,puleumanopeu,Фурманов,فورمانوف,フルマノフ,富爾馬諾夫,푸르마노프', 57.2536300, 41.1084900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121350, 'Fryazino', 'Fryazino', 'Frjasino,Frjazino,Fryazino,Фрязино', 55.9605600, 38.0455600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121351, 'Fryazevo', 'Fryazevo', 'Frjazevo,Fryazevo,Фрязево', 55.7332100, 38.4645800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121352, 'Fryanovo', 'Fryanovo', 'Frjanovo,Fryanovo,Фряново', 56.1333300, 38.4500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121353, 'Froly', 'Froly', 'Frolovo,Froly,Фролы', 57.9214000, 56.2728000, 'RU', '2014-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121354, 'Frolovo', 'Frolovo', 'Frolovo,Frolowo,Frołowo,Frólovo,Gorad Frolava,frwlwf,frwlwfw,fu luo luo wo,Горад Фролава,Фролово,Фролово балһсн,فرولوف,فرولوفو,弗羅洛沃', 49.7713300, 43.6622200, 'RU', '2016-08-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121355, 'Frolishchi', 'Frolishchi', 'Florishchi,Frolishcheva Pustyn'',Frolishcheva Pustyn’,Frolishchi,Frolishhi,Frolisjtsji,Фролищи', 56.4217700, 42.6518700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121356, 'Fosforitnyy', 'Fosforitnyy', 'Fosforitny,Fosforitnyj,Fosforitnyy,Фосфоритный', 55.3289200, 38.8950900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121357, 'Fornosovo', 'Fornosovo', 'Fornosovo,Novo-Lisino,Vornasuo,Форносово', 59.5688900, 30.5544400, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121358, 'Foki', 'Foki', 'Foki,Фоки', 56.6930000, 54.3498500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121359, 'Firsanovka', 'Firsanovka', 'Firsanovka,Firsanovskiy,Фирсановка', 55.9536100, 37.2408300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121360, 'Firovo', 'Firovo', 'Firovo,Фирово', 57.4813500, 33.7021100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121361, 'Filimonki', 'Filimonki', 'Filimonki,Филимонки', 55.5579400, 37.3471900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121362, 'Fili', 'Fili', 'Fili,Фили', 55.7481900, 37.4796900, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121363, 'Ferzikovo', 'Ferzikovo', 'Ferzikovo,Poselok Ferzikovo,Posëlok Ferzikovo,Ферзиково', 54.5191300, 36.7567100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121364, 'Fershampenuaz', 'Fershampenuaz', 'Fershampenuaz,Fersjampenuaz,Фершампенуаз', 53.5202000, 59.8117000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121365, 'Ferapontovo', 'Ferapontovo', 'Ferapontovo,Ферапонтово', 59.9542500, 38.5674500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121366, 'Fedurnovo', 'Fedurnovo', 'Fedurnovo,Федурново', 55.7548800, 38.0469600, 'RU', '2016-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121367, 'Fëdorovskoye', 'Fedorovskoye', 'Fedorovskiy,Fedorovskoe,Fedorovskoje,Fedorovskoye,Fjodorovskoe,Fëdorovskoye,Possai,Федоровское,Фёдоровское', 59.6630600, 30.5322200, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121368, 'Fatezh', 'Fatezh', 'Fatesh,Fatezh,Fatezj,Фатеж', 52.0891000, 35.8632000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121369, 'Fastovetskaya', 'Fastovetskaya', 'Fastoveckaja,Fastovetsaya,Fastovetskaja,Fastovetskaya,Фастовецкая', 45.9188900, 40.1588900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121370, 'Falënki', 'Falenki', 'Falenki,Faljonki,Falënki,Фаленки,Фалёнки', 58.3612700, 51.5946100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121371, 'Fakel', 'Fakel', 'Fakel,Sergiyevskiy,Sergiyevskiy Zavod,Факел', 57.6310000, 53.0251000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121372, 'Ezhva', 'Ezhva', 'Ehzhva,Ezhva,Ezjva,Sloboda,Эжва', 61.8128100, 50.7283400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121373, 'Etoka', 'Etoka', 'Ehtoka,Etoka,Etoko,Verkhne-Etokskiy,Этока', 43.9194400, 43.0483300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121374, 'Essoyla', 'Essoyla', 'Dessoilu,Ehssojla,Essojla,Essoyla,Jessoila,Эссойла', 61.8698300, 33.1490100, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121375, 'Ertil’', 'Ertil''', 'Ehrtil'',Ertil,Ertil'',Ertil’,Эртиль', 51.8405600, 40.8055600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121376, 'Erpeli', 'Erpeli', 'Ehrpeli,Erpeli,Эрпели', 42.8058400, 46.9773200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121377, 'Engel’-Yurt', 'Engel''-Yurt', 'Ehngel''-Jurt,Ehngel''s-Jurt,Ehngel-Jurt,Ehngels-Jurt,Engel''-Jurt,Engel''-Yurt,Engel''s-Jurt,Engel-Yurt,Engels-Yurt,Engel’-Yurt,Èngel’-Jurt,Èngel’s-Jurt,Энгел-Юрт,Энгелс-Юрт,Энгель-Юрт,Энгельс-Юрт', 43.3263300, 46.3604800, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121378, 'Engel’s', 'Engel''s', 'Ehngel''s,Engel''s,Engels,Engels an der Wolga,Engel’s,Pokrovsk,Pokrovskaya,Энгельс', 51.4838900, 46.1052800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121379, 'Energetik', 'Energetik', 'Ehnergetik,Energetik,Энергетик', 51.7445000, 58.7934000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121380, 'Enem', 'Enem', 'Ehnem,Enem,Enem Pervyy,Энем', 44.9264000, 38.9058400, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121381, 'Emmaus', 'Emmaus', 'Ehmmaus,Ehmmauss,Emmaus,Emmauss,Poselok Emmaus,Posëlok Emmaus,Эммаус,Эммаусс', 56.7805500, 36.1150000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121382, 'El’ton', 'El''ton', 'Ehl''ton,El''ton,Elton,El’ton,Novyy El''ton,Novyy El’ton,Эльтон', 49.1273000, 46.8470300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121383, 'Elista', 'Elista', 'ESL,Ehlista,Ehlst,Elist,Elista,Elistà,Elistá,Eliszta,Elst,Gorad Ehlista,Stepnoi,Stepnoy,ai li si ta,alysta,aylysta,erisuta,yelliseuta,Ėlista,Ελίστα,Горад Эліста,Елиста,Еліста,Элиста,Элст,Элст балһсн,Элһэтэ,אליסטה,إيليستا,الیستا,ایلیستا,エリスタ,埃利斯塔,옐리스타', 46.3077800, 44.2558300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121384, 'Elektrougli', 'Elektrougli', 'Ehlektrougli,Elektroiugli,Elektroougli,Elektrouegli,Elektrougli,Elektrouqli,Elektroügli,Gorad Ehlektravugli,ai lie ke te luo wu ge li,alktrwgly,alyktrwawgly,aylyktrwghly,erekutorouguri,yellegteulougeulli,Ėlektrougli,Горад Электравуглі,Електроугли,Електроуглі,Электроугли,Электроугли балһсн,إيليكتروغلي,الکتروگلی,الیکترواوگلی,エレクトロウグリ,埃列克特羅烏格利,옐렉트로우글리', 55.7244500, 38.2090800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121385, 'Elektrostal’', 'Elektrostal''', 'Ehlektrostal'',Elektrostal,Elektrostal'',Elektrostalj,Elektrostal’,yellegteuloseutal,Электросталь,옐렉트로스탈', 55.7895900, 38.4467100, 'RU', '2014-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121386, 'Elektrogorsk', 'Elektrogorsk', 'Ehlektrogorsk,Elektrogors''k,Elektrogorsk,Elektrogorskas,Elektroperedacha,Elektroperedachr,Elektroqorsk,Gorad Ehlektragorsk,ai lie ke te luo ge er si ke,alktrwgwrsk,alyktrwgwrsk,aylyktrwghwrsk,erekutorogorusuku,yellegteulogoleuseukeu,Ėlektrogorsk,Горад Электрагорск,Електрогорск,Електрогорськ,Электрогорск,Электрогорск балһсн,إيليكتروغورسك,الکتروگورسک,الیکتروگورسک,エレクトロゴルスク,埃列克特羅戈爾斯克,옐렉트로고르스크', 55.8843100, 38.7864000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121387, 'El’brus', 'El''brus', 'Ehl''brus,El''brus,Elbrus,El’brus,Gagishi,Gyagishch,Ialbuzi,Эльбрус', 43.2577100, 42.6443500, 'RU', '2013-01-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121388, 'Ekazhevo', 'Ekazhevo', 'Ehkazhevo,Ekazhevo,Ekazjevo,Novoardonskoye,Novyy Ardon,Экажево', 43.2122200, 44.8230600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121389, 'Edissiya', 'Edissiya', 'Edisseya,Edissia,Edissiya,Ehdissija,Эдиссия', 44.0511100, 44.5408300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121390, 'Dzhubga', 'Dzhubga', 'Dshubga,Dzhubga,Dzhubq,Dzjubga,Джубга', 44.3211000, 38.7073000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121391, 'Dzhiginka', 'Dzhiginka', 'Dshijinskoje,Dzhiginka,Dzhiginsko,Dzhiginskoye,Dzjiginka,Michaelsfeld,Джигинка', 45.1330000, 37.3382500, 'RU', '2016-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121392, 'Dzhayrakh', 'Dzhayrakh', 'Dzhajrakh,Dzhayrakh,Dzhejrakh,Dzheyrakh,Dzjejrakh,Джайрах,Джейрах', 42.8204300, 44.6813900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121393, 'Dzhalka', 'Dzhalka', 'Dzalka,Dzhalka,Dzhalkkh,Dzjalka,Džalka,Dƶalq,Джалка,Джалкх', 43.3186000, 45.9878700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121394, 'Dzhalil’', 'Dzhalil''', 'Dzhalil'',Dzhalil’,Dzjalil,Джалиль', 55.0239000, 52.7358000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121395, 'Dzerzhinskiy', 'Dzerzhinskiy', 'Dzerzhinskij,Dzerzhinskiy,Dzerzjinskij,Дзержинский', 55.6294500, 37.8565400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121396, 'Dzerzhinsk', 'Dzerzhinsk', 'Chernorech''ye,Chernorech’ye,Chernoye,Dserschinsk,Dzerhinsh,Dzerjinsk,Dzerzhins''k,Dzerzhinsk,Dzerzinsk,Dzerzinska,Dzerzinskas,Dzerzjinsk,Dzerĵinsk,Dzeržinsk,Dzeržinska,Dzeržinskas,Dzierzynsk,Dzierżyńsk,Dzjarzhynsk,Rastyapino,[dʲzʲɪrˈʐɨnsk],d seiyr cinskh,dzrzhynsk,dzyrjynsk,dzyrzhnsk,jeleujinseukeu,jerujinsuku,jie er ren si ke,Дзержинск,Дзержинськ,Дзяржынск,دزرژینسک,دزيرجينسك,دزیرژنسک,ดเซียร์จินสค์,ジェルジンスク,捷尔任斯克,제르진스크', 56.2414300, 43.4553900, 'RU', '2016-11-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121397, 'Dyurtyuli', 'Dyurtyuli', 'Djurtjuli,Dyrtyli,Dyurtyuli,Дюртюли', 55.4910600, 54.8688300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121398, 'Dyshne-Vedeno', 'Dyshne-Vedeno', 'Akhnoda,Aknada,Aknady,Dishni Vedeno,Dishni-Vedana,Disne Vedeno,Disni-Vedana,Disni-Vedeno,Disnini Vedana,Dişni-Vedana,Dişni-Vedeno,Dişnini Vedana,Dišne Vedeno,Dyshne-Vedeno,Dyshni-Vedeno,Dyshny-Vedeno,Dysjne-Vedeno,Dysni-Vedeno,Dyšni-Vedeno,Акнада,Дишни Ведено,Дишни-Ведана,Дышне-Ведено,Дышни-Ведено', 42.9643500, 46.1157800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121399, 'Dylym', 'Dylym', 'Dylym,Дылым', 43.0709900, 46.6345400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121400, 'Dyat’kovo', 'Dyat''kovo', 'Djat''kovo,Djatkovo,Djatkowa,Dyat''kovo,Dyat’kovo,Дятьково', 53.5978200, 34.3382500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121401, 'Dvortsy', 'Dvortsy', 'Dvorcy,Dvorets,Dvortsy,Дворцы', 54.6167700, 35.9974000, 'RU', '2016-07-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121402, 'Dvinskoy', 'Dvinskoy', 'Dvinskoj,Dvinskoy,Двинской', 62.1519000, 45.1184000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121403, 'Duvan', 'Duvan', 'Duvan,Дуван', 55.6949700, 57.9023700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121404, 'Dorgeli', 'Dorgeli', 'Dorgeli,Durgeli,Доргели', 42.6670000, 47.2943500, 'RU', '2014-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121405, 'Duminichi', 'Duminichi', 'Duminichi,Duminitsji,Думиничи', 53.9344600, 35.1099300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121406, 'Dulyapino', 'Dulyapino', 'Duljapino,Dulyapino,Poselok Dulyapino,Posëlok Dulyapino,Дуляпино', 57.2578300, 40.8147100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121407, 'Dukhovshchina', 'Dukhovshchina', 'Doechovsjtsjina,Doukhovchtchina,Duchovscina,Duchovščina,Duchowschtschina,Duchowscina,Duchowszczina,Duchowšćina,Duhovscina,Duhovstsina,Duhovštšina,Duhovščina,Dujovshina,Dukhovschina,Dukhovshchina,Dukhovshhina,Dukhovshina,Dukhovsjtsjina,Dukhovsxina,Duxovsina,Duxovşina,Duĥovŝĉina,Gorad Dukhaushchyna,do~uhofushichina,du huo fu xi na,duhobsina,dwkhwfshchyna,dwkhwfshtshyna,Горад Духаўшчына,Духовшина,Духовшчина,Духовщина,دوخوفشتشينا,دوخوفشچینا,ドゥホフシチーナ,杜霍夫希納,두홉시나', 55.1919000, 32.4111000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121408, 'Dukhovnitskoye', 'Dukhovnitskoye', 'Dukhovnickoe,Dukhovnitskoje,Dukhovnitskoye,Духовницкое', 52.4828000, 48.2137000, 'RU', '2012-02-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121409, 'Dubrovka', 'Dubrovka', 'Dubrovka,Дубровка', 59.2286600, 51.1557800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121410, 'Dubrovka', 'Dubrovka', 'Dubrovka,Dubrovki,Дубровка', 56.3910100, 28.6385000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121411, 'Dubrovka', 'Dubrovka', 'Dubrovka,Дубровка', 53.6907000, 33.5071000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121412, 'Dubrovitsy', 'Dubrovitsy', 'Dubrovicy,Dubrovitsy,Sovkhoz Dubrovitsy,Дубровицы', 55.4396900, 37.4867000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121413, 'Dubovyy Umët', 'Dubovyy Umet', 'Dubovy Umet,Dubovyj Umet,Dubovyj Umjot,Dubovyy Umet,Dubovyy Umët,Дубовый Умет,Дубовый Умёт', 52.9762900, 50.2856900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121414, 'Dubovskoye', 'Dubovskoye', 'Dubovskoe,Dubovskoje,Dubovskoye,Дубовское', 47.4142000, 42.7697000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121415, 'Dubovka', 'Dubovka', 'Doubovka,Dubovk,Dubovka,Dubovkai jaras,Dubovkai járás,Dubowka,Gorad Dubouka,du bo fu ka,dwbwfka,dwbwfka  astan wlgwgrad,Горад Дубоўка,Дубовка,Дубовка балһсн,دوبوفكا,دوبوفکا، استان ولگوگراد,杜博夫卡', 49.0582500, 44.8290000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121416, 'Dubna', 'Dubna', 'Doebna,Doubna,Dubna,Dubno,Dubnà,Dubná,Gorad Dubna,do~ubuna,du bu na,dub na,dubeuna,dubna,dwbna,dwbnh,Горад Дубна,Дубна,Дубна балһсн,דובנה,دوبنا,ดุบนา,ドゥブナ,杜布纳,두브나', 56.7333300, 37.1666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121417, 'Dubna', 'Dubna', 'Dubna,Дубна', 54.1541600, 36.9617300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121418, 'Dubki', 'Dubki', 'Dubki,Дубки', 57.3000000, 40.2500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121419, 'Dubki', 'Dubki', 'Dubki,Дубки', 43.0211600, 46.8374600, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121420, 'Duba-Yurt', 'Duba-Yurt', 'Duba-Jurt,Duba-Yurt,Dubin-Ehvl,Dubin-Ehvla,Dubin-Evl,Dubin-Evla,Rodnikovoe,Rodnikovoye,Дуба-Юрт,Дубин-Эвл,Дубин-Эвла,Родниковое', 43.0353400, 45.7304600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121421, 'Druzhnaya Gorka', 'Druzhnaya Gorka', 'Druzhnaja Gorka,Druzhnaya Gorka,Druzjnaja Gorka,Orinansavotta,Дружная Горка', 59.2801800, 30.1270900, 'RU', '2017-02-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121422, 'Druzhinino', 'Druzhinino', 'Druzhinino,Druzjinino,Дружинино', 56.7894500, 59.5142800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121423, 'Druzhba', 'Druzhba', 'Druzhba,Дружба', 55.8860300, 37.7426700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121424, 'Druzhba', 'Druzhba', 'Druzhba,Дружба', 44.1953000, 42.0170000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121425, 'Drezna', 'Drezna', 'Dresna,Drezna,Driezna,Drjezna,Gorad Drehzna,de lie zi na,dryzna,drzna,Горад Дрэзна,Дрезна,Дрезна балһсн,درزنا,دريزنا,دریزنا,德列茲納', 55.7420800, 38.8475300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121426, 'Drakino', 'Drakino', 'Drakino,Дракино', 51.1389800, 39.4021500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121427, 'Doschatoye', 'Doschatoye', 'Doschatoe,Doschatoye,Doshchatoye,Dostsjatoje,Досчатое', 55.3886000, 42.1032000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121428, 'Dorokhovo', 'Dorokhovo', 'Dorochowo,Dorokhovo,Дорохово', 55.5505600, 36.3744400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121429, 'Dorogomilovo', 'Dorogomilovo', 'Dorogomilovo,Дорогомилово', 55.7500000, 37.5666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121430, 'Dorogobuzh', 'Dorogobuzh', 'Dorogoboezj,Dorogobouj,Dorogobuj,Dorogobusch,Dorogobuz,Dorogobuzas,Dorogobuzh,Dorogobuzh na Dnepre,Dorogobuzj,Dorogobuĵ,Dorogobuż,Dorogobuž,Dorogobužas,Dorohobusum,Doroqobuj,Gorad Daragabuzh,dologobusi,dorogobuji,duo luo ge bu ri,dwrwghwbwj,dwrwgwbazh,Горад Дарагабуж,Дорогобуж,دوروغوبوج,دوروگوباژ,ドロゴブージ,多羅戈布日,도로고부시', 54.9150000, 33.2972200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121431, 'Donskoye', 'Donskoye', 'Donskaya,Donskoe,Donskoje,Donskoye,Донское', 52.7749500, 41.4775900, 'RU', '2013-06-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121432, 'Donskoye', 'Donskoye', 'Donskoe,Donskoje,Donskoye,Patriarsheye,Vodop''yanovo,Vodop''yanovskoye,Vodopinovskoe,Vodop’yanovo,Vodop’yanovskoye,Донское', 52.6174000, 38.9738000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121433, 'Donskoye', 'Donskoye', 'Donskoe,Donskoje,Donskoye,Донское', 45.4551800, 41.9741100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121434, 'Donskoy', 'Donskoy', 'Donskoj,Donskoy,Донской', 53.9710600, 38.3362700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121435, 'Donskoy', 'Donskoy', 'Donskoj,Donskoy,Донской', 47.4140400, 40.2574200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121436, 'Donetsk', 'Donetsk', 'Donec''k,Doneck,Donecka,Donetk,Donets''k,Donetsk,Donetsk i Russland,Donets’k,Donezk,Donețk,Donieck,Donjeck,Doněck,Doņecka,Gorad Daneck,Gunderovskaya,Gundorovka,Gundorovskaya,Gundurovka,donecheukeu,dun nie ci ke,dwntsk,dwntsk  rwsyh,Горад Данецк,Донецк,Донецк балһсн,Донецьк,Доњецк,دونتسک,دونتسک، روسیه,頓涅茨克,도네츠크', 48.3348700, 39.9459000, 'RU', '2016-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121437, 'Dondukovskaya', 'Dondukovskaya', 'Dondukovskaja,Dondukovskaya,Дондуковская', 44.8819000, 40.3627100, 'RU', '2016-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121438, 'Domodedovo', 'Domodedovo', 'Domodedova,Domodedovas,Domodedovo,Domodedowo,Domodiedowo,Domodédovo,Domodědovo,Gorad Damadzedava,domodedobo,domojedovu~o,duo mo jie duo wo,dwmwddwfw,dwmwdydwfw,dwmwdydww,Горад Дамадзедава,Домодедово,Домодедово балһсн,Домодєдово,دوموددوفو,دوموديدوفو,دومودیدوو,ドモジェドヴォ,多莫傑多沃,도모데도보', 55.4413000, 37.7536700, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121439, 'Dombarovskiy', 'Dombarovskiy', 'Dombarovskij,Dombarovskiy,Домбаровский', 50.7587000, 59.5386000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121440, 'Dolzhanskaya', 'Dolzhanskaya', 'Doljansk,Dolshanskaja,Dolzhanka,Dolzhanskaja,Dolzhanskaya,Dolzjanskaja,Stanitsa Dolzhanskaya,Должанская', 46.6336900, 37.8024600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121441, 'Dolgorukovo', 'Dolgorukovo', 'Dolgorukovo,Долгоруково', 52.3194500, 38.3452700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121442, 'Dolgoprudnyy', 'Dolgoprudnyy', 'Dolgoprodnyy,Dolgoprudnyi,Dolgoprudnyj,Dolgoprudnyy,Dolgoprudyy,Долгопрудный', 55.9495800, 37.5018300, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121443, 'Dobryatino', 'Dobryatino', 'Dobriatino,Dobrjatino,Dobryatino,Добрятино', 55.5055000, 41.3195000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121444, 'Dobryanka', 'Dobryanka', 'Dobrjanka,Dobryanka,Dobryansk,Добрянка', 58.4644000, 56.4127000, 'RU', '2015-07-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121445, 'Dobrun’', 'Dobrun''', 'Dobrun,Dobrun'',Dobrun’,Добрунь', 53.1851200, 34.2462500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121446, 'Dobroye', 'Dobroye', 'Dobroe,Dobroje,Dobroye,Доброе', 52.8678000, 39.8109000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121447, 'Dobrinka', 'Dobrinka', 'Dobrinka,Добринка', 52.1652800, 40.4730600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121448, 'Dno', 'Dno', 'Dno,Gorad Dno,de nuo,deuno,dnw,dono,Горад Дно,Дно,دنو,ドノー,德诺,드노', 57.8277200, 29.9636800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121449, 'Dneprovskaya', 'Dneprovskaya', 'Dneprovskaja,Dneprovskaya,Dnjeprowskaja,Днепровская', 45.6235900, 38.8080700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121450, 'Dmitrovsk-Orlovskiy', 'Dmitrovsk-Orlovskiy', 'Dmitrovsk,Dmitrovsk-Orlovskij,Dmitrovsk-Orlovskiy,Dmitrowsk,Дмитровск-Орловский', 52.5050000, 35.1464000, 'RU', '2013-12-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121451, 'Dmitrovskiy Pogost', 'Dmitrovskiy Pogost', 'Dmitrovskij Pogost,Dmitrovskiy Pogost,Дмитровский Погост', 55.3133300, 39.8335800, 'RU', '2012-09-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121452, 'Dmitrov', 'Dmitrov', 'Demitriovia,Dmitrov,Dmitrow,Dmítrov,Gorad Dzmitrau,de mi te luo fu,deumiteulopeu,dmitrov,dmtrwf,dmytrwf,domitorofu,dymytrwf,Горад Дзмітраў,Дмитров,Дмитров балһсн,دمتروف,دميتروف,دیمیتروف,ドミトロフ,德米特罗夫,드미트로프', 56.3448500, 37.5204100, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121453, 'Dmitriyevskoye', 'Dmitriyevskoye', 'Dmitrievskaja,Dmitrievskoe,Dmitriyevskaya,Dmitriyevskoye,Novo-Dimitrievskoe,Дмитриевская,Дмитриевское', 45.8052900, 41.8966700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121454, 'Dmitriyevskaya', 'Dmitriyevskaya', 'Dmitrievskaja,Dmitrijevskaja,Dmitriyevskaya,Дмитриевская', 45.6563900, 40.7652800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121455, 'Dmitriyevka', 'Dmitriyevka', 'Dmitrievka,Dmitriyevka,Дмитриевка', 54.7500000, 55.3333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121456, 'Divnoye', 'Divnoye', 'Divnoe,Divnoje,Divnoye,Diwnoje,Дивное', 45.9088900, 43.3547200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121457, 'Divnomorskoye', 'Divnomorskoye', 'Divnomorskoe,Divnomorskoje,Divnomorskoye,Fal''shivy Gelendzhik,Fal''shivyy Gelendzhik,Fal’shivy Gelendzhik,Fal’shivyy Gelendzhik,Дивноморское', 44.5017000, 38.1342000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121458, 'Diveyevo', 'Diveyevo', 'Diveevo,Divejevo,Diveyevo,Дивеево', 55.0432900, 43.2417800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121459, 'Dinskaya', 'Dinskaya', 'Dinskaja,Dinskaya,Динская', 45.2151600, 39.2265000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121460, 'Dimitrovgrad', 'Dimitrovgrad', 'Dimitrovgrad,Dimitrovgrad i Russland,Dimitrovgradas,Dimitrovqrad,Dimitrowgrad,Gorad Dzimitraugrad,Melekes,Melekess,Mitreen'' osh,dimiteulobeugeuladeu,dimitorofugurado,dymytrwfghrad,dymytrwfgrad  rwsyh,dymytrwwgrad,ji mi te luo fu ge lei,Горад Дзімітраўград,Димитровград,Мелекес,Митреень ош,Мәләкәс,ديميتروفغراد,دیمیتروفگراد، روسیه,دیمیترووگراد,ディミトロフグラード,季米特洛夫格勒,디미트로브그라드', 54.2138600, 49.6183800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121461, 'Digora', 'Digora', 'Digora,Khristianskoye,Дигора', 43.1580600, 44.1569400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121462, 'Deyskoye', 'Deyskoye', 'Deiskoye,Dejskoe,Dejskoje,Deyskoye,Дейское', 43.4754600, 44.1618200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121463, 'Devitsa', 'Devitsa', 'Devica,Devitsa,Девица', 51.6352000, 38.9450000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121464, 'Detchino', 'Detchino', 'Detchino,Dettsjino,Детчино', 54.8092300, 36.3075000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121465, 'Desnogorsk', 'Desnogorsk', 'Desnogors''k,Desnogorsk,Desnoqorsk,Diesnogorsk,Gorad Dzjasnagorsk,deseunogoleuseukeu,desunogorusuku,dsnwgwrsk,dysnwghwrsk,jie si nuo ge er si ke,Горад Дзяснагорск,Десногорск,Десногорськ,دسنوگورسک,ديسنوغورسك,デスノゴルスク,傑斯諾戈爾斯克,데스노고르스크', 54.1507700, 33.2815100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121466, 'Deshovki', 'Deshovki', 'Deshovka,Deshovki,Desjovki,Дешовки', 54.0033300, 35.7877100, 'RU', '2017-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121467, 'Dergachi', 'Dergachi', 'Dergachi,Dergatsji,Дергачи', 51.2328000, 48.7659000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121468, 'Derbent', 'Derbent', 'Cali,Chjali,Darband,Darbant,Derbend,Derbent,Derbenta,Derbentas,Derbente,Derbentum,Dərbənd,Gorad Dzerbent,K''vevar,Temyrkualeh,deleubenteu,derubento,drbnd,drbnt,jie er bin te,Горад Дзербент,Дарбант,Дербенд,Дербент,Дербент балһсн,Дәрбәнт,Кьвевар,Темыркъалэ,Цали,Чяли,Դերբենդ,דרבנט,دربند,დერბენტი,デルベント,傑爾賓特,데르벤트', 42.0677900, 48.2898700, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121469, 'Demyansk', 'Demyansk', 'Demjansk,Demyansk,Демянск', 57.6430100, 32.4660000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121470, 'Dem’yanovo', 'Dem''yanovo', 'Dem''janovo,Dem''yanovo,Demjanovo,Dem’yanovo,Демьяново', 60.3511100, 47.0841700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121471, 'Demikhovo', 'Demikhovo', 'Demikhova,Demikhovo,Демихово', 55.7968500, 38.8840400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121472, 'Demidov', 'Demidov', 'Demidov,Demidow,Demídov,Diemidow,Gorad Dzjamidau,Porech''ye,Porech’ye,demidofu,demidopeu,dmydwf,dymydwf,jie mi duo fu,Горад Дзямідаў,Демидов,دمیدوف,ديميدوف,デミドフ,傑米多夫,데미도프', 55.2706300, 31.5149700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121473, 'Dedovsk', 'Dedovsk', 'Dedovo,Dedovs''k,Dedovsk,Dedovskaj,Dedovskiy,Dedowsk,Diedowsk,Dédovsk,Gorad Dzedausk,ddwfsk,dedobseukeu,dedofusuku,dydwfsk,dykwwsk,jie duo fu si ke,Горад Дзедаўск,Дедовск,Дедовск балһсн,Дедовскай,Дєдовськ,ددوفسک,ديدوفسك,دیکووسک,デドフスク,傑多夫斯克,데돕스크', 55.8686100, 37.1222200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121474, 'Dedovichi', 'Dedovichi', 'Dedovichi,Dedovici,Dedovitsi,Dedovitsji,Dedovitši,Dedoviči,Dedowitschi,Дедовичи', 57.5516600, 29.9501800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121475, 'Dedino', 'Dedino', 'Dedino,Дедино', 56.2446100, 28.2505900, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121476, 'Dedenëvo', 'Dedenevo', 'Dedenevo,Dedenjovo,Dedenëvo,Деденёво', 56.2428300, 37.5176900, 'RU', '2014-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121477, 'Debesy', 'Debesy', 'Debessy,Debesy,Дебесы', 57.6515000, 53.8089000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121478, 'Davydovo', 'Davydovo', 'Davydova,Davydovo,Dvydovo,Давыдово', 55.6085900, 38.8610900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121479, 'Davydovka', 'Davydovka', 'Davydovka,Davyidovka,Dawidowka,Давыдовка', 51.1578100, 39.4291500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121480, 'Davydkovo', 'Davydkovo', 'Davydkovo,Давыдково', 55.7181500, 37.4727100, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121481, 'Davlekanovo', 'Davlekanovo', 'Davlekanova,Davlekanovo,Davlekaovo,Dawlekanowo,Dəvləkən,Gorad Daulekanava,da fu lie ka nuo wo,dabeullekanobo,daburekanobo,daflykanwfw,dawlkanwfw,Горад Даўлеканава,Давлеканово,Давлеканово балһсн,Дәүләкән,دافليكانوفو,داولکانوفو,ダブレカノボ,達夫列卡諾沃,다블레카노보', 54.2214500, 55.0343400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121482, 'Darovskoy', 'Darovskoy', 'Darovskoj,Darovskoy,Darovskoye,Даровской', 58.7699900, 47.9564200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121483, 'Dankov', 'Dankov', 'Dankov,Dankova,Dankovo,Dankow,Gorad Dankou,dan ke fu,dankwf,Горад Данкоў,Данков,Данков балһсн,دانكوف,دانکوف,丹科夫', 53.2515500, 39.1555300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121484, 'Danki', 'Danki', 'Danki,Данки', 54.9180600, 37.5700900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121485, 'Danilovka', 'Danilovka', 'Danilovka,Даниловка', 50.3557300, 44.1168100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121486, 'Danilov', 'Danilov', 'Danilov,Danilow,Daniłow,Gorad Danilau,dan ni luo fu,danillopeu,danirofu,danylwf,Горад Данілаў,Данилов,دانيلوف,دانیلوف,ダニーロフ,丹尼洛夫,다닐로프', 58.1908000, 40.1717100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121487, 'Dal’neye Konstantinovo', 'Dal''neye Konstantinovo', 'Dal''ne-Konstantinovo,Dal''nee Konstantinovo,Dal''neye Konstantinovo,Dalneje Konstantinovo,Dal’ne-Konstantinovo,Dal’neye Konstantinovo,Konstantinovo,Дальнее Константиново', 55.8102500, 44.0959500, 'RU', '2013-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121488, 'Dalakovo', 'Dalakovo', 'Dalakovo,Dallagkau,Dallakau,Dolakovo,Dollaqkau,Далаково,Долаково', 43.2375900, 44.5896400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121489, 'Dagestanskiye Ogni', 'Dagestanskiye Ogni', 'Dagestanskie Ogni,Dagestanskije Ogni,Dagestanskiye Ogni,Дагестанские Огни', 42.1158900, 48.1920400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121490, 'Dachnoye', 'Dachnoye', 'Dachnoe,Dachnoye,Tasnoi,Дачное', 59.8416700, 30.2558300, 'RU', '2015-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121491, 'Dachnoye', 'Dachnoye', 'Dachnoe,Dachnoye,Дачное', 43.0846800, 44.7358000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121492, 'Chusovoy', 'Chusovoy', 'Chusovaya,Chusovij,Chusovoi,Chusovoj,Chusovoy,Chusovói,Chusva,Ciusovoi,Csuszovoj,Cusovoi,Cusovoj,Cusovoy,Cusowoj,Czusowoj,Gorad Chusavoj,Tchoussovoi,Tchoussovoï,Tchussovoi,Tjusovoj,Tschussowoi,Tsjoesovoj,Tsjusovoj,Tsusovoi,Tšusovoi,Zavod Chusovskoye,chwswfwy,chwswwwyy,qiu suo wo yi,tshwswfwy,Çusovoy,Ĉusovoj,Čusovoi,Čusovoj,Čusowoj,Горад Чусавой,Чусва,Чусовий,Чусовой,Чусовој,تشوسوفوي,چوسوفوی,چوسوووئی,丘索沃伊', 58.3013000, 57.8131000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121493, 'Churovichi', 'Churovichi', 'Churovichi,Tsjurovitsji,Чуровичи', 52.1693000, 31.9926000, 'RU', '2014-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121494, 'Chupa', 'Chupa', 'Chup,Chupa,Cuuppa,Tsjupa,Tsuupa,Tsuuppa,Tšuupa,Tšuuppa,Čuuppa,Чупа', 66.2700100, 33.0548600, 'RU', '2015-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121495, 'Chukhloma', 'Chukhloma', 'Chukhloma,Tsjukhloma,Чухлома', 58.7537500, 42.6831800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121496, 'Chufarovo', 'Chufarovo', 'Chufarovo,Tsjufarovo,Чуфарово', 54.0963000, 47.3367000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121497, 'Chudovo', 'Chudovo', 'Chudovo,Chúdovo,Cudovo,Czudowo,Tchoudovo,Tchudovo,Tiutova,Tjudovo,Tschudowo,Tsjoedovo,Tsjudovo,Tsudovo,Tšudovo,chudobo,chudovu~o,chwdwfw,qiu duo wo,tshwdwfw,Çudovo,Ĉudovo,Čudovo,Чудово,تشودوفو,چودوفو,チュドヴォ,丘多沃,추도보', 59.1166700, 31.6833300, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121498, 'Chuchkovo', 'Chuchkovo', 'Chuchkovo,Tsjutsjkovo,Чучково', 54.2693100, 41.4464800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121499, 'Chontaul', 'Chontaul', 'Chontaul,Tsjontaul,Чонтаул', 43.3048100, 46.8596700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121500, 'Chkalovskiy', 'Chkalovskiy', 'CKL,Chkalovskaya,Chkalovskij,Chkalovskiy,Shhelkovo-3,Shhjolkovo-3,Чкаловский,Щелково-3,Щёлково-3', 55.8953400, 38.0776300, 'RU', '2017-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121501, 'Chkalovsk', 'Chkalovsk', 'Chkalovsk,Tsjkalovsk,Vasil''yevo,Vasilevo,Vasil’yevo,Чкаловск', 56.7677600, 43.2513500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121502, 'Chistoye', 'Chistoye', 'Chistoe,Chistoye,Tsjistoje,Чистое', 56.5375300, 43.0044500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121503, 'Chistopol’', 'Chistopol''', 'Chistaj,Chistopol'',Chistopol’,Tsistopol,Tsjistopol,Tšistopol,Чистай,Чистополь', 55.3631100, 50.6424400, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121504, 'Chishmy', 'Chishmy', 'Chishmy,Tsjisjmy,Чишмы', 54.5764800, 55.3764200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121505, 'Chirkey', 'Chirkey', 'Cherkai,Chirkat,Chirkej,Chirkey,Chirkkat,Staryy Chirkey,Staryy-Cherkey,Tsjirkej,Чиркей', 42.9613100, 46.9786600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121506, 'Chiri-Yurt', 'Chiri-Yurt', 'Cemzavod,Chir-Yurt,Chiri-Jurt,Chiri-Yurt,Chu''jrin-Ehvl,Ciri-Jurt,Cuyrin-Evl,Nadrec''e,Nadrech''e,Nadrech''ye,Nadrech’ye,Nadreč’e,Tsjiri-Jurt,Çüyrin-Evl,Čiri-Jurt,Надречье,Цемзавод,Чири-Юрт,Чуьйрин-Эвл', 43.0886900, 45.7432300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121507, 'Chikola', 'Chikola', 'Chikola,Tsjikola,Чикола', 43.1905500, 43.9209300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121508, 'Chesnokovka', 'Chesnokovka', 'Chesnokovka,Tsjesnokovka,Чесноковка', 54.6124200, 55.9457500, 'RU', '2016-06-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121509, 'Cherusti', 'Cherusti', 'Cherust'',Cherusti,Cherust’,Tsjerusti,Черусти', 55.5497600, 40.0107100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121510, 'Chertkovo', 'Chertkovo', 'Chertkovo,Tsjertkovo,Чертково', 49.3847000, 40.1547100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121511, 'Chyorny Yar', 'Chyorny Yar', 'Cherny Yar,Chernyj Jar,Chernyy Yar,Chjornyj Jar,Chyorny Yar,Chërnyy Yar,Tschernyi-jar,Tschernyjar,Tsjernyj Jar,Черный Яр,Чёрный Яр', 48.0624200, 46.1091100, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121512, 'Chernyshkovskiy', 'Chernyshkovskiy', 'Chernyshkov,Chernyshkovskij,Chernyshkovskiy,Tschernyschkowski,Tsjernysjkovskij,Tzhernyshkovskiy,Чернышковский', 48.4218800, 42.2308300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121513, 'Chernyanka', 'Chernyanka', 'Chernjanka,Chernyanka,Tschernjanka,Tsjernjanka,Чернянка', 50.9409500, 37.8069300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121514, 'Chernyakhovsk', 'Chernyakhovsk', 'Cerniachovskas,Cernjachovsk,Cernjahovsk,Cernjakhovsk,Chernikovsk,Chernjakhovsk,Chernyakhovsk,Chernyakhovskiy,Chernyakovsky,Czerniachowsk,Insterburg,Isrutis,Tschernjachowsk,Tsernjahovsk,Tšernjahovsk,Wystruc,Wystruć,cheleunyahobseukeu,Ĉernjaĥovsk,Černiachovskas,Černjachovsk,Černjahovsk,Černjakhovsk,Įsrutis,Черняховск,체르냐홉스크', 54.6334500, 21.8155700, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121515, 'Chernushka', 'Chernushka', 'Chernushka,Tchernouchka,Tschernuschka,Tsjernusjka,qie er nu shen ka,Чернушка,切爾努什卡', 56.5072200, 56.0766100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121516, 'Chernukha', 'Chernukha', 'Chernukha,Tsjernukha,Чернуха', 55.5973900, 43.7556000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121517, 'Chernoyerkovskaya', 'Chernoyerkovskaya', 'Chernoerkovskaja,Chernoyerkovskaya,Tsjernojerkovskaja,Черноерковская', 45.4330600, 37.7686100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121518, 'Chernomorskiy', 'Chernomorskiy', 'Chernomorskij,Chernomorskiy,Tsjernomorskij,Черноморский', 44.8505600, 38.4936100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121519, 'Chernolesskoye', 'Chernolesskoye', 'Chernolesskoe,Chernolesskoye,Tsjernolesskoje,Чернолесское', 44.7155600, 43.7133300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121520, 'Chernoistochinsk', 'Chernoistochinsk', 'Chernoistochinsk,Chernoistochinskiy,Tsjernoistotsjinsk,Черноисточинск', 57.7363900, 59.8719400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121521, 'Chernogolovka', 'Chernogolovka', 'Cernogolovka,Cernogolowka,Cernoqolovka,Chernogolovka,Chernogolovko,Chornogolovka,Czernogolowka,Czernogołowka,Tchernogolovka,Tschernogolowka,Tsernogolovka,Tsjernogolovka,Txernogolovka,Tšernogolovka,chrnwglwwka,chrnwgwlwfka,qie er nuo ge luo fu ka,tshyrnwghwlwfka,Çernoqolovka,Ĉernogolovka,Černogolovka,Černogolowka,Черноголовка,Черноголовка балһсн,Черноголовко,Чорноголовка,تشيرنوغولوفكا,چرنوگلووکا,چرنوگولوفکا,切爾諾戈洛夫卡', 56.0000000, 38.3666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121522, 'Chernitsyno', 'Chernitsyno', 'Chernicyno,Chernitsyno,Tsjernitsyno,Черницыно', 51.5073900, 36.0510100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121523, 'Cherneya', 'Cherneya', 'Cherneja,Cherneya,Чернея', 56.2497500, 28.5425600, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121524, 'Chërnaya Kholunitsa', 'Chernaya Kholunitsa', 'Chernaja Kholunica,Chernaya Kholunitsa,Chjornaja Kholunica,Chërnaya Kholunitsa,Tsjernaja Kholunitsa,Черная Холуница,Чёрная Холуница', 58.8511500, 51.7154500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121525, 'Chornoye', 'Chornoye', 'Chernoye,Chjornoe,Chornoye,Chërnoye,Чёрное', 55.7461100, 38.0688900, 'RU', '2016-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121526, 'Chern’', 'Chern''', 'Chern'',Chern’,Tsjern,Чернь', 53.4523200, 36.9145000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121527, 'Chermoz', 'Chermoz', 'Chermoz,Tsjermoz,Чермоз', 58.7813000, 56.1577000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121528, 'Chermen', 'Chermen', 'Bazorkino,Bozorkino,Chermen,Tsjermen,Чермен', 43.1486100, 44.7069400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121529, 'Cherkizovo', 'Cherkizovo', 'Cherkizovo,Tekstil''shchiki,Tekstil’shchiki,Tsjerkizovo,Черкизово', 55.9758300, 37.7875000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121530, 'Cherkessk', 'Cherkessk', 'Batalpashinsk,Cerkesk,Cerkessk,Cherkes kuala,Cherkessk,Cherkessk shakhar,Czerkiesk,Shehrdzhehs kualeh,Sherkesh shakhar,Tscherkessk,Tserkessk,Tsjerkessk,Tšerkessk,Yezhovo-Cherkessk,Zhezhoro-Cherkessk,cheleukeseukeu,cherukesuku,zrqsq,Ĉerkessk,Čerkesk,Черкес къала,Черкесск,Черкесск шахар,Шеркеш шахар,Шэрджэс къалэ,צרקסק,チェルケスク,체르케스크', 44.2233300, 42.0577800, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121531, 'Cherkasskoye', 'Cherkasskoye', 'Cherkaskoye,Cherkasskoe,Cherkasskoye,Cherkasy,Tsjerkasskoje,Черкасское', 52.4289500, 47.2104800, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121532, 'Cherepovets', 'Cherepovets', 'CEE,Cerepovec,Cerepoveca,Cerepovecas,Cerepoveco,Cerepovet,Cerepovets,Cerepoveț,Cerjepowjec,Cherepovec,Cherepovec'',Cherepovets,Cherepovetz,Cherepovéts,Cserepovec,Czerepowiec,Gorad Charapavec,Tcherepovets,Tjerepovets,Tscherepowez,Tserepovets,Tsjerepovets,Txerepovets,Tšerepovets,chelepobecheu,cherepovu~etsu,chrpwwts,chyrypwwts,qie lie bo wei ci,tshyrybwfyts,Çerepovets,Ĉerepoveco,Čerepovec,Čerepoveca,Čerepovecas,Čerjepowjec,Горад Чарапавец,Череповетс,Череповец,Череповець,تشيريبوفيتس,چرپووتس,چیریپووتس,チェレポヴェツ,切列波韋茨,체레포베츠', 59.1333300, 37.9000000, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121533, 'Cherepet’', 'Cherepet''', 'Cherepet'',Cherepet’,Tsjerepet,Черепеть', 54.1178400, 36.3787700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121534, 'Cheremushskiy', 'Cheremushskiy', 'Cheremukha,Cheremushskij,Cheremushskiy,Cherëmukha,Tsjeremusjskij,Черемушский', 61.2730600, 47.2636100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121535, 'Cherëmushki', 'Cheremushki', 'Cheremushki,Cherjomushki,Cherëmushki,Черёмушки', 55.6647300, 37.5613500, 'RU', '2016-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121536, 'Cherëmukhovo', 'Cheremukhovo', 'Cheremukhovo,Cherjomukhovo,Cherëmukhovo,Tsjeremukhovo,Черемухово,Черёмухово', 60.3484200, 59.9850700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121537, 'Cheremshan', 'Cheremshan', 'Cheremshan,Tsjeremsjan,Черемшан', 54.6666700, 51.5000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121538, 'Cheremisinovo', 'Cheremisinovo', 'Cheremisinovo,Tsjeremisinovo,Черемисиново', 51.8855000, 37.2646000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121539, 'Cherdyn’', 'Cherdyn''', 'Cherdyn'',Cherdyn’,Tscherdyn,Tsjerdyn,Чердынь', 60.4029500, 56.4786800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121540, 'Cherdakly', 'Cherdakly', 'Cherdakly,Tsjerdakly,Чердаклы', 54.3594000, 48.8449700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121541, 'Chemodanovka', 'Chemodanovka', 'Chemodanovka,Tsjemodanovka,Чемодановка', 53.2316200, 45.2473800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121542, 'Chelno-Vershiny', 'Chelno-Vershiny', 'Chelno-Vershiny,Tsjelno-Versjiny,Челно-Вершины', 54.4148000, 51.0859400, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121543, 'Chelbasskaya', 'Chelbasskaya', 'Chelbaskaya,Chelbasskaja,Chelbasskaya,Tsjelbasskaja,Челбасская', 45.9792400, 39.3718600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121544, 'Chekmagush', 'Chekmagush', 'Chekmagush,Chekmagushi,Tsjekmagusj,Чекмагуш', 55.1319400, 54.6555600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121545, 'Chekhov', 'Chekhov', 'Cechov,Cehov,Cehova,Cexov,Chejov,Chekhov,Chéjov,Czechow,Gorad Chehkhau,Lopasnya,Tchekhov,Tjechov,Tschechow,Tsehhov,Tsehov,Tsjekhov,Tsjekhov i Moskva oblast,Tšehhov,Tšehov,chehofu,chehopeu,chkhwf  astan mskw,chykhwf,qi he fu,tshykhwf,Çexov,Ĉeĥov,Čechov,Čehov,Čehova,Горад Чэхаў,Чехов,تشيخوف,چخوف، استان مسکو,چیخوف,チェーホフ,契訶夫,체호프', 55.1477000, 37.4772800, 'RU', '2013-01-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121546, 'Chekalin', 'Chekalin', 'Chekalin,Dikhvin,Likhvin,Tsjekalin,Чекалин', 54.0968500, 36.2449900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121547, 'Chegem Vtoroy', 'Chegem Vtoroy', 'Chechem,Chegem Vtoroj,Chegem Vtoroy,Tsjegem Vtoroj,Чегем Второй', 43.5958300, 43.5994400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121548, 'Chegem', 'Chegem', 'Chechem,Chegem,Tsjegem,Чегем', 43.2833300, 43.1333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121549, 'Chechen-Aul', 'Chechen-Aul', 'Cecana,Cecen-Aul,Chechana,Chechen-Aul,Kalinovka,Tsjetsjen-Aul,Çeçana,Čečen-Aul,Калиновка,Чечана,Чечен-Аул', 43.2000000, 45.7888900, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121550, 'Chebsara', 'Chebsara', 'Chabsara,Chebsara,Tsjebsara,Чебсара', 59.2001600, 38.8355600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121551, 'Cheboksary', 'Cheboksary', 'CSY,Ceboksarad,Ceboksarai,Ceboksari,Ceboksary,Ceboksarî,Chabaksar,Cheboksar,Cheboksar'',Cheboksara,Cheboksari,Cheboksary,Cheboksar’,Choupachkar,Csebokszari,Csebokszári,Czeboksary,Gorad Chehbaksary,Shoupashkaru,Shovakshehҥer,Shubashkar,Shupashkar,Shyvashar,Supaskar,Tcheboksary,Tjeboksary,Tscheboksary,Tscheboxari,Tseboksaro,Tseboksary,Tsjeboksari,Tsjeboksary,Txeboksari,Txeboksary,Tšeboksary,Tšeboksarõ,chebogsali,cheboksari,chebokusaru,chybwksary,qie bo ke sa lei,tshybwksary,zbwqsry,Çeboksarı,Ĉeboksari,Čeboksarad,Čeboksarai,Čeboksari,Čeboksary,Şupaşkar,Горад Чэбаксары,Чабаксар,Чебоксар,Чебоксара,Чебоксари,Чебоксары,Шовакшэҥер,Шоупашкаръ,Шубашкар,Шупашкар,Шывашар,Չեբոքսարի,צבוקסרי,تشيبوكساري,چاباق‌سر,چیبوکساری,چیبوکسارے,ჩებოქსარი,チェボクサル,切博克萨雷,체복사리', 56.1322200, 47.2519400, 'RU', '2013-01-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121552, 'Chaykovskiy', 'Chaykovskiy', 'Chajkovskij,Chaykovskiy,Tsaikovski,Tsjajkovskij,Tšaikovski,Чайковский', 56.7686400, 54.1148400, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121553, 'Chaykovskaya', 'Chaykovskaya', 'Chajkovskaja,Chaykovskaya,Tsjajkovskaja,Чайковская', 58.1288000, 55.5352000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121554, 'Chastyye', 'Chastyye', 'Chastye,Chastyye,Tsjastye,Частые', 57.2887600, 54.9727800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121555, 'Chashnikovo', 'Chashnikovo', 'Chashnikovo,Tsjasjnikovo,Чашниково', 56.0333300, 37.1666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121556, 'Chaplygin', 'Chaplygin', 'Chaplygin,Ranenburg,Tsjaplygin,Чаплыгин', 53.2431900, 39.9628800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121557, 'Chapayevsk', 'Chapayevsk', 'Capaevsk,Capajevsk,Capajewsk,Ceapaievsk,Chapaevs''k,Chapaevsk,Chapajevsk,Chapayevsk,Chapáyevsk,Czapajewsk,Gorad Chapaeusk,Ivashchenkovo,Tchapaievsk,Tchapaïevsk,Tjapajevsk,Trotsk,Tsapajevsk,Tschapajewsk,Tsjapajevsk,Tšapajevsk,chapayebseukeu,chapayfsk,chpayywsk,qia pa ye fu si ke,tshabayyfsk,Ĉapajevsk,Čapaevsk,Čapajewsk,Горад Чапаеўск,Чапаевск,Чапаєвськ,Чапајевск,تشاباييفسك,چاپایفسک,چپائیوسک,恰帕耶夫斯克,차파옙스크', 52.9771000, 49.7086000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121558, 'Chamzinka', 'Chamzinka', 'Chamzinka,Tsjamzinka,Чамзинка', 54.4018800, 45.7838700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121559, 'Chamlykskaya', 'Chamlykskaya', 'Chamlikskaya,Chamlykskaja,Chamlykskaya,Chamlyskaya,Tschamlykaja,Tsjamlykskaja,Чамлыкская', 44.7158300, 40.8786100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121560, 'Chaltyr', 'Chaltyr', 'Chaltyr,Chaltyr'',Chaltyr’,Tschaltyr,Tsjaltyr,Чалтырь', 47.2847700, 39.4823200, 'RU', '2014-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121561, 'Chagoda', 'Chagoda', 'Belyy Bychek,Belyy Bychok,Cagoda,Chagoda,Tsagoda,Tsjagoda,Tšagoda,Čagoda,Чагода', 59.1640000, 35.3285000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121562, 'Chaadayevka', 'Chaadayevka', 'Chaadaevka,Chaadayevka,Tsjaadajevka,Чаадаевка', 53.1427000, 45.9122000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121563, 'Bytosh’', 'Bytosh''', 'Bytosh'',Bytoshskiy,Bytosh’,Bytosj,Бытошь', 53.8186100, 34.0911600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121564, 'Bystrogorskiy', 'Bystrogorskiy', 'Bystrogorskij,Bystrogorskiy,Быстрогорский', 48.2081300, 41.1409700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121565, 'Bylym', 'Bylym', 'Byllym,Bylym,Ugol''nyy,Ugol’nyy,Былым', 43.4650000, 43.0388900, 'RU', '2014-06-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121566, 'Bykovo', 'Bykovo', 'Bykovo,Быково', 55.6361400, 38.0802700, 'RU', '2014-06-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121567, 'Bykovo', 'Bykovo', 'Bykovo,Быково', 55.6207500, 38.0797000, 'RU', '2014-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121568, 'Bykovo', 'Bykovo', 'Bykovo,Bykowo,Kalinov,Kalinova Balka,Kalinovaya Balka,Быково', 49.7661800, 45.3886600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121569, 'Buzuluk', 'Buzuluk', 'Bouzoulouk,Bozaulyk,Busuluk,Buzuluk,Buzulukas,Buzułuk,Gorad Buzuluk,bu zu lu ke,bujullukeu,bwzwlwk,Бозаулык,Бузулук,Быҙаулыҡ,Горад Бузулук,بوزولوك,بوزولوک,布祖盧克,부줄루크', 52.7807000, 52.2635000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121570, 'Buzdyak', 'Buzdyak', 'Buzdjak,Buzdyak,Буздяк', 54.5833300, 54.5500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121571, 'Buynaksk', 'Buynaksk', 'Boejnaksk,Buinaksk,Bujnakh"sk,Bujnaksk,Buynaksk,Temir Khan Choura,Temir-Khan-Shura,bu-inagseukeu,Буйнакск,Буйнахъск,부이낙스크', 42.8190000, 47.1192000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121572, 'Buy', 'Buy', 'Buj,Buy,Буй', 58.4806700, 41.5369900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121573, 'Buturlinovka', 'Buturlinovka', 'Boutourlinovka,Buturlinivka,Buturlinovka,Buturlinovskiy,Buturlinowka,Buturlínovka,Gorad Buturlinauka,bu tu er li nuo fu ka,butuleullinobka,bwtwrlynwfka,Бутурлиновка,Бутурлиновка балһсн,Бутурлинівка,Горад Бутурлінаўка,بوتورلینوفکا,布圖爾利諾夫卡,부투를리놉카', 50.8238900, 40.6091700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121574, 'Buturlino', 'Buturlino', 'Buturlino,Бутурлино', 55.5667300, 44.8973800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121575, 'Burtunay', 'Burtunay', 'Burtunaj,Burtunay,Буртунай', 42.9886000, 46.6303400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121576, 'Burmakino', 'Burmakino', 'Burmakino,Burmikino,Бурмакино', 57.4166300, 40.2368700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121577, 'Burlatskoye', 'Burlatskoye', 'Burlackoe,Burlatskoe,Burlatskoje,Burlatskoye,Бурлатское,Бурлацкое', 45.0563900, 43.6350000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121578, 'Buribay', 'Buribay', 'Buribai,Buribaj,Buribay,Buryubaeva,Бурибай', 51.9616700, 58.1591700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121579, 'Burevestnik', 'Burevestnik', 'Burevestnik,Sovkhoz Burevestnik,Буревестник', 56.1440300, 43.7883200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121580, 'Burayevo', 'Burayevo', 'Buraevo,Burajevo,Burayevo,Бураево', 55.8406900, 55.4083400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121581, 'Bolgar', 'Bolgar', 'Bolgar,Bulgar,Kuybyshev,Spask,Spassk,Spassk-Tatarskiy,Болгар', 54.9500000, 49.0666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121582, 'Bulgakovo', 'Bulgakovo', 'Bulgakovo,Булгаково', 54.4968000, 55.8843000, 'RU', '2016-06-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121583, 'Buinsk', 'Buinsk', 'Buinsk,Буинск', 55.1950000, 47.0608000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121584, 'Buinsk', 'Buinsk', 'Boeinsk,Bouinsk,Bouïnsk,Bua,Buinsk,Gorad Buinsk,Pava,bu yin si ke,bu-inseukeu,buinsuku,bwynsk,bwyynsk  tatarstan,Буинск,Горад Буінск,Пăва,بوينسك,بویینسک، تاتارستان,ブインスク,布因斯克,부인스크', 54.9711900, 48.2918400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121585, 'Buguruslan', 'Buguruslan', 'Bogoroslan,Bogyryslan,Bougourouslan,Bugurslan,Buguruslan,Buguruslanas,Buguruslano,Buguruslán,Buguruszlan,Bugurusłan,Buquruslan,Gorad Buguruslan,bu gu lu si lan,buguluseullan,bwghwrwslan,bwgwrwslan,Богырыслан,Боғорослан,Бугурслан,Бугуруслан,Горад Бугуруслан,بوغوروسلان,بوگوروسلان,布古魯斯蘭,부구루슬란', 53.6554000, 52.4420000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121586, 'Bugul’ma', 'Bugul''ma', 'Bugul''ma,Bugulina,Bugulma,Bugul’ma,Bөgelmə,UUA,Бугульма,Бөгелмә', 54.5378000, 52.7985000, 'RU', '2017-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121587, 'Budogoshch’', 'Budogoshch''', 'Budogoschtsch,Budogoschtsch-Sumpe,Budogoshch'',Budogoshch’,Budogoshh'',Budogosjtsj,Будогощь', 59.2815800, 32.4707400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121588, 'Budënnovsk', 'Budennovsk', 'Budennovsk,Budennowsk,Budenovsk,Budjennowsk,Budjonnovsk,Budyonovsk,Budënnovsk,Karabagly,Prikumsk,Svetaya Kresta,Svyatoy Krest,Буденновск,Будённовск', 44.7838900, 44.1658300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121589, 'Bryukhovetskaya', 'Bryukhovetskaya', 'Brjukhoveckaja,Brjukhovetskaja,Bryukhovetskaya,Брюховецкая', 45.8060300, 38.9995900, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121590, 'Bryansk', 'Bryansk', 'BZK,Breansk,Briansk,Briańsk,Brjansk,Brjansko,Bryansk,beulyanseukeu,Брянск,Брјанск,브랸스크', 53.2520900, 34.3716700, 'RU', '2013-01-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121591, 'Brusyanka', 'Brusyanka', 'Brusianskij,Brusjanka,Brusjanskij,Brusyanka,Brusyanskiy,Брусянка,Брусянский', 53.9849200, 38.0359300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121592, 'Bronnitsy', 'Bronnitsy', 'Bronicai,Bronici,Bronnici,Bronnicy,Bronniti,Bronnitsi,Bronnitso,Bronnitsy,Bronnitsõ,Bronnizy,Bronnițî,Brónnitsi,Gorad Bronnicy,beulonichi,brwnytsy,bu long ni qi,buron''nitsu~i,Броници,Броннитси,Бронницы,Бронницы балһсн,Бронниці,Горад Бронніцы,برونيتسي,برونیتسی,ブロンニツィ,布龍尼齊,브로니치', 55.4211200, 38.2618800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121593, 'Breytovo', 'Breytovo', 'Brejtovo,Breytovo,Брейтово', 58.2992500, 37.8617200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121594, 'Nogamerzin-Yurt', 'Nogamerzin-Yurt', 'Bratskiy,Bratskoe,Bratskoje,Bratskoye,Lomaz-Jurt,Lomaz-Yurt,NogIamirzin-Jurt,Nogaj-Mirza-Jurt,Nogamerzin-Jurt,Nogamerzin-Yurt,Nogamirzin-Yurt,Nogay-Mirza,Nogay-Mirza-Yurt,Nomaz-Jurt,Nomaz-Yurt,Noġamirzin-Yurt,Братское,Ломаз-Юрт,НогІамирзин-Юрт,Ногай-Мирза-Юрт,Ногамерзин-Юрт,Номаз-Юрт', 43.6536100, 44.8888900, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121595, 'Bratovshchina', 'Bratovshchina', 'Bratovshchina,Bratovshhina,Bratovsjtsjina,Братовщина', 56.0500000, 37.8833300, 'RU', '2016-07-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121596, 'Brateyevo', 'Brateyevo', 'Brat"yevo,Brateevo,Brateyevo,Brat”yevo,Братеево', 55.6375500, 37.7643800, 'RU', '2016-04-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121597, 'Borzoy', 'Borzoy', 'Al''pijskoe,Al''piyskoye,Al’pijskoe,Al’piyskoye,Barzoy,Borze,Borzoj,Borzoy,Альпийское,Борзе,Борзой', 42.8414700, 45.6274600, 'RU', '2012-02-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121598, 'Borskoye', 'Borskoye', 'Borskoe,Borskoje,Borskoye,Борское', 53.0333300, 51.7166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121599, 'Borovsk', 'Borovsk', 'Borovs''k,Borovsk,Borowsk,Bórovsk,bo luo fu si ke,bolobseukeu,borofusuku,bwrwfsk,Боровск,Боровськ,بوروفسك,بوروفسک,ボロフスク,博羅夫斯克,보롭스크', 55.2063900, 36.4861100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121600, 'Borovoy', 'Borovoy', 'Borovaya,Borovoi,Borovoj,Borovoy,Боровой', 64.6121000, 32.2496800, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121601, 'Borovoy', 'Borovoy', 'Borovoj,Borovoy,Borovyj,Borovyy,Боровой,Боровый', 63.2300500, 52.8903100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121602, 'Borovichi', 'Borovichi', 'Borovichi,Borovichí,Borovici,Boroviciai,Borovitchi,Borovitji,Borovitsi,Borovitsji,Borovitši,Boroviçi,Boroviĉi,Boroviči,Borovičiai,Borowicze,Borowitschi,Gorad Baravichy,bo luo wei qi,bolobichi,borovu~ichi,bwrwfytshy,bwrwwychy,Боровичи,Боровичі,Горад Баравічы,بوروفيتشي,بوروویچی,ボロヴィチ,博羅維奇,보로비치', 58.3877800, 33.9154600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121603, 'Borok', 'Borok', 'Borok,Grigorovo,Борок', 58.0653200, 38.2362000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121604, 'Borodinskiy', 'Borodinskiy', 'Borodino,Borodinskij,Borodinskiy,Бородинский', 53.9985900, 37.8179200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121605, 'Orekhovo-Borisovo Yuzhnoye', 'Orekhovo-Borisovo Yuzhnoye', 'Orekhovo-Borisovo Juzhnoe,Orekhovo-Borisovo Yuzhnoye,Орехово-Борисово Южное', 55.6333300, 37.7333300, 'RU', '2016-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121606, 'Borisovka', 'Borisovka', 'Bohsouka,Borisovka,Борисовка', 50.6015500, 36.0154900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121607, 'Borisova Griva', 'Borisova Griva', 'Borisova Griva,Борисова Грива', 60.0893600, 30.9772700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121608, 'Borisoglebskiy', 'Borisoglebskiy', 'Borisoglebskaya Sloboda,Borisoglebskij,Borisoglebskiy,Borisoglebskiye Slobody,Борисоглебский', 57.2586000, 39.1508000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121609, 'Borisoglebsk', 'Borisoglebsk', 'Borisoglebs''k,Borisoglebsk,Borisoglebska,Borisoglebskas,Borisogļebska,Borisoqlebsk,Borissoglebsk,Borysoglebsk,Gorad Barysaglebsk,bao li suo ge lie bu si ke,bolisogeullebseukeu,bwryswghlybsk,bwryswglbsk,bwryswglybsk,Борисоглебск,Борисоглебск балһсн,Борисоглєбськ,Горад Барысаглебск,بوريسوغليبسك,بوریسوگلبسک,بوریسوگلیبسک,鲍里索格列布斯克,보리소글렙스크', 51.3671300, 42.0849400, 'RU', '2016-12-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121610, 'Borinskoye', 'Borinskoye', 'Borinskiye Zavody,Borinskoe,Borinskoje,Borinskoye,Боринское', 52.4569000, 39.3713000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121611, 'Borgustanskaya', 'Borgustanskaya', 'Borgustanskaja,Borgustanskaya,Боргустанская', 44.0547000, 42.5288000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121612, 'Bor', 'Bor', 'Bor,Bor i Nizjegorod oblast,Boras,Gorad Bor,Motavka,bo er,boleu,bwr,bwr  astan nyzhny nwwgwrwd,Бор,Горад Бор,بور,بور، استان نیژنی نووگورود,博爾,보르', 56.3580800, 44.0747700, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121613, 'Bamut', 'Bamut', 'Bamut,Bomut,Bukovka,Bummat,Bummate,Nizhniy Bamut,Бамут,Буковка,Буммат,Буммате', 43.1598600, 45.1973400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121614, 'Bol’shoy Khomutets', 'Bol''shoy Khomutets', 'Bol''shoj Khomutec,Bol''shoy Khomutets,Bol’shoy Khomutets,Большой Хомутец', 52.7828500, 39.8721400, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121615, 'Bol’shoy Karay', 'Bol''shoy Karay', 'Bol''shoj Karaj,Bol''shoy Karay,Bol’shoy Karay,Большой Карай', 51.6054200, 42.6900600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121616, 'Bol’shoye Skuratovo', 'Bol''shoye Skuratovo', 'Bol''shoe Skuratovo,Bol''shoye Skuratovo,Bol’shoye Skuratovo,Skuratovo,Большое Скуратово,Скуратово', 53.4385200, 36.8408500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121617, 'Bol’shoye Selo', 'Bol''shoye Selo', 'Bol''shoe Selo,Bol''shoye Selo,Bolsjoje Selo,Bol’shoye Selo,Большое Село', 57.7177400, 38.9334100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121618, 'Bol’shoye Murashkino', 'Bol''shoye Murashkino', 'Bol''shoe Murashkino,Bol''shoye Murashkino,Bol.Murasjkino,Bol’shoye Murashkino,Murashkino,Большое Мурашкино', 55.7826100, 44.7754100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121619, 'Bol’shoye Gryzlovo', 'Bol''shoye Gryzlovo', 'Bol''shoe Gryzlovo,Bol''shoye Grizlovo,Bol''shoye Gryzlovo,Bol’shoye Grizlovo,Bol’shoye Gryzlovo,Verkhneye Gryzlovo,Большое Грызлово', 54.8003300, 37.6393900, 'RU', '2012-07-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121620, 'Bol’shoye Boldino', 'Bol''shoye Boldino', 'Bol''shoe Boldino,Bol''shoye Boldino,Bol’shoye Boldino,Большое Болдино', 55.0058800, 45.3141900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121621, 'Bol''shiye Vyazëmy', 'Bol''shiye Vyazemy', 'Bol''shie Vjazjomy,Большие Вязёмы', 55.6205800, 36.9762000, 'RU', '2010-07-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121622, 'Bolshevo', 'Bolshevo', 'Bolshevo,Болшево', 55.9348600, 37.8300200, 'RU', '2014-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121623, 'Bol’shaya Setun’', 'Bol''shaya Setun''', 'Bol''shaja Setun'',Bol''shaya Setun'',Bol’shaya Setun’,Большая Сетунь', 55.7166700, 37.4166700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121624, 'Bol’shaya Martynovka', 'Bol''shaya Martynovka', 'Bol''shaja Martynovka,Bol''shaya Martinovka,Bol''shaya Martynovka,Bol.Martynovka,Bol’shaya Martinovka,Bol’shaya Martynovka,Martynov,Martynovka,Martynovskoye,Martynowskoje,Бол.Мартыновка,Большая Мартыновка', 47.2742100, 41.6668100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121625, 'Bol’shaya Izhora', 'Bol''shaya Izhora', 'Bol''shaja Izhora,Bol''shaya Izhora,Bolsjaja Izjora,Bol’shaya Izhora,Haisevaisi,Большая Ижора', 59.9379600, 29.5772100, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121626, 'Bolokhovo', 'Bolokhovo', 'Bolochevo,Bolokhovka,Bolokhovo,Болохово', 54.0837800, 37.8289500, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121627, 'Bologoye', 'Bologoye', 'Bologoe,Bologoje,Bologoye,Бологое', 57.8799000, 34.1068100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121628, 'Bolkhov', 'Bolkhov', 'Bolchov,Bolchovas,Bolchow,Bolhovo,Boljov,Bolkhov,Bolĥovo,Bołchow,Bóljov,Bólkhov,Gorad Bolkhau,bo er huo fu,bolhopeu,boruhofu,bwlkhwf,Болхов,Болхов балһсн,Горад Болхаў,بولخوف,ボルホフ,博爾霍夫,볼호프', 53.4429500, 36.0054600, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121629, 'Bolgatovo', 'Bolgatovo', 'Bolgatovo,Bolgotovo,Болгaтово,Болгатово', 56.7978500, 28.9365300, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121630, 'Boksitogorsk', 'Boksitogorsk', 'Boksitogors''k,Boksitogorsk,Boksitogorska,Boksitogorskas,Boksitoqorsk,Bokszitogorszk,Gorad Baksitagorsk,bo ke xi tuo ge er si ke,bogsitogoleuseukeu,bokushitogorusuku,bwksytwghwrsk,bwksytwgwrsk,Бокситогорск,Бокситогорськ,Горад Баксітагорск,بوكسيتوغورسك,بوکسیتوگورسک,ბოქსიტოგორსკი,ボクシトゴルスク,博克西托戈爾斯克,복시토고르스크', 59.4740500, 33.8485300, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121631, 'Bokovskaya', 'Bokovskaya', 'Bokovskaja,Bokovskaya,Боковская', 49.2289900, 41.8306000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121632, 'Bokino', 'Bokino', 'Bokino,Бокино', 52.6374400, 41.4596800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121633, 'Boguchar', 'Boguchar', 'Boguchar,Bogutsjar,Богучар', 49.9357700, 40.5450000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121634, 'Bogovarovo', 'Bogovarovo', 'Bogovarovo,Боговарово', 58.9784900, 47.0246200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121635, 'Bogoslovka', 'Bogoslovka', 'Bogoslovka,Богословка', 53.2083700, 44.8013300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121636, 'Bogorodskoye', 'Bogorodskoye', 'Bogorodskoe,Bogorodskoye,Богородское', 55.8135300, 37.7161700, 'RU', '2016-03-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121637, 'Bogorodskoye', 'Bogorodskoye', 'Bogorodskoe,Bogorodskoje,Bogorodskoye,Богородское', 57.8284900, 50.7485600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121638, 'Bogorodskoye', 'Bogorodskoye', 'Bogorodskoe,Bogorodskoye,Klintsevo,Богородское', 57.0469500, 41.0135400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121639, 'Bogorodskoye', 'Bogorodskoye', 'Bogorodskoe,Bogorodskoye,Богородское', 56.5500000, 37.8833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121640, 'Bogorodskoye', 'Bogorodskoye', 'Bogorodskoe,Bogorodskoje,Bogorodskoye,Богородское', 56.5000000, 38.1833300, 'RU', '2014-11-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121641, 'Bogorodsk', 'Bogorodsk', 'Bogorods''k,Bogorodsk,Bogorodskas,Bogorodskoje,Bogorodskoye,Boqorodsk,Gorad Bagarodsk,bo ge luo ci ke,bwghwrwdsk,bwgwrwdsk  astan nyzhny nwwgwrwd,Богородск,Богородськ,Горад Багародск,بوغورودسك,بوگورودسک، استان نیژنی نووگورود,博戈羅茨克', 56.1051300, 43.5129400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121642, 'Bogoroditsk', 'Bogoroditsk', 'Bogorodic''k,Bogorodick,Bogorodickas,Bogoroditk,Bogoroditsk,Bogorodizk,Bogorodițk,Boqorodick,Boqorodiçk,Gorad Bagarodzick,bo ge luo ji ci ke,bogolodicheukeu,bogorojitsuku,bwghwrwdytsk,bwgwrwdytsk,Богородицк,Богородицьк,Горад Багародзіцк,بوغوروديتسك,بوگورودیتسک,ボゴロジツク,博戈羅季茨克,보고로디츠크', 53.7716600, 38.1240800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121643, 'Bogolyubovo', 'Bogolyubovo', 'Bogoljubovo,Bogolyubovo,Боголюбово', 56.1905200, 40.5231300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121644, 'Bogatyye Saby', 'Bogatyye Saby', 'Bogatye Saby,Bogatyye Saby,Saby,Богатые Сабы', 56.0102000, 50.4483000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121645, 'Bogatyr’', 'Bogatyr''', 'Bogatyr,Bogatyr'',Bogatyr’,Богатырь', 53.4298000, 49.9455000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121646, 'Bogatoye', 'Bogatoye', 'Bogatoe,Bogatoje,Bogatoye,Pavlovka,Богатое', 53.0601000, 51.3325000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121647, 'Bobrov', 'Bobrov', 'Bobrov,Bobrovas,Bobrow,Borrov,Gorad Babrou,bo bu luo fu,bwbrwf,bwbrwf  rwsyh,Бобров,Бобров балһсн,Горад Баброў,بوبروف,بوبروف، روسیه,博布羅夫', 51.0961100, 40.0333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121648, 'Blizhne-Pesochnoye', 'Blizhne-Pesochnoye', 'Blizhne-Pesochnoe,Blizhne-Pesochnoye,Blizhnepesochnaya,Blizjne-Pesotsjnoje,Pesochnaya,Pesochnya,Ближне-Песочное', 55.3456000, 42.1015000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121649, 'Blechepsin', 'Blechepsin', 'Blechenskiy,Blechepsin,Bletsjepsin,Blichensin,Блечепсин', 44.8202800, 40.5002800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121650, 'Blagoyevo', 'Blagoyevo', 'Blagoevo,Blagojevo,Blagoyevo,Благоево', 63.4231000, 47.9646000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121651, 'Blagoveshchensk', 'Blagoveshchensk', 'Blagovechtchensk,Blagovescensk,Blagovescenska,Blagovescenskas,Blagoveschensk,Blagovescsenszk,Blagoveshchensk,Blagoveshchenskiy,Blagoveshchenskiy Zavod,Blagoveshhen,Blagoveshhens''k,Blagoveshhensk,Blagovesjtsjensk,Blagovesjtsjensk i Basjkortostan,Blagovestsensk,Blagoveŝĉensk,Blagoveštšensk,Blagoveščensk,Blagoveščenska,Blagoveščenskas,Blagovjeshchensk,Blagoweschtschensk,Blagoweschtschenski,Blagowieszczensk,Blagowjescensk,Blagowješćensk,Blaqovesensk,Blaqoveşensk,Błagowieszczeńsk,Gorad Blagaveshchansk,beullagobesyenseukeu,blaghwfyshtshynsk,blagwwshchnsk  bashqyrstan,bu la ge wei shen si ke,Благовешченск,Благовещен,Благовещенск,Благовещенск балһсн,Благовєщенськ,Благовјешченск,Горад Благавешчанск,بلاغوفيشتشينسك,بلاگووشچنسک، باشقیرستان,布拉戈維申斯克,블라고베셴스크', 55.0350000, 55.9780600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121652, 'Blagodatnoye', 'Blagodatnoye', 'Berestovka,Blagodatnoe,Blagodatnoje,Blagodatnoye,Благодатное', 45.3997200, 42.5866700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121653, 'Blagodarnyy', 'Blagodarnyy', 'Blagodarnoe,Blagodarnoje,Blagodarnoye,Blagodarnyj,Blagodarnyy,Blagodatnoye,Благодарный', 45.0977800, 43.4363900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121654, 'Bizhbulyak', 'Bizhbulyak', 'Bizhbuljak,Bizhbulyak,Bizjbuljak,Бижбуляк', 53.6967000, 54.2642000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121655, 'Bisert’', 'Bisert''', 'Bisert,Bisert'',Bisertskiy Zavod,Bisert’,Бисерть', 56.8617400, 59.0523100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121656, 'Biryulëvo', 'Biryulevo', 'Birjuljovo,Biryulevo,Biryulëvo,Бирюлёво', 55.5863500, 37.6778100, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121657, 'Birsk', 'Birsk', 'Birs''k,Birsk,Birskas,Birszk,Boere,Böre,Gorad Birsk,Puro,bi er si ke,bileuseukeu,byrsk,Бирск,Бирск балһсн,Бірськ,Бөре,Бөрө,Горад Бірск,Пӱрӧ,بيرسك,بیرسک,比爾斯克,비르스크', 55.4211100, 55.5427800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121658, 'Bilyarsk', 'Bilyarsk', 'Biljarsk,Bilyarsk,Билярск', 54.9835800, 50.3867100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121659, 'Bilimbay', 'Bilimbay', 'Bilimbaj,Bilimbay,bylymbay,Билимбай,بيليمباي', 56.9688900, 59.8149000, 'RU', '2013-07-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121660, 'Bibirevo', 'Bibirevo', 'Bibirevo,Бибирево', 55.8833300, 37.6000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121661, 'Bezopasnoye', 'Bezopasnoye', 'Bezopasnoe,Bezopasnoje,Bezopasnoye,Безопасное', 45.6483300, 41.9360300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121662, 'Bezhta', 'Bezhta', 'Bezhita,Bezhta,Bezjta,Бежта', 42.1338000, 46.1282800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121663, 'Bezhetsk', 'Bezhetsk', 'Bejeck,Bejetk,Bejetsk,Bejețk,Beschezk,Beshezk,Bezeck,Bezeckas,Bezetsk,Bezhec''k,Bezheck,Bezhetsk,Bezjetsk,Beĵeck,Bežeck,Bežeckas,Bežetsk,Biezeck,Bieżeck,Gorad Bezhack,bejecheukeu,bejetsuku,bie re ci ke,byjytsk,bzhtsk,Бежетск,Бежецк,Бежецьк,Горад Бежацк,بيجيتسك,بژتسک,ベジェツク,別熱茨克,베제츠크', 57.7850600, 36.6965100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121664, 'Bezhanitsy', 'Bezhanitsy', 'Bezanicy,Bezanitso,Bezanitsy,Bezhanicy,Bezhanitsy,Bezjanitsy,Bežanicy,Bežanitsy,Bežanitsõ,Бежаницы', 56.9766900, 29.8906500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121665, 'Bezenchuk', 'Bezenchuk', 'Bezenchuk,Borodinskiy,Byrodinskiy,Безенчук', 52.9820000, 49.4333000, 'RU', '2014-09-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121666, 'Betlitsa', 'Betlitsa', 'Betlica,Betlitsa,Бетлица', 54.0094600, 33.9587500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121667, 'Bessonovka', 'Bessonovka', 'Bessonovka,Бессоновка', 53.3096800, 45.0406900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121668, 'Bessonovka', 'Bessonovka', 'Bessonovka,Bessonowka,Бессоновка', 50.5264400, 36.3010700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121669, 'Besskorbnaya', 'Besskorbnaya', 'Besskorbnaja,Besskorbnaya,Bezskorbnaya,Бесскорбная', 44.6447000, 41.3110000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121670, 'Besleneyevskaya', 'Besleneyevskaya', 'Besleneevskaja,Beslenejevskaja,Besleneyevskaya,Beslineyevskaya,Бесленеевская', 44.2310000, 40.7250000, 'RU', '2015-06-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121671, 'Besleney', 'Besleney', 'Beslenej,Besleney,Besleny,Бесленей', 44.2405000, 41.7387000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121672, 'Beslan', 'Beslan', 'Belsan,Beslaen,Beslan,Beslán,Bieslan,Biesłan,beseullan,beslani,besuran,Беслæн,Беслан,בסלאן,ბესლანი,ベスラン,베슬란', 43.1921700, 44.5431300, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121673, 'Beshpagir', 'Beshpagir', 'Beshpagin,Beshpagir,Besjpagir,Бешпагир', 45.0216700, 42.3808300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121674, 'Bershet’', 'Bershet''', 'Bershet'',Bershet’,Bersjet,Бершеть', 57.7309000, 56.3783000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121675, 'Bernovo', 'Bernovo', 'Bernovo,Берново', 56.6863300, 34.7035700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121676, 'Berezniki', 'Berezniki', 'Beresniki,Bereznikai,Berezniki,Bereznikí,Bereznyiki,Berezņiki,Bieriezniki,Bjerezniki,Gorad Bjarehzniki,Kydzzakar,Usol''ye-Solikamskoye,Usol’ye-Solikamskoye,belejeuniki,berezuniki,bie lie ci ni ji,bryznyky,brznyky,byryznyky,Березники,Березњики,Горад Бярэзнікі,Кыдззакар,برزنیکی,بریزنیکی,بيريزنيكي,ベレズニキ,别列兹尼基,베레즈니키', 59.4091000, 56.8204000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121677, 'Berëznik', 'Bereznik', 'Bereznik,Berjoznik,Berëznik,Dvinskoj Bereznik,Dvinskoy Bereznik,Semenovskaya,Semenovskoye,Semënovskoye,Берёзник,Двинской Березник', 62.8520000, 42.7071000, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121678, 'Berezayka', 'Berezayka', 'Berezajaka,Berezajka,Berezayka,Березайка', 57.9883300, 33.9036100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121679, 'Berezanskaya', 'Berezanskaya', 'Berezanskaja,Berezanskaya,Березанская', 45.7056200, 39.5932400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121680, 'Berëza', 'Bereza', 'Bereza,Berjoza,Berëza,Береза,Берёза', 53.5183300, 50.1396700, 'RU', '2016-10-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121681, 'Bereslavka', 'Bereslavka', 'Bereslavka,Bereslavskiy,Береславка', 48.6254100, 44.0449100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121682, 'Berendeyevo', 'Berendeyevo', 'Berendeevo,Berendeyevo,Berendyeevo,Берендеево', 56.6007800, 39.0217300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121683, 'Berdyaush', 'Berdyaush', 'Berdjausch,Berdjaush,Berdyaush,Бердяуш', 55.1619000, 59.1464000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121684, 'Benoy-Yurt', 'Benoy-Yurt', 'Bena-Jurt,Bena-Yurt,Beno-Jurt,Beno-Yurt,Benoj-Jurt,Benoy-Yurt,Ozernoe,Ozernoye,Ozjornoe,Ozërnoe,Ozërnoye,Бена-Юрт,Бено-Юрт,Беной-Юрт,Озёрное', 43.6930500, 45.0502500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121685, 'Belyy Gorodok', 'Belyy Gorodok', 'Belyj Gorodok,Belyj-Gorodok,Belyy Gorodok,Gorodok,Белый Городок,Белый-Городок', 56.9650000, 37.5125000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121686, 'Belyye Stolby', 'Belyye Stolby', 'Belye Stolby,Belyye Stolby,Белые Столбы', 55.3313600, 37.8540000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121687, 'Belyye Berega', 'Belyye Berega', 'Belye Berega,Belyye Berega,Белые Берега', 53.2085100, 34.6640500, 'RU', '2014-09-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121688, 'Belyy', 'Belyy', 'Beloi,Bely,Belyj,Belyy,Byeloi,Белый', 55.8402000, 32.9419000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121689, 'Belyayevka', 'Belyayevka', 'Beljaevka,Belyayevka,Belyayevskiy,Беляевка', 51.3974200, 56.4166700, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121690, 'Belozërsk', 'Belozersk', 'Belosersk,Belozersk,Belozersko,Belozjorsk,Belozërsk,bellojeleuseukeu,Белозерск,Белозёрск,Белозјорск,벨로제르스크', 60.0288000, 37.8084000, 'RU', '2014-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121691, 'Beloye', 'Beloye', 'Beloe,Beloje,Beloye,Beloyy,Белое', 45.0483200, 39.6514300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121692, 'Belousovo', 'Belousovo', 'Belousovo,Белоусово', 55.0949900, 36.6732000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121693, 'Beloretsk', 'Beloretsk', 'BCX,Belorec''k,Beloreck,Beloreckas,Beloret,Beloretk,Beloretsk,Beloretskiy Zavod,Belorezk,Belorețk,Bielorieck,Biełorieck,Bjelorjeck,Gorad Belarehck,bellolecheukeu,bie luo lie ci ke,blwrtsk,bylwrtsk,bylwrytsk,Белорет,Белорецк,Белорецк балһсн,Бєлорєцьк,Горад Беларэцк,بلورتسک,بيلوريتسك,بیلورتسک,بیلوریتسک,別洛列茨克,벨로레츠크', 53.9630600, 58.3980600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121694, 'Ilaskhan-Yurt', 'Ilaskhan-Yurt', 'Belorec''e,Belorecenskoe,Belorech''e,Belorech''ye,Belorechenskoe,Belorech’ye,Beloreçenskoe,Beloreč’e,Ehliskhan-Jurt,Eliskhan-Yurt,Elisxan-Yurt,Ilashan-Jurt,Ilaskhan-Jurt,Ilaskhan-Yurt,Ilasxan-Yurt,Iliskhan-Jurt,Ilisxan-Yurt,Белореченское,Белоречье,Иласхан-Юрт,Илисхан-Юрт,Элисхан-Юрт', 43.2791000, 46.1022900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121695, 'Belorechensk', 'Belorechensk', 'Belorechensk,Biserskiy,Bisertskiy,Белореченск', 58.7725100, 52.2935700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121696, 'Belorechensk', 'Belorechensk', 'Belorecensk,Belorecenskas,Belorechens''k,Belorechensk,Belorechenskaya,Beloretchensk,Beloretschensk,Beloretschenskaja,Beloretsjensk,Beloretxensk,Beloreçensk,Beloreĉensk,Belorečensk,Belorečenskas,Beloréchensk,Belorétxensk,Bieloriecziensk,Biełorieczieńsk,Gorad Belarehchansk,bie luo lie qin si ke,blwrchnsk  krasnwdar,bylwrychynsk,bylwrytshynsk,Белореченск,Бєлорєченськ,Горад Беларэчанск,بلورچنسک، کراسنودار,بيلوريتشينسك,بیلوریچینسک,別洛列琴斯克', 44.7712700, 39.8787900, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121697, 'Beloozërskiy', 'Beloozerskiy', 'Beloozerskij,Beloozerskiy,Beloozjorskij,Beloozërskiy,Белоозерский,Белоозёрский', 55.4597800, 38.4435800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121698, 'Beloostrov', 'Beloostrov', 'Beloostrov,Novyy Krasnoostrov,Valkeasaari,Valkiesuari,Valkiešuari,Белоостров', 60.1511800, 30.0015100, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121699, 'Beloomut', 'Beloomut', 'Beloomut,Beloomutovo,Nizhniy Beloomut,Verkhniy Beloomut,Белоомут', 54.9447800, 39.3394100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121700, 'Belomorsk', 'Belomorsk', 'Belomors''k,Belomorsk,Belomorskas,Belomorsku,Bielomorsk,Biełomorsk,Bjelomorsk,Byelomorsk,Gorad Belamorsk,Solunin,Soroka,Sorokhan,Soroki,Sorokka,Suomua,bai hai cheng,bellomoleuseukeu,beromorusuku,blwmwrsk,bylwmwrsk,Šuomua,Беломорск,Бєломорськ,Горад Беламорск,بلومورسک,بيلومورسك,بیلومورسک,ベロモルスク,白海城,벨로모르스크', 64.5232200, 34.7668000, 'RU', '2017-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121701, 'Balakhi', 'Balakhi', 'Balakhi,Belokhi,Бaлaхи', 56.5737000, 28.7035000, 'RU', '2017-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121702, 'Belogor’ye', 'Belogor''ye', 'Belogor''e,Belogor''ye,Belogorje,Belogor’ye,Byelogore,Белогорье', 50.4904000, 40.0095000, 'RU', '2015-09-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121703, 'Belinskiy', 'Belinskiy', 'Belinskij,Belinskiy,Chembar,Белинский', 52.9647400, 43.4164700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121704, 'Belgorod', 'Belgorod', 'Belgorod,Belgorod shaary,Belgoroda,Belgorodas,Belgorodo,Belnkoront,Belqorod,Bielgorod,Bielogroda,Biełgorod,Bilhorod-Dnistrovskyi,Bjelgorod,Bélgorod,Bělgorod,EGO,Gorad Belgarad,belgolodeu,belgoroda,berugorodo,bie er ge luo de,blgwrwd,bylghwrwd,Μπέλγκοροντ,Белгород,Белгород балһсн,Белгород шаары,Бєлгород,Горад Белгарад,Բելգորոդ,בלגורוד,بلگورود,بيلغورود,بیلگوروڈ,बेल्गोरोद,ベルゴロド,别尔哥罗德,벨고로드', 50.6107400, 36.5801500, 'RU', '2012-11-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121705, 'Belgatoy', 'Belgatoy', 'Belgatay,Belgatoj,Belgatoy,Belgazoi,Kurgannoe,Kurgannoye,Белгатой,Курганное', 43.1899500, 45.8308200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121706, 'Belëv', 'Belev', 'Belev,Beljov,Belve,Belëv,Белёв', 53.8119400, 36.1319400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121707, 'Belebey', 'Belebey', 'Belebei,Belebej,Belebey,Belebeï,Belebéi,Bielebiej,Gorad Beljabej,Pelepej,bie lie bie yi,blby,bylyby,bylybyy,Белебей,Белебеј,Бәләбәй,Горад Белябей,Пелепей,بلبی,بيليبي,بیلیبیئ,別列別伊', 54.1166700, 54.1166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121708, 'Belaya Rechka', 'Belaya Rechka', 'Belaja Rechka,Belaja Retsjka,Belaya Rechka,Белая Речка', 56.2849100, 39.4066500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121709, 'Belaya Rechka', 'Belaya Rechka', 'Belaja Rechka,Belaja Retsjka,Belaya Rechka,Белая Речка', 43.4380600, 43.5350000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121710, 'Belaya Kholunitsa', 'Belaya Kholunitsa', 'Belaia Kholounitsa,Belaja Cholunica,Belaja Choluniza,Belaja Holunica,Belaja Holunitsa,Belaja Holunyica,Belaja Kholunica,Belaja Kholunitsa,Belaja Ĥolunica,Belaya Kholunitsa,Belaya Xolunitsa,Belaïa Kholounitsa,Belokholunitskiy,Belokholunitskiy Zavod,Belokolunitskiy,Bielaja Cholunica,Biełaja Chołunica,Bila Kholunicja,Bjelaja Cholunica,Byelokhohmitski Zavod,Gorad Belaja Khalunica,Osh Kholunice,bai huo lu ni cha,bellayahollunicha,blaya khwlwnytsa,bylaya khwlwnytsa,Белая Холуница,Белаја Холуница,Біла Холуниця,Горад Белая Халуніца,Ош Холунице,Բելայա Խոլունիցա,بلایا خولونیتسا,بيلايا خولونيتسا,白霍盧尼察,벨라야홀루니차', 58.8400000, 50.8527800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121711, 'Belaya Kalitva', 'Belaya Kalitva', 'Belaia Kalitva,Belaja Kalitva,Belaja Kalitwa,Belaja-Kalitva,Belaya Kalitva,Belaïa Kalitva,Belokalitvenskaya,Bielaja Kalitwa,Biełaja Kalitwa,Bila Kalitva,Bjelaja Kalitwa,Byelaya Kalitva,Bélaya Kalitvá,Gorad Belaja Kalitva,Ust''-Belokalitvenskaya,Ust’-Belokalitvenskaya,bai ka li te wa,bellayakalliteuba,blaya kalytfa,bylaya kalytfa,Белая Калитва,Белая Калитва балһсн,Белая-Калитва,Белаја Калитва,Біла Калитва,Горад Белая Калітва,Բելայա Կալիտվա,بلایا کالیتفا,بيلايا كاليتفا,白卡利特瓦,벨라야칼리트바', 48.1858500, 40.7742400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121712, 'Belaya Glina', 'Belaya Glina', 'Belaja Glina,Belaya Glina,Glina,Белая Глина', 46.0780200, 40.8665100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121713, 'Belaya', 'Belaya', 'Belaja,Belaya,Beloye,Белая', 51.0544400, 35.7161100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121714, 'Bekovo', 'Bekovo', 'Bekovo,Беково,Բեկովո', 52.4663200, 43.7119900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121715, 'Bekhteyevka', 'Bekhteyevka', 'Bekhteevka,Bekhtejevka,Bekhteyevka,Бехтеевка', 50.8072100, 37.2085300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121716, 'Bekeshevskaya', 'Bekeshevskaya', 'Bekeshevskaja,Bekeshevskaya,Bekesjevskaja,Бекешевская', 44.1138900, 42.4269400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121717, 'Begunitsy', 'Begunitsy', 'Begunicy,Begunitsy,Бегуницы', 59.5855200, 29.3175700, 'RU', '2016-08-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121718, 'Begichevskiy', 'Begichevskiy', 'Begichevskij,Begichevskiy,Begitsjevskij,Бегичевский', 53.7960500, 38.2549800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121719, 'Spassk', 'Spassk', 'Bednodem''janovsk,Bednodem''yanovsk,Bednodem''yanovskiy,Bednodem’yanovsk,Bednodem’yanovskiy,Bogdanovo,Spassk,Беднодемьяновск,Спасск', 53.9255900, 43.1839400, 'RU', '2016-11-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121720, 'Bedeyeva Polyana', 'Bedeyeva Polyana', 'Bedeeva Poljana,Bedeeva-Poljana,Bedeyeva Polyana,Бедеева Поляна,Бедеева-Поляна', 55.3234500, 56.3888200, 'RU', '2016-08-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121721, 'Bazarnyy Syzgan', 'Bazarnyy Syzgan', 'Bazarny Syzgan,Bazarnyj Syzgan,Bazarnyy Syzgan,Базарный Сызган', 53.7511700, 46.7535400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121722, 'Bazarnyy Karabulak', 'Bazarnyy Karabulak', 'Bazarny Karabulak,Bazarnyj Karabulak,Bazarnyy Karabulak,Базарный Карабулак', 52.2683300, 46.4144400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121723, 'Bazarnyye Mataki', 'Bazarnyye Mataki', 'Bazarnye Mataki,Bazarnyye Mataki,Bazarnyye Matani,Базарные Матаки', 54.8833300, 49.9333300, 'RU', '2014-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121724, 'Baymak', 'Baymak', 'Bajmak,Baymak,Baymak-Tanalykovo,Баймак', 52.5933300, 58.3225000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121725, 'Bavtugay', 'Bavtugay', 'Bartugay,Bavtugaj,Bavtugay,Бавтугай', 43.1680800, 46.8341500, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121726, 'Bavly', 'Bavly', 'Bavly,Бавлы', 54.3930400, 53.2602300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121727, 'Bavleny', 'Bavleny', 'Bavieni,Bavleny,Бавлены', 56.3944800, 39.5650400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121728, 'Batyrevo', 'Batyrevo', 'Batyrevo,Batyrjovo,Batyrëvo,Bol''shoye Batyrevo,Bol’shoye Batyrevo,Батырево,Батырёво', 55.0675000, 47.6111100, 'RU', '2014-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121729, 'Baturinskaya', 'Baturinskaya', 'Baturinskaja,Baturinskaya,Батуринская', 45.7926700, 39.3706500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121730, 'Batetskiy', 'Batetskiy', 'Bateckij,Batetskij,Batetskiy,Батетский,Батецкий', 58.6461000, 30.3026800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121731, 'Botayurt', 'Botayurt', 'Batajurt,Batayurt,Botajurt,Botayurt,Ботаюрт', 43.3186500, 46.6837100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121732, 'Bataysk', 'Bataysk', 'Batajsk,Bataysk,Gorodovikovsk,Батайск', 47.1397500, 39.7518100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121733, 'Botashyurt', 'Botashyurt', 'Batashyurt,Botash-Jurt,Botashjurt,Botashyurt,Боташ-Юрт,Боташюрт', 43.3080100, 46.5099100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121734, 'Bashmakovo', 'Bashmakovo', 'Bashmakovo,Башмаково', 53.2132900, 43.0342000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121735, 'Barysh', 'Barysh', 'Baris,Barish,Barix,Bariŝ,Barych,Barys,Barysas,Barysch,Barysh,Barysh osh,Barysj,Baryš,Baryšas,Barış,Gorad Barysh,ba lei shen,balisi,barysh,Бариш,Барыш,Барыш ош,Горад Барыш,باريش,باریش,巴雷什,바리시', 53.6553300, 47.1122900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121736, 'Barybino', 'Barybino', 'Barybino,Boribino,Барыбино', 55.2676800, 37.8933300, 'RU', '2015-01-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121737, 'Baryatino', 'Baryatino', 'Bariatino,Barjatino,Baryatino,Baryatinskaya,Baryatinskoye,Барятино', 54.3120600, 34.5209600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121738, 'Barvikha', 'Barvikha', 'Barvikha,Барвиха', 55.7421200, 37.2792600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121739, 'Barsukovskaya', 'Barsukovskaya', 'Barsukovskaja,Barsukovskaya,Барсуковская', 44.7632000, 41.8191000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121740, 'Barsuki', 'Barsuki', 'Barsuki,Барсуки', 54.2654800, 37.4874600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121741, 'Barda', 'Barda', 'Barda,Барда', 56.9287000, 55.5962000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121742, 'Barashevo', 'Barashevo', 'Barashevo,Barasjevo,Барашево', 54.5325000, 42.8791700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121743, 'Baranchinskiy', 'Baranchinskiy', 'Baranchinskij,Baranchinskiy,Баранчинский', 58.1617000, 59.6991000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121744, 'Bammatyurt', 'Bammatyurt', 'Bamat-Yurt,Bammat-Jurt,Bammatjurt,Bammatyurt,Баммат-Юрт,Бамматюрт', 43.3431500, 46.6085300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121745, 'Baltay', 'Baltay', 'Baltaj,Baltay,Boltayevskaya,Балтай', 52.4652500, 46.6308100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121746, 'Baltasi', 'Baltasi', 'Baltasi,Балтаси', 56.3462000, 50.2062000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121747, 'Balezino', 'Balezino', 'Balesino,Balezino,balyzynw,Балезино,Балезіно,Բալեզինո,باليزينو', 57.9787000, 53.0138000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121748, 'Balashov', 'Balashov', 'Balachov,Balaschow,Balashov,Balashovo,Balasjov,Balasov,Balasovas,Balaszow,Balaŝov,Balaşov,Balašov,Balašovas,Bałaszow,Gorad Balashou,ba la shao fu,balashwf,Балашов,Горад Балашоў,بالاشوف,巴拉紹夫', 51.5502000, 43.1667000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121749, 'Balashikha', 'Balashikha', 'Balachikha,Balaschicha,Balashikha,Balashikhae,Balashikhe,Balasicha,Balasiha,Balasihha,Balasixa,Balasjicha,Balasjikha,Balaszycha,Balaŝiĥa,Balaşiha,Balaşixa,Balašicha,Balašiha,Balašihha,Balașiha,Balishikha,Bałaszycha,Gorad Balashykha,ba la xi ha,balashyka,balashykha,ballasiha,barashiha,Балашихæ,Балашиха,Балашихе,Горад Балашыха,بالاشيكا,بالاشیخا,バラシハ,巴拉希哈,발라시하', 55.8094500, 37.9580600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121750, 'Balasheyka', 'Balasheyka', 'Balashejka,Balasheyka,Balasjejka,Балашейка', 53.2841000, 48.0851000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121751, 'Balakovo', 'Balakovo', 'BWO,Balakova,Balakovas,Balakovo,Balakowo,Bałakowo,Gorad Balakova,ba la ke wo,balakwfw,balakww,ballakobo,Балаково,Балаково балһсн,Горад Балакова,بالاكوفو,بالاکوفو,بالاکوو,巴拉科沃,발라코보', 52.0278200, 47.8007000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121752, 'Balakirevo', 'Balakirevo', 'Balakirevo,Parakirevo,Yasnaya Polyana,Балакирево', 56.5058800, 38.8432400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121753, 'Balakhonovskoye', 'Balakhonovskoye', 'Balakhonovskoe,Balakhonovskoje,Balakhonovskoye,Bogoslavskaya,Bogoslovskoye,Балахоновское', 44.7767000, 41.7842000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121754, 'Novaya Balakhna', 'Novaya Balakhna', 'Balachna,Balahna,Balakhna,Balaĥna,Novaya Balakhna,ballaheuna,Балахна,발라흐나', 56.4898900, 43.6011400, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121755, 'Balabanovo', 'Balabanovo', 'Balabanova,Balabanovo,Balabanowo,Balobanovo,Bałabanowo,ba la ba nuo wo,Балабаново,巴拉巴諾沃', 55.1816100, 36.6606000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121756, 'Baksheyevo', 'Baksheyevo', 'Badsheyevo,Baksheevo,Baksheyevo,Бакшеево', 55.7086000, 39.8766600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121757, 'Baksanenok', 'Baksanenok', 'Baksanenok,Kasayevo,Баксаненок', 43.6897200, 43.6547200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121758, 'Baksan', 'Baksan', 'Baksan,Baksanas,Baksanskie,Bakssan,Baskhan,Behkhusehn,Gorad Baksan,ba ke sang,bagsan,baksan,Баксан,Баксан балһсн,Басхан,Бэхъсэн,Горад Баксан,باكسان,باکسان,巴克桑,박산', 43.6880600, 43.5369400, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121759, 'Bakaly', 'Bakaly', 'Bakaly,Бакалы', 55.1788900, 53.8027800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121760, 'Bakal', 'Bakal', 'Bakal,Bakalas,Gorad Bakal,ba ka er,bakal,Бакал,Горад Бакал,باكال,باکال,巴卡爾,바칼', 54.9417000, 58.8083000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121761, 'Bagrationovsk', 'Bagrationovsk', 'Bagratinovsk,Bagrationivs''k,Bagrationovsk,Bagrationovska,Bagrationovskas,Bagrationowsk,Bagratyionovszk,Baqrationovsk,Eylau,Gorad Bagracijonausk,Preussisch Eylau,Preussisch-Eylau,Preußisch Eylau,Preysish Aylau,Preyss Aylau,Preyss-Eylau,Prusu Ylava,Prūsų Ylava,Stadt Preussisch Eylau,Stadt Preußisch Eylau,Ylava,ba ge la ji ao nuo fu si ke,bageulationobseukeu,baghrashynwfsk,bagrationovsk,bagratywnwwsk,bagratyywnwfsk,bagurationofusuku,Багратионовск,Багратіонівськ,Горад Баграціёнаўск,باغراشينوفسك,باگراتیئونوفسک,باگراتیونووسک,バグラティオノフスク,巴格拉季奧諾夫斯克,바그라티오놉스크', 54.3871400, 20.6437200, 'RU', '2016-03-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121762, 'Bagramovo', 'Bagramovo', 'Bagramovo,Баграмово', 54.7233700, 39.4518600, 'RU', '2014-10-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121763, 'Bagayevskaya', 'Bagayevskaya', 'Bagaevskaja,Bagajevskaja,Bagajewskaja,Bagayevskaya,Bagayevskiy,Багаевская', 47.3241100, 40.3879100, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121764, 'Bachi-Yurt', 'Bachi-Yurt', 'BIachin-Jurt,B`acin-Yurt,Bachi-Jurt,Bachi-Yurt,Baci-Jurt,Batsji-Jurt,Bači-Jurt,Bwacin-Yurt,Bwaçin-Yurt,B‘açin-Yurt,Krasnoarmejskoe,Krasnoarmeyskoe,Krasnoarmeyskoye,Pervomajskoe,Pervomaysk,Pervomayskoe,Pervomayskoye,БІачин-Юрт,Бачи-Юрт,Красноармейское,Первомайское', 43.2241700, 46.1942300, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121765, 'Babynino', 'Babynino', 'Babinino,Babynino,Poselok Babynino,Posëlok Babynino,Бабынино', 54.3938500, 35.7701300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121766, 'Babushkin', 'Babushkin', 'Babushkin,Babusjkin,Losinoostrovskaya,Бабушкин', 55.8693100, 37.7296600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121767, 'Babugent', 'Babugent', 'Babugent,Cherek,Бабугент', 43.2794200, 43.5502000, 'RU', '2012-08-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121768, 'Babino', 'Babino', 'Babino,Бабино', 56.2256400, 43.6238000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121769, 'Babayurt', 'Babayurt', 'Babajurt,Babayurt,Бабаюрт', 43.6002000, 46.7788800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121770, 'Babayevo', 'Babayevo', 'Babaevo,Babajewo,Babayevo,Бабаево', 59.3936000, 35.9371000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121771, 'Azovskaya', 'Azovskaya', 'Azovskaja,Azovskaya,Азовская', 44.7908300, 38.6263900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121772, 'Azov', 'Azov', 'Asoff,Asovia,Asow,Azak,Azov,Azov - Azov,Azov - Азов,Azova,Azovas,Azow,Gorad Azou,ajopeu,azofu,azwf,ya su,Азак,Азов,Азов балһсн,Горад Азоў,Ազով,אזוב,آزوف,ازوف,アゾフ,亞速,아조프', 47.1077900, 39.4164800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121773, 'Ayutinskiy', 'Ayutinskiy', 'Ajutinskij,Aytinskiy,Ayutinskiy,Vlasovo-Ayuta,Аютинский', 47.7822800, 40.1476300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121774, 'Aysha', 'Aysha', 'Ajsha,Ajsja,Aysha,Айша', 55.8703500, 48.6318700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121775, 'Aykino', 'Aykino', 'Ajkino,Aykino,Айкино', 62.2248100, 49.9922200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121776, 'Avtury', 'Avtury', 'Avtara,Avturi,Avtury,Ehvtara,Evtara,Novosadovoe,Novosadovoye,Əvtara,Автуры,Новосадовое,Эвтара', 43.1635400, 46.0012000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121777, 'Avtovo', 'Avtovo', 'Autuansaari,Avtoro,Avtovo,Avtovon metroasema,Awtowo,Derevnya Aftova,Estacao Avtovo,Estação Avtovo,Sosnovka,Stancyja metro Autava,Автово,Станцыя метро Аўтава,Ավտովո', 59.8716700, 30.2658300, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121778, 'Avsyunino', 'Avsyunino', 'Avsiunino,Avsjunino,Avsyunino,Авсюнино', 55.5651600, 39.1232400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121779, 'Avdon', 'Avdon', 'Avdon,Авдон', 54.6666700, 55.7166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121780, 'Aushiger', 'Aushiger', 'Aushiger,Ausjiger,Аушигер', 43.3961100, 43.7316700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121781, 'Atyashevo', 'Atyashevo', 'Atjashevo,Atyashevo,Batushevo,Атяшево,Батушево', 54.5644300, 46.0690500, 'RU', '2014-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121782, 'Atkarsk', 'Atkarsk', 'Atarsk,Atkar,Atkars''k,Atkarsk,Atkarska,Atkarskas,Gorad Atkarsk,a te ka er si ke,askaleuseukeu,atkarsk,Аткар,Аткарск,Аткарск балһсн,Аткарськ,Горад Аткарск,آتکارسک,أتكارسك,اتکارسک,阿特卡爾斯克,앗카르스크', 51.8718500, 45.0077500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121783, 'Atig', 'Atig', 'Atig,Атиг', 56.6930700, 59.4227100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121784, 'Ateptsevo', 'Ateptsevo', 'Ageptsevo,Atepcevo,Ateptsevo,Ateptsovo,Атепцево', 55.3236400, 36.7500200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121785, 'Atemar', 'Atemar', 'Atemar,Атемар', 54.1809700, 45.4090900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121786, 'Atamanskaya', 'Atamanskaya', 'Atamanskaja,Atamanskaya,Атаманская', 46.1773000, 39.6358000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121787, 'Astrakhan', 'Astrakhan', 'ASF,Actarkhan,Ashhtehrkhuan,Ashttarkhan,Astarkhaan,Astiraxan,Astraca,Astracan,Astrachan,Astrachan'',Astrachane,Astrachanum,Astrachanė,Astrachań,Astrachaň,Astrachán,Astracán,Astracã,Astrahan,Astrahana,Astrahano,Astrahaņa,Astrakan,Astrakhan,Astrakhan'',Astrakán,Astraxan,Astraxon,Astraĥano,Asztrahan,Asztrahán,Gorad Astrakhan'',Həstərxan,Həştərxan,a si te la han,aseuteulahan,astrakhan,astrakhana,astʼrakhani,asutorahan,Àstrakhan,Əsterkhan,ʼstrhn,Άστραχαν,Аçтăрхан,Астархаан,Астрахан,Астрахань,Ашттархан,Ащтэрхъан,Горад Астрахань,Әстерхан,Әәдрхн балһсн,Աստրախան,אסטרחן,آستراخان,أستراخان,استراخان,आस्त्राख़ान,आस्त्राखान,အကစထရာကနမြ,အက်စထရာကန်မြို့,ასტრახანი,アストラハン,阿斯特拉罕,아스트라한', 46.3496800, 48.0407600, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121788, 'Assinovskaya', 'Assinovskaya', 'A''khkinchu-Borze,Akh-Borze,Assinovskaja,Assinovskaya,Assinowskaja,Assinskaya,Ax-Borze,Axkincu-Borze,Ehkha-Borze,Exa-Borze,Äxkinçu-Borze,Ассиновская,Ах-Борзе,Аьхкинчу-Борзе,Эха-Борзе', 43.2416700, 45.1819400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121789, 'Askino', 'Askino', 'Askin,Askino,Аскино', 56.0901300, 56.5783100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121790, 'Ashukino', 'Ashukino', 'Ashchukino,Ashukino,Ashukinskiy,Ашукино', 56.1666700, 37.9500000, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121791, 'Ashitkovo', 'Ashitkovo', 'Ashitkovo,Asjitkovo,Ашитково', 55.4517300, 38.5951800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121792, 'Ashil’ta', 'Ashil''ta', 'Ashil''ta,Ashil’ta,Asjilta,Ашильта', 42.7704200, 46.7299200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121793, 'Asha', 'Asha', 'Asha,Аша', 54.9973000, 57.2722000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121794, 'Asekeyevo', 'Asekeyevo', 'Asekeevo,Asekejevo,Asekeyevo,Асекеево', 53.5742500, 52.7972400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121795, 'Asanovo', 'Asanovo', 'Asanovo,Асаново', 54.8941800, 55.4908300, 'RU', '2010-06-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121796, 'Arzgir', 'Arzgir', 'Arsgir,Arzgir,Арзгир', 45.3727800, 44.2205600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121797, 'Arzamas', 'Arzamas', 'Arsamas,Arsamassium,Arzamas,Arzamasas,Arzamass,Arzamasz,Gorad Arzamas,a er zha ma si,aleujamaseu,aruzamasu,arzamas,Арзамас,Горад Арзамас,آرزاماس,أرزاماس,ارزاماس,アルザマス,阿爾扎馬斯,아르자마스', 55.3948500, 43.8399200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121798, 'Arti', 'Arti', 'Arti,arty,Арти,Әртә,Արտի,أرتي', 56.4234400, 58.5327600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121799, 'Arsk', 'Arsk', 'Arca,Archa,Ars''k,Arsk,Arça,a er si ke,aleuseukeu,arsk,arusuku,Арск,Арськ,Арча,آرسک,أرسك,ارسک,アルスク,阿爾斯克,아르스크', 56.0915100, 49.8778300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121800, 'Arshan’', 'Arshan''', 'Arshan'',Arshan’,Arsjan,Prigorodnaya Arshan'',Prigorodnaya Arshan’,Sadovyy,Аршань', 46.2732000, 44.2200000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121801, 'Arsen’yevo', 'Arsen''yevo', 'Aren''yevo,Aren’yevo,Arsen''evo,Arsen''yevo,Arsen’yevo,Арсеньево', 53.7389300, 36.6642900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121802, 'Arsaki', 'Arsaki', 'Arsaki,Арсаки', 56.3833300, 38.4833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121803, 'Armavir', 'Armavir', 'Aramir,Armavir,Armavir i Russland,Armavira,Armaviras,Armawir,Gorad Armavir,a er ma wei er,aleumabileu,armafyr,armawyr,armawyr  rws,armawyr  rwsyh,arumavu~iru,Армавир,Армавир балһсн,Армавір,Горад Армавір,آرماویر,آرماویر، روسیه,أرمافير,ارماویر، روس,アルマヴィル,阿爾馬維爾,아르마비르', 44.9892000, 41.1234000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121804, 'Arkul’', 'Arkul''', 'Arkul'',Arkul’,Аркуль', 57.2808500, 50.0440000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121805, 'Arkhonskaya', 'Arkhonskaya', 'Arkhohskaya,Arkhonskaja,Arkhonskaya,Архонская', 43.1100000, 44.5125000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121806, 'Arkhipovka', 'Arkhipovka', 'Arkhipovka,Архиповка', 56.6629200, 41.2543400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121807, 'Arkhipo-Osipovka', 'Arkhipo-Osipovka', 'Arkhipo-Osipovka,Arkhipo-Osipovskaya,Arkhipo-Osipovskoye,Архипо-Осиповка', 44.3719400, 38.5297200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121808, 'Arkhangel’skoye', 'Arkhangel''skoye', 'Arkhan'',Arkhangel''skoe,Arkhangel''skoye,Arkhangelskoje,Arkhangel’skoye,Arkhan’,Архангельское', 55.8548600, 35.3287300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121809, 'Arkhangel’skoye', 'Arkhangel''skoye', 'Arkhangel''skoe,Arkhangel''skoye,Arkhangelskoje,Arkhangel’skoye,Poselok Arkhangel''skoye,Posëlok Arkhangel’skoye,Архангельское', 55.7879100, 37.2998400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121810, 'Arkhangel’sk', 'Arkhangel''sk', 'ARH,Archangel,Archangelsk,Arhankeli,Arkangeli,Arkhangel''sk,Arkhangelsk,Arkhangel’sk,Novo-Kholmogory,Novyye Kholmogory,Архангельск', 64.5401000, 40.5433000, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121811, 'Arkadak', 'Arkadak', 'Arkadag,Arkadak,Arkadakas,Gorad Arkadak,a er ka da ke,aleukadag,arkadak,Аркадаг,Аркадак,Аркадак балһсн,Горад Аркадак,آرکاداک,أركاداك,ارکاداک,阿爾卡達克,아르카닥', 51.9326100, 43.4977900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121812, 'Argun', 'Argun', 'Argoen,Argoun,Argun,Argun i Tsjetsjenia,Argunas,Arguun,Argún,Gorad Argun,Kolkhoznoe,Kolkhoznoye,Kolxoznoe,Orga,Ustar-Gordoy,a er gong,aleugun,arghn,arghuni,argwn,Аргун,Аргун балһсн,Аргъун,Горад Аргун,Колхозное,Орга,آرگون,أرغن,ارگون، چیچن جمہوریہ,არღუნი,阿爾貢,아르군', 43.2971300, 45.8745400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121813, 'Argudan', 'Argudan', 'Argudan,Cherex,Аргудан', 43.4213900, 43.9158300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121814, 'Ardon’', 'Ardon''', 'Ardon,Ardon'',Ardon’,Ардонь', 52.7352400, 32.3085700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121815, 'Ardon', 'Ardon', 'AErydon,Ardon,Ardon i Nord-Ossetia,Ardona,Ardonas,Ardón,Gorad Ardon,a er dong,aleudon,ardwn,ardwn  awstyay shmaly-alanya,arudon,Æрыдон,Ардон,Ардон балһсн,Горад Ардон,Արդոն,آردون، اوستیای شمالی-آلانیا,أردون,اردون، جمہوریہ شمالی اوسیشیا-الانیا,アルドン,阿尔东,아르돈', 43.1772000, 44.2970200, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121816, 'Ardatov', 'Ardatov', 'Ardatov,Ardatovo,Ардатов', 55.2420500, 43.0969900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121817, 'Ardatov', 'Ardatov', 'Ardan,Ardatov,Ardatov i Mordovia,Ardatovas,Ardatow,Ardátov,Gorad Ardatau,a er da tuo fu,aleudatopeu,ardatwf,ardatwf  mwrdwwya,Ăрдан,Ардатов,Ардатов балһсн,Горад Ардатаў,آرداتوف، موردوویا,أرداتوف,ارداتوف,阿爾達托夫,아르다토프', 54.8476700, 46.2387800, 'RU', '2016-07-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121818, 'Arbazh', 'Arbazh', 'Arbazh,Арбаж', 57.6804100, 48.3064700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121819, 'Apsheronsk', 'Apsheronsk', 'Apcheronsk,Apscheranskaja,Apscheronsk,Apscheronskij,Apseronsk,Apseronskas,Apsheron,Apsherons''k,Apsheronsk,Apsheronskaya,Apsheronskiy,Apsjeronsk,Apszeronsk,Apszerońsk,Apxeronsk,Apŝeronsk,Apšeronsk,Apšeronskas,Gorad Apsharonsk,a pu xie lun si ke,abshrwnsk,abshyrwnsk,absyelonseukeu,apshyrwnsk,Апшеронск,Апшеронск балһсн,Апшеронськ,Горад Апшаронск,آبشرونسک,أبشيرونسك,اپشیرونسک,阿普歇倫斯克,압셰론스크', 44.4647200, 39.7341700, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121820, 'Aprelevka', 'Aprelevka', 'Aprelevka,Aprelewka,Aprielewka,Aprjelewka,Aprélevka,Gorad Aprehleuka,a pu lei lie fu ka,abrylyfka,apeulellebka,aprlfka,aprylfka,aprylywka,apurerefuka,Апрелевка,Апрелевка балһсн,Апрелєвка,Апрељевка,Горад Апрэлеўка,آپرلفکا,أبريليفكا,اپریلفکا,اپریلیوکا,アプレレフカ,阿普雷列夫卡,아프렐렙카', 55.5519400, 37.0801000, 'RU', '2016-07-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121821, 'Apatity', 'Apatity', 'Apatiitti,Apatit,Apatitad,Apatitai,Apatiti,Apatito,Apatity,Apatitî,Apatitõ,Apatitı,Apatyty,Gorad Apatyty,KVK,a pa ji te,abatyty,apachito~ui,apatiti,apatyty,Апатити,Апатиты,Горад Апатыты,آپاتیتی,أباتيتي,اپاتیتی,アパチートゥイ,阿帕季特,아파티티', 67.5641400, 33.4031000, 'RU', '2013-06-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121822, 'Apastovo', 'Apastovo', 'Apastovo,Апастово', 55.2029300, 48.5109100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121823, 'Antropovo', 'Antropovo', 'Antropova,Antropovo,Антропово', 58.3987600, 43.0065900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121824, 'Antipovka', 'Antipovka', 'Antipovka,Антиповка', 49.8299400, 45.3121600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121825, 'Ansalta', 'Ansalta', 'Ansalta,Ансалта', 42.6894100, 46.1178200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121826, 'Anopino', 'Anopino', 'Anopenskiy,Anopino,Poselok Anopenskiy,Posëlok Anopenskiy,Анопино', 55.6980900, 40.6670700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121827, 'Annino', 'Annino', 'Annamoisio,Annino,Аннино', 59.7705600, 30.0561100, 'RU', '2017-01-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121828, 'Anna', 'Anna', 'Anna,Анна', 51.4842000, 40.4299000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121829, 'Andzhiyevskiy', 'Andzhiyevskiy', 'Andzhievskij,Andzhiyevskiy,Анджиевский', 44.2388900, 43.0855600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121830, 'Andreyevskoye', 'Andreyevskoye', 'Andreevskoe,Andrejevskoje,Andreyevka,Andreyevskaya,Andreyevskoye,Андреевское', 55.5548700, 37.9256600, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121831, 'Andreyevo', 'Andreyevo', 'Andreevo,Andreyevo,Andreyevskiy,Poselok Andreyevskiy,Posëlok Andreyevskiy,Андреево', 55.9465000, 41.1505000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121832, 'Andreyevka', 'Andreyevka', 'Andreevka,Andrejevka,Andreyevka,Андреевка', 55.9802800, 37.1350000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121833, 'Endirey', 'Endirey', 'Andreyaul,Ehndirej,Endirej,Endirey,Эндирей', 43.1631600, 46.6540100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121834, 'Andreapol’', 'Andreapol''', 'Andreapol'',Andreapol’,Dubno,Андреаполь', 56.6513400, 32.2664000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121835, 'Andi', 'Andi', 'Andi,Анди', 42.7835900, 46.2617100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121836, 'Anastasiyevskaya', 'Anastasiyevskaya', 'Anastasevskaya,Anastasievskaja,Anastasijevskaja,Anastasiyevka,Anastasiyevskaya,Anastassijewskaja,Анастасиевская', 45.2157600, 37.8925800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121837, 'Anastasiyevka', 'Anastasiyevka', 'Anastas''yevka,Anastasievka,Anastasijevka,Anastasiyevka,Anastassjewska,Anastas’yevka,Анастасиевка', 47.5607200, 38.5283700, 'RU', '2010-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121838, 'Anapskaya', 'Anapskaya', 'Anapskaja,Anapskaya,Анапская', 44.8967100, 37.3860000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121839, 'Anapa', 'Anapa', 'AAQ,Anaapa,Anap,Anapa,Anape,Gorad Anapa,a na pa,anaba,anapa,xa na pa,Ανάπα,Анаапа,Анапа,Анапа балһсн,Анапе,Горад Анапа,Անապա,آناپا,أنابا,اناپا,ਅਨਾਪਾ,อะนาปา,ანაპა,アナパ,阿纳帕,아나파', 44.8908400, 37.3239000, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121840, 'Amzya', 'Amzya', 'Amzja,Amzya,Амзя', 56.2346000, 54.3850000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121841, 'Amin’yevo', 'Amin''yevo', 'Amin''evo,Amin''yevo,Aminjevo,Amin’yevo,Аминьево', 55.7000000, 37.4666700, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121842, 'Altukhovo', 'Altukhovo', 'Altukhova,Altukhovo,Алтухово', 52.6755900, 34.3670300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121843, 'Altud', 'Altud', 'Altud,Tambievo,Алтуд', 43.7219400, 43.8658300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121844, 'Alnashi', 'Alnashi', 'Alnashi,Alnasji,Алнаши', 56.1873800, 52.4791900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121845, 'Al’met’yevsk', 'Al''met''yevsk', 'Al''met''evsk,Al''met''yevo,Al''met''yevsk,Almetjevsk,Almetyevsk,Al’met’yevo,Al’met’yevsk,Əlmət,Альметьевск,Әлмәт', 54.9044200, 52.3154000, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121846, 'Almaznyy', 'Almaznyy', 'Almaznyj,Almaznyy,Алмазный', 48.0447600, 40.0450100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121847, 'Alleroy', 'Alleroy', 'Alleroj,Alleroy,Shuragat,Suragat,Şuragat,Аллерой,Шурагат', 43.2171100, 46.2820900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121848, 'Alkhazurovo', 'Alkhazurovo', 'Alhazurovo,Alkhazurovo,Olkhazar-KIotar,Olkhazaran-KIotar,Olxazar-Khotar,Olxazaran-Khotar,Privol''noe,Privol''noye,Privol’noe,Privol’noye,Алхазурово,Олхазар-КІотар,Олхазаран-КІотар,Привольное', 43.0639000, 45.6513400, 'RU', '2014-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121849, 'Alkhan-Yurt', 'Alkhan-Yurt', 'Ajvazovskoe,Alchantschurt,Alhan-Jurt,Alkhan-Jurt,Alkhan-Yurt,Ayvazovo,Ayvazovskoe,Ayvazovskoye,Ermolovskaja,Ermolovskaya,Ialkhan-Jurt,Walxan-Yurt,Іалхан-Юрт,Айвазовское,Алхан-Юрт,Ермоловская', 43.2317900, 45.5722800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121850, 'Alkhan-Kala', 'Alkhan-Kala', 'Alhan-Kala,Alkhan-Kala,Ialkhan-GIala,Mezdugor''e,Mezhdugor''e,Mezhdugor''ye,Mezhdugor’ye,Meždugor’e,Walxan-Gala,Walxan-Ġala,Іалхан-ГІала,Алхан-Кала,Междугорье', 43.2586100, 45.5391700, 'RU', '2014-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121851, 'Ali-Yurt', 'Ali-Yurt', 'Ali-Jurt,Ali-Yurt,Naron,Али-Юрт', 43.1425000, 44.8525000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121852, 'Alikovo', 'Alikovo', 'Alikovo,Ehlek,alykwfw,Аликово,Аліково,Элĕк,Әлек,Ալիկովո,أليكوفو', 55.7382700, 46.7549300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121853, 'Ali-Berdukovskiy', 'Ali-Berdukovskiy', 'Ali-Berdukovskij,Ali-Berdukovskiy,Aliberdukovskaya,Али-Бердуковский', 43.9895200, 41.7421200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121854, 'Aleksin', 'Aleksin', 'Aleksin,Aleksinas,Aleksine,Alexin,Gorad Aleksin,a lie ke xin,alekasina,alksyn,allegsin,alyksn,alyksyn,arekushin,Алексин,Горад Алексін,آلکسین,أليكسين,الیکسن,ਅਲੇਕਸਿਨ,アレクシン,阿列克辛,알렉신', 54.5050300, 37.0674000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121855, 'Alekseyevskoye', 'Alekseyevskoye', 'Alekseevskoe,Alekseyevskoye,Алексеевское', 55.3070600, 50.1135300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121856, 'Alekseyevskaya', 'Alekseyevskaya', 'Alekseevskaja,Alekseevskaya,Alekseyevskaya,Алексеевская', 50.2896000, 42.1845000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121857, 'Alekseyevskaya', 'Alekseyevskaya', 'Alekseevskaja,Aleksejevskaja,Alekseyevskaya,Алексеевская', 45.7716700, 40.1552800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121858, 'Alekseyevka', 'Alekseyevka', 'Alekseevka,Aleksejevka,Alekseyevo,Алексеевка', 55.6300000, 37.8000000, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121859, 'Alekseyevka', 'Alekseyevka', 'Alekseevka,Aleksejevka,Alekseyevka,Алексеевка', 54.8500000, 55.2333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121860, 'Alekseyevka', 'Alekseyevka', 'Alekseevka,Alekseyevka,Алексеевка', 52.3058300, 48.0261100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121861, 'Alekseyevka', 'Alekseyevka', 'Alekseevka,Alekseyevka,Алексеевка', 50.6309000, 38.6903000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121862, 'Aleksandrovskoye', 'Aleksandrovskoye', 'Aleksandrovskoe,Aleksandrovskoje,Aleksandrovskoye,Alexandrowskoje,Alyeksandrovskoe,Александровское', 44.7141700, 43.0008300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121863, 'Aleksandrovskaya', 'Aleksandrovskaya', 'Aleksandrovskaja,Aleksandrovskaya,Aleksandrovskiy,Александровская', 60.0516800, 29.9793500, 'RU', '2016-10-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121864, 'Aleksandrovskaya', 'Aleksandrovskaya', 'Aleksandrovskaja,Aleksandrovskaya,Aleksanskoi,Александровская', 59.7308300, 30.3322200, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121865, 'Aleksandrovskaya', 'Aleksandrovskaya', 'Aleksandrovskaja,Aleksandrovskaya,Александровская', 43.4833300, 43.6500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121866, 'Aleksandrovsk', 'Aleksandrovsk', 'Aleksandrovsk,Aleksandrovsk i Russland,Aleksandrovskas,Aleksandrovskiy,Aleksandrowsk,Alekszandrovszk,Alexandrovsk,Alexandrowsk,Gorad Aljaksandrausk,Lytva,ailaigazaindrovasaka,alksandrwfsk  prm,allegsandeulobseukeu,alygzndrwwsk  pyrm krayy,alyksandrwfysk,ya li shan de luo fu si ke,Александровск,Горад Аляксандраўск,Лытва,أليكساندروفيسك,الکساندروفسک، پرم,الیگزندرووسک، پیرم کرائی,ਐਲੈਗਜ਼ੈਂਡ੍ਰੋਵਸਕ,亞歷山德羅夫斯克,알렉산드롭스크', 59.1581000, 57.5695000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121867, 'Aleksandrov Gay', 'Aleksandrov Gay', 'Aleksandrov Gaj,Aleksandrov Gay,Александров Гай', 50.1470400, 48.5703700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121868, 'Aleksandrov', 'Aleksandrov', 'Aleksandrov,Aleksandrova,Aleksandrovas,Aleksandrovo,Aleksandrow,Aleksàndrov,Aleksándrov,Alexandrov,Alexandrow,Gorad Aljaksandrau,alaigazaindarova,alksandrwf,allegsandeulopeu,alygzndrwf  wladymyr awblast,alyksandrwf,arekusandorofu,ya li shan de luo fu,Александров,Горад Аляксандраў,أليكساندروف,الکساندروف,الیکساندروف,الیگزندروف، ولادیمیر اوبلاست,ਅਲੈਗਜ਼ੈਂਡਰੋਵ,アレクサンドロフ,亞歷山德羅夫,알렉산드로프', 56.3951600, 38.7121600, 'RU', '2016-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121869, 'Aleksandro-Nevskiy', 'Aleksandro-Nevskiy', 'Aleksandro-Nevskaya,Aleksandro-Nevskij,Aleksandro-Nevskiy,Aleksandro-Nevskoye,Александро-Невский', 53.4751000, 40.2095000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121870, 'Aleksandriyskaya', 'Aleksandriyskaya', 'Aleksandrijskaja,Aleksandriyskaya,Александрийская', 44.2272200, 43.3452800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121871, 'Aleksandriya', 'Aleksandriya', 'Aleksandria,Aleksandrija,Aleksandriya,Александрия', 45.0947200, 43.2455600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121872, 'Alatyr’', 'Alatyr''', 'Alatyr,Alatyr'',Alatyr’,Ulatar,Алатырь,Улатăр', 54.8421000, 46.5813000, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121873, 'Alakurtti', 'Alakurtti', 'Alakurti-Tuntsa,Alakurtti,Allakurtti,Алакуртти', 66.9672000, 30.3490500, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121874, 'Alabushevo', 'Alabushevo', 'Alabushevo,Alabusjevo,Алабушево', 56.0166700, 37.1500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121875, 'Ak”yar', '', 'Akjar,Akujar,Ak”yar,Khaibulina,Khaybulino,Khaybullino,Акъяр', 51.8590500, 58.2213600, 'RU', '2010-06-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121876, 'Akusha', 'Akusha', 'Akusha,Akusja,Акуша', 42.2688500, 47.3411400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121877, 'Aktyubinskiy', 'Aktyubinskiy', 'Ak-Tubya,Aktjubinskij,Aktyubinskiy,Актюбинский', 54.8137200, 52.8055900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121878, 'Russkiy Aktash', 'Russkiy Aktash', 'Aktash,Russkij Aktash,Russkiy Aktash,Акташ,Русский Акташ', 55.0384000, 52.1214000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121879, 'Aktanysh', 'Aktanysh', 'Aktanysh,Aktanysj,Актаныш', 55.7215600, 54.0829300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121880, 'Levoberezhnyy', 'Levoberezhnyy', 'Aksin''ino,Aksinino,Aksin’ino,Levoberezhnyj,Levoberezhnyy,Аксиньино,Левобережный', 55.8500000, 37.4833300, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121881, 'Aksay', 'Aksay', 'Aksaj,Aksay,Aksayskaya,Аксай', 47.2583800, 39.8667500, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121882, 'Aksay', 'Aksay', 'Aksaj,Aksay,Novo Aksai,Аксай', 43.3725400, 46.4449700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121883, 'Aksarayskiy', 'Aksarayskiy', 'Aksarajskij,Aksarayskiy,Аксарайский', 46.7924400, 48.0118800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121884, 'Aksakovo', 'Aksakovo', 'Aksakovo,Аксаково', 54.0333300, 54.1500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121885, 'Aknada', 'Aknada', 'Aknada,Aknoda,Ankoda,Акнада', 42.4015500, 46.1722800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121886, 'Staraya Akkermanovka', 'Staraya Akkermanovka', 'Akkerman,Akkermanovka,Akkermanovskiy,Staraja Akkermanovka,Staraya Akkermanovka,Staroakkermanovka,Аккермановка,Старая Аккермановка', 51.2466900, 58.2390800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121887, 'Akhunovo', 'Akhunovo', 'Akhunova,Akhunovo,Ахуново', 54.2079000, 59.6017000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121888, 'Akhtyrskiy', 'Akhtyrskiy', 'Akhtyrskij,Akhtyrskiy,Ахтырский', 44.8546000, 38.3031000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121889, 'Akhty', 'Akhty', 'Achty,Ahto,Ahtõ,Akhceg'',Akhta,Akhtay,Akhti,Akhty,Axti,Sjalo Akhty,a gan ti,akhty,Ахта,Ахти,Ахты,Ахцегь,Сяло Ахты,Ախտի,أختي,阿幹提', 41.4596800, 47.7312300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121890, 'Akhtubinsk', 'Akhtubinsk', 'Achtubinsk,Achtubińsk,Ahtubinsk,Akhtubinsk,Aĥtubinsk,Ахтубинск', 48.2795500, 46.1721700, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121891, 'Akhtanizovskaya', 'Akhtanizovskaya', 'Achtanisowskaja,Akhtanizovskaja,Akhtanizovskaya,Ахтанизовская', 45.3212800, 37.1007100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121892, 'Agvali', 'Agvali', 'Ageali,Agvali,Agvaly,Агвали', 42.5385300, 46.1196700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121893, 'Agryz', 'Agryz', 'AEgerce,Agriz,Agroz,Agrys,Agryz,Agryzas,Agrõz,Gorad Agryz,a ge lei ci,ageuliseu,aghryz,agriza,agryz,aguru~izu,Ägerce,Əgerce,Агриз,Агрыз,Горад Агрыз,Әгерҗе,آگریز,أغريز,اگریز,ਆਗ੍ਰੀਜ਼,アグルィズ,阿格雷兹,아그리스', 56.5203400, 52.9942200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121894, 'Agronom', 'Agronom', 'Agronom,Агроном', 45.1402100, 39.1948400, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121895, 'Agoy', 'Agoy', 'Agoj,Agoy,Aguy,Агой', 44.1466000, 39.0373000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121896, 'Ageyevo', 'Ageyevo', 'Ageevo,Ageyevo,Агеево', 54.1588300, 36.4692700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121897, 'Agapovka', 'Agapovka', 'Agapovka,Agapovo,Agapovskiy,Агаповка', 53.2973000, 59.1348000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121898, 'Agalatovo', 'Agalatovo', 'Agalatova,Agalatovo,Ohalatva,Агалатово', 60.2195000, 30.2738800, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121899, 'Afrikanda', 'Afrikanda', 'Africanda,Afrikanda,Haapalahti,Poselok Afrikanda,Posëlok Afrikanda,Африканда', 67.4428900, 32.7827900, 'RU', '2012-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121900, 'Afonino', 'Afonino', 'Afonino,Афонино', 56.2620100, 44.0950300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121901, 'Afipskiy', 'Afipskiy', 'Afipskij,Afipskiy,Georgiafipskaya,Georgiye-Afipskaya,Афипский', 44.9000500, 38.8426500, 'RU', '2013-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121902, 'Adyge-Khabl’', 'Adyge-Khabl''', 'Adyge-Khabl,Adyge-Khabl'',Adyge-Khabl’,Адыге-Хабль', 44.3343400, 41.9392200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121903, 'Adler', 'Adler', 'Adler,Adlerskij rajon,Adlersky City District,Adlersky rajon,Adlerský rajón,District Adlerski,Distrito de Adler,Distrito de Ádler,a de lie er,Адлер,Адлерский район,阿德列爾', 43.4289600, 39.9239100, 'RU', '2014-07-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121904, 'Adil’-Yangiyurt', 'Adil''-Yangiyurt', 'Adil''-Jangi-Jurt,Adil''-Jangijurt,Adil''-Yangiyurt,Adil’-Yangiyurt,Адиль-Янги-Юрт,Адиль-Янгиюрт', 43.5632800, 46.5846200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121905, 'Adamovka', 'Adamovka', 'Adamovka,Адамовка', 51.5223000, 59.9396000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121906, 'Achkhoy-Martan', 'Achkhoy-Martan', 'Achkhoi-Martan,Achkhoj-Martan,Achkhoy-Martan,Achoj-Martan,Atsjkhoj-Martan,Ačhoj-Martan,Iashkhojn-Marta,Novosel''skoe,Novosel''skoye,Novosel’skoe,Novosel’skoye,TIekh''a-Marta,Thexa-Marta,Theẋa-Marta,Wasxoyn-Marta,Waşxoyn-Marta,Іашхойн-Марта,Ачхой-Мартан,Новосельское,ТІехьа-Марта', 43.1899700, 45.2837300, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121907, 'Achit', 'Achit', 'Achit,Achitskoye,Ачит', 56.7985000, 57.8994000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121908, 'Achisu', 'Achisu', 'Achi,Achisu,Ачи,Ачису', 42.6519700, 47.6828200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121909, 'Achikulak', 'Achikulak', 'Achikulak,Achikulakskoye,Atsjikulak,Ачикулак', 44.5516700, 44.8377800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121910, 'Abzakovo', 'Abzakovo', 'Abzakova,Abzakovo,Абзаково', 53.8286100, 58.5933300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121911, 'Abrau-Dyurso', 'Abrau-Dyurso', 'Abrau-Djurso,Abrau-Dyurso,Абрау-Дюрсо', 44.6997300, 37.6009800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121912, 'Abramovka', 'Abramovka', 'Abramovka,Abramowka,Абрамовка', 51.1886000, 41.0202000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121913, 'Abinsk', 'Abinsk', 'Abins''k,Abinsk,Abinska,Abinskas,Abinskaya,Abinskiy,Abińsk,Gorad Abinsk,a bin si ke,abinseukeu,abisaka,abynsk,Абинск,Абинск балһсн,Абінськ,Горад Абінск,آبینسک,أبينسك,ابینسک,ਅਬਿੰਸਕ,阿宾斯克,아빈스크', 44.8680300, 38.1572800, 'RU', '2013-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121914, 'Abdulino', 'Abdulino', 'Abdoulino,Abdulina,Abdulinas,Abdulino,Abdulla,Abduļina,Abdúlino,Gorad Abdulina,a bo du li nuo,abadulino,abdullino,abdwlynw,abeudullino,Абдулино,Абдулла,Абдуліно,Горад Абдуліна,آبدولینو,أبدولينو,ابدولینو,ਅਬਦੂਲੀਨੋ,阿卜杜利诺,아브둘리노,압둘리노', 53.7000000, 53.6666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121915, 'Abadzekhskaya', 'Abadzekhskaya', 'Abadzekhskaja,Abadzekhskaya,Абадзехская', 44.3938900, 40.2213900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121916, 'Vasil’yevo', 'Vasil''yevo', 'Vasil''evo,Vasil''yevo,Vasilevo,Vasileyevo,Vasiljevo,Vasil’yevo,Васильево', 55.8359500, 48.6582000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121917, 'Ryl’sk', 'Ryl''sk', 'Ryl''sk,Rylsk,Ryl’sk,Рыльск', 51.5655000, 34.6822000, 'RU', '2012-01-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121918, 'Gedzhukh', 'Gedzhukh', 'Gedzhukh,Gedzjukh,Геджух', 42.1278600, 48.0647400, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121919, 'Krasnoyarskaya', 'Krasnoyarskaya', 'Krasnojarskaja,Krasnoyarskaya,Красноярская', 47.4955000, 42.1856000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121920, 'Vidyayevo', 'Vidyayevo', 'Vidjaevo,Vidyayeva,Vidyayevo,Видяево', 69.3191400, 32.8048800, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121921, 'Snezhnogorsk', 'Snezhnogorsk', 'Gorad Snezhnagorsk,Murmansk-60,Olenaya Guba Base,Snejnogorsk,Snejnoqorsk,Sneschnogorsk,Snezhnogors''k,Snezhnogorsk,Snezjnogorsk,Snezjnogorsk i Murmansk oblast,Sneznogorsk,Sneznogorskas,Sneĵnogorsk,Snežnogorsk,Snežnogorskas,Snieznogorsk,Snieżnogorsk,Snjeznogorsk,Snježnogorsk,asnzhnwgwrsk  awblast mwrmansk,si nie ri nuo ge er si ke,snjnwghwrsk,Горад Снежнагорск,Снежногорск,Снєжногорськ,اسنژنوگورسک، اوبلاست مورمانسک,سنجنوغورسك,斯涅日諾戈爾斯克', 69.1933300, 33.2531400, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121922, 'Kokrek', 'Kokrek', 'Kokrek,Кокрек', 43.2363900, 46.7266500, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121923, 'Kontenko', 'Kontenko', 'Kontenko,Контенко', 45.3580600, 36.8322200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121924, 'Vyshestebliyevskaya', 'Vyshestebliyevskaya', 'Vyshesteblievskaja,Vyshestebliyevskaya,Vysjesteblijevskaja,Вышестеблиевская', 45.1961100, 37.0180600, 'RU', '2010-08-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121925, 'Pervomayskoye', 'Pervomayskoye', 'Pervomajskoe,Pervomayskiy,Pervomayskoye,Первомайское', 43.9190400, 46.7101900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121926, 'Vostochny', 'Vostochny', 'Borec,Borets,Vostochnyj,Борец,Восточный', 44.3149400, 44.1963700, 'RU', '2016-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121927, 'Stepnoye', 'Stepnoye', '', 44.2708300, 44.5850000, 'RU', '2006-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121928, 'Kara-Tyube', 'Kara-Tyube', 'Kara-Tjube,Kara-Tyube,Кара-Тюбе', 44.6336100, 45.4369400, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121929, 'Neftekumsk', 'Neftekumsk', 'Gorad Nefcjakumsk,Neftekoemsk,Neftekoumsk,Neftekumsk,Nieftiekumsk,Njeftekumsk,nftkwmsk,nie fu jie ku mu si ke,Горад Нефцякумск,Нефтекумск,Нефтекумск балһсн,نفتكومسك,نفتکومسک,涅夫捷庫姆斯克', 44.7558300, 44.9925000, 'RU', '2012-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121930, 'Imeni Pervogo Maya', 'Imeni Pervogo Maya', 'Imeni Pervogo Maya,Pervoe Maja,Pervoje Maja,Pervoye Maya,Первое Мая', 50.8899700, 39.5919000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121931, 'Rabocheostrovsk', 'Rabocheostrovsk', 'Papinsaari,Papinsuari,Rabocheostrovs''k,Rabocheostrovsk,Rabocʻeostrovsk,Rabotseostrovsk,Rabotšeostrovsk,Vallankumoussaari,Рабочеостровск,Рабочеостровськ,Ռաբոչեոստրովսկ', 64.9854700, 34.7661100, 'RU', '2015-12-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121932, 'Lutkun', 'Lutkun', 'Lutkun,Луткун', 41.4808400, 47.6857800, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121933, 'Druzhba', 'Druzhba', 'Druzhba,Дружба', 42.2410800, 47.9979800, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121934, 'Gerga', 'Gerga', 'Gerga,Герга', 42.3464500, 47.9633300, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121935, 'Imeni Chkalova', 'Imeni Chkalova', 'Chkalova,Chkalovskij,Чкаловский', 47.2813900, 39.7488900, 'RU', '2009-12-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121936, 'Alagir', 'Alagir', 'Alagir,Alagiras,Alaguir,Ałagir,Gorad Alagir,a la ji er,alaghyr,alagir,alagira,alagyr,allagileu,Алагир,Алагир балһсн,Горад Алагір,Ալագիր,آلاگیر,ألاغير,الاگیر,ਅਲਾਗਿਰ,阿拉吉尔,알라기르', 43.0422200, 44.2222200, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121937, 'Yuzhnyy', 'Yuzhnyy', '', 45.0025000, 40.4747200, 'RU', '2006-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121938, 'Kovalevskoye', 'Kovalevskoye', 'Kovalevskoe,Kovalevskoje,Kovalevskoye,Ковалевское', 45.1941700, 40.9761100, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121939, 'Persianovka', 'Persianovka', 'Persianovka,Persianovskij,Persianovskiy,Персиановка,Персиановский', 47.5297200, 39.4183300, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121940, 'Karamakhi', 'Karamakhi', 'Kara-Makhi,Karamakhi,Кара-Махи,Карамахи', 42.6193400, 47.2601700, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121941, 'Alkhan-Churt', 'Alkhan-Churt', 'Alhan-Curt,Alhan-Čurt,Alkhan-Churt,Alkhan-Churtskij,Alkhan-Tsjurt,Alxan-Curtskii,Alxan-Çurtskii,Алхан-Чурт,Алхан-Чуртский', 43.3519400, 44.7869400, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121942, 'Novyy Khushet', 'Novyy Khushet', 'Novyj Khushet,Novyj Khusjet,Novyy Khushet,Новый Хушет', 42.8994100, 47.5604000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121943, 'Khambi-Irze', 'Khambi-Irze', 'Hambi-Irze,Kha''mbin-Irze,Khambi-Irze,Khambi-Irzi,Lermontov-Jurt,Lermontov-Yurt,Xambi-Irzi,Xambin-Irze,Xämbin-Irze,Лермонтов-Юрт,Хамби-Ирзе,Хамби-Ирзи,Хаьмбин-Ирзе', 43.2350200, 45.4530200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121944, 'Orël-Izumrud', 'Orel-Izumrud', 'Orel-Izumrud,Orjol-Izumrud,Orël-Izumrud,Орёл-Изумруд', 43.4600500, 39.9237700, 'RU', '2013-01-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121945, 'Vysokoye', 'Vysokoye', 'Nizhne-Vysokoye,Vysokoe,Vysokoye,Высокое', 43.4630400, 39.9670100, 'RU', '2012-12-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121946, 'Sovetskoye', 'Sovetskoye', 'Sovetskoe,Sovetskoye,Советское', 46.7219400, 42.1463900, 'RU', '2013-05-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121947, 'Zavetnyy', 'Zavetnyy', 'Zavetnyj,Zavetnyy,Заветный', 44.9316000, 41.1373000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121948, 'Yasnaya Polyana', 'Yasnaya Polyana', 'Jasnaja Poljana,Yasnaya Polyana,Ясная Поляна', 44.0225000, 42.7539000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121949, 'Borisovka', 'Borisovka', 'Borisovka,Борисовка', 50.6236100, 35.9902800, 'RU', '2010-08-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121950, 'Kurovskoye', 'Kurovskoye', 'Kurovskoe,Kurovskoje,Kurovskoye,Куровское', 54.5429900, 36.0026200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121951, 'Il’inskoye', 'Il''inskoye', 'Il''inskoe,Il''inskoye,Il’inskoye,Ильинское', 55.2491700, 37.9580500, 'RU', '2015-01-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121952, 'Rozhdestvenskiy', 'Rozhdestvenskiy', 'Rozhdestvenskij,Rozhdestvenskiy,Рождественский', 54.2957000, 37.5701900, 'RU', '2017-05-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121953, 'Vorotynsk', 'Vorotynsk', 'Vorotynsk', 54.4282800, 36.0464600, 'RU', '2016-03-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121954, 'Chupryakovo', 'Chupryakovo', 'Chuprjakovo,Chupryakovo,Чупряково', 55.5528200, 36.6272100, 'RU', '2012-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121955, 'Annino', 'Annino', 'Annino,Аннино', 55.5831600, 37.2601900, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121956, 'Razvilka', 'Razvilka', 'Razvilka,Развилка', 55.5920900, 37.7408500, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121957, 'Dubovka', 'Dubovka', 'Dubovka,Дубовка', 53.9522300, 38.0627600, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121958, 'Dagomys', 'Dagomys', 'Dagomys,Дагомыс', 43.6697400, 39.6686300, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121959, 'Gornoye Loo', 'Gornoye Loo', 'Gornoe Loo,Gornoje Loo,Gornoye Loo,Горное Лоо', 43.7129400, 39.6049200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121960, 'Bugry', 'Bugry', 'Bugry,Pukra,Бугры', 60.0712100, 30.3922500, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121961, 'Ferma', 'Ferma', 'Ferma,Ферма', 57.9016000, 56.3064000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121962, 'Gorod Shebekino', 'Gorod Shebekino', 'Gorod Shebekino,Город Шебекино', 50.4166700, 36.9166700, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121963, 'Korkmaskala', 'Korkmaskala', 'Korkmaskala,Коркмаскала', 43.0237900, 47.2943600, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121964, 'Bol''shoe Isakovo', 'Bol''shoe Isakovo', 'Bol''shoe Isakovo,Bol''shoye Isakovo,Bol’shoye Isakovo,Isakovo,Большое Исаково,Исаково', 54.7177400, 20.6028400, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121965, 'Maloye Isakovo', 'Maloye Isakovo', 'Laut,Lauth,Maloe Isakovo,Maloye Isakovo,Лаут,Малое Исаково', 54.7326900, 20.5841300, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121966, 'Otradnoye', 'Otradnoye', 'Otradnoe,Otradnoye,Отрадное', 54.9411400, 20.1139700, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121967, 'Yuzhnyy', 'Yuzhnyy', 'Jesau,Juzhnyj,Juzjnyj,Yuzhnyy,Южный', 54.5483700, 20.5984300, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121968, 'Surok', 'Surok', 'Surok,Сурок', 56.4469400, 48.1213900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121969, 'Partsa', 'Partsa', 'Parca,Partsa,Парца', 54.3653000, 42.8617000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121970, 'Udarnyy', 'Udarnyy', 'Udarnyj,Udarnyy,Ударный', 54.3409000, 42.8611000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121971, 'Lepley', 'Lepley', 'Leplej,Lepley,Леплей', 54.3092000, 42.8599000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121972, 'Pavlovo', 'Pavlovo', 'Gorad Paulava,Pavlovas,Pavlovo,Pavlovo i Nizjegorod oblast,Pawlowo,Pawłowo,Pávlovo,ba fu luo wo,baflwfw,pabeullobo,pawlwf  nyzhny nwwgwrwd,pawlww,Горад Паўлава,Павлово,بافلوفو,پاولوف، نیژنی نووگورود,پاولوو,巴甫洛沃,파블로보', 55.9686000, 43.0912000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121973, 'Atlashevo', 'Atlashevo', 'Atlashevo,Novoje Atlasjevo,Novoye Atlashevo,Атлашево', 56.0123500, 47.5561500, 'RU', '2012-02-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121974, 'Privolzhskiy', 'Privolzhskiy', 'Privolzhskij,Privolzhskiy,Privolzjskij,Приволжский', 55.9613500, 48.4151200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121975, 'Belidzhi', 'Belidzhi', 'Belidzhi,Белиджи', 41.8918400, 48.4124700, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121976, 'Khazar', 'Khazar', 'Khazar,Vos''moy Uchastok Sovkhoza Imeni Karla Marksa,Vos’moy Uchastok Sovkhoza Imeni Karla Marksa,Хазар', 41.9974000, 48.3332500, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121977, 'Zaozërsk', 'Zaozersk', 'Murmansk-150,Zaozersk,Zaozjorsk,Zaozërsk,Заозерск,Заозёрск', 69.4005200, 32.4476100, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121978, 'Pervoye Maya', 'Pervoye Maya', 'Pervoe Maja,Pervomayskiy,Pervoye Maya,Первое Мая', 56.1640300, 44.7195500, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121979, 'Pasha', 'Pasha', 'Pasha,Паша', 60.3954600, 33.0430800, 'RU', '2012-08-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121980, 'Lesnoy', 'Lesnoy', 'Lesnoj,Lesnoy,Nizhnyaya Tura,Sverdlovsk-45,Лесной', 58.6366700, 59.8022200, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121981, 'Kondratovo', 'Kondratovo', 'Kondratovo,Pervomayskiy,Кондратово', 57.9804000, 56.1066000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121982, 'Ileza', 'Ileza', 'Ileza,Илеза', 61.0532800, 43.9002100, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121983, 'Trëkhgornyy', 'Trekhgornyy', 'Trekhgornyy,Trjokhgornyj,Trëkhgornyy,Yuryuzan'',Yuryuzan’,Zlatoust''-26,Zlatoust’-26,Трёхгорный', 54.8150000, 58.4591700, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121984, 'Mirnyy', 'Mirnyy', 'Leningrad-300,Mirnyj,Mirnyy,Мирный', 62.7640900, 40.3374600, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121985, 'Znamensk', 'Znamensk', 'Gorad Znamensk,Kapustin Jar,Kapustin Yar-1,Snamensk,Znamensk,Znamensk i Astrakhan oblast,Znamiensk,Znàmensk,Známensk,ci na mian si ke,jeunamenseukeu,znamnsk  awblast astrakhan,znamynsk,Горад Знаменск,Знаменск,Знаменск балһсн,Капустин Яр,زنامنسک، اوبلاست آستراخان,زنامينسك,兹纳缅斯克,즈나멘스크', 48.5842000, 45.7338000, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121986, 'Svetlyy', 'Svetlyy', 'Svetlyj,Svetlyy,Светлый', 51.6737000, 45.6305400, 'RU', '2013-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121987, 'Zvëzdnyy', 'Zvezdnyy', 'Bershetskiye Dachi,Perm''-76,Perm’-76,Zvezdnyj,Zvezdnyy,Zvëzdnyy,Звездный', 57.7325000, 56.3147200, 'RU', '2011-12-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121988, 'Zarechnyy', 'Zarechnyy', 'Penza-19,Zarechnyj,Zarechnyy,Заречный', 53.1333300, 46.5833300, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121989, 'Ozërnyy', 'Ozernyy', 'Bologoye-4,Ozernyy,Ozjornyj,Ozërnyy,Озёрный', 57.9000000, 33.6500000, 'RU', '2016-05-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121990, 'Dvubratskiy', 'Dvubratskiy', 'Dvubratskij,Dvubratskiy,Двубратский', 45.2388800, 39.8049900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121991, 'Yuzhnyy', 'Yuzhnyy', '', 44.7211100, 39.8791800, 'RU', '2011-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121992, 'Kochubeyevskoye', 'Kochubeyevskoye', 'Kochubeevskoe,Kochubeyevskoye,Kotschubejewskoje,Кочубеевское', 44.6441700, 41.8452800, 'RU', '2011-12-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121993, 'Udarnyy', 'Udarnyy', 'Udarnyj,Udarnyy,Ударный', 44.3491700, 42.5052800, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121994, 'Novoterskiy', 'Novoterskiy', 'Novoterskij,Novoterskiy,Новотерский', 44.1486100, 43.0925000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121995, 'Zmeyka', 'Zmeyka', 'Zmejka,Zmeyka,Змейка', 44.1427800, 43.1208300, 'RU', '2012-08-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121996, 'Svetlopolyansk', 'Svetlopolyansk', 'Svetlopoljansk,Svetlopolyansk,Светлополянск', 59.4183600, 52.3604500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121997, 'Putëvka', 'Putevka', 'Putevka,Putjovka,Putëvka,Путевка,Путёвка', 53.2583300, 34.2877800, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121998, 'Kazachka', 'Kazachka', 'Kazachka,Kazatsjka,Казачка', 53.3644000, 38.0694000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(121999, 'Vnukovo', 'Vnukovo', 'Vnukovo,Внуково', 55.6119400, 37.2961100, 'RU', '2016-04-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122000, 'Moskovskiy', 'Moskovskiy', 'Moskovskij,Moskovskiy,Московский', 55.5991100, 37.3549500, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122001, 'Zhitnevo', 'Zhitnevo', 'Zhitnevo,Zjitnevo,Житнево', 55.3423300, 37.9146400, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122002, 'Zubutli-Miatli', 'Zubutli-Miatli', 'Zabutli-Miatli,Zubutli-Miatli,Зубутли-Миатли', 43.1988600, 46.8124100, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122003, 'Solnechnoye', 'Solnechnoye', 'Batashevskiy,Solnechnoe,Solnechnoye,Solnetsjnoje,Солнечное', 43.2760000, 46.5069700, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122004, 'Shamil’kala', 'Shamil''kala', 'Shamil''kala,Shamil’kala,Шамилькала', 42.6858100, 46.8639300, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122005, 'Novyy Sulak', 'Novyy Sulak', 'Novyj Sulak,Novyy Sulak,Sulak,Новый Сулак,Сулак', 43.2123900, 46.8142600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122006, 'Novyy Kostek', 'Novyy Kostek', 'Novyj Kostek,Novyy Kostek,Новый Костек', 43.3353000, 46.8246600, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122007, 'Usinsk', 'Usinsk', 'Gorad Usinsk,Oesinsk,Oussinsk,USK,Usins''k,Usinsk,Usinska,Uskar,Ussinsk,Uszinszk,awsynsk,wu xin si ke,Горад Усінск,Усинск,Усинск балһсн,Ускар,Усінськ,أوسينسك,اوسینسک,烏辛斯克', 65.9938900, 57.5280600, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122008, 'Krasnyy Kommunar', 'Krasnyy Kommunar', 'Krasnyj Kommunar,Krasnyy Kommunar,Красный Коммунар', 51.9643600, 55.3668000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122009, 'Volovo', 'Volovo', 'Volovo,Волово', 53.5583100, 38.0028500, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122010, 'Mednogorskiy', 'Mednogorskiy', 'Mednogorskij,Mednogorskiy,Медногорский', 43.9178000, 41.1825500, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122011, 'Khankala', 'Khankala', 'Hankala,KhangIala,Khankala,Xangala,Xanġala,ХангІала,Ханкала', 43.3021200, 45.7556400, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122012, 'Pravokubanskiy', 'Pravokubanskiy', 'Pravokubanskij,Pravokubanskiy,Правокубанский', 43.9172100, 41.8841300, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122013, 'Novyye Lapsary', 'Novyye Lapsary', 'Novye Lapsary,Novyye Lapsary,Новые Лапсары', 56.0685000, 47.2142000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122014, 'Raduzhnyy', 'Raduzhnyy', 'Raduzhnyj,Raduzhnyy,Raduzjnyj,Радужный', 59.4833300, 49.6500000, 'RU', '2015-10-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122015, 'Priladozhskiy', 'Priladozhskiy', 'Priladozhskij,Priladozhskiy,Priladozjskij,Приладожский', 59.8500000, 31.4833300, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122016, 'Molochnyy', 'Molochnyy', 'Molochnyj,Molochnyy,Molotsjnyj,Молочный', 68.8538900, 33.0204600, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122017, 'Iskateley', 'Iskateley', 'Iskatelej,Искателей', 67.6802600, 53.1511700, 'RU', '2010-05-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122018, 'Tsibanobalka', 'Tsibanobalka', 'Cibanobalka,Tsibanobalka,Цибанобалка', 44.9803400, 37.3438400, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122019, 'Myskhako', 'Myskhako', 'Myskhako,Мысхако', 44.6713900, 37.7433300, 'RU', '2010-08-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122020, 'Lermontovo', 'Lermontovo', 'Lermontovo,Лермонтово', 44.3038000, 38.7572000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122021, 'Chinar', 'Chinar', 'Chinar,Tsjinar,Чинар', 42.1079800, 48.1432100, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122022, 'Petra-Dubrava', 'Petra-Dubrava', 'Petra-Dubrava,Петра-Дубрава', 53.2961300, 50.3655400, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122023, 'Povolzhskiy', 'Povolzhskiy', 'Povolzhskij,Povolzhskiy,Povolzjskij,Поволжский', 53.5854000, 49.7629000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122024, 'Verkhnebakanskiy', 'Verkhnebakanskiy', 'VERKHNEBAKANSKIJ,Verkhne Bakanskaya,Verkhnebakanskij,Verkhnebakanskiy,Verkhniy Bakanskiy,ВЕРХНЕБАКАНСКИЙ,Верхнебаканский', 44.8491700, 37.6572200, 'RU', '2013-06-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122025, 'Kochubey', 'Kochubey', 'Kochubej,Kochubey,Kotsjubej,Кочубей', 44.3861100, 46.5825000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122026, 'Nezhinskiy', 'Nezhinskiy', 'Nezhinskij,Nezhinskiy,Nezjinskij,Нежинский', 43.9283300, 42.6855600, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122027, 'Tyube', 'Tyube', 'Tjube,Tyube,Тюбе', 43.0492600, 47.3074200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122028, 'Novyy Chirkey', 'Novyy Chirkey', 'Novyj Chirkej,Novyj Tsjirkej,Novyy Chirkey,Новый Чиркей', 43.1620500, 47.0558500, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122029, 'Uchkent', 'Uchkent', 'Uchkent,Utsjkent,Учкент', 43.1142700, 47.0825500, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122030, 'Mursalimkino', 'Mursalimkino', 'Mursalimkino,Мурсалимкино', 55.0379000, 58.5585000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122031, 'Belozërnyy', 'Belozernyy', 'Belozernyj,Belozernyy,Belozjornyj,Belozërnyy,Белозерный,Белозёрный', 45.0643300, 38.6790100, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122032, 'Sovkhoznyy', 'Sovkhoznyy', 'Sovkhoznyj,Sovkhoznyy,Совхозный', 45.2946200, 38.1138400, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122033, 'Raduzhnyy', 'Raduzhnyy', 'Raduzhnyj,Raduzhnyy,Радужный', 55.1368000, 38.7280300, 'RU', '2015-10-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122034, 'Biorki', 'Biorki', 'Biorki,Биорки', 55.0528000, 38.6087300, 'RU', '2015-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122035, 'Pervomayskiy', 'Pervomayskiy', 'Pervomajskij,Pervomayskiy,Первомайский', 55.0669600, 38.6648900, 'RU', '2015-03-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122036, 'Obukhovo', 'Obukhovo', 'Obukhovo,Обухово', 59.8438900, 30.4511100, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122037, 'Galashki', 'Galashki', 'Galashki,Galasjki,Галашки', 43.1174000, 44.9905500, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122038, 'Staryy Malgobek', 'Staryy Malgobek', 'Staryj Malgobek,Staryy Malgobek,Старый Малгобек', 43.5443700, 44.5959200, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122039, 'Sokol', 'Sokol', 'Sokol,Сокол', 57.9146000, 56.0456000, 'RU', '2015-05-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122040, 'Krasnobrodskiy', 'Krasnobrodskiy', 'Krasnobrodskij,Krasnobrodskiy,Krasnyy Brod,Краснобродский', 54.1581000, 86.4486000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122041, 'Zyuzel’skiy', 'Zyuzel''skiy', 'Ziuzelskij,Zjuzel''skij,Zyuzel''skiy,Zyuzel’skiy,Зюзельский', 56.4856000, 60.1331000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122042, 'Zyryanskoye', 'Zyryanskoye', 'Zyrjanskoe,Zyrjanskoje,Zyryanskoye,Зырянское', 56.8305800, 86.6273400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122043, 'Zykovo', 'Zykovo', 'Zykovo,Зыково', 55.9550300, 93.1609300, 'RU', '2013-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122044, 'Zverinogolovskoye', 'Zverinogolovskoye', 'Swerinoglowskaja,Zveringolovskoye,Zverinogolovskiy,Zverinogolovskoe,Zverinogolovskoje,Zverinogolovskoye,Звериноголовское', 54.4539700, 64.8524200, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122045, 'Zudilovo', 'Zudilovo', 'Zudilovo,Зудилово', 53.4927000, 83.8937000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122046, 'Zonal’noye', 'Zonal''noye', 'Zonal''naya,Zonal''noe,Zonal''noye,Zonalnoje,Zonal’naya,Zonal’noye,Зональное', 52.6665000, 84.9331000, 'RU', '2016-04-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122047, 'Znamenskoye', 'Znamenskoye', 'Znamenskoe,Znamenskoje,Znamenskoye,Знаменское', 57.1280600, 73.8282100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122048, 'Zmeinogorsk', 'Zmeinogorsk', 'Gorad Zmjainagorsk,Smeinogorsk,Zmeinogorsk,Zmeïnogorsk,Zmieinogorsk,ci mei yi nuo ge er si ke,zmynwghwrsk,zmynwgwrsk,Горад Змяінагорск,Змеиногорск,زمينوغورسك,زمینوگورسک,兹梅伊诺戈尔斯克', 51.1577600, 82.1953400, 'RU', '2013-12-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122049, 'Zheleznodorozhnyy', 'Zheleznodorozhnyy', 'Zheleznodorozhnyj,Zheleznodorozhnyy,Железнодорожный', 55.1018300, 61.5492600, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122050, 'Zelënyy Bor', 'Zelenyy Bor', 'Zelenyj Bor,Zelenyy Bor,Zelënyy Bor,Зеленый Бор', 53.6217800, 91.6152800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122051, 'Zelenogorskiy', 'Zelenogorskiy', 'Zelenogorskij,Zelenogorskiy,Зеленогорский', 55.0333300, 87.0000000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122052, 'Zelenoborsk', 'Zelenoborsk', 'Konda,Zelenoborsk,Зеленоборск', 61.4708800, 64.0434400, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122053, 'Zdvinsk', 'Zdvinsk', 'Zdvinsk,Здвинск', 54.7020600, 78.6610500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122054, 'Zaykovo', 'Zaykovo', 'Zajkovo,Zaykovo,Зайково', 57.5613000, 62.7568100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122055, 'Zav’yalovo', 'Zav''yalovo', 'Zav''jalovo,Zav''yalovo,Zavjalovo,Zav’yalovo,Завьялово', 52.8380500, 80.9197000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122056, 'Zavodouspenskoye', 'Zavodouspenskoye', 'Zavodouspenskoe,Zavodouspenskoje,Zavodouspenskoye,Заводоуспенское', 56.8625600, 65.0155300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122057, 'Zavodoukovsk', 'Zavodoukovsk', 'Gorad Zavodaukousk,Sawodoukowsk,Zavodo-oekovsk,Zavodooukovsk,Zavodoukovsk,Zavodoukovskiy,Zavodoukovskoye,Zavodoukovszk,Zawodoukowsk,zafwdwkwfsk,zawwdwkwfsk,zha wo duo wu ke fu si ke,Горад Заводаўкоўск,Заводоуковск,زافودوكوفسك,زاوودوکوفسک,扎沃多烏科夫斯克', 56.5042000, 66.5515300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122058, 'Zaton', 'Zaton', 'Zaton,Затон', 53.2936100, 83.8072200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122059, 'Zarinsk', 'Zarinsk', 'Gorad Zarynsk,Sarinsk,Zarinsk,Zarinskaja,Zarinskaya,zarynsk,zha lin si ke,Горад Зарынск,Заринск,Заринская,زارينسك,زارینسک,扎林斯克', 53.7074000, 84.9493000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122060, 'Zarechnyy', 'Zarechnyy', 'Zarechnyj,Zarechnyy,Zaretsjnyj,Заречный', 56.8110000, 61.3254000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122061, 'Zapolyarnyy', 'Zapolyarnyy', 'Zapoljarnyj,Zapolyarnyy,Заполярный', 67.4955200, 63.7327500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122062, 'Zalesovo', 'Zalesovo', 'Zalesovo,Залесово', 53.9938900, 84.7430600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122063, 'Yuzhnyy', 'Yuzhnyy', 'Juzhnyj,Juzjnyj,Yuzhnyy,Южный', 53.2541700, 83.6936100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122064, 'Yuzhnoural’sk', 'Yuzhnoural''sk', 'Juzhnoural''sk,Juzjnouralsk,Nizhne-Uvel''skoye,Nizhne-Uvel’skoye,Yuzhnoural''sk,Yuzhnoural''skiy,Yuzhnoural’sk,Yuzhnoural’skiy,Южноуральск', 54.4418000, 61.2536000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122065, 'Yushala', 'Yushala', 'Jushala,Jusjala,Yushala,Юшала', 57.0761100, 64.2601100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122066, 'Yurty', 'Yurty', 'Jurty,Yurty,Юрты', 56.0498000, 97.6348000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122067, 'Yurginskoye', 'Yurginskoye', 'Jurginskoe,Jurginskoje,Korginskoye,Yurga,Yurginskoye,Юргинское', 56.8188800, 67.3921100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122068, 'Yurgamysh', 'Yurgamysh', 'Jurgamysh,Jurgamysj,Yurgamysh,Юргамыш', 55.3745400, 64.4622200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122069, 'Yurga', 'Yurga', 'Jurga,Yurga,yuruga,Юрга,ユルガ', 55.7230600, 84.8861100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122070, 'Yetkul’', 'Yetkul''', 'Etkul'',Jetkul,Yetkul'',Yetkul’,Еткуль', 54.8221000, 61.5880000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122071, 'Yertarskiy', 'Yertarskiy', 'Ertarskij,Jertarskij,Yertarkoye,Yertarskiy,Yertarskoye,Ертарский', 56.7901600, 64.2995200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122072, 'Yermakovskoye', 'Yermakovskoye', 'Ermakovskoe,Jermakovskoje,Yermakovskoe,Yermakovskoye,Ермаковское', 53.2754500, 92.4002100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122073, 'Yeniseysk', 'Yeniseysk', 'EIE,Eniseisk,Enisejsk,Eniséjsk,Jeniseiskas,Jenisejk,Jenisejsk,Jenisseisk,Yeniseisk,Yeniseyevo,Yeniseysk,Јенисејк,Енисейск', 58.4493700, 92.1796800, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122074, 'Yemel’yanovo', 'Yemel''yanovo', 'Emel''janovo,Jemeljanovo,Yemel''yanovo,Yemel’yanovo,Емельяново', 56.1677600, 92.6753900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122075, 'Yemanzhelinsk', 'Yemanzhelinsk', 'Emanzelinsk,Emanzhelinka,Emanzhelins''k,Emanzhelinsk,Emanzhelinskij,Emanželinsk,Gorad Emanzhalinsk,Iemanjelinsk,Jamanuelga,Jemanjelinsk,Jemanschelinsk,Jemanzelinsk,Jemanzhelinsk,Jemanzjelinsk,Jemanĵelinsk,Jemanželinsk,Yemanjelinsk,Yemanzhelinka,Yemanzhelinsk,Yemanzhelinskiy,ye man re lin si ke,ymanzhlynsk,ymnjlnsk,Єманжелинськ,Јеманжелинск,Горад Еманжалінск,Еманжелинка,Еманжелинск,Еманжелинский,Яманъелга,يمنجلنسك,یمانژلینسک,葉曼熱林斯克', 54.7547200, 61.3208300, 'RU', '2017-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122076, 'Yemanzhelinka', 'Yemanzhelinka', 'Emanzhelinka,Emanzhelinsk,Jemanzjelinsk,Yemanzhelinka,Yemanzhelinskiy,Еманжелинка,Еманжелинск', 54.8010000, 61.2989000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122077, 'Yelanskiy', 'Yelanskiy', 'Elanskij,Jelanskij,Yelanskiy,Еланский', 56.8419000, 62.5014000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122078, 'Yekaterinburg', 'Yekaterinburg', 'Catharinoburgum,Ekaterimburgo,Ekaterinburg,Ekaterinburgo,Iekaterinbourg,Jekaterinburg,Jekaterinburga,Jekaterinburgas,Jekaterinenburg,Jekaterynburg,Jekatyerinburg,Jekatěrinburg,SVX,Sverdlovsk,Sverolovsk,Yekaterinburg,ekaterinburuku,ye ka jie lin bao,yekatelinbuleukeu,yqtrynbwrg,Єкатеринбург,Екатеринбург,Свердловск,יקטרינבורג,エカテリンブルク,葉卡捷琳堡,예카테린부르크', 56.8519000, 60.6122000, 'RU', '2013-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122079, 'Yaya', 'Yaya', 'Jaja,Yaya,Яя', 56.2060000, 86.4400000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122080, 'Yashkino', 'Yashkino', 'Jaschkino,Jashkino,Yashkino,Яшкино', 55.8736000, 85.4265000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122081, 'Yar-Sale', 'Yar-Sale', 'Jar-Sale,Yar-Sale,Яр-Сале', 66.8654000, 70.8378400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122082, 'Yarovoye', 'Yarovoye', 'Jarovoe,Jarovoje,Yarovoy,Yarovoye,Яровое', 52.9273000, 78.5800000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122083, 'Yarkovo', 'Yarkovo', 'Jarkovo,Yarkovo,Ярково', 57.4038600, 67.0639000, 'RU', '2012-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122084, 'Yarkovo', 'Yarkovo', 'Jarkovo,Yarkova,Yarkovo,Ярково', 54.8056000, 82.5989000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122085, 'Yalutorovsk', 'Yalutorovsk', 'Jalutorovsk,Yalutorovsk,Ялуторовск', 56.6535800, 66.3005700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122086, 'Yagunovskiy', 'Yagunovskiy', 'Davydova,Ishanova,Jagunovskij,Yagunovskiy,Ягуновский', 55.2828000, 85.9780000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122087, 'Yagunovo', 'Yagunovo', 'Jagunovo,Yagunova,Yagunovo,Ягуново', 55.2464500, 86.0109700, 'RU', '2015-03-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122088, 'Vvedenskoye', 'Vvedenskoye', 'Vvedenskoe,Vvedenskoye,Vvednskoe,Введенское,Введнское', 55.4742600, 65.0844900, 'RU', '2012-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122089, 'Vostochnyy', 'Vostochnyy', 'Vostochnyj,Vostochnyy,Vostotsjnyj,Восточный', 58.7999100, 61.8139100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122090, 'Vorkuta', 'Vorkuta', 'Gorad Varkuta,VKT,Vorcuta,Vorkoeta,Vorkouta,Vorkut,Vorkuta,Vorkuta karkytsh,Vorkutà,Vorkutá,Workuta,boleukuta,fwrkwta,vu~orukuta,wo er ku ta,wwrkwta,wwrqwth,Βορκουτά,Воркута,Воркута балһсн,Вӧркута,Вӧркута каркытш,Горад Варкута,Վորկուտա,וורקוטה,فوركوتا,وورکوتا,ヴォルクタ,沃尔库塔,보르쿠타', 67.4988400, 64.0525300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122091, 'Vorgashor', 'Vorgashor', 'Vorgashor,Vorgasjor,Воргашор', 67.5835500, 63.7939900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122092, 'Volchikha', 'Volchikha', 'Volchikha,Voltchikha,Voltsjikha,Волчиха', 52.0135600, 80.3571500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122093, 'Volchansk', 'Volchansk', 'Volchanka,Volchansk,Voltsjansk,Волчанск', 59.9378000, 60.0810000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122094, 'Vlasikha', 'Vlasikha', 'Vlasikha,Власиха', 53.2972200, 83.5741700, 'RU', '2016-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122095, 'Vkhodnoy', 'Vkhodnoy', 'Vkhodnoj,Vkhodnoy,Входной', 54.9518100, 73.1710800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122096, 'Vishnëvogorsk', 'Vishnevogorsk', 'Vishnevogorsk,Vishnëvogorsk,Visjnevogorsk,Вишнëвогорск,Вишневогорск', 55.9913000, 60.6579000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122097, 'Vinzili', 'Vinzili', 'Vinzili,Винзили', 56.9593800, 65.7708000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122098, 'Vikulovo', 'Vikulovo', 'Vikulovo,Викулово', 56.8166700, 70.6106900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122099, 'Veseloyarsk', 'Veseloyarsk', 'Veselojarsk,Veseloyarsk,Veseloyarskoye,Veselyy Yar,Веселоярск', 51.2873700, 81.1070300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122100, 'Vershina Tei', 'Vershina Tei', 'Teya,Tjoja,Vershina Tei,Vershina Tjoi,Вершина Тёи,Тёя', 53.2685800, 89.5600800, 'RU', '2013-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122101, 'Verkh-Suetka', 'Verkh-Suetka', '', 53.3040100, 80.0467500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122102, 'Verkhotur’ye', 'Verkhotur''ye', 'Verkhotur''e,Verkhotur''ye,Verkhoturje,Verkhotur’ye,Верхотурье', 58.8627100, 60.8053600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122103, 'Verkh-Tula', 'Verkh-Tula', 'Verkh-Tula,Verkhne-Tulinskoye,Verkhnyaya Tula,Верх-Тула', 54.8839000, 82.7762000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122104, 'Verkhnyaya Sysert’', 'Verkhnyaya Sysert''', 'Verkhne Sysertskiy,Verkhnjaja Sysert,Verkhnjaja Sysert'',Verkhnyaya Sysert'',Verkhnyaya Sysert’,Верхняя Сысерть', 56.4401200, 60.7556300, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122105, 'Verkhnyaya Sinyachikha', 'Verkhnyaya Sinyachikha', 'Verkhniy Sinyachikhinskiy,Verkhnjaja Sinjachikha,Verkhnjaja Sinjatsjikha,Verkhnyaya Sinyachikha,Верхняя Синячиха', 57.9760400, 61.6673300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122106, 'Verkhnyaya Salda', 'Verkhnyaya Salda', 'Aukstutine Salda,Aukštutinė Salda,Gorad Verkhnjaja Salda,Jugary Sally,Salda,Verchniagia Salnta,Verchnjaja Salda,Verhnjaja Salda,Verkhnaja Salda,Verkhniaia Salda,Verkhniaïa Salda,Verkhnja Salda,Verkhnjaja Salda,Verkhnyaya Salda,Verxnyaya Salda,Verĥnjaja Salda,Werchnjaja Salda,Wierchniaja Salda,Wierchniaja Sałda,Wjerchnjaja Salda,fyrkhnyaya salda,shang sa er da,wrkhnyaya salda,wyrkhnayya salda,Βέρχνιαγια Σαλντά,Верхня Салда,Верхняя Салда,Верхњаја Салда,Горад Верхняя Салда,Югары Саллы,فيرخنيايا سالدا,ورخنیایا سالدا,ویرخناییا سالدا,上薩爾達', 58.0487400, 60.5594900, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122107, 'Verkhnyaya Pyshma', 'Verkhnyaya Pyshma', 'Aukstutine Pysma,Aukštutinė Pyšma,Gorad Verkhnjaja Pyshma,Jugary Pyshma,Pyshma,Turi Pyshma,Verchniagia Pisma,Verchnjaja Pysjma,Verchnjaja Pysma,Verchnjaja Pyšma,Verhnjaja Pisma,Verhnjaja Posma,Verhnjaja Pysma,Verhnjaja Pyšma,Verhnjaja Põšma,Verkhnaja Pishma,Verkhniaia Pychma,Verkhniaïa Pychma,Verkhnja Pishma,Verkhnjaja Pishma,Verkhnjaja Pyshma,Verkhnjaja Pysjma,Verkhnyaya Pyshma,Verxnyaya Pisma,Verxnyaya Pışma,Verĥnjaja Piŝma,Werchnjaja Pyschma,Wierchniaja Pyszma,Wjerchnjaja Pysma,Wjerchnjaja Pyšma,beleuheunyayapisima,fyrkhnyaya byshma,shang pei shen ma,wrkhnyaya pyshma,wrkhnyya pyshma,Βέρχνιαγια Πησμά,Верхня Пишма,Верхняя Пишма,Верхняя Пышма,Верхњаја Пишма,Горад Верхняя Пышма,Пышма,Тури Пышмă,Югары Пышма,فيرخنيايا بيشما,ورخنیایا پیشما,ورخنییا پیشما,上佩什馬,베르흐냐야피시마', 56.9704700, 60.5821900, 'RU', '2012-11-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122108, 'Verkhnyaya Inta', 'Verkhnyaya Inta', 'Verkhnjaja Inta,Верхняя Инта', 65.9811500, 60.3094500, 'RU', '2010-01-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122109, 'Verkhniy Ufaley', 'Verkhniy Ufaley', 'Verkhnij Ufalej,Verkhniy Ufaley,Верхний Уфалей', 56.0556000, 60.2397000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122110, 'Verkh-Bekhtemir', 'Verkh-Bekhtemir', 'Verkh-Bekhtemir,Verkhne-Bekhtemirskoye,Verkhniy Bakhtemir,Verkhniy Bekhtemir,Verkhniy Bekhzhemor,Верх-Бехтемир', 52.7659600, 85.9050800, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122111, 'Verkh-Neyvinskiy', 'Verkh-Neyvinskiy', 'Verkhne-Neivinsk,Verkhne-Neyvinskiy,Verkhneivinsk,Verkhniye-Nevinsk', 57.2701300, 60.1376200, 'RU', '2009-03-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122112, 'Verkhneye Dubrovo', 'Verkhneye Dubrovo', 'Dubrovinskiy,Verkhnee Dubrovo,Verkhneje Dubrovo,Verkhneye Dubrovo,Верхнее Дуброво', 56.7528000, 61.0468000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122113, 'Verkh-Katunskoye', 'Verkh-Katunskoye', 'Varki,Verkh-Katunskoe,Verkh-Katunskoje,Verkh-Katunskoye,Verkhne-Katunskoye,Verkhneye Katunskoye,Yarki,Верх-Катунское', 52.4500000, 85.4316200, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122114, 'Verkh-Chebula', 'Verkh-Chebula', 'Verkh-Chebula,Verkh-Tsjebula,Verkhne Chebulinskoye,Verkhne-Chebula,Verkhnyaya Chebula,Верх-Чебула', 56.0306200, 87.6221500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122115, 'Vengerovo', 'Vengerovo', 'Spasskoye,Vengerovo,Венгерово', 55.6848500, 76.7470700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122116, 'Varna', 'Varna', 'Varna,Варна', 53.3819400, 60.9747200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122117, 'Vargashi', 'Vargashi', 'Vargashi,Vargasji,Варгаши', 55.3555600, 65.8466700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122118, 'Vakhrushevo', 'Vakhrushevo', 'Vakhrushevo,Вахрушево', 55.2317000, 61.7173000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122119, 'Vagay', 'Vagay', 'Vagaj,Vagay,Vagayskoye,Wagai,Вагай', 57.9356600, 69.0195300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122120, 'Uzhur', 'Uzhur', 'Gorad Uzhur,Oujour,Ujur,Uschur,Uzhur,Uzjur,Uzur,Uĵur,Użur,Užur,awjwr,awzhwr,wu ru er,Горад Ужур,Ужур,أوجور,اوژور,烏茹爾', 55.3124600, 89.8330100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122121, 'Uyar', 'Uyar', 'Ujar,Uyar,Уяр', 55.8118000, 94.3247000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122122, 'Uvel’skiy', 'Uvel''skiy', 'Uvel''skij,Uvel''skiy,Uvelskij,Uvel’skiy,Увельский', 54.4446000, 61.3574000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122123, 'Uvat', 'Uvat', 'Uvat,Уват', 59.1422700, 68.8888100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122124, 'Usyatskoye', 'Usyatskoye', 'Usiatskoje,Usjatskoe,Usyatskoye,Усятское', 52.5680600, 85.7608500, 'RU', '2013-09-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122125, 'Ust’yanka', 'Ust''yanka', 'Ust''janka,Ust''yanka,Ustjanka,Ust’yanka,Устьянка', 53.4527000, 78.7425000, 'RU', '2012-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122126, 'Ust’-Ulagan', 'Ust''-Ulagan', 'Ulagan,Ust''-Ulagan,Ust’-Ulagan,Улаган,Усть-Улаган', 50.6325800, 87.9604600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122127, 'Ust’-Tarka', 'Ust''-Tarka', 'Ust''-Tarka,Ust''-Tarskoye,Ust-Tarka,Ust’-Tarka,Ust’-Tarskoye,Усть-Тарка', 55.5671500, 75.7050000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122128, 'Ust’-Koksa', 'Ust''-Koksa', 'Ust''-Koksa,Ust-Koksa,Ust’-Koksa,Усть-Кокса', 50.2696000, 85.6108000, 'RU', '2013-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122129, 'Ust’-Kan', 'Ust''-Kan', 'Ust''-Kan,Ust-Kan,Ust’-Kan,Усть-Кан', 50.9276000, 84.7610000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122130, 'Ust’-Kalmanka', 'Ust''-Kalmanka', 'Ust''-Kalmanka,Ust''-Kalmanskoye,Ust-Kalmanka,Ust’-Kalmanka,Ust’-Kalmanskoye,Усть-Калманка', 52.1207000, 83.3050000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122131, 'Ust’-Ishim', 'Ust''-Ishim', 'Ust''-Ishim,Ust-Isjim,Ust’-Ishim,Усть-Ишим', 57.6935000, 71.1665000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122132, 'Ust’-Isha', 'Ust''-Isha', 'Ust''-Isha,Ust-Isja,Ust’-Isha,Усть-Иша', 52.1820100, 85.9675700, 'RU', '2013-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122133, 'Ust’-Charyshskaya Pristan’', 'Ust''-Charyshskaya Pristan''', 'Ust''-Char-Pristan'',Ust''-Charysh,Ust''-Charyshskaja Pristan'',Ust''-Charyshskaya Pristan'',Ust-Tsjarysjskaja Pristan,Ust’-Char-Pristan’,Ust’-Charysh,Ust’-Charyshskaya Pristan’,Усть-Чарышская Пристань', 52.3934000, 83.6635000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122134, 'Zelenogorsk', 'Zelenogorsk', 'Barga,Gorad Zelenagorsk,Krasnoyarsk-45,Selenogorsk,Ust''-Barga,Ust’-Barga,Zelenogorsk,Zelenogorsk i Krasnojarsk kraj,Zielenogorsk,jellenogoleuseukeu,ze lie nuo ge er si ke,zlnwgwrsk  krasnwyarsk,zlynwgwrsk,zylynwghwrsk,Горад Зеленагорск,Зеленогорск,Зељеногорск,زلنوگورسک، کراسنویارسک,زلینوگورسک,زيلينوغورسك,泽列诺戈尔斯克,젤레노고르스크', 56.1124000, 94.5985000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122135, 'Ust’-Bagaryak', 'Ust''-Bagaryak', 'Nizhnyaya,Ust''-Bagarjak,Ust''-Bagaryak,Ust-Bagarjak,Ust’-Bagaryak,Усть-Багаряк', 56.1327800, 61.8472200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122136, 'Ust’-Abakan', 'Ust''-Abakan', 'Ust''-Abakan,Ust''-Abakanskoye,Ust-Abakan,Ust’-Abakan,Ust’-Abakanskoye,Усть-Абакан', 53.8365100, 91.3907700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122137, 'Uspenka', 'Uspenka', 'Uspenka,Успенка', 56.8015800, 69.2270200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122138, 'Urengoy', 'Urengoy', 'UEN,Urengoi,Urengoj,Urengoy,Уренгой', 65.9655000, 78.3692900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122139, 'Uray', 'Uray', 'Nizhnyaya Arpa,URJ,Urai,Uraj,Uray,Урай', 60.1304400, 64.7889600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122140, 'Ural', 'Ural', 'Ural,Урал', 55.9052000, 94.7537000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122141, 'Uporovo', 'Uporovo', 'Uporovo,Упорово', 56.3109300, 66.2692600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122142, 'Uk', 'Uk', 'Tret''ya Ferma,Tret’ya Ferma,Uk,Vtoraya Ferma,Ук', 55.0790000, 98.8586000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122143, 'Uglovskoye', 'Uglovskoye', 'Uglovskoe,Uglovskoje,Uglovskoye,Угловское', 51.3557000, 80.1942000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122144, 'Ubinskoye', 'Ubinskoye', 'Ubinskoe,Ubinskoje,Ubinskoye,Убинское', 55.3067500, 79.6801600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122145, 'Tyumentsevo', 'Tyumentsevo', 'Tjumencevo,Tjumentsevo,Tyumentseva,Tyumentsevo,Тюменцево', 53.3224000, 81.4980000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122146, 'Tyumen', 'Tyumen', 'Gorad Cjumen'',TJM,Temen,Tioumen,Tiumen,Tiumene,Tiumenė,Tiumeń,Tiumén,Tjoemen,Tjumen,Tjumen'',Tjumen'' khot,Tjumena,Tjumenj,Tjumeno,Tjumeń,Tjumeņa,Tuemen,Tumen,Tumenum,Tyoumen,Tyumen,Tyumen'',Tyumeny,Tyumen’,Tümen,chumeni,qiu ming,tyumen,tyumena,tywmn,tywmyn,Ťumeň,Горад Цюмень,Тĕмен,Тюмен,Тюмень,Тюмень хот,Тјумењ,Түмен,Түмэн,Төмән,טיומן,تيومين,تیومن,ٹیومن,त्युमेन,チュメニ,秋明,튜멘', 57.1522200, 65.5272200, 'RU', '2014-08-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122147, 'Tyukhtet', 'Tyukhtet', 'Tjukhtet,Tyukhtet,Тюхтет', 56.5393900, 89.3122100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122148, 'Tyukalinsk', 'Tyukalinsk', 'Tjukalinsk,Tyukalinsk,Тюкалинск', 55.8732100, 72.1967300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122149, 'Tyubuk', 'Tyubuk', 'Tjubuk,Tyubuk,Тюбук', 56.0552100, 60.9405000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122150, 'Tyazhinskiy', 'Tyazhinskiy', 'Tjazhinskij,Tjazjinskij,Tyazhin,Tyazhing,Tyazhinskiy,Tyazhinskoye,Тяжинский', 56.1160700, 88.5227900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122151, 'Turukhansk', 'Turukhansk', 'THX,Turukhansk,Туруханск', 65.7947900, 87.9500600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122152, 'Turochak', 'Turochak', 'Turochak,Turochan,Turotsjak,Турочак', 52.2576000, 87.1224000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122153, 'Turinskaya Sloboda', 'Turinskaya Sloboda', 'Turinskaja Sloboda,Turinskaja-Sloboda,Turinskaya Sloboda,Туринская Слобода', 57.6232000, 64.3857500, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122154, 'Turinsk', 'Turinsk', 'Gorad Turynsk,Toerinsk,Tourinsk,Turins''k,Turinsk,tu lin si ke,twrynsk,Τουρίνσκ,Горад Турынск,Туринск,Туринськ,Түре,تورينسك,تورینسک,圖林斯克', 58.0457500, 63.6960500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122155, 'Turgoyak', 'Turgoyak', 'Turgojak,Turgoyak,Тургояк', 55.1500000, 60.1183300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122156, 'Turan', 'Turan', 'Gorad Turan,Poselok Turanskiy,Posëlok Turanskiy,Toeran,Touran,Turan,Turan i Russland,Turanskiy,Turán,tu lan shi,tulan,twran,Горад Туран,Туран,توران,图兰市,투란', 52.1449000, 93.9188700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122157, 'Tuim', 'Tuim', 'Tuim,Туим', 54.3394900, 89.9458600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122158, 'Tugulym', 'Tugulym', 'Tugulym,Тугулым', 57.0590600, 64.6425100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122159, 'Tsementnyy', 'Tsementnyy', 'Cementnyj,Tsementnyj,Tsementnyy,Цементный', 57.4693000, 60.1536000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122160, 'Tsementnozavodskiy', 'Tsementnozavodskiy', 'Cementnozavodskij,Tsementnozavodskij,Tsementnozavodskiy,Цементнозаводский', 67.6283400, 64.0896500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122161, 'Tselinnoye', 'Tselinnoye', 'Celinnoe,Novo-Kocherdyk,Novyy Kocherdyk,Tselinnoje,Tselinnoye,Целинное', 54.5011100, 63.6736100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122162, 'Tselinnoye', 'Tselinnoye', 'Celinnoe,Tselinnoje,Tselinnoye,Yaminskoye,Целинное', 53.0782200, 85.6536300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122163, 'Trudarmeyskiy', 'Trudarmeyskiy', 'Trudarmejskij,Trudarmeysk,Trudarmeyskiy,Trudarmeyskoye,Tyrgan,Трудармейский', 54.1320000, 86.4098000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122164, 'Troitsk', 'Troitsk', 'Troick,Troitsk,Troitskoye,Троицк', 55.7012800, 72.2336900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122165, 'Troitskoye', 'Troitskoye', 'Troickoe,Troitskoje,Troitskoye,Троицкое', 52.9821000, 84.6757000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122166, 'Troitskiy', 'Troitskiy', 'Troickij,Troitskij,Troitskiy,Троицкий', 57.0602800, 63.7481100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122167, 'Troitsk', 'Troitsk', 'Gorad Troick,Troic''k,Troick,Troitk,Troitsk,Troitsk i Tsjeljabinsk oblast,Troizk,Troițk,Troïtsk,te luo yi ci ke,trwytsk,trwytsk  awblast chlyabynsk,Горад Троіцк,Троицк,Троїцьк,تروئتسک,ترويتسك,ترویتسک، اوبلاست چلیابینسک,特羅伊茨克', 54.0979000, 61.5773000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122168, 'Topol’noye', 'Topol''noye', 'Topol''naya,Topol''noe,Topol''noye,Topolnoje,Topol’naya,Topol’noye,Топольное', 51.5105000, 84.4813000, 'RU', '2013-08-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122169, 'Topki', 'Topki', 'Topki,tuo pu ji,Топки,托普基', 55.2769000, 85.6163000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122170, 'Topchikha', 'Topchikha', 'Topchikha,Toptsjikha,Топчиха', 52.8192000, 83.1185000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122171, 'Toora-Khem', 'Toora-Khem', 'Doora-Khem,Dora-Khem,Doro-Kem,Saldam,Toora-Khem,Tora-Khem,Салдам,Тоора-Хем', 52.4655600, 96.1179600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122172, 'Tomsk', 'Tomsk', 'Gorad Tomsk,TOF,Tom''sku,Tomck,Tomium,Toms''k,Tomsk,Tomska,Tomskaj,Tomskas,Tomszk,Tomçk,tomseukeu,tomska,tomusuku,tuo mu si ke,twmsk,twmsq,Τομσκ,Горад Томск,Томск,Томскай,Томськ,Томьскъ,Տոմսկ,טומסק,تومسك,تومسک,ٹومسک,तोम्स्क,トムスク,托木斯克,톰스크', 56.4977100, 84.9743700, 'RU', '2013-02-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122173, 'Tolmachëvo', 'Tolmachevo', 'Tolmacheva,Tolmachevo,Tolmachëvo,Tolmatsjevo,Толмачëво,Толмачево', 54.9824000, 82.7363000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122174, 'Togur', 'Togur', 'Togur,Тогур', 58.3631000, 82.8265000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122175, 'Togul', 'Togul', 'Togul,Тогул', 53.4670000, 85.9128000, 'RU', '2013-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122176, 'Toguchin', 'Toguchin', 'Goguchin,Toguchin,Togutsjin,Toruchin,Тогучин', 55.2352800, 84.3858300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122177, 'Tobol’sk', 'Tobol''sk', 'TOX,Tobol''sk,Tobolsk,Tobol’sk,Тобольск', 58.1980700, 68.2545700, 'RU', '2017-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122178, 'Tisul’', 'Tisul''', 'Tisul,Tisul'',Tisul’,Тисуль', 55.7617300, 88.3122800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122179, 'Tinskoy', 'Tinskoy', 'Tinskaya,Tinskiy,Tinskoj,Tinskoy,Vyselke-Tinskiy,Vyselok Tiny,Тинской', 56.1513000, 96.9173000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122180, 'Timiryazevskoye', 'Timiryazevskoye', 'Novaya Eushta,Timirjazevskij,Timirjazevskoe,Timiryazevskiy,Timiryazevskoye,Тимирязевский,Тимирязевское', 56.4898800, 84.8779500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122181, 'Teya', 'Teya', '', 60.3720200, 92.6295600, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122182, 'Tevriz', 'Tevriz', 'Tavrizskoye,Tevriz,Тевриз', 57.5090000, 72.4042000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122183, 'Temirtau', 'Temirtau', 'Temirtau,Timer-Tau,Темиртау', 53.1377000, 87.4538000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122184, 'Tegul’det', 'Tegul''det', 'Tegul''det,Teguldet,Tegul’det,Тегульдет', 57.3067900, 88.1600400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122185, 'Teeli', 'Teeli', 'Teeli,Tehehli,Tehli,Teli,Тэли,Тээли', 51.0139800, 90.2053500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122186, 'Tazovskiy', 'Tazovskiy', 'Khal''mer-Sede,Khal’mer-Sede,Tazovskij,Tazovskiy,Tazovskoye,Тазовский', 67.4715000, 78.7162000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122187, 'Tayzhina', 'Tayzhina', 'Tajzhina,Tajzjina,Tayzhina,Тайжина', 53.6679000, 87.4362000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122188, 'Tayshet', 'Tayshet', 'Taischet,Taishet,Tajset,Tajshet,Tajsjet,Tajŝet,Tajšet,Tashieta,Tayshet,tai she te,taisheto,taisyeteu,Тайшет,Тајшет,タイシェト,泰舍特,타이셰트', 55.9342000, 98.0044000, 'RU', '2016-12-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122189, 'Tayginka', 'Tayginka', 'Tajginka,Tayginka,Тайгинка', 55.6244000, 60.5076000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122190, 'Tayga', 'Tayga', 'Taiga,Tajga,Tayga,Тайга', 56.0640200, 85.6223800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122191, 'Tavricheskoye', 'Tavricheskoye', 'Tavricheskoe,Tavricheskoye,Tavritsjeskoje,Таврическое', 54.5850800, 73.6395000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122192, 'Tavda', 'Tavda', 'Gorad Tauda,Tavda,Tavdà,Tavdá,Tavnta,Tawda,ta fu da,tafda,tawda,Ταβντά,Горад Таўда,Тавда,Тәүде,تافدا,تاودا,塔夫達', 58.0425400, 65.2725800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122193, 'Tatarsk', 'Tatarsk', 'Gorad Tatarsk,Tatars''k,Tatarsk,da da si ke,tatarsk,Горад Татарск,Татарск,Татарськ,تاتارسك,تاتارسک,韃靼斯克', 55.2190300, 75.9828300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122194, 'Tashtyp', 'Tashtyp', 'Tashtyp,Tashtypskoye,Tasjtyp,Таштып', 52.7954200, 89.8947700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122195, 'Tashtagol', 'Tashtagol', 'Tashtagol,Tashtapol,Tashtogol,Tasjtagol,Таштагол', 52.7657000, 87.8894000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122196, 'Tashara', 'Tashara', 'Tashara,Tasjara,Ташара', 55.5195000, 83.5094000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122197, 'Tashanta', 'Tashanta', 'Tashanta,Tasjanta,Ташанта', 49.7157300, 89.1942500, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122198, 'Taseyevo', 'Taseyevo', 'Taseevo,Tasejevo,Taseyevo,Taseyevskoye,Tasyeevo,Тасеево', 57.2145700, 94.8939300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122199, 'Tarko-Sale', 'Tarko-Sale', 'Gorad Tarka-Sale,TQL,Tarka-Sale,Tarko Sale,Tarko Salė,Tarko-Sale,Tarko-Salé,Tarsale,ta er ke sa lie,tarkw-sal,tarkw-salh,Горад Тарка-Сале,Тарко Сале,Тарко-Сале,تاركو-سال,تارکو-ساله,塔爾科薩列', 64.9161100, 77.7745700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122200, 'Tara', 'Tara', 'Gorad Tara,Tara,Tara i Russland,ta la,tara,tara  rwsyh,Горад Тара,Тара,تارا,تارا، روسیه,塔拉', 56.8943600, 74.3709600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122201, 'Talnakh', 'Talnakh', 'Talnakh,Талнах', 69.4865000, 88.3972000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122202, 'Tal’menka', 'Tal''menka', 'Tal''menka,Tal''menskoye,Talmenka,Tal’menka,Tal’menskoye,Тальменка', 53.8183000, 83.5677000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122203, 'Talitsa', 'Talitsa', 'Talica,Talitsa,Талица', 56.8804000, 60.0213000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122204, 'Talitsa', 'Talitsa', 'Gorad Talica,Talica,Talicja,Talitsa,Taliza,Taliça,Tàlitsa,ta li cha,talytsa,talytsa  awblast swrdlwfsk,Τάλιτσα,Горад Таліца,Талица,Талиця,تاليتسا,تالیتسا، اوبلاست سوردلوفسک,塔利察', 57.0109500, 63.7325400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122205, 'Tabuny', 'Tabuny', 'Tabuny,Табуны', 52.7773000, 78.7896000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122206, 'Tabory', 'Tabory', 'Tabory,Таборы', 58.5198200, 64.5494700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122207, 'Sysert’', 'Sysert''', 'Sysert,Sysert'',Sysert’,Сысерть', 56.5024300, 60.8191700, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122208, 'Sychëvka', 'Sychevka', 'Sychevka,Sychevskoye,Sychjovka,Sychovka,Sychëvka,Sytsjevka,Сычевка,Сычёвка', 52.0512000, 84.7788000, 'RU', '2013-09-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122209, 'Svetlyy', 'Svetlyy', 'Svetlyj,Svetlyy,Светлый', 56.9166700, 85.9666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122210, 'Svetlyy', 'Svetlyy', 'Svetliy,Svetlyj,Svetlyy,Светлый', 50.8183300, 60.8519400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122211, 'Svetlogorsk', 'Svetlogorsk', 'Svetlogorsk,Светлогорск', 66.9376200, 88.3526500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122212, 'Suzun', 'Suzun', 'Suzun,Сузун', 53.7841000, 82.3116000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122213, 'Sut-Khol’', 'Sut-Khol''', 'Sug-Aksy,Sut-Khol'',Sut-Khol’,Суг-Аксы,Сут-Холь', 51.4069800, 91.2924400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122214, 'Suslovo', 'Suslovo', 'Suslovo,Суслово', 56.2166700, 88.1166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122215, 'Surgut', 'Surgut', 'Gorad Surgut,SGC,Soergoet,Sorgyt,Sourgout,Surgut,Surguta,Surgutas,Surguto,Surgutum,Surqut,Szurgut,srgwt,su er gu te,suleuguteu,suruguto,swrghwt,swrgwt,Горад Сургут,Соргыт,Сургут,סורגוט,سرگوت,سورغوت,سورگوت,スルグト,蘇爾古特,수르구트', 61.2500000, 73.4166700, 'RU', '2017-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122216, 'Sumkino', 'Sumkino', 'Sumkino,Сумкино', 58.1108300, 68.3244400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122217, 'Sukpak', 'Sukpak', 'Sukpak,Сукпак', 51.6666700, 94.6333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122218, 'Sukhoy Log', 'Sukhoy Log', 'Sukhoj Log,Sukhoy Log,Сухой Лог', 56.9094000, 62.0296000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122219, 'Sukhobuzimskoye', 'Sukhobuzimskoye', 'Sukhobuzimskoe,Sukhobuzimskoje,Sukhobuzimskoye,Сухобузимское', 56.5000000, 93.2727800, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122220, 'Stukovo', 'Stukovo', 'Stukovo,Стуково', 53.2127800, 83.3377800, 'RU', '2012-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122221, 'Strezhevoy', 'Strezhevoy', 'SWT,Strazhevoy,Strezhevoj,Strezhevoy,Strezhevoye,Strezhevsy,Strezjevoj,Стрежевой', 60.7333000, 77.5889000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122222, 'Strelka', 'Strelka', 'Strelka,Стрелка', 58.0727800, 93.0344400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122223, 'Staryy Togul', 'Staryy Togul', 'Star.Togul,Staro-Togul''skaya,Staro-Togul’skaya,Staryj Togul,Staryy Togul,Стар.Тогул,Старый Тогул', 53.4291000, 85.9006000, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122224, 'Staryy Nadym', 'Staryy Nadym', 'Staryj Nadym,Старый Надым', 65.6118200, 72.6841700, 'RU', '2010-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122225, 'Staropyshminsk', 'Staropyshminsk', 'Pyshminskiy,Staropyshminsk,Staropysjminsk,Старопышминск', 56.9386700, 60.9029500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122226, 'Staropesterevo', 'Staropesterevo', 'Pesterevskoye,Staropesterevo,Stropesterovo,Старопестерево', 54.5001000, 86.4094000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122227, 'Starobachaty', 'Starobachaty', 'Bachatskoye,Bachaty,Bochatskoye,Bochaty,Boghatyy,Starobachaty,Starobatsjaty,Старобачаты', 54.2425000, 86.2072000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122228, 'Staroaleyskoye', 'Staroaleyskoye', 'Staroalejskoe,Staroalejskoje,Staroaleyskoye,Староалейское', 51.0061100, 82.0000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122229, 'Starobelokurikha', 'Starobelokurikha', 'Staraya Belokurikha,Starobelokurikha,Старобелокуриха', 52.0520600, 85.0876500, 'RU', '2013-11-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122230, 'Stantsionno-Oyashinskiy', 'Stantsionno-Oyashinskiy', 'Oyash,Stancionno-Ojashinskij,Stantsionno-Ojasjinskij,Stantsionno-Oyashinskiy,Станционно-Ояшинский', 55.4664000, 83.8245000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122231, 'Srostki', 'Srostki', 'Srostinskoye,Srostki,Сростки', 52.4209000, 85.6992300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122232, 'Sredneuralsk', 'Sredneuralsk', 'Gorad Sjarehdnjaural''sk,Sredneoeralsk,Sredneouralsk,Sredneural''s''k,Sredneural''sk,Sredneuralsk,Srednjeuralsk,Srentneouralsk,Sriednieuralsk,asrdnywralsk,srydnwralsk,zhong wu la er si ke,Σρεντνεουράλσκ,Горад Сярэдняўральск,Среднеуралск,Среднеуральск,Средњеураљск,Срєднєуральськ,اسردنئورالسک,سريدنورالسك,中烏拉爾斯克', 56.9892100, 60.4666200, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122233, 'Spassk', 'Spassk', 'Spassk,Spasskoye,Спасск', 52.7470000, 87.7545000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122234, 'Sovkhoznyy', 'Sovkhoznyy', 'Sovkhoznyj,Sovkhoznyy,Совхозный', 56.5599000, 61.4260000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122235, 'Sovetskoye', 'Sovetskoye', 'Gryaznukha,Sovetskoe,Sovetskoje,Sovetskoye,Советское', 52.2855600, 85.4142400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122236, 'Sovetskiy', 'Sovetskiy', 'Sovetskij,Sovetskiy,Советский', 67.4833300, 64.4166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122237, 'Sovetskiy', 'Sovetskiy', 'OVS,Sovetskij,Sovetskiy,Советский', 61.3613900, 63.5841700, 'RU', '2017-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122238, 'Sos’va', 'Sos''va', 'Sos''va,Sos''vinskiy Zavod,Sosva,Sos’va,Sos’vinskiy Zavod,Сосьва', 59.1766200, 61.8557900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122239, 'Sosnovoborsk', 'Sosnovoborsk', 'Gorad Sasnovaborsk,Sosnovobors''k,Sosnovoborsk,Sosnovoborsk i Krasnojarsk kraj,Sosnowoborsk,suo si nuo wo bo er si ke,swsnwfwbwrsk,swsnwfwbwrsk  krasnwyarsk,Горад Сасноваборск,Сосновоборск,Сосновоборськ,سوسنوفوبورسك,سوسنوفوبورسک، کراسنویارسک,索斯諾沃博爾斯克', 56.1217000, 93.3385000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122240, 'Sorsk', 'Sorsk', 'Dzerzhinskiy,Gorad Sorsk,Sora,Sorsk,soleuseukeu,suo er si ke,Горад Сорск,Сорск,索尔斯克,소르스크', 54.0033300, 90.2466700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122241, 'Sorokino', 'Sorokino', 'Sorokino,Сорокино', 53.7500000, 84.9166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122242, 'Solton', 'Solton', 'Solton,Soltonskoye,Солтон', 52.8429000, 86.4787000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122243, 'Soloneshnoye', 'Soloneshnoye', 'Solnechnoye,Soloneshnoe,Soloneshnoye,Solonesjnoje,Soloreshnoye,Солонешное', 51.6544000, 84.3197000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122244, 'Sokur', 'Sokur', 'Novyy Sokur,Sokur,Сокур', 55.2093000, 83.3190000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122245, 'Sokolovo', 'Sokolovo', 'Sokolovo,Sonolovo,Соколово', 52.5318000, 84.7896000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122246, 'Snezhnogorsk', 'Snezhnogorsk', 'Snezhnogorsk,Snezjnogorsk,Снежногорск', 68.0930600, 87.7400000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122247, 'Smolenskoye', 'Smolenskoye', 'Smolenskoe,Smolenskoje,Smolenskoye,Смоленское', 52.3044700, 85.0785000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122248, 'Slavgorodskoye', 'Slavgorodskoye', 'Slavgorodskoe,Slavgorodskoye,Славгородское', 53.0214000, 78.6435000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122249, 'Slavgorod', 'Slavgorod', 'Gorad Slaugarad,Slavgorod,Slawgorod,Slàvgorod,Slávgorod,Sslawgorod,Sławgorod,aslawgwrwd,si la fu ge luo de,slafghwrwd,Горад Слаўгарад,Славгород,اسلاوگورود,سلافغورود,斯拉夫戈羅德', 52.9978000, 78.6449000, 'RU', '2014-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122250, 'Sladkovo', 'Sladkovo', 'Sladkovo,Sladkovskoye,Сладково', 55.5283500, 70.3385400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122251, 'Shushenskoye', 'Shushenskoye', 'Shush,Shushenskoe,Shushenskoye,Shushinskoe,Sjusjenskoje,Шушенское', 53.3250000, 91.9355600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122252, 'Shumskiy', 'Shumskiy', 'Shumskij,Shumskiy,Sjumskij,Шумский', 54.8318000, 99.1328000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122253, 'Shumikha', 'Shumikha', 'Choumikha,Gorad Shumikha,Schumicha,Shumikha,Sjoemicha,Sjumikha,Sumicha,Sumiha,Sumixa,shu mi ha,shwmykha,Ŝumiĥa,Şumixa,Šumicha,Šumiha,Горад Шуміха,Шумиха,شوميخا,شومیخا,舒米哈', 55.2261100, 63.2961100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122254, 'Shul’gin Log', 'Shul''gin Log', 'Shul''gin Log,Shul''gin-Log,Shul’gin Log,Шульгин Лог,Шульгин-Лог', 52.1698500, 85.8557300, 'RU', '2013-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122255, 'Shubenka', 'Shubenka', 'Shubenka,Shubenskoye,Shubinka,Sjubenka,Шубенка', 52.6551000, 85.0985800, 'RU', '2013-10-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122256, 'Shitkino', 'Shitkino', 'Shitka,Shitkina,Shitkino,Sjitkino,Шиткино', 56.3703000, 98.3543000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122257, 'Shirokaya Rechka', 'Shirokaya Rechka', 'Shirokaja Rechka,Shirokaya Rechka,Sjirokaja-Retsjka,Широкая Речка', 56.7985800, 60.4852200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122258, 'Shira', 'Shira', 'Chiro,Shira,Sjira,Шира', 54.4911100, 89.9530600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122259, 'Shipunovo', 'Shipunovo', 'Shipunovo,Sjipunovo,Шипуново', 52.1582000, 82.2173000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122260, 'Sherkaly', 'Sherkaly', 'Sharkaly,Sherkal''skaya,Sherkaly,Sherkal’skaya,Sjerkaly,Шеркалы', 62.7580600, 65.4752800, 'RU', '2014-05-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122261, 'Sheregesh', 'Sheregesh', 'Sheregesh,Sjeregesj,Шерегеш', 52.9209000, 87.9869000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122262, 'Sherbakul’', 'Sherbakul''', 'Sherbakul'',Sherbakul’,Sjerbakul,Шербакуль', 54.6315900, 72.3963500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122263, 'Shelabolikha', 'Shelabolikha', 'Shelabolikha,Sjelabolikha,Шелаболиха', 53.4131000, 82.6167000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122264, 'Sheberta', 'Sheberta', 'Sheberta,Shebreta,Sjeberta,Шеберта', 54.6417800, 99.8920900, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122265, 'Shebalino', 'Shebalino', 'Shebalino,Shebilano,Sjebalino,Шебалино', 51.2916700, 85.6772200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122266, 'Shchelkun', 'Shchelkun', 'Shchelkun,Shchelkunskoye,Shhelkun,Sjtsjelkun,Щелкун', 56.3033800, 60.9483100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122267, 'Shatrovo', 'Shatrovo', 'Shatrovo,Sjatrovo,Шатрово', 56.5197000, 64.6320000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122268, 'Sharypovo', 'Sharypovo', 'Charypovo,Chernenko,Gorad Sharypava,Saripovo,Sarypovo,Scharypowo,Sharipovo,Sharyp,Sharypovo,Sharypovskoye,Sjarypovo,Szarypowo,Xaripovo,Xarípovo,sha lei bo wo,sharybwfw,sharypwfw,Ŝaripovo,Šaripovo,Šarypovo,Горад Шарыпава,Шарипово,Шарып,Шарыпово,شاريبوفو,شاریپوفو,沙雷波沃', 55.5402800, 89.2008300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122269, 'Shalinskoye', 'Shalinskoye', 'Shalinskoe,Shalinskoye,Sjalinskoje,Шалинское', 55.7194000, 93.7589000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122270, 'Shakhi', 'Shakhi', 'Shakhi,Sjakhi,Шахи', 53.3361000, 83.3624000, 'RU', '2012-05-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122271, 'Shagonar', 'Shagonar', 'Sagaan-Aryg,Shagaan-Aryg,Shagak-Arig,Shagan-Aryg,Shagokar,Shagonar,Sjagonar,Šagaan-Aryg,Шагаан-Арыг,Шагонар', 51.5333300, 92.8000000, 'RU', '2016-11-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122272, 'Shadrinsk', 'Shadrinsk', 'Chadrinsk,Gorad Shadrynsk,Sadrinsk,Sadrinszk,Schadrinsk,Shadrin,Shadrins''k,Shadrinsk,Sjadrinsk,sha de lin si ke,shadrnsk,shadrnysk,shadrynsk,syadeulinseukeu,Ŝadrinsk,Šadrinsk,Șadrinsk,Горад Шадрынск,Шадрин,Шадринск,Шадринськ,شادرنسک,شادرنیسک,شادرينسك,沙德林斯克,샤드린스크', 56.0852000, 63.6335000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122273, 'Shabrovskiy', 'Shabrovskiy', 'Pereskachka,Shabrovskij,Shabrovskiy,Sjabrovskij,Шабровский', 56.6359700, 60.5806500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122274, 'Severo-Yeniseyskiy', 'Severo-Yeniseyskiy', 'Severo-Enisejskij,Severo-Jenisejskij,Severo-Yeniseiki,Severo-Yeniseysk,Severo-Yeniseyskiy,Северо-Енисейский', 60.3755200, 93.0301700, 'RU', '2013-07-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122275, 'Severnoye', 'Severnoye', 'Severnoe,Severnoje,Severnoye,Северное', 56.3491200, 78.3618900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122276, 'Severka', 'Severka', 'Severka,Северка', 56.8688000, 60.3015000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122277, 'Severka', 'Severka', 'Severka,Severnaya,Severnoye,Северка', 52.1333300, 79.2833300, 'RU', '2012-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122278, 'Serov', 'Serov', 'Gorad Sjarou,Kabakovsk,Nadezhdinsk,Serof,Serov,Serova,Serovas,Serow,Sierow,selopeu,serofu,srwf,syrwf,syrww,xie luo fu,Σερόφ,Горад Сяроў,Серов,Сєров,سروف,سيروف,سیروو,セロフ,谢罗夫,세로프', 59.6033400, 60.5787000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122279, 'Novoseleznëvo', 'Novoseleznevo', 'Novoseleznevo,Novoseleznjovo,Novoseleznëvo,Selezneva,Seleznevo,Seleznëva,Seleznëvo,Новоселезнево,Новоселезнёво', 55.6820700, 69.2056200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122280, 'Sayansk', 'Sayansk', 'Sajansk,Sajanskij,Sayansk,Sayanskiy,Саянск,Саянский', 54.1500000, 91.8850000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122281, 'Sayanogorsk', 'Sayanogorsk', 'Oznachennaya,Oznachennoye,Sajanogorsk,Sayanogorsk,Саяногорск', 53.0875000, 91.3997200, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122282, 'Saryg-Sep', 'Saryg-Sep', 'Saryg-Sep,Saryy-Sey,Saryye-Sep,Znamenka,Znamenskiy,Сарыг-Сеп', 51.4907400, 95.5608100, 'RU', '2013-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122283, 'Sargazy', 'Sargazy', 'Sargazy,Саргазы', 55.0206400, 61.2498500, 'RU', '2013-09-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122284, 'Sargatskoye', 'Sargatskoye', 'Poselkovo-Sargatskoye,Sargatka,Sargatskoe,Sargatskoje,Sargatskoye,Саргатское', 55.6100600, 73.4971600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122285, 'Saranpaul’', 'Saranpaul''', 'Saranpaul,Saranpaul'',Saranpaul’,Саранпауль', 64.2610200, 60.9023300, 'RU', '2013-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122286, 'Sannikovo', 'Sannikovo', 'Sannikova,Sannikovo,Санниково', 53.3448000, 83.9749000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122287, 'Samus’', 'Samus''', 'Samus,Samus'',Samus’,Zaton Samus''kin,Zaton Samus’kin,Самусь', 56.7448200, 84.7042200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122288, 'Samagaltay', 'Samagaltay', 'Samagalday,Samagaltaj,Samagaltay,Samgaltay,Самагалтай', 50.6022000, 95.0047000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122289, 'Salym', 'Salym', 'Kintus,Salym,Салым', 60.0625000, 71.4788900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122290, 'Salekhard', 'Salekhard', 'Gorad Salekhard,Obdor,Obdorsk,Obdorsr,SLY,Salechard,Salechardas,Salechardum,Salehard,Saleharda,Salehardo,Salejard,Salekhard,Saleĥardo,Szalehard,sa lie ha er de,salkhard,sallehaleuteu,sareharudo,slhrd,Горад Салехард,Обдор,Обдорск,Салехард,סלחרד,سالخارد,サレハルド,萨列哈尔德,살레하르트', 66.5300000, 66.6019400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122291, 'Salair', 'Salair', 'Salair,Salairskoye,Салаир', 54.2312000, 85.7972000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122292, 'Safakulevo', 'Safakulevo', 'Safakulevo,Safakulewo,Sayakulevo,Сафакулево', 54.9901000, 62.5442000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122293, 'Sovkhoznyy', 'Sovkhoznyy', 'Sadovyy,Sovkhoznyj,Sovkhoznyy,Sverdlovskiy,Совхозный', 56.7637400, 60.5493800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122294, 'Russkaya Polyana', 'Russkaya Polyana', 'Russkaja Poljana,Russkaya Polyana,Русская Поляна', 53.7794400, 73.8805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122295, 'Rudnichnyy', 'Rudnichnyy', 'Auerbach,Auerbakhovskoye,Rudnichnyj,Rudnichnyy,Rudniki,Rudnitsjnyj,Рудничный', 59.7011800, 60.2881700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122296, 'Rudnichnyy', 'Rudnichnyy', 'Rudnichnyj,Rudnichnyy,Рудничный', 56.0846900, 86.2498800, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122297, 'Rubtsovsk', 'Rubtsovsk', 'Gorad Rubcousk,Roebtsovsk,Roubtsovsk,Rubcovs''k,Rubcovsk,Rubcovska,Rubcovskas,Rubcowsk,Rubtovsk,Rubtsovsk,Rubzowsk,Rubțovsk,Rupcovsk,Rustovsk,lu bu zuo fu si ke,lubchobseukeu,ruputsu~ofusuku,rwbtswfsk,rwbtswwsk,Горад Рубцоўск,Рубцовск,Рубцовськ,Рупцовск,روبتسوفسك,روبتسوفسک,روبتسووسک,ルプツォフスク,魯布佐夫斯克,룹촙스크', 51.5147300, 81.2061300, 'RU', '2013-11-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122298, 'Roza', 'Roza', 'Rosa,Roza,Роза', 54.9163000, 61.4586000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122299, 'Rostovka', 'Rostovka', 'Rostovka,Ростовка', 55.3842000, 71.8891300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122300, 'Romanovo', 'Romanovo', 'Romanovka,Romanovo,Romanovskiy,Romanovskoye,Романово', 52.6182000, 81.2271000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122301, 'Rodino', 'Rodino', 'Rodino,Родино', 52.4978300, 80.2029400, 'RU', '2013-07-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122302, 'Rezh', 'Rezh', 'Rezh,Rezj,Реж', 57.3700500, 61.4042800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122303, 'Reftinskiy', 'Reftinskiy', 'Reftinskij,Reftinskiy,Рефтинский', 57.0901300, 61.6769200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122304, 'Rebrikha', 'Rebrikha', 'Rebrikha,Ребриха', 53.0733300, 82.3408300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122305, 'Razdolinsk', 'Razdolinsk', 'Razdol''stroy,Razdolinsk,Razdol’stroy,Раздолинск', 58.4211100, 94.6658300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122306, 'Rassvet', 'Rassvet', 'Rassvet,Spasovka,Рассвет', 56.9990000, 91.4724000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122307, 'Pyshma', 'Pyshma', 'Pyshma,Pysjma,Пышма', 56.9522600, 63.2512900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122308, 'Prosvet', 'Prosvet', 'Prosvet,Просвет', 55.5702800, 65.0825000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122309, 'Promyshlennyy', 'Promyshlennyy', 'Promyshlennyj,Promyshlennyy,Promyshlenyy,Promysjlennyj,Промышленный', 67.5833300, 63.9166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122310, 'Promyshlennovskiy', 'Promyshlennovskiy', 'Bol''shaya Promyshlenka,Bol''she-Promyshlenka'',Bol’shaya Promyshlenka,Bol’she-Promyshlenka’,Promyshlennovskij,Promyshlennovskiy,Promysjlennovskij,Промышленновский', 55.4833300, 86.2000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122311, 'Promyshlennaya', 'Promyshlennaya', 'Promyshlennaja,Promyshlennaya,Promysjlennaja,Промышленная', 54.9159000, 85.6385000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122312, 'Prokudskoye', 'Prokudskoye', 'Prokudskoe,Prokudskoje,Prokudskoye,Прокудское', 55.0089000, 82.4574000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122313, 'Prokop’yevsk', 'Prokop''yevsk', 'Prokop''evsk,Prokop''yevo,Prokop''yevsk,Prokop''yevskiy,Prokopjevsk,Prokopyevsk,Prokop’yevo,Prokop’yevsk,Prokop’yevskiy,Prokoyevsk,Прокопьевск', 53.9059000, 86.7190000, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122314, 'Pritomskiy', 'Pritomskiy', 'Pritomskij,Pritomskiy,Притомский', 53.7724000, 87.6082000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122315, 'Priiskovyy', 'Priiskovyy', 'Andreyevskiy,Priiskovy,Priiskovyj,Priiskovyy,Приисковый', 54.6561100, 88.6872200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122316, 'Predivinsk', 'Predivinsk', 'Predivinsk,Предивинск', 57.0631000, 93.4374000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122317, 'Poykovskiy', 'Poykovskiy', 'Pojkovskij,Poykovskiy,Пойковский', 61.2333300, 73.3333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122318, 'Potanino', 'Potanino', 'Potanino,Потанино', 55.1786000, 61.6222000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122319, 'Pospelikha', 'Pospelikha', 'Pospelikha,Поспелиха', 51.9500000, 81.7666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122320, 'Polysayevo', 'Polysayevo', 'Polysaevo,Polysajevo,Polysayeva,Polysayevo,Полысаево', 54.6012000, 86.2459000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122321, 'Polunochnoye', 'Polunochnoye', 'Polunochnaya,Polunochnoe,Polunochnoye,Polunotsjnoje,Polynochye,Полуночное', 60.8697200, 60.4152800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122322, 'Poltavka', 'Poltavka', 'Poltavka,Полтавка', 54.3662900, 71.7631900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122323, 'Polovinnoye', 'Polovinnoye', 'Polovinnoe,Polovinnoje,Polovinnoye,Половинное', 54.7913900, 65.9863900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122324, 'Polovinnoye', 'Polovinnoye', 'Polovinnaya,Polovinnoe,Polovinnoje,Polovinnoye,Половинное', 53.7567100, 79.2432700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122325, 'Polevskoy', 'Polevskoy', 'Polevskoj,Polevskoy,Tolevskoy,Полевской', 56.4422200, 60.1877800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122326, 'Poletayevo', 'Poletayevo', 'Poletaevo,Poletajevo,Poletayevo,Poletayevo Pervoye,Полетаево', 55.0336000, 61.1138000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122327, 'Pokrovskoye', 'Pokrovskoye', 'Pokrovskoe,Pokrovskoje,Pokrovskoye,Покровское', 56.4704000, 61.6092000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122328, 'Podsosnovo', 'Podsosnovo', 'Podsosnovo,Подсосново', 53.3721000, 78.9184000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122329, 'Podsineye', 'Podsineye', 'Podsinee,Podsineje,Podsineye,Podsinyaya,Подсинее', 53.6658300, 91.5363900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122330, 'Podgornoye', 'Podgornoye', 'Podgornoe,Podgornoje,Podgornoye,Подгорное', 57.7886100, 82.6519400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122331, 'Plast', 'Plast', 'Gorad Plast,Plast,Plast i Russland,blast,plast,pu la si te,Горад Пласт,Пласт,بلاست,پلاست,普拉斯特', 54.3691400, 60.8136100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122332, 'Pirovskoye', 'Pirovskoye', 'Pirovsk,Pirovskoe,Pirovskoje,Pirovskoye,Пировское', 57.6301200, 92.2637300, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122333, 'Pionerskiy', 'Pionerskiy', 'Pionerskij,Pionerskiy,Пионерский', 61.1947200, 62.8688900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122334, 'Pioner', 'Pioner', 'Pioner,Пионер', 55.3166000, 85.9508000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122335, 'Petukhovo', 'Petukhovo', 'Petukhovo,Yudino,Петухово', 55.0691700, 67.9019400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122336, 'Petropavlovskoye', 'Petropavlovskoye', 'Petropavlovskoe,Petropavlovskoje,Petropavlovskoye,Петропавловское', 52.0712000, 84.1070000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122337, 'Petrokamenskoye', 'Petrokamenskoye', 'Petrokamenskoe,Petrokamenskoje,Petrokamenskoye,Петрокаменское', 57.7160000, 60.6484000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122338, 'Pervomayskoye', 'Pervomayskoye', 'Pervomajskoe,Pervomajskoje,Pervomayskoye,Pyshkino-Troitskoye,Первомайское', 57.0761000, 86.2313000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122339, 'Pervomayskoye', 'Pervomayskoye', 'Pervomajskoe,Pervomajskoje,Pervomayskoye,Sredne-Krayushkino,Первомайское', 53.7211100, 84.0183300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122340, 'Pervomayskiy', 'Pervomayskiy', 'Pervomajskij,Pervomayskiy,Pervomayskoye,Первомайский', 52.9173000, 81.6624000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122341, 'Pelym', 'Pelym', 'Pelym,Пелым', 61.0108300, 61.9977800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122342, 'Pavlovsk', 'Pavlovsk', 'Pavlovsk,Pavlovskoye,Павловск', 53.3186100, 82.9822200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122343, 'Pavlogradka', 'Pavlogradka', 'Pavlodarka,Pavlogradka,Pavlogradskoye,Павлоградка', 54.2024000, 73.5592000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122344, 'Partizanskoye', 'Partizanskoye', 'Partizanskoe,Partizanskoje,Partizanskoye,Perovo,Партизанское', 55.4972000, 94.3922000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122345, 'Parizh', 'Parizh', 'Parizh,Parizhskiy,Parizj,Париж', 53.2974000, 60.1005000, 'RU', '2012-08-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122346, 'Parabel’', 'Parabel''', 'Parabel,Parabel'',Parabel’,Парабель', 58.6977800, 81.4825000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122347, 'Pankrushikha', 'Pankrushikha', 'Pankrushikha,Pankrusjikha,Панкрушиха', 53.8319400, 80.3405600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122348, 'Pangody', 'Pangody', 'Pangody,Пангоды', 65.8500200, 74.4859300, 'RU', '2009-12-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122349, 'Ovsyanka', 'Ovsyanka', 'Ovsianka,Ovsjanka,Ovsyanka,Овсянка', 55.9583000, 92.5720000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122350, 'Ous', 'Ous', 'Ous,Оус', 60.9058300, 61.5186100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122351, 'Osinniki', 'Osinniki', 'Gorad Asinniki,Osiniki,Osinniki,Ossinniki,ao xin ni ji,awsynyky,Горад Асіннікі,Осиники,Осинники,أوسينيكي,اوسینیکی,奧辛尼基', 53.6239000, 87.3598000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122352, 'Orlik', 'Orlik', 'Orlik,Орлик', 52.5178000, 99.8250000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122353, 'Ordynskoye', 'Ordynskoye', 'Ordiinskoe,Ordinskoe,Ordinskoje,Ordynskoe,Ordynskoje,Ordynskoye,Ордынское', 54.3656000, 81.8994000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122354, 'Onokhino', 'Onokhino', 'Onokhina,Onokhino,Онохино', 56.9250100, 65.5394000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122355, 'Onguday', 'Onguday', 'Ongudaj,Onguday,Онгудай', 50.7500000, 86.1500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122356, 'Omutinskiy', 'Omutinskiy', 'Omutinskij,Omutinskiy,Omutinskoe,Omutinskoye,Omutinsnoye,Омутинский,Омутинское', 56.4745300, 67.6708700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122357, 'Omsk', 'Omsk', 'Gorad Omsk,OMS,Om''sku,Omby,Omium,Oms''k,Omsc,Omsk,Omska,Omskas,Omszk,Omva,amsk,awmsk,e mu si ke,omseukeu,omska,omusuku,xxm skh,Ομσκ,Горад Омск,Омбы,Омва,Омск,Омськ,Омьскъ,Օմսկ,אומסק,أومسك,امسک,اومسک,ओम्स्क,ออมสค์,ომსკი,オムスク,鄂木斯克,옴스크', 54.9924400, 73.3685900, 'RU', '2013-05-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122358, 'Okoneshnikovo', 'Okoneshnikovo', 'Okoneshnikovo,Okoneshninovo,Okonesjnikovo,Оконешниково', 54.8376700, 75.0834300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122359, 'Odesskoye', 'Odesskoye', 'Odesskoe,Odesskoje,Odesskoye,Одесское', 54.2150000, 72.9651000, 'RU', '2013-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122360, 'Obukhovskoye', 'Obukhovskoye', 'Obukhovskoe,Obukhovskoye,Obuxovskoje,Обуховское', 56.8345000, 62.6120000, 'RU', '2012-07-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122361, 'Ob’', 'Ob''', 'Ob,Ob'',Ob’,Обь', 54.9872000, 82.7166000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122362, 'Nyda', 'Nyda', 'Nyda,Ныда', 66.6247200, 72.9227800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122363, 'Nyagan', 'Nyagan', 'NYA,Nagin,Njagan,Njagan'',Nyagan,Nyakh,Nyakhyn'',Nyakhyn’,Yurty Nyagin,Нягань', 62.1405600, 65.3936100, 'RU', '2013-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122364, 'Noyabrsk', 'Noyabrsk', 'NOJ,Nojabr''sk,Noyabrsk,Ноябрьск', 63.1930900, 75.4372800, 'RU', '2013-12-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122365, 'Novyy Urengoy', 'Novyy Urengoy', 'NUX,Noviy Urengoi,Novy Urengoy,Novyj Urengoj,Novyy Urengoy,Новый Уренгой', 66.0833300, 76.6333300, 'RU', '2014-03-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122366, 'Novaya Zaimka', 'Novaya Zaimka', 'Nov.Zaimka,Novaja Zaimka,Novaya Zaimka,Novozaimka,Нов.Заимка,Новая Заимка', 56.4857100, 66.9241300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122367, 'Novovarshavka', 'Novovarshavka', 'Novovarshavka,Novovarsjavka,Нововаршавка', 54.1721000, 74.6946000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122368, 'Novotyryshkino', 'Novotyryshkino', 'Novotyryshkino,Novotyrysjkino,Novoye Tyryshkino,Новотырышкино', 52.0833000, 84.9089000, 'RU', '2013-09-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122369, 'Novosineglazovskiy', 'Novosineglazovskiy', 'Novosineglazovskij,Novosineglazovskiy,Sineglazovo,Новосинеглазовский', 55.0392800, 61.3768000, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122370, 'Novosilikatnyy', 'Novosilikatnyy', 'Novosilikatnyj,Novosilikatnyy,Новосиликатный', 53.3097200, 83.6238900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122371, 'Novosibirsk', 'Novosibirsk', 'Cen Ceper,Gorad Novasibirsk,Nobosimpirsk,Novo-Nikolaevsk,Novo-Nikolaievsk,Novo-Nikolaïevsk,Novonikolaevsk,Novonikolayevsk,Novosibir,Novosibir''sku,Novosibirs''k,Novosibirscum,Novosibirsk,Novosibirska,Novosibirskaj,Novosibirskas,Novosibirsko,Novosimpirsk,Novossibirsk,Novoszibirszk,Nowosibirsk,Nowosibirski,Nowosybirsk,OVB,Odsibiren'' osh,Vil'' Sibirkar,no wo sibiskh,nobosibileuseukeu,novosibirsk,novosibirska,novu~oshibirusuku,nwbwsybyrsq,nwfwsybyrsk,nwwsybrsk,nwwsybyrsk,xin xi bo li ya,Çĕн Çĕпĕр,Νοβοσιμπίρσκ,Νοβοσιμπιρσκ,Виль Сибиркар,Горад Новасібірск,Новониколаевск,Новосибирск,Новосибирскай,Новосибирьскъ,Новосибірськ,Новосібір,Одсибирень ош,Նովոսիբիրսկ,נובוסיבירסק,نوفوسيبيرسك,نووسیبرسک,نووسیبیرسک,नोवोसिबिर्स्क,โนโวซีบีสค์,ნოვოსიბირსკი,ノヴォシビルスク,新西伯利亚,新西伯利亞,노보시비르스크', 55.0415000, 82.9346000, 'RU', '2015-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122372, 'Novopesterevo', 'Novopesterevo', 'Novopesterevo,Novopesterovo,Pesterevskoye,Новопестерево', 54.4429000, 85.7401000, 'RU', '2014-12-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122373, 'Novoomskiy', 'Novoomskiy', 'Novoomskij,Novoomskiy,Новоомский', 54.8415200, 73.3017400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122374, 'Novolugovoye', 'Novolugovoye', 'Novaya Lugovaya,Novolugovoe,Novolugovoje,Novolugovoye,Novolugovskoye,Новолуговое', 54.9792000, 83.1138000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122375, 'Novokuznetsk', 'Novokuznetsk', 'Cusnezia,Gorad Navakuzneck,Kuvnetsk,Kuznetsk,Kuznetsk-Sibirskiy,NOZ,Novokoeznetsk,Novokouznetsk,Novokusnetsk,Novokuznec''k,Novokuzneck,Novokuznecka,Novokuzneckas,Novokuznetk,Novokuznetsk,Novokuznețk,Novokuznjeck,Novokuznyeck,Novokuzněck,Novokuzņecka,Nowokoeznetsk,Nowokusnezk,Nowokuznieck,Nowokuźnieck,Stalinsk,nobokujeunecheukeu,novu~okuzunetsuku,nwbwqwznzq,nwfwkwzntsk,nwwkwzntsk,xin ku ci nie ci ke,Νοβοκουζνέτσκ,Горад Навакузнецк,Новокузнетск,Новокузнецк,Новокузнецьк,Новокузњецк,Сталинск,נובוקוזנצק,نوفوكوزنتسك,نووکوزنتسک,نووکوزنٹسک,ノヴォクズネツク,新库兹涅茨克,노보쿠즈네츠크', 53.7557000, 87.1099000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122376, 'Novogornyy', 'Novogornyy', 'Novogornyj,Novogornyy,Новогорный', 55.6300000, 60.7919000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122377, 'Novochernorechenskiy', 'Novochernorechenskiy', 'Novochernorechenskij,Novochernorechenskiy,Novochernorechenskoye,Novotsjernoretsjenskij,Новочернореченский', 56.2665800, 91.0923400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122378, 'Novobiryusinskiy', 'Novobiryusinskiy', 'Novobirjusinskij,Novobiryusinskaya,Novobiryusinskiy,Новобирюсинский', 56.9578000, 97.7076000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122379, 'Novoasbest', 'Novoasbest', 'Krasnoural''skiy Rudnik,Krasnoural’skiy Rudnik,Novoasbest,Novoazbest,Новоасбест', 57.7422500, 60.2877300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122380, 'Novoaltaysk', 'Novoaltaysk', 'Chesnokovka,Chesnokovo,Chesnokovskoye,Novoaltajsk,Novoaltaysk,noboaltaiseukeu,Новоалтайск,노보알타이스크', 53.3917000, 83.9363000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122381, 'Novoagansk', 'Novoagansk', 'Novoagansk,Новоаганск', 61.9449000, 76.6625000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122382, 'Novikovo', 'Novikovo', 'Novikovo,Новиково', 52.6223100, 85.9639200, 'RU', '2013-09-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122383, 'Novichikha', 'Novichikha', 'Novichikha,Novitsjikha,Новичиха', 52.2040000, 81.3877000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122384, 'Novaya Lyalya', 'Novaya Lyalya', 'Novaja Ljalja,Novaya Lyalya,Новая Ляля', 59.0550300, 60.5989900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122385, 'Norilsk', 'Norilsk', 'Gorad Naryl''sk,Noril''s''k,Noril''sk,Noriljsk,Norilsk,Norilska,Norilskas,Norilsko,Norilskoe,Norilszk,Noril’sk,Noriļska,Noriľsk,Norylsk,nolilseukeu,noririsuku,nuo li er si ke,nwrlsk,nwrylsk,nwrylsq,Горад Нарыльск,Норилск,Норильск,Норильськ,Нориљск,נורילסק,نورلسک,نوريلسك,نوریلسک,ノリリスク,諾里爾斯克,노릴스크', 69.3535000, 88.2027000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122386, 'Nizhnyaya Tavda', 'Nizhnyaya Tavda', 'Nizhnjaja Tavda,Nizhnyaya Tavda,Nizjnjaja Tavda,Tavdinskoe,Tavdinskoye,Нижняя Тавда', 57.6730600, 66.1725000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122387, 'Souzga', 'Souzga', 'Nizhnyaya Souzga,Nizhnyaya Suuzga,Souzga,Соузга', 51.8872200, 85.8494400, 'RU', '2014-01-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122388, 'Nizhnyaya Salda', 'Nizhnyaya Salda', 'Nizhnjaja Salda,Nizhnyaya Salda,Nizjnjaja Salda,Salda,Нижняя Салда', 58.0775600, 60.7202000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122389, 'Nizhnyaya Poyma', 'Nizhnyaya Poyma', 'Nizhnjaja Pojma,Nizhnyaya Poyma,Nizjnjaja Pojma,Нижняя Пойма', 56.1643000, 97.2065000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122390, 'Nizhnyaya Omka', 'Nizhnyaya Omka', 'Nizhne-Omka,Nizhnjaja Omka,Nizhnyaya Omka,Nizhnyaya Omskaya,Нижняя Омка', 55.4337500, 74.9425600, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122391, 'Nizhniy Ingash', 'Nizhniy Ingash', 'Nizh.Ingash,Nizhnij Ingash,Nizhniy Ingash,Ниж.Ингаш,Нижний Ингаш', 56.2003000, 96.5373000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122392, 'Nizhnevartovsk', 'Nizhnevartovsk', 'Gorad Nizhnjavartausk,NJC,Nijnevartovsk,Nischnewartowsk,Nizhn''ovartovs''k,Nizhne-Vartovskaya,Nizhne-Vartovskoye,Nizhnevartovsk,Nizhnevartovskiy,Nizhnevártovsk,Nizjnevartovsk,Niznevartovsk,Niznevartovska,Niznevartovskas,Nizniewartowsk,Niĵnevartovsk,Niżniewartowsk,Nižnevartovsk,Nižnevartovskas,nijeunebaleutobseukeu,nijinevu~arutofusuku,nyjnfartwfsk,nyzhnwartwfsk,nyzhnywartwwsk,xia wa er tuo fu si ke,Ņižņevartovska,Горад Ніжнявартаўск,Нижневартовск,Нижньовартовськ,Нижњевартовск,Түбән Варта,نيجنفارتوفسك,نیژنوارتوفسک,نیژنیوارتووسک,ニジネヴァルトフスク,下瓦爾托夫斯克,니즈네바르톱스크', 60.9344000, 76.5531000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122393, 'Nizhneudinsk', 'Nizhneudinsk', 'Gorad Nizhneudzinsk,Nijneoudinsk,Nijneudinsk,Nischneudinsk,Nizhneudinsk,Nizhneúdinsk,Nizjneudinsk,Nizneudinsk,Niznieudinsk,Niĵneudinsk,Niżnieudinsk,Nižneudinsk,Nižněudinsk,Nyizsnyeugyinszk,nijeune-udinseukeu,nyjnywdysk,nyzhnywdynsk,xia wu jin si ke,Горад Ніжнеудзінск,Нижнеудинск,نيجنيوديسك,نیژنئودینسک,下烏金斯克,니즈네우딘스크', 54.9076000, 99.0276000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122394, 'Nikolo-Pavlovskoye', 'Nikolo-Pavlovskoye', 'Nikola Pazlovsky,Nikolo-Pavlovskoe,Nikolo-Pavlovskoje,Nikolo-Pavlovskoye,Николо-Павловское', 57.7830600, 60.0577800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122395, 'Nikolayevka', 'Nikolayevka', 'Nikolaevka,Nikolayevka,Николаевка', 51.9255600, 79.4158300, 'RU', '2012-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122396, 'Nikitinskiy', 'Nikitinskiy', 'Nikitinskij,Nikitinskiy,Никитинский', 54.5845000, 86.0115000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122397, 'Neyvo-Shaytanskiy', 'Neyvo-Shaytanskiy', 'Nejvo-Shajtanskij,Nejvo-Sjajtanskij,Neyvo-Shaytanskiy,Нейво-Шайтанский', 57.7286000, 61.2495600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122398, 'Neyvo-Rudyanka', 'Neyvo-Rudyanka', 'Nejvo-Rudjanka,Neyvo-Rudyanka,Нейво-Рудянка', 57.3444000, 60.1343000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122399, 'Nev’yansk', 'Nev''yansk', 'Nev''jansk,Nev''yansk,Nevjansk,Nev’yansk,Невьянск', 57.4953000, 60.2112000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122400, 'Gal’bshtadt', 'Gal''bshtadt', 'Gal''bshtadt,Gal’bshtadt,Gol''bshtadt,Gol’bshtadt,Nekrasovo,Гальбштадт,Некрасово', 53.2264000, 78.9845000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122401, 'Nefteyugansk', 'Nefteyugansk', 'NFG,Neftejugansk,Nefteyugansk,Нефтеюганск', 61.0997900, 72.6034900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122402, 'Nazyvayevsk', 'Nazyvayevsk', 'Gorad Nazyvaeusk,Nasywajewsk,Nazivaevsk,Nazivajevsk,Nazyvaevsk,Nazyvaievsk,Nazyvajevsk,Nazyvayevsk,Nazyvayevskaya,Nazyvaïevsk,Nazywajewsk,Novonazyvayevka,Novonazyvayevskoye,na ji wa ye fu si ke,najibayepeuseukeu,nazwayfsk,nazyfayfsk,Горад Называеўск,Називаевск,Називајевск,Называевск,نازوایفسک,نازيفايفسك,納濟瓦耶夫斯克,나지바예프스크', 55.5697500, 71.3529400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122403, 'Nazarovo', 'Nazarovo', 'Gorad Nazarava,Nasarowo,Nazarovo,Nazarowo,Nazàrovo,na zha luo wo,nazarwfw,nazarwfw  krasnwyarsk,Горад Назарава,Назарово,نازاروفو,نازاروفو، کراسنویارسک,納扎羅沃', 56.0104000, 90.4011000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122404, 'Nauchnyy Gorodok', 'Nauchnyy Gorodok', 'Nauchnyj Gorodok,Nauchnyy Gorodok,Nautsjnyj-Gorodok,Научный Городок', 53.4203000, 83.5210000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122405, 'Nalobikha', 'Nalobikha', 'Nalobikha,Налобиха', 53.2005600, 84.6038900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122406, 'Nagornyy', 'Nagornyy', 'Nagornyj,Nagornyy,Нагорный', 52.7959000, 83.5498000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122407, 'Nadym', 'Nadym', 'Faktoriya Nadym,Gorad Nadym,NYM,Nadim,Nadom,Nadym,Nadymas,Nadõm,na de mu,nadym,Горад Надым,Надим,Надым,ناديم,نادیم,納德姆', 65.5333300, 72.5166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122408, 'Myski', 'Myski', 'Gorad Myski,Miski,Moski,Myski,Mõski,Tomazak,mei si ji,mysky,Горад Мыскі,Миски,Мыски,ميسكي,میسکی,梅斯基', 53.7090000, 87.8014000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122409, 'Muzhi', 'Muzhi', 'Muzhi,Muzji,Мужи', 65.4003000, 64.7027800, 'RU', '2013-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122410, 'Muslyumovo', 'Muslyumovo', 'Musljumovo,Muslyumova,Muslyumovo,Муслюмово', 55.6133000, 61.6260000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122411, 'Muromtsevo', 'Muromtsevo', 'Muromcevo,Muromtsevo,Муромцево', 56.3723800, 75.2417500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122412, 'Mundybash', 'Mundybash', 'Mundybash,Mundybasj,Мундыбаш', 53.2110000, 87.2983000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122413, 'Mugur-Aksy', 'Mugur-Aksy', 'Mugur-Aksy,Мугур-Аксы', 50.3807200, 90.4373900, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122414, 'Motygino', 'Motygino', 'Motygina,Motygino,Мотыгино', 58.1840100, 94.6933900, 'RU', '2013-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122415, 'Moskovskiy', 'Moskovskiy', 'Moskovskij,Moskovskiy,Московский', 57.1110800, 65.4229800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122416, 'Moshkovo', 'Moshkovo', 'Moschkowo,Moshkovo,Мошково', 55.3053000, 83.6104000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122417, 'Moryakovskiy Zaton', 'Moryakovskiy Zaton', 'Morjakovskij Zaton,Moryakovka,Moryakovskiy Zaton,Моряковский Затон', 56.6944800, 84.6514500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122418, 'Mortka', 'Mortka', 'Mortka,Мортка', 59.3322200, 66.0213900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122419, 'Monetnyy', 'Monetnyy', 'Monetnaya,Monetny,Monetnyj,Monetnyy,Монетный', 57.0472000, 60.8794000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122420, 'Molchanovo', 'Molchanovo', 'Molchanovo,Moltsjanovo,Молчаново', 57.5816700, 83.7691700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122421, 'Mokrousovo', 'Mokrousovo', 'Mokrousovo,Мокроусово', 55.8102800, 66.7652800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122422, 'Mochishche', 'Mochishche', 'Mochishche,Mochishhe,Motsjisjtsje,Мочище', 55.1586000, 83.1229000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122423, 'Mishkino', 'Mishkino', 'Mischkino,Mishkino,Misjkino,Мишкино', 55.3388900, 63.9175000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122424, 'Minusinsk', 'Minusinsk', 'Gorad Minusinsk,Minoesinsk,Minoussinsk,Minusinka,Minusins''k,Minusinsk,Minusinskas,Minusinsko,Minusińsk,Minussinsk,mi nu xin si ke,minushinsuku,minusinaska,minusinseukeu,mynwsnsk,mynwsynsk,Горад Мінусінск,Минусинск,Мінусинськ,مينوسينسك,مینوسنسک,مینوسینسک,মিনুসিনস্ক,ミヌシンスク,米努辛斯克,미누신스크', 53.7102800, 91.6875000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122425, 'Mikhaylovskoye', 'Mikhaylovskoye', 'Mikhajlovskij,Mikhajlovskoe,Mikhaylovka,Mikhaylovskiy,Mikhaylovskoye,Михайловский,Михайловское', 51.8238900, 79.7172200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122426, 'Miasskoye', 'Miasskoye', 'Miasskiy,Miasskoe,Miasskoje,Miasskoye,Миасское', 55.2784000, 61.8905000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122427, 'Miass', 'Miass', 'Gorad Mias,Mias,Miasa,Miasas,Miass,Miassz,Mijas,mi a si,miaseu,miasu,myas,Горад Міас,Мейәс,Миас,Миасс,Мияс,Мијас,Міас,مياس,میاس,ミアス,米阿斯,미아스', 55.0450000, 60.1083300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122428, 'Mezhdurechenskiy', 'Mezhdurechenskiy', 'Mezhdurechenskij,Mezhdurechenskiy,Mezjduretsjenskij,Междуреченский', 59.6000000, 65.9333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122429, 'Mezhdurechensk', 'Mezhdurechensk', 'Gorad Mezhdurehchansk,Mejdouretchensk,Mejdurecensk,Mejdurechensk,Mejduretxensk,Mejdurétxensk,Meschduretschensk,Mezdurecensk,Mezdurecenska,Mezdurecenskas,Mezduretsensk,Mezhdurechens''k,Mezhdurechensk,Mezhduréchensk,Mezjdoeretsjensk,Mezjduretjensk,Mezjduretsjensk,Mezjduretsjensk i Kemerovo oblast,Meĵdureĉensk,Mežduretšensk,Meždurečensk,Meždurečenska,Meždurečenskas,Miezdurieczensk,Mieżdurieczensk,Ol''zheras,Ol’zheras,mei ri du lie qin si ke,mejeudulechenseukeu,mejudo~urechensuku,myjdwrychynsk,myjdwrytshynsk,mzhdwrchnsk  awblast kmrww,Горад Междурэчанск,Междуреченск,Мєждурєченськ,ميجدوريتشينسك,مژدورچنسک، اوبلاست کمروو,میجدوریچینسک,メジュドゥレチェンスク,梅日杜列琴斯克,메즈두레첸스크', 53.6941700, 88.0602800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122430, 'Mendeleyevo', 'Mendeleyevo', 'Mendeleevo,Mendeleyevo,Менделеево', 58.1666700, 68.3000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122431, 'Mel’nikovo', 'Mel''nikovo', 'Mel''nikova,Mel''nikovo,Melnikovo,Mel’nikova,Mel’nikovo,Мельниково', 56.5573800, 84.0835000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122432, 'Melioratorov', 'Melioratorov', 'Melioratorov,Мелиораторов', 57.2106500, 65.6077400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122433, 'Megion', 'Megion', 'Gorad Megijon,Maron,Mayon,Megion,Megiono,Meguion,Meqion,Miegion,Mjegion,megion,mei ji weng,mgywn,myjwn,Горад Мегіён,Мегион,ميجون,مگیون,メギオン,梅吉翁,메기온', 61.0296000, 76.1136000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122434, 'Mayna', 'Mayna', 'Majna,Mayna,Майна', 53.0063900, 91.4836100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122435, 'Mayma', 'Mayma', 'Majma,Mayma,Mayma-Chergachak,Майма', 52.0157700, 85.9096300, 'RU', '2015-06-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122436, 'Maslyanino', 'Maslyanino', 'Masljanino,Maslyanino,Maslyannino,Маслянино', 54.3436100, 84.2111100, 'RU', '2013-07-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122437, 'Martyush', 'Martyush', 'Martjush,Martjusj,Martyush,Мартюш', 56.4000000, 61.8819400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122438, 'Martynovo', 'Martynovo', 'Martynovo,Martynovskoye,Мартыново', 53.2666700, 85.8833300, 'RU', '2013-08-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122439, 'Mariinsk', 'Mariinsk', 'Gorad Maryinsk,Mariins''k,Mariinsk,ma lin si ke,malinseukeu,maryansk,marynsk,Горад Марыінск,Мариинск,Маріїнськ,ماريانسك,مارینسک,მარიინსკი,馬林斯克,마린스크', 56.2138900, 87.7472200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122440, 'Manzya', 'Manzya', 'Manza,Manzia,Manzja,Manzya,Манзя', 58.4922200, 96.2616700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122441, 'Manzherok', 'Manzherok', 'Manzherok,Manzjerok,Манжерок', 51.8286100, 85.7672200, 'RU', '2012-11-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122442, 'Mamontovo', 'Mamontovo', 'Mamontovo,Мамонтово', 52.7055000, 81.6244000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122443, 'Malysheva', 'Malysheva', 'Imeni Malysheva,Malysheva,Malysjeva,Малышева', 57.1185100, 61.4034500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122444, 'Malougrenevo', 'Malougrenevo', '', 52.5568000, 85.3390800, 'RU', '2013-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122445, 'Malinovoye Ozero', 'Malinovoye Ozero', 'Malinovoe Ozero,Malinovoje Ozero,Malinovoye Ozero,Mikhaylovskiy,Малиновое Озеро', 51.6752800, 79.7825000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122446, 'Makushino', 'Makushino', 'Makuschino,Makushino,Makusjino,Макушино', 55.2102800, 67.2441700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122447, 'Lyubinskiy', 'Lyubinskiy', 'Ljubinskij,Lyubino,Lyubinskiy,Novo-Lyubino,Любинский', 55.1542100, 72.6924700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122448, 'Luzino', 'Luzino', 'Luzino,Luzinskiy,Лузино', 54.9481100, 73.0353100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122449, 'Lugovskoy', 'Lugovskoy', 'Lugovskoj,Lugovskoy,Pyshma,Луговской', 56.9584900, 64.5289700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122450, 'Losinyy', 'Losinyy', 'Losinyj,Losinyy,Лосиный', 57.1386200, 61.0666300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122451, 'Lokosovo', 'Lokosovo', 'Lokosovo,Локосово', 61.1333300, 74.8166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122452, 'Lobva', 'Lobva', 'Lobva,Лобва', 59.1853800, 60.5184600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122453, 'Listvyanskiy', 'Listvyanskiy', 'Listvjanskij,Listvyanka,Listvyanskiy,Листвянский', 54.4399000, 83.4984000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122454, 'Listvyagi', 'Listvyagi', 'Listvjagi,Listvyagi,Листвяги', 53.6772000, 86.9510000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122455, 'Linëvo', 'Linevo', 'Linevo,Linjovo,Linëvo,Линево,Линёво', 54.4589000, 83.3764000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122456, 'Lesosibirsk', 'Lesosibirsk', 'Gorad Lesasibirsk,Lesosibirsk,Lesosibirskas,Lessosibirsk,Lessossibirsk,Maklakova,Maklakovo,Novomaklakovo,lie suo xi bi er si ke,lswsybyrsk,lyswsybyrsk,Горад Лесасібірск,Лесосибирск,Новомаклаково,لسوسيبيرسك,لسوسیبیرسک,لیسوسیبیرسک,列索西比爾斯克', 58.2358300, 92.4827800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122457, 'Lesogorsk', 'Lesogorsk', 'Lesogorsk,Лесогорск', 56.0458000, 99.5136000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122458, 'Lesnoye', 'Lesnoye', 'Lesnoe,Lesnoje,Lesnoye,Лесное', 52.4692600, 85.2554700, 'RU', '2013-11-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122459, 'Lesnikovo', 'Lesnikovo', 'Lesnikovo,Лесниково', 55.2822200, 65.3175000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122460, 'Leninsk-Kuznetsky', 'Leninsk-Kuznetsky', 'Gorad Leninsk-Kuznecki,Kuznecko Leninskas,Leninsk Kuznecki,Leninsk Kuznetski,Leninsk Kuzniecki,Leninsk-Koeznetski,Leninsk-Kouznetski,Leninsk-Kusnezki,Leninsk-Kuzneckij,Leninsk-Kuznetki,Leninsk-Kuznetsk,Leninsk-Kuznetski,Leninsk-Kuznetskij,Leninsk-Kuznetskiy,Leninsk-Kuznetsky,Leninsk-Kuznețki,Leninska-Kuznecka,Lenińsk Kuźniecki,Léninsk-Kuznetski,lie ning si ke-ku zi nie ci ji,lnynsk-kwzntsky,lnynsk-kwzntskyy,lynnsk kwznytsky,Ļeņinska-Kuzņecka,Горад Ленінск-Кузнецкі,Ленинск-Кузнецкий,Лењинск Кузњецки,لنينسك-كوزنتسكي,لنینسک-کوزنتسکیی,لیننسک کوزنیتسکی,列寧斯克-庫茲涅茨基', 54.6567000, 86.1737000, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122461, 'Lebyazh’ye', 'Lebyazh''ye', 'Lebjazh''e,Lebjazje,Lebyazh''ye,Lebyazh''ye Vtoroye,Lebyazh’ye,Lebyazh’ye Vtoroye,Лебяжье', 55.2688900, 66.4947200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122462, 'Lebyazh’ye', 'Lebyazh''ye', 'Lebjazh''e,Lebjazje,Lebyazh''ya,Lebyazh''ye,Lebyazh’ya,Lebyazh’ye,Лебяжье', 53.2436100, 83.6533300, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122463, 'Labytnangi', 'Labytnangi', 'Gorad Labytnangi,Labitnangi,Labotnangi,Labytnangi,Labytnangis,Labytnangui,Labõtnangi,la bei te nan ji,labytnanghy,labytnangy,Горад Лабытнангі,Лабитнанги,Лабитнангі,Лабытнанги,لابيتنانغي,لابیتنانگی,拉貝特南吉', 66.6572200, 66.4183300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122464, 'Kyzyl-Mazhalyk', 'Kyzyl-Mazhalyk', 'Kyzyl-Madzhalyk,Kyzyl-Mazhalyk,Kyzyl-Mazjalyk,Кызыл-Мажалык', 51.1459400, 90.5808000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122465, 'Kyzyl-Khaya', 'Kyzyl-Khaya', 'Kyzyl-Khaja,Kyzyl-Khaya,Кызыл-Хая', 50.0498600, 89.8782100, 'RU', '2010-03-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122466, 'Kyzyl', 'Kyzyl', 'Belotsarsk,Bielorsarsk,Chi-ch''i-erh,Chi-ch’i-erh,Gorad Kyzyl,K''en-mu-pi-ch''i-erh,KYZ,Kezelli,Khem Belder,Kizil,Kizil Khoto,Kizila,Kozol,Krasni,Krasnij,Krasny,Krasnyy,Kysyl,Kyzyl,Kyzyl Khoro,Kyzyl Khoto,Kyzyl shaary,Kyzylas,Kyzył,Këzëlli,Kîzîl,Kõzõl,Kızıl,K’en-mu-pi-ch’i-erh,Qizil,kayzl,ke zi lei,kijil,kizila,kuzuru,kyzl,kyzyl,qyzyl,Κιζίλ,Горад Кызыл,Кизил,Кызыл,Кызыл шаары,Қызыл,קיזיל,كيزيل,کائزل,کیزل,کیزیل,किज़िल,クズル,克孜勒,키질', 51.7147200, 94.4533800, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122467, 'Kytmanovo', 'Kytmanovo', 'Kytmanov,Kytmanovo,Кытманово', 53.4593000, 85.4479000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122468, 'Kyshtym', 'Kyshtym', 'Kyshtym,Kysjtym,Кыштым', 55.7140000, 60.5528000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122469, 'Kyshtovka', 'Kyshtovka', 'Kyshtovka,Kysjtovka,Кыштовка', 56.5549800, 76.6271300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122470, 'Kvitok', 'Kvitok', 'Kvitok,Квиток', 56.0724000, 98.4813000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122471, 'Kuzedeyevo', 'Kuzedeyevo', 'Kuzedeevo,Kuzedejevo,Kuzedeyevo,Kuzedeyevskoye,Кузедеево', 53.3308000, 87.2019000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122472, 'Kuybyshev', 'Kuybyshev', 'Gorad Kujbyshau,Kaen,Kainsk,Kouibychev,Kouïbychev,Kuibosev,Kuibyschew,Kuibyshev,Kuibõšev,Kujbisev,Kujbishev,Kujbiŝev,Kujbišev,Kujbysev,Kujbysew,Kujbyshev,Kujbysjev,Kujbyszew,Kujbyšev,Kujbyšew,Kuybyshev,Kúibyshev,gu bi xue fu,ku-ibisyepeu,kwybshyf,kwybyshf  astan nwwsybyrsk,Горад Куйбышаў,Каен,Куйбишев,Куйбышев,Кујбишев,كويبشيف,کویبیشف، استان نووسیبیرسک,古比雪夫,쿠이비셰프', 55.4475300, 78.3218100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122473, 'Kurtamysh', 'Kurtamysh', 'Gorad Kurtamysh,Koertamysj,Kortamysh,Kourtamych,Kurtamis,Kurtamish,Kurtamiŝ,Kurtamys,Kurtamysch,Kurtamysh,Kurtamysj,Kurtamyš,Kurtamış,ku er ta mei shen,kuleutamisi,kwrtamaysh,kwrtamysh,Горад Куртамыш,Кортамыш,Куртамиш,Куртамыш,كورتامايش,کورتامیش,庫爾塔梅什,쿠르타미시', 54.9102800, 64.4319400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122474, 'Kurgan', 'Kurgan', 'Gorad Kurgan,KRO,Koergan,Kourgan,Kurgan,Kurgan Pervyy,Kurgan i Kurgan oblast,Kurgana,Kurganas,Kurgano,Kurgán,Kurgāna,Kurqan,krgan,ku er gan,kuleugan,kurugan,kwrgan  awblast kwrgan,kwrgan  kwrgan awblast,kwrghan,Горад Курган,Курган,كورغان,کرگان,کورگان، اوبلاست کورگان,کورگان، کورگان اوبلاست,クルガン,库尔干,쿠르간', 55.4500000, 65.3333300, 'RU', '2013-07-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122475, 'Kuragino', 'Kuragino', 'Kuragino,Kuraguino,Курагино', 53.8878500, 92.6815200, 'RU', '2013-11-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122476, 'Kupino', 'Kupino', 'Kupino,Купино', 54.3663500, 77.2980500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122477, 'Kungurtug', 'Kungurtug', 'Kungur-Tuk,Kungurtug,Кунгуртуг', 50.5994400, 97.5227800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122478, 'Kunashak', 'Kunashak', 'Kunashak,Kunasjak,Кунашак', 55.7032000, 61.5498000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122479, 'Kuminskiy', 'Kuminskiy', 'Kuminskij,Kuminskiy,Куминский', 58.6666700, 66.5666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122480, 'Kulunda', 'Kulunda', 'Kulunda,Кулунда', 52.5660000, 78.9385000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122481, 'Kudryashovskiy', 'Kudryashovskiy', 'Kudrjashovskij,Kudrjasjovskij,Kudryashevskiy,Kudryashovskiy,Кудряшовский', 55.0974000, 82.7742000, 'RU', '2013-11-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122482, 'Krutinka', 'Krutinka', 'Krutinka,Krutinskoye,Крутинка', 56.0055000, 71.5113100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122483, 'Krutikha', 'Krutikha', 'Krutikha,Крутиха', 53.9599000, 81.2093000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122484, 'Krutaya Gorka', 'Krutaya Gorka', 'Krutaja Gorka,Krutaya Gorka,Крутая Горка', 55.3649300, 73.2231000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122485, 'Krivosheino', 'Krivosheino', 'Krivosheino,Krivosjeino,Кривошеино', 57.3430600, 83.9261100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122486, 'Krivodanovka', 'Krivodanovka', 'Krivodanovka,Криводановка', 55.0881000, 82.6551000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122487, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasny Yar,Krasnyj Jar,Krasnyy Yar,Красный Яр', 57.1275000, 84.5302800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122488, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasny Yar,Krasnyj Jar,Krasnyy Yar,Красный Яр', 55.2424200, 72.9263500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122489, 'Krasnyy Yar', 'Krasnyy Yar', 'Krasny Yar,Krasnyj Jar,Krasnyy Yar,Красный Яр', 52.3575000, 85.3380600, 'RU', '2013-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122490, 'Krasnyy Oktyabr’', 'Krasnyy Oktyabr''', 'Krasnyj Oktjabr'',Krasnyy Oktyabr'',Krasnyy Oktyabr’,Красный Октябрь', 55.6566700, 64.8133300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122491, 'Krasnozërskoye', 'Krasnozerskoye', 'Krasnoozersk,Krasnozersk,Krasnozerskoe,Krasnozerskoje,Krasnozerskoye,Krasnozjorskoe,Krasnozërskoye,Краснозерское,Краснозёрское', 53.9827700, 79.2373500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122492, 'Krasnoye', 'Krasnoye', 'Krasnoe,Krasnoje,Krasnoye,Красное', 54.6068000, 85.3899000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122493, 'Krasnoyarsk', 'Krasnoyarsk', 'KJA,Krasnoiarsk,Krasnojarsk,Krasnoyarsk,Krasnoïarsk,keulaseunoyaleuseukeu,Красноярск,크라스노야르스크', 56.0183900, 92.8671700, 'RU', '2017-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122494, 'Krasnoyarka', 'Krasnoyarka', 'Krasnojarka,Krasnoyarka,Красноярка', 55.3333300, 73.1166700, 'RU', '2010-08-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122495, 'Krasnoural’sk', 'Krasnoural''sk', 'Krasnoural''sk,Krasnouralsk,Krasnoural’sk,Uralmed''stroy,Uralmed’stroy,Красноуральск', 58.3638000, 60.0407000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122496, 'Krasnotur’insk', 'Krasnotur''insk', 'Krasnotur''insk,Krasnoturinsk,Krasnotur’insk,Tur''inskiy,Tur’inskiy,Краснотурьинск', 59.7666000, 60.2086000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122497, 'Krasnoturansk', 'Krasnoturansk', 'Krasnoturansk,Краснотуранск', 54.3186100, 91.5638900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122498, 'Krasnoshchekovo', 'Krasnoshchekovo', 'Kraskoshchekovo,Krasnoshchekovo,Krasnoshchëkovo,Krasnoshhjokovo,Krasnosjtsjekovo,Краснощёково', 51.6708300, 82.7288900, 'RU', '2014-04-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122499, 'Krasnoobsk', 'Krasnoobsk', 'Krasnoobsk,Краснообск', 54.9198000, 82.9909000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122500, 'Krasnokamensk', 'Krasnokamensk', 'Krasnokamensk,Краснокаменск', 54.3338900, 93.2594400, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122501, 'Krasnogvardeyskiy', 'Krasnogvardeyskiy', 'Irbitskiy,Krasnogvardejskij,Krasnogvardeyskiy,Красногвардейский', 57.3792800, 62.3195200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122502, 'Krasnogorskoye', 'Krasnogorskoye', 'Krasnogorskoe,Krasnogorskoje,Krasnogorskoye,Staraya Barda,Staro-Bardinskoye,Красногорское', 52.2953000, 86.1979000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122503, 'Krasnogorskiy', 'Krasnogorskiy', 'Krasnogorskij,Krasnogorskiy,Красногорский', 54.6025000, 61.2310000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122504, 'Krasnogorskiy', 'Krasnogorskiy', 'Krasnaya Gorka,Krasnogorskij,Krasnogorskiy,Красногорский', 54.5471000, 86.2810000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122505, 'Krapivinskiy', 'Krapivinskiy', 'Krapivino,Krapivinskij,Krapivinskiy,Крапивинский', 54.9992000, 86.8133000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122506, 'Kozhevnikovo', 'Kozhevnikovo', 'Kozhevnikovo,Kozjevnikovo,Кожевниково', 56.2588900, 83.9713900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122507, 'Koyelga', 'Koyelga', 'Koelga,Kojelga,Koyelga,Коелга', 54.6522400, 60.9049000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122508, 'Kosikha', 'Kosikha', 'Kosikha,Косиха', 53.3616700, 84.5822200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122509, 'Koshurnikovo', 'Koshurnikovo', 'Koshurnikovo,Кошурниково', 54.1666700, 93.3000000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122510, 'Kosh-Agach', 'Kosh-Agach', 'Kosh-Agach,Kosj-Agatsj,Кош-Агач', 49.9927300, 88.6759800, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122511, 'Kormilovka', 'Kormilovka', 'Kormilovka,Кормиловка', 55.0026400, 74.1028100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122512, 'Korkino', 'Korkino', 'Korkino,ke er ji nuo,Коркино,科爾基諾', 54.8913000, 61.3969000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122513, 'Kopeysk', 'Kopeysk', 'Kopeisk,Kopejsk,Kopeysk,Kopi,Kopiejsk,Ugolnye Kopi,Копейск', 55.1172200, 61.6282300, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122514, 'Kondinskoye', 'Kondinskoye', 'KXD,Kondinskoe,Kondinskoje,Kondinskoye,Nakhrachi,Кондинское', 59.6480600, 67.4100000, 'RU', '2016-06-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122515, 'Yugorsk', 'Yugorsk', 'Jugorsk,Komsomol''skij,Komsomol''skiy,Komsomol’skiy,Yugorsk,Комсомольский,Югорск', 61.3122600, 63.3306700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122516, 'Kommunisticheskiy', 'Kommunisticheskiy', 'Kommunisticheskij,Kommunisticheskiy,Samza,Коммунистический,Самза', 61.6788900, 64.4819400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122517, 'Kommunar', 'Kommunar', 'Kommunar,Коммунар', 54.3483500, 89.2829700, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122518, 'Kolyvan’', 'Kolyvan''', 'Kolyban,Kolyvan,Kolyvan'',Kolyvan’,Колывань', 55.3053000, 82.7391000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122519, 'Kol’tsovo', 'Kol''tsovo', 'Kol''covo,Kol''tsovo,Koltsovo,Kol’tsovo,Кольцово', 54.9376000, 83.1825000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122520, 'Kolpashevo', 'Kolpashevo', 'Kolpashev,Kolpashevo,Kolpasjevo,Колпашево', 58.3130600, 82.9088900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122521, 'Kolosovka', 'Kolosovka', 'Kolosova,Kolosovka,Колосовка', 56.4677900, 73.6109600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122522, 'Kodinsk', 'Kodinsk', 'Gorad Kadzinsk,Kodinsk,Kodinskaya,Kodinskaya Zaimka,Kodinskij,Kodinskiy,Kodynsk,Kodyńsk,Kódinsk,ke jin si ke,kwdynsk,Горад Кадзінск,Кодинск,Кодинский,كودينسك,کودینسک,科金斯克', 58.6880600, 99.1844400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122523, 'Kochki', 'Kochki', 'Kochki,Kochkovskoye,Kotsjki,Кочки', 54.3358300, 80.4805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122524, 'Kochenëvo', 'Kochenevo', 'Kochenevo,Kochenjovo,Kochenova,Kochenëvo,Konchenevo,Koyschenewo,Коченёво', 55.0218000, 82.2020000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122525, 'Klyuchi', 'Klyuchi', 'Kljuchi,Kljutsji,Klyuchi,Ключи', 52.2530300, 79.1686800, 'RU', '2013-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122526, 'Klyuchevsk', 'Klyuchevsk', 'Kljuchevsk,Kljutsjevsk,Klyuchevsk,Teply-Klyuch,Teplyy Klyuch,Tëplyy Klyuch,Ключевск', 57.1216000, 60.9414000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122527, 'Kiselëvsk', 'Kiselevsk', 'Kiselevsk,Kiseljovsk,Kiselyovsk,Kiselëvsk,Kizelovsk,Киселевск,Киселёвск', 53.9900000, 86.6621000, 'RU', '2016-05-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122528, 'Kirovgrad', 'Kirovgrad', 'Gorad Kiraugrad,Kalata,Kirovgrad,Kirovgrád,Kirovnkrant,Kirovqrad,Kirowgrad,ji luo fu ge lei,kilobeugeuladeu,kyrwfghrad,kyrwfgrad,Κιροβγκράντ,Горад Кіраўград,Кировград,Кіровград,كيروفغراد,کیروفگراد,基洛夫格勒,키로브그라드', 57.4297200, 60.0597200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122529, 'Khulimsunt', 'Khulimsunt', 'Khulim-Sund,Khulimsunt,Khulyum-Sunt,Хулимсунт', 62.8633300, 61.6436100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122530, 'Khudoyelanskoye', 'Khudoyelanskoye', 'Khudo-Elan'',Khudo-Jelan,Khudoelanskoe,Khudoyelan'',Khudoyelanskaya,Khudoyelanskoye,Khudoyelan’,Худо-Елань,Худоеланское', 54.7037500, 99.6304200, 'RU', '2013-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122531, 'Khovu-Aksy', 'Khovu-Aksy', 'Khovu-Aksy,Хову-Аксы', 51.1329400, 93.7128600, 'RU', '2013-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122532, 'Kharp', 'Kharp', 'Kharp,Харп', 66.8013900, 65.8080600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122533, 'Khanty-Mansiysk', 'Khanty-Mansiysk', 'Chanti-Mansiisk,Chanty Mansijskas,Chanty-Mansiejsk,Chanty-Mansijsk,Chanty-Mansyjsk,Gorad Khanty-Mansijsk,HMA,Hanti-Mansiisk,Hanti-Mansijsk,Hanti-Mansiysk,Hanti-Manszijszk,Hantimansijska,Hanto-Mansiisk,Hanty-Mansijsk,Hantî-Mansiisk,Hantõ-Mansiisk,Hantı-Mansiysk,Janty-Mansisk,Jograkar,Jomvosh,Khanti-Mansijs''k,Khanti-Mansijsk,Khanti-Mansisk,Khanty Mansisk,Khanty-Mansiisk,Khanty-Mansijsk,Khanty-Mansisk,Khanty-Mansiysk,Khanty-Mansiïsk,Ostyako-Vogul''sk,Ostyako-Vogul’sk,Xanti-Mansi,Xanti-Mansiysk,Xanti-mansiysk,han te-man xi si ke,hantimansiseukeu,hnty-mnsysq,khanty mansyysk,khanty-mansysk,khanty-mansyysk,Ĥanti-Mansijsk,Ёмвош,Горад Ханты-Мансійск,Йӧгракар,Ханти-Мансийск,Ханти-Мансијск,Ханти-Мансійськ,Ханты-Мансийск,Խանտի-Մանսիյսկ,חנטי-מנסיסק,خانتي-مانسييسك,خانتی مانسیئسک,خانتی-مانسیسک,خانتی-مانسییسک,ხანტი-მანსიისკი,ハンティ・マンシースク,汉特-曼西斯克,한티만시스크', 61.0041700, 69.0019400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122534, 'Khandagayty', 'Khandagayty', 'Handagaytay,Khandagajty,Khandagayty,Хандагайты', 50.7333300, 92.0500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122535, 'Khabary', 'Khabary', 'Khabari,Khabary,Хабары', 53.6258800, 79.5345000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122536, 'Ketovo', 'Ketovo', 'Ketovo,Кетово', 55.3550000, 65.3258300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122537, 'Kemerovo', 'Kemerovo', 'Gorad Kemerava,KEJ,Kemer,Kemerova,Kemerovas,Kemerovo,Kemerovo khot,Kemerowo,Kèmerovo,Kémerovo,Shcheglovsk,ke mai luo wo,kemelobo,kemerovo,kemerovu~o,kmrwf,kymyrwfw,kymyrww,qmrwbw,Горад Кемерава,Кемĕр,Кемерово,Кемерово хот,Կեմերովո,קמרובו,كيميروفو,کمروف,کیمیروو,केमेरोवो,ケメロヴォ,克麥羅沃,케메로보', 55.3333300, 86.0833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122538, 'Kedrovoye', 'Kedrovoye', 'Kedrovoe,Kedrovoje,Kedrovoye,Кедровое', 57.1576000, 60.5698000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122539, 'Kedrovka', 'Kedrovka', 'Kedrovka,Кедровка', 55.5333300, 86.0500000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122540, 'Kazanskoye', 'Kazanskoye', 'Kazanskoe,Kazanskoje,Kazanskoye,Казанское', 55.6447700, 69.2350000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122541, 'Kazachinskoye', 'Kazachinskoye', 'Kazachinskiy,Kazachinskoe,Kazachinskoye,Kazatsjinskoje,Казачинское', 57.7004000, 93.2809000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122542, 'Kaz', 'Kaz', 'Kaz,Каз', 52.9113000, 87.3105000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122543, 'Kayyerkan', 'Kayyerkan', 'Kajerkam,Kajerkan,Kayerkan,Kayyerkan,Кайеркан', 69.3786100, 87.7438900, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122544, 'Kataysk', 'Kataysk', 'Katajsk,Kataysk,Katayskoye,Катайск', 56.2890000, 62.5841000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122545, 'Kasli', 'Kasli', 'Gorad Kasli,Kasli,Kaslinskiy Zavod,Kaslí,ka si li,kasly,Горад Каслі,Касли,Каслі,Кәсле,كاسلي,کاسلی,卡斯利', 55.8909000, 60.7616000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122546, 'Kartaly', 'Kartaly', 'Gorad Kartaly,Kartali,Kartaly,Kartalí,ka er ta lei,kartaly,Горад Карталы,Картали,Карталы,Кәртәле,كارتالي,کارتالی,卡爾塔雷', 53.0528500, 60.6490300, 'RU', '2012-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122547, 'Karpinsk', 'Karpinsk', 'Bogoslovskiy,Gorad Karpinsk,Karpins''k,Karpinsk,Karpinskas,Karpińsk,Ugol''nyy,Ugol’nyy,ka er ping si ke,karbynsk,karpynsk,Καρπίνσκ,Горад Карпінск,Карпинск,Карпінськ,كاربينسك,کارپینسک,卡爾平斯克', 59.7703000, 59.9964000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122548, 'Kargat', 'Kargat', 'Kargat,Каргат', 55.1955600, 80.2811100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122549, 'Kargasok', 'Kargasok', 'Kargasen,Kargasok,Novyy Kargasok,Каргасок', 59.0555600, 80.8572200, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122550, 'Karatuzskoye', 'Karatuzskoye', 'Karatuz,Karatuzskoe,Karatuzskoje,Karatuzskoye,Каратузское', 53.6072200, 92.8666700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122551, 'Karasuk', 'Karasuk', 'Gorad Karasuk,Karassouk,Karassuk,Karasuk,Karasukas,ka la su ke,karaswk,Горад Карасук,Карасук,كاراسوك,کاراسوک,卡拉蘇克', 53.7377200, 78.0402600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122552, 'Karagayla', 'Karagayla', 'Karagajla,Karagajlinskij,Karagayla,Karagaylinskiy,Kargaylinskaya,Nizhniye Karagayli,Карагайла,Карагайлинский', 54.1720000, 86.5521000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122553, 'Karabash', 'Karabash', 'Gorad Karabash,Karabach,Karabaix,Karabas,Karabasch,Karabash,Karabasj,Karabaŝ,Karabaš,ka la ba shen,karabash,karabash  awblast chlyabynsk,Горад Карабаш,Карабаш,كاراباش,کاراباش، اوبلاست چلیابینسک,卡拉巴什', 55.4808000, 60.2157000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122554, 'Kansk', 'Kansk', 'Gorad Kansk,Kansk,Kanskas,Kańsk,kan si ke,kanseukeu,kansk,Горад Канск,Канск,كانسك,کانسک,坎斯克,칸스크', 56.2016700, 95.7175000, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122555, 'Kanashevo', 'Kanashevo', 'Kanashevo,Kanasjevo,Канашево', 55.2169000, 62.0634000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122556, 'Kamyshlov', 'Kamyshlov', 'Gorad Kamyshlou,Kamishlov,Kamislof,Kamislov,Kamixlov,Kamiŝlov,Kamoslov,Kamychlov,Kamyschlow,Kamyshlov,Kamyshly,Kamysjlov,Kamyslov,Kamyslow,Kamyszlow,Kamyszłow,Kamyšlov,Kamyšlow,Kamõšlov,Kamışlov,Komyschlow,ka mei shen luo fu,kamyshlwf,Καμισλόφ,Горад Камышлоў,Камишлов,Камышлов,Камышлы,كاميشلوف,کامیشلوف,卡梅什洛夫', 56.8427800, 62.7111100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122557, 'Kamensk-Ural’skiy', 'Kamensk-Ural''skiy', 'Kamenisk,Kamensk,Kamensk-Ural''skij,Kamensk-Ural''skiy,Kamensk-Uralskij,Kamensk-Uralsky,Kamensk-Ural’skiy,Каменск-Уральский', 56.4185000, 61.9329000, 'RU', '2016-05-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122558, 'Mys-Kamennyy', 'Mys-Kamennyy', 'Kamennyy,Mys-Kamennyj,Mys-Kamennyy,YMK,Мыс-Каменный', 68.4597200, 73.5902800, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122559, 'Kamen’-na-Obi', 'Kamen''-na-Obi', 'Kamen'',Kamen''-na-Obi,Kamen-Na-Obi,Kamen’,Kamen’-na-Obi,Камень-на-Оби', 53.7884000, 81.3423000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122560, 'Kaltay', 'Kaltay', 'Kadtay,Kaltaj,Kaltay,Koltayskoye,Калтай', 56.2791700, 84.8786100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122561, 'Kaltan', 'Kaltan', 'Kaltan,Kaltanskaya,Nizhniy Kaltan,Калтан', 53.5347000, 87.2457000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122562, 'Kalmanka', 'Kalmanka', 'Kalmanka,Kalmanskoye,Калманка', 52.8991700, 83.5433300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122563, 'Kalinovo', 'Kalinovo', 'Kalinovo,Калиново', 57.1317000, 60.1464000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122564, 'Kalachinsk', 'Kalachinsk', 'Gorad Kalachynsk,Kalachinsk,Kalachly,Kalacinsk,Kalaczinsk,Kalanchinsk,Kalatchinsk,Kalatschinek,Kalatschinsk,Kalatsinsk,Kalatsjinsk,Kalatšinsk,Kalaĉinsk,Kalačinsk,Kałaczinsk,ka la qin si ke,kalachynsk,kalatshynsk,kallachinseukeu,Горад Калачынск,Калачинск,Калачлы,كالاتشينسك,کالاچینسک,卡拉欽斯克,칼라친스크', 55.0528600, 74.5751100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122565, 'Kaa-Khem', 'Kaa-Khem', 'Ka-Khem,Kaa-Khem,Kok-Tey,Каа-Хем', 51.6833300, 94.7333300, 'RU', '2014-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122566, 'Izumrud', 'Izumrud', 'Izumrud,Изумруд', 57.0788100, 61.3993200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122567, 'Izhmorskiy', 'Izhmorskiy', 'Izhmorka,Izhmorskij,Izhmorskiy,Izhmorskoye,Izjmorka-2ja,Ижморский', 56.1923900, 86.6416100, 'RU', '2014-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122568, 'Ivdel’', 'Ivdel''', 'Ivdel'',Ivdel''-1,Ivdel’,Ивдель,Ивдель-1', 60.6911100, 60.4205600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122569, 'Itatskiy', 'Itatskiy', 'Itat,Itatskaya,Itatskij,Itatskiy,Итатский', 56.0700000, 89.0369400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122570, 'Iskitim', 'Iskitim', 'Gorad Iskicim,Iskitim,ayskytym,yi si ji ji mu,Іскітим,Горад Іскіцім,Искитим,إيسكيتيم,ایسکیتیم,伊斯基季姆', 54.6366000, 83.3045000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122571, 'Ishim', 'Ishim', 'Byen Isjim,Gorad Ishym,Ichim,Ischim,Ishem,Ishim,Isim,Isjim,Iszym,Ixim,Iŝim,Išim,Ișim,ayshym,isim,yi xi mu,İşim,Ішим,Горад Ішым,Ишем,Ишим,إيشيم,ایشیم,伊希姆,이심', 56.1128100, 69.4901500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122572, 'Isetskoye', 'Isetskoye', 'Isetskoe,Isetskoje,Isetskoye,Исетское', 56.4858000, 65.3226000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122573, 'Iset’', 'Iset''', 'Iset,Iset'',Iset’,Исеть', 56.9779000, 60.3718000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122574, 'Irtyshskiy', 'Irtyshskiy', 'Irtyshskij,Irtyshskiy,Irtysjskij,Иртышский', 58.3333300, 68.1333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122575, 'Irtyshskiy', 'Irtyshskiy', 'Irtyshskij,Irtyshskiy,Irtysjskij,Иртышский', 54.8142600, 73.5872200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122576, 'Irsha', 'Irsha', 'Irsha,Irsja,Ирша', 55.9273000, 94.7999000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122577, 'Irbit', 'Irbit', 'Ehrbet,Gorad Irbit,Irbit,Irmpit,ayrbyt,irbit,yi er bi te,İrbit,Ιρμπίτ,Ірбіт,Горад Ірбіт,Ирбит,Эрбет,إيربيت,ایربیت,伊爾比特', 57.6705200, 63.0710000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122578, 'Irbeyskoye', 'Irbeyskoye', 'Irbejskoe,Irbejskoje,Irbeyskoye,Ирбейское', 55.6396000, 95.4515000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122579, 'Inya', 'Inya', 'Inja,Inskaya,Inya,Иня', 53.5044000, 82.6712000, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122580, 'Inya', 'Inya', 'Inja,Inya,Иня', 50.4666700, 86.6166700, 'RU', '2013-10-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122581, 'Inta', 'Inta', 'Gorad Inta,INA,Int,Inta,Intà,Intá,anta,aynta,inta,yin ta,İnta,Інта,Горад Інта,Инта,Инта балһсн,إنتا,اینتا,因塔,인타', 66.0316900, 60.1659400, 'RU', '2012-02-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122582, 'Inskoy', 'Inskoy', 'Inskoj,Inskoy,Инской', 54.4297000, 86.4400000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122583, 'Ilanskiy', 'Ilanskiy', 'Ilanskij,Ilanskiy,Ilanskoe,Ilanskoye,Иланский', 56.2325000, 96.0652000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122584, 'Ikovka', 'Ikovka', 'Ikovka,Иковка', 55.6088900, 64.9375000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122585, 'Igrim', 'Igrim', 'IRM,Igrim,Igrimskiye,Yurty Igrim,Игрим', 63.1906000, 64.4162000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122586, 'Igarka', 'Igarka', 'IAA,Igarka,Igarkae,Игаркæ,Игарка', 67.4655000, 86.6027000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122587, 'Idrinskoye', 'Idrinskoye', 'Idrinskoe,Idrinskoje,Idrinskoye,Идринское', 54.3708300, 92.1358300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122588, 'Gur’yevsk', 'Gur''yevsk', 'Gur''evsk,Gur''yevsk,Gur''yevskov,Gurevsk,Gurjevsk,Gur’yevsk,Gur’yevskov,Гурьевск', 54.2833300, 85.9333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122589, 'Gryaznovskoye', 'Gryaznovskoye', 'Grjaznovskoe,Gryaznovskoye,Грязновское', 56.7825000, 61.7053000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122590, 'Grishkovka', 'Grishkovka', 'Grishevka,Grishkovka,Grisjkovka,Гришковка', 53.1487000, 78.7510000, 'RU', '2012-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122591, 'Gramoteino', 'Gramoteino', 'Gramoteina,Gramoteino,Грамотеино', 54.5368000, 86.3839000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122592, 'Gornyy Shchit', 'Gornyy Shchit', 'Gornoshchitskoye,Gornoshitski,Gornoshitskoye,Gornyj Shhit,Gornyj Sjtsjit,Gornyy Shchit,Горный Щит', 56.6881500, 60.5194700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122593, 'Gornyy', 'Gornyy', 'Gornyj,Gornyy,Горный', 55.1153000, 83.9059000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122594, 'Gornyak', 'Gornyak', 'Gornjak,Gornyak,Горняк', 55.1344600, 61.6826800, 'RU', '2012-12-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122595, 'Gornyak', 'Gornyak', 'Gornjak,Gornyak,Горняк', 50.9941700, 81.4661100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122596, 'Gornopravdinsk', 'Gornopravdinsk', 'Filinskoye,Gorno-Filinskoye,Gornopravdinsk,Горноправдинск', 60.0500000, 69.9000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122597, 'Gorno-Altaysk', 'Gorno-Altaysk', 'Gorno-Altaisk,Gorno-Altaiskas,Gorno-Altajsk,Gorno-Altaysk,Gorno-Altaïsk,Gorno-Ałtajsk,Gornyy Altaysk,Oirat-Tura,Oirot-Tura,Oyrot-Tura,RGK,Tuulu Altaj,Ulala,goleunoaltaiseukeu,Горно-Алтайск,Туулу Алтай,고르노알타이스크', 51.9605600, 85.9189200, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122598, 'Plotnikovo', 'Plotnikovo', 'Gorbunovka,Gorbunovskiy,Plotnikovo,Plotnikovskiy,Плотниково', 55.0247200, 85.9436100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122599, 'Gon’ba', 'Gon''ba', 'Gon''ba,Gonba,Gon’ba,Гоньба', 53.4172000, 83.5747000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122600, 'Golyshmanovo', 'Golyshmanovo', 'Golyshmanovo,Golysjmanovo,Katyshka,Голышманово', 56.3979000, 68.3727900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122601, 'Glyadyanskoye', 'Glyadyanskoye', 'Gljadjanskoe,Gljadjanskoje,Glyadyanskoye,Глядянское', 54.9075000, 65.0883300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122602, 'Gari', 'Gari', 'Gari,Garinskoye,Гари', 59.4307500, 62.3496700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122603, 'Filimonovo', 'Filimonovo', 'Filimonovo,Филимоново', 56.2011100, 95.4611100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122604, 'Erzin', 'Erzin', 'Bay-Tag,Ehrzin,Erzin,Saryg-Buluk,Saryg-Bulun,Эрзин', 50.2600000, 95.1623000, 'RU', '2013-10-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122605, 'Elekmonar', 'Elekmonar', 'Ehlekmonar,Elekmonar,Элекмонар', 51.4608300, 86.0219400, 'RU', '2012-05-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122606, 'Dzerzhinskoye', 'Dzerzhinskoye', 'Dzerzhinskoe,Dzerzhinskoye,Dzerzjinskoje,Rozhdestvenskoye,Дзержинское', 56.8344400, 95.2283300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122607, 'Dvurechensk', 'Dvurechensk', 'Dvurechensk,Dvuretsjensk,Khrompik,Двуреченск', 56.5982000, 61.0953000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122608, 'Dudinka', 'Dudinka', 'Doedinka,Doudinka,Dudink,Dudinka,Dudinka shaary,Dudinskoe,Dugyinka,Gorad Dudzinka,do~udinka,du jin ka,dudinka,dwbynka,dwdynka,dwdynqh,Горад Дудзінка,Дудинка,Дудинка шаары,Дудінка,דודינקה,دوبینکا,دودينكا,ドゥディンカ,杜金卡,두딘카', 69.4058300, 86.1777800, 'RU', '2016-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122609, 'Dubrovino', 'Dubrovino', 'Dubrovino,Дубровино', 55.4718000, 83.2907000, 'RU', '2015-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122610, 'Dubinino', 'Dubinino', 'Dubinino,Dubininskoye,Дубинино', 55.6191700, 89.0911100, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122611, 'Dorogino', 'Dorogino', 'Dorogina,Dorogino,Дорогино', 54.3598000, 83.3198000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122612, 'Dolgoderevenskoye', 'Dolgoderevenskoye', 'Dolgoderevenskoe,Dolgoderevenskoje,Dolgoderevenskoye,Долгодеревенское', 55.3444400, 61.3444400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122613, 'Divnogorsk', 'Divnogorsk', 'Divnogors''k,Divnogorsk,Divnogorskas,Diwnogorsk,Gorad Dziunagorsk,Skit,dibeunogoleuseukeu,dyfnwghwrsk,dywnwgwrsk,ji fu nuo ge er si ke,Горад Дзіўнагорск,Дивногорск,Дивногорськ,ديفنوغورسك,دیونوگورسک,季夫諾戈爾斯克,디브노고르스크', 55.9581000, 92.3726000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122614, 'Dikson', 'Dikson', 'DKS,Dikson,Dikson qəsəbəsi,Diksonas,Port Dickson,dikuson,dyqswn,Диксон,Діксон,דיקסון,ディクソン', 73.5081900, 80.5291800, 'RU', '2013-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122615, 'Degtyarsk', 'Degtyarsk', 'Degtjarsk,Degtyarka,Degtyarsk,Дегтярск', 56.7040000, 60.0879000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122616, 'Dalmatovo', 'Dalmatovo', 'Dalmatovo,Dalmatowo,Dolmatovo,Gorad Dalmatava,da er ma tuo wo,dalmatobo,dalmatwfw,Горад Далматава,Далматово,دالماتوفو,達爾馬托沃,달마토보', 56.2600000, 62.9362000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122617, 'Chunskiy', 'Chunskiy', 'Chuna,Chunskij,Chunskiy,Tsjunskij,Чунский', 56.0815000, 99.6342000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122618, 'Chunoyar', 'Chunoyar', 'Chunojar,Chunoyar,Tsjunojar,Чунояр', 57.4483000, 97.3286000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122619, 'Chulym', 'Chulym', 'Chalyn,Chulim,Chulym,Tsjulym,Чулым', 55.0997200, 80.9572200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122620, 'Choya', 'Choya', 'Chaya,Choja,Choya,Tsjoja,Чоя', 52.0108000, 86.5467000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122621, 'Chistogorskiy', 'Chistogorskiy', 'Chistogorskij,Chistogorskiy,Tsjistogorskij,Чистогорский', 53.9835000, 87.3843000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122622, 'Chesma', 'Chesma', 'Chesma,Tsjesma,Чесма', 53.8111100, 60.6533300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122623, 'Chervishevo', 'Chervishevo', 'Chervishevo,Chervishiyevskoye,Chervishjovo,Tsjervisjevo,Червишёво', 56.9463500, 65.4278200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122624, 'Chernogorsk', 'Chernogorsk', 'Cernogorsk,Chernogorsk,Kharatas,Tsernogorsk,Tšernogorsk,cheleunogoleuseukeu,Ĉernogorsk,Харатас,Черногорск,체르노고르스크', 53.8236100, 91.2841700, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122625, 'Cherlak', 'Cherlak', 'Chavlak,Cherlak,Cherlakovskaya,Cherlakskiy,Tsjerlak,Черлак', 54.1550000, 74.8055000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122626, 'Cherga', 'Cherga', 'Chavia,Cherga,Tsjerga,Черга', 51.5688900, 85.5625000, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122627, 'Cherepanovo', 'Cherepanovo', 'Cherepanovo,Tsjerepanovo,Черепаново', 54.2222000, 83.3810000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122628, 'Cherëmushki', 'Cheremushki', 'Cheremushki,Cherjomushki,Cherëmushki,Tsjeremusjki,Черёмушки', 52.8557600, 91.4167200, 'RU', '2013-06-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122629, 'Cheremshanka', 'Cheremshanka', 'Cheremshanka,Tsjeremsjanka,Черемшанка', 56.1192000, 60.2680400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122630, 'Cheremnoye', 'Cheremnoye', 'Cheremnoe,Cheremnovo,Cheremnovskoye,Cheremnoye,Tsjeremnoje,Черемное', 53.1697200, 83.2133300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122631, 'Novobirilyussy', 'Novobirilyussy', 'Chepysheva,Chipusheva,Novobiriljussy,Novobirilyussy,Новобирилюссы', 56.9526000, 90.6807000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122632, 'Chemal', 'Chemal', 'Chemal,Chemla,Tsjemal,Чемал', 51.4111100, 86.0050000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122633, 'Chelyabinsk', 'Chelyabinsk', 'CEK,Celabinsk,Celabinska,Celaebinsk,Celeabinsk,Celiabinsc,Celiabinsca,Celiabinskas,Celjabinsk,Celyabinsk,Chelepi,Cheliabinsk,Cheliábinsk,Cheljaba,Cheljaba osh,Cheljabe,Cheljabi,Cheljabins''k,Cheljabinsk,Chelyabinsk,Cseljabinszk,Czelabinsk,Czelabińsk,Gorad Chaljabinsk,Tcheliabinsk,Tchelyabinsk,Tchéliabïnsk,Tjeljabinsk,Tscheljabinsk,Tseliampinsk,Tseljabinsk,Tsjeljabinsk,Tsyelyabinsk,Txeliabinsk,Txeliàbinsk,Tšeljabinsk,celiyabinska,celyabinska,che li ya bin si ke,chellyabinseukeu,cheryabinsuku,chlyabnsk,chlyabynsk,chylyabnsk,tshylyabnsk,zlyʼbynsq,Çelyabinsk,Ĉeljabinsk,Čeliabinskas,Čeljabinsk,Čeläbinsk,Čeļabinska,Čeľabinsk,Τσελιάμπινσκ,Горад Чалябінск,Силәбе,Челепи,Челяба,Челяба ош,Челябе,Челябинск,Челябі,Челябінськ,Чељабинск,Чиләбе,Чєлѣбиньскъ,Չելյաբինսկ,טשעליאבינסק,צליאבינסק,تشيليابنسك,چلیابنسک,چلیابینسک,چیلیابنسک,चेलियाबिन्स्क,चेल्याबिंस्क,চেলিয়াবিন্‌স্ক,ჩელიაბინსკი,チェリャビンスク,車里雅賓斯克,첼랴빈스크', 55.1540200, 61.4291500, 'RU', '2017-06-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122634, 'Chebarkul’', 'Chebarkul''', 'Chebarkul'',Chebarkul’,Tsjebarkul,Чебаркуль', 54.9749000, 60.3633000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122635, 'Charyshskoye', 'Charyshskoye', 'Charishskaya,Charyshskoe,Charyshskoye,Tsjarysjskoje,Чарышское', 51.3978000, 83.5598000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122636, 'Chany', 'Chany', 'Chany,Tschany,Tsjany,Чаны', 55.3120500, 76.7646800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122637, 'Chadan', 'Chadan', 'Chadan,Chadana,Dzhedanna,Tsjadan,Чадан', 51.2833300, 91.5833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122638, 'Bystryy Istok', 'Bystryy Istok', 'Bystry Istok,Bystryiy Istok,Bystryj Istok,Bystryy Istok,Быстрый Исток', 52.3710000, 84.3873000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122639, 'Bystryanka', 'Bystryanka', 'Bystrjanka,Bystryanka,Bystryanskoye,Быстрянка', 52.2861100, 85.8283300, 'RU', '2013-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122640, 'Butka', 'Butka', 'Butka,Butki,Бутка', 56.7178800, 63.7866100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122641, 'Burla', 'Burla', 'Burla,Бурла', 53.3362000, 78.3301000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122642, 'Bulanash', 'Bulanash', 'Bulanash,Bulanasj,Буланаш', 57.2782500, 61.9965000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122643, 'Brodokalmak', 'Brodokalmak', 'Brodokalmak,Brodokamlak,Бродокалмак', 55.5748000, 62.0820000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122644, 'Bredy', 'Bredy', 'Bredy,Бреды', 52.4152800, 60.3411100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122645, 'Borovskiy', 'Borovskiy', 'Borovskij,Borovskiy,Боровский', 57.0409600, 65.7201800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122646, 'Borovoy', 'Borovoy', 'Borovaya,Borovoj,Borovoy,Боровой', 55.4333300, 86.0833300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122647, 'Borovikha', 'Borovikha', 'Borovikha,Боровиха', 53.5072000, 83.8379000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122648, 'Borodino', 'Borodino', 'Borodinas,Borodino,Borodino i Krasnojarsk kraj,Borodinó,Gorad Baradzino,bo luo ji nuo,bolodino,bwrwdynw,bwrwdynw  krasnwyarsk,Бородино,Горад Барадзіно,بورودينو,بورودینو، کراسنویارسک,博羅季諾,보로디노', 55.9061000, 94.9079000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122649, 'Bor', 'Bor', 'Bor,TGP,Бор', 61.6011100, 90.0180600, 'RU', '2017-02-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122650, 'Bol’sherech’ye', 'Bol''sherech''ye', 'Bol''sherech''e,Bol''sherech''ye,Bol''sherechenskoye,Bolsjeretsje,Bol’sherechenskoye,Bol’sherech’ye,Большеречье', 56.0925200, 74.6271600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122651, 'Bolotnoye', 'Bolotnoye', 'Bolotinskoe,Bolotnoe,Bolotnoje,Bolotnoye,Болотное', 55.6716700, 84.3980600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122652, 'Boguchany', 'Boguchany', 'Boguchany,Bogutsjany,Богучаны', 58.3813900, 97.4530600, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122653, 'Bograd', 'Bograd', 'Bagrad,Bograd,Боград', 54.2344400, 90.8327800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122654, 'Bogotol', 'Bogotol', 'Bogotol,Bogotolas,Bogotoł,Borotol,Gorad Bagatol,bo ge tuo er,bogotol,bwghwtwl,bwgwtwl,Боготол,Горад Багатол,بوغوتول,بوگوتول,波戈托爾,보고톨', 56.2077800, 89.5341700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122655, 'Bogdanovich', 'Bogdanovich', 'Bogdandvich,Bogdanovich,Bogdanovichi,Bogdanovikhi,Bogdanovitsj,Богданович', 56.7802800, 62.0494400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122656, 'Bogashevo', 'Bogashevo', 'Bogashevo,Bogashevskiy,Bogasjevo,Богашево', 56.3679800, 85.1441400, 'RU', '2013-02-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122657, 'Bogandinskiy', 'Bogandinskiy', 'Bogandinskaya,Bogandinskij,Bogandinskiy,Bogandinskoye,Богандинский', 56.8937500, 65.8937800, 'RU', '2014-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122658, 'Bobrovskiy', 'Bobrovskiy', 'Bobrovskij,Bobrovskiy,Bobrovskoye,Бобровский', 56.6732000, 60.9807000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122659, 'Bobrovka', 'Bobrovka', 'Bobrovka,Bobrovskij,Bobrovskiy,Бобровка,Бобровский', 54.0470000, 61.7455000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122660, 'Bobrovka', 'Bobrovka', 'Bobrovka,Bobrovskii Zaton,Bobrovskoye,Бобровка', 53.1836100, 83.8763900, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122661, 'Blagoveshchenka', 'Blagoveshchenka', 'Blagoveshchenka,Blagoveshhenka,Blagovesjtsjenka,Благовещенка', 52.8333300, 79.8666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122662, 'Biysk', 'Biysk', 'Biejsk,Biisk,Bijs''k,Bijsk,Biscum,Bisk,Biysk,Biyusk,Mpisk,Viysk,bi si ke,biseukeu,Μπισκ,Бийск,Бійськ,比斯克,비스크', 52.5363900, 85.2072200, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122663, 'Biskamzha', 'Biskamzha', 'Biskamzha,Biskamzja,Бискамжа', 53.4497200, 89.5272200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122664, 'Biryusinsk', 'Biryusinsk', 'Birjusinsk,Biryusinsk,Suyetikha,Бирюсинск', 55.9634000, 97.8235000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122665, 'Beya', 'Beya', 'Beja,Beya,Бея', 53.0533300, 90.9138900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122666, 'Beryozovsky', 'Beryozovsky', 'Berjozovskij,Beryozovsky,Берёзовский', 56.9083000, 60.8019000, 'RU', '2014-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122667, 'Berëzovskiy', 'Berezovskiy', 'Berezovskij,Berezovskiy,Berjozovskij,Berëzovskiy,Березовский,Берёзовский', 55.6000000, 86.2000000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122668, 'Berëzovo', 'Berezovo', 'Berezov,Berezovo,Berjozovo,Berëzovo,EZV,Sugmut-Vozh,Берёзово', 63.9380600, 65.0419400, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122669, 'Berëzovka', 'Berezovka', 'Berejovskij,Bereyovski,Berezovka,Berezovskiy,Berezovskoi,Berezovskoye,Berjozovka,Berëzovka,Berëzovskiy,Berëzovskoi,Berëzovskoye,Березовка,Берёзовка', 56.0304400, 93.1116400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122670, 'Berëzovka', 'Berezovka', 'Berevovka,Berezovka,Berjozovka,Berëzovka,Березовка,Берёзовка', 52.3511100, 85.8272200, 'RU', '2013-10-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122671, 'Beregovoy', 'Beregovoy', 'Beregovoj,Beregovoy,Kharina,Kharino,Береговой', 55.1730100, 73.2198400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122672, 'Berdsk', 'Berdsk', 'Berds''k,Berdsk,Berdskas,Berdskoye,Bierdsk,Bjerdsk,Bordsk,Gorad Berdsk,beleucheukeu,bie er ci ke,brdsk,byrdsk,Бердск,Бердськ,Горад Бердск,بردسک,بيردسك,بیردسک,別爾茨克,베르츠크', 54.7551000, 83.0967000, 'RU', '2016-12-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122673, 'Belyy Yar', 'Belyy Yar', 'Bely Yar,Belyj Jar,Belyj-Jar,Belyy Yar,Белый Яр,Белый-Яр', 58.4447200, 85.0425000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122674, 'Belyy Yar', 'Belyy Yar', 'Belyj Jar,Belyy Yar,Naryl Koye,Narylkov,Белый Яр', 53.6038900, 91.3902800, 'RU', '2014-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122675, 'Belyashi', 'Belyashi', 'Beljashi,Beljasji,Belyashi,Беляши', 49.7333300, 87.4166700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122676, 'Belozërskoye', 'Belozerskoye', 'Belozerskoe,Belozerskoye,Belozjorskoe,Belozërskoye,Белозерское,Белозёрское', 55.8213900, 65.5841700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122677, 'Beloyarskiy', 'Beloyarskiy', 'Belojarskij,Beloyarskiy,EYK,Белоярский', 63.7119400, 66.6722200, 'RU', '2013-04-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122678, 'Beloyarskiy', 'Beloyarskiy', 'Belojarskij,Beloyarsk,Beloyarskiy,Beloyarskoye,Белоярский', 56.7584000, 61.4143000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122679, 'Beloyarsk', 'Beloyarsk', 'Belojarsk,Beloyarsk,Beloyarskoye,Белоярск', 53.4461000, 83.9048000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122680, 'Belovo', 'Belovo', 'Belova,Belovas,Belovo,Belovo i Russland,Belowo,Bielowo,Biełowo,Gorad Bjalova,bellobo,bie luo wo,blwfw  rwsyh,bylwfw,bylwww,Белово,Бєлово,Горад Бялова,بلوفو، روسیه,بيلوفو,بیلووو,別洛沃,벨로보', 54.4165000, 86.2976000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122681, 'Belokurikha', 'Belokurikha', 'Belokourikha,Belokuricha,Belokurih,Belokuriha,Belokurija,Belokurikha,Belokuriĥa,Belokúrija,Belokúrikha,Bielokuricha,Biełokuricha,Gorad Belakurykha,Novaya Belokurikha,Novobelokurikha,bellokuliha,bie luo ku li ha,blwkwrykha,bylwkwrykha,Белокуриха,Горад Белакурыха,بلوکوریخا,بيلوكوريخا,بیلوکوریخا,別洛庫里哈,벨로쿠리하', 51.9959000, 84.9896000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122682, 'Belogorsk', 'Belogorsk', 'Belogorsk,Kiya-Shaltyr'',Kiya-Shaltyr’,Белогорск', 55.0177800, 88.4897200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122683, 'Bayunovskiye Klyuchi', 'Bayunovskiye Klyuchi', 'Bajunovo,Bajunovskie Kljuchi,Bayunovo,Bayunovo-Klyuchi,Bayunovskiye Klyuchi,Баюново,Баюновские Ключи', 53.3280600, 84.1822200, 'RU', '2013-09-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122684, 'Baykit', 'Baykit', 'Baikit,Bajkit,Baykit,Байкит', 61.6769400, 96.3791700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122685, 'Bay-Khaak', 'Bay-Khaak', 'Baj-Khaak,Baj-Khak,Bay-Khaak,Bay-Khak,Baygak,Бай-Хаак,Бай-Хак', 51.1610500, 94.4637100, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122686, 'Baykalovo', 'Baykalovo', 'Bajkalovo,Baykalovo,Байкалово', 57.3981100, 63.7684100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122687, 'Bayevo', 'Bayevo', 'Baevo,Bajevo,Bayevo,Баево', 53.2706500, 80.7792100, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122688, 'Bastan', 'Bastan', 'Bastan,Бастан', 51.8588900, 79.4744400, 'RU', '2012-04-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122689, 'Barzas', 'Barzas', 'Barzas,Барзас', 55.7291200, 86.3223300, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122690, 'Baryshevo', 'Baryshevo', 'Barysheva,Baryshevo,Barysjevo,Барышево', 54.9564000, 83.1822000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122691, 'Barsovo', 'Barsovo', 'Barsovo,Барсово', 61.1666700, 73.1666700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122692, 'Barnaul', 'Barnaul', 'BAX,Barnaoel,Barnaoul,Barnauel,Barnaul,Barnaul - Barnaul,Barnaul - Барнау́л,Barnaula,Barnaulas,Barnaulia,Barnauyl,Barnauł,Barnaúl,Barnaül,Gorad Barnaul,Mparnaoul,ba er nao er,baleunaul,barna''ula,barnal,barnawl,barnaywl,barunauru,Μπαρναούλ,Барнаул,Барнауыл,Горад Барнаул,Բարնաուլ,ברנאול,بارنائول,بارنال,بارناول,बर्नाउल,バルナウル,巴尔瑙尔,바르나울', 53.3605600, 83.7636100, 'RU', '2016-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122693, 'Barabinsk', 'Barabinsk', 'Baraba,Barabins''k,Barabinsk,Barabinskas,Barabińsk,Baràbinsk,Gorad Barabinsk,ba la bin si ke,balabinseukeu,barabinsuku,barabynsk,Бараба,Барабинск,Барабінськ,Горад Барабінск,بارابينسك,بارابینسک,バラビンスク,巴拉賓斯克,바라빈스크', 55.3570900, 78.3569700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122694, 'Baraba', 'Baraba', 'Baraba,Бараба', 56.7500000, 61.7666700, 'RU', '2012-07-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122695, 'Balgazyn', 'Balgazyn', 'Balgazik,Balgazin,Balgazun,Balgazyn,Балгазын', 51.0000000, 95.2000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122696, 'Balakhta', 'Balakhta', 'Balakhta,Балахта', 55.3842500, 91.6187200, 'RU', '2013-11-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122697, 'Bakchar', 'Bakchar', 'Bakchar,Baktsjar,Бакчар', 57.0186100, 82.0711100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122698, 'Bagan', 'Bagan', 'Bagan,Karasinskiy,Баган', 54.1001400, 77.6646200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122699, 'Bachatskiy', 'Bachatskiy', 'Bachatskij,Bachatskiy,Бачатский', 54.2927000, 86.1285000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122700, 'Azovo', 'Azovo', 'Azovo,Azovskoye,Азово', 54.6997200, 73.0236700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122701, 'Azanka', 'Azanka', 'Azanka,Азанка', 58.0401200, 64.7892700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122702, 'Aya', 'Aya', 'Aja,Aya,Ayskoye,Ая', 51.9453200, 85.8016800, 'RU', '2010-08-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122703, 'Atagay', 'Atagay', 'Atagaj,Atagay,Атагай', 55.1033000, 99.3875000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122704, 'Askiz', 'Askiz', 'Askiz,Аскиз', 53.1372200, 90.4283300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122705, 'Askiz', 'Askiz', 'Askiz,Askysskoye,Askyzskoye,Аскиз', 53.1319400, 90.5263900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122706, 'Asino', 'Asino', 'Asinas,Asino,Assino,Gorad Asina,a xi nuo,ashino,asino,asynw,Асино,Асіно,Горад Асіна,آسینو,أسينو,اسینو,アシノ,阿西诺,아시노', 56.9998700, 86.1439300, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122707, 'Asbestovskiy', 'Asbestovskiy', 'Asbestovskij,Asbestovskiy,Asbestovyy,Асбестовский', 57.7557400, 61.3967200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122708, 'Asbest', 'Asbest', 'Asbest,Asbest i Russland,Asbestas,Asbiest,Asmpest,Gorad Asbest,a si bie si te,asbst,asbyst,aseubeseuteu,asubesuto shi,Ασμπέστ,Асбест,Горад Асбест,Әсбест,אסבסט,آسبست,أسبيست,اسبست,اسبیست,アスベスト市,阿斯别斯特,아스베스트', 57.0099300, 61.4577600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122709, 'Artyshta', 'Artyshta', 'Artyshta,Artyshtinskaya,Артышта', 54.1222000, 86.2909000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122710, 'Artybash', 'Artybash', 'Artybash,Artybasj,Артыбаш', 51.7927800, 87.2761100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122711, 'Artëmovskiy', 'Artemovskiy', 'Artemovsk,Artemovski,Artemovskij,Artemovskiy,Artjomovskij,Artëmovskiy,Yegorshina,Yegorshino,Yegorshinskiye Kopi,Артемовский,Артёмовский', 57.3555000, 61.8686500, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122712, 'Aromashevo', 'Aromashevo', 'Aromashevo,Aromasjevo,Аромашево', 56.8601800, 68.6375400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122713, 'Armizonskoye', 'Armizonskoye', 'Armizonskoe,Armizonskoje,Armizonskoye,Армизонское', 55.9461100, 67.6736100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122714, 'Argayash', 'Argayash', 'Argajash,Argayash,Аргаяш', 55.4888000, 60.8767000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122715, 'Aramil', 'Aramil', 'Aramil,Aramil'',Aramilis,Aramiľ,Gorad Aramil'',a la mi er,alamil,aramyl,Αραμίλ,Арамил,Арамиль,Арамиљ,Араміль,Горад Араміль,Әрәмәле,آرامیل,أراميل,ارامیل,阿拉米爾,아라밀', 56.6977000, 60.8369000, 'RU', '2014-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122716, 'Anzhero-Sudzhensk', 'Anzhero-Sudzhensk', 'Anjero-Sudjensk,Anschero-Sudschensk,Anshero-Sudshensk,Anzero-Sudzensk,Anzherka,Anzhero-Sudzhenka,Anzhero-Sudzhensk,Anzhero-Sujensk,Anĵero-Sudĵensk,Anžero-Sudžensk,Sudzhenka,anjelosujenseukeu,Анжеро-Судженск,안제로수젠스크', 56.0810000, 86.0285000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122717, 'Anton’yevka', 'Anton''yevka', 'Anton''evka,Anton''yevka,Anton''yevskoye,Antonjevskoje,Antonovskaya,Antonovskoye,Antonoyskaya,Anton’yevka,Anton’yevskoye,Антоньевка', 51.9961000, 83.9740000, 'RU', '2013-11-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122718, 'Antipino', 'Antipino', 'Antipina,Antipino,Антипино', 57.1067900, 65.7575500, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122719, 'Andra', 'Andra', 'Andra,Karakarskiye,Андра', 62.5147200, 65.8877800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122720, 'Alzamay', 'Alzamay', 'Alzamaj,Alzamay,Alzamayskoye,Алзамай', 55.5562000, 98.6644000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122721, 'Altayskoye', 'Altayskoye', 'Altaisk,Altaiskoe,Altajskij,Altajskoe,Altayskiy,Altayskoye,Алтайский,Алтайское', 51.9533300, 85.3325000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122722, 'Aleysk', 'Aleysk', 'Aleisk,Aleiskas,Alejs''k,Alejsk,Aleysk,Aleyskaya,Aleyskoye,Aleïsk,Gorad Alejsk,a lie yi si ke,alesaka,alleiseukeu,alysk,Алейск,Алейськ,Алејск,Горад Алейск,Ալեյսկ,آلیسک,أليسك,الیسک,ਅਲੇਸਕ,阿列伊斯克,알레이스크', 52.4926000, 82.7822000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122723, 'Aleksandrovskoye', 'Aleksandrovskoye', 'Aleksandrovka,Aleksandrovskoe,Aleksandrovskoje,Aleksandrovskoye,Александровское', 56.7408300, 85.3905600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122724, 'Alapayevsk', 'Alapayevsk', 'Alapaevs''k,Alapaevsk,Alapajevsk,Alapajewsk,Alapayevsk,Alpaevsk,Ałapajewsk,Алапаевск,Алапаєвськ,Алапајевск', 57.8515800, 61.6962700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122725, 'Aktash', 'Aktash', 'Aktash,Акташ', 50.3000000, 87.7333300, 'RU', '2013-07-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122726, 'Aksarka', 'Aksarka', 'Aksarka,Oksarka,Аксарка', 66.5605600, 67.7975000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122727, 'Ak-Dovurak', 'Ak-Dovurak', 'Ak Dovurakas,Ak-Dovoerak,Ak-Dovourak,Ak-Dovurak,Ak-Dowurak,Ak-Tovurak,Gorad Ak-Davurak,a ke duo wu la ke,agdobulag,ak dwwwrak,ak-dwwwrak,aka-dovuraka,akl-dwfwrak,Ак-Довурак,Горад Ак-Давурак,آک-دوووراک,أكل-دوفوراك,اک دوووراک,ਅਕ-ਡੋਵੂਰਾਕ,阿克多武拉克,악도부락', 51.1833300, 90.6000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122728, 'Akademgorodok', 'Akademgorodok', 'Akademgorodok,Akademicheskiy Gorodok,Gorod Nauki,Novosibirskij Akademgorodok,Novosibirskiy Nauchnyy Tsentr,Science City,akademgolodokeu,akademugorodoku,akadymjwrwdwk,Академгородок,Новосибирский Академгородок,أكاديمجورودوك,アカデムゴロドク,아카뎀고로도크', 54.8523000, 83.1060000, 'RU', '2015-11-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122729, 'Agirish', 'Agirish', 'Agirish,Akrysh,Агириш', 61.9247200, 63.0230600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122730, 'Aginskoye', 'Aginskoye', 'Aginskoe,Aginskoje,Aginskoye,Агинское', 55.2586000, 94.9079000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122731, 'Achinsk', 'Achinsk', 'ACS,Achins''k,Achinsk,Acinsk,Acinska,Acinskas,Aczynsk,Aczyńsk,Atchinsk,Atjinsk,Atschinsk,Atsinsk,Atsjinsk,Atxinsk,Atšinsk,Açinsk,Aĉinsk,Ačinsk,Ačinska,Ačinskas,Gorad Achynsk,a qin si ke,achinseukeu,achinsuku,achynsk,akisaka,atshynsk,Àtxinsk,Áchinsk,Ачинск,Ачинськ,Горад Ачынск,آچینسک,أتشينسك,اچینسک,ਅਕਿੰਸਕ,アチンスク,阿钦斯克,아친스크', 56.2694000, 90.4993000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122732, 'Abaza', 'Abaza', 'Abasa,Abaz,Abaza,Abazá,Gorad Abaza,a ba zha,abaza,abaza shhr,Абаза,Горад Абаза,آبازا,آبازا،شهر,أبازا,ابازا,ਅਬਾਜ਼ਾ,阿巴扎', 52.6550000, 90.0927800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122733, 'Abatskoye', 'Abatskoye', 'Abatskij,Abatskiy,Abatskoe,Abatskoye,Абатский,Абатское', 56.2874800, 70.4555300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122734, 'Aban', 'Aban', 'Aban,Alban,Абан', 56.6787000, 96.0658000, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122735, 'Abalak', 'Abalak', 'Abalak,Abalakskoye,Абалак', 58.1286100, 68.5944400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122736, 'Abakan', 'Abakan', 'ABA,Abakan,Abakan shaary,Abakana,Abakanas,Abakanskoye,Abakán,Agban,Ampakan,Gorad Abakan,a ba kan,abakan,abakana,Αμπακάν,Абакан,Абакан шаары,Ағбан,Горад Абакан,Աբական,آباکان,أباكان,اباکان,अबाकान,ਅਬਾਕਾਨ,アバカン,阿巴坎,아바칸', 53.7155600, 91.4291700, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122737, 'Abagur', 'Abagur', 'Abagur,Abinskaya,Абагур', 53.7308000, 87.2526000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122738, 'Ursk', 'Ursk', 'Barit,Ursk,Urskoe,Urskoje,Zvonchikha,Барит,Урское', 54.4541700, 85.4002800, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122739, 'Snezhinsk', 'Snezhinsk', 'Cheljabinsk-70,Chelyabinsk-70,Gorad Snezhynsk,Semidesjatka,Semidesyatka,Snejinsk,Sneschinsk,Snezhins''k,Snezhinsk,Snezinsk,Snezjinsk,Sneĵinsk,Snežinsk,Sniezynsk,Snieżynsk,Sněžinsk,asnzhynsk,si nie ren si ke,snjynsk,snyzhynsk,Горад Снежынск,Семидесятка,Снежинск,Снєжинськ,Челябинск-70,اسنژینسک,سنجينسك,سنیژینسک,斯涅任斯克', 56.0850000, 60.7313900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122740, 'Shuvakish', 'Shuvakish', 'Shuvakish,Шувакиш', 56.9187000, 60.4772700, 'RU', '2013-09-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122741, 'Istok', 'Istok', 'Istok,Kompressornyj,Kompressornyy,Исток,Компрессорный', 56.7908600, 60.7788900, 'RU', '2014-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122742, 'Priob’ye', 'Priob''ye', 'Priob''e,Priob''ye,Priobje,Priob’ye,Приобье', 62.5205600, 65.5963900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122743, 'Il’ichevo', 'Il''ichevo', 'Il''ichevo,Ilitsjevo,Il’ichevo,Sovkhoz Imeni Il''icha,Sovkhoz Imeni Il’icha,Ильичево', 53.2788900, 91.8402800, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122744, 'Tanzybey', 'Tanzybey', 'Tanzibey,Tanzybej,Tanzybey,Танзыбей', 53.1326500, 92.9433500, 'RU', '2013-06-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122745, 'Ozersk', 'Ozersk', 'Chelyabinsk-40,Chelyabinsk-65,Ozersk,Ozjorsk,Озёрск', 55.7555600, 60.7027800, 'RU', '2014-04-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122746, 'Zheleznogorsk', 'Zheleznogorsk', 'Atomgrad,Devyatka,Krasnoyarsk-26,Krasnoyarsk-9,Zeleznogorsk,Zheleznogorsk,Zjeleznogorsk,Železnogorsk,Железногорск', 56.2511100, 93.5319400, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122747, 'Novoural’sk', 'Novoural''sk', 'Novoural''sk,Novoural’sk,Sverdlovsk-44,Verkh-Nejvinskij,Верх-Нейвинский,Новоуральск', 57.2438900, 60.0838900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122748, 'Seversk', 'Seversk', 'Gorad Seversk,Severs''k,Seversk,Severskas,Sewersk,Sewjersk,Siewiersk,Sèversk,Tomsk-7,sebeleuseukeu,sevu~erusuku,swrsk,sywrsk,xie wei er si ke,Горад Северск,Северск,Сєвєрськ,سورسک,سیورسک,セヴェルスク,謝韋爾斯克,세베르스크', 56.6005600, 84.8863900, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122749, 'Lokomotivnyy', 'Lokomotivnyy', 'Kartaly-Shest'',Kartaly-Shest’,Lokomotivnyj,Lokomotivnyy,Локомотивный', 53.0118000, 60.5684000, 'RU', '2012-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122750, 'Solnechnyy', 'Solnechnyy', 'Solnechnyj,Solnechnyy,Uzhur-4,Солнечный', 56.1158300, 92.9252800, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122751, 'Svobodnyy', 'Svobodnyy', 'Nizhniy Tagil-39,Svobodnyj,Svobodnyy,Свободный', 58.0397200, 60.3961100, 'RU', '2014-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122752, 'Kedrovyy', 'Kedrovyy', 'Kedrovyj,Kedrovyy,Krasnoyarsk-66,Кедровый', 56.2823200, 91.5376000, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122753, 'Sibirskiy', 'Sibirskiy', 'Pervomayskiy,Sibirskij,Sibirskiy,Sibirskoye,Сибирский', 53.5777000, 83.7577000, 'RU', '2012-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122754, 'Malinovskiy', 'Malinovskiy', 'Malinovskij,Malinovskiy,Малиновский', 61.1952800, 62.8397200, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122755, 'Novyye Zori', 'Novyye Zori', 'Novye Zori,NovyeZori,Novyye Zori,Новые Зори,НовыеЗори', 53.2477800, 83.4250000, 'RU', '2012-05-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122756, 'Gubkinskiy', 'Gubkinskiy', 'Gubkinskij,Губкинский', 64.4340000, 76.5026100, 'RU', '2010-06-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122757, 'Purpe', 'Purpe', 'Purpe,Пурпе', 64.4802800, 76.6897200, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122758, 'Iogach', 'Iogach', 'Iogach,Iogatsj,Иогач', 51.7816700, 87.2630600, 'RU', '2012-05-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122759, 'Raduzhny', 'Raduzhny', 'Gorad Raduzhny,RAT,Radoujny,Radujnij,Radujniy,Radujnıy,Raduschny,Raduzhni,Raduzhny,Raduzhnyj,Raduzjnyj,Raduzjnyj i Khanty-Mansia,Raduznas,Raduznoi,Raduzny,Raduznyi,Raduznyj,Raduĵnij,Radużny,Radužnas,Radužnyi,Radužnyj,Radužnõi,la du ri nei,ladujeuni,rado~ujinui,radwjny,radwzhny  khanty-mansy,Горад Радужны,Радужни,Радужный,رادوجني,رادوژنی، خانتی-مانسی,ラードゥジヌイ,拉杜日內,라두즈니', 62.0961100, 77.4750000, 'RU', '2013-11-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122760, 'Turtas', 'Turtas', 'Turtas,Туртас', 58.9386700, 69.1339300, 'RU', '2012-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122761, 'Kedrovyy', 'Kedrovyy', 'Kedrovyj,Kedrovyy,Кедровый', 57.5197200, 79.5155600, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122762, 'Muravlenko', 'Muravlenko', 'Gorad Muraulenka,Moeravlenko,Mouravlenko,Muravlenkas,Muravlenko,Murawlenko,mu la fu lian ke,mwrawlnkw,mywraflnkw,Горад Мураўленка,Муравленко,מוראבלנקו,موراولنکو,ميورافلنكو,穆拉夫連科', 63.7897700, 74.5230100, 'RU', '2009-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122763, 'Starokamyshinsk', 'Starokamyshinsk', 'Starokamyshinsk,Starokamysjinsk,Старокамышинск', 55.0391200, 61.5877800, 'RU', '2012-12-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122764, 'Timiryazevskiy', 'Timiryazevskiy', 'Timirjazevskij,Timirjazvskij,Timiryazevskiy,Тимирязвский,Тимирязевский', 54.9291700, 60.7625000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122765, 'Bazhovo', 'Bazhovo', 'Bazhovo,Bazjovo,Imeni Bazhova,Бажово', 55.0595500, 61.6044500, 'RU', '2012-12-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122766, 'Roshchino', 'Roshchino', 'Roshchino,Roshhino,Рощино', 55.3101200, 61.2636300, 'RU', '2012-12-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122767, 'Lyantor', 'Lyantor', 'Ljantor,Lyantorskiy,Лянтор', 61.6194500, 72.1554600, 'RU', '2009-12-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122768, 'Sadovyy', 'Sadovyy', 'Sadovyj,Sadovyy,Садовый', 55.1361000, 82.9659000, 'RU', '2015-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122769, 'Uyskoye', 'Uyskoye', 'Ujskoe,Ujskoje,Uyskoye,Уйское', 54.3775000, 60.0047200, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122770, 'Krasnyy Chikoy', 'Krasnyy Chikoy', 'Krasnoy Chikoy,Krasny Chikoy,Krasnyi Chikoi,Krasnyj Chikoj,Krasnyj Tsjikoj,Krasnyy Chikoy,Красный Чикой', 50.3632100, 108.7544500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122771, 'Zvëzdnyy', 'Zvezdnyy', 'Zvezdnyj,Zvezdnyy,Zvjozdnyj,Zvëzdnyy,Звездный,Звёздный', 56.7492000, 106.4799000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122772, 'Zima', 'Zima', 'Gorad Zima,Sima,Zima,Zimà,ji ma,zyma,Горад Зіма,Зима,زيما,زیما,济马', 53.9202000, 102.0442000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122773, 'Zhireken', 'Zhireken', 'Zhireken,Zjireken,Жирекен', 52.8265700, 117.3072500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122774, 'Zhigansk', 'Zhigansk', 'Shigansk,ZIX,Zhigansk,Zjigansk,Жиганск', 66.7660100, 123.3741800, 'RU', '2013-08-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122775, 'Zhigalovo', 'Zhigalovo', 'Zhigalovo,Zjigalovo,Жигалово', 54.8106100, 105.1580800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122776, 'Zhemchug', 'Zhemchug', 'Baga-Gorkhon,Bogo-Gorkhon,Bokho-Gorkhon,Boto-Gorkhon,Bukhogirknon'',Bukhogirknon’,Zhemchug,Zjemtsjug,Бого-Горхон,Жемчуг', 51.6861000, 102.4590000, 'RU', '2013-10-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122777, 'Zheleznogorsk-Ilimskiy', 'Zheleznogorsk-Ilimskiy', 'Korshunikha,Zheleznogorsk,Zheleznogorsk-Ilimskij,Zheleznogorsk-Ilimskiy,Zjeleznogorsk-Ilimskij,Железногорск-Илимский', 56.5768000, 104.1217000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122778, 'Zheleznodorozhnyy', 'Zheleznodorozhnyy', 'Zheleznodorozhnyj,Zheleznodorozhnyy,Zjeleznodorozjnyj,Железнодорожный', 57.9052500, 102.7783800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122779, 'Zhatay', 'Zhatay', 'Zhataj,Zhatay,Zhataystroy,Жатай', 62.1597500, 129.8284300, 'RU', '2014-08-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122780, 'Zharikovo', 'Zharikovo', 'Karikovo,Zharikovo,Zjarikovo,Жариково', 44.5880000, 131.7277000, 'RU', '2013-10-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122781, 'Zeya', 'Zeya', 'Seja,Zeja,Zeya,Зея', 53.7360100, 127.2570000, 'RU', '2013-12-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122782, 'Zavodskoy', 'Zavodskoy', 'Zavodskoj,Zavodskoy,Заводской', 43.4624200, 132.2849400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122783, 'Zavitinsk', 'Zavitinsk', 'Gorad Zavicinsk,Sawitinsk,Zavitaya,Zavitins''k,Zavitinsk,jabitinseukeu,zafytynsk,zawytynsk,zha wei jing si ke,Горад Завіцінск,Завитинск,Завітінськ,زافيتينسك,زاویتینسک,扎维京斯克,자비틴스크', 50.1111800, 129.4415600, 'RU', '2013-12-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122784, 'Zarubino', 'Zarubino', 'Zarubino,Зарубино', 42.6325700, 131.0900500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122785, 'Zarechnyy', 'Zarechnyy', 'Zarechnyj,Zarechnyy,Zaretsjnyj,Заречный', 51.8492800, 107.5210000, 'RU', '2013-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122786, 'Zalari', 'Zalari', 'Zalari,Залари', 53.5584000, 102.5065000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122787, 'Zakamensk', 'Zakamensk', 'Gorad Zakamensk,Gorodok,Sakamensk,Zakamens''k,Zakamensk,Zakamenskas,Zakamiensk,Zakhaamin khot,Zakàmensk,Zakámensk,jakamenseukeu,zakamnsk,zakamynsk,zha ka mian si ke,Горад Закаменск,Закаменск,Закаменск балһсн,Закаменськ,Захаамин хот,زاكامينسك,زاکامنسک,扎卡缅斯克,자카멘스크', 50.3741000, 103.2863000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122788, 'Zaigrayevo', 'Zaigrayevo', 'Zaigraeve,Zaigraevo,Zaigrajevo,Zaigrakvo,Zaigrayeva,Zaigrayevo,Заиграево', 51.8348700, 108.2670000, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122789, 'Zabaykal’sk', 'Zabaykal''sk', 'Otpor,Zabajkal''sk,Zabajkalsk,Zabaykal''sk,Zabaykal’sk,Забайкальск', 49.6513000, 117.3255700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122790, 'Ytyk-Kyuyël’', 'Ytyk-Kyuyel''', 'Ityk-Kel,Ytyk-Kel'',Ytyk-Kel’,Ytyk-Kjuel,Ytyk-Kyuyel'',Ytyk-Kyuyël'',Ytyk-Kyuyël’,ytyk-Kjujol'',Ытык-Кюёль', 62.3611900, 133.5604400, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122791, 'Yerofey Pavlovich', 'Yerofey Pavlovich', 'Erofei Pavlovich,Erofej Pavlovich,Erofey-Palvovich,Jerofej Pavlovitsj,Yerofei Pavlovich,Yerofey Pavlovich,Ерофей Павлович', 53.9630500, 121.9580500, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122792, 'Yerbogachen', 'Yerbogachen', 'ERG,Erbogachen,Jerbogatsjen,Yerbogachen,Yerbogachën,Ербогачен', 61.2801600, 108.0153500, 'RU', '2013-04-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122793, 'Yelantsy', 'Yelantsy', 'Elancy,Jelantsy,Yelantsy,Еланцы', 52.8028600, 106.4046600, 'RU', '2014-05-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122794, 'Yekaterinovka', 'Yekaterinovka', 'Ekaterinovka,Jekaterinovka,Yekateranovka,Yekaterinovka,Екатериновка', 42.9252500, 133.0492200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122795, 'Yekaterinoslavka', 'Yekaterinoslavka', 'Ekaterinoslavka,Jekaterinoslavka,Kaganovich,Yekaterinoslavka,Yekaterinoslovka,Екатеринославка', 50.3734400, 129.1095700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122796, 'Yedogon', 'Yedogon', 'Edogon,Jedogon,Yedogon,Едогон', 54.2549000, 100.2385000, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122797, 'Yaroslavskiy', 'Yaroslavskiy', 'Jaroslavskij,Yaroslavskiy,Ярославский', 44.1857800, 132.2286200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122798, 'Yakutsk', 'Yakutsk', 'D''okuuskaj,Jakutsk,YKS,Yakutsk,Yerkutsk,yakucheukeu,Дьокуускай,Якутск,야쿠츠크', 62.0338900, 129.7330600, 'RU', '2017-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122799, 'Yakovlevka', 'Yakovlevka', 'Jakovlevka,Yakovlevka,Яковлевка', 44.4258800, 133.4740600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122800, 'Vysokogornyy', 'Vysokogornyy', 'Muli,Vysokogornyj,Vysokogornyy,Высокогорный', 50.0988500, 139.1228400, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122801, 'Rechka-Vydrino', 'Rechka-Vydrino', 'Rechka Vydrino,Rechka-Vydrino,Vodrinskiy,Vydrino,Vydrinski,Vydrinskiy,Выдрино,Речка-Выдрино', 51.4892000, 104.8429000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122802, 'Vydreno', 'Vydreno', 'Shezhnaya Vydrino,Vidrino,Vydreno,Vydrino,Выдрено', 51.4630000, 104.6425000, 'RU', '2013-08-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122803, 'Vyazemskiy', 'Vyazemskiy', 'Vjazemskij,Vyazemskaya,Vyazemskiy,Vyazemskoye,Вяземский', 47.5375700, 134.7555600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122804, 'Vrangel’', 'Vrangel''', 'Vrangel,Vrangel'',Vrangel’,Врангель', 42.7302100, 133.0832200, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122805, 'Vozdvizhenka', 'Vozdvizhenka', 'Vozdvizhenka,Vozdvizjenka,Воздвиженка', 43.8941300, 131.9458900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122806, 'Vostok', 'Vostok', 'Vostok,Vostok Vtoroy,Восток', 46.4514800, 135.8273800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122807, 'Volochayevka Vtoraya', 'Volochayevka Vtoraya', 'Volochaevka Vtoraja,Volochaevka-Vtoraja,Volochayevka Vtoraya,Volotsjajevka-Vtoraja,Vtoraya Volochayevka,Волочаевка Вторая,Волочаевка-Вторая', 48.5669500, 134.5823200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122808, 'Vol’no-Nadezhdinskoye', 'Vol''no-Nadezhdinskoye', 'Vol''no-Nadezhdinskoe,Vol''no-Nadezhdinskoye,Vol''no-Nadyezhdinskoye,Volno-Nadezjdinskoje,Vol’no-Nadezhdinskoye,Vol’no-Nadyezhdinskoye,Вольно-Надеждинское', 43.3749600, 131.9967500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122809, 'Volchanets', 'Volchanets', 'Volchanec,Volchanets,Voltsjanets,Волчанец', 42.9138800, 132.7622200, 'RU', '2016-04-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122810, 'Vladivostok', 'Vladivostok', 'Bladibostok,Gorad Uladzivastok,VVO,Vladivostok,Vladivostoka,Vladivostokas,Vladivostokium,Vlagyivosztok,Wladiwostok,Wladywostok,Władywostok,beulladiboseutokeu,fladyfwstwk,hai can wai,hai can wei,urajiosutoku,vilativostok,vladivastak,vladivostoka,w la di wx s txkh,wladywstwk,wldywwstwq,Βλαδιβοστόκ,Владивосток,Горад Уладзівасток,Վլադիվոստոկ,וולאדיוואסטאק,ולדיווסטוק,فلاديفوستوك,ولادیوستوک,ولادی‌وؤستؤک,ولادی‌وستوک,ولاڈیووسٹوک,व्लादिवोस्तॉक,व्लादिवोस्तोक,விலாடிவொஸ்டொக்,ವ್ಲಾಡಿವಾಸ್ಟಾಕ್,วลาดีวอสตอค,ვლადივოსტოკი,ウラジオストク,海参崴,海參崴,블라디보스토크', 43.1056200, 131.8735300, 'RU', '2010-08-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122811, 'Vladimiro-Aleksandrovskoye', 'Vladimiro-Aleksandrovskoye', 'Aleksandrovka,Aleksandrovskoe,Alexandrovka,Vladimir,Vladimiro-Aleksandrovskoe,Vladimiro-Aleksandrovskoje,Vladimiro-Aleksandrovskoye,Vladimirovka,Владимиро-Александровское', 42.8913400, 133.0780100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122812, 'Vitim', 'Vitim', 'Vitim,Витим', 59.4432600, 112.5699300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122813, 'Vilyuysk', 'Vilyuysk', 'Gorad Viljujsk,VYI,Viliouisk,Viliouïsk,Viliuisk,Viliujskas,Viliúisk,Viljoejsk,Viljuisk,Viljujsk,Viljujszk,Vilueisk,Vilujsk,Vilujska,Vilyuisk,Vilyusk,Vilyuysk,Vilüisk,Viļujska,Wiljuisk,Wilujsk,billyuiseukeu,fylywysk,vu~iryuisuku,wei liu yi si ke,wylywysk,Бүлүү,Вилюйск,Виљујск,Горад Вілюйск,فيليويسك,ویلیویسک,ヴィリュイスク,维柳伊斯克,빌류이스크', 63.7468300, 121.6333900, 'RU', '2013-09-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122814, 'Vikhorevka', 'Vikhorevka', 'Vikhorevka,Вихоревка', 56.1212800, 101.1776700, 'RU', '2012-08-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122815, 'Vidim', 'Vidim', 'Vidim,Видим', 56.4088000, 103.1106000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122816, 'Vershino-Shakhtaminskiy', 'Vershino-Shakhtaminskiy', 'Verchin-Shakhtaminskiy,Verkhne-Shaktama,Verkhnyaya Shakhtama,Vershino-Shakhtaminskij,Vershino-Shakhtaminskiy,Versjino-Sjakhtaminskij,Вершино-Шахтаминский', 51.3002400, 117.8876200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122817, 'Vershino-Darasunskiy', 'Vershino-Darasunskiy', 'Darasun,Vershina Darasuna,Vershino-Darasunskij,Vershino-Darasunskiy,Versjino-Darasunskij,Вершино-Дарасунский', 52.3660400, 115.5266100, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122818, 'Verkh-Usugli', 'Verkh-Usugli', '', 52.7000000, 115.1666700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122819, 'Verkhoyansk', 'Verkhoyansk', 'Verchojansk,Verchojanskas,Verhojansk,Verkhoiansk,Verkhojansk,Verkhoyansk,Verkhoïansk,Verĥojansk,Werchojansk,Wierchojansk,Wierchojańsk,beleuhoyanseukeu,beruhoyansuku,Верхоянск,ורחויאנסק,ベルホヤンスク,베르호얀스크', 67.5538700, 133.3897600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122820, 'Verkhnevilyuysk', 'Verkhnevilyuysk', 'VHV,Verkhneviljujsk,Verkhnevilyuysk,Верхневилюйск', 63.4457800, 120.3073900, 'RU', '2013-09-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122821, 'Vanavara', 'Vanavara', 'Faktoriya Vanavar,Vanavara,Vanovara,Ванавара', 60.3467900, 102.2843400, 'RU', '2013-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122822, 'Ust’-Uda', 'Ust''-Uda', 'Ust''-Uda,Ust-Uda,Ust’-Uda,Усть-Уда', 54.1742000, 103.0304000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122823, 'Ust’-Ordynskiy', 'Ust''-Ordynskiy', 'Kargana,Ust''-Orda,Ust''-Ordynskij,Ust''-Ordynskiy,Ust-Ordynskij,Ust’-Orda,Усть-Ордынский', 52.8050000, 104.7508300, 'RU', '2010-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122824, 'Ust-Maya', 'Ust-Maya', 'UMS,Ust Maisk,Ust''-Maja,Ust''-Mayskoye,Ust-Maiskoe,Ust-Maja,Ust-Maya,Ust’-Mayskoye,Усть-Мая', 60.4155300, 134.5440500, 'RU', '2013-09-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122825, 'Ust-Kuyga', 'Ust-Kuyga', 'UKG,Ust''-Kujga,Ust-Kujga,Ust-Kuyga,Усть-Куйга', 70.0020800, 135.5487600, 'RU', '2013-09-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122826, 'Ust’-Kut', 'Ust''-Kut', 'UKX,Ust Kutsk,Ust''-Kut,Ust-Kut,Ust’-Kut,Усть-Кут', 56.7938000, 105.7672000, 'RU', '2017-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122827, 'Ust’-Karsk', 'Ust''-Karsk', 'Ust''-Karsk,Ust-Kara,Ust-Karsk,Ust’-Karsk,Усть-Карск', 52.7020600, 118.8016300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122828, 'Ust’-Ilimsk', 'Ust''-Ilimsk', 'UIK,Ust''-Ilimsk,Ust-Ilimsk,Ust’-Ilimsk,Усть-Илимск', 58.0005600, 102.6619400, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122829, 'Ust’-Barguzin', 'Ust''-Barguzin', 'Ust Batguzin,Ust''-Barguzin,Ust-Barguzin,Ust’-Barguzin,Усть-Баргузин', 53.4111600, 109.0310300, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122830, 'Ussuriysk', 'Ussuriysk', 'Lungsod ng Ussurijsk,Nikol''sk-Ussuriyskiy,Nikolaevsk-Ussuri,Nikol’sk-Ussuriyskiy,Oessoeriejsk,Ussuriisk,Ussurijsk,Ussuriysk,Ussuryjsk,Usszurijszk,Voroshilov,usuliseukeu,usurisuku,wu su li si ke,Уссурийск,ウスリースク,乌苏里斯克,우수리스크', 43.8029100, 131.9457800, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122831, 'Usol’ye-Sibirskoye', 'Usol''ye-Sibirskoye', 'Isol''ye-Sibirskoye,Isol’ye-Sibirskoye,Usel''ye-Sibirskoye,Usel’ye-Sibirskoye,Usol''e-Sibirskoe,Usol''ye,Usol''ye-Sibirskoye,Usole Sibirskoe,Usolje-Sibirskoje,Usol’ye,Usol’ye-Sibirskoye,Усолье-Сибирское', 52.7519400, 103.6452800, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122832, 'Ushumun', 'Ushumun', 'Ushumun,Usjumun,Ушумун', 52.7863300, 126.5376700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122833, 'Urusha', 'Urusha', 'Urusha,Urusja,Уруша', 54.0530300, 122.8856100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122834, 'Urik', 'Urik', 'Urik,Урик', 52.4605100, 104.2401600, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122835, 'Ulety', 'Ulety', 'Ulety,Uljoty,Ulëty,Улёты', 51.3558900, 112.4843000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122836, 'Ulan-Ude', 'Ulan-Ude', 'Oelan-Oede,Oulan Ounte,UUD,Ulaan-Udeh,Ulaan-Үdeh,Ulan Ude,Ulan Udė,Ulan-Ude,Ulan-Udeh,Ulan-Udè,Ulán-Udé,Ułan-Ude,Verkhne-Udinsk,Verkhneudinsk,ullan-ude,wu lan wu de,Ουλάν Ουντέ,Верхнеудинск,Улаан-Удэ,Улаан-Үдэ,Улан Уде,Улан-Удэ,אולן-אודה,ウラン・ウデ,烏蘭烏德,울란우데', 51.8272100, 107.6062700, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122837, 'Uglovoye', 'Uglovoye', 'Uglovaya,Uglovoe,Uglovoje,Uglovoye,Угловое', 43.3280700, 132.0883200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122838, 'Uglekamensk', 'Uglekamensk', 'Severnyy Suchan,Uglekamensk,Углекаменск', 43.2199600, 133.2317700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122839, 'Udachny', 'Udachny', 'Gorad Udachny,Novyy,Oedatsjny,Oudatchny,PYJ,Pribut,Udachnaj,Udachnaya,Udachni,Udachnij,Udachnoye,Udachny,Udachnyj,Udacnas,Udacnii,Udacnij,Udacnija,Udacnyj,Udacznyj,Udatschny,Udatsjnij,Udatsjnyj,Udatsnyi,Udatxni,Udatšnyi,Udaĉnij,Udačnas,Udačnii,Udačnija,Udačnyj,awdachny,awdatshny,udachini,udachinui,wu da qi nei,Горад Удачны,Удачнай,Удачни,Удачний,Удачный,أوداتشني,اوداچنی,ウダーチヌイ,乌达奇内,우다치니', 66.4298900, 112.4021000, 'RU', '2013-05-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122840, 'Tyrma', 'Tyrma', 'Tyrma,Тырма', 50.0477000, 132.1501100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122841, 'Tyret’ Pervaya', 'Tyret'' Pervaya', 'Pervaya Tyret'',Pervaya Tyret’,Tyret'',Tyret'' 1-ya (Pervaya),Tyret'' Pervaja,Tyret'' Pervaya,Tyret’,Tyret’ 1-ya (Pervaya),Tyret’ Pervaya,Тыреть Первая', 53.6702800, 102.3105600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122842, 'Tynda', 'Tynda', 'Gorad Tynda,TYD,Tind,Tinda,Tonda,Tonda Winter Camp,Tynda,Tyndinskiy,Tõnda,Tönda Winter Camp,teng da,tinda,tynda,Горад Тында,Тинда,Тында,تيندا,تیندا,ティンダ,滕达,틴다', 55.1560000, 124.7247900, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122843, 'Tygda', 'Tygda', 'Tygda,Тыгда', 53.1116900, 126.3290700, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122844, 'Turuntayevo', 'Turuntayevo', 'Turuntaevo,Turuntajevo,Turuntayevo,Турунтаево', 52.2020300, 107.6448400, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122845, 'Turka', 'Turka', 'Polovinka,Turka,Turkinski,Турка', 52.9492000, 108.2217000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122846, 'Tura', 'Tura', 'Toera,Toura,Tura,Turinskaya Kul''tbaza,Turinskaya Kul’tbaza,Turinskaya Kutbaza,tu la,tula,Тура,圖拉,투라', 64.2776900, 100.2184900, 'RU', '2012-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122847, 'Tulyushka', 'Tulyushka', 'Tulinskoye,Tuljushka,Tuljusjka,Tulunskoye,Tulyushka,Тулюшка', 54.4585100, 101.1705400, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122848, 'Tulun', 'Tulun', 'Gorad Tulun,Toeloen,Touloun,Tulun,Tulunas,Tulún,tu lun,twlwn,Горад Тулун,Тулун,تولون,图伦', 54.5635800, 100.5814300, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122849, 'Trudovoye', 'Trudovoye', 'Toudovoye,Trudovoe,Trudovoje,Trudovoye,Трудовое', 43.2982300, 132.0687700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122850, 'Topolëvo', 'Topolevo', 'Topolevo,Topoljovo,Topolëvo,Тополево,Тополёво', 48.5026400, 135.1761100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122851, 'Tommot', 'Tommot', 'Gorad Tamot,Tommot,Tommota,Tomot,Tomotas,tommoteu,tonmoto,tuo mo te,twmwt,Горад Тамот,Томмот,Томот,توموت,トンモト,托莫特,톰모트', 58.9571700, 126.2915800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122852, 'Tokur', 'Tokur', 'Tokur,Токур', 53.1353100, 132.8899600, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122853, 'Tiksi', 'Tiksi', 'IKS,Tiksi,Tiksii,Tiksis,Tyikszi,tigsi,tikushi,tyqsy,Тикси,Тиксии,Тіксі,טיקסי,ティクシ,틱시', 71.6900200, 128.8646700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122854, 'Fokino', 'Fokino', 'Fokino,Fokino i Primorskij kraj,Fókino,Gorad Fokina,Shkotovo-17,Tikhookeanskiy,fokino,fu ji nuo,fwkynw,fwkynw  prymwrsky,fwkynw  prymwrsky krayy,pokino,Горад Фокіна,Фокино,Фокіно,فوكينو,فوکینو، پریمورسکی,فوکینو، پریمورسکی کرائی,フォーキノ,福基諾,포키노', 42.9742900, 132.4057400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122855, 'Terney', 'Terney', 'Ternay,Ternei,Ternej,Terney,Terney-Morozovskoye,Терней', 45.0527800, 136.6088100, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122856, 'Tel’ma', 'Tel''ma', 'Tel''ma,Telma,Tel’ma,Тельма', 52.6981000, 103.7138000, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122857, 'Tayturka', 'Tayturka', 'Taiturka,Tajturka,Tayturka,Тайтурка', 52.8691700, 103.4608300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122858, 'Tavrichanka', 'Tavrichanka', 'Tavrichanka,Tavritsjanka,Тавричанка', 43.3255100, 131.8626400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122859, 'Novonukutskiy', 'Novonukutskiy', 'Novonukutskij,Novonukutskiy,Takhtal-Ongoy,Tatkhal-Ongoy,Новонукутский', 53.7002000, 102.7117000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122860, 'Tataurovo', 'Tataurovo', 'Tataurovo,Verkhneye Tataurovo,Татаурово', 52.1418200, 107.4405400, 'RU', '2012-12-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122861, 'Tarbagatay', 'Tarbagatay', 'Tarbagatai,Tarbagataj,Tarbagatay,Tarbagatayskoye,Тарбагатай', 51.4819500, 107.3615800, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122862, 'Tarbagatay', 'Tarbagatay', 'Tabargatai,Tarbagatai,Tarbagataj,Tarbagatay,Тарбагатай', 51.1755900, 109.0948400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122863, 'Tankhoy', 'Tankhoy', 'Tankhoi,Tankhoj,Tankhoy,Taukhoi,Танхой', 51.5568300, 105.1262000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122864, 'Tambovka', 'Tambovka', 'Tambovka,Тамбовка', 50.0996800, 128.0572400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122865, 'Taldan', 'Taldan', 'Darudan,Taldak,Taldan,Талдан', 53.6898100, 124.8149000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122866, 'Talakan', 'Talakan', 'Talakan,Yakutskoye,Талакан', 50.2637800, 130.2675500, 'RU', '2013-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122867, 'Taksimo', 'Taksimo', 'Taksimo,Toksimo,Таксимо', 56.3416200, 114.9004800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122868, 'Takhtamygda', 'Takhtamygda', 'Tachtamydga,Takhtamygda,Тахтамыгда', 54.1103100, 123.6080200, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122869, 'Tabaga', 'Tabaga', 'Lesokombinat,Tabaga,Лесокомбинат,Табага,Табаҕа', 61.8550200, 129.6002200, 'RU', '2014-08-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122870, 'Svobodnyy', 'Svobodnyy', 'Alekseyevsk,Svobodni,Svobodny,Svobodnyi,Svobodnyj,Svobodnyy,Свободный', 51.3752500, 128.1409700, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122871, 'Svirsk', 'Svirsk', 'Gorad Svirsk,Svirsk,Svirskoye,Swirsk,Szvirszk,aswyrsk,seubileuseukeu,sfyrsk,si wei er si ke,Горад Свірск,Свирск,اسویرسک,سفيرسك,斯維爾斯克,스비르스크', 53.0858300, 103.3325000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122872, 'Svetlaya', 'Svetlaya', 'Svetlaja,Svetlaya,Svetloe,Svetloye,Светлая', 46.5421700, 138.3297300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122873, 'Suntar', 'Suntar', 'SUY,Suntar,Suntarsk,Suntarskoye,Сунтар', 62.1444400, 117.6319400, 'RU', '2013-08-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122874, 'Sretensk', 'Sretensk', 'Gorad Srehcensk,Sretensk,Srietiensk,Sryetensk,Srétensk,asrtnsk,si li jian si ke,srytnsk,Горад Срэценск,Сретенск,اسرتنسک,سريتنسك,斯利坚斯克', 52.2478000, 117.7083500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122875, 'Srednebelaya', 'Srednebelaya', 'Sovkhoz Crednebel''skiy,Sovkhoz Crednebel’skiy,Sredne-Beloye,Srednebelaja,Srednebelaya,Среднебелая', 50.6585400, 128.0093200, 'RU', '2014-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122876, 'Spasskoye', 'Spasskoye', 'Spasskoe,Spasskoye,Спасское', 44.6121500, 132.8000700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122877, 'Spassk-Dal’niy', 'Spassk-Dal''niy', 'Spassk,Spassk Dal''ni,Spassk Dal’ni,Spassk-Dal''nij,Spassk-Dal''niy,Spassk-Dal’niy,Spasskoe,Speasskdalniy,Спасск-Дальний,Спасское', 44.5988400, 132.8259300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122878, 'Sotnikovo', 'Sotnikovo', 'Sotnikovo,Сотниково', 51.8844800, 107.4825000, 'RU', '2013-03-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122879, 'Sosnovo-Ozerskoye', 'Sosnovo-Ozerskoye', 'Sosnovo-Ozernoye,Sosnovo-Ozerskoe,Sosnovo-Ozerskoje,Sosnovo-Ozerskoya,Sosnovo-Ozerskoye,Сосново-Озерское', 52.5246600, 111.5412400, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122880, 'Соловьевск', 'Solov''evsk', 'Solov''evsk,Solov''yeva,Solov''yevka,Solov''yevsk,Solov''yova,Solov''yëvsk,Solovjevsk,Соловьевск', 54.2333300, 124.4333300, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122881, 'Solnechnyy', 'Solnechnyy', 'Solnechnyj,Solnechnyy,Solnetsjnyj,Солнечный', 60.3021700, 137.5556300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122882, 'Solnechnyy', 'Solnechnyy', 'Solnechnyj,Solnechnyy,Solnetsjnyj,Солнечный', 50.7236700, 136.6383100, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122883, 'Solnechnyy', 'Solnechnyy', 'Solnechnyj,Solnechnyy,Solnetsjnyj,Солнечный', 50.5833300, 137.0333300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122884, 'Sokol', 'Sokol', 'Sokol,Сокол', 51.8003600, 107.4443700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122885, 'Smolyaninovo', 'Smolyaninovo', 'Smoljanikowe,Smoljaninovo,Smolyan''novo,Smolyaninovo,Smolyaniovo,Smolyan’novo,Смоляниново', 43.2880100, 132.4558600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122886, 'Smolenshchina', 'Smolenshchina', 'Smolenshchina,Smolenshhina,Smolensjtsjina,Смоленщина', 52.2552800, 104.1280600, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122887, 'Smolenka', 'Smolenka', 'Smolenka,Smolenska,Smolenskaya,Smolenskoye,Смоленка', 52.1352300, 113.4974000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122888, 'Smidovich', 'Smidovich', 'In,Smidovich,Smidovitsj,Смидович', 48.5964700, 133.8086600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122889, 'Slyudyanka', 'Slyudyanka', 'Sladyanka,Sljudjanka,Sludyanka,Slyadyanka,Slyudyanka,Слюдянка', 51.6594400, 103.7061100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122890, 'Slavyanka', 'Slavyanka', 'Slavjanka,Slavyanka,Slavyansk,Славянка', 42.8641300, 131.3882000, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122891, 'Skovorodino', 'Skovorodino', 'Gorad Skavarodzina,Rukhlovo,Rukholo,Skovorodino,Skovorodinó,Skoworodino,askwwwrwdynw,seukobolodino,si ke wo luo ji nuo,skwfwrwdynw,skwwrwdynw  amwr awblast,sukoborodino,Горад Скавародзіна,Сковородино,Сковородіно,اسکووورودینو,سكوفورودينو,سکوورودینو، آمور اوبلاست,スコボロディノ,斯科沃罗季诺,스코보로디노', 53.9847300, 123.9403000, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122892, 'Sivakovka', 'Sivakovka', 'Sivakovka,Сиваковка', 44.4783800, 132.3671800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122893, 'Sivaki', 'Sivaki', 'Sivak,Sivaki,Сиваки', 52.6343000, 126.7477700, 'RU', '2016-10-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122894, 'Shtykovo', 'Shtykovo', 'Maykhe,Maykho,Muravinaya,Muraviny,Shtykovo,Sjtykovo,Штыково', 43.3891800, 132.3612900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122895, 'Shkotovo', 'Shkotovo', 'Schkotowo,Shkatova,Shkotovo,Sjkotovo,Шкотово', 43.3209200, 132.3543300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122896, 'Shirokiy', 'Shirokiy', 'Allochkin Otrog,Shirokij,Shirokiy,Sjirokij,Широкий', 49.7590700, 129.5198800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122897, 'Shimanovsk', 'Shimanovsk', 'Chimanovsk,Gorad Shymanousk,Schimanowsk,Shimanovs''k,Shimanovsk,Shimanovskaya,Shimanovskiy,Shimanovskoye,Simanovsk,Sjimanovsk,Ximanovsk,shymanwfsk,shymanwwsk,xi ma nuo fu si ke,Ŝimanovsk,Šimanovsk,Горад Шыманоўск,Шимановск,Шимановськ,شيمانوفسك,شیمانوفسک,شیمانووسک,希马诺夫斯克', 52.0057500, 127.6775600, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122898, 'Shilka', 'Shilka', 'Shilka,Sjilka,Шилка', 51.8500000, 116.0333300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122899, 'Shestakovo', 'Shestakovo', 'Shestakova,Shestakovo,Шестаково', 56.4915000, 103.9600000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122900, 'Sheragul', 'Sheragul', 'Sharagul,Sheragul,Sjeragul,Шерагул', 54.4624300, 100.9099400, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122901, 'Shelopugino', 'Shelopugino', 'Shelapugino,Shelopugino,Shelopushno,Sjelopugino,Шелопугино', 51.6528600, 117.5630300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122902, 'Shelekhov', 'Shelekhov', 'Chelekhov,Gorad Shehlekhau,Schelechow,Selechov,Selehov,Selexov,Shelejov,Shelekhov,Shelikhov,Shélejov,Sjelechov,Sjelekhov,shlkhwf,shylkhwf,xie lie huo fu,Ŝeleĥov,Şelexov,Šelechov,Šelehov,Горад Шэлехаў,Шелехов,شلخوف,شيلخوف,謝列霍夫', 52.2138900, 104.1000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122903, 'Sharalday', 'Sharalday', 'Bol''shoy Sharalday,Bol’shoy Sharalday,Sharaldaj,Sharalday,Sharalday-Bol''shoy,Sharalday-Bol’shoy,Sheralday,Sjaraldaj,Шаралдай', 51.0252800, 107.6448700, 'RU', '2015-08-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122904, 'Shamanka', 'Shamanka', 'Shamanka,Shamanka Pervaya,Sjamanka,Шаманка', 52.0666700, 103.8202800, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122905, 'Severomuysk', 'Severomuysk', 'Severomujsk,Severomuysk,Северомуйск', 56.1480600, 113.4266700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122906, 'Severobaykal’sk', 'Severobaykal''sk', 'Khojto Bajgal,Severobaikalsk,Severobajkal''sk,Severobajkalsk,Severobaykal''sk,Severobaykal’sk,Северобайкальск,Хойто Байгал', 55.6369500, 109.3229700, 'RU', '2016-11-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122907, 'Seryshevo', 'Seryshevo', 'Seryshevo,Serysjevo,Серышево', 51.0939100, 128.3825800, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122908, 'Sergeyevka', 'Sergeyevka', 'Sergeevka,Sergejevka,Sergeyevka,Sergeyevskoye,Sergyeeuka,Sergyyevka,Сергеевка', 43.3490900, 133.3597200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122909, 'Serebryanyy Bor', 'Serebryanyy Bor', 'Serebrjanyj Bor,Serebryanyy Bor,Серебряный Бор', 56.6707600, 124.8375400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122910, 'Selikhino', 'Selikhino', 'Selikhin,Selikhino,Селихино', 50.3683200, 137.5016300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122911, 'Selenduma', 'Selenduma', 'Selenduma,Selenginsk Duma,Selenginskaya Duma,Селендума', 50.9130600, 106.2405600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122912, 'Nizhniy Sayantuy', 'Nizhniy Sayantuy', 'Nizhnij Sajantuj,Nizhniy Sayantuy,Nizjnij Sajantuj,Sayantui,Sayantunskoye,Sayantuy,Vakhmistrovo,Нижний Саянтуй', 51.7375100, 107.5130800, 'RU', '2013-08-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122913, 'Saskylakh', 'Saskylakh', 'SYS,Saskylakh,Саскылах', 71.9634700, 114.0919900, 'RU', '2013-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122914, 'Sangar', 'Sangar', 'Sangaar,Sangar,Sangar-Khaya,Sangaras,Sangaruhaya,Sangary,Сангаар,Сангар', 63.9230100, 127.4713500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122915, 'Russkiy', 'Russkiy', 'Russkij,Russkiy,Русский', 43.0224000, 131.8601000, 'RU', '2012-02-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122916, 'Rudnyy', 'Rudnyy', 'Lifudzin,Rudny,Rudnyj,Rudnyy,Рудный', 44.2775900, 134.9610600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122917, 'Rudnogorsk', 'Rudnogorsk', 'Rudnogorsk,Рудногорск', 57.2639000, 103.7519000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122918, 'Rudnaya Pristan’', 'Rudnaya Pristan''', 'Plavzavod,Rudnaja Pristan,Rudnaja Pristan'',Rudnaya Pristan'',Rudnaya Pristan’,Tetjuche,Tetyukhe,Tetyukhe-Pristan'',Tetyukhe-Pristan’,Рудная Пристань', 44.3581200, 135.8147800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122919, 'Romny', 'Romny', 'Romny,Ромны', 50.7207000, 129.2912200, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122920, 'Romanovka', 'Romanovka', 'Romanovka,Романовка', 43.2329400, 132.4571400, 'RU', '2013-10-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122921, 'Rettikhovka', 'Rettikhovka', 'Retikhovka,Rettikhoveka,Rettikhovka,Rhettikhovka,Ritikhovka,Rittikhovka,Реттиховка', 44.1703800, 132.7708300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122922, 'Razdol’noye', 'Razdol''noye', 'Razdol''noe,Razdol''noye,Razdolnoje,Razdol’noye,Razudorinoe,Раздольное', 43.5389400, 131.8969100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122923, 'Raychikhinsk', 'Raychikhinsk', 'Gorad Rajchykhinsk,Raicihinsk,Raitchikhinsk,Raitschichinsk,Raitxikhinsk,Raitxíkhinsk,Raičihinsk,Rajchikhins''k,Rajchikhinsk,Rajcichinsk,Rajcihinsk,Rajtsjikhinsk,Rajĉiĥinsk,Rajčichinsk,Raychikhihsk,Raychikhinsk,Raïtchikhinsk,lai qi xin si ke,raychykhynsk,raytshykhynsk,Горад Райчыхінск,Райчихинск,Райчихінськ,Рајчихинск,Ռայչիխինսկ,رايتشيخينسك,رایچیخینسک,赖奇欣斯克', 49.7899800, 129.4099200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122924, 'Putyatin', 'Putyatin', 'Putjatin,Putyatin,Shkotovo-26,Путятин', 42.8617900, 132.4156400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122925, 'Primorskiy', 'Primorskiy', 'Primorskij,Primorskiy,Приморский', 43.0996200, 131.5893800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122926, 'Priiskovyy', 'Priiskovyy', 'Priiskovaya,Priiskovyj,Priiskovyy,Приисковый', 51.9333300, 116.6333300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122927, 'Priargunsk', 'Priargunsk', 'Novo-Tsurukhaitui,Novo-Tsurukhaytuy,Novo-Tsurukhaytuyevskiy,Novo-Tsurukhtuyevskiy,Priargunsk,Tsurukhaytuy,Приаргунск', 50.3691000, 119.1012000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122928, 'Priamurskiy', 'Priamurskiy', 'Pokrovka,Povrovka,Priamurskij,Priamurskiy,Приамурский', 48.5271600, 134.9035900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122929, 'Preobrazheniye', 'Preobrazheniye', 'Preobrazhenie,Preobrazheniye,Preobrazjenije,Преображение', 42.9011700, 133.9043000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122930, 'Poyarkovo', 'Poyarkovo', 'Pojarkovo,Poyarkov,Poyarkovo,Поярково', 49.6267800, 128.6535200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122931, 'Popova', 'Popova', 'Popova,Попова', 42.9609600, 131.7249400, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122932, 'Pokrovsk', 'Pokrovsk', 'Gorad Pakrousk,Pokrovka,Pokrovs''k,Pokrovsk,Pokrovska,Pokrovskaj,Pokrovskas,Pokrovsko,Pokrowsk,Polrovskoye,Porovskoye,bo ke luo fu si ke,bwkrwfsk,pokeulobseukeu,pokurofusuku,pwkrwfsk  yaqwtstan,Горад Пакроўск,Покровск,Покровскай,Покровськ,بوكروفسك,پوکروفسک، یاقوتستان,پوکرووسک، سخا جمہوریہ,ポクロフスク,波克罗夫斯克,포크롭스크', 61.4776800, 129.1369900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122933, 'Pokrovka', 'Pokrovka', 'Pokrovka,Покровка', 43.9533100, 131.6344300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122934, 'Pokosnoye', 'Pokosnoye', 'Pokosnoe,Pokosnoje,Pokosnoye,Pokosnyy,Покосное', 55.5258300, 101.0536100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122935, 'Pogranichnyy', 'Pogranichnyy', 'Grodekovo,Pogranichnyj,Pogranichnyy,Pogranitsjnyj,Пограничный', 44.4097000, 131.3778000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122936, 'Plastun', 'Plastun', 'Plastun,TLY,Пластун', 44.7607700, 136.2804800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122937, 'Pivovarikha', 'Pivovarikha', 'Pivovarikha,Пивовариха', 52.2705600, 104.4458300, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122938, 'Petrovsk-Zabaykal’skiy', 'Petrovsk-Zabaykal''skiy', 'Petrovsk,Petrovsk Zabaikal''skiy,Petrovsk Zabaikal’skiy,Petrovsk-Zabaikalski,Petrovsk-Zabajkal''skij,Petrovsk-Zabajkalskij,Petrovsk-Zabaykal''skiy,Petrovsk-Zabaykal’skiy,Petrovski Zabaikalski,Petrovskiy Zavod,Петровск-Забайкальский', 51.2753000, 108.8430100, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122939, 'Petropavlovka', 'Petropavlovka', 'Petropavlovka,Petropavlovskoye,Петропавловка', 50.6114000, 105.3196000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122940, 'Pervomayskiy', 'Pervomayskiy', 'Pervomajskij,Pervomayskiy,Первомайский', 51.6701300, 115.6254300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122941, 'Perfilovo', 'Perfilovo', 'Perfilovo,Перфилово', 54.4108300, 100.4845400, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122942, 'Peleduy', 'Peleduy', 'Maly Peleduy,Malyy Peleduy,Peleduj,Peleduy,Пеледуй', 59.6288900, 112.7405600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122943, 'Partizansk', 'Partizansk', 'Gorad Partyzansk,Partisansk,Partizans''k,Partizansk,Partyizanszk,Suchan,Suchanskiy Rudnik,Sutschan,bartyzansk,paleutijanseukeu,partyzansk,paruchizansuku,you ji dui cheng,Горад Партызанск,Партизанск,Партизанськ,Պարտիզանսկ,بارتيزانسك,پارتیزانسک,パルチザンスク,游击队城,파르티잔스크', 43.1216500, 133.1234700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122944, 'Oyëk', 'Oyek', 'Oek,Ojek,Ojok,Oyek,Oyëk,Оек,Оёк', 52.5861100, 104.4555600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122945, 'Ovsyanka', 'Ovsyanka', 'Ovsianka,Ovsjanka,Ovsyanka,Овсянка', 53.5786800, 126.8962300, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122946, 'Osa', 'Osa', 'Osa,Оса', 53.3872200, 103.8769400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122947, 'Orlovskiy', 'Orlovskiy', 'Orlovskij,Orlovskiy,Spokoynyy,Орловский', 51.0333300, 114.8333300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122948, 'Onokhoy', 'Onokhoy', 'Onokhoj,Onokhoy,Onokhoy-Shibir,Онохой', 51.9285900, 108.0669300, 'RU', '2014-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122949, 'Olovyannaya', 'Olovyannaya', 'Olovjannaja,Olovyannaya,Olovyanraya,Оловянная', 50.9500000, 115.5666700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122950, 'Ol’ga', 'Ol''ga', 'Ol''ga,Olga,Ol’ga,Permskaya,Ольга', 43.7473500, 135.2909000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122951, 'Olenyok', 'Olenyok', 'ONK,Olenek,Olenekskaya Kul''tbaza,Olenekskaya Kul’tbaza,Olenjok,Olenskaya Kultbaza,Olenyok,Оленёк', 68.5047200, 112.4485000, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122952, 'Olyokminsk', 'Olyokminsk', 'OLZ,Olekminsk,Oljokminsk,Olyokminsk,Олёкминск', 60.3743000, 120.4203000, 'RU', '2014-04-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122953, 'Okino-Klyuchi', 'Okino-Klyuchi', 'Okino,Okino-Kljuchi,Okino-Kljutsji,Okino-Kluchevskaya,Okino-Klyuch,Okino-Klyuchevskaya,Okino-Klyuchi,Окино-Ключи', 50.5938900, 107.1094400, 'RU', '2015-08-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122954, 'Nyurba', 'Nyurba', 'NYR,Njurba,Nyurba,Нюрба', 63.2841700, 118.3319400, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122955, 'Novyy Zagan', 'Novyy Zagan', 'Novyj Zagan,Novyy Zagan,Новый Заган', 51.0285800, 107.7637600, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122956, 'Novyy Uoyan', 'Novyy Uoyan', 'Novyj Uojan,Novyy Uoyan,Новый Уоян', 56.1572200, 111.7055600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122957, 'Novosysoyevka', 'Novosysoyevka', 'Novaya Sysoyevka,Novosysoevka,Novosysojevka,Novosysoyevka,Sysoyevka,Новосысоевка', 44.2347000, 133.3642000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122958, 'Novoshakhtinskiy', 'Novoshakhtinskiy', 'Novoshakhtinskij,Novoshakhtinskiy,Novosjakhtinskij,Новошахтинский', 44.0257600, 132.1658300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122959, 'Novoraychikhinsk', 'Novoraychikhinsk', 'Novorajchikhinsk,Novorajtsjikhinsk,Novoraychikhinsk,Новорайчихинск', 49.7842300, 129.5905100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122960, 'Novopokrovka', 'Novopokrovka', 'Katerinoe,Kotel''naya,Kotel’naya,Novo-Petrovskoye,Novo-Pokrovskiy,Novopokrovka,Novopokrovskoye,Novopokurofuskoe,Новопокровка', 45.8529600, 134.5003500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122961, 'Novopavlovka', 'Novopavlovka', 'Novopavlovka,Новопавловка', 51.2172400, 109.2130500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122962, 'Novonikol’sk', 'Novonikol''sk', 'Novo Nikolayevsk,Novonikol''sk,Novonikol''skoye,Novonikolsk,Novonikol’sk,Novonikol’skoye,Новоникольск', 43.8551800, 131.8625700, 'RU', '2013-10-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122963, 'Novokruchininskiy', 'Novokruchininskiy', 'Novaya,Novokruchininskij,Novokruchininskiy,Novokrutsjininskij,Новокручининский', 51.7836000, 113.7759100, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122964, 'Novokizhinginsk', 'Novokizhinginsk', 'Novokizhinginsk,Novokizjinginsk,Новокижингинск', 51.6162000, 109.6026500, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122965, 'Novobureyskiy', 'Novobureyskiy', 'Nikolayevka,Novoburejskij,Novobureyskiy,Pribrezhnaya,Pristan'' Bureya,Pristan’ Bureya,Новобурейский', 49.7969500, 129.8744300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122966, 'Novaya Igirma', 'Novaya Igirma', 'Nov.Igirma,Novaja Igirma,Novaya Igirma,Novaya Igrima,Novo Igirma,Нов.Игирма,Новая Игирма', 57.1334000, 103.9112000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122967, 'Novaya Bryan’', 'Novaya Bryan''', 'Novaja Brjan,Novaja Brjan'',Novaya Bryan'',Novaya Bryan’,Novo-Bryanskoye,Novoy Bryan,Новая Брянь', 51.7169900, 108.2701400, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122968, 'Nizhniy Tsasuchey', 'Nizhniy Tsasuchey', 'Nizhnij Casuchej,Nizhniy Tsasuchey,Nizjnij Tsasutsjej,Нижний Цасучей', 50.5166700, 115.1333300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122969, 'Nizhniy Kuranakh', 'Nizhniy Kuranakh', 'Nizhnij Kuranakh,Nizhniy Kuranakh,Nizjnij Kuranakh,Нижний Куранах', 58.8238000, 125.5227800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122970, 'Nizhniy Bestyakh', 'Nizhniy Bestyakh', 'Bestyakh,Nizhnij Bestjakh,Nizhniy Bestyakh,Nizjnij Bestjakh,Нижний Бестях', 61.9620200, 129.9124500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122971, 'Nizhneangarsk', 'Nizhneangarsk', 'Kozlovo,Nizhneangarsk,Nizjneangarsk,Нижнеангарск', 55.7932600, 109.5802900, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122972, 'Nikol’sk', 'Nikol''sk', 'Nikol''sk,Nikol''skaya,Nikol''skoye,Nikolsk,Nikol’sk,Nikol’skaya,Nikol’skoye,Никольск', 51.1886700, 108.3218700, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122973, 'Nikolayevskiy', 'Nikolayevskiy', 'Nikolaevskij,Nikolajevskij,Nikolayevski Zavod,Nikolayevskiy,Nikolayevskiy Zavod,Николаевский', 51.6552600, 107.8006800, 'RU', '2015-08-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122974, 'Never', 'Never', 'Larinskiy,Never,Невер', 53.9794600, 124.1577700, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122975, 'Neryungri', 'Neryungri', 'N''iruungra,Neriungri,Neriungris,Nerjoengri,Nerjungri,Neryugran,Neryungar,Neryungra,Neryungri,Nүөrүҥgүrү,nelyungeuli,Нерюнгри,Ньируунгра,Нүөрүҥгүрү,네륜그리', 56.6663700, 124.6382500, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122976, 'Nerchinskiy Zavod', 'Nerchinskiy Zavod', 'Nerchinsk,Nerchinsk-zavod,Nerchinskij Zavod,Nerchinskiy Zavod,Nerchinskizavod,Nertsjinskij Zavod,Нерчинский Завод', 51.3082900, 119.6159700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122977, 'Nerchinsk', 'Nerchinsk', 'Gorad Nerchynsk,Nehrchүү,Nerchins''k,Nerchinsk,Nercinsk,Nercinskas,Nerczynsk,Nerczyńsk,Nertchinsk,Nertjinsk,Nertschia,Nertschinsk,Nertsinsk,Nertsjinsk,Nertxinsk,Nertšinsk,Nerĉinsk,Nerčinsk,Nerčinskas,Nyercsinszk,neleuchinseukeu,neruchinsuku,ni bu chu,nrchynsk,nrzynsq,nyrtshynsk,Горад Нерчынск,Нерчинск,Нерчинськ,Нэрчүү,נרצינסק,نرچینسک,نيرتشينسك,ネルチンスク,尼布楚,네르친스크', 51.9833300, 116.5833300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122978, 'Nekrasovka', 'Nekrasovka', 'Nekrasovka,Некрасовка', 48.3520800, 135.2322100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122979, 'Naushki', 'Naushki', 'Naushinski,Naushinskiy,Naushki,Nausjki,Наушки', 50.3827800, 106.1055600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122980, 'Namtsy', 'Namtsy', 'Namcy,Namskoye,Namtsy,Намцы', 62.7195900, 129.6672200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122981, 'Nakhodka', 'Nakhodka', 'Gorad Nakhodka,Nachodka,Nahhodka,Nahodka,Nahotk,Najodka,Nakhodka,Nakhodkae,Nakhodko,Nakhotka,Naxodka,Naĥodka,na huo de ka,nahoska,nahotoka,nakhwdka,Горад Находка,Находкæ,Находка,Находко,Нахотка,ناخودكا,ناخودکا,ナホトカ,納霍德卡,나홋카', 42.8138400, 132.8734800, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122982, 'Mukhorshibir’', 'Mukhorshibir''', 'Mokhor''shigir,Mokhor’shigir,Mukhor Shibar,Mukhor-Shibir'',Mukhor-Shigir,Mukhorshibir'',Mukhorshibir’,Мухор-Шибирь,Мухоршибирь', 51.0498600, 107.8299700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122983, 'Mukhen', 'Mukhen', 'Mukhen,Мухен', 48.1967200, 136.1269100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122984, 'Mugun', 'Mugun', 'Mugun,Мугун', 54.4714300, 100.2483100, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122985, 'Monastyrishche', 'Monastyrishche', 'Monastyrischtsche,Monastyrishche,Monastyrishhe,Monastyrisjtsje,Монастырище', 44.1964100, 132.5022300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122986, 'Mokhsogollokh', 'Mokhsogollokh', 'Mokhsogollokh,Мохсоголлох', 61.3961900, 128.9381000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122987, 'Mogzon', 'Mogzon', 'Mogzon,Могзон', 51.7406000, 111.9655500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122988, 'Mogoytuy', 'Mogoytuy', 'Mogojtuj,Mogoytuy,Могойтуй', 51.2833300, 114.9166700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122989, 'Mogocha', 'Mogocha', 'Gorad Magocha,Mogacha,Mogoc,Mogoca,Mogocha,Mogocza,Mogotcha,Mogotsa,Mogotscha,Mogotsja,Mogotxa,Mogotša,Mogoĉa,Mogoč,Mogoča,Mogucha,mo ge qia,mwghwtsha,mwgwcha,mwgwzh,Горад Магоча,Могоча,מוגוצה,موغوتشا,موگوچا,莫戈恰', 53.7341700, 119.7651500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122990, 'Mnogovershinnyy', 'Mnogovershinnyy', 'Mnogovershinnyj,Mnogovershinnyy,Mnogoversjinnyj,Многовершинный', 53.9334500, 139.9274000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122991, 'Mnogoudobnoye', 'Mnogoudobnoye', 'Mnogoubodnoye,Mnogoudobnaya,Mnogoudobnoe,Mnogoudobnoje,Mnogoudobnoye,Mnogoyedobnaya,Многоудобное', 43.4680200, 132.4667500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122992, 'Mishelevka', 'Mishelevka', 'Mishelevka,Misheleyka,Misjelevka,Мишелевка', 52.8575000, 103.1719400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122993, 'Mirny', 'Mirny', 'Gorad Mirny,MJZ,Miirinehj,Mirnas,Mirnehj,Mirnej,Mirney,Mirni,Mirnii,Mirnij,Mirnija,Mirnoi,Mirny,Mirnyi,Mirnyj,Mirnyj i Sakha,Mirnõi,mi er nei,mileuni,mirunui,myrny,myrny  yaqwtstan,Горад Мірны,Мииринэй,Мирней,Мирни,Мирний,Мирный,Мирнэй,ميرني,میرنی، سخا جمہوریہ,میرنی، یاقوتستان,ミールヌイ,米尔内,미르니', 62.5352800, 113.9611100, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122994, 'Mikhaylovka', 'Mikhaylovka', 'Mikhailovka,Mikhajlovka,Mikhaylovka,Mikhaylovskoye,Михайловка', 43.9328300, 132.0091100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122995, 'Meget', 'Meget', 'Meget,Мегет', 52.4150000, 104.0494400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122996, 'Mayya', 'Mayya', 'Maja,Majja,Maya,Mayya,Майя', 61.7382400, 130.2816100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122997, 'Markovo', 'Markovo', 'Markova,Markovo,Markovskoye,Марково', 57.3205600, 107.0880600, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122998, 'Markha', 'Markha', 'Bol''shaya Markha,Bol’shaya Markha,Markha,Марха', 62.1145400, 129.7440300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(122999, 'Manzurka', 'Manzurka', 'Manzurka,Манзурка', 53.4855600, 106.0544400, 'RU', '2014-08-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123000, 'Mamakan', 'Mamakan', 'Mamakan,Мамакан', 57.8161100, 114.0027800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123001, 'Mama', 'Mama', 'Mama,Мама', 58.3105600, 112.8986100, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123002, 'Makkaveyevo', 'Makkaveyevo', 'Makaveyevo,Makkaveevo,Makkavejevo,Makkaveyevo,Makkaveyeyskiy,Makoveyevo,Маккавеево', 51.7532500, 113.9454000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123003, 'Magistral’nyy', 'Magistral''nyy', 'Magistral''nyj,Magistral''nyy,Magistralnyj,Magistral’nyy,Магистральный', 56.1714800, 107.4416600, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123004, 'Magdagachi', 'Magdagachi', 'GDG,Magadagachi,Magdagachi,Magdagaci,Magdagatschi,Magdagatsji,Magdagatxi,Magdagači,Магдагачи,Մագդագաչի', 53.4539800, 125.8093200, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123005, 'Magan', 'Magan', 'GYG,Magan,Маган', 62.1074600, 129.5318400, 'RU', '2013-09-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123006, 'Sergeyevka', 'Sergeyevka', 'Lyublino,Sergeevka,Sergeyevka,Sergievskij,Sergiyevskiy,Сергеевка,Сергиевский', 44.3381000, 131.6612900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123007, 'Lyalichi', 'Lyalichi', 'Lalichi,Ljalichi,Ljalitsji,Lyalichi,Pavlovka,Ляличи', 44.0735200, 132.3899100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123008, 'Luchki', 'Luchki', 'Luchki,Lutsjki,Лучки', 44.2861300, 132.2597500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123009, 'Luchegorsk', 'Luchegorsk', 'Lucegorsk,Luchegors''k,Luchegorsk,Lutschegorsk,Lutsjegorsk,Lučegorsk,lu qie ge er si ke,Лучегорск,Лучегорськ,盧切戈爾斯克', 46.4765600, 134.1953200, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123010, 'Londoko', 'Londoko', 'Landoko,Londoko,Londoko-Kamenushka,Лондоко', 49.0180500, 131.9914200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123011, 'Livadiya', 'Livadiya', 'Livadia,Livadija,Livadiya,Ливадия', 42.8682000, 132.6736700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123012, 'Litovko', 'Litovko', 'Litovko,Литовко', 49.2375400, 135.1740100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123013, 'Listvyanka', 'Listvyanka', 'Listrinichnoye,Listvenichnoye,Listvinichnoye,Listvjanka,Listvyanka,Листвянка', 51.8535000, 104.8693000, 'RU', '2013-01-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123014, 'Lipovtsy', 'Lipovtsy', 'Krasnopol''ye,Krasnopol’ye,Lipovcy,Lipovtsi,Lipovtsky,Lipovtsy,Липовцы', 44.2001800, 131.7237300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123015, 'Lesozavodsk', 'Lesozavodsk', 'Gorad Lesazavodsk,Lesozavodsk,Lesozawodzk,Lesozayodsk,Lessosawodsk,Lessozavodsk,Leszozavodszk,Lisozavods''k,Ljesozavodsk,Ussuri,lesojabocheukeu,lie suo zha wo ci ke,lswzafwdsk,lswzawdsk,lyswzaww,resozavu~otsuku,Љесозаводск,Горад Лесазаводск,Лесозаводск,Лісозаводськ,لسوزافودسك,لسوزاودسک,لیسوزاوو,レソザヴォーツク,列索扎沃茨克,레소자보츠크', 45.4788500, 133.4282500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123016, 'Lermontovka', 'Lermontovka', 'Lermontovka,Лермонтовка', 47.1479500, 134.3347700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123017, 'Lensk', 'Lensk', 'Gorad Lensk,Lens''k,Lensk,Lenska,Lenskas,Lenskej,Lensko,Liehnskehj,Mukhtuya,ULK,lenseukeu,lian si ke,lnsk,lnsq,lynsk,rensuku,Ļenska,Горад Ленск,Ленск,Ленскей,Ленськ,Лиэнскэй,לנסק,لنسک,لينسك,لینسک,レンスク,连斯克,렌스크', 60.7252800, 114.9277800, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123018, 'Leninskoye', 'Leninskoye', 'Blyukherovo,Leninskoe,Leninskoye,Mikhailo-Semenovskoye,Mikhaylo-Semenovskoye,Ленинское', 47.9350100, 132.6202500, 'RU', '2014-04-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123019, 'Leninskiy', 'Leninskiy', 'Leninskij,Leninskiy,Nizhne-Stalinsk,Nizhniy Stalinskiy,Ленинский', 58.5714100, 125.4391800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123020, 'Lebedinyy', 'Lebedinyy', 'Lebedinyj,Lebedinyy,Verkhne-Stalinsk,Verkhniy Stalinskiy,Лебединый', 58.4884400, 125.4941500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123021, 'Lazo', 'Lazo', 'Lazo,Лазо', 45.8705200, 133.6502100, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123022, 'Lazo', 'Lazo', 'Lazo,Vangou,Лазо', 43.3856300, 133.9061000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123023, 'Kysyl-Syr', 'Kysyl-Syr', 'Kysyl-Syr,Кысыл-Сыр', 63.8948200, 122.7654000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123024, 'Kyren', 'Kyren', 'Koren,Kyren,Кырен', 51.6828000, 102.1408000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123025, 'Kyra', 'Kyra', 'Kora,Kyra,Кыра', 49.5790300, 111.9763800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123026, 'Kyakhta', 'Kyakhta', 'Kjakhta,Kyakhta,Troitskosavsk,Кяхта', 50.3573700, 106.4503300, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123027, 'Kuytun', 'Kuytun', 'Khaikhta,Khaita,Kuitun,Kujtun,Kuytuk,Kuytun,Куйтун', 54.3424100, 101.5091700, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123028, 'Kutulik', 'Kutulik', 'Kutulik,Kutulyk,Кутулик', 53.3508300, 102.7838900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123029, 'Kurumkan', 'Kurumkan', 'Kurumkan,Kurumken,Курумкан', 54.3209300, 110.3065100, 'RU', '2013-11-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123030, 'Kurort-Darasun', 'Kurort-Darasun', 'Darasun,Kurort Darasun,Kurort-Darasun,Курорт Дарасун,Курорт-Дарасун', 51.1990500, 113.7159900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123031, 'Kultuk', 'Kultuk', 'Kultuk,Zabaykalsk,Култук', 51.7208300, 103.6955600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123032, 'Kul’dur', 'Kul''dur', 'Kul''dur,Kuldur,Kul’dur,Kurort,Кульдур', 49.2046500, 131.6384000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123033, 'Kudara-Somon', 'Kudara-Somon', 'Kudara,Kudara-Somon,Кудара-Сомон', 50.1547200, 107.4013900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123034, 'Kropotkin', 'Kropotkin', 'Krapotkin,Kropotkin,Кропоткин', 58.5094400, 115.3216700, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123035, 'Krasnorechenskiy', 'Krasnorechenskiy', 'Krasnorechenskij,Krasnorechenskiy,Krasnoretsjenskij,Краснореченский', 44.6280700, 135.3526200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123036, 'Krasnokamensk', 'Krasnokamensk', 'Chandacha,Chindachi,Chindachinskaya,Gorad Krasnakamensk,Krasnokamensk,Krasnokamenskas,Krasnokamiensk,Krasnokàmensk,ke la si nuo ka mian si ke,krasnwkamnsk,krasnwkamnsk  srzmyn zabaykalsky,Горад Краснакаменск,Краснокаменск,كراسنوكامنسك,کراسنوکامنسک,کراسنوکامنسک، سرزمین زابایکالسکی,克拉斯諾卡緬斯克', 50.0979000, 118.0369000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123037, 'Kraskino', 'Kraskino', 'Kraskino,Novo''kievsk,Novo-Kievsku,Novo-Kiyevskoye,Novokivsk,Novokiyevsk,Novo’kievsk,Краскино', 42.7107100, 130.7812600, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123038, 'Kotik', 'Kotik', 'Kotik,Котик', 54.6505700, 100.4539500, 'RU', '2013-09-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123039, 'Korfovskiy', 'Korfovskiy', 'Korfovskij,Korfovskiy,Корфовский', 48.2225900, 135.0596600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123040, 'Konstantinovka', 'Konstantinovka', 'Konstantinovka,Konstantinovskoye,Константиновка', 49.6187600, 127.9902500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123041, 'Komsomolsk-on-Amur', 'Komsomolsk-on-Amur', 'KXK,Komsomol''s''k-na-Amuri,Komsomol''sk,Komsomol''sk-na-Amure,Komsomolsk am Amur,Komsomolsk del Amur,Komsomolsk-na-Amure,Komsomolsk-on-Amur,Komsomolsk-sur-l''Amour,Komsomol’sk,Permskoye,a mu er he pan gong qing cheng,komsomolseukeunaamule,komusomorisuku・na・amure,Комсомольск-на-Амуре,Комсомольськ-на-Амурі,コムソモリスク・ナ・アムーレ,阿穆尔河畔共青城,콤소몰스크나아무레', 50.5503400, 137.0099500, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123042, 'Kokuy', 'Kokuy', 'Kodui,Koduy,Kokuj,Kokur,Kokuy,Kokuyskaya,Nokuy,Poselok Kukuyskiy,Posëlok Kukuyskiy,Кокуй', 52.2063400, 117.5541200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123043, 'Knyaze-Volkonskoye', 'Knyaze-Volkonskoye', 'Knjaze-Volkonskoe,Knjaze-Volkonskoje,Knyaze-Volkonka,Knyaze-Volkonskoye,Князе-Волконское', 48.4654700, 135.4558200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123044, 'Knevichi', 'Knevichi', 'Knevichi,Knevitsji,Кневичи', 43.3997500, 132.1880800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123045, 'Klyuchevskiy', 'Klyuchevskiy', 'Kljuchevskij,Kljutsjevskij,Klyuchevskiy,Klyuchevskoy,Klyuchi,Ключевский', 53.5336000, 119.4526900, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123046, 'Klichka', 'Klichka', 'Klichka,Klichki,Klitsjka,Кличка', 50.4457000, 117.9960000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123047, 'Kizhinga', 'Kizhinga', 'Kizhinga,Kizjinga,Кижинга', 51.8476000, 109.9079500, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123048, 'Kitoy', 'Kitoy', 'Kitoi,Kitoj,Kitoy,Китой', 52.6000000, 103.9000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123049, 'Kirovskiy', 'Kirovskiy', 'Kirovskij,Kirovskiy,Uspenka,Uspenovka,Usupenka,Кировский', 45.0927200, 133.5008400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123050, 'Kirensk', 'Kirensk', 'Gorad Kirehnsk,KCK,Kirensk,Kirenskaj,Kirenszk,Kireńsk,Kírensk,ji lian si ke,kilenseukeu,kirensuku,kyrnsk,kyrynsk,Горад Кірэнск,Киренск,Киренскай,كيرينسك,کیرنسک,キレンスク,基廉斯克,키렌스크', 57.7852800, 108.1119400, 'RU', '2012-05-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123051, 'Kimil’tey', 'Kimil''tey', 'Kimil''tej,Kimil''tey,Kimiltei,Kimiltej,Kimil’tey,Кимильтей', 54.1337000, 101.9811000, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123052, 'Kichera', 'Kichera', 'Kichera,Kitsjera,Кичера', 55.9387400, 110.1012200, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123053, 'Khuzhir', 'Khuzhir', 'Khoujir,Khuzhir,Khuzhirtuy,Khuzhirtuyskiy,Mal.Khuzhir,Мал.Хужир,Хужир', 53.1938900, 107.3397200, 'RU', '2015-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123054, 'Khurba', 'Khurba', 'Khurba,Хурба', 50.4065700, 136.8827600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123055, 'Khrebtovaya', 'Khrebtovaya', 'Izbushechnaya,Khrebtovaja,Khrebtovaya,Verkhnyaya Khrebtovaya,Хребтовая', 56.7032000, 104.2494000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123056, 'Khorol’', 'Khorol''', 'Khoral,Khorel,Khorol,Khorol'',Khorol''sk,Khorol''skaya,Khorol''sko,Khorol’,Khorol’sk,Khorol’skaya,Khorol’sko,Хороль', 44.4263100, 132.0763800, 'RU', '2014-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123057, 'Khorinsk', 'Khorinsk', 'Khorinsk,Khorinskoye,Хоринск', 52.1663100, 109.7762600, 'RU', '2013-01-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123058, 'Khor', 'Khor', 'Khor,Khorskiy,Хор', 47.8869600, 134.9463000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123059, 'Khonkholoy', 'Khonkholoy', 'Khonkhaloy,Khonkholoj,Khonkholoy,Konkholoi,Хонхолой', 51.1318600, 108.2251500, 'RU', '2015-08-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123060, 'Khomutovo', 'Khomutovo', 'Khomutovo,Хомутово', 52.4658300, 104.4025000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123061, 'Kholtoson', 'Kholtoson', 'Kholtoson,Nizhniy Kholtoson,Холтосон', 50.2981000, 103.3097000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123062, 'Kholbon', 'Kholbon', 'Kholbon,Холбон', 51.8833300, 116.2500000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123063, 'Khingansk', 'Khingansk', 'Khingansk,Mikoyanovsk,Хинганск', 49.1282100, 131.1932200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123064, 'Khilok', 'Khilok', 'Chilok,Chilokas,Gorad Khilok,Hilok,Jilok,Khilok,hylwq,khylwk,xi luo ke,Ĥilok,Горад Хілок,Хилок,Хілок,חילוק,خيلوك,خیلوک,希洛克', 51.3677700, 110.4680400, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123065, 'Khatassy', 'Khatassy', 'Khatassy,Khatssy,Хатассы', 61.9063800, 129.6330200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123066, 'Khatanga', 'Khatanga', 'Chatanga,HTG,Khatanga,Khatenga,Хатанга', 71.9800200, 102.4711100, 'RU', '2013-10-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123067, 'Khandyga', 'Khandyga', 'KDY,Khandyga,Хандыга', 62.6533300, 135.5667000, 'RU', '2014-02-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123068, 'Khabarovsk', 'Khabarovsk', 'Chabarofsk,Chabarovsk,Chabarovskas,Chabarowsk,Champarofsk,Gorad Khabarausk,Habarovsk,Habarovska,Habarovszk,Jabarovsk,Jabárovsk,KHV,Khabarovka,Khabarovs''k,Khabarovsk,Khabarovskaj,Khabàrovsk,Khbarovsk,Xabarovsk,bo li,habalobseukeu,habarofusuku,hbrwbsq,khabarovska,khabarwfsk,khabarwwsk,Ĥabarovsk,Χαμπάροφσκ,Горад Хабараўск,Хабаровск,Хабаровскай,Хабаровськ,Խաբարովսկ,חברובסק,خاباروفسك,خاباروفسک,خابارووسک,ہابروسک,खबारोव्स्क,ख़ाबारोव्स्क,ハバロフスク,伯力,하바롭스크', 48.4827100, 135.0837900, 'RU', '2012-12-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123069, 'Kazachinskoye', 'Kazachinskoye', 'Kazachinskaye,Kazachinskoe,Kazachinskoye,Kazatsjinskoje,Казачинское', 56.2697400, 107.5762400, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123070, 'Kavalerovo', 'Kavalerovo', 'KVR,Kavalerovo,Kavaletovo,Kawalerowo,Kovalerovo,Kovalevo,Кавалерово', 44.2722100, 135.0522700, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123071, 'Karymskoye', 'Karymskoye', 'Karomskaya,Karymskaya,Karymskoe,Karymskoje,Karymskoye,Karömskaya,Карымское', 51.6166700, 114.3500000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123072, 'Kangalassy', 'Kangalassy', 'Kangalasskiye Kopi,Kangalassy,Kangalastsy,Kangalasy,Namtogor,Odey Vtoroy,Кангалассы', 62.3482400, 129.9647100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123073, 'Kamen’-Rybolov', 'Kamen''-Rybolov', 'Kamen,Kamen''-Rybolov,Kamen-Rybolov,Kamen’-Rybolov,Камень-Рыболов', 44.7452000, 132.0465000, 'RU', '2012-04-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123074, 'Kamenka', 'Kamenka', 'Kamenka,Каменка', 44.4586500, 136.0140300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123075, 'Kalga', 'Kalga', 'Kalga,Калга', 50.9253800, 118.8995800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123076, 'Kalanguy', 'Kalanguy', 'Kalangui,Kalanguj,Kalanguy,Kolanguy,Kolonduy,Калангуй', 51.0166700, 116.5166700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123077, 'Kadaya', 'Kadaya', 'Kadai,Kadaja,Kaday,Kadaya,Kadaya Pervaya,Кадая', 50.9325400, 119.2946800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123078, 'Kachug', 'Kachug', 'Kachug,Kachuga,Kachurga,Katsjug,Качуг', 53.9605600, 105.8816700, 'RU', '2014-05-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123079, 'Kabansk', 'Kabansk', 'Kabansk,Кабанск', 52.0486100, 106.6527800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123080, 'Izvestkovyy', 'Izvestkovyy', 'Izvestkovaya,Izvestkovyj,Izvestkovyy,Известковый', 48.9804300, 131.5527400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123081, 'Ivolginsk', 'Ivolginsk', 'Ivolga,Ivolginsk,Ivologinsk,Иволгинск', 51.7491900, 107.2837400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123082, 'Ivanovka', 'Ivanovka', 'Ivanovka,Ивановка', 43.9687900, 132.4833100, 'RU', '2013-10-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123083, 'Istok', 'Istok', 'Istok,Исток', 52.0952800, 106.2475000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123084, 'Irkutsk', 'Irkutsk', 'Ehrkhүү khot,Ehrkhүү khoto,Gorad Irkuck,IKT,Ircutia,Irkoetsk,Irkotsk,Irkoutsk,Irkuck,Irkutk,Irkuts''k,Irkutsc,Irkutsk,Irkutska,Irkutskaj,Irkutskas,Irkutszk,Irkuțk,Irkùck,ayrktsk,ayrkwtsk,ileukucheukeu,irakutska,irukutsuku,xir khut skh,yi er ku ci ke,İrkutsk,Ιρκούτσκ,Іркутськ,Горад Іркуцк,Иркутск,Иркутскай,Иркуцк,Эрхүү хот,Эрхүү хото,Өrket,Өркет,אירקוטסק,אירקוצק,إيركوتسك,ارکٹسک,ایرکتسک,ایرکوتسک,इरकुत्स्क,อีร์คุตสค์,ირკუტსკი,イルクーツク,伊爾庫茨克,이르쿠츠크', 52.2977800, 104.2963900, 'RU', '2013-12-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123085, 'Imeni Poliny Osipenko', 'Imeni Poliny Osipenko', 'Imeni Poliny Osipenko,Kerbi,Kerbinsk,Osipenko,Poselok Imeni Poliny Osipenko,im.Poliny Osipenko,imeni Poliny Osipenko,Имени Полины Осипенко,им.Полины Осипенко,имени Полины Осипенко', 52.4227000, 136.4869200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123086, 'Il’ka', 'Il''ka', 'Il''ka,Ilka,Il’ka,Илька', 51.7211400, 108.5216900, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123087, 'Ilir', 'Ilir', 'Ilir,Илир', 55.2247300, 100.6849800, 'RU', '2013-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123088, 'Il’inka', 'Il''inka', 'Il''inka,Il''inskiy,Il''inskoye,Il''inskyi Istochnik,Ilinka,Ilyinskoye,Il’inka,Il’inskiy,Il’inskoye,Il’inskyi Istochnik,Ильинка', 52.1194400, 107.2708300, 'RU', '2015-04-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123089, 'Ikey', 'Ikey', 'Ikej,Ikey,Икей', 54.1919400, 100.0811100, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123090, 'Gusinoye Ozero', 'Gusinoye Ozero', 'Gusinoe Ozero,Gusinoje-Ozero,Gusinoozerskiy Datsan,Gusinoozyorskiy Monastery,Gusinoye Ozero,Гусиное Озеро', 51.1144400, 106.2613900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123091, 'Gusinoozyorsk', 'Gusinoozyorsk', 'Bestuzhev,Gusinoozerak,Gusinoozersk,Gusinoozjorsk,Gusinoozyorsk,Gusinoozërsk,Gusnooversk,Shakhty,Yelanovskiy,Гусиноозёрск', 51.2833300, 106.5000000, 'RU', '2014-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123092, 'Guran', 'Guran', 'Guran,Гуран', 54.7612700, 100.6439900, 'RU', '2013-07-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123093, 'Gornyye Klyuchi', 'Gornyye Klyuchi', 'Gornye Kljuchi,Gornye-Kljutsji,Gornyye Klyuchi,Горные Ключи', 45.2422100, 133.5060100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123094, 'Gornyy', 'Gornyy', 'Gornyj,Gornyy,Solnechnoye,Solnechnyy,Горный', 50.7634400, 136.4495100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123095, 'Gornorechenskiy', 'Gornorechenskiy', 'Gornorechenskij,Gornorechenskiy,Gornoretsjenskij,Горнореченский', 44.2655500, 135.1146500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123096, 'Gorin', 'Gorin', 'Gorin,Горин', 51.1986100, 136.6621600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123097, 'Gazimurskiy Zavod', 'Gazimurskiy Zavod', 'Gazimurskij Zavod,Gazimurskiy Zavod,Gazimurskizavod,Газимурский Завод', 51.5535200, 118.3446000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123098, 'Gadaley', 'Gadaley', 'Gadalej,Gadaley,Гадалей', 54.4031800, 100.7409300, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123099, 'Ekimchan', 'Ekimchan', 'Ehkimchan,Ekimchan,Ekimtsjan,Экимчан', 53.0697200, 132.9401100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123100, 'Dzhida', 'Dzhida', 'Dzhida,Dzjida,Джида', 50.6772200, 106.1805600, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123101, 'Dzhebariki-Khaya', 'Dzhebariki-Khaya', 'Dzhebariki-Khaja,Dzhebariki-Khaya,Dzjebariki-Khaja,Джебарики-Хая', 62.2108400, 135.8487600, 'RU', '2014-02-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123102, 'Dunay', 'Dunay', 'Dunai,Dunaj,Dunay,Shkotovo-22,Дунай', 42.8788100, 132.3352100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123103, 'Dul’durga', 'Dul''durga', 'Dul''durga,Duldurga,Duldurgh,Dul’durga,Дульдурга', 50.6761100, 113.5930600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123104, 'Drovyanaya', 'Drovyanaya', 'Drouyanaya,Drovjanaja,Drovyanaya,Дровяная', 51.5762000, 113.0407800, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123105, 'Dostoyevka', 'Dostoyevka', 'Dostoevka,Dostojevka,Dostoyevka,Достоевка', 44.3255400, 133.4813400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123106, 'Domna', 'Domna', 'Demninskoye,Dominskoye,Domna,Domninskoye,Domno,Домна', 51.8971200, 113.1573000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123107, 'Dauriya', 'Dauriya', 'Dauria,Daurija,Dauriya,Daurskoye,Даурия', 49.9333300, 116.8666700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123108, 'Darasun', 'Darasun', 'Darasun,Дарасун', 51.6594000, 113.9751500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123109, 'Dal’nerechensk', 'Dal''nerechensk', 'Dal''nerechensk,Dalneretsjensk,Dal’nerechensk,Iman,Дальнереченск', 45.9314900, 133.7390600, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123110, 'Churapcha', 'Churapcha', 'Churapcha,Tsjuraptsja,Чурапча', 61.9985800, 132.4334100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123111, 'Chumikan', 'Chumikan', 'Chumikan,Chumukan,Tsjumikan,Чумикан', 54.7185700, 135.3163000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123112, 'Chul’man', 'Chul''man', 'Chul''man,Chul’man,NER,Tsjulman,Utesnaya,Чульман', 56.8473500, 124.9081200, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123113, 'Chuguyevka', 'Chuguyevka', 'Chuguevka,Chuguyevka,Tsjugujevka,Чугуевка', 44.1665200, 133.8649500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123114, 'Chkalovskoye', 'Chkalovskoye', 'Chkalovskoe,Chkalovskoye,Tsjkalovskoje,Zen''kovka,Zen’kovka,Чкаловское', 44.8380800, 133.0433200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123115, 'Chita', 'Chita', 'Chita,Chitá,HTA,Tchita,Tschita,Tsita,Tsjita,Tšita,chi ta,chita,Чита,チタ,赤塔,치타', 52.0317100, 113.5008700, 'RU', '2017-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123116, 'Chernyshevskiy', 'Chernyshevskiy', 'Chernyshevskij,Chernyshevskiy,Tsjernysjevskij,Чернышевский', 63.0160100, 112.4690100, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123117, 'Chernyshevsk', 'Chernyshevsk', 'Chernyshevsk,Imeni Kaganovicha,Poselok Imeni Kaganovicha,Posëlok Imeni Kaganovicha,Tsjernysjevsk,Чернышевск', 52.5220900, 117.0171200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123118, 'Chernyshëvka', 'Chernyshevka', 'Chernyshevka,Chernyshjovka,Chernyshëvka,Tsjernysjevka,Чернышевка,Чернышёвка', 44.1997100, 133.1319300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123119, 'Chernigovka', 'Chernigovka', 'Chernigovka,Tsjernigovka,Черниговка', 44.3421600, 132.5693700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123120, 'Cheremkhovo', 'Cheremkhovo', 'Cheremkhovo,Tseremhovo,Tsjeremkhovo,Tšeremhovo,Черемхово', 53.1561100, 103.0675000, 'RU', '2016-12-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123121, 'Chegdomyn', 'Chegdomyn', 'Chagdamin,Chagdamyn,Chegdomyn,Tsjegdomyn,Чегдомын', 51.1285300, 133.0082700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123122, 'Chara', 'Chara', 'Char,Chara,Staraja Chara,Старая Чара,Чара', 56.9063900, 118.2630600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123123, 'Bureya', 'Bureya', 'Bureia,Bureja,Bureya,Бурея', 49.8121200, 129.8127800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123124, 'Bukachacha', 'Bukachacha', 'Bukachacha,Bukatsjatsja,Букачача', 52.9833300, 116.9166700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123125, 'Budagovo', 'Budagovo', 'Budagovo,Будагово', 54.6255000, 100.1310900, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123126, 'Borzya', 'Borzya', 'Bolzhia,Borzia,Borzja,Borzya,Борзя', 50.3833300, 116.5166700, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123127, 'Borogontsy', 'Borogontsy', 'Borogoncy,Borogontsi,Borogontsy,Борогонцы', 62.6706000, 131.1634400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123128, 'Bol’shoy Kunaley', 'Bol''shoy Kunaley', 'Bol''shoj Kunalej,Bol''shoy Kunaley,Bolsjoj Kunalej,Bol’shoy Kunaley,Kunaleiskoye,Kunaley,Kunaleyskoye,Большой Куналей', 51.4320300, 107.6089000, 'RU', '2013-08-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123129, 'Bol’shoy Kamen’', 'Bol''shoy Kamen''', 'Bol''shoj Kamen'',Bol''shoy Kamen'',Bol’shoy Kamen’,Большой Камень', 43.1128300, 132.3540000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123130, 'Bol’shaya Tura', 'Bol''shaya Tura', 'Bol''shaja Tura,Bol''shaya Tura,Bol’shaya Tura,Большая Тура', 51.6164200, 114.1124200, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123131, 'Bol’shaya Rechka', 'Bol''shaya Rechka', 'Bol''shaja Rechka,Bol''shaya Rechka,Bolsjaja Retsjka,Bol’shaya Rechka,Большая Речка', 51.9536000, 104.7335000, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123132, 'Bokhan', 'Bokhan', 'Bokhan,Бохан', 53.1530000, 103.7714000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123133, 'Bodaybo', 'Bodaybo', 'Bodaibo,Bodajbo,Bodaybo,ODO,Бодайбо', 57.8505600, 114.1933300, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123134, 'Blagoveshchensk', 'Blagoveshchensk', 'BQS,Blagovechtchensk,Blagovescensk,Blagovescenska,Blagovescenskas,Blagoveschensk,Blagovescsenszk,Blagoveshchensk,Blagoveshensk,Blagoveshhens''k,Blagoveshhensk,Blagoveshhensk shaary,Blagovesjtjensk,Blagovesjtsjensk,Blagovestsensk,Blagovesxensk,Blagovextxensk,Blagoveŝĉensk,Blagoveşçensk,Blagoveštšensk,Blagoveščensk,Blagoveščenska,Blagoveščenskas,Blagoveșcensk,Blagovjescensk,Blagovjeshchensk,Blagovješčensk,Blagovyeshchensk,Blagovéshchensk,Blagovésxensk,Blagověščensk,Blagoweschtschensk,Blagowesjtsjensk,Blagowieszczensk,Blagowjeschtschensk,Blаgоvеsjtsjеnsk,Błagowieszczeńsk,Gorad Blagaveshchansk,Hailanpao,b la ko wech chen skh,beullagobesyenseukeu,blaghwfyshtshynsk,blagwwshchnsk,blagwwyshchnsk,blagwwyshchynsk,blʼgwbsznsq,buragovu~eshichensuku,hai lan pao,Благовешенск,Благовешченск,Благовещенск,Благовещенск шаары,Благовєщенськ,Благовјешченск,Горад Благавешчанск,Բլագովեշչենսկ,בלאגובשצנסק,بلاغوفيشتشينسك,بلاگووشچنسک,بلاگوویشچنسک,بلاگوویشچینسک,บลาโกเวชเชนสค์,ბლაგოვეშჩენსკი,ブラゴヴェシチェンスク,海兰泡,海蘭泡,블라고베셴스크', 50.2796100, 127.5405000, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123135, 'Blagodatnoye', 'Blagodatnoye', 'Blagodatnoe,Blagodatnoje,Blagodatnoye,Blagodatny,Благодатное', 44.3228500, 132.0905000, 'RU', '2013-10-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123136, 'Birobidzhan', 'Birobidzhan', 'Birabidzhan,Birobican,Birobidjan,Birobidschan,Birobidshansk,Birobidzan,Birobidzana,Birobidzanas,Birobidzhan,Birobidzhán,Birobidzjan,Birobidzsan,Birobidżan,Birobidžan,Birobidžana,Birobidžanas,Birobigano,Birobijan,Birobiĝano,Bîrobîcan,Gorad Birabidzhan,Tikhon''kaya Stantsiya,Tikhon’kaya Stantsiya,Tikhou''kaya Stantsiya,Tikhou’kaya Stantsiya,bi luo bi zhan,bilobijan,birobijan,byrwbygn,byrwbyjan,Биробиджан,Биробиџан,Біробіджан,Горад Бірабіджан,ביראבידזשאן,בירוביגן,بيروبيجان,بیروبیجان,ビロビジャン,比罗比詹,비로비잔', 48.7928400, 132.9238600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123137, 'Birakan', 'Birakan', 'Birakan,Birokan,Биракан', 48.9930200, 131.7202600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123138, 'Bira', 'Bira', 'Bira,Birskij,Birskiye,Бира,Бирский', 49.0013500, 132.4682600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123139, 'Bikin', 'Bikin', 'Bikin,Bikinas,Bikine,Bikín,Gorad Bikin,bi jin,bikin,bykyn,Бикин,Горад Бікін,بيكين,بیکین,ビキン,比金,비킨', 46.8129300, 134.2501200, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123140, 'Bichura', 'Bichura', 'Bichura,Bichurskoye,Bitsjura,Бичура', 50.5880600, 107.6022200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123141, 'Berkakit', 'Berkakit', 'Berhakit,Berkakit,Berkokit,Беркакит', 56.5745600, 124.7763500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123142, 'Berëzovyy', 'Berezovyy', 'Berezovyj,Berezovyy,Berjozovyj,Berëzovyy,Veli,Берёзовый', 51.6689700, 135.6658400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123143, 'Berdigestyakh', 'Berdigestyakh', 'Berdigestjakh,Berdigestyakh,Berdigistyakh,Berdigyastyakh,Бердигестях', 62.0984200, 126.6957300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123144, 'Belogorsk', 'Belogorsk', 'Aleksandrovka,Aleksandrovsk,Beletorsk,Belogors''k,Belogorsk,Belogorsk i Amur oblast,Belogorskas,Beloqorsk,Bielogorsk,Biełogorsk,Gorad Belagorsk,Kuibyshevka,Kuybyshevka,Kuybyshevka-Vostochnaya,Svobodnyy-18,bellogoleuseukeu,berogorusuku,bie luo ge er si ke,blwgwrsk  astan amwr,bylwghwrsk,bylwgwrsk,bylwgwrsk  amwr awblast,Белогорск,Бєлогорськ,Горад Белагорск,بلوگورسک، استان آمور,بيلوغورسك,بیلوگورسک,بیلوگورسک، آمور اوبلاست,ベロゴルスク,别洛戈尔斯克,벨로고르스크', 50.9164400, 128.4772600, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123145, 'Baykal’sk', 'Baykal''sk', 'Bajkal''sk,Bajkalsk,Baykal''sk,Baykal’sk,Байкальск', 51.5151000, 104.1402000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123146, 'Bayangol', 'Bayangol', 'Bajangol,Bayangol,Баянгол', 50.6977000, 103.4656000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123147, 'Bayanday', 'Bayanday', 'Baindai,Bainday,Bajandaj,Bayanday,Баяндай', 53.0661100, 105.5138900, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123148, 'Batagay-Alyta', 'Batagay-Alyta', 'Alytay-Bataga,Batagai-Alyta,Batagaj-Alyta,Batagay-Alyta,SUK,Sakkyryr,Батагай-Алыта,Саккырыр', 67.7984600, 130.4011900, 'RU', '2013-10-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123149, 'Batagay', 'Batagay', 'BQJ,Batagaj,Batagay,Батагай', 67.6565300, 134.6396200, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123150, 'Barguzin', 'Barguzin', 'Barguzin,Баргузин', 53.6187500, 109.6390400, 'RU', '2012-09-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123151, 'Barabash', 'Barabash', 'Barabash,Barabasj,Барабаш', 43.1994800, 131.4918500, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123152, 'Balyaga', 'Balyaga', 'Baljaga,Balyaga,Баляга', 51.1529300, 108.9276700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123153, 'Baley', 'Baley', 'Balei,Balej,Baley,Batey,Novo-Troitskiy Promysel,Nowo Troizkoje,Балей', 51.5816600, 116.6339500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123154, 'Balakhninskiy', 'Balakhninskiy', 'Balakhninskij,Balakhninskiy,Балахнинский', 58.0105600, 114.2769400, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123155, 'Balagansk', 'Balagansk', 'Baiagansk,Balagansk,Balaganski,Балаганск', 54.0057000, 103.0523400, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123156, 'Baklashi', 'Baklashi', 'Akinino-Baklashi,Baklashi,Baklasji,Баклаши', 52.2255600, 104.0486100, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123157, 'Bagdarin', 'Bagdarin', 'Bagdarin,Bogdarin,Багдарин', 54.4333300, 113.6000000, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123158, 'Badar', 'Badar', 'Badar,Bodarskoye,Бадар', 54.3994800, 100.5943600, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123159, 'Bada', 'Bada', 'Bada,Бада', 51.3910000, 109.8614500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123160, 'Babushkin', 'Babushkin', 'Babushkin,Mosovsk,Mysovaya,Mysovsk,Mösovsk,Бабушкин', 51.7122200, 105.8647200, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123161, 'Babstovo', 'Babstovo', 'Babetova,Babetovskiy,Babetovskoye,Babstova,Babstovo,Babstovskoye,Babstvo,Babstwo,Babustowa,Babustōwa,Babusutowa,Babusutōwa,Бабстово', 48.1185300, 132.4791300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123162, 'Aykhal', 'Aykhal', 'Aihal,Aikhal,Ajkhal,Aykhal,Айхал', 65.9338100, 111.4834000, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123163, 'Ayan', 'Ayan', 'Ajan,Ayan,Аян', 56.4631400, 138.1777700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123164, 'Atamanovka', 'Atamanovka', 'Atamanovka,Atamanskaja,Atamanskaya,Атамановка,Атаманская', 51.9333300, 113.6333300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123165, 'Artëm', 'Artem', 'Artem,Artjom,Artëm,Артем,Артём', 43.3595000, 132.1888700, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123166, 'Arsen’yev', 'Arsen''yev', 'Arsen''ev,Arsen''yev,Arsenjev,Arsen’yev,Semenovka,Арсеньев', 44.1525400, 133.2779100, 'RU', '2016-12-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123167, 'Arkhara', 'Arkhara', 'Arkhara,Архара', 49.4244700, 130.0856900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123168, 'Anuchino', 'Anuchino', 'Akuchino,Anuchino,Anutsjino,Анучино', 43.9657100, 133.0584600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123169, 'Angarsk', 'Angarsk', 'Angars''k,Angarsk,Angarska,Angarskas,Angarskiy,Angarszk,Anqarsk,Gorad Angarsk,agarasaka,an jia er si ke,angaleuseukeu,angarsk,angarusuku,angharsk,Ангарск,Ангарськ,Горад Ангарск,آنگارسک,أنغارسك,انگارسک,ਅੰਗਾਰਸਕ,アンガルスク,安加尔斯克,안가르스크', 52.5366700, 103.8863900, 'RU', '2014-10-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123170, 'Amurzet', 'Amurzet', 'Amurzet,Амурзет', 47.6954100, 131.0949300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123171, 'Amursk', 'Amursk', 'Amoursk,Amurs''k,Amursk,Amurskas,Amursko,Gorad Amursk,Padali,a mu er si ke,amuleuseukeu,amurasaka,amurusuku,amwrsk,Αμούρσκ,Амурск,Амурськ,Горад Амурск,آمورسک,أمورسك,ਅਮੁਰਸਕ,アムールスク,阿穆尔斯克,아무르스크', 50.2368500, 136.8813600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123172, 'Amga', 'Amga', 'Amga,Amia,Amma,Sjalo Amga,amgha,Амга,Амма,Сяло Амга,Ամգա,أمغا', 60.9000900, 131.9788200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123173, 'Amazar', 'Amazar', 'Amazar,Амазар', 53.8603300, 120.8792500, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123174, 'Almaznyy', 'Almaznyy', 'Almaznyj,Almaznyy,Алмазный', 62.4491700, 114.3277800, 'RU', '2012-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123175, 'Alekseyevskaya', 'Alekseyevskaya', 'Alekseevka,Alekseevsk,Alekseevskaja,Alekseyevka,Alekseyevsk,Alekseyevskaya,Алексеевка,Алексеевск,Алексеевская', 57.8500000, 108.4000000, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123176, 'Aleksandrovskiy Zavod', 'Aleksandrovskiy Zavod', 'Aleksandrovski Zavod,Aleksandrovskij Zavod,Aleksandrovskiy Zavod,Alexsandrovskiy Zavod,Александровский Завод', 50.9252500, 117.9377300, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123177, 'Aldan', 'Aldan', 'ADH,Aldan,Aldanas,Ałdan,Nezametnyy,aldan,Алдан,알단', 58.6102100, 125.3961300, 'RU', '2016-11-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123178, 'Aksha', 'Aksha', 'Aksha,Aksja,Акша', 50.2813900, 113.2866700, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123179, 'Aginskoye', 'Aginskoye', 'Aga,Aginskoe,Aginskoje,Aginskoye,Agińskoje,aginseukoye,Ага,Агинское,Агинскоје,아긴스코예', 51.1000000, 114.5300000, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123180, 'Afanas’yeva', 'Afanas''yeva', 'Afanas''eva,Afanas''evo,Afanas''yeva,Afanas''yevo,Afanas’yeva,Afanas’yevo,Afonas''yevo,Afonas’yevo,Афанасьева,Афанасьево', 54.6395800, 100.6175500, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123181, 'Deputatsky', 'Deputatsky', 'DPT,Deputatskij,Deputatskiy,Deputatsky,Депутатский', 69.3095800, 139.9757100, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123182, 'Novyy Urgal', 'Novyy Urgal', 'Novyj Urgal,Novyy Urgal,Новый Ургал', 51.0708900, 132.6007500, 'RU', '2012-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123183, 'Dal''negorsk', 'Dal''negorsk', 'Dal''negorsk,Dalnegorsk,Дальнегорск', 44.5603900, 135.5700900, 'RU', '2010-07-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123184, 'Bratsk', 'Bratsk', 'BTK,Brack,Brats''k,Bratsk,Bratska,Bratskas,Gorad Brack,beulacheukeu,bratsk,bu la ci ke,buratsuku,Братск,Братськ,Горад Брацк,براتسك,براتسک,ブラーツク,布拉茨克,브라츠크', 56.1325000, 101.6141700, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123185, 'Sayansk', 'Sayansk', 'Sajansk,Sayansk,Саянск', 54.1088000, 102.1648000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123186, 'Kuanda', 'Kuanda', 'Kuanda,Куанда', 56.3161100, 116.0805600, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123187, 'Novaya Chara', 'Novaya Chara', 'Novaja Chara,Novaja Tsjara,Novaya Chara,Новая Чара', 56.8163900, 118.2986100, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123188, 'Yantal’', 'Yantal''', 'Jantal,Jantal'',Yantal'',Yantal’,Янталь', 56.8471000, 105.2542000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123189, 'Khabarovsk Vtoroy', 'Khabarovsk Vtoroy', 'Khabarovsk Vtoroj,Khabarovsk Vtoroy,Хабаровск Второй', 48.4377600, 135.1332900, 'RU', '2012-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123190, 'Dzerzhinsk', 'Dzerzhinsk', 'Dzerzhinsk,Дзержинск', 52.2802800, 104.3869400, 'RU', '2013-08-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123191, 'Markova', 'Markova', 'Markova,Markovo,Маркова,Марково', 52.2088900, 104.2108300, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123192, 'Ust’-Kamchatsk Staryy', 'Ust''-Kamchatsk Staryy', '', 56.2277800, 162.4777800, 'RU', '2006-01-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123193, 'Vilyuchinsk', 'Vilyuchinsk', 'Gorad Viljuchynsk,Petropavlovsk-Kamchatskiy-50,Vilioutchinsk,Viljoetsjinsk,Viljuchins''k,Viljuchinsk,Viljucinsk,Viljucsinszk,Viljutsinsk,Viljutsjinsk,Viljutšinsk,Viljučinsk,Viluchinsk,Vilucinsk,Viluecinsk,Viluĉinsk,Vilyuchinsk,Vilüčinsk,Wiljutschinsk,Wiluczinsk,billyuchinseukeu,fylwtshnsk,vu~iryuchinsuku,wei liu qin si ke,wylywchnsk,wylywchynsk,Бүлүүчинскэй,Вилючинск,Виључинск,Вілючинськ,Горад Вілючынск,فيلوتشنسك,ویلیوچنسک,ویلیوچینسک,ヴィリュチンスク,维柳钦斯克,빌류친스크', 52.9311000, 158.4046900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123194, 'Zyryanka', 'Zyryanka', 'Novaya Zyryanka,ZKP,Zyrjanka,Zyryanka,Зырянка', 65.7348900, 150.8942900, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123195, 'Zavety Il’icha', 'Zavety Il''icha', 'Ibyche,Li''ichi,Li’ichi,Zavety Il''icha,Zavety Il’icha', 49.0373700, 140.2698900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123196, 'Yuzhno-Sakhalinsk', 'Yuzhno-Sakhalinsk', 'Gorad Juzhna-Sakhalinsk,Ioujno-Sakhalinsk,Iujno-Sahalinsk,Iujno-Sakhalinsk,Joezjno-Sachalinsk,Jujno-Sahalinsk,Juschno-Sachalinsk,Juzhno-Sakhalins''k,Juzhno-Sakhalinsk,Juzhnosakhalinsk,Juzjno-Sachalinsk,Juzjno-Sakhalinsk,Juzno Sachalinskas,Juzno-Sachalinsk,Juzno-Sahalinsk,Juzno-Sahhalinsk,Juznosachalinsk,Juznosahalinska,Juzsno-Szahalinszk,Juĵno-Saĥalinsk,Jużnosachalińsk,Južno Sachalinskas,Južno-Sachalinsk,Južno-Sahalinsk,Južno-Sahhalinsk,Južnosahaļinska,Suvisahalinsk,Toekhara,Toyohara,Toyokhara,Toëkhara,UUS,Urajimirofuka,Yujno-Sahalinsk,Yujno-Saxalinsk,Yuzhno-Sajalinsk,Yuzhno-Sakhalinsk,nan sa ha lin si ke,yujeunosahallinseukeu,yujhno-sakhalinska,yujinosaharinsuku,ywjnw-sakhalynsk,ywzhnw-sakhalynsk,ywzhnw-skhalnsk,ywzhnwskhalynsk,ywznw-shlynsq,Јужно-Сахалинск,Горад Южна-Сахалінск,Южно-Сахалинск,Южно-Сахалінськ,Южносахалинск,יוזנו-סחלינסק,يوجنو-ساخالينسك,یوژنو-ساخالینسک,یوژنو-سخالنسک,یوژنوسخالینسک,युझ्नो-साखालिन्स्क,ユジノサハリンスク,南萨哈林斯克,유즈노사할린스크', 46.9540700, 142.7360300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123197, 'Yuzhno-Kurilsk', 'Yuzhno-Kurilsk', 'DEE,Furukamappu,Furukamapu,Hurukamappu,Hurukamapu,Iujno-Kurilsk,Joezjno-Koerilsk,Juschno-Kurilsk,Juzhno-Kuril''sk,Juzjno-Kurilsk,Juzno-Kurilsk,Jużno-Kurilsk,Južno-Kurilsk,Kokamappu,Yuzhno-Kuril''skoye,Yuzhno-Kurilsk,Yuzhno-Kuril’skoye,Yuzhno-Kurl''sk,Yuzhno-Kurl’sk,gu fu bu,nan ku li er si ke,yujeunokulilseukeu,Южно-Курильск,南庫里爾斯克,古釜布,유즈노쿠릴스크', 44.0273400, 145.8614600, 'RU', '2015-04-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123198, 'Yelizovo', 'Yelizovo', 'Elizovo,Jelizovo,PKC,Yelizovo,Елизово', 53.1890900, 158.3813500, 'RU', '2016-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123199, 'Yagodnoye', 'Yagodnoye', 'Jagodnoe,Jagodnoje,Yagodnoy,Yagodnoye,Yagodnyy,Yagodnöy,Ягодное', 62.5240600, 149.6282700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123200, 'Yablochnyy', 'Yablochnyy', 'Jablochnyj,Jablotsjnyj,Randomari,Rantomari,Yablochnyy,Яблочный', 47.1520000, 142.0567800, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123201, 'Vostok', 'Vostok', '', 48.9771500, 142.9155600, 'RU', '2013-01-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123202, 'Vanino', 'Vanino', 'Vakino,Vaninas,Vanino,Wanino,banino,fanynw,wa ni nuo,wanino,Ванино,Ваніно,فانينو,ワニノ,瓦尼诺,바니노', 49.0984800, 140.2531300, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123203, 'Vakhrushev', 'Vakhrushev', 'Tomarigishi,Tomarikishi,Tomarikisi,Vakhrushev,Vakhrusjev,Вахрушев', 48.9903500, 142.9530300, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123204, 'Ust’-Omchug', 'Ust''-Omchug', 'Ust''-Omchug,Ust''-Omchuk,Ust-Omtsjug,Ust’-Omchug,Ust’-Omchuk,Усть-Омчуг', 61.1333600, 149.6328300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123205, 'Ust-Nera', 'Ust-Nera', 'Nera,Oest-Nera,Oust-Nera,USR,Ust Nera,Ust''-Nera,Ust''-Niera,Ust-Nera,Ust´-Niera,Usť-Něra,Uus N''ara,Yuryakh-Terde,usuchi=nera,Уст-Нера,Усть-Нера,Уус Ньара,ウスチ＝ネラ', 64.5696800, 143.2370000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123206, 'Uptar', 'Uptar', 'Uptar,Уптар', 59.8992300, 150.8737600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123207, 'Uglezavodsk', 'Uglezavodsk', 'Higashi-Naibuchi,Khigasi-Naybut,Uglezavodsk,Углезаводск', 47.3233200, 142.6331700, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123208, 'Uglegorsk', 'Uglegorsk', 'Esutoru,Esutoru-Hamashigai,Gorad Ugljagorsk,Hama-shigai,Ouglegorsk,Uglegorsk,Uqleqorsk,awghlyghwrsk,awglgwrsk  sakhalyn,awlygwrsk  skhaln awblast,ugeullegoleuseukeu,uguregorusuku,wu ge lie ge er si ke,Горад Углягорск,Углегорск,Угљегорск,أوغليغورسك,اولیگورسک، سخالن اوبلاست,اوگلگورسک، ساخالین,ウグレゴルスク,乌格列戈尔斯克,우글레고르스크', 49.0804700, 142.0644900, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123209, 'Tymovskoye', 'Tymovskoye', 'Derbinsk,Derbinskoye,Tymovskoe,Tymovskoje,Tymovskoye,Тымовское', 50.8492500, 142.6652000, 'RU', '2014-06-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123210, 'Tungor', 'Tungor', 'Tungor,Тунгор', 53.3912100, 142.9575500, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123211, 'Troitskoye', 'Troitskoye', 'Namikawa,Toroetsukoe,Troickoe,Troitskoje,Troitskoye,Troytskoye,Троицкое', 46.9249300, 142.6453200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123212, 'Tomari', 'Tomari', 'Tomari,Tomarioro,Tomarioru,Томари', 47.7648200, 142.0710600, 'RU', '2014-05-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123213, 'Tilichiki', 'Tilichiki', 'Telichiki,Tilichiki,Tilichiky,Tilighiki,Tilitsjiki,Тиличики', 60.4279500, 166.0576400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123214, 'Tigil’', 'Tigil''', 'Tigil,Tigil'',Tigil’,Тигиль', 57.7597900, 158.6816100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123215, 'Talaya', 'Talaya', '', 61.3703800, 152.7687800, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123216, 'Susuman', 'Susuman', 'Gorad Susuman,Soesoeman,Soussouman,Susman,Sussuman,Susuman,Susumanas,Szuszuman,su su man,susuman,susumani,swswman,Горад Сусуман,Сусуман,سوسومان,სუსუმანი,ススマン,苏苏曼', 62.7807500, 148.1539600, 'RU', '2014-06-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123217, 'Srednekolymsk', 'Srednekolymsk', 'Gorad Sjarehdnekalymsk,Orto Khalyma,SEK,Seredn''okolims''k,Srednekolimsk,Srednekolymsk,Srednekolymskas,Sredněkolymsk,Sriedniekolymsk,Sriedniekołymsk,asrdnkwlymsk,seuledeunekollimseukeu,srydnkwlymsk,suredonekorimusuku,zhong ke lei mu si ke,Горад Сярэднекалымск,Орто Халыма,Середньоколимськ,Среднеколимск,Среднеколымск,Средњеколимск,اسردنکولیمسک,سريدنكوليمسك,سرہدنیکولیمسک,スレドネコリムスク,中科雷姆斯克,스레드네콜림스크', 67.4565900, 153.7024600, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123218, 'Sovetskaya Gavan’', 'Sovetskaya Gavan''', 'GVN,Port Soviet,Sovetskaja Gavan,Sovetskaja Gavan'',Sovetskaya Gavan'',Sovetskaya Gavan’,Soviet Harbor,Sovietskaya Harbour,Znamenskoye,Советская Гавань', 48.9721500, 140.2891900, 'RU', '2017-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123219, 'Sokol', 'Sokol', 'Sokol,Сокол', 59.9183400, 150.7495600, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123220, 'Sokol', 'Sokol', 'Barishiyatakoe,Otani,Sokol,Ōtani,Сокол', 47.2446400, 142.7516700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123221, 'Smirnykh', 'Smirnykh', 'Keton,Ketongai,Kiton,Smirnov,Smirnykh,Смирных', 49.7459600, 142.8371600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123222, 'Sinegor''ye', 'Sinegor''ye', 'Sinegor''e,Синегорье', 62.0878200, 150.5216200, 'RU', '2013-11-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123223, 'Sinegorsk', 'Sinegorsk', 'Kavakami,Kavakami-Tandzan,Kawakami,Kawakamitanzan,Pusutaaki,Sinegorsk,Синегорск', 47.1727800, 142.5157700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123224, 'Shebunino', 'Shebunino', 'Koni,Kōni,Minami-Nayosi,Minami-nayoshi,Shebunino,Sjebunino,Шебунино', 46.4301000, 141.8569900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123225, 'Shakhtersk', 'Shakhtersk', 'EKS,Shakhtersk,Shatiersk,Shatinsk,Sjakhtersk,Toro,Tōro,Шахтерск', 49.1717500, 142.1364000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123226, 'Seymchan', 'Seymchan', 'Seimchan,Sejmchan,Sejmtsjan,Semchan,Seymchan,Сеймчан', 62.9337300, 152.3910900, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123227, 'Severo-Kuril’sk', 'Severo-Kuril''sk', 'Kashiwabara,Kasivobara,Severo-Kuril''sk,Severo-Kurilsk,Severo-Kuril’sk,sebelo kulilseukeu,Северо-Курильск,세베로 쿠릴스크', 50.6753100, 156.1269500, 'RU', '2017-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123228, 'Pravda', 'Pravda', 'Hirochi,Hiroti,Khirochi,Khiroti,Pirochi,Pravda,Pravka,Правда', 46.9397200, 142.0042600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123229, 'Poronaysk', 'Poronaysk', 'Poronajsk,Poronaysk,Shikika,Shikuka,Shisuka,Sikuka,Поронайск', 49.2218800, 143.0969400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123230, 'Pevek', 'Pevek', 'Gorad Pevek,PWE,Peeqin,Pevek,Peveka,Pevekas,Peveke,Pewek,byfyk,pebekeu,pei wei ke,pevu~eku,pwk  chwkwtka,pywyk,Горад Певек,Певек,بيفيك,پوک، چوکوتکا,پیویک,ペヴェク,佩韦克,페베크', 69.7028700, 170.2999300, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123231, 'Petropavlovsk-Kamchatsky', 'Petropavlovsk-Kamchatsky', 'Gorad Petrapaulausk-Kamchacki,Kamchatkataagy Petropavlovskaj,Kamciatkos Petropavlovskas,Kamčiatkos Petropavlovskas,PKC,Petropaulovscum Camtschaticum,Petropavlofsk Kamtsatski,Petropavlovs''k-Kamchats''kij,Petropavlovsk,Petropavlovsk Kamcatkal,Petropavlovsk Kamcatski,Petropavlovsk Kamchatski,Petropavlovsk Kamchatsky,Petropavlovsk Kamciatki,Petropavlovsk Kamciațki,Petropavlovsk Kamčatkal,Petropavlovsk Kamčatski,Petropavlovsk-Kamcatski,Petropavlovsk-Kamcatskij,Petropavlovsk-Kamchatkari,Petropavlovsk-Kamchatski,Petropavlovsk-Kamchatskij,Petropavlovsk-Kamchatskiy,Petropavlovsk-Kamchatsky,Petropavlovsk-Kamtchatski,Petropavlovsk-Kamtjatskij,Petropavlovsk-Kamtsatski,Petropavlovsk-Kamtsjatski,Petropavlovsk-Kamtsjatskij,Petropavlovsk-Kamtxatski,Petropavlovsk-Kamtšatski,Petropavlovsk-Kamçatski,Petropavlovsk-Kamĉatskij,Petropavlovsk-Kamčatski,Petropavlovsk-Kamčatskij,Petropavlovska-Kamcatska,Petropavlovska-Kamčatska,Petropavlovszk-Kamcsatszkij,Petropawlofsk-Kamtsjatski,Petropawlowsk-Kamtschatski,Petropàvlovsk-Kamtxatski,Petropávlovsk-Kamchatski,Pietropawlowsk Kamczacki,Pietropawłowsk Kamczacki,btrwbaflwfsk,kan cha jia bi de ba fu luo fu si ke,kan cha jia de bi de ba fu luo fu si ke,peteulopabeullobseukeukamchacheuki,peteulopabeullopeuseukeu kamchaseuki,pi tra paflafskh-khamchat ski,ptrwpawlwfsk-kamchatskyy,ptrwpblwbsq-qmztsqy,pytrwpawlwwsk kmchatsky,Πετροπάβλοφσκ Καμτσάτσκι,Горад Петрапаўлаўск-Камчацкі,Камчаткатааҕы Петропавловскай,Петропавловск Камчатски,Петропавловск-Камчаткăри,Петропавловск-Камчатски,Петропавловск-Камчатский,Петропавловськ-Камчатський,Կամչատկայի Պետրոպավլովսկ,פטרופבלובסק-קמצטסקי,بتروبافلوفسك,پتروپاولوفسک-کامچاتسکیی,پٹروپاولوسک-کامچاٹسکی,پیتروپاولووسک کمچاتسکی,ปิตราปัฟลัฟสค์-คัมชัตสกี,ペトロパブロフスク・カムチャツキー,堪察加彼得巴甫洛夫斯克,堪察加的彼得巴甫洛夫斯克,페트로파블로프스크 캄차스키,페트로파블롭스크캄차츠키', 53.0444400, 158.6507600, 'RU', '2017-06-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123232, 'Paratunka', 'Paratunka', 'Paratunka,Паратунка', 52.9620200, 158.2572300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123233, 'Palatka', 'Palatka', 'Palatka,Палатка', 60.1018300, 150.9343300, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123234, 'Palana', 'Palana', 'Palan,Palana,Palanae,Pałana,balana,pa la na,pallana,parana,plnh,Παλάνα,Паланæ,Палана,פלנה,بالانا,パラナ,帕拉纳,팔라나', 59.0838400, 159.9563000, 'RU', '2012-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123235, 'Ozernovskiy', 'Ozernovskiy', 'Ozernaya,Ozernovskij,Ozernovskiy,Ozernoye,Озерновский', 51.4960400, 156.5010200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123236, 'Ossora', 'Ossora', 'Ossora,Оссора', 59.2478100, 163.0703400, 'RU', '2016-07-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123237, 'Orotukan', 'Orotukan', 'Orotukan,Urutukan,Оротукан', 62.2642300, 151.6715300, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123238, 'Omsukchan', 'Omsukchan', 'Omsukchan,Omsuktsjan,Омсукчан', 62.5157500, 155.7903800, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123239, 'Ola', 'Ola', 'Ola,Ола', 59.5782300, 151.2981900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123240, 'Okhotsk', 'Okhotsk', 'OHO,Ochock,Ochotium,Ochotsk,Ohhotsk,Ohotsk,Ohotska,Ohotszk,Ojotsk,Okhotak,Okhots''k,Okhotsk,Okhotskaj,Okotsk,e huo ci ke,ohocheukeu,ohotsuku,Охотск,Охотскай,Охотськ,オホーツク,鄂霍次克,오호츠크', 59.3620000, 143.2146800, 'RU', '2014-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123241, 'Okha', 'Okha', 'OHH,Okha,Okhe,Оха', 53.5899100, 142.9531300, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123242, 'Nogliki', 'Nogliki', 'NGK,Noglik,Nogliki,Novliki,Ноглики', 51.7991700, 143.1387100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123243, 'Nikolayevsk-on-Amure', 'Nikolayevsk-on-Amure', 'NLI,Nikolaevsk,Nikolaevsk-na-Amur,Nikolaevsk-na-Amure,Nikolaevsk-on-Amur,Nikolaievsk,Nikolaievsk-sur-l''Amour,Nikolajevsk aan de Amoer,Nikolajevsk na Amuru,Nikolajevsk-na-Amure,Nikolajewsk nad Amurem,Nikolayevsk,Nikolayevsk-on-Amur,Nikolaïevsk-sur-l''Amour,Nikołajewsk nad Amurem,ni gu la ye fu si ke,nikollayebseukeunaamule,Николаевск-на-Амуре,Николајевск на Амуру,ニコラエフスク・ナ・アムーレ,尼古拉耶夫斯克,니콜라옙스크나아무레', 53.1465700, 140.7228700, 'RU', '2014-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123244, 'Nevel’sk', 'Nevel''sk', 'Honto,Khonto,Nevel''sk,Nevelsk,Nevel’sk,Невельск', 46.6790200, 141.8562900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123245, 'Myaundzha', 'Myaundzha', 'Bilikan,Mjaundzha,Mjaundzja,Myaundzha,Мяунджа', 63.0499600, 147.1843800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123246, 'Mgachi', 'Mgachi', 'Mgachi,Poselok Mgachi,Мгачи', 51.0483400, 142.2682100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123247, 'Mayskiy', 'Mayskiy', 'Desna,Dyesna,Majskij,Mayskiy,Майский', 48.9988700, 140.2097600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123248, 'Makarov', 'Makarov', 'Higashishirutoru,Higasisirutoru,Makarov,Shiritori,Shiritoru,Shirutoru,Siritoru,Sirutoru,Макаров', 48.6269800, 142.7799900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123249, 'Mago', 'Mago', 'Mago,Маго', 53.2585100, 140.1826900, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123250, 'Magadan', 'Magadan', 'GDX,Gorad Magadan,Magadaan,Magadan,Magadana,Magadanas,Magadán,Mankantan,Maqadan,ma jia dan,magadan,magadana,maghadan,majadan,mgdn,Μαγκαντάν,Горад Магадан,Магадаан,Магадан,Մագադան,מגדן,ماجادان,ماغادان,ماگادان,मागादान,マガダン,马加丹,마가단', 59.5638000, 150.8034700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123251, 'Lososina', 'Lososina', 'Lososina,Лососина', 48.9965200, 140.3146200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123252, 'Leonidovo', 'Leonidovo', 'Kami-shikika,Kami-shikuka,Kamisikuka,Leonidovo,Sikuka,Sikukagawa,Леонидово', 49.2861900, 142.8697500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123253, 'Lazarev', 'Lazarev', 'Kungasnaya,Lazarev,Lazarevka,Mys Lazareva,Лазарев', 52.2230700, 141.5126500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123254, 'Kuril’sk', 'Kuril''sk', 'Kuril''sk,Kurilsk,Kuril’sk,Sh-Iana,Shana,Syana,Курильск', 45.2268600, 147.8776700, 'RU', '2016-05-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123255, 'Krasnogorsk', 'Krasnogorsk', 'Chinnai,Chinnay,Krasnogorsk,Tinnay,Uzunai,Красногорск', 48.4172800, 142.0868600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123256, 'Korsakov', 'Korsakov', 'Gorad Karsakau,Korsakov,Korsakow,Korskov,Korusakofu,Odomari,Otomari,Poroantomari,ke er sa ke fu,koleusakopeu,korusakofu,kwrsakwf,kwrskwf,Ódomari,Ōtomari,Горад Карсакаў,Корсаков,كورسكوف,کورساکوف,コルサコフ,科尔萨科夫,코르사코프', 46.6342000, 142.7772200, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123257, 'Klyuchi', 'Klyuchi', 'Kljuchi,Kljutsji,Kluchi,Klychi,Klyuchevsk,Klyuchi,Klyutchi,Ключи', 56.3203500, 160.8454100, 'RU', '2013-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123258, 'Kholodnyy', 'Kholodnyy', 'Kholodnyj,Kholodnyy,Холодный', 62.7133300, 147.9136100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123259, 'Kholmsk', 'Kholmsk', 'Kholmsk,Maoka,Mauka,Moaka,Холмск', 47.0473700, 142.0504800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123260, 'Gornozavodsk', 'Gornozavodsk', 'Gornozavodsk,Naiboro,Naihoro,Naiporo,Nayboro,Naykhoro,Горнозаводск', 46.5598400, 141.8435800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123261, 'Gastello', 'Gastello', 'Gastello,Grebenskoye,Naiero,Nairo,Naiyoro,Nayoro,Nayro,Гастелло', 49.1005600, 142.9591700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123262, 'Evensk', 'Evensk', 'Bol''shaya Garmanda,Bol’shaya Garmanda,Ehvensk,Evensk,SWV,Эвенск', 61.9172200, 159.2334800, 'RU', '2013-08-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123263, 'Esso', 'Esso', 'Ehsso,Esso,Onovgai,Onovgay,Ornovgay,Yesso,Эссо', 55.9273800, 158.7070800, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123264, 'Dukat', 'Dukat', 'Dukat,Дукат', 62.5723100, 155.3498800, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123265, 'Dolinsk', 'Dolinsk', 'Dolins''k,Dolinsk,Garuginourasukoe,Gorad Dolinsk,Ochiai,Oshiai,Otiai,Otiay,dollinseukeu,dorinsuku,duo lin si ke,dwlynsk,dwlynsk  skhaln awblast,Горад Долінск,Долинск,Долинськ,دولينسك,دولینسک,دولینسک، سخالن اوبلاست,ドリンスク,多林斯克,돌린스크', 47.3294600, 142.7929100, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123266, 'De-Kastri', 'De-Kastri', 'Chikhacheva,De-Kastri,Debastri,Decastri,Port De Kastri,Port Kastri,Де-Кастри', 51.4754300, 140.7698600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123267, 'Chokurdakh', 'Chokurdakh', 'Baryllakh,CKH,Chakurdakh,Chekyrdakh,Chokurdakh,Tsjokurdakh,Чокурдах', 70.6189700, 147.8973000, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123268, 'Cherskiy', 'Cherskiy', 'CYX,Cherskij,Cherskiy,Kresty,Nizhne-Kresty,Nizhniye Kresty,Stadukhina,Tsjerskij,Черский', 68.7532500, 161.3319700, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123269, 'Chekhov', 'Chekhov', 'Chekhov,Noda,Nodasamu,Nodasan,Nota,Notasamu,Notasan,Tsjekhov,Чехов', 47.4498400, 141.9906400, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123270, 'Bykov', 'Bykov', 'Bykov,Naibuchi,Naybuti,Быков', 47.3209900, 142.5622600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123271, 'Boshnyakovo', 'Boshnyakovo', 'Bol''shakovo,Bol’shakovo,Boshnjakovo,Boshnyakovo,Bosjnjakovo,Nishi-sakutan,Nishisakovtan,Nisisakutan,Posyolok,Sakotan,Shakotan,Vos-Bushin''yakov,Vos-Bushin’yakov,Бошняково', 49.6457200, 142.1704700, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123272, 'Bogorodskoye', 'Bogorodskoye', 'BQG,Bogorodsk,Bogorodskaya,Bogorodskoe,Bogorodskoje,Bogorodskoye,Богородское', 52.3739700, 140.4357900, 'RU', '2017-01-22', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123273, 'Bilibino', 'Bilibino', 'Bilibinas,Bilibino,Bilíbino,Gorad Bilibina,bi li bi nuo,billibino,bylybynw,Билибино,Білібіно,Горад Білібіна,بيليبينو,بیلیبینو,比利比诺,빌리비노', 68.0546400, 166.4372100, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123274, 'Beringovskiy', 'Beringovskiy', 'Beringovskij,Beringovskiy,Bukhta Ugol'' Naya,Bukhta Ugol’ Naya,Ugol''naya,Ugol''nyy,Ugolnoe,Ugol’naya,Ugol’nyy,Беринговский', 63.0610100, 179.3504600, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123275, 'Belaya Gora', 'Belaya Gora', 'BGN,Belaja Gora,Belaya Gora,Белая Гора', 68.5380500, 146.1858300, 'RU', '2013-08-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123276, 'Atlasovo', 'Atlasovo', 'Atlasovo,Атласово', 55.6065000, 159.6426600, 'RU', '2013-01-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123277, 'Arman’', 'Arman''', 'Arman'',Arman’,Армань', 59.6699400, 150.1316400, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123278, 'Aniva', 'Aniva', 'Aniva,Aniwa,Gorad Aniva,Rudaka,Rutaka,a ni wa,aniba,aniwa,anyfa,anywa,Анива,Аніва,Горад Аніва,آنیوا,أنيفا,انیوا,アニワ,阿尼瓦,아니바', 46.7149200, 142.5286600, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123279, 'Anadyr', 'Anadyr', 'Anadir,Anadira,Anadirj,Anado,Anador,Anadyr,Anadyr'',Anadyris,Anadyrsk,Anadyr’,Anadîr,Anadõr,Anadır,Anantir,Anàdir,Anádyr,DYR,Gorad Anadyr,Novo-Mariinsk,Novo-Mariinskiy,Post Novo-Mariinskiy,Qagiirgiin,a na de er,anadili,anadira,anadiri,anadyr,ʼnʼdyr,Ανάντιρ,Анадир,Анадырь,Горад Анадыр,אנאדיר,آنادیر,أنادير,ਅਨਾਦਿਰ,ᑲᒌᕐᒌᓐ,アナディリ,阿纳德尔,아나디리', 64.7342400, 177.5103000, 'RU', '2016-02-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123280, 'Aleksandrovsk-Sakhalinskiy', 'Aleksandrovsk-Sakhalinskiy', 'Aleksandrovsk,Aleksandrovsk-Sakhalinskij,Aleksandrovsk-Sakhalinskiy,Aleksandrovski,Alexandrovsk,Александровск-Сахалинский', 50.8992600, 142.1621500, 'RU', '2012-10-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123281, 'Yantarnyy', 'Yantarnyy', 'Jantarnas,Jantarnyj,Pal''mnikken,Palmnicken,Palmniken,Palvininkai,Pal’mnikken,Yantarnyy,Янтарный', 54.8710200, 19.9401600, 'RU', '2015-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123282, 'Mamonovo', 'Mamonovo', 'Heiligenbeil,Khayligenbayl'',Khayligenbayl’,Kheyligenbeyl,Mamonova,Mamonovas,Mamonovo,Mamonowo,Sventapile,ma mo nuo fu,mamonobo,mamonovu~o,mamwnwfw,Šventapilė,Мамоново,مامونوفو,マモノヴォ,馬莫諾夫,마모노보', 54.4642700, 19.9380100, 'RU', '2015-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123283, 'Donskoye', 'Donskoye', 'Dirzkaimis,Diržkaimis,Donskoe,Donskoje,Donskoye,Gross Dirschkeim,Gross Dirshkaym,Донское', 54.9384200, 19.9682100, 'RU', '2015-01-15', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123284, 'Baltiysk', 'Baltiysk', 'Baltiisk,Baltijsk,Baltijskas,Baltisk,Baltiysk,Baltyjsk,Bałtyjsk,Pilawa,Piliava,Pillau,baltiseukeu,Балтийск,발티스크', 54.6545500, 19.9092900, 'RU', '2015-01-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123285, 'Provideniya', 'Provideniya', 'PVS,Port Provideniya,Providenija,Provideniya,pu luo wei jie ni ya,Провидения,普罗维杰尼亚', 64.4228900, -173.2264100, 'RU', '2016-09-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123286, 'Lorino', 'Lorino', 'Loren,Lorino,Лорино', 65.5033100, -171.7039600, 'RU', '2012-11-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123287, 'Lavrentiya', 'Lavrentiya', 'Chukotskaya Kul''thaza,Chukotskaya Kul’thaza,Kul''tbaza,Kul’tbaza,Lavrentia,Lavrentija,Lavrentiya,la fu lian ji ya,Лаврентия,拉夫连季亚', 65.5860400, -171.0208200, 'RU', '2016-10-05', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123288, 'Egvekinot', 'Egvekinot', 'Egvekinot,Egvekinotas,Egwekinot,Ehgvekinot,ai ge wei ji nuo te,Ėgvekinot,Эгвекинот,Էգվեկինոտ,埃格韦基诺特', 66.3216600, -179.1219800, 'RU', '2016-09-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123289, 'Raduzhnyy', 'Raduzhnyy', 'Raduzhnyj,Raduzhnyy,Raduzjnyj,Радужный', 58.4989900, 49.6434700, 'RU', '2015-10-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123290, 'Grazhdanka', 'Grazhdanka', 'Grazhdanka,Grazjdanka,Гражданка', 44.2163000, 133.1770600, 'RU', '2012-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123291, 'Oktyabr’skiy', 'Oktyabr''skiy', 'Oktjabr''skij,Oktjabrskij,Oktyabr''skiy,Oktyabr’skiy,Октябрьский', 57.7445600, 41.0019300, 'RU', '2012-06-06', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123292, 'Logovskoye', 'Logovskoye', 'Logovskoe,Logovskoye,Логовское', 53.4943000, 84.2016000, 'RU', '2012-08-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123293, 'Magas', 'Magas', 'Gorad Magas,IGT,Magas,Magasa,Magasas,Magaso,Magass,Magàs,Magás,Mankas,Maqas,Mehguehs,ma jia si,magas,magaseu,magasi,magasu,maghas,Μαγκάς,Горад Магас,Магас,Магас балһсн,МагӀас,Мэгъэс,Մագաս,מגאס,ماغاس,ماگاس,მაგასი,マガス,馬加斯,마가스', 43.2225700, 44.7726100, 'RU', '2016-12-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123294, 'Vas’kovo', 'Vas''kovo', 'Vas''kovo,Vas’kovo,Васьково', 64.4122000, 40.4639000, 'RU', '2015-04-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123295, 'Isakogorka', 'Isakogorka', 'Isakogorka,Исакогорка', 64.4460000, 40.6531000, 'RU', '2015-06-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123296, 'Kurilovo', 'Kurilovo', '', 55.3727100, 37.3770300, 'RU', '2015-06-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123297, 'Izmaylovo', 'Izmaylovo', 'Izmajlovo,Izmaylovo,Sovkhoz Izmaylovo,Измайлово', 55.5642800, 37.6425400, 'RU', '2017-04-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123298, 'Krasnoznamensk', 'Krasnoznamensk', 'Krasnosnamensk,Krasnoznamens''k,Krasnoznamensk,Krasnoznamensk i Moskva oblast,Krasnoznamiensk,Krasnoznamjensk,ke la si nuo zi na mian si ke,keulaseunojeunamenseukeu,krasnwznamnsk,krasnwznamnsk  astan mskw,kurasunozunamensuku,Краснознаменск,Краснознаменск балһсн,Краснознаменськ,كراسنوزنامنسك,کراسنوزنامنسک,کراسنوزنامنسک، استان مسکو,クラスノズナメンスク,克拉斯諾茲納緬斯克,크라스노즈나멘스크', 55.5994400, 37.0386100, 'RU', '2015-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123299, 'Posëlok Mar’ino', 'Poselok Mar''ino', 'Poselok Mar''ino,Posjolok Mar''ino,Posëlok Mar’ino,Посёлок Марьино', 55.5500000, 37.3200000, 'RU', '2012-09-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123300, 'Mosrentgen', 'Mosrentgen', 'Mosrentgen,Poselok Zavoda Mosrentgen,Posëlok Zavoda Mosrentgen,Мосрентген', 55.6197000, 37.4640200, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123301, 'Zarech’ye', 'Zarech''ye', 'Zarech''e,Zarech''ye,Zarech’ye,Заречье', 55.6866700, 37.3924000, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123302, 'Povedniki', 'Povedniki', 'Povedniki,Поведники', 55.9700000, 37.6000000, 'RU', '2012-05-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123303, 'Chertanovo Yuzhnoye', 'Chertanovo Yuzhnoye', 'Chertanovo Vtoroe,Chertanovo Yuzhnoye,Poselok Mosgazoprovod,Posëlok Mosgazoprovod,Чертаново Второе', 55.5907200, 37.5951900, 'RU', '2016-04-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123304, 'Sredniy', 'Sredniy', 'Srednij,Sredniy,Средний', 52.8884000, 103.4904000, 'RU', '2013-08-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123305, 'Zagor’ye', 'Zagor''ye', 'Zagor''e,Zagor''ye,Zagor’ye,Загорье', 55.5765700, 37.6670900, 'RU', '2015-01-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123306, 'Orekhovo-Borisovo', 'Orekhovo-Borisovo', 'Orekhovo-Borisovo,Орехово-Борисово', 55.6125200, 37.7263900, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123307, 'Pad’ Mel’nichnaya', 'Pad'' Mel''nichnaya', 'Pad'' Mel''nichnaja,Pad'' Mel''nichnaya,Pad’ Mel’nichnaya,Падь Мельничная', 52.1600000, 104.3800000, 'RU', '2015-08-23', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123308, 'Metrogorodok', 'Metrogorodok', 'Metrogorodok,Poselok Metrostroya,Posëlok Metrostroya,Метрогородок', 55.8096100, 37.7873900, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123309, 'Novyy', 'Novyy', 'Novyj,Novyy,Новый', 43.3643800, 132.0210900, 'RU', '2013-10-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123310, 'Chistyye Bory', 'Chistyye Bory', '', 58.3647200, 41.6277800, 'RU', '2007-07-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123311, 'Zarya', 'Zarya', '', 52.5969600, 85.1757000, 'RU', '2013-09-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123312, 'Pervomayskoye', 'Pervomayskoye', '', 52.5988800, 85.2576900, 'RU', '2013-09-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123313, 'Stan-Bekhtemir', 'Stan-Bekhtemir', 'Stan-Bekhtemir,Stanitsa Bakhtemir,Stanitsa Bekhtemir', 52.6066500, 85.6261900, 'RU', '2013-09-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123314, 'Kogalym', 'Kogalym', 'Gorad Kagalym,KGP,Kogalim,Kogalom,Kogalym,Kogalymas,Kogalîm,Kogalõm,Kogalım,Kogałym,Koqalim,Koqalım,ke jia lei mu,kogarimu,kwgalym,kwghalym,Горад Кагалым,Когалим,Когалым,كوغاليم,کوگالیم,コガリム,科加雷姆', 62.2653700, 74.4790600, 'RU', '2014-08-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123315, 'Pyt-Yakh', 'Pyt-Yakh', 'Pyt''-Jakh,Pyt-Yakh,Пыть-Ях', 60.7498500, 72.8582400, 'RU', '2009-03-03', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123316, 'Langepas', 'Langepas', 'Langepas,Лангепас', 61.2543900, 75.2124000, 'RU', '2008-11-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123317, 'Североморск-3', 'Severomorsk-3', 'Severomorsk-3,Североморск-3', 68.8786200, 33.7263100, 'RU', '2013-03-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123318, 'Киевский', 'Kievskij', 'Kievskij,Kievskiy,Киевский', 55.4299900, 36.8666000, 'RU', '2013-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123319, 'Obolensk', 'Obolensk', 'Obolensk,Оболенск', 54.9774100, 37.2244900, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123320, 'Lesnoy', 'Lesnoy', 'Lesnoj,Lesnoy,Лесной', 57.6198000, 63.0784000, 'RU', '2012-01-20', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123321, 'Muromtsevo', 'Muromtsevo', 'Muromcevo,Muromtsevo,Муромцево', 55.9309600, 40.9073800, 'RU', '2013-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123322, 'Нежданинское', 'Nezhdaninskoe', 'Nezhdaninskoe,Нежданинское', 62.5052300, 139.0510400, 'RU', '2013-11-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123323, 'Vzmorye', 'Vzmorye', 'Vzmor''e,Vzmorye,Взморье', 54.6960600, 20.2361300, 'RU', '2014-10-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123324, 'Shikotan', 'Shikotan', 'Shikotan,Шикотан', 43.7991600, 146.7216400, 'RU', '2014-07-27', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123325, 'Peresvet', 'Peresvet', 'Gorad Perasvet,Peresvet,Pereswet,Pierieswiet,Pjerjeswjet,byrsft,pei lie si wei te,prsft,pyryswyt,Горад Перасвет,Пересвет,Пересвет балһсн,Пересвєт,بيرسفت,پرسفت,پیریسویت,佩列斯韋特', 56.4230200, 38.1761200, 'RU', '2013-09-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123326, 'Blyasino', 'Blyasino', 'Bljasino,Blyasino,Блясино', 56.9456500, 28.3062100, 'RU', '2017-06-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123327, 'Lobovo', 'Lobovo', 'Lobovo,Лобово', 56.5286000, 28.8505000, 'RU', '2017-05-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123328, 'Pribrezhnyy', 'Pribrezhnyy', 'Pribrezhnyj,Прибрежный', 53.4866200, 49.8583600, 'RU', '2010-01-21', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123329, 'Zarya', 'Zarya', 'Zarja,Заря', 55.7553300, 38.0957800, 'RU', '2013-01-04', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123330, 'Raduzhnyy', 'Raduzhnyy', 'Raduzhnyj,Радужный', 56.0038000, 40.3390500, 'RU', '2015-10-01', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123331, 'Nizhnesortymskiy', 'Nizhnesortymskiy', 'Nizhnesortymskij,Нижнесортымский', 62.4396500, 71.7602900, 'RU', '2010-04-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123332, 'Pokachi', 'Pokachi', 'Pokachi,Покачи', 61.7198200, 75.3682700, 'RU', '2010-04-30', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123333, 'Izluchinsk', 'Izluchinsk', 'Izluchinsk,Излучинск', 60.9794400, 76.9242100, 'RU', '2010-05-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123334, 'Oktyabr’skiy', 'Oktyabr''skiy', 'Oktjabr''skij,Oktyabr''skiy,Oktyabr’skiy,Октябрьский', 48.6550000, 43.8040000, 'RU', '2015-03-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123335, 'Kusak', 'Kusak', 'Kusak,Кусак', 53.2238000, 78.9337000, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123336, 'Sudoverf’', 'Sudoverf''', 'Sudoverf'',Sudoverf’,Судоверфь', 58.1169600, 38.6417500, 'RU', '2017-02-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123337, 'Singapay', 'Singapay', 'Singapaj,Сингапай', 61.1545200, 72.6607200, 'RU', '2010-10-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123338, 'Norkino', 'Norkino', 'Norkino,Норкино', 56.6682000, 29.0286000, 'RU', '2017-05-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123339, 'Shevlyakovo', 'Shevlyakovo', 'Shevljakovo,Shevlyakova,Shevlyakovo,Шевляково', 56.3973300, 36.8597300, 'RU', '2014-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123340, 'Noginsk-9', 'Noginsk-9', 'Dubrovo,Noginsk-9,Stromyn'',Дуброво,Ногинск-9,Стромынь', 56.0668100, 38.5001300, 'RU', '2010-11-07', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123341, 'Staroye Arakchino', 'Staroye Arakchino', 'Staroe Arakchino,Staroye Arakchino,Старое Аракчино', 55.8041000, 48.9709000, 'RU', '2014-10-24', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123342, 'Sagan-Nur', 'Sagan-Nur', 'Sagan-Nur,Саган-Нур', 51.3436000, 108.4449000, 'RU', '2015-08-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123343, 'Voznesenskiy', 'Voznesenskiy', 'Voznesenskij,Voznesenskiy,Вознесенский', 54.8968000, 99.1031000, 'RU', '2013-09-08', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123344, 'Emar', 'Emar', 'Emar,Емар', 43.2041700, 132.1564300, 'RU', '2012-04-26', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123345, 'Algatuy', 'Algatuy', 'Algatuj,Algatuy,Алгатуй', 54.4009000, 100.2550000, 'RU', '2013-07-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123346, 'Kurortnyy', 'Kurortnyy', 'Kuusela', 60.1656200, 29.9080000, 'RU', '2013-10-13', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123347, 'Chernaya Rechka', 'Chernaya Rechka', 'Chernaja rechka,Черная речка', 59.9859400, 30.3033800, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123348, 'Untolovo', 'Untolovo', 'Juntolovo,Юнтолово', 60.0122000, 30.2089700, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123349, 'Petrogradka', 'Petrogradka', 'Petrogradka,Петроградка', 59.9656700, 30.3115400, 'RU', '2013-06-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123350, 'Vasyl''evsky Ostrov', 'Vasyl''evsky Ostrov', 'Vasil''evskij ostrov,Vasileostrovskij,Vasilinsaari,Василеостровский,Васильевский остров', 59.9409100, 30.2537700, 'RU', '2013-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123351, 'Parnas', 'Parnas', 'Parnas,Парнас', 60.0696400, 30.3487000, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123352, 'Kalininskiy', 'Kalininskiy', 'Kalininskij,Калининский', 59.9967500, 30.3899000, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123353, 'Krasnogvargeisky', 'Krasnogvargeisky', 'Krasnogvardejskij,Красногвардейский', 59.9730500, 30.4760700, 'RU', '2013-04-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123354, 'Admiralteisky', 'Admiralteisky', 'Admiraltejskij,Адмиралтейский', 59.9083900, 30.2848400, 'RU', '2013-06-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123355, 'Krestovskiy ostrov', 'Krestovskiy ostrov', 'Krestovskij ostrov,Крестовский остров', 59.9709100, 30.2578900, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123356, 'Akademicheskoe', 'Akademicheskoe', 'Akademicheskoe,Академическое', 60.0137500, 30.3947100, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123357, 'Finlyandskiy', 'Finlyandskiy', 'Finljandskij,Финляндский', 59.9682400, 30.3641500, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123358, 'Centralniy', 'Centralniy', 'Central''nyj,Центральный', 59.9311100, 30.3607200, 'RU', '2013-06-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123359, 'Tonshalovo', 'Tonshalovo', 'Tonshalovo,Тоншалово', 59.1948300, 37.9474600, 'RU', '2013-03-29', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123360, 'Svetlanovskiy', 'Svetlanovskiy', 'Svetlanovskij,Svetlanovskoe,Светлановский,Светлановское', 60.0027600, 30.3305100, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123361, 'Sampsonievskiy', 'Sampsonievskiy', 'Sampsonievskij,Sampsonievskoe,Сампсониевский,Сампсониевское', 59.9849900, 30.3429500, 'RU', '2013-04-02', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123362, 'Vostochnoe Degunino', 'Vostochnoe Degunino', 'Vostochnoe Degunino,Восточное Дегунино', 55.8801000, 37.5575800, 'RU', '2014-01-31', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123363, 'Blagovetschenskaya', 'Blagovetschenskaya', '', 45.0553000, 37.1327600, 'RU', '2013-08-11', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123364, 'Rybnoye', 'Rybnoye', 'Rybnoe,Rybnoye,Рыбное', 56.4134900, 37.6218000, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123365, 'Podosinki', 'Podosinki', 'Podosinki,Подосинки', 56.2083700, 37.5474100, 'RU', '2014-11-19', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123366, 'Petrovskiy', 'Petrovskiy', 'Petrovskij,Posjolok Sovkhoza Petrovskij,Петровский,Посёлок Совхоза Петровский', 52.2415900, 40.6497600, 'RU', '2014-05-25', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123367, 'Avtopoligon', 'Avtopoligon', 'Avtopoligon,Автополигон', 56.3498400, 37.3229600, 'RU', '2014-08-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123368, 'Budenovetc', 'Budenovetc', 'Budenovetc,Budjonovec,Будёновец', 56.3797500, 37.6277400, 'RU', '2014-08-17', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123369, 'Gorshkovo', 'Gorshkovo', 'Gorshkovo,Горшково', 56.3756100, 37.4124000, 'RU', '2014-11-10', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123370, 'Ol''yavidovo', 'Ol''yavidovo', 'Ol''javidovo,Ol''yavidovo,Ольявидово', 56.5033000, 37.7516000, 'RU', '2015-02-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123371, 'Filippovka', 'Filippovka', 'Filippovka,Филипповка', 57.4373000, 57.0193400, 'RU', '2015-04-28', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123372, 'LMS', 'LMS', 'LMS,Poselok LugoMeliorativnoj stancii,ЛМС,Поселок ЛугоМелиоративной станции', 55.3142500, 37.1854600, 'RU', '2016-05-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123373, 'Krasnaya Pahra', 'Krasnaya Pahra', 'Krasnaja Pakhra,Красная Пахра', 55.4322300, 37.2696600, 'RU', '2016-05-12', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123374, 'Poselok Turisticheskogo pansionata "Klyazminskoe vodohranilische"', 'Poselok Turisticheskogo pansionata "Klyazminskoe vodohranilische"', 'Kljaz''minskoe vodokhranilishhe,Pansionat «Kljaz''minskoe vodokhranilishhe»,Poselok Pansionat Kljaz''minskoe vodokhranilishhe,Poselok Pansionat «Kljaz''minskoe vodokhranilishhe»,Poselok Turisticheskogo pansionata "Klyazminskoe vodohranilische",Posjolok Turisticheskogo pansionata «Kljaz''minskoe vodokhranilishhe»,Клязьминское водохранилище,Пансионат «Клязьминское водохранилище»,Поселок Пансионат «Клязьминское водохранилище»,Поселок Пансионат Клязьминское водохранилище,Посёлок Туристического пансионата «Клязьминское водохранилище»', 55.9950700, 37.6719900, 'RU', '2016-07-18', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123375, 'Novoorlovsk', 'Novoorlovsk', 'Novoorlovsk,Новоорловск', 51.0754900, 114.7261000, 'RU', '2016-10-16', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123376, 'Petrovskoye', 'Petrovskoye', 'Petrovskoe,Petrovskoye,Петровское', 56.6975500, 28.6450000, 'RU', '2017-05-09', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123377, 'Tanais', 'Tanais', 'Tanais,Танаис', 47.2683700, 39.3342500, 'RU', '2017-05-14', 183);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123378, 'Rwamagana', 'Rwamagana', 'Rouamankana,Rvamagana,Rwamagana,Rwanagana,lu wa ma jia na,Ρουαμαγκάνα,Рвамагана,盧瓦馬加納', -1.9487000, 30.4347000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123379, 'Musanze', 'Musanze', 'Musanze,RHG,Ruhengeri,Ruhengeris,Rukhengeri,Рухенгери', -1.4998400, 29.6349700, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123380, 'Nzega', 'Nzega', 'Mont Nzega,Nseka,Nzega', -2.4790000, 29.5564000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123381, 'Kigali', 'Kigali', 'Gorad Kigali,KGL,Kigale,Kigali,Kigalis,Kigalo,Kigaly,Kinkali,Kiqali,Kígalí,ji jia li,khikali,kigali,kigalli,kigari,kikali,kygaly,kyghaly,Κιγκάλι,Горад Кігалі,Кигали,Кігалі,Կիգալի,קיגאלי,كيغالي,کیگالی,किगाली,ਕਿਗਾਲੀ,கிகாலி,කිගාලි,คิกาลี,ཀི་ག་ལི།,კიგალი,ኪጋሊ,キガリ,吉佳利,키갈리', -1.9499500, 30.0588500, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123382, 'Kibuye', 'Kibuye', 'Kibue,Kibuje,Kibujė,Kibuye,Кибуе', -2.0602800, 29.3477800, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123383, 'Kibungo', 'Kibungo', 'Kibungo,Kibungu,Кибунго', -2.1597000, 30.5427000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123384, 'Gitarama', 'Gitarama', 'Gitarama,Gitarame,Nkitarama,gitalama,gitarama,ji ta la ma,Γκιταράμα,Гитарама,Гитараме,გიტარამა,ギタラマ,吉塔拉馬,기타라마', -2.0744400, 29.7566700, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123385, 'Gikongoro', 'Gikongoro', '', -2.4639700, 29.5738900, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123386, 'Cyangugu', 'Cyangugu', 'Cyangugu,Rusizi,Shangugu,Siangugu,Сиангугу', -2.4846000, 28.9075000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123387, 'Gisenyi', 'Gisenyi', 'Colline Gosenyi,Gisehn''i,Gisen''i,Gisenjis,Gisenyi,Gosenyi,Nkiseni,giseni,ji sai ni,jysayny,Γκισένι,Гисеньи,Гисэньи,جيسايني,ギセニ,吉塞尼,기세니', -1.7027800, 29.2563900, 'RW', '2010-08-19', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123388, 'Byumba', 'Byumba', 'Biumba,Bjumba,Byumba,Биумба', -1.5763000, 30.0675000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123389, 'Butare', 'Butare', 'BTQ,Butare,Butaré,Butarė,Бутаре', -2.5966700, 29.7394400, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123390, 'Butare', 'Butare', 'Astrida,Boutare,Butare,Butaré,Butarė,Huye,bu ta lei shi,butale,butare,Μπουτάρε,Бутаре,බුතාරේ නගරය,ブタレ,布塔雷市,부타레', -2.6038000, 29.7431000, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123391, 'Nyanza', 'Nyanza', 'Nyabisindu', -2.3518700, 29.7508900, 'RW', '2016-07-06', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123392, 'Eglise Catholique, Centrale GIKO', 'Eglise Catholique, Centrale GIKO', '', -1.9365300, 29.8061000, 'RW', '2017-07-16', 184);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123393, 'Yanbu', 'Yanbu', 'YNB,Yambo,Yanbu,Yanbu al-Bahar,Yanbu'' al Bahr,Yanbu`,Yanbu` al Bahr,Yanbu‘,Yanbu‘ al Baḩr,Yenbo,Yenbo` al Bahar,Yenbo‘ al Bahar,ynbʿ,ينبع', 24.0895400, 38.0618000, 'SA', '2017-05-23', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123394, 'Unayzah', 'Unayzah', '''Unaiza,Onaizah,Onizah,UZH,Unaizah,Unajza,Unayzah,Uneyze,ou nai zai,ʿnyzt,Унайза,عنيزة,‘Unaiza,歐奈宰', 26.0879300, 43.9636800, 'SA', '2017-07-08', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123395, 'Umm Lajj', 'Umm Lajj', 'Umm Lajj,Umm Lej,Umm Lujj', 25.0212600, 37.2685000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123396, 'Umm as Sāhik', 'Umm as Sahik', 'Umm as Sahik,Umm as Sāhik,Umm es Sahich,Umm-as-Sahak,Umm-as-Sāhak', 26.6536100, 49.9163900, 'SA', '2013-06-22', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123397, 'Turaif', 'Turaif', 'At Turayf,Aţ Ţurayf,Et Turaif,Eṭ Ṭuraif,Mahattat al Turayf,Mahattat at Turayf,Maḩaţţat al Ţurayf,Maḩaţţat aţ Ţurayf,TUI,Turaif,Turayf,Tureyf,tryf,tryf‎‎,tu lai fu,Ţurayf,طريف‎‎,طریف,圖賴夫', 31.6725200, 38.6637400, 'SA', '2016-09-20', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123398, 'Turabah', 'Turabah', 'Ramadan,Taraba,Turaba,Turabah,Turbah', 21.2140600, 41.6331000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123399, 'At Tūbī', 'At Tubi', 'At Tubi,At Tūbī,Tobi', 26.5577800, 49.9916700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123400, 'Tārūt', 'Tarut', 'Darin Fort,Tarut,Tarut fort,Tārūt,Tārūt fort', 26.5733200, 50.0369400, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123401, 'Tanūmah', 'Tanumah', 'Tanuma,Tanumah,Tanūmah', 27.1000000, 44.1333300, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123402, 'Tabuk', 'Tabuk', 'Gabouk,TUU,Tabouk,Tabuk,Tabukas,Tabūk,Taebuk,Tebuek,Tebuk,Tebük,Täbuk,ta bu ke,tabukeu,tabukk,tabuku,tbwk,Табук,תבוכ,تبوك,تبوک,تبوک، سعودی عرب,തബൂക്ക്,タブーク,塔布克,타부크', 28.3998000, 36.5715100, 'SA', '2015-09-12', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123403, 'Ţubarjal', 'Tubarjal', 'Tabarjal,Tubarjal,tbrjl,Ţabarjal,Ţubarjal,طبرجل', 30.4998700, 38.2160300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123404, 'Tabālah', 'Tabalah', 'Tabala,Tabalah,Tabālah', 19.9500000, 42.4000000, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123405, 'Sulţānah', 'Sultanah', 'Sultanah,Sulţānah', 24.4925800, 39.5857200, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123406, 'Sayhāt', 'Sayhat', 'As Saihat,As Saihāt,As Sayhat,As Sayhāt,Saihat,Sayhat,Sayhāt,Sihat,Sīhāt', 26.4852200, 50.0404600, 'SA', '2014-03-09', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123407, 'Şāmitah', 'Samitah', 'Samitah,Samta,Şāmitah,Самта', 16.5960100, 42.9443500, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123408, 'Sakakah', 'Sakakah', 'AJF,Sakaka,Sakakah,Sakākā,Skaka,Skâka,sai ka kai,sakaka,skaka,skakh,Сакака,سكاكا,سکاکه,ਸਕਾਕਾ,സകാക,サカーカ,塞卡凱,사카카', 29.9697400, 40.2064100, 'SA', '2015-12-13', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123409, 'Şafwá', 'Safwa', 'Safwa,Safwah,Şafwah,Şafwá', 26.6498600, 49.9522300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123410, 'Şabyā', 'Sabya', 'Al-Sabya,As Sabya,Aş Şabyā,Sabie,Sabiya,Sabya,sbya,Şabyā,صبيا', 17.1495000, 42.6253700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123411, 'Raḩīmah', 'Rahimah', 'Rahaima,Rahimah,Raḩīmah', 26.7079100, 50.0619400, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123412, 'Rābigh', 'Rabigh', 'Rabegh,Rabigh,Rabigh Qasr,Rābigh', 22.7985600, 39.0349300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123413, 'Qal‘at Bīshah', 'Qal`at Bishah', 'BHH,Bisha,Qal`at Bishah,Qal‘at Bīshah', 20.0005400, 42.6052000, 'SA', '2017-02-13', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123414, 'Najrān', 'Najran', 'EAM,Najran,Najrān,njran,نجران', 17.4932600, 44.1276600, 'SA', '2017-07-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123415, 'Mulayjah', 'Mulayjah', 'Mulaidja,Mulaija,Mulayjah', 27.2710300, 48.4241900, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123416, 'Mislīyah', 'Misliyah', 'Masliya,Masliyah,Maslīyah,Misliyah,Mislīyah,mslyt,مسلية', 17.4598800, 42.5572000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123417, 'Marāt', 'Marat', 'Marah,Marat,Marrat,Marrāt,Marāh,Marāt', 25.0700700, 45.4614700, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123418, 'Mecca', 'Mecca', 'A Meca,La Meca,La Mecca,La Mecque,Macoraba,Maekkae,Makka,Makkah,Makkah al Mukarramah,Makkah al Mukarraman,Makkah al-Mukarramah,Meca,Mecca,Mecka,Meice,Meka,Mekao,Meke,Mekka,Mekkah,Mekke,Mekko,Mäkkä,mai jia,mak kah,meka,mekka,mkh,mkt,mkt almkrmt,Μέκκα,Мека,Мекка,מכה,مكة,مكة المكرمة,مکه,مکہ,มักกะฮ์,མ་ཁ།,მექა,メッカ,麥加,메카', 21.4266400, 39.8256300, 'SA', '2014-04-29', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123419, 'Khamis Mushait', 'Khamis Mushait', 'Chamis Musaitas,Chamis Muschait,Chamis Muszajt,Chamis Mušaitas,KMX,Khamis Mushait,Khamis Mushayt,Khamis-Mushait,Khamis-Mushajt,Khamīs Mushayt,hai mi si mu xie te,hamiseumusyaiteu,hmys mwsyyt,kamicu mucait,khamis musaitt,khmys mshyt,Хамис Мушаит,Хамис-Мушаит,Хамис-Мушайт,Хаміс-Мушайт,חמיס מושייט,خميس مشيط,خمیس مشیط,கமீசு முசைத்,ഖമീസ് മുശൈത്ത്,ハミース・ムシャイト,海米斯穆谢特,하미스무샤이트', 18.3000000, 42.7333300, 'SA', '2013-11-25', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123420, 'Julayjilah', 'Julayjilah', 'Julaijilah,Julayjilah', 25.5000000, 49.6000000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123421, 'Jizan', 'Jizan', 'Djayzan,Djayzān,Djazan,Djāzān,Dzhizan,GIZ,Gazan,Gizan,Gizán,Jaizan,Jazan,Jezan,Jizan,Jāzān,Jīzān,Qizan,Qīzān,jazan,Джизан,جازان', 16.8891700, 42.5511100, 'SA', '2014-02-01', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123422, 'Jeddah', 'Jeddah', 'Chidda,Cidda,Ciddae,Cidde,Ciddä,Ciddə,Djedda,Djeddah,Djidda,Dschidda,Dzeda,Dzedda,Dzhida,Dzhidda,Dzhiddae,Dzhiddat,Dzhidde,Dzida,Dzidd,Dzidda,Dzsidda,Dzudda,Dżudda,Džeda,Džedda,Džida,Džidd,Džidda,Gedda,Gidda,Gido,Gorad Dzhyda,Iedda,JED,Jaddah,Jedda,Jeddah,Jida,Jidda,Jiddah,Jidde,Jidá,Judah,Juddah,Tzenta,Yida,Yidda,Zhidda,gdh,jada,jdh,jdt,jeda,jedda,jeddaha,ji da,jida,jidda,jitta,yid dah,Ĝido,Ğidda,Τζέντα,Џеда,Горад Джыда,Джида,Джиддæ,Джидда,Джиддат,Джидде,Жидда,Ջիդդա,גדה,جدة,جده,جدہ,ޖިއްދާ,जेद्दाह,জেদ্দা,ਜੱਦਾ,ஜித்தா,ജിദ്ദ,ญิดดะฮ์,ჯიდა,ジッダ,吉达,吉達,제다,지다', 21.5423800, 39.1979700, 'SA', '2017-06-22', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123423, 'Ha''il', 'Ha''il', 'HAS,Ha''il,Hael,Hajel,Hayil,hayl,حائل,Ḥâjel', 27.5218800, 41.6907300, 'SA', '2016-01-28', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123424, 'Farasān', 'Farasan', 'Farasan,Farasān', 16.7022200, 42.1183300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123425, 'Duba', 'Duba', 'Daba,Dhaba,Diba,Duba,Zbe,Ziba'',Z̧ibā’,dba,Дуба,ضبا,Ḑabā', 27.3513400, 35.6901400, 'SA', '2016-01-28', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123426, 'Buraydah', 'Buraydah', 'Buraeydae,Buraida,Buraidah,Burajda,Buraydah,Buräydä,brydt,بريدة', 26.3259900, 43.9749700, 'SA', '2014-04-29', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123427, 'Abqaiq', 'Abqaiq', 'Abaqaiq,Abkaik,Abkaikas,Abkajk,Abkayk,Abqaik,Abqaiq,Abqayq,Abqaïq,Bukayk,Buqayq,Madinat Abqaiq,bqyq,bu gai ge,Абкайк,Աբքայք,بقيق,بقیق,布蓋格', 25.9371000, 49.6776100, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123428, 'Badr Ḩunayn', 'Badr Hunayn', 'Badr,Badr Hunain,Badr Hunayn,Badr Ḩunayn', 23.7829200, 38.7904700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123429, 'Az Zulfi', 'Az Zulfi', 'Az Zilfi,Az Zilfī,Az Zulfi,ZUL,Zilfi', 26.2994500, 44.8154200, 'SA', '2017-07-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123430, 'Dhahran', 'Dhahran', 'Az Zahran,Az-Zahran,Az̧ Z̧ahrān,DHA,Dahahron,Dahran,Dahrán,Dakhran,Dhahram,Dhahran,Dharaan,Gorad Dakhran,Ntachran,Zahran,Zhahran,alzhran,dahrani,dalan,daran,zai he lan,zha ha lan,zhran,Νταχράν,Горад Дахран,Дахран,דהראן,الظهران,ظهران,ظہران,ദഹ്റാൻ,დაჰრანი,ダーラン,宰赫兰,扎哈蘭,다란', 26.2886400, 50.1139600, 'SA', '2013-11-17', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123431, 'Aţ Ţaraf', 'At Taraf', 'Al-Taraf,At Taraf,Aţ Ţaraf', 25.3627600, 49.7250400, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123432, 'Ta’if', 'Ta''if', 'At Ta''if,At-Ta''if,At-Ta’if,Aţ Ţā’if,TIF,Ta''if,Taef,Taif,Tayif,Taëf,Ta’if,Tāif,altayf,Таиф,الطائف', 21.2702800, 40.4158300, 'SA', '2015-09-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123433, 'As Sulayyil', 'As Sulayyil', 'As Sulayyil,As Sullayyil,SLF,Sulaiyil', 20.4606700, 45.5779200, 'SA', '2017-07-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123434, 'Sājir', 'Sajir', 'As Sajir,As Sājir,Sajir,Sājir', 25.1825100, 44.5996400, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123435, 'As Saffānīyah', 'As Saffaniyah', 'As Saffaniyah,As Saffānīyah,Ra''s as Saffaniyah,Ra’s as Saffaniyah,Safania,Safaniya', 27.9708300, 48.7300000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123436, 'Riyadh', 'Riyadh', 'Al-Riad,Al-Riyad,Ar Riyadh,Ar Riyādh,Ar-Riaad,Ar-Rijad,Ar-Riyad,Ar-Riyod,Ar-Riyāḑ,Ehr-Rijad,Er-Rijad,Er-riyad,Gorad Ehr-Ryjad,RUH,Riaad,Riad,Riade,Riadi,Riado,Riadum,Riant,Rihad,Rijad,Rijada,Rijadas,Rijád,Rijāda,Riyad,Riyadh,Riyaḍ,Ríad,alryad,er-riadi,li ya de,liyadeu,raiyadha,ri''ada,ri''adha,riyad,riyada,riyadh,riyadha,riyado,riyat,ryad,ryyad,Ər-Riyad,Ριάντ,Ар-Рияд,Горад Эр-Рыяд,Ер-Ріяд,Рияд,Ријад,Эр-Рияд,Ալ-Ռիադ,ריאד,الرياض,رىياد,رياض,ریاض,ڕیاز,रियाद,रियाध,রিয়াদ,ৰিয়াধ,ਰਿਆਧ,ରିଆଦ,ரியாத்,ರಿಯಾಧ್,റിയാദ്,ริยาด,རིས་ཡག,ერ-რიადი,ሪያድ,リヤド,利雅得,利雅德,리야드', 24.6877300, 46.7218500, 'SA', '2016-01-21', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123437, 'Ar Rass', 'Ar Rass', 'Al Russ,Ar Rass,El Russ,Rass,alrs,الرس', 25.8694400, 43.4973000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123438, 'Arar', 'Arar', 'Ara`ar,Arar,Ara‘ar,RAE,عرعر', 30.9753100, 41.0380800, 'SA', '2016-10-22', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123439, 'An Nimāş', 'An Nimas', 'Al-Nimas,Al-Nimās,An Nimas,An Nimāş,Numas,Numās', 19.1454700, 42.1200900, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123440, 'Qurayyat', 'Qurayyat', 'Al Qurayyat,Al Qurayyāt,An Nabk,An Nabk Abu Nakhlah,Gurayat,Nabek,Qurayyat,URY,alqryat,القريات', 31.3317600, 37.3428200, 'SA', '2016-10-23', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123441, 'Al Wajh', 'Al Wajh', 'Al Wajh,Alwejh,EJH,Wajj,Wejh', 26.2455100, 36.4524900, 'SA', '2016-09-20', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123442, 'Al-`Ula', 'Al-`Ula', 'Al Ola,Al `Ula,Al ‘Ulá,Al''-Ula,Al-`Ula,Dedan,ULH,alʿla,ou la,Аль-Ула,العلا,歐拉', 26.6085300, 37.9231600, 'SA', '2016-12-18', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123443, 'Al Qurayn', 'Al Qurayn', 'Al Ghuraim,Al Qurayn,Al-Qurain,Qarain', 25.4833300, 49.6000000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123444, 'Qaisumah', 'Qaisumah', 'AQI,Al Qaysumah,Gaisum,Gaisun,Qaisumah,alqyswmt,alqyswmt‎‎,القيصومة‎‎,القیصومة', 28.3111700, 46.1272900, 'SA', '2016-10-23', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123445, 'Al Qaţīf', 'Al Qatif', 'Al Qatif,Al Qaţīf,Ehl''-Katif,El Katif,Qatif,Эль-Катиф', 26.5208000, 50.0245200, 'SA', '2012-10-17', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123446, 'Al Qārah', 'Al Qarah', 'Al Qarah,Al Qārah,El Qara,Qarah,Qārah', 25.4166700, 49.6666700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123447, 'Al Muţayrifī', 'Al Mutayrifi', 'Al Mutairifi,Al Mutayrifi,Al Muţayrifī,Matairafi,Muteirfeh,Umm Terfi', 25.4787900, 49.5576300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123448, 'Al Munayzilah', 'Al Munayzilah', 'Al Munaizilah,Al Munayzilah,Manaizlah,Manzilah,Minazla', 25.3833300, 49.6666700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123449, 'Al Mubarraz', 'Al Mubarraz', 'Al Mubarraz', 25.4100000, 49.5808300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123450, 'Al Mindak', 'Al Mindak', 'Al Mindak,Al Mindaq,Mandak,Mendak', 20.1588000, 41.2833700, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123451, 'Al Mithnab', 'Al Mithnab', 'Al Midnab,Al Miznab,Midhnib,Mudhnib,almdhnb,المذنب', 25.8601200, 44.2222800, 'SA', '2012-10-09', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123452, 'Al Markaz', 'Al Markaz', 'Al Markaz', 25.4000000, 49.7333300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123453, 'Medina', 'Medina', 'Al Madina,Al Madinah,Al Madinah al Munawwarah,Al Madīnah,Al Madīnah al Munawwarah,Al Medina,El Medina,Gorad Medzina,Lathrippa,MED,Madina,Madinah,Madinah al-Munawwarah,Madinat,Madīna,Maedinae,Mediina,Medin,Medina,Medinae,Medine,Medino,Medyna,Medína,Medîne,Medīna,Mädinä,Médine,Mədinə,Yathrib,almdynt,almdynt almnwrh,almdynt almnwrt,ma di nah,madina,mai de na,matina,mdynh,medina,Μεδίνα,Горад Медзіна,Мадина,Мадинат,Мединæ,Медина,Медине,Медіна,Мәдинә,Մադինա,אל-מדינה,المدينة,المدينة المنورة,المدينة المنوره,مدينه,مدینه,مدینھ,مدینہ منورہ,مەدینە,މަދީނާ,मदिना,मदीना,মদিনা,মেডিনা,ਮਦੀਨਾ,મદીના,மதீனா,మదీనా,മദീന,มะดีนะฮ์,მედინა,መዲና,マディーナ,麥地那,麦地那,메디나', 24.4686100, 39.6141700, 'SA', '2014-11-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123454, 'Khobar', 'Khobar', 'Al Khobar,Al Khubar,Al-Chubar,Al-Khobar,Al-Khubar,Ehl''-Khubar,El Huber,El''-Khubar,Khobar,ala-khobara,alkhbr,khbr,kobaleu,mhafzt alkhbr,Ель-Хубар,Эль-Хубар,Әл-Хубар,الخبر,خبر,محافظة الخبر,अल-खोबर,ഖോബാർ,アル・コバール,코바르', 26.2794400, 50.2083300, 'SA', '2013-11-17', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123455, 'Al Khafjī', 'Al Khafji', 'Al Khafji,Al Khafjī,Ra''s al Khafji,Ra’s al Khafjī', 28.4390500, 48.4913200, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123456, 'Al Jumūm', 'Al Jumum', 'Al Jumum,Al Jumun,Al Jumūm,Al Jumūn,Jumum', 21.6169400, 39.6980600, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123457, 'Al Jubayl', 'Al Jubayl', 'Ainain,Ainan,Al Jubayl,Al''-Dzhubajl'',Jubail,Jubail al Bahri,Jubayl,Jubayl `Aynayw,Jubayl al Bahri,Jubayl al Baḩri,Jubayl ‘Aynayw,`Aynayn,aljbyl,Аль-Джубайль,الجبيل,‘Aynayn', 27.0112200, 49.6582500, 'SA', '2013-01-10', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123458, 'Al Jubayl', 'Al Jubayl', 'Al Jubayl,Al''-Dzhubajl'',Al-Jubail,Аль-Джубайль', 25.4000000, 49.6500000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123459, 'Al Jarādīyah', 'Al Jaradiyah', 'Al Jaradiyah,Al Jarādīyah', 16.5794600, 42.9124000, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123460, 'Al Jafr', 'Al Jafr', 'Al Jafr,Bab-al-Jafar,Bāb-al-Jafar,Djafar,Jafar,Jafr', 25.3769400, 49.7236100, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123461, 'Al Hufūf', 'Al Hufuf', 'Al Hufuf,Al Hufūf,HOF,Hofuf,Hofūf,Hufuf,Hufūf', 25.3645700, 49.5653200, 'SA', '2017-07-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123462, 'Al Bukayrīyah', 'Al Bukayriyah', 'Al Bukayriyah,Al Bukayrīyah,Bukayriyah,Bukayrīyah,Keriya', 26.1442200, 43.6593300, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123463, 'Al Baţţālīyah', 'Al Battaliyah', 'Al Battaliyah,Al Baţţālīyah', 25.4333300, 49.6333300, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123464, 'Al Bahah', 'Al Bahah', 'ABT,Al Bahah,Al Bāḩah,Ehl''-Bakha,albaht,ba ha,baha,Эль-Баха,الباحة,巴哈,바하', 20.0128800, 41.4676700, 'SA', '2016-12-18', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123465, 'Al Arţāwīyah', 'Al Artawiyah', 'Al Artawiyah,Al Arţāwīyah,Al Irtawiya,Al Irtāwīya,Artawiyah,Artawiyya,Arţāwīyah', 26.5052600, 45.3443700, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123466, 'Al Awjām', 'Al Awjam', 'Ajam,Ajam al Qatif,Ajam al Qatīf,Al Ajam,Al Awjam,Al Awjām,Al Ājām,El Ajam,Lajam,Lājām', 26.5632400, 49.9433100, 'SA', '2012-06-28', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123467, '‘Afīf', '`Afif', 'Afif,`Afif,‘Afīf', 23.9065000, 42.9172400, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123468, 'Ad Dilam', 'Ad Dilam', 'Ad Dilam,Dilam,aldlm,الدلم', 23.9910400, 47.1618100, 'SA', '2014-09-30', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123469, 'Ad Dawādimī', 'Ad Dawadimi', 'Ad Dawadami,Ad Dawadimi,Ad Dawādamī,Ad Dawādimī,Ad Duwadami,Ad Duwādamī,Al-Dawadimi,Al-Dawādimi,DWD,Duwadami,Duwadimi,Duwādimi', 24.5077200, 44.3923700, 'SA', '2017-07-05', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123470, 'Ad Darb', 'Ad Darb', 'Ad Darb,Darb,aldrb,الدرب', 17.7228500, 42.2526100, 'SA', '2017-06-06', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123471, 'Dammam', 'Dammam', 'Ad Dammam,Ad Dammām,Ad-Dammam,Ad-Damman,DMM,Daemmam,Damam,Damamas,Dammam,Damman,Dammám,Dammām,Dämmam,Ed Dammam,Ntamam,aldmam,da man,dam''mam,dam''mama,damam,damama,damami,dammam,danmamu,dmam,xad dam mam,Νταμάμ,Дамам,Даммам,דמאם,الدمام,دمام,दम्मम,दम्माम,ਦਮਾਮ,డమ్మామ్,ദമാം,อัดดัมมาม,დამამი,ダンマーム,达曼,담맘', 26.4344200, 50.1032600, 'SA', '2014-08-19', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123472, 'Abū ‘Arīsh', 'Abu `Arish', 'Abi `Arish,Abu `Arish,Abu al `Arish,Abu al ‘Arish,Abī ‘Arīsh,Abū ‘Arīsh,ٲبو عريش', 16.9688700, 42.8325100, 'SA', '2012-01-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123473, 'Abha', 'Abha', 'AEbha,AHB,Abh,Abha,Abhá,Abhā,Abkha,Ebha,abaha,abeuha,abha,abuha,ai bo ha,Äbha,Абха,أبها,ابها,ابھا,അബഹ,アブハー,艾卜哈,아브하', 18.2163900, 42.5052800, 'SA', '2014-10-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123474, 'Ḩajrat al Khinbish', 'Hajrat al Khinbish', 'Hajrat al Khinbish,Ḩajrat al Khinbish', 27.7824800, 45.0367500, 'SA', '2015-12-06', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123475, 'Şuwayr', 'Suwayr', 'Suwayr,Şuwayr', 30.1171300, 40.3892500, 'SA', '2012-01-19', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123476, 'Tumayr', 'Tumayr', 'Tumayr', 25.7039300, 45.8679600, 'SA', '2012-01-19', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123477, 'Al Fuwayliq', 'Al Fuwayliq', 'Al Fuwayliq', 26.4432200, 43.2534000, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123478, 'Al Majāridah', 'Al Majaridah', 'Al Majaridah,Al Majāridah', 19.1236100, 41.9111100, 'SA', '2013-08-11', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123479, 'Al Muwayh', 'Al Muwayh', 'Al Jadid,Al Jadīd,Al Muwayh', 22.4333300, 41.7582900, 'SA', '2012-01-19', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123480, 'Al Hadā', 'Al Hada', 'Al Hada,Al Hadā', 21.3675300, 40.2869400, 'SA', '2012-01-19', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123481, 'Ash Shafā', 'Ash Shafa', 'Ash Shafa,Ash Shafā,Ash-Shafa,Аш-Шафа', 21.0721000, 40.3118500, 'SA', '2013-09-16', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123482, 'Mizhirah', 'Mizhirah', 'Mizhirah,mzhrt,مزهرة', 16.8261100, 42.7333300, 'SA', '2017-06-07', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123483, 'shokhaibٍ', 'shokhaib', 'shkhyb,شخيب', 24.4902300, 46.2687100, 'SA', '2008-05-27', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123484, 'Unaizah', 'Unaizah', 'Unaizah,Unajza,Unayza,Unayzah,ou nai zai,unaisa,Унайза,عنيزة,عنیزه,عنیزہ,محافظة عنيزة,ഉനൈസ,歐奈宰', 26.0842700, 43.9935500, 'SA', '2016-02-24', 195);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123493, 'Victoria', 'Victoria', 'Biktoria,Fiktoria,Gorad Viktoryja,Mahe,Mahé,Port Victoria,Victoria,Victoria pa Seychellane,Victoria på Seychellane,Victòria,Viktori,Viktoria,Viktorii,Viktorija,Viktorio,Viktoriya,Viktorya,Wiktoria,bigtolia,fyktwrya,vhiktoriya,vikatori''a,viktoriya,vu~ikutoria,wei duo li ya,wiktxreiy,wyktwrya,wyqtwryh,Βικτόρια,Βικτώρια,Виктори,Виктория,Викторија,Вікторія,Горад Вікторыя,Վիկտորիա,ויקטוריה,فيكتوريا,وکٹوریا,وکٹوریہ,ویکتوریا,ڤیکتۆریا، سیشێل,व्हिक्टोरिया,ਵਿਕਟੋਰੀਆ,விக்டோரியா,วิกตอเรีย,ཝིག་ཐོ་རི་ཡ།,ვიქტორია,ቪክቶሪያ፥ ሲሸልስ,ヴィクトリア,維多利亞,维多利亚,빅토리아', -4.6166700, 55.4500000, 'SC', '2014-02-08', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123494, 'Takamaka', 'Takamaka', '', -4.7666700, 55.5000000, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123495, 'Port Glaud', 'Port Glaud', '', -4.6666700, 55.4166700, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123496, 'Cascade', 'Cascade', '', -4.6666700, 55.5000000, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123497, 'Bel Ombre', 'Bel Ombre', 'Bel Ombre,Belle Ombre', -4.6166700, 55.4166700, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123498, 'Beau Vallon', 'Beau Vallon', 'Beau Vallon', -4.6209100, 55.4301500, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123499, 'Anse Royale', 'Anse Royale', 'Anse Royal,Anse Royale', -4.7333300, 55.5166700, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123500, 'Anse Boileau', 'Anse Boileau', '', -4.7166700, 55.4833300, 'SC', '2013-08-10', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123501, 'La Passe', 'La Passe', '', -4.3480800, 55.8326900, 'SC', '2016-03-31', 198);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123485, 'Tulagi', 'Tulagi', 'Tulaghi,Tulagi', -9.1030600, 160.1505600, 'SB', '2017-01-04', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123486, 'Honiara', 'Honiara', 'HIR,Honiara,Honiaro,Khoniara,Oniara,ho ni xa ra,honiala,honiara,huo ni ya la,hwnyara,Ονιάρα,Хониара,הוניארה,هونيارا,هونیارا,โฮนีอารา,ሆኒያራ,ホニアラ,霍尼亚拉,霍尼亞拉,호니아라', -9.4333300, 159.9500000, 'SB', '2012-01-18', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123487, 'Gizo', 'Gizo', 'GZO,Ghizo,Gizo,Gizo Government Station', -8.1030300, 156.8418600, 'SB', '2013-06-29', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123488, 'Buala', 'Buala', '', -8.1449700, 159.5921200, 'SB', '2013-03-07', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123489, 'Auki', 'Auki', 'AKS,Auke,Auki,Rarasu', -8.7677800, 160.6977800, 'SB', '2017-01-04', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123490, 'Lata', 'Lata', 'Lata', -10.7250000, 165.7972200, 'SB', '2017-01-04', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123491, 'Kirakira', 'Kirakira', 'IRA,Kirakira,ji la ji la,kirakira,kyrakyra,Киракира,کیراکیرا,キラキラ,基拉基拉', -10.4544200, 161.9204500, 'SB', '2013-06-29', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123492, 'Taro', 'Taro', 'Taro', -6.7111100, 156.3972200, 'SB', '2017-02-05', 204);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123502, 'Dongola', 'Dongola', 'Ciutat de Dongola,DOG,Dongola,Donkola,Donqola,Dunkula,Dunqula,Dunqulah,Dunqulā,Gorad Dangola,Nton''nkola,dnqla,dnqlh,dong gu la,dong-golla,dongola,dongora,Ντόνγκολα,Горад Дангола,Донгола,دنقلا,دنقله,डोंगोला,ドンゴラ,棟古拉,동골라', 19.1816300, 30.4768900, 'SD', '2016-01-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123503, 'Zalingei', 'Zalingei', 'ZLX,Zalingee,Zalingei,Zalinjay,Zalinje,Zalinji,Zālinjī,zalnjy,zalnjy (mdynt),Залингее,زالنجي,زالنجي (مدينة)', 12.9091800, 23.4705800, 'SD', '2016-01-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123504, 'Wagar', 'Wagar', 'Wagar,Wagga', 16.1525000, 36.2032000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123505, 'Wad Rāwah', 'Wad Rawah', 'Hillet Sa`id,Hillet Sa‘id,Wad Rawa,Wad Rawah,Wad Rāwa,Wad Rāwah', 15.1602800, 33.1397200, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123506, 'Wad Medani', 'Wad Medani', 'DNI,Medani,Wad Madani,Wad Medani,wd mdny,ود مدني', 14.4011800, 33.5198900, 'SD', '2016-12-20', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123507, 'Wad az Zāki', 'Wad az Zaki', 'Wad az Zaki,Wad az Zāki,Wad ez Zaki', 14.4619000, 32.2065000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123508, 'Umm Ruwaba', 'Umm Ruwaba', 'Um Ruaba,Um Ruwwaba,Um Ruwwāba,Umm Ruwaba,Umm Ruwabah,Umm Ruwābah', 12.9061000, 31.2158000, 'SD', '2012-04-06', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123509, 'Umm Kaddadah', 'Umm Kaddadah', 'Um Kaddada,Umm Kaddadah,Umm Kaddādah,Umm Keddada', 13.6016900, 26.6875900, 'SD', '2012-02-15', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123510, 'Um Jar Al Gharbiyya', 'Um Jar Al Gharbiyya', 'Um Jar Al Gharbiyya,Umm Garr,Umm Jarr', 13.8013000, 32.4078000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123511, 'Omdurman', 'Omdurman', 'Omdoerman,Omdourman,Omdurman,Omdurmana,Omdurmanas,Omdurmán,Omdurmāna,Umm Durman,Umm Durmán,Umm Durmān,am drman,ama daramana,en tu man,omduleuman,omdurman,omdurmani,omudo~uruman,xxm de xr man,Омдурман,Омдурман қаласы,אומדורמאן,أم درمان,ام درمان,ਅਮ ਦਰਮਾਨ,ออมเดอร์มาน,ომდურმანი,オムドゥルマン,恩图曼,옴두르만', 15.6445300, 32.4777300, 'SD', '2012-02-02', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123512, 'Tokār', 'Tokar', 'Tawkar,Tokar,Tokār,Ţawkar', 18.4254000, 37.7290000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123513, 'Tandaltī', 'Tandalti', 'Tandalti,Tandaltī,Tendelti', 13.0166700, 31.8666700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123514, 'Talodi', 'Talodi', 'Talawdi,Talawdī,Talodi', 10.6324600, 30.3797000, 'SD', '2012-04-06', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123515, 'Singa', 'Singa', 'Senga,Singa,Sinja,Sinjah,snjt,سنجة', 13.1483000, 33.9311700, 'SD', '2016-07-17', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123516, 'Shendi', 'Shendi', 'Shandi,Shendi,Shindi,Shindî', 16.6915000, 33.4341000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123517, 'Sawākin', 'Sawakin', 'Savakine,Sawakin,Sawākin,Suakin,Савакине', 19.1059000, 37.3321000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123518, 'Sinnar', 'Sinnar', 'Sannar,Sannār,Sennaar,Sennar,Sennār,Sinnar', 13.5690700, 33.5671800, 'SD', '2016-07-17', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123519, 'Rabak', 'Rabak', 'KST,Rabak,Rabaq,rbk,ربك', 13.1808700, 32.7399900, 'SD', '2013-05-18', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123520, 'Nyala', 'Nyala', 'N''jala,Niala,Nijala,Niyala,Niyālā,Njala,Njalo,Nyala,Nyāla,UYL,ni ya la,nialla,nyala,nyalh,nyara,Ньяла,نيالا,نیاله,ニャラ,尼亚拉,니알라', 12.0488800, 24.8806900, 'SD', '2016-01-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123521, 'Merowe', 'Merowe', 'MWE,Marawi,Marawī,Merawi,Merowe', 18.4703600, 31.8112600, 'SD', '2016-10-14', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123522, 'Marabba', 'Marabba', '', 12.3500000, 32.1833300, 'SD', '2006-01-17', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123523, 'Maiurno', 'Maiurno', '', 13.4166700, 33.6666700, 'SD', '2006-01-27', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123524, 'Kutum', 'Kutum', 'Kutum', 14.2000000, 24.6666700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123525, 'Kosti', 'Kosti', 'Costi,KST,Kosti,Kusti,Kūstī,rbk,Кусти,ربك', 13.1629000, 32.6634700, 'SD', '2014-05-28', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123526, 'Kurmuk', 'Kurmuk', 'Kurmuk,Kurmul', 10.5500000, 34.2833300, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123527, 'Kuraymah', 'Kuraymah', 'Kareima,Karemah,Karima,Karêmah,Kuraymah', 18.5500000, 31.8500000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123528, 'Kināna', 'Kinana', 'Kenana,Kinana,Kinanah,Kināna,Kinānah', 14.0361000, 33.1712000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123529, 'Kassala', 'Kassala', 'Cassala,KSL,Kasala,Kassala,Kassale,Kassalā,Kaszala,Statul Kassala,ka sa la,kasalla,kassara,ksl,ksla,Кассала,Кассале,كسل,کسلا,カッサラ,卡薩拉,카살라', 15.4509900, 36.3999800, 'SD', '2012-02-02', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123530, 'Karmah an Nuzul', 'Karmah an Nuzul', 'Karma An Nuzul,Karmah,Karmah an Nuzul,Kerma,Kerma en Nuzl,Kermah', 19.6333300, 30.4166700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123531, 'Kadugli', 'Kadugli', 'KDX,Kadugli,Kaduqli,Kāduqlī,kadqly,Кадугли,كادقلى,كادقلي', 11.0111100, 29.7183300, 'SD', '2016-01-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123532, 'Gebeit', 'Gebeit', 'Gebeit,Jabet,Jabēt', 21.0666700, 36.3166700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123533, 'Jalqani', 'Jalqani', 'Galgani,Jalqani', 12.4486000, 34.2186000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123534, 'Doka', 'Doka', 'Doka', 13.5166700, 35.7666700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123535, 'Dilling', 'Dilling', 'Ad Dalanj,Dilling,Диллинг', 12.0500000, 29.6500000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123536, 'Port Sudan', 'Port Sudan', 'Bur Sudan,Burt Sudan,Būr Sūdān,Būrt Sūdān,Gorad Port-Sudan,New Sawakin,New Sawâkin,PZU,Port Sodan,Port Sudan,Port Sudanas,Port Szudan,Port Szudán,Port-Soudan,Port-Sudan,Port-sudan,Porto Sudan,Porto Sudao,Porto Sudão,Puerto Sudan,Puerto Sudán,Pòrt Sodan,Shaikh Barghuth,Shaikh Barghūth,Shaykh Burghuth,Shaykh Burghūth,Sheikh Barghuth,Sheikh Barghūth,Sudanhavenurbo,bwr swdan,bwrtswdan,phxrt sudan,poteusudan,potosudan,su dan gang,Горад Порт-Судан,Порт Судан,Порт-Судан,Պորտ Սուդան,פורט סודאן,بور سودان,بورتسودان,پورٹ سوڈان,พอร์ตซูดาน,ポートスーダン,苏丹港,포트수단', 19.6174500, 37.2164400, 'SD', '2015-06-04', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123537, 'Berber', 'Berber', 'Barbar,Berber', 18.0215800, 33.9829900, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123538, 'Bārah', 'Barah', 'Bara,Barah,Bāra,Bārah', 13.7000000, 30.3666700, 'SD', '2016-11-04', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123539, 'Atbara', 'Atbara', 'ATB,Atbara,Atbarah,Atbare,Madent Atbara,`Atbarah,a te ba la,atobara,Атбара,Атбаре,عطبرة,عطبره,‘Aţbarah,アトバラ,阿特巴拉', 17.7021700, 33.9863800, 'SD', '2012-01-28', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123540, 'As Sūkī', 'As Suki', 'As Suki,As Sūkī,Es Suki', 13.3166700, 33.8833300, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123541, 'Ar Ruseris', 'Ar Ruseris', 'Ar Roseris,Ar Rusayris,Ar Ruseris,Ar Ruşayriş,Er Roseires,Ruseres,Ruṣêreṣ', 11.8659000, 34.3869000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123542, 'Ar Rahad', 'Ar Rahad', 'Ar Rahad,Er Rahad,Rahad', 12.7166700, 30.6500000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123543, 'Aroma', 'Aroma', '', 15.8166700, 36.1333300, 'SD', '2006-01-27', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123544, 'Argo', 'Argo', 'Argo,Arqo', 19.5166700, 30.4166700, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123545, 'An Nuhūd', 'An Nuhud', 'An Nahud,An Nahūd,An Nuhud,An Nuhūd,En Nahud,En Nahūd,NUD,Nahad', 12.7000000, 28.4333300, 'SD', '2017-02-10', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123546, 'El Obeid', 'El Obeid', 'Al Obayyid,Al Ubayd,Al Ubayyid,Al Ubayyiḑ,Al-Ubayyid,Al-`Obed,Al-‘Obêd,EBD,El Obeid,El Ubeiyad,`Ubed,alaby,Ел Обеид,الأبي,‘Ubêd', 13.1842100, 30.2166900, 'SD', '2013-12-14', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123547, 'Al Qiţena', 'Al Qitena', 'Al Qitena,Al Qiţena,Al Qutaynah,Al Quţaynah,El Geteina,El Qeteina', 14.8648000, 32.3668000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123548, 'Al Qadarif', 'Al Qadarif', 'Al Qadarif,Al Qaḑārif,Al-Kadarif,Al-Qadarif,Al-Qaḑārif,El Gedaref,El-Gadarif,GSU,Gadaref,Gadarif,Gedaref,alqdarf,jia da li fu,Гедареф,אל-קדריף,القضارف,加达里夫', 14.0349300, 35.3834400, 'SD', '2017-02-09', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123549, 'Al Masallamiyya', 'Al Masallamiyya', 'Al Masallamiyya,Al Musallamiyah,Al Musallamīyah,El Mesellemiya,Mesellemiya,Messelemiya', 14.5748000, 33.3373000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123550, 'Al Mijlad', 'Al Mijlad', 'Al Mijlad,Al Mujlad,El Muglad,Muglad', 11.0333300, 27.7333300, 'SD', '2015-08-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123551, 'El Matama', 'El Matama', 'Al Matamma,Al Matammah,El Matama,El Metemma,Matammah,Maṭammah,Metemma', 16.7095000, 33.3565000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123552, 'Al Manāqil', 'Al Manaqil', 'Al Manaqil,Al Manāqil,El Managil,El Manaqil,El Manāqil,Manaqil', 14.2459000, 32.9891000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123553, 'Al Lagowa', 'Al Lagowa', 'Al Lagawa,Al Lagowa,Al Lagāwa,El Lagowa', 11.4000000, 29.1333300, 'SD', '2015-08-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123554, 'Khartoum', 'Khartoum', 'Al Khartum,Al Kharţūm,Al Khurtum,Al Khurţūm,Cartum,Cartúm,Chartoum,Chartum,Chartumas,Chartúm,Hartum,Hartumo,Jartum,KRT,Kartum,Kartúm,Khartoem,Khartoum,Khartoun,Khartum,Khartun - alkhrtwm,Khartún - الخرطوم,haleutum,harutsumu,hrtwm,karttaum,ke tu mu,khartwm,khrtwm,Ĥartumo,Χαρτούμ,Картум,Хартум,חרטום,خارطوم,خرطوم,கார்த்தௌம்,ཁར་ཏུམ,ካርቱም,ハルツーム,喀土穆,하르툼', 15.5517700, 32.5324100, 'SD', '2011-10-26', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123555, 'Al Kiremit al ‘Arakiyyīn', 'Al Kiremit al `Arakiyyin', 'Al Kereimet,Al Kiremit al `Arakiyyin,Al Kiremit al ‘Arakiyyīn,El Kereimet,Kereimet', 14.3476000, 32.9437000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123556, 'Al Kawa', 'Al Kawa', 'Al Kawa,Al Kawah,El Kawa,Kawa', 13.7463000, 32.4996000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123557, 'Geneina', 'Geneina', 'Aj Jinena,Aj Jinēna,Al Geneina,Al Jeneina,Al Jinena,Al Jinēna,Al Junaynah,EGN,El Geneina,Geneina,aljnynt,الجنينة', 13.4526200, 22.4472500, 'SD', '2013-11-10', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123558, 'Al Hilāliyya', 'Al Hilaliyya', 'Al Hilaliyah,Al Hilaliyya,Al Hilāliyya,Al Hilālīyah,El Hilaliya,El Hilāliya,Hilaliya', 14.9398000, 33.2340000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123559, 'Al Ḩawātah', 'Al Hawatah', 'Al Hawatah,Al Hawwata,Al Ḩawātah,El Hawata', 13.4166700, 34.6333300, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123560, 'Al Hasaheisa', 'Al Hasaheisa', 'Al Hasaheisa,Al Hasahisa,Al Ḩaşāḩīşa,El Hasaheisa,El Hasiheisa,Hasiheisa', 14.7526400, 33.2983600, 'SD', '2012-02-02', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123561, 'Al Fūlah', 'Al Fulah', 'Al Fulah,Al Fūlah,Al-Fula,El Fula,Rigl el Fula,Rijl Al Fula', 11.7329200, 28.3578600, 'SD', '2011-10-26', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123562, 'El Fasher', 'El Fasher', 'Al Fashir,Al Fāshir,Al-Faschir,Al-Fashir,ELF,Ehl''-Fashir,El Fasher,Tendelti,Эль-Фашир', 13.6279300, 25.3493600, 'SD', '2013-12-14', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123563, 'El Bauga', 'El Bauga', 'Al Bauga,El Bauga', 18.2619700, 33.9081200, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123564, 'Ad Douiem', 'Ad Douiem', 'Ad Diwem,Ad Douiem,Ad Duwaym,Ad Duwem,Ad Duwēm,Al Dewaym,Dewaim,Dueim,Ed Dueim,Ehd-Duehjm,aldwym,aldwym (mdynt),Эд-Дуэйм,الدويم (مدينة),الدویم', 14.0012000, 32.3116000, 'SD', '2013-06-15', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123565, 'El Daein', 'El Daein', 'ADV,Ad Du''ayn,Ed Daein,El Daein,aldʿyn,الضعين,الضعین', 11.4618600, 26.1258300, 'SD', '2013-08-10', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123566, 'Ad Dindar', 'Ad Dindar', '', 13.2000000, 34.1666700, 'SD', '2006-01-17', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123567, 'Ed Damer', 'Ed Damer', 'Ad Damar,Ad Damir,Ad Dāmir,Ad-Damir,Al-Damir,Ed Damer,El Damar,aldamr,الدامر', 17.5989800, 33.9720500, 'SD', '2016-01-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123568, 'Ad-Damazin', 'Ad-Damazin', 'Ad Damazin,Ad Damāzīn,Ad-Damazin,Damazin,Ed Damazin,RSS,aldmazyn,Ед Дамазин,الدمازين', 11.7891000, 34.3592000, 'SD', '2014-04-20', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123569, 'Ad Dabbah', 'Ad Dabbah', 'Ad Dabba,Ad Dabbah,Al Dabbah,Dabbah,Debba,Debbat el Muaskar,Debbeh,EDB,Ed Debba', 18.0500000, 30.9500000, 'SD', '2017-02-10', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123570, 'Abū Zabad', 'Abu Zabad', '', 12.3500000, 29.2500000, 'SD', '2015-08-07', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123571, 'Abu Jibeha', 'Abu Jibeha', 'Abu Gibeyah,Abu Gubeiha,Abu Jibeha,Abu Jubayhah,Abu-Gebeiha,Abū Jubayhah', 11.4562000, 31.2285000, 'SD', '2012-01-19', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123572, 'El Fula', 'El Fula', 'Al Fulah,Al Fūlah,Al-Fula,El Fula,alfwlt,الفولة', 11.7119500, 28.3462000, 'SD', '2016-01-09', 211);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123573, 'Viken', 'Viken', '', 64.7258700, 20.9154800, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123574, 'Ursviken', 'Ursviken', 'Ursvik', 64.7126100, 21.1658000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123575, 'Umeå', 'Umea', 'Gorad Umea,Oumeo,Owmeo,UME,Ubmi,Uma,Umea,Umeo,Umeå,Uumaja,awmyw,ume''o,ume-o,umeo,umi''o,xu me xo,yu mo ao,Ūmeo,Ούμεο,Горад Умеа,Умео,Ումեո,אומאו,أوميو,امیہ,اومئو,اومیو,ऊमेओ,ਊਮਿਓ,อูเมโอ,უმეო,ウメオ,于默奧,우메오', 63.8284200, 20.2597200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123576, 'Töre', 'Toere', 'Toere,Tore,Töre,Tøre', 65.9124300, 22.6512800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123577, 'Täfteå', 'Taeftea', 'Taftea,Teftea,Tefteå,Täfteå', 63.8397000, 20.4785700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123578, 'Storvik', 'Storvik', 'Storavik,Storvik,Storåvik', 65.1500000, 20.7333300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123579, 'Södra Sunderbyn', 'Soedra Sunderbyn', 'Sodra Sunderbyn,Soedra Sunderbyn,Sunderbyn,Södra Sunderbyn,Sødra Sunderbyn', 65.6598300, 21.9400400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123580, 'Skelleftehamn', 'Skelleftehamn', 'Skelleftehamn', 64.6833300, 21.2333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123581, 'Skellefteå', 'Skelleftea', 'Heletti,SFT,Selefteo,Shelefteo,Shellefteo,Skelleftea,Skellefteå,chellef te xo,kkhlftya,sherefuteo,syellepeute-o,xie lai fu te ao,Šelefteo,Шелефтео,Шеллефтео,کخلفتئا,เชลเลฟเตโอ,შელეფტეო,シェレフテオ,謝萊夫特奧,셸레프테오', 64.7506700, 20.9527900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123582, 'Råneå', 'Ranea', '', 65.8548200, 22.2912600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123583, 'Sävar', 'Saevar', '', 63.9038300, 20.5501400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123584, 'Rosvik', 'Rosvik', 'Rosvik', 65.4333300, 21.7000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123585, 'Rolfs', 'Rolfs', 'Rolfs', 65.8500000, 23.1166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123586, 'Roknäs', 'Roknaes', 'Roknas,Roknäs', 65.3500000, 21.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123587, 'Robertsfors', 'Robertsfors', 'Robertsforsh,Робертсфорш', 64.1932400, 20.8480600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123588, 'Röbäck', 'Roebaeck', 'Robacksby,Rodback,Röbäcksby,Rödbäck', 63.8087900, 20.1890100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123589, 'Sävast', 'Saevast', '', 65.7700200, 21.7311300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123590, 'Piteå', 'Pitea', 'Piitime,Pita,Pitea,Pitejas,Piteo,Piteå,Pitėjas,pi te ao,piteo,Питео,Пітео,پیته‌آ,პიტეო,ピーテオ,皮特奧', 65.3171700, 21.4794400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123591, 'Pajala', 'Pajala', 'PJA,Pajala,Паяла', 67.2128400, 23.3660700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123592, 'Övertorneå', 'OEvertornea', 'Ehverturneo,Everturneo,Jovertorneo,Matarenki,OEvertornea,Ofer Torne,Ofver Tornea,Overtorne,Overtornea,Ylitornio,Öfer Torne,Öfver Torneå,Övertorneå,Øvertorneå,Евертурнео,Йоверторнео,Эвертурнео', 66.3877800, 23.6542500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123593, 'Överkalix', 'OEverkalix', 'OEverkalix,Overkalix,Ylikainuu,Överkalix,Øverkalix', 66.3275400, 22.8441400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123594, 'Obbola', 'Obbola', 'Obbola', 63.7000000, 20.3166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123595, 'Norrfjärden', 'Norrfjaerden', 'Norrfjarden,Norrfjärden', 65.4180500, 21.5015100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123596, 'Malmberget', 'Malmberget', 'Mal''mberge,Mal''mberger,Mal''mberget,Malmberget,Malmberiet,Malmivaara,malmbyryt,mlmbqyt,Малмбериет,Мальмберге,Мальмбергер,Мальмбергет,مالمبيريت,ملمبقیت', 67.1752900, 20.6549500, 'SE', '2014-03-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123597, 'Luleå', 'Lulea', 'Gorad Lulea,LLA,Liuleo,Ljuleo,Lula,Lulea,Luleju,Luleo,Luleå,Luulaja,lu lei ao,luleo,lulle-o,lwlyw,rureo,Горад Лулеа,Лулео,Люлео,לולאו,للیہ,لولئو,لوليو,لولیو,ლულეო,ルレオ,呂勒奧,룰레오', 65.5841500, 22.1546500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123598, 'Långsele', 'Langsele', '', 64.8166700, 20.2500000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123599, 'Kiruna', 'Kiruna', 'Giron,Gorad Kiruna,KRN,Kiiruna,Kirun,Kiruna,ji lu na,kiluna,kiruna,kyrwna,qyrwnh,Горад Кіруна,Кируна,Кіруна,Կիրունա,קירונה,كيرونا,کیرونا,கிருனா,キルナ,基律纳,키루나', 67.8557200, 20.2251300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123600, 'Kalix', 'Kalix', 'Kaihnuu,Kainuu,Kaliks,klyks,Каликс,Калікс,کلیکس', 65.8529800, 23.1564500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123601, 'Kåge', 'Kage', '', 64.8357100, 20.9845300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123602, 'Hortlax', 'Hortlax', 'Hortlax', 65.2818800, 21.4054400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123603, 'Holmsund', 'Holmsund', 'Kholmsund,huo er mu song de,hwlmswnd,Холмсунд,هولمسوند,霍尔姆松德', 63.7060200, 20.3640900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123604, 'Haparanda', 'Haparanda', 'Gaparanda,Haaparanta,Haparanda,Khaparanda,ha pa lan da,hapalanda,haparanda,Гапаранда,Хапаранда,هاپاراندا,哈帕兰达,하파란다', 65.8354900, 24.1367600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123605, 'Gammelstad', 'Gammelstad', 'Gammelstad,Gammelstaden', 65.6393100, 22.0114500, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123606, 'Gällivare', 'Gaellivare', 'Ellivare,GEV,Gaellivare,Gällivare,Jaellivaara,Jelivare,Jelivarė,Jellivaara,Jiehllevarri,Jiellevari gielda,Jiellevarre,Jiellevarri,Jiellevári gielda,Jiellevárre,Jiellevárri,Jällivaara,Vahcir,Vahtjer,Váhtjer,Váhčir,i~erivu~are,yalyfarh,yalywrh,ye li wa lei,yellibale,Єлліваре,Елливаре,Йеливаре,Йиэллеварри,ياليفاره,یالیوره,イェリヴァーレ,耶利瓦勒,옐리바레', 67.1338700, 20.6527800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123607, 'Forsbacka', 'Forsbacka', '', 64.7666700, 20.5000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123608, 'Ersmark', 'Ersmark', 'Ersmark', 63.8833300, 20.3166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123609, 'Byske', 'Byske', '', 64.9525800, 21.2058000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123610, 'Burträsk', 'Burtraesk', '', 64.5166700, 20.6500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123611, 'Bureå', 'Burea', 'Burea,Bureå', 64.6166700, 21.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123612, 'Boliden', 'Boliden', 'Boliden', 64.8666700, 20.3833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123613, 'Boden', 'Boden', 'Puuti,Suttes', 65.8251800, 21.6886400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123614, 'Bergsviken', 'Bergsviken', 'Bergsviken', 65.3000000, 21.3833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123615, 'Bergnäset', 'Bergnaeset', '', 65.5779100, 22.1084400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123616, 'Backa', 'Backa', '', 64.9833300, 21.0666700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123617, 'Älvsbyn', 'AElvsbyn', 'Alvsbyn,El''vsbjun,Elfsby,Elvsbjun,Елвсбюн,Ельвсбюн', 65.6762400, 21.0016200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123618, 'Alunda', 'Alunda', 'Alunda', 60.2666700, 18.4000000, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123619, 'Anneberg', 'Anneberg', '', 60.2416700, 18.4166700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123620, 'Björklinge', 'Bjorklinge', 'Bjoerklinge,Bjorklinge,Björklinge,Bjørklinge', 60.0300400, 17.5520300, 'SE', '2012-12-03', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123621, 'Marieberg', 'Marieberg', '', 60.2333300, 18.5000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123622, 'Ystad', 'Ystad', 'Istad,Istadas,Justad,Ystad,Ystadium,Ystao,aystd,istad,isutaddo,wiseutadeu,ystad,yu si ta de,Істад,Истад,Юстад,ایستد,يستاد,یستاد,イースタッド,于斯塔德,위스타드', 55.4296600, 13.8204100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123623, 'Vrigstad', 'Vrigstad', 'Vrigstad', 57.3500000, 14.4666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123624, 'Vittsjö', 'Vittsjoe', 'Vittsjo,Vittsjoe,Vittsjö,Vittsjø', 56.3436600, 13.6608100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123625, 'Vislanda', 'Vislanda', 'Vislanda', 56.7833300, 14.4500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123626, 'Viskafors', 'Viskafors', 'Viskafors', 57.6294100, 12.8489000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123627, 'Visby', 'Visby', 'Gorad Visbju,VBY,Visbi,Visbija,Visbis,Visbju,Visbue,Visby,Visbü,Vismpy,Wisbia,bhisbi,biseubwi,fysby,visbis,visbiu,visbus,vu~isubyu,wei si bi,wysby,wyzbh,Βίσμπυ,Висби,Висбю,Вісбю,Горад Вісбю,ויסבי,فيسبي,ویزبه,ویسپے,भिस्बी,ვისბიუ,ヴィスビュー,維斯比,비스뷔', 57.6408900, 18.2960200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123628, 'Virserum', 'Virserum', 'Virserum', 57.3166700, 15.5833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123629, 'Vintrosa', 'Vintrosa', 'Vintrosa', 59.2500000, 14.9500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123630, 'Vinslöv', 'Vinsloev', 'Vinsloev,Vinslov,Vinslöv,Vinsløv', 56.1000000, 13.9166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123631, 'Vinninga', 'Vinninga', 'Vinninga', 58.4500000, 13.2666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123632, 'Vingåker', 'Vingaker', 'Vingoker,Вингокер', 59.0433000, 15.8737400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123633, 'Vindeln', 'Vindeln', 'Vindeln,Винделн', 64.2017500, 19.7194500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123634, 'Vimmerby', 'Vimmerby', 'Vemmaria,Vimerbis,Vimerbju,Vimmerbju,fymrby,vu~inmerubyu,wei mo bi,wymrbh,Вимербю,Виммербю,فيمربي,ویمربه,ヴィンメルビュー,維默比', 57.6658800, 15.8551500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123635, 'Vilhelmina', 'Vilhelmina', 'VHM,Vilhelmina,Vualtjere', 64.6241700, 16.6559600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123636, 'Vikingstad', 'Vikingstad', '', 58.3830400, 15.4320100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123637, 'Viken', 'Viken', '', 56.1500000, 12.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123638, 'Vikarbyn', 'Vikarbyn', 'Vikarbyn', 60.9166700, 15.0166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123639, 'Vi', 'Vi', 'Vi,Viforsen', 62.3000000, 17.1666700, 'SE', '2017-01-10', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123640, 'Vibble', 'Vibble', 'Vibble,Vible', 57.6045200, 18.2560100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123641, 'Vetlanda', 'Vetlanda', 'Vetlanda,Vitlanda,wtlanda,Ветланда,وتلاندا', 57.4288700, 15.0776200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123642, 'Vellinge', 'Vellinge', 'Vallinge,Velinge,Vällinge,wlynyh,Велинге,ولینیه', 55.4712400, 13.0197100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123643, 'Vejbystrand', 'Vejbystrand', 'Saltoren,Saltören,Vejbystrand', 56.3177800, 12.7672200, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123644, 'Veinge', 'Veinge', 'Veinge', 56.5500000, 13.0666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123645, 'Veddige', 'Veddige', 'Veddige', 57.2659100, 12.3322000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123646, 'Veberöd', 'Veberoed', 'Veberod,Veberoed,Veberöd,Veberød', 55.6333300, 13.4833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123647, 'Växjö', 'Vaexjoe', 'Gorad Veksheh,VXO,Vaexjoe,Vaxjo,Vekse,Veksh''o,Vekshe,Vekshjo,Vekše,Vekšė,Vexioe,Vexionia,Vexiö,Växjö,begsye,bekusho,faksyw,vekshe,wei ke she,wek chex,wkfw,wqsh,wykyw,Векше,Векшьо,Векшё,Горад Векшэ,וקשה,فاكسيو,وکفو,ویکوہ,ویکیو,เวกเชอ,ვექშე,ベクショー,韦克舍,벡셰', 56.8776700, 14.8090600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123648, 'Vaxholm', 'Vaxholm', 'Vaksholmas,Vakskhol''m,Vakskholm,Waxholm,wa ke si huo er mu,wkshlm,Ваксхолм,Ваксхольм,وکسهلم,瓦克斯霍爾姆', 59.4022500, 18.3531700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123649, 'Vattholma', 'Vattholma', 'Vattholma', 60.0166700, 17.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123650, 'Västervik', 'Vaestervik', 'VVK,Vaestervik,Vestervik,Vestervikas,Vestrovicum,Västervik,wstwyk,Вестервик,وستویک,ვესტერვიკი', 57.7584000, 16.6373300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123651, 'Västerås', 'Vaesteras', 'Arosia,Gorad Vestehros,Vaesteras,Vesteros,Vesterosa,Vesterosas,Västerås,beseuteloseu,fystyrws,vu~esuterosu,wei si te luo si,wes te ros,wstrws,wystyrws,Βεστερός,Вестерос,Горад Вестэрос,וועסטעראס,וסטרוס,فيستيروس,واسٹیراس,وستروس,ویستیروس,เวสเตโรส,ვესტეროსი,ヴェステロース,韦斯特罗斯,베스테로스', 59.6161700, 16.5527600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123652, 'Vasastan', 'Vasastan', 'Vasastaden', 59.3457100, 18.0498500, 'SE', '2016-10-14', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123653, 'Vårsta', 'Varsta', '', 59.1652800, 17.7972200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123654, 'Värnamo', 'Vaernamo', 'Vernamo,Vernamu,wrnmw,Вернамо,Вернаму,ورنمو', 57.1860400, 14.0400100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123655, 'Vargön', 'Vargon', 'Varagon,Varagons,Varagön,Vargoen,Vargon,Vargön,Vargøn', 58.3559900, 12.3906000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123656, 'Vårgårda', 'Vargarda', 'Vargarda gielda,Vårgårda gielda', 58.0370600, 12.8090700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123657, 'Varberg', 'Varberg', 'Gorad Varberg,Varberg,Varbergas,Varberi,Varburg,Varburgum,baleubeli,varbergi,vu~aruberi,wa er bei li,warbrh,wrbrg,Варберг,Варбери,Горад Варберг,ורברג,واربره,ვარბერგი,ヴァールベリ,瓦尔贝里,바르베리', 57.1055700, 12.2507800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123658, 'Vara', 'Vara', 'Wara', 58.2623400, 12.9541300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123659, 'Vansbro', 'Vansbro', 'Vansboro,Vansbru,fansbrw,wnsbrw,Вансбру,فانسبرو,ونسبرو', 60.5089300, 14.2245800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123660, 'Vännäsby', 'Vaennaesby', 'Vannasby,Vännäsby', 63.9156400, 19.8243800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123661, 'Vännäs', 'Vaennaes', 'Venes,Венес', 63.9067600, 19.7571200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123662, 'Vänersborg', 'Vaenersborg', 'Venersborg,Venersburgum,Venershbori,Venesborgas,Venešborgas,wei na shen bao,wnshbwy,Венерсборг,Венершбори,ونشبوی,維納什堡', 58.3807500, 12.3234000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123663, 'Vallentuna', 'Vallentuna', 'Valentiuna,Valentjuna,Valentuna,Vallentunan kunta,wlntwna,Валентуна,Валентюна,ولنتونا', 59.5343600, 18.0775800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123664, 'Vallda', 'Vallda', 'Vallda', 57.4775000, 12.0013900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123665, 'Valla', 'Valla', '', 63.5500000, 13.8000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123666, 'Valla', 'Valla', 'Valla', 59.0166700, 16.3833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123667, 'Valje', 'Valje', 'Valje', 56.0627900, 14.5438800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123668, 'Valdemarsvik', 'Valdemarsvik', 'Valdemarshvik,faldymarshfyk,Валдемаршвик,فالديمارشفيك', 58.2031000, 16.6022500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123669, 'Valbo', 'Valbo', 'Valbo', 60.6500000, 17.0333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123670, 'Vålberg', 'Valberg', 'Valberg,Vålberg', 59.3914500, 13.1863300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123671, 'Vagnhärad', 'Vagnhaerad', 'Vagnharad,Vagnhärad', 58.9458700, 17.4875700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123672, 'Vaggeryd', 'Vaggeryd', 'Vagerjud,Вагерюд', 57.4980700, 14.1484200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123673, 'Vadstena', 'Vadstena', 'Gorad Vadstehna,Vadstena,Vadstenium,fadstynt,wa si tai na,wstyna,Вадстена,Горад Вадстэна,فادستينة,وستئنا,瓦斯泰納', 58.4486300, 14.8896900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123674, 'Uppsala', 'Uppsala', 'Gorad Upsala,Oupsala,QYX,Ubsala,Upfala,Uppsal,Uppsala,Uppsalae,Uppsalir,Upsala,Upsalia,Upsalo,Upsāla,apsala,awbsala,awpsala,ubsalla,upcala,upsala,upusara,wu pu sa la,xup sx la,Ουψάλα,Горад Упсала,Убсала,Уппсалæ,Уппсала,Упсала,Упфала,Өпсала,Ուփսալա,אופסאלא,אופסלה,أوبسالا,اوبسالا,اوپسالا,اپسالا,उप्साला,உப்சாலா,อุปซอลา,უფსალა,ᐆᑉᓴᓚ/uupsala,ウプサラ,乌普萨拉,웁살라', 59.8588200, 17.6388900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123675, 'Upplands Väsby', 'Upplands Vaesby', 'Uplands Vasby,Uplands Vesbi,Uplands Vesbis,Uplands Vesbju,Uplands Väsby,Upplands Vasby,Vasby,Vasby Villastad,Väsby,Väsby Villastad,awplndz wzbh,Упландс Весби,Упландс Весбю,اوپلندز وزبه,اپلینڈز ویسبی', 59.5183900, 17.9112800, 'SE', '2013-03-11', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123676, 'Hjärup', 'Hjaerup', '', 55.6688000, 13.1393100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123677, 'Ulricehamn', 'Ulricehamn', 'Bogesund,Ulricehamn,awlshmn,اولسهمن', 57.7915900, 13.4142200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123678, 'Uddevalla', 'Uddevalla', 'Uddevala,Uddevalla,Udevala,adwala,awdwala,udeballa,udevala,wu de wa la,Уддевала,Уддевалла,Удевала,ادوالا,اودوالا,უდევალა,乌德瓦拉,우데발라', 58.3478400, 11.9424000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123679, 'Tyringe', 'Tyringe', 'Tyringe', 56.1603700, 13.5981100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123680, 'Tygelsjö', 'Tygelsjoe', 'Tygelsjo,Tygelsjoe,Tygelsjö,Tygelsjø', 55.5166700, 13.0000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123681, 'Tvååker', 'Tvaaker', 'Tvaaker,Tvååker', 57.0414700, 12.3995000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123682, 'Tumba', 'Tumba', 'Tumba,tmba,tumba,twmba,Тумба,تمبا,تومبا,툼바', 59.1985800, 17.8331700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123683, 'Tullinge', 'Tullinge', '', 59.2000000, 17.9000000, 'SE', '2011-08-16', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123684, 'Trosa', 'Trosa', 'Trusa,te lu sa,trwsa,Труса,تروسا,特魯薩', 58.8962100, 17.5481200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123685, 'Trönninge', 'Troenninge', 'Troenninge,Tronninge,Tronningeby,Trönninge,Trönningeby,Trønninge', 56.6166700, 12.9333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123686, 'Trollhättan', 'Trollhaettan', 'Gorad Trol''khetan,THN,Trolem Excudia,Trolhetanas,Trolkhetan,Troll''gettan,Troll''khettan,Trollhaettan,Trollhattan,Trollhättan,t rxl het tan,te luo er hai tan,teulolhetan,tororuhettan,trwlhatn,trwlhtan,trwlhtn,Горад Трольхетан,Тролльгеттан,Тролльхеттан,Тролхетан,טרולהטן,ترولهاتن,ترولهتان,ٹرولہاٹن,ตรอลเฮตตัน,ტროლჰეტანი,トロルヘッタン,特羅爾海坦,트롤헤탄', 58.2836500, 12.2886400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123687, 'Gimo', 'Gimo', '', 60.1730400, 18.1850700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123688, 'Trelleborg', 'Trelleborg', 'Tralleborg,Treleborg,Treleborgas,Trelebori,Trelleborg,Trileoburgum,Trälleborg,te lei lei bao,teulelleboli,trlbwrg,Трелеборг,Трелебори,Треллеборг,ترلبورگ,ტრელებორგი,特雷勒堡,트렐레보리', 55.3751400, 13.1569100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123689, 'Trekanten', 'Trekanten', 'Trekanten', 56.7000000, 16.1166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123690, 'Träslövsläge', 'Traslovslage', 'Laejet,Läjet,Traesloevslaege,Traslovslage,Träslövsläge', 57.0541700, 12.2789900, 'SE', '2016-09-08', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123691, 'Tranemo', 'Tranemo', 'Tranemo', 57.4833300, 13.3500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123692, 'Tranås', 'Tranas', 'Tranos,Tranosas,tranaws,Транос,تراناوس', 58.0371700, 14.9782000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123693, 'Torup', 'Torup', 'Torup', 56.9566300, 13.0772500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123694, 'Torslanda', 'Torslanda', '', 57.7243200, 11.7701300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123695, 'Torshälla', 'Torshaella', 'Torshalla,Torshkhela,Torshälla,tuo shen hai la,twrshhla,Торшхела,تورشهلا,托什海拉', 59.4166700, 16.4666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123696, 'Torsby', 'Torsby', 'TYF,Torsbyn kunta,Torshbju,Tursbju,Торшбю,Турсбю', 60.1352700, 13.0082000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123697, 'Torsås', 'Torsas', '', 56.4125100, 15.9984400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123698, 'Tormestorp', 'Tormestorp', 'Tormastorp,Tormestorp', 56.1135000, 13.7451600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123699, 'Torekov', 'Torekov', 'Torekov', 56.4250000, 12.6333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123700, 'Töreboda', 'Toereboda', 'Toereboda,Toreboda,Töreboda,Tøreboda,trbwda,تربودا', 58.7073900, 14.1259700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123701, 'Tomelilla', 'Tomelilla', '', 55.5429300, 13.9546000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123702, 'Tollarp', 'Tollarp', '', 56.1666700, 14.2833300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123703, 'Tollarp', 'Tollarp', 'Tollarp', 55.9333300, 13.9833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123704, 'Töcksfors', 'Toecksfors', 'Tocksfors,Toecksfors,Töcksfors,Tøcksfors', 59.5081600, 11.8443100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123705, 'Tjuvkil', 'Tjuvkil', 'Tjuvkil', 57.9000000, 11.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123706, 'Tingsryd', 'Tingsryd', 'Tingsrjud,Тингсрюд', 56.5247000, 14.9790200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123707, 'Timrå', 'Timra', 'Timro,tymrwa,Тимро,Тімро,تیمروآ', 62.4865400, 17.3261300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123708, 'Timmernabben', 'Timmernabben', 'Timmernabben', 56.9666700, 16.4333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123709, 'Tillberga', 'Tillberga', 'Tillberga', 59.6833300, 16.6166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123710, 'Tierp', 'Tierp', 'Tierp,XFU,tyrp,Тиерп,تیرپ', 60.3426900, 17.5181200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123711, 'Tidaholm', 'Tidaholm', 'Tidagol''m,Tidakhol''m,tdhwlm,Тидахольм,Тідагольм,تدهولم', 58.1803500, 13.9582400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123712, 'Tibro', 'Tibro', '', 58.4245300, 14.1616200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123713, 'Tenhult', 'Tenhult', 'Tenhult', 57.7076100, 14.3220500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123714, 'Teckomatorp', 'Teckomatorp', '', 55.8666700, 13.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123715, 'Tärnsjö', 'Taernsjoe', 'Tarnsjo,Tärnsjö', 60.1500000, 16.9333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123716, 'Tanumshede', 'Tanumshede', 'Grabados rupestres de Tanum,Gravures rupestres de Tanum,Naskal''nye rel''efy v Tanume,Tanum,Tanumshede,Tanumshedė,ta nu mu si hai de,tanumaseda,Наскальные рельефы в Тануме,तनुमशेड,ტანუმშედე,塔努姆斯海德', 58.7238500, 11.3258700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123717, 'Tallboda', 'Tallboda', 'Tallboda', 58.4252100, 15.6815400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123718, 'Täby', 'Taby', '', 59.4439000, 18.0687200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123719, 'Taberg', 'Taberg', 'Smalands Taberg,Smålands Taberg,Taberg', 57.6772200, 14.0887600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123720, 'Svenljunga', 'Svenljunga', '', 57.4955100, 13.1107800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123721, 'Sveg', 'Sveg', 'EVG,Sveg,Свег', 62.0340700, 14.3657700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123722, 'Svedala', 'Svedala', 'Svedala,swdala,Сведала,سودالا', 55.5078800, 13.2351500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123723, 'Svärtinge', 'Svaertinge', 'Svartinge,Svartinge Villasamhalle,Svärtinge,Svärtinge Villasamhälle', 58.6550700, 16.0282300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123724, 'Svärdsjö', 'Svaerdsjoe', 'Svardsjo,Svärdsjö', 60.7402200, 15.9017300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123725, 'Svängsta', 'Svaengsta', 'Svangsta,Svängsta', 56.2666700, 14.7666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123726, 'Svanesund', 'Svanesund', 'Svanesund', 58.1429200, 11.8182100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123727, 'Svalsta', 'Svalsta', 'Svalsta', 58.7427300, 16.8697800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123728, 'Svalöv', 'Svaloev', 'Sval''ov,Svaliovas,Svaloev,Svalof,Svalov,Svalöf,Svalöv,Svaløv,Свальов', 55.9134000, 13.1076200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123729, 'Surte', 'Surte', 'Surte', 57.8253300, 12.0160400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123730, 'Surahammar', 'Surahammar', 'Sjurakhamar,swrhmr,Сюрахамар,سورهمر', 59.7072500, 16.2218800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123731, 'Sunne', 'Sunne', '', 59.8376400, 13.1430200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123732, 'Sundsvall', 'Sundsvall', 'Gorad Sundsval'',SDL,Sountsval,Sundsval,Sundsval FA,Sundsvalis,Sundsvall,Sundsvall'',sndsfal,sndswal,song zi wa er,sundsvali,sunseubal,suntsuvu~aru,swndswal,Σούντσβαλ,Горад Сундсваль,Сундсвал,Сундсвалль,Սունդսվալ ՖԱ,סונדסוואל,سندسفال,سندسوال,سوندسوال,სუნდსვალი,スンツヴァル,松茲瓦爾,순스발', 62.3912900, 17.3063000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123733, 'Sundsbruk', 'Sundsbruk', 'Sund,Sundsbruk', 62.4580600, 17.3488900, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123734, 'Sundbyberg', 'Sundbyberg', 'Sundyberg', 59.3612800, 17.9711400, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123735, 'Styrsö', 'Styrsoe', 'Styrso,Styrsoe,Styrsö,Styrsø', 57.6163900, 11.7855600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123736, 'Sturkö', 'Sturkoe', 'Sturko,Sturkoe,Sturkö,Sturkø', 56.0833300, 15.7000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123737, 'Sturefors', 'Sturefors', 'Sturefors', 58.3333300, 15.7333300, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123738, 'Strövelstorp', 'Stroevelstorp', 'Stroevelstorp,Strovelstorp,Strövelstorp,Strøvelstorp', 56.1697900, 12.8392500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123739, 'Strömsund', 'Stroemsund', 'Str''omsund,Straejmie,Stroemsund,Stromsund,Strömsund,Strømsund,Стрьомсунд', 63.8520600, 15.5558300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123740, 'Strömstad', 'Stroemstad', 'Str''omstad,Strjomstad,Stroemstad,Stromstad,Strömstad,Strømstad,si te lun si ta de,strwmstd,Стрьомстад,Стрёмстад,سترومستد,斯特伦斯塔德', 58.9394500, 11.1712000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123741, 'Strömsnäsbruk', 'Stroemsnaesbruk', 'Stromsnasbruk,Strömsnäsbruk', 56.5500000, 13.7166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123742, 'Strömma', 'Stroemma', 'Stroemma,Stromma,Strömma,Strømma', 59.2833300, 18.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123743, 'Strängnäs', 'Straengnaes', 'Strangnass,Stregnesia,Strengnes,Strengnesas,Strängnäss,si te lan nai si,strnys,sutorengunesu,Стренгнес,سترنیس,ストレングネース,斯特兰奈斯', 59.3774100, 17.0311900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123744, 'Storvreta', 'Storvreta', 'Storvreld,Storvreta', 59.9593300, 17.7058800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123745, 'Storvik', 'Storvik', 'Storvik', 60.5833300, 16.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123746, 'Storuman', 'Storuman', 'Luspie,SQO', 65.0959000, 17.1173100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123747, 'Storfors', 'Storfors', '', 59.5318300, 14.2720100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123748, 'Storebro', 'Storebro', 'Storebro', 57.5833300, 15.8500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123749, 'Stora Höga', 'Stora Hoega', 'Stora Hoega,Stora Hoga,Stora Höga,Stora Høga', 58.0166700, 11.8333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123750, 'Storå', 'Stora', '', 59.7140900, 15.1316900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123751, 'Stöpen', 'Stoepen', 'Stoepen,Stopen,Stöpen,Støpen', 58.4780200, 13.8661100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123752, 'Stockvik', 'Stockvik', 'Stockvik,Stockviksverken', 62.3366700, 17.3658300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123753, 'Stockholm', 'Stockholm', 'Estocolm,Estocolme,Estocolmo,Estocolmu,Estocòlme,Estokolma,Estokolmo,Gorad Stakgol''m,Holmia,STO,Stjokolna,Stoccholm,Stoccolma,Stockholbma,Stockholm,Stockolm,Stocolm,Stocolma,Stocòlma,Stocólma,Stokcholme,Stokgol''m,Stokgol''m osh,Stokgolm,Stokhol''m,Stokholm,Stokholma,Stokholmas,Stokholmi,Stokholmo,Stokkholm,Stokkholmur,Stokkhólmur,Stokkolma,Stokol''ma,Stokolm,Stuculma,Stuokhuolms,Stócólm,Sztokholm,Sztokhòlm,Tukholma,astkhlm,satakahoma,seutogholleum,si de ge er mo,stak''hom,stakahoma,stokahoma,stwkhwlm,stwqhwlm,stxkholm,sutokkuhorumu,Štokholm,Στοκχόλμη,Горад Стакгольм,Стокhольм,Стокгольм,Стокгольм ош,Стокольма,Стокхолм,Стокҳолм,Стёколна,Ստոկհոլմ,סטוקהולם,שטאקהאלם,استکهلم,ستوكهولم,ستۆکھۆڵم,سٹاکہوم,ܣܛܘܩܗܘܠܡ,स्टकहोम,स्टॉकहोम,स्तकहोम,স্টকহোম,ਸਟਾਕਹੋਮ,ஸ்டாக்ஹோம்,స్టాక్‌హోమ్,ಸ್ಟಾಕ್‍ಹೋಮ್,സ്റ്റോക്ക്‌ഹോം,สตอกโฮล์ม,སི་ཏོག་ཧོ་ལིམ།,စတော့ဟုမ်းမြို့,სტოკჰოლმი,ስቶኮልም,ᔅᑑᒃᓱᓪᒻ/stuukhulm,ストックホルム,斯德哥尔摩,斯德哥爾摩,스톡홀름,', 59.3325800, 18.0649000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123754, 'Stockaryd', 'Stockaryd', 'Stockaryd', 57.3173700, 14.5934100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123755, 'Stigtomta', 'Stigtomta', 'Stigtomta', 58.8000000, 16.7833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123756, 'Stenungsund', 'Stenungsund', 'Stenungsund,stnwnswnd,Стенунгсунд,ستنونسوند', 58.0704600, 11.8181000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123757, 'Stenstorp', 'Stenstorp', '', 58.4833300, 15.0666700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123758, 'Stenstorp', 'Stenstorp', 'Stenstorp', 58.2725400, 13.7145400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123759, 'Stenkullen', 'Stenkullen', 'Stenkullen', 57.7947600, 12.3168800, 'SE', '2015-11-27', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123760, 'Steninge', 'Steninge', 'Steninge', 56.7690000, 12.6303400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123761, 'Stenhamra', 'Stenhamra', 'Stenhamra', 59.3344000, 17.6884200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123762, 'Stehag', 'Stehag', 'Stehag', 55.9018800, 13.3957700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123763, 'Stavsnäs', 'Stavsnaes', 'Stavsnas,Stavsnäs', 59.2833300, 18.6833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123764, 'Stångby', 'Stangby', 'Stangby,Stångby', 55.7503000, 13.1979700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123765, 'Stallarholmen', 'Stallarholmen', 'Stallarholmen', 59.3666700, 17.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123766, 'Staffanstorp', 'Staffanstorp', 'Stafanstorp,Stafanstorpas,stfnstwl,Стафансторп,ستفنستول', 55.6427700, 13.2063800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123767, 'Gamla Stan', 'Gamla Stan', 'Gamla Stan,Gamla stan,Old Town,Staden,Tukholman vanha kaupunki,Tukholman vanhakaupunki', 59.3262700, 18.0725100, 'SE', '2016-10-21', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123768, 'Sösdala', 'Soesdala', 'Soesdala,Sosdala,Sösdala,Søsdala', 56.0399200, 13.6781100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123769, 'Sorsele', 'Sorsele', 'Sorsele,Sorshele,Suarsa,Соршеле', 65.5348400, 17.5370200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123770, 'Sörforsa', 'Soerforsa', 'Soerforsa,Sorforsa,Sörforsa,Sørforsa', 61.7333300, 16.9833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123771, 'Söråker', 'Soeraker', 'Soeraker,Soraker,Söråker,Søråker', 62.5056100, 17.5103200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123772, 'Sölvesborg', 'Soelvesborg', 'S''olvesbori,Selvesborg,Sjol''vesborg,Soelvesborg,Solvesborg,Sölvesborg,Sølvesborg,se er wo si bao,swlwsbwrh,Селвесборг,Сьолвесбори,Сёльвесборг,سولوسبوره,瑟爾沃斯堡', 56.0520500, 14.5752500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123773, 'Solna', 'Solna', 'Sol''na,Сольна', 59.3600400, 18.0008600, 'SE', '2014-09-09', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123774, 'Sollentuna', 'Sollentuna', '', 59.4280400, 17.9509300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123775, 'Sollefteå', 'Solleftea', 'Solefteo,Solleftea,Sollefteo,Sollefteå,swlftyw,Солефтео,Соллефтео,سولفتئو', 63.1666700, 17.2666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123776, 'Sollebrunn', 'Sollebrunn', 'Sollebrunn', 58.1166700, 12.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123777, 'Södra Vi', 'Soedra Vi', 'Sodra Vi,Soedra Vi,Södra Vi,Sødra Vi', 57.7399300, 15.7939100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123778, 'Södra Sandby', 'Sodra Sandby', 'Sodra Sandby,Soedra Sandby,Södra Sandby,Sødra Sandby', 56.5666700, 16.6166700, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123779, 'Södra Sandby', 'Soedra Sandby', 'Sodra Sandby,Soedra Sandby,Södra Sandby,Sødra Sandby', 55.7167700, 13.3465900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123780, 'Södertälje', 'Soedertaelje', 'Gorad Sjodehrtehl''e,JSO,S''odertale,S''odertele,S''odertelie,Sedertel''e,Sedertele,Sedertelje,Siodertelje,Sioderteljė,Sjodertel''e,Soedertaelje,Södertälje,Telga australis,XEZ,nan tai li ye,sederuterie,sex de xr telye,soedeleutellie,swdrtalya,swdtlya,Горад Сёдэртэлье,Седертельє,Седертелје,Седертеље,Сьодертале,Сьодертеле,Сьодертелие,Сёдертелье,سودتلیا,سودرتاليا,سودرتالیا,سودرتالیے,เซอเดอร์เตลเย,სედერტელიე,セーデルテリエ,南泰利耶,쇠데르텔리에', 59.1955400, 17.6252500, 'SE', '2017-07-08', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123781, 'Södermalm', 'Soedermalm', 'Katarina-Sofia,Maria gamla stan,Maria-Gamlastan,Sodermalm,Soeder,Soedermalm,Sofia gamla stan,Söder,Södermalm,Sødermalm', 59.3127800, 18.0757700, 'SE', '2016-11-03', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123782, 'Söderköping', 'Soederkoeping', 'S''odersh''oping,Sjoderchjoping,Soderkoping,Soederkoeping,Söderköping,Søderkøping,nan xue ping,swdrshwpyng,Сьодершьопинг,Сёдерчёпинг,سودرشوپینگ,南雪平', 58.4805700, 16.3222100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123783, 'Söderhamn', 'Soederhamn', 'S''oderkhamn,SOO,Sederkhamn,Sioderhamnas,Sjoderkhamn,Soderhamn,Soederhamn,Söderhamn,Søderhamn,se de gang,soedeleuham,Седерхамн,Сьодерхамн,Сёдерхамн,瑟德港,쇠데르함', 61.3037300, 17.0592100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123784, 'Söderfors', 'Soderfors', 'Soderfors,Soederfors,Söderfors,Søderfors', 64.8166700, 18.0500000, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123785, 'Söderfors', 'Soederfors', 'Soderfors,Soederfors,Söderfors,Søderfors', 60.3833300, 17.2333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123786, 'Smygehamn', 'Smygehamn', 'Smygehamn', 55.3433700, 13.3698900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123787, 'Smögen', 'Smoegen', 'Sm''ogen,Smoegen,Smogen,Smögen,Smøgen,Смьоген', 58.3559300, 11.2241100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123788, 'Smedjebacken', 'Smedjebacken', 'Smedebaken,Смедебакен,سمدیه‌بکن', 60.1418100, 15.4141600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123789, 'Smedby', 'Smedby', '', 60.7000000, 15.0500000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123790, 'Smedby', 'Smedby', 'Smedby', 56.6741300, 16.2432000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123791, 'Smålandsstenar', 'Smalandsstenar', 'Smalandsstenar,Smålandsstenar', 57.1624100, 13.4121200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123792, 'Slottsbron', 'Slottsbron', 'Slottsbron,Solttsbron', 59.3227000, 13.1026800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123793, 'Skutskär', 'Skutskaer', 'Skutsher,Stutskar,Stutskär,skwchkhwarh,Скутшер,سکوچخوآره', 60.6250700, 17.4155200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123794, 'Skurup', 'Skurup', 'Skjurup,skrwp,Скюруп,سکروپ', 55.4783900, 13.5018600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123795, 'Skultuna', 'Skultuna', '', 59.7166700, 16.4166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123796, 'Skultorp', 'Skultorp', 'Skultorp', 58.3500000, 13.8333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123797, 'Skrea', 'Skrea', 'Skrea', 56.8833300, 12.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123798, 'Skövde', 'Skoevde', 'KVB,Schedvia,Sh''ovde,Shevde,Shjovde,Siovde,Skoevde,Skofde,Skovd,Skovde,Sköfde,Skövd,Skövde,Skøvde,kwdh,she fu de,shevde,syebeude,Šiovdė,Шевде,Шьовде,Шёвде,سکاووڈے,کوده,შევდე,舍夫德,셰브데', 58.3911800, 13.8450600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123799, 'Skottsund', 'Skottsund', 'Skottsund', 62.2905600, 17.3869400, 'SE', '2014-10-09', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123800, 'Sköllersta', 'Skoellersta', 'Skoellersta,Skollersta,Sköllersta,Skøllersta', 59.1373800, 15.3394000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123801, 'Skogstorp', 'Skogstorp', 'Skogstorp', 59.3247200, 16.4828400, 'SE', '2014-09-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123802, 'Skoghall', 'Skoghall', 'Skoghalis,Skogkhal,Skugkhal,skwghl,Скогхал,Скугхал,سکوگهل', 59.3232400, 13.4655200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123803, 'Skivarp', 'Skivarp', 'Skivarp', 55.4166700, 13.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123804, 'Skinnskatteberg', 'Skinnskatteberg', '', 59.8302800, 15.6933700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123805, 'Skillingaryd', 'Skillingaryd', 'Skillingaryd', 57.4304400, 14.0938300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123806, 'Skepplanda', 'Skepplanda', 'Skepplanda', 57.9833300, 12.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123807, 'Skegrie', 'Skegrie', 'Skegrie,Skregie', 55.4063300, 13.0769300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123808, 'Skattkärr', 'Skattkaerr', 'Skattkarr,Skattkärr', 59.4120800, 13.6707800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123809, 'Skärhamn', 'Skaerhamn', '', 57.9866500, 11.5574200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123810, 'Skåre', 'Skare', 'Skare,Skarelage,Skåre,Skåreläge', 55.3833300, 13.0500000, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123811, 'Skåre', 'Skare', 'Skare,Skåre', 59.4333300, 13.4333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123812, 'Skärblacka', 'Skaerblacka', 'Skarblacka,Skärblacka', 58.5666700, 15.9000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123813, 'Skara', 'Skara', 'Scara,Skara,si ka la,skwra,Скара,سکورا,斯卡拉', 58.3865900, 13.4383600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123814, 'Skänninge', 'Skanninge', 'Skanninge,Skenninge,Skänninge', 59.9333300, 18.4833300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123815, 'Skänninge', 'Skaenninge', 'Sheninge,Skanninge,Skänninge,Шенинге', 58.3942700, 15.0865900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123816, 'Sjuntorp', 'Sjuntorp', 'Sjuntorp', 58.2000000, 12.2166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123817, 'Sjömarken', 'Sjomarken', 'Sjoemarken,Sjomarken,Sjömarken,Sjømarken', 57.7153300, 12.8349500, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123818, 'Sjöbo', 'Sjoebo', 'Sh''obu,Sjobo,Sjoebo,Sjöbo,Sjøbo,kkhbw,Шьобу,کخبو', 55.6313500, 13.7062200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123819, 'Simrishamn', 'Simrishamn', 'Cimbrishamn,Cimbrorum Portus,Cimbrorum portus,Gorad Simryskhamn,Simrishamn,Simrishavn,Simriskhamn,shimurisuhamun,symyryshmn,Горад Сімрысхамн,Симрисхамн,سیمیریسهمن,シムリスハムン', 55.5565300, 14.3503700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123820, 'Siljansnäs', 'Siljansnaes', 'Siljansnas,Siljansnäs', 60.7833300, 14.8500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123821, 'Sigtuna', 'Sigtuna', 'Gorad Sigtuna,Sigtjuna,Sigtuna,Sigtuna jaras,Sigtuna járás,Sigtunae,Sinktouna,sigeutuna,syghtwna,sygtwna,xi ge di na,Σιγκτούνα,Горад Сігтуна,Сигтунæ,Сигтуна,Сигтюна,سيغتونا,سیگتونا,სიგტუნა,ሲግቱና,錫格蒂納,시그투나', 59.6173100, 17.7236100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123822, 'Sibbhult', 'Sibbhult', 'Sibbhult', 56.2666700, 14.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123823, 'Segeltorp', 'Segeltorp', '', 59.2759700, 17.9307200, 'SE', '2012-08-13', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123824, 'Sävsjö', 'Saevsjoe', 'Sevsh''o,swkhw,Севшьо,سوخو', 57.4032700, 14.6624400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123825, 'Sävja', 'Saevja', '', 59.8187200, 17.6995800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123826, 'Sätofta', 'Satofta', 'Satofta,Sätofta', 55.9166700, 13.5500000, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123827, 'Sätila', 'Saetila', '', 57.5417200, 12.4342900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123828, 'Säter', 'Saeter', 'Satar,Seter,Сетер', 60.3477800, 15.7505100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123829, 'Särö', 'Saro', 'Saro,Särö', 57.5057700, 11.9321000, 'SE', '2011-11-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123830, 'Sandviken', 'Sandviken', 'Sandviken,Sandviken i Sverige,Sandvikenas,Santviken,sandeubiken,sandwykn,sang de wei ken,Σάντβικεν,Сандвикен,Сандвікен,ساندویکن,სანდვიკენი,桑德維肯,산드비켄', 60.6166700, 16.7666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123831, 'Sandarne', 'Sandarne', 'Sandarne', 61.2589300, 17.1528400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123832, 'Sandared', 'Sandared', '', 57.7099200, 12.7923800, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123833, 'Saltsjöbaden', 'Saltsjoebaden', 'Sal''tshjobaden,Saltsh''obaden,Saltsjobaden,Saltsjobadenas,Saltsjoebaden,Saltsjöbaden,Saltsjøbaden,shao shi ba dun,sltshwbdn,Салтшьобаден,Сальтшёбаден,سلتشوبدن,稍士巴頓', 59.2833300, 18.3000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123834, 'Sålanda', 'Salanda', '', 57.9833300, 12.2166700, 'SE', '2015-03-26', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123835, 'Sala', 'Sala', 'Sala,XYX', 59.9199300, 16.6065500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123836, 'Säffle', 'Saeffle', 'Sefle,sefure,sflh,Сефле,سففلے,سفله,ᓴᕝᓕ,セフレ', 59.1322900, 12.9288800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123837, 'Rydsgård', 'Rydsgard', 'Rydsgard,Rydsgård', 55.4728500, 13.5882900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123838, 'Rydebäck', 'Rydebaeck', 'Rydeback,Rydebäck', 55.9666700, 12.7666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123839, 'Rydaholm', 'Rydaholm', 'Rydaholm,Smalands Rydaholm,Smålands Rydaholm', 56.9838800, 14.3084900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123840, 'Ryd', 'Ryd', '', 58.6666700, 15.0833300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123841, 'Ryd', 'Ryd', 'Ryd', 56.4666700, 14.6833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123842, 'Rottne', 'Rottne', 'Rottne', 57.0166700, 14.9000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123843, 'Rosersberg', 'Rosersberg', 'Rosersberg', 59.5833300, 17.8833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123844, 'Rönninge', 'Ronninge', 'Roenninge,Ronninge,Rönninge,Rønninge', 59.2000000, 17.7333300, 'SE', '2014-04-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123845, 'Ronneby', 'Ronneby', 'RNB,Ronebi,Ronebis,Ronebju,Ronnebju,Ronneby,long ne bi,rwnybh,Ронеби,Ронебю,Роннебю,رونیبه,龙讷比', 56.2099900, 15.2760200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123846, 'Rönnäng', 'Roennaeng', 'Ronnang,Rönnäng', 57.9333300, 11.5833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123847, 'Romme', 'Romme', '', 60.4333300, 15.5000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123848, 'Rödeby', 'Roedeby', 'Rodeby,Roedeby,Rödeby,Rødeby', 56.2607800, 15.6214300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123849, 'Rinkabyholm', 'Rinkabyholm', 'Rinkabyholm', 56.6497200, 16.2666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123850, 'Rindö', 'Rindoe', 'Rindo,Rindoe,Rindö,Rindø', 59.3968800, 18.3943400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123851, 'Rimforsa', 'Rimforsa', '', 58.1362400, 15.6865000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123852, 'Rimbo', 'Rimbo', 'Rimbo,Rimbu,Римбу', 59.7500000, 18.3666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123853, 'Resarö', 'Resaroe', 'Resaro,Resaroe,Resarö,Resarø', 59.4291000, 18.3338600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123854, 'Reftele', 'Reftele', 'Reftele', 57.1746700, 13.5949800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123855, 'Rävlanda', 'Raevlanda', 'Ravlanda,Rävlanda', 57.6533800, 12.4979100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123856, 'Rättvik', 'Raettvik', '', 60.8863200, 15.1178700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123857, 'Råtorp', 'Ratorp', '', 59.4019700, 13.4914400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123858, 'Råsunda', 'Rasunda', '', 59.3658800, 17.9956900, 'SE', '2015-10-29', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123859, 'Ramnäs', 'Ramnaes', 'Ramnas,Ramnäs', 59.7666700, 16.2000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123860, 'Perstorp', 'Perstorp', '', 56.1382900, 13.3947600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123861, 'Pershagen', 'Pershagen', 'Pershagen', 59.1549400, 17.6534000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123862, 'Påskallavik', 'Paskallavik', 'Paskallavik,Påskallavik', 57.1666700, 16.4500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123863, 'Partille', 'Partille', '', 57.7395000, 12.1064200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123864, 'Pålsboda', 'Palsboda', 'Palsboda,Pålsboda', 59.0656500, 15.3374700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123865, 'Påarp', 'Paarp', 'Paarp,Påarp', 56.0333300, 12.8166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123866, 'Oxie', 'Oxie', 'Oxie,awksy,اوکسی', 55.5401400, 13.0960500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123867, 'Oxelösund', 'Oxeloesund', 'Gorad Okseljosund,Oksel''osund,Okselesund,Oxeloesund,Oxelosund,Oxelösund,Oxeløsund,Ukseljosund,Горад Окселёсунд,Окселесунд,Оксельосунд,Укселёсунд,اوکسه‌لوسوند', 58.6705700, 17.1015200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123868, 'Överum', 'OEverum', 'OEverum,Overum,Överum,Øverum', 57.9885600, 16.3139000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123869, 'Östra Ljungby', 'OEstra Ljungby', 'OEstra Ljungby,Ostra Ljungby,Östra Ljungby,Østra Ljungby', 56.1960100, 13.0919900, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123870, 'Östhammar', 'OEsthammar', 'Jostkhamar,OEsthammar,Osthammar,Östhammar,Østhammar,Йостхамар', 60.2590900, 18.3740800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123871, 'Östervåla', 'OEstervala', 'OEstervala,Ostervala,Östervåla,Østervåla', 60.1833300, 17.1833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123872, 'Östersund', 'OEstersund', 'Ehstersund,Estersount,Estersund,Estesunda,Estesundas,Estešunda,Estešundas,Gorad Ehstehrsund,Jostershund,OEstersund,OSD,Ostersund,awstrshwnd,awstrswnd,awstshwnd,e si te song de,esuterusundo,oeseuteleusundeu,Östersund,Østersund,Έστερσουντ,Горад Эстэрсунд,Естерсунд,Йостершунд,Эстерсунд,إوسترسوند,اوسترشوند,اوستشوند,اوسٹرسنڈ,ესტერსუნდი,エステルスンド,厄斯特松德,외스테르순드', 63.1792000, 14.6356600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123873, 'Östermalm', 'OEstermalm', 'Ehstermal''m,OEstermalm,Ostermalm,Stockholm kerueletei,Stockholm kerületei,Östermalm,Østermalm,Эстермальм', 59.3387900, 18.0848700, 'SE', '2010-08-28', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123874, 'Österbymo', 'OEsterbymo', 'OEsterbymo,Osterbymo,Österbymo,Østerbymo', 57.8246500, 15.2735700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123875, 'Österbybruk', 'OEsterbybruk', 'OEsterbybruk,Osterbybruk,Österbybruk,Østerbybruk', 60.2000000, 17.9000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123876, 'Ösmo', 'OEsmo', 'OEsmo,Osmo,Ösmo,Øsmo', 58.9833300, 17.9000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123877, 'Oskarström', 'Oskarstroem', 'Oskarsstrom,Oskarsström,Oskarstroem,Oskarstrom,Oskarström,Oskarstrøm', 56.8000000, 12.9666700, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123878, 'Oskarshamn', 'Oskarshamn', 'Doederhultsvik,Döderhultsvik,OSK,Oskarsgamn,Oskarshamn,Oskarshamnas,Oskarshkhamn,Oskarskhamn,Oskaršhamnas,ao si ka gang,awskrshhm,Оскарсгамн,Оскарсхамн,Оскаршхамн,اوسکرشهم,奧斯卡港', 57.2645500, 16.4483700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123879, 'Osby', 'Osby', 'Osbju,awzbh,Осбю,اوزبه', 56.3816500, 13.9936400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123880, 'Örsundsbro', 'OErsundsbro', 'OErsundsbro,Orsundsbro,Orundsbro,Örsundsbro,Ørsundsbro', 59.7333300, 17.3000000, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123881, 'Orsa', 'Orsa', 'Orsa,Orsha,awrsha,Орса,Орша,اورشا', 61.1203400, 14.6155000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123882, 'Örnsköldsvik', 'OErnskoeldsvik', 'Ehrnshjol''dsvik,Ernseldsvika,Ernshel''dsvik,Ernsheldsvik,Ernsioldsvikas,Ernšioldsvikas,Gorad Ehrnshehl''dsvik,Jornsh''oldsvik,OER,OErnskoeldsvik,OEvik,Ornskoldsvik,Ornskolntsvik,anshldswyk,awrnshwldsfyk,en she er ci wei ke,erunsherutsubiku,oeleunsyelseubikeu,xeirncheils wik,Örnsköldsvik,Övik,Ørnskøldsvik,Ērnšeldsvīka,Όρνσκολντσβικ,Горад Эрншэльдсвік,Ерншелдсвик,Ерншельдсвік,Йорншьолдсвик,Орнсколдсвик,Эрншёльдсвик,أورنشولدسفيك,انشلدسویک,เอิร์นเชิลส์วีก,ერნშელდსვიკი,エルンシェルツビク,恩舍尔兹维克,외른셸스비크', 63.2909100, 18.7152500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123883, 'Ornäs', 'Ornaes', '', 60.5094400, 15.5412800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123884, 'Örkelljunga', 'OErkelljunga', 'Jorkeljunga,OErkelljunga,Orkelljunga,Örkelljunga,Ørkelljunga,Йоркелюнга', 56.2833800, 13.2777300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123885, 'Öregrund', 'OEregrund', 'Joregrund,OEregrund,Oregrund,Öregrund,Øregrund,Йорегрунд', 60.3333300, 18.4333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123886, 'Örebro', 'OErebro', 'Ehrebru,Erebro,Erebru,Erebrū,Erempro,Gorad Ehrehbru,Jorebru,OErebro,OErebro kommuna,OErebro  Isvec,ORB,Orebro,Orebrogia,arybrw,awrbrw,awrybrw,e lei bu lu,erebre,ereburu,oelebeulo,xex re bru,Örebro,Örebro kommuna,Örebro  İsveç,Ørebro,Έρεμπρο,Горад Эрэбру,Еребро,Еребру,Йоребру,Эребру,ארברו,ערעברו,أوربرو,اریبرو,اوربرو,اوریبرو,เออเรบรู,ერებრე,エレブルー,厄勒布鲁,외레브로', 59.2741200, 15.2066000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123887, 'Örbyhus', 'OErbyhus', 'OErbyhus,Orbyhus,Örbyhus,Ørbyhus', 60.2240700, 17.7013800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123888, 'Önnestad', 'OEnnestad', 'OEnnestad,Onnestad,Önnestad,Ønnestad', 56.0574700, 14.0223300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123889, 'Olstorp', 'Olstorp', '', 58.8166700, 16.6333300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123890, 'Olofström', 'Olofstroem', 'Olofstroem,Olofstrom,Olofström,Olofstrøm,Ulofstr''om,Ulufstrjom,awlwfstrwm,Улофстрьом,Улуфстрём,اولوفستروم', 56.2773000, 14.5340200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123891, 'Olofstorp', 'Olofstorp', '', 58.2500000, 14.0000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123892, 'Olofstorp', 'Olofstorp', '', 57.8044400, 12.1713100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123893, 'Öjersjö', 'OEjersjoe', 'OEjersjoe,Ojersjo,Öjersjö,Øjersjø', 57.6988200, 12.1344800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123894, 'Ödsmål', 'OEdsmal', 'OEdsmal,Odmals socken,Odsmal,Ödmåls socken,Ödsmål,Ødsmål', 58.1000000, 11.8500000, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123895, 'Ödeshög', 'OEdeshoeg', 'Jodeskh''og,OEdeshoeg,Odeshog,Ödeshög,Ødeshøg,Йодесхьог', 58.2294900, 14.6529400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123896, 'Odensjö', 'Odensjoe', 'Odensjo,Odensjoe,Odensjö,Odensjø', 57.7166700, 14.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123897, 'Odensbacken', 'Odensbacken', 'Odensbacken', 59.1666700, 15.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123898, 'Ödåkra', 'OEdakra', 'OEdakra,Odakra,Ödåkra,Ødåkra', 56.1041200, 12.7477000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123899, 'Öckerö', 'OEckeroe', 'OEckeroe,Ockero,Öckerö,Øckerø', 57.7081400, 11.6558500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123900, 'Ockelbo', 'Ockelbo', 'Okelbu,Окелбу', 60.8912000, 16.7184600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123901, 'Nynäshamn', 'Nynaeshamn', 'Nineshamnas,Nineskhamn,Njuneskhamn,Nynaeshamn,Nynashamm,Nynäshamm,Nynäshamn,ni nai si gang,nyns hamn,nynshm,Нинесхамн,Нюнесхамн,نينس هامن,نینسهم,尼奈斯港', 58.9033700, 17.9479300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123902, 'Nykvarn', 'Nykvarn', '', 59.8000000, 18.3000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123903, 'Nykvarn', 'Nykvarn', '', 59.1771800, 17.4323000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123904, 'Nyköping', 'Nykoeping', 'Gorad Njuchehping,Niceping,Nicheping,Nisiopingas,Nišiopingas,Njuchjoping,Njush''oping,Nykoeping,Nykoping,Nyköping,Nykøping,ni xue ping,nwisyeping,nyshwbng,nyshwpyng,Горад Нючэпінг,Ничепінг,Нићепинг,Нючёпинг,Нюшьопинг,نیشوبنگ,نیشوپینگ,ნიუჩეპინგი,尼雪平,뉘셰핑', 58.7530000, 17.0078800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123905, 'Nyhammar', 'Nyhammar', 'Nyhammar', 60.2833300, 14.9666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123906, 'Nybro', 'Nybro', 'Nibro,Nibru,Njubru,nybrw,Нибро,Нюбру,نیبرو', 56.7446100, 15.9071400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123907, 'Nossebro', 'Nossebro', '', 58.1880800, 12.7159900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123908, 'Norsjö', 'Norsjoe', 'Naarene,Norsh''o,Norsjo,Norsjoe,Norsjö,Norsjø,Nurshe,Nåarene,Норшьо,Нурше', 64.9120600, 19.4815300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123909, 'Norrtälje', 'Norrtaelje', 'Norrtaeljen kunta,Norrtel''e,Norrtelge,Norrtelje,Norrtäljen kunta,Nortele,Nortelje,Norteljė,Telga borealis,nuo er tai li ye,nwrtlyh,Норртелье,Норртельє,Нортеле,Нортеље,نورتليه,نورتلیه,诺尔泰利耶', 59.7579900, 18.7049600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123910, 'Norrköping', 'Norrkoeping', 'Gorad Norchehping,NRK,Norceping,Norcopia,Norrcheping,Norrchjoping,Norrkoeping,Norrkoping,Norrköping,Norrkøping,Norrshjopin,Norsepinga,Norsh''oping,Norsheping,Norsiopingas,Noršiopingas,Noršēpinga,bei xue ping,noleusyeping,noshopingu,nwrkwpng,nwrshwbyngh,nwrshwpyng,nwrspyng,nxr chex ping,Горад Норчэпінг,Норрчепінг,Норрчёпинг,Норршёпин,Норшепинг,Норшьопинг,Норћепинг,נארשעפינג,נורשפינג,نورشوبينغ,نورشوپینگ,نورکوپنگ,นอร์เชอปิง,ნორჩეპინგი,ノーショーピング,北雪平,노르셰핑', 58.5941900, 16.1826000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123911, 'Norra Åsum', 'Norra Asum', 'Norra Asum,Norra Åsum', 55.9833300, 14.1500000, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123912, 'Nordmaling', 'Nordmaling', 'Nordmaling,Нордмалинг', 63.5685200, 19.5024400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123913, 'Norberg', 'Norberg', 'Norbergby,Norberi,Норбери', 60.0650500, 15.9236600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123914, 'Nora', 'Nora', '', 59.5192600, 15.0397900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123915, 'Nolby', 'Nolby', '', 62.2875000, 17.3691700, 'SE', '2014-10-09', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123916, 'Njurundabommen', 'Njurundabommen', 'Njurunda', 62.2633900, 17.3835400, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123917, 'Nättraby', 'Naettraby', 'Nattraby,Nättraby', 56.2000000, 15.5166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123918, 'Näsum', 'Naesum', 'Nasum,Näsum', 56.1769300, 14.4970600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123919, 'Nässjö', 'Naessjoe', 'Neshe,Nesse,Nessh''o,Nesshjo,Nesšė,nai she,nkkhw,Несшьо,Несшё,Неше,نکخو,奈舍', 57.6530700, 14.6967600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123920, 'Nacka', 'Nacka', 'Nak,Naka,Нака', 59.3105300, 18.1637200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123921, 'Myggenäs', 'Myggenaes', '', 58.0617600, 11.7493600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123922, 'Munkfors', 'Munkfors', '', 59.8385600, 13.5436100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123923, 'Munkedal', 'Munkedal', 'Munkedal,Мункедал', 58.4663400, 11.6734500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123924, 'Munka-Ljungby', 'Munka-Ljungby', 'Munka-Ljungby', 56.2500000, 12.9666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123925, 'Mullsjö', 'Mullsjoe', 'Mullsjo,Mullsjoe,Mullsjö,Mullsjø', 57.9171000, 13.8783100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123926, 'Motala', 'Motala', 'Commune de Motala,Motala,Mutala,Mūtala,mwtla,mwtlh,Мотала,Мутала,מוטלה,موتلا,მუტალა', 58.5370600, 15.0364900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123927, 'Mörtnäs', 'Mortnas', 'Mortnas,Mörtnäs', 59.3166700, 18.4500000, 'SE', '2012-05-05', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123928, 'Mörrum', 'Moerrum', 'Moerrum,Mörrum', 56.1928100, 14.7473900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123929, 'Morgongåva', 'Morgongava', 'Morgongava,Morgongåva', 59.9339500, 16.9635300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123930, 'Mörbylånga', 'Moerbylanga', 'Moerbylanga,Morbylanga,Mörbylånga,Mørbylånga', 56.5248000, 16.3787700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123931, 'Mörarp', 'Moerarp', 'Moerarp,Morarp,Mörarp,Mørarp', 56.0574900, 12.8801800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123932, 'Mora', 'Mora', '', 61.0070400, 14.5431600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123933, 'Mönsterås', 'Moensteras', 'Moensteras,Monsteras,Mönsterås,Mønsterås', 57.0413400, 16.4446300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123934, 'Mölnlycke', 'Moelnlycke', 'M''olnljuke,Mel''nlike,Melnlike,Miolnlike,Miolnliuke,Miolnliukė,Miolnlīkė,Mjol''nljukke,Moelnlycke,Molnlica,Molnlycke,Mölnlycke,Mølnlycke,Mēlnlike,menrikke,moelleunlwike,mwlnlykkh,Μέλνλικε,Мелнлике,Мельнлике,Мьолнлюке,Мёльнлюкке,מעלנליקע,مولنلیککه,ሜልንልኬ,ᒧᓪᓐᓕᑭ/ Mölnlycke,メンリッケ,묄른뤼케', 57.6589300, 12.1179200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123935, 'Mölndal', 'Moelndal', 'M''olndal,Melndal,Melndala,Miolndalas,Mjol''ndal'',Mjol''ndal''skaja kommuna,Moelndal,Molndal,Mölndal,Mølndal,Mēlndala,Мелндал,Мьолндал,Мёльндаль,Мёльндальская коммуна,ሜልንዳል,ᒧᓪᓐᑕᓪ/Mölndal', 57.6554000, 12.0137800, 'SE', '2012-05-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123936, 'Mölnbo', 'Moelnbo', 'Moelnbo,Molnbo,Mölnbo,Mølnbo', 59.0500000, 17.4166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123937, 'Mölltorp', 'Moelltorp', 'Moelltorp,Molltorp,Mölltorp,Mølltorp', 58.5000000, 14.4000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123938, 'Molkom', 'Molkom', 'Molkom', 59.6005700, 13.7211500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123939, 'Moheda', 'Moheda', 'Moheda', 57.0000000, 14.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123940, 'Mockfjärd', 'Mockfjaerd', 'Mockfjard,Mockfjards Kapell,Mockfjärd,Mockfjärds Kapell', 60.5000000, 14.9666700, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123941, 'Mjölby', 'Mjoelby', 'M''jol''bju,M''olbju,Miolbis,Mjelbi,Mjoelby,Mjolby,Mjölby,Mjølby,mywnbh,Мьолбю,Мьёльбю,Мјелби,میونبه', 58.3259500, 15.1236500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123942, 'Mjällby', 'Mjallby', '', 56.6833300, 12.7666700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123943, 'Mjällby', 'Mjaellby', 'Mjallby,Mjällby', 56.0500000, 14.6833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123944, 'Mellerud', 'Mellerud', 'Melerud,Mellerud,Мелеруд,Меллеруд', 58.6997900, 12.4531200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123945, 'Mellbystrand', 'Mellbystrand', 'Mellbystrand', 56.4856100, 12.9395800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123946, 'Matfors', 'Matfors', 'Matfors', 62.3486400, 17.0317300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123947, 'Märsta', 'Maersta', 'Marsta,Mershha,Mersta,Meršta,Märsta,mai shen ta,mashta,Мерста,Мерща,ماشتا,迈什塔', 59.6215700, 17.8547600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123948, 'Markaryd', 'Markaryd', 'Markarjud,Маркарюд', 56.4613500, 13.5964400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123949, 'Mariestad', 'Mariestad', 'Mariaestadium,Mariestad,Mariestadas,Marijestad,ma li si ta de,mrystad,Мариестад,Маријестад,Марієстад,مریستاد,瑪麗斯塔德', 58.7097100, 13.8236700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123950, 'Marieholm', 'Marieholm', 'Marieholm,Marieholmsbruk', 57.3833300, 13.8500000, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123951, 'Marieholm', 'Marieholm', 'Marieholm', 55.8666700, 13.1500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123952, 'Mariefred', 'Mariefred', 'Mariefred,Marijefred,ma li fei lai de,Мариефред,瑪麗費萊德', 59.2596300, 17.2230000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123953, 'Mariannelund', 'Mariannelund', 'Mariannelund', 57.6166700, 15.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123954, 'Mantorp', 'Mantorp', 'Mantorp', 58.3500000, 15.2833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123955, 'Malung', 'Malung', 'Malung,malwng,malwnk,Малунг,مالونك,مالونگ', 60.6832900, 13.7154200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123956, 'Malmslätt', 'Malmslaett', 'Malmen', 58.4110200, 15.5164700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123957, 'Malmö', 'Malmoe', 'MMA,Mal''mjo,Malm''o,Malme,Malmey,Malmo,Malmoe,Malmogia,Malmö,Malmø,Málmey,ma er mo,marume,Малме,Малмьо,Мальмё,מאלמה,マルメ,马尔莫,马尔默', 55.6058700, 13.0007300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123958, 'Malmköping', 'Malmkoeping', 'Malmkoeping,Malmkoping,Malmköping,Malmkøping', 59.1333300, 16.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123959, 'Malmbäck', 'Malmbaeck', 'Malmback,Malmbäck', 57.5766700, 14.4617000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123960, 'Målilla', 'Malilla', '', 57.3877300, 15.8067500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123961, 'Malå', 'Mala', '', 65.1850100, 18.7424300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123962, 'Lysekil', 'Lysekil', 'Ljuseshil,Lysekil,lysshyl,Люсешил,لیسشیل', 58.2742900, 11.4357600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123963, 'Lycksele', 'Lycksele', 'LYC,Liksele,Ljuksele,Lyoksele,lu ke se lei,lyksylh,Ликселе,Люкселе,لیکسیله,吕克瑟勒', 64.5953700, 18.6735100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123964, 'Lund', 'Lund', 'Gorad Lund,Lount,Lund,Lunda,Lundas,Lundur,long de,lund,lunda,lundeu,lundi,lunt,lwnd,rundo,Λουντ,Горад Лунд,Лунд,Лөнд,لنڈ,لوند,لونڈ,লুন্ড,லுண்ட்,ลุนด์,ლუნდი,ルンド,隆德,룬드', 55.7058400, 13.1932100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123965, 'Ludvika', 'Ludvika', 'Liudvika,Ludovica,Ludvika,Ludviki,lu de wei ka,lwdwykh,Лудвика,لودویکه,盧德維卡', 60.1495900, 15.1877600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123966, 'Lövstalöt', 'Loevstaloet', 'Loevstaloet,Lovstalot,Lövstalöt,Løvstaløt', 59.9574000, 17.5782600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123967, 'Lönsboda', 'Loensboda', 'Loensboda,Lonsboda,Lönsboda,Lønsboda', 56.4000000, 14.3166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123968, 'Lomma', 'Lomma', 'Loma,Lomma i Sverige,lwma,Лома,لوما', 55.6724400, 13.0684900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123969, 'Lödöse', 'Loedoese', 'L''od''ose,Ljodjose,Lodose,Loedoese,Lödöse,Lødøse,Льодьосе,Лёдёсе', 58.0299400, 12.1593400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123970, 'Löddeköpinge', 'Loeddekoepinge', 'Loddekopinge,Loeddekoepinge,Löddeköpinge,Løddekøpinge', 55.7666700, 13.0166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123971, 'Löberöd', 'Loeberoed', 'Loberod,Loeberoed,Löberöd,Løberød', 55.7761000, 13.5241400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123972, 'Ljusne', 'Ljusne', '', 61.2117000, 17.1279000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123973, 'Ljusdal', 'Ljusdal', 'Jusdal,Jusdal'',ywsdal,Юсдал,Юсдаль,يوسدال,یوسدال', 61.8288300, 16.0912600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123974, 'Ljungskile', 'Ljungskile', 'Jungshile,Jungsile,Jungšilė,Ljungskile,Юнгшиле', 58.2245200, 11.9201400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123975, 'Ljungsbro', 'Ljungsbro', 'Ljugsbro,Ljungsbro', 58.5166700, 15.5000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123976, 'Ljunghusen', 'Ljunghusen', 'Ljunghusen', 55.3979300, 12.9248600, 'SE', '2013-03-03', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123977, 'Ljungbyholm', 'Ljungbyholm', 'Ljungbyholm', 56.6333300, 16.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123978, 'Ljungbyhed', 'Ljungbyhed', 'Ljungbyhed', 56.0743700, 13.2401000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123979, 'Ljungby', 'Ljungby', 'Jungbi,Jungbis,Jungbju,lywnbh,yong bi,Јунгби,Юнгбю,لئونبه,永比', 56.8332400, 13.9408200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123980, 'Lit', 'Lit', 'Lit', 63.3202900, 14.8459400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123981, 'Linköping', 'Linkoeping', 'Gorad Linchehping,LPI,Lin''kopin''nk,Linceping,Lincheping,Linchjoping,Lincopia,Linkoeping,Linkoping,Linköping,Linkøping,Linsepinga,Linsh''oping,Linsheping,Linsiopingas,Linšiopingas,Linšēpinga,lin chex ping,lin xue ping,linsyeping,lnkwmng,lnshwpng,lynshwbyngh,lynshwpyng,rinshepingu,Λινκόπινγκ,Горад Лінчэпінг,Линчёпинг,Линшепинг,Линшьопинг,Линьшөпин,Линћепинг,Лінчепінг,לינשעפינג,لنشوپنگ,لنکومنگ,لينشوبينغ,لینشوپینگ,ลินเชอปิง,ლინჩეპინგი,リンシェーピング,林雪平,린셰핑', 58.4108600, 15.6215700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123982, 'Linghem', 'Linghem', 'Linghem', 58.4333300, 15.7833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123983, 'Lindsdal', 'Lindsdal', 'Lindsdal', 56.7333300, 16.3000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123984, 'Lindome', 'Lindome', 'Lindome', 57.5666700, 12.0833300, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123985, 'Lindö', 'Lindoe', 'Lindo,Lindoe,Lindohall,Lindö,Lindöhall,Lindø', 58.6166700, 16.2500000, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123986, 'Lindholmen', 'Lindholmen', 'Lindholmen', 59.5833300, 18.1000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123987, 'Lindesberg', 'Lindesberg', 'Lindesberga,Lindesberi,lin de si bei li,lyndsby,Линдесбери,لیندسبی,林德斯貝里', 59.5920200, 15.2304000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123988, 'Limmared', 'Limmared', 'Limmared', 57.5359200, 13.3556600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123989, 'Lilla Edet', 'Lilla Edet', 'Lila Edet,Lilla Edet,Лила Едет', 58.1333300, 12.1333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123990, 'Lidköping', 'Lidkoeping', 'LDK,Lidceping,Lidchjoping,Lidecopia,Lidkoeping,Lidkoping,Lidköping,Lidkøping,Lidsh''oping,Lidsiopingas,Lidšiopingas,li de xue ping,lydshwpyng,Лидкопинг,Лидчёпинг,Лидшьопинг,Лидћепинг,لیدشوپینگ,ლიდჩეპინგი,利德雪平', 58.5051700, 13.1576500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123991, 'Lidingö', 'Lidingoe', 'Lidingo,Lidingo Villastad,Lidingoe,Lidingö,Lidingö Villastad,Lidingø', 59.3666700, 18.1333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123992, 'Lessebo', 'Lessebo', '', 56.7518500, 15.2696900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123993, 'Lerum', 'Lerum', '', 57.7705100, 12.2690400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123994, 'Lenhovda', 'Lenhovda', 'Lenhovda', 57.0000000, 15.2833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123995, 'Leksand', 'Leksand', 'Leksand,XXO,lksnd,rekusando,Лександ,لکسند,レクサンド', 60.7303000, 14.9999400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123996, 'Laxå', 'Laxa', 'Lakso,Лаксо', 58.9863000, 14.6190400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123997, 'Långvik', 'Langvik', 'Langvik,Långvik', 59.2458300, 18.5166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123998, 'Långshyttan', 'Langshyttan', 'Langshyttan,Långshyttan', 60.4523800, 16.0383100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(123999, 'Långsele', 'Langsele', 'Langsele,Långsele', 63.1833300, 17.0666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124000, 'Länghem', 'Laenghem', 'Langhem,Länghem', 57.6000000, 13.2333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124001, 'Landvetter', 'Landvetter', '', 57.6866500, 12.2116900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124002, 'Landskrona', 'Landskrona', 'Coronia,Gorad Landskruna,JLD,Landscrone,Landskrona,Landskruna,Landskrūna,lan si ke lu na,landskrwna,lanseukeulona,ranzukuruna,Горад Ландскруна,Ландскруна,لاندسکرونا,لانڈسکرونا,ランズクルーナ,兰斯克鲁纳,란스크로나', 55.8708000, 12.8301600, 'SE', '2017-06-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124003, 'Landsbro', 'Landsbro', 'Landsbro', 57.3666700, 14.9000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124004, 'Lammhult', 'Lammhult', 'Lamhult,Lammhult', 57.1666700, 14.5833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124005, 'Laholm', 'Laholm', 'Lacholmas,Lagaholmia,Laholmo,Lakhol''m,Lakholm,lhwlm,Лахолм,Лахольм,لاہولم,لهولم', 56.5120700, 13.0437100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124006, 'Lagan', 'Lagan', 'Lagan', 56.9166700, 13.9833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124007, 'Kvissleby', 'Kvissleby', 'Kvissle,Kvissleby,Kvitsle', 62.2936100, 17.3750000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124008, 'Kvidinge', 'Kvidinge', 'Kvidinge', 56.1338600, 13.0467800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124009, 'Kvicksund', 'Kvicksund', 'Kvicksund', 59.4509900, 16.3213100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124010, 'Kvänum', 'Kvaenum', 'Kvanum,Kvänum', 58.3000000, 13.1833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124011, 'Kungsör', 'Kungsoer', 'Kungs''or,Kungsoer,Kungsor,Kungsör,Kungsør,Rungsor,Rungsör,kwngzwr,Кунгсьор,کونگزور', 59.4224500, 16.0965600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124012, 'Kungsholmen', 'Kungsholmen', 'Kungsholmen', 59.3318300, 18.0411800, 'SE', '2016-10-14', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124013, 'Kungshamn', 'Kungshamn', '', 58.3630500, 11.2593800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124014, 'Kungsbacka', 'Kungsbacka', 'Kungsbacka Skene,Kungsbaka,Kungsbakka,kong si ba ka,kwngzbkka,Кунгсбака,Кунгсбакка,کونگزبککا,孔斯巴卡', 57.4871900, 12.0761200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124015, 'Kungsängen', 'Kungsaengen', 'Kungsengen,kwngsngn,Кунгсенген,کونگسنگن', 59.4785700, 17.7483400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124016, 'Kungälv', 'Kungaelv', 'Konghelle,Kungaelv,Kungahaella,Kungahälla,Kungehl''v,Kungelv,Kungelva,Kungelvas,Kunglev,Kungälv,kong ai er fu,kungaelpeu,kwnlw,Кунгелв,Кунглев,Кунгэльв,کونلو,კუნგელვი,孔艾尔夫,쿤갤프', 57.8709600, 11.9805400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124017, 'Kummelnäs', 'Kummelnas', 'Kummelnas,Kummelnäs', 59.3500000, 18.2833300, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124018, 'Kumla', 'Kumla', 'Kumla,kumla,kwmla,kwmlh,Кумла,كوملا,کومله,쿰라', 59.1277000, 15.1434100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124019, 'Krylbo', 'Krylbo', 'Krylbo,Kyrlbo', 60.1333300, 16.2166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124020, 'Krokom', 'Krokom', 'Krokum,Крокум', 63.3258900, 14.4488300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124021, 'Krokek', 'Krokek', 'Krokek', 58.6723100, 16.3674100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124022, 'Kristinehamn', 'Kristinehamn', 'Bro,Kristinehamn,Kristinehamnas,Kristinekhamn,XYN,ke li si di na gang,krystynh hamn,krystynhamn,Кристинехамн,كريستينه هامن,کریستینهامن,ክሪስቲነሃምን,克里斯蒂娜港', 59.3097800, 14.1080800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124023, 'Kristianstad', 'Kristianstad', 'Christianostadium,Christiansstad,Gorad Krystyjanstad,KID,Krishanstad,Krisianstad,Kristianstad,Kristianstadas,Kristijanstad,ke li si di an si ta de,keuliseutianseutadeu,khristeiyn s tad,krytmsth,kurishansutado,Горад Крыстыянстад,Кристианстад,Кристијанстад,Кришанстад,Крістіанстад,کریتمسته,คริสเตียนสตัด,კრისტიანსტადი,クリシャンスタード,克里斯蒂安斯塔德,크리스티안스타드', 56.0312900, 14.1524200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124024, 'Kristdala', 'Kristdala', 'Kristdala', 57.4007000, 16.2049600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124025, 'Kramfors', 'Kramfors', 'KRF,Kramfors,Kramforsh,kramfwsh,Крамфорш,کرامفوش', 62.9316100, 17.7764600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124026, 'Kopparmora', 'Kopparmora', 'Kopparmora', 59.3330600, 18.5830600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124027, 'Kopparberg', 'Kopparberg', 'Kopparberg Koping,Kopparberg Köping,Kopparbergs Koping,Kopparbergs Köping,Kopparsberg', 59.8759700, 14.9943600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124028, 'Köpmanholmen', 'Koepmanholmen', 'Koepmanholmen,Kopmanholmen,Kopmansholmen,Köpmanholmen,Köpmansholmen,Køpmanholmen', 63.1666700, 18.5666700, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124029, 'Köpingebro', 'Koepingebro', 'Koepingebro,Kopingebro,Köpingebro,Køpingebro', 55.4552600, 13.9345300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124030, 'Köping', 'Koeping', 'Koeping,Koping,Köping,Køping', 59.5140400, 15.9925500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124031, 'Kolsva', 'Kolsva', 'Kolsva', 59.6000000, 15.8333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124032, 'Kolbäck', 'Kolbaeck', 'Kolback,Kolbäck', 59.5651600, 16.2303700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124033, 'Kode', 'Kode', 'Kode', 57.9426300, 11.8505100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124034, 'Knivsta', 'Knivsta', 'Knivsta,knywsta,Книвста,کنیوستا', 59.7256400, 17.7875300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124035, 'Knislinge', 'Knislinge', 'Knislinge,Knisslinge', 56.1833300, 14.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124036, 'Knäred', 'Knaered', 'Knared,Knäred', 56.5186100, 13.3242300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124037, 'Klippan', 'Klippan', '', 56.1355900, 13.1308600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124038, 'Klintehamn', 'Klintehamn', 'Klintekhamn,Клинтехамн', 57.3866700, 18.2037100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124039, 'Klågerup', 'Klagerup', '', 55.5941600, 13.2457400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124040, 'Kista', 'Kista', 'Chista,Kista,siseuta,xi si ta,Киста,Чиста,希斯塔,시스타', 59.4031600, 17.9447900, 'SE', '2013-08-25', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124041, 'Kisa', 'Kisa', '', 57.9878100, 15.6330300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124042, 'Kinna', 'Kinna', 'Kina,Shina,Sina,shyna,Šina,Кина,Шина,شینا', 57.5072800, 12.6946300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124043, 'Kimstad', 'Kimstad', '', 58.5496700, 15.9629600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124044, 'Kilafors', 'Kilafors', 'Kilafors', 61.2333300, 16.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124045, 'Kil', 'Kil', 'Kil,XXN', 59.5023400, 13.3127700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124046, 'Kaxholmen', 'Kaxholmen', 'Kaxholmen', 57.8534500, 14.3045700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124047, 'Kävlinge', 'Kaevlinge', 'Shevlinge,shwlynyh,Шевлинге,شولینیه', 55.7918800, 13.1102100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124048, 'Katrineholm', 'Katrineholm', 'Cathrineholm,Katrineholmas,Katrinekhol''m,Katrinekholm,ka te lin na huo er mu,kateulineholleum,katorinehorumu,katrynhwlm,Катринехолм,Катринехольм,کاترینهولم,კატრინეჰოლმი,カトリーネホルム,卡特琳娜霍尔姆,카트리네홀름', 58.9958700, 16.2072100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124049, 'Karlstad', 'Karlstad', 'Carolostadium,Gorad Karl''stad,KSD,Karlstad,Karlstadas,Karlstade,Kārlstade,ka er si ta de,kalseutadeu,karlshth,karlsta,karlstad,karusutado,qrlstd,Горад Карльстад,Карлстад,קרלסטד,كارلستاد,کارلستا,کارلسٹاڈ,کارلشته,კარლსტადი,ካርልስታድ,ᑲᕐᓪᔅᑕᑦ,カールスタード,卡尔斯塔德,칼스타드', 59.3793000, 13.5035700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124050, 'Karlskrona', 'Karlskrona', 'Caroli Corona,Gorad Karl''skruna,Karlskrona,Karlskruna,Karlskróna,Karlskrūna,ka er si ke lu na,kalseukeulona,karlsakrona,karlskrwna,karusukuruna,kharl sk ru na,klskrwna,qrlsqrwnh,Горад Карльскруна,Карлскруна,קרלסקרונה,كارلسكرونا,کارلسکرونا,کلسکرونا,कार्ल्सक्रोना,คาร์ลสกรูนา,კარლსკრონა,カールスクルーナ,卡尔斯克鲁纳,칼스크로나', 56.1615600, 15.5866100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124051, 'Karlskoga', 'Karlskoga', 'Gorad Karlskuga,KSK,Kariskoga,Karlskoga,Karlskuga,ka er si ku jia,kalseukoga,karlskwgha,klskwga,Горад Карлскуга,Карлскога,Карлскоґа,Карлскуга,Կարլսկուգա,كارلسكوغا,کلسکوگا,კარლსკუგა,卡尔斯库加,칼스코가', 59.3266700, 14.5238600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124052, 'Karlshamn', 'Karlshamn', 'Karlshamn,Karlshamnas,Karlskhamn,ka er si gang,kalshhmn,Карлсхамн,کالشهمن,卡爾斯港', 56.1706000, 14.8618800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124053, 'Karlsborg', 'Karlsborg', 'Karlsbori,Карлсбори', 58.5372400, 14.5047000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124054, 'Karlholmsbruk', 'Karlholmsbruk', 'Karlholm,Karlholmsbruk', 60.5209100, 17.6315200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124055, 'Kalmar', 'Kalmar', 'Calmaria,Gorad Kal''mar,KLR,Kal''mar,Kalmar,Kalmar kommuna,Kalmar stad,Kalmara,Kalmaras,Municipalita di Kalmar,Municipalità di Kalmar,ka er ma,kalmaleu,kalmar,karumaru shi,kha lmar,klmar,klmr,Горад Кальмар,Калмар,Кальмар,كالمار,کالمار,کلمار,کلمر,คาลมาร์,კალმარი,カルマル市,卡爾馬,칼마르', 56.6615700, 16.3616300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124056, 'Kallinge', 'Kallinge', 'Kallinge', 56.2484100, 15.2872100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124057, 'Kållered', 'Kallered', '', 57.6099200, 12.0510600, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124058, 'Källby', 'Kaellby', 'Kallby,Källby', 58.5099900, 13.3058200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124059, 'Kågeröd', 'Kageroed', 'Kagerod,Kageroed,Kågeröd,Kågerød', 55.9997600, 13.0879500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124060, 'Jursla', 'Jursla', 'Jursla', 58.6666700, 16.1833300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124061, 'Jörlanda', 'Joerlanda', 'Joerlanda,Jorlanda,Jörlanda,Jørlanda', 57.9863000, 11.8294300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124062, 'Jordbro', 'Jordbro', 'Jordbro', 59.1497200, 18.1166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124063, 'Jonstorp', 'Jonstorp', '', 58.0000000, 12.7166700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124393, 'Georgetown', 'Georgetown', 'ASI,Corctaun,Dzhordzhtaun,Dzordztaun,Dzordztauna,Dzordztaunas,Džordžtauna,Džordžtaunas,Georgetown,Georgetown pa Ascension,Georgetown på Ascension,cxrc thawn,jarj tavun,jojitaun,qiao zhi dui,Џорџтаун,Джорджтаун,Ջորջթաուն,جارج ٹاؤن، جزیرہ اسینشن,ஜார்ஜ் டவுன்,จอร์จทาวน์,ジョージタウン,乔治敦,조지타운', -7.9286100, -14.4119400, 'SH', '2016-10-08', 186);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124394, 'Edinburgh of the Seven Seas', 'Edinburgh of the Seven Seas', 'Edimburgo de los Siete Mares,Edimburgo dos Sete Mares,Edinburg Sedam Mora,Edinburg semi moriv,Edinburga Septinas Juras,Edinburga Septiņās Jūrās,Edinburgas,Edinburgh,Edinburgh-of-the-Seven-Seas,Ehdinburg,Ehdynburg-Sjami-Morau,Eideann na Seachd Muir,Karedin an Seyth Moryow,Settlement of Edinburgh,Tristan Island Settlement,Tristan Settlement,Yeddi dəniz Edinburqu,qi hai ai ding bao,xe din beirk xxf dexa se wen sis,Èideann na Seachd Muir,Единбург Седам Мора,Единбург семи морів,Эдинбург,Эдынбург-Сямі-Мораў,Յոթ ծովերի Էդինբուրգ,אדינבורו על שבעת הימים,سات سمندر کا ایڈنبرا,เอดินเบิร์กออฟเดอะเซเวนซีส์,エディンバラ・オブ・ザ・セブン・シーズ,七海爱丁堡', -37.0675700, -12.3115500, 'SH', '2011-03-16', 186);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124395, 'Jamestown', 'Jamestown', 'Ceymstaun,Dzeimstauna,Dzeimstaunas,Dzejmstaun,Dzhejmstaun,Džeimstauna,Džeimstaunas,Gorad Dzhehjmstaun,HLE,Iacobopolis,Jamestauno,Jamestown,Tzeimstaoun,Zhejmstaun,cems thawn,jeimseutaun,jemsata''una,jemstavun,jemuzutaun,jyms tawn,jymz ٹawn  synٹ ہlyna,jymztawn  synt hlyna,zhan mu si dui,Ĵamestaŭno,Τζέιμσταουν,Џејмстаун,Горад Джэймстаўн,Джеймстаун,Жеймстаун,גיימסטאון,דזשיימסטאן,جيمس تاون,جیمز ٹاون، سینٹ ہلینا,جیمزتاون، سینت هلینا,جیمزٹاؤن,جەیمستاون,जेम्सटाउन,ஜேம்ஸ்டவுன்,เจมส์ทาวน์,ჯეიმზტაუნი,ジェームズタウン,詹姆斯敦,제임스타운', -15.9387200, -5.7167500, 'SH', '2016-04-22', 186);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124392, 'Singapore', 'Singapore', 'SIN,Sin-ka-po,Singapore,Singapore City,Singapour,Singapur,Singapura,Sinkapoure,Sîn-kâ-po,Tumasik,cinkappur,prathes singkhpor,shingaporu,sigapura,sing-gapol,sing-gapoleu,singapura,singkh por,sngapwr,snghafwrt,syngpwr,xin jia po,xing jia po,Σιγκαπούρη,Сингапур,Сінгапур,סינגפור,سنغافورة,سنگاپور,सिंगापुर,सिंगापूर,ਸਿੰਗਾਪੁਰ,சிங்கப்பூர்,ประเทศสิงคโปร์,สิงค์โปร,ປະເທດສງກະໂປ,ປະເທດສິງກະໂປ,စငကာပနငင,စင်ကာပူနိုင်ငံ,សងហបរ,សិង្ហបុរី,シンガポール,新加坡,星架坡,싱가포르,싱가폴', 1.2896700, 103.8500700, 'SG', '2016-02-13', 200);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124396, 'Žužemberk', 'Zuzemberk', 'Obcina Zuzemberk,Občina Žužemberk,Seisenberg,Zuzemberk,Zuzemperk,jujenberuku,Žužemberk,Žužemperk,ジュジェンベルク', 45.8338900, 14.9291700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124397, 'Žirovnica', 'Zirovnica', 'Obcina Zirovnica,Občina Žirovnica,Zirovnica,jirovunitsu~a,Žirovnica,ジロヴニツァ', 46.4047200, 14.1400000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124398, 'Žiri', 'Ziri', 'Sairach,Ziri,Žiri', 46.0422200, 14.1072200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124399, 'Zgornji Duplek', 'Zgornji Duplek', 'Zgornji Duplek', 46.5136100, 15.7208300, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124400, 'Zgornje Pirniče', 'Zgornje Pirnice', 'Zgornje Pirnice,Zgornje Pirniče', 46.1425100, 14.4315800, 'SI', '2014-04-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124401, 'Zgornje Jezersko', 'Zgornje Jezersko', 'Zgornje Jezersko', 46.3941000, 14.5065900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124402, 'Zgornje Gorje', 'Zgornje Gorje', 'Zgornje Gorje', 46.3796200, 14.0693700, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124403, 'Zgornje Bitnje', 'Zgornje Bitnje', 'Zgornje Bitnje', 46.2200000, 14.3366700, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124404, 'Zgornja Polskava', 'Zgornja Polskava', 'Zgornja Polskava', 46.4255600, 15.6122200, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124405, 'Zgornja Kungota', 'Zgornja Kungota', 'Ober Sankt Kunigund,Zgornja Kungota,Zgornja Spodnja Kungota,Zgornja Sveta Kungota', 46.6391700, 15.6155600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124406, 'Žetale', 'Zetale', 'Obcina Zetale,Občina Žetale,Zetale,jetare,Žetale,ジェタレ', 46.2735600, 15.8265800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124407, 'Železniki', 'Zelezniki', 'Zeleznica,Zelezniki,Železnica,Železniki', 46.2199900, 14.1415900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124408, 'Zavrč', 'Zavrc', 'Zavrc,Zavrč', 46.3916700, 16.0497200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124409, 'Žalec', 'Zalec', 'Obcina Zalec,Občina Žalec,Zalec,jaretsu,Žalec,ジャレツ', 46.2515100, 15.1648200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124410, 'Zagorje ob Savi', 'Zagorje ob Savi', 'Gmina Zagorje ob Savi,Obcina Zagorje ob Savi,Občina Zagorje ob Savi,Zagore prie Savos,Zagore-ob-Savi,Zagorje,Zagorje ob Savi,Zagorė prie Savos,jagole-obeusabi,sa wa he pan zha ge lie,zaghry ab safy,zagryh ab sawy,Загорє-об-Саві,Загорје об Сави,زاغري أب سافي,زاگریه اب ساوی,زگورجے اب سوی,ザゴリェ・オプ・サヴィ,薩瓦河畔扎戈列,자고레오브사비', 46.1317900, 14.9969400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124411, 'Zabukovica', 'Zabukovica', 'Zabukovica', 46.2140800, 15.1595400, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124412, 'Vuzenica', 'Vuzenica', 'Vuzenica', 46.5963900, 15.1672200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124413, 'Vrtojba', 'Vrtojba', 'Vertoiba in Campi Santi,Vrtojba', 45.9125000, 13.6341700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124414, 'Vrhnika', 'Vrhnika', 'Nauporto,Ober-Laibach,Vrhnika,Vrkhnika,Врхника', 45.9635000, 14.2948400, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124415, 'Vransko', 'Vransko', 'Franz,Vransko', 46.2438900, 14.9513900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124416, 'Volčja Draga', 'Volcja Draga', 'Valvolciana,Volcja Draga,Volčja Draga', 45.9069400, 13.6775000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124417, 'Vojnik', 'Vojnik', 'Vojnik', 46.2933300, 15.3033300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124418, 'Vodice', 'Vodice', 'Woditz', 46.1898700, 14.4949200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124419, 'Vnanje Gorice', 'Vnanje Gorice', 'Vnanje Gorice', 46.0072200, 14.4219400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124420, 'Vitomarci', 'Vitomarci', 'Vitomarci', 46.5275000, 15.9394400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124421, 'Vitanje', 'Vitanje', 'Vitanje,Weitenstein', 46.3816700, 15.2958300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124422, 'Vipava', 'Vipava', 'Obcina Vipava,Občina Vipava,Vipacco,Vipava,Vippaco,vu~ipavu~a,Випава,ヴィパーヴァ', 45.8466700, 13.9630600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124423, 'Videm', 'Videm', 'Videm,Videm  Dobrepolje,Widem', 45.8500000, 14.6941700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124424, 'Veržej', 'Verzej', 'Verzej,Veržej', 46.5836100, 16.1652800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124425, 'Verd', 'Verd', 'Verd', 45.9566700, 14.3058300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124426, 'Velike Lašče', 'Velike Lasce', 'Gmina Velike Lasce,Gmina Velike Lašče,Gross-Laschitz,Grosslaschitz,Großlaschitz,Opcina Velike Lasce,Općina Velike Lašče,Velike Lasce,Velike Lashche,Velike Lashhe,Velike Lašče,bellikelasyuche,Велике Лашче,Велике Лаще,ヴェリケ・ラシチェ,벨리케라슈체', 45.8322200, 14.6363900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124427, 'Velika Polana', 'Velika Polana', 'Nagypalina,Palina,Velika Polana', 46.5719400, 16.3469400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124428, 'Turnišče', 'Turnisce', 'Bantornya,Bántornya,Turnisce,Turnischa,Turnišče', 46.6277800, 16.3202800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124429, 'Trzin', 'Trzin', 'Trzin', 46.1333300, 14.5666700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124430, 'Tržič', 'Trzic', 'Neumarktl,Trsic,Tršič', 46.3635700, 14.3104600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124431, 'Trnovska Vas', 'Trnovska Vas', 'Sankt Wolfgang in Windischbueheln,Sankt Wolfgang in Windischbüheln,Trnovska Ves', 46.5201900, 15.8865700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124432, 'Trnovlje pri Celju', 'Trnovlje pri Celju', 'Trnovlje,Trnovlje pri Celju', 46.2566700, 15.2952800, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124433, 'Trebnje', 'Trebnje', 'Praetorium Latobicorum,Trebne,Trebnje,te lei bu nie,teulebeune,torebunye,trbnjh,trbnyh,Требнє,Требње,تربنجه,تربنیه,トレブニェ,特雷布涅,트레브네', 45.9041700, 15.0216700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124434, 'Trbovlje', 'Trbovlje', 'Obcina Trbovlje,Občina Trbovlje,Trbovlje,torubovurye,トルボヴリェ', 46.1550000, 15.0533300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124435, 'Topolšica', 'Topolsica', 'Topolschitz,Topolscica,Topolščica', 46.4002800, 15.0215700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124436, 'Sveti Tomaž', 'Sveti Tomaz', 'Kostanj,Sveti Tomaz,Sveti Tomaz pri Ormozu,Sveti Tomaž,Sveti Tomaž pri Ormožu,Tomaz,Tomaz pri Ormozu,Tomaž,Tomaž pri Ormožu', 46.4841700, 16.0836100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124437, 'Tolmin', 'Tolmin', 'Obcina Tolmin,Občina Tolmin,Talmina,Tolmin,Tolmino,torumin,Толмин,トールミン', 46.1830400, 13.7332100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124438, 'Velenje', 'Velenje', 'Belenie,Mestna obcina Velenje,Mestna občina Velenje,Titovo Velenje,Velen''e,Velenje,Wollan,Wöllan,bellenye,vu~erenie,Βέλενιε,Веленье,ヴェレニエ,벨레녜', 46.3591700, 15.1102800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124439, 'Tišina', 'Tisina', 'Csendlak,Tisina,Tišina', 46.6580600, 16.0916700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124440, 'Tabor', 'Tabor', 'Tabor', 46.2361100, 15.0183300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124441, 'Sv. Duh', 'Sv. Duh', 'Sveti Duh', 46.1833300, 14.3333300, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124442, 'Sv. Anton', 'Sv. Anton', 'San Antonio di Capodistria,Sant''Antonio,Sant’Antonio,Sveti Anton', 45.5258300, 13.8319400, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124443, 'Sv. Ana v Slov. Goricah', 'Sv. Ana v Slov. Goricah', 'Sveta Ana,Sveta Ana v Slovenskih Goricah', 46.6491700, 15.8441700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124444, 'Štore', 'Store', 'Obcina Store,Občina Štore,Store,shutore,Štore,シュトレ', 46.2208300, 15.3138900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124445, 'Starše', 'Starse', 'Sankt Johann an Drau-Felde,Sent Janz,Starse,Starše,Sveti Janez na Dravskom Polju,Šent Janž', 46.4658300, 15.7672200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124446, 'Središče ob Dravi', 'Sredisce ob Dravi', 'Sredisce,Sredisce ob Dravi,Središče,Središče ob Dravi', 46.3941700, 16.2680600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124447, 'Spodnji Duplek', 'Spodnji Duplek', 'Spodnji Duplek', 46.5030600, 15.7452800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124448, 'Spodnje Hoče', 'Spodnje Hoce', 'Spodnje Hoce,Spodnje Hoče', 46.5000000, 15.6500000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124449, 'Spodnja Idrija', 'Spodnja Idrija', 'Idria di Sotto,Spodnja Idrija,Unteridria', 46.0319400, 14.0272200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124450, 'Spodnja Hajdina', 'Spodnja Hajdina', 'Hajdina,Obcina Hajdina,Občina Hajdina,Spodnja Hajdina,haidina,ハイディナ', 46.4088900, 15.8469400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124451, 'Šoštanj', 'Sostanj', 'Schonstein,Schönstein,Sostanj,Sostanj Mesto,Šoštanj', 46.3800000, 15.0486100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124452, 'Solčava', 'Solcava', 'Solcava,Solčava,Sulzbach', 46.4194400, 14.6936100, 'SI', '2013-08-06', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124453, 'Sodražica', 'Sodrazica', 'Soarazica,Soaražica,Soderschitz,Sodrazica,Sodrazice,Sodražica,Sodražice', 45.7611100, 14.6355600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124454, 'Šmartno pri Slovenj Gradcu', 'Smartno pri Slovenj Gradcu', 'Smartin,Smartno,Smartno pri Slovenj Gradcu,Smartno pri Slovenjem Gradcu,Šmartin,Šmartno,Šmartno pri Slovenj Gradcu,Šmartno pri Slovenjem Gradcu', 46.4894400, 15.1066700, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124455, 'Šmartno pri Litiji', 'Smartno pri Litiji', 'Sankt Martin,Smartin,Smartno,Smartno pri Litiji,Smartno pri Litui,Šmartin,Šmartno,Šmartno pri Litiji,Šmartno pri Litui', 46.0444400, 14.8441700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124456, 'Šmartno ob Paki', 'Smartno ob Paki', 'Smartin ob Paki,Smartno,Smartno ob Paki,Šmartin ob Paki,Šmartno,Šmartno ob Paki', 46.3333300, 15.0333300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124457, 'Šmarjeta', 'Smarjeta', 'Smarjeta,Šmarjeta', 45.8833300, 15.2500000, 'SI', '2015-11-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124458, 'Šmarje pri Jelšah', 'Smarje pri Jelsah', 'Shmare,Smarije,Smarje,Smarje pri Jelsah,Šmarje,Šmarje pri Jelšah', 46.2272200, 15.5191700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124459, 'Šmarje-Sap', 'Smarje-Sap', 'Smarje,Smarje Sap,Šmarje,Šmarje Sap', 45.9761800, 14.6117700, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124460, 'Šmarca', 'Smarca', 'Smarca,Šmarca', 46.1933300, 14.5966700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124461, 'Slovenske Konjice', 'Slovenske Konjice', 'Gonobitz,Konjice,Obcina Slovenske Konjice,Občina Slovenske Konjice,Slovenske Konice,Slovenske Konjice,Словенске Коњице,スロヴェンスケ・コニツェ', 46.3366700, 15.4258300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124462, 'Slovenska Bistrica', 'Slovenska Bistrica', 'Slovenska Bistrica,Windisch-Feistritz,スロヴェンスカ・ビストリツァ', 46.3927800, 15.5744400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124463, 'Slovenj Gradec', 'Slovenj Gradec', 'Mestna obcina Slovenj Gradec,Mestna občina Slovenj Gradec,Sloven''-Gradec,Slovenj Gradec,Slovenji Gradec,Slovenski Gradec,Windischgraz,sloven gradec,Словен Градец,Словень-Градец,スロヴェニ・グラデツ', 46.5102800, 15.0805600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124464, 'Škofljica', 'Skofljica', 'Comuna Skofljica,Comuna Škofljica,Gmina Skofljica,Gmina Škofljica,Obcina Skofljica,Občina Škofljica,Opcina Skofljica,Opshtina Shkoflica,Općina Škofljica,Shkoflica,Skofelca,Skofljica,shukofuritsu~a,syukopeullicha,Škofelca,Škofljica,Општина Шкофљица,Шкофліца,シュコフリツァ,슈코플리차', 45.9833300, 14.5766700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124465, 'Škofja Loka', 'Skofja Loka', 'Bischoflack,Gmina Skofja Loka,Gmina Škofja Loka,Shkof''ja-Loka,Shkofja Loka,Skofia Loka,Skofja Loka,Skosja Loka,shen ke fei ya luo ka,shkfya lka,shkwfja lwka,syukopyaloka,Škofja Loka,Шкофья-Лока,Шкофя Лока,Шкофја Лока,شكوفجا لوكا,شکفیا لکا,შკოფია-ლოკა,シュコーフィア・ロカ,什科菲亞洛卡,슈코퍄로카', 46.1655100, 14.3062600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124466, 'Škocjan', 'Skocjan', 'Skocijan,Skocjan,Škocijan,Škocjan', 45.9066700, 15.2913900, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124467, 'Sežana', 'Sezana', 'Gmina Sezana,Gmina Sežana,Sesana,Sexana,Sezana,Sezhana,Sežana,sai zha na,sejana,syjana,szhana,Сежана,سيجانا,سژانا,セジャーナ,塞扎纳,세자나', 45.7092400, 13.8733300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124468, 'Sevnica', 'Sevnica', '', 46.0077800, 15.3155600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124469, 'Šentvid pri Stični', 'Sentvid pri Sticni', 'Sentvid,Sentvid Pri Sticni,Sentvid pri Sticni,Šentvid,Šentvid Pri Stični,Šentvid pri Stični', 45.9500400, 14.8434400, 'SI', '2014-04-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124470, 'Šentrupert', 'Sentrupert', 'Sankt Ruprecht,Sentrupert,Šentrupert', 45.9777800, 15.0955600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124471, 'Šentjur', 'Sentjur', 'Gmina Sentjur,Gmina Šentjur,Obcina Sentjur,Občina Šentjur,Sankt Georgen,Sent Jurij,Sentjur,Sentjur pri Celju,Shentjur,Sveti Juraj,Sveti Jurij,Sveti Jurij pri Celju,cai lie fu jin shen te you er,shntywr,shyntjwr,syenchuleupeulichellyu,Šent Jurij,Šentjur,Šentjur pri Celju,Шентюр,Шентјур,شنتیور,شينتجور,シェントユル・プリ・ツェリュ,采列附近申特尤爾,셴추르프리첼류', 46.2172200, 15.3975000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124472, 'Šentjernej', 'Sentjernej', 'Obcina Sentjernej,Občina Šentjernej,Sankt Bartlmae,Sankt Bartlmä,Sent Jernej,Sentjernej,shentoi~erunyei,Šent Jernej,Šentjernej,シェントイェルニェイ', 45.8400000, 15.3361100, 'SI', '2015-12-03', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124473, 'Šentilj v Slov. Goricah', 'Sentilj v Slov. Goricah', 'Obcina Sentilj,Občina Šentilj,Sentilj,Sveti Ilj,shentiri,Šentilj,シェンティリ', 46.6816700, 15.6480600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124474, 'Senovo', 'Senovo', 'Senovo', 46.0236100, 15.4769400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124475, 'Šenčur', 'Sencur', 'Sencur,Šenčur', 46.2455600, 14.4197200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124476, 'Šempeter v Savinj. Dolini', 'Sempeter v Savinj. Dolini', 'Sempeter,Sveti Peter,Šempeter', 46.2563900, 15.1219400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124477, 'Šempeter pri Gorici', 'Sempeter pri Gorici', 'San Pietro,San Pietro di Gorizia,San Pietro di Gorízia,Sempeter,Sempeter pri Gorici,Sent Peter,Sveti Peter,Šempeter pri Gorici', 45.9275000, 13.6411100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124478, 'Šempas', 'Sempas', 'Sambasso,Schonpals,Schönpals,Sempas,Šempas', 45.9302800, 13.7436100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124479, 'Semič', 'Semic', 'Semic,Semitsch,Semič', 45.6461100, 15.1822200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124480, 'Selnica ob Muri', 'Selnica ob Muri', 'Selnica,Selnica ob Muri', 46.6833300, 15.7000000, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124481, 'Šalovci', 'Salovci', 'Gross-Schaal,Klein-Schaal,Sal,Salovci,Schabing,Šalovci', 46.8250000, 16.2980600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124482, 'Ruše', 'Ruse', 'Maria Rast,Obcina Ruse,Občina Ruše,Rose,Roše,Ruse,Ruše,rushe,ルシェ', 46.5394400, 15.5158300, 'SI', '2016-10-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124483, 'Rogoza', 'Rogoza', 'Rogoza', 46.5000000, 15.6833300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124484, 'Rogatec', 'Rogatec', 'Rogatec,Rohitsch', 46.2294400, 15.7002800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124485, 'Rogašovci', 'Rogasovci', 'Rogacovci,Rogasevci,Rogasovci,Rogačovci,Rogaševci,Rogašovci,Szarvaslak', 46.8000000, 16.0333300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124486, 'Rogaška Slatina', 'Rogaska Slatina', 'Hohitsch Sauerbrunn,Obcina Rogaska Slatina,Občina Rogaška Slatina,Rogaska Slatina,Rogaška Slatina,ロガーシュカ・スラティナ', 46.2375000, 15.6397200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124487, 'Ribnica na Pohorju', 'Ribnica na Pohorju', 'Ribnica,Ribnica na Pohorju', 46.5350000, 15.2727800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124488, 'Ribnica', 'Ribnica', 'Reifnitz,Ribnica', 45.7386100, 14.7275000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124489, 'Renče', 'Rence', 'Ranziano,Rence,Renče', 45.8900000, 13.6686100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124490, 'Rečica ob Savinji', 'Recica ob Savinji', 'Recica,Recica ob Savinji,Rečica,Rečica ob Savinji', 46.3166700, 14.9166700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124491, 'Razvanje', 'Razvanje', 'Razvanje', 46.5144400, 15.6361100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124492, 'Ravne na Koroškem', 'Ravne na Koroskem', 'Gustanj,Gutenstein,Gutenstein in Kaernten,Gutenstein in Kärnten,Guštanj,Ravne,Ravne na Koroskem,Ravne na Koroškem', 46.5430600, 14.9691700, 'SI', '2016-03-22', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124493, 'Ravne', 'Ravne', 'Ravne', 46.4141300, 15.0608700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124494, 'Rakičan', 'Rakican', 'Battyanfalva,Battyánfalva,Rakican,Rakicsan,Rakicsán,Rakitsan,Rakitsán,Rakičan', 46.6516700, 16.2041700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124495, 'Rakek', 'Rakek', 'Racche,Rakek', 45.8133300, 14.3111100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124496, 'Radovljica', 'Radovljica', 'Gmina Radovljica,Obcina Radovljica,Občina Radovljica,Radmannsdorf,Radovlica,Radovlicja,Radovljica,radovuritsu~a,Радовлиця,Радовљица,ラドヴリツァ', 46.3444400, 14.1744400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124497, 'Radomlje', 'Radomlje', 'Radomlje', 46.1736100, 14.6122200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124498, 'Radlje ob Dravi', 'Radlje ob Dravi', 'Marenberg,Mariberg,Obcina Radlje ob Dravi,Občina Radlje ob Dravi,Radlje,Radlje ob Dravi,ラドリェ・オブ・ドラヴィ', 46.6141700, 15.2263900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124499, 'Radenci', 'Radenci', 'Obcina Radenci,Občina Radenci,Radein,Radenci,Radinci,radentsu~i,ラデンツィ', 46.6420100, 16.0378100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124500, 'Radeče', 'Radece', 'Obcina Radece,Občina Radeče,Radece,Radeče,radeche,ラデチェ', 46.0680600, 15.1838900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124501, 'Rače', 'Race', 'Kranichsfeld,Race,Radisel,Rače', 46.4519400, 15.6813900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124502, 'Puconci', 'Puconci', 'Battyand,Battyánd,Puconci,Pusonci', 46.7066700, 16.1563900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124503, 'Ptuj', 'Ptuj', 'Mestna obcina Ptuj,Mestna občina Ptuj,Pettau,Ptuj,puto~ui,Птуй,プトゥイ', 46.4200500, 15.8701800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124504, 'Prvačina', 'Prvacina', 'Prevacina,Prvacina,Prvačina', 45.8900000, 13.7180600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124505, 'Prevalje', 'Prevalje', 'Pollain,Prevalje', 46.5469400, 14.9208300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124506, 'Preserje pri Radomljah', 'Preserje pri Radomljah', 'Preserje,Preserje pri Radomljah', 46.1691100, 14.5969800, 'SI', '2014-04-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124507, 'Preddvor', 'Preddvor', 'Hoflein,Höflein,Preddvor,Predvor', 46.3025000, 14.4230600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124508, 'Prebold', 'Prebold', 'Obcina Prebold,Občina Prebold,Prebold,pureborudo,プレボルド', 46.2369400, 15.0925000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124509, 'Pragersko', 'Pragersko', 'Pragerhof,Pragersko', 46.3966700, 15.6600000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124510, 'Postojna', 'Postojna', 'Adelsberg,Postojna,Postumia,Postumia Grotte,Postumija,Postúmia,posutoina,ポストイナ', 45.7743500, 14.2152800, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124511, 'Portorož', 'Portoroz', 'POW,Portorose,Portoroz,Portorozh,Portorož,bo er tuo luo,bwrtwrwz,Порторож,بورتوروز,波爾托羅', 45.5142900, 13.5920600, 'SI', '2014-07-16', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124512, 'Polzela', 'Polzela', 'Obcina Polzela,Občina Polzela,Polzela,poruzera,ポルゼラ', 46.2833300, 15.0666700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124513, 'Poljčane', 'Poljcane', 'Poljcane,Poljčane', 46.3119400, 15.5791700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124514, 'Podvelka', 'Podvelka', 'Podvelka', 46.5869400, 15.3305600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124515, 'Podlehnik', 'Podlehnik', 'Podhlenik,Podlehnik', 46.3352800, 15.8800000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124516, 'Podčetrtek', 'Podcetrtek', 'Obcina Podcetrtek,Občina Podčetrtek,Opshtina Podchetrtek,Podcetrtek,Podčetrtek,potchetoruteku,Општина Подчетртек,ポッチェトルテク', 46.1569400, 15.5986100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124517, 'Pivka', 'Pivka', 'Obcina Pivka,Občina Pivka,Pibka,Pietro del Carso,Pivka,San Peter,San Pietro del Carso,Sent Peter,Sent Peter na Krasu,Sveti Peter na Krasu,pifuka,Šent Peter,Šent Peter na Krasu,Πίβκα,Пивка,ピフカ', 45.6829200, 14.1958800, 'SI', '2015-10-22', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124518, 'Piran', 'Piran', 'Grad Piran,Obcina Piran,Občina Piran,Piran,Pirano,piran,Пиран,ピラン', 45.5277800, 13.5705600, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124519, 'Pesnica pri Mariboru', 'Pesnica pri Mariboru', 'Pesnica,Pesnica pri Maribor,Pesnica pri Mariboru,Possnitz-Hofen,Pössnitz-Hofen', 46.6069400, 15.6766700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124520, 'Pekre', 'Pekre', 'Pekre', 46.5472200, 15.5955600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124521, 'Pameče', 'Pamece', 'Pamece,Pameče', 46.5341700, 15.0791700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124522, 'Osilnica', 'Osilnica', 'Osilnica,Oslinica', 45.5291400, 14.6983800, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124523, 'Ormož', 'Ormoz', 'Friedau,Ormob,Ormos,Ormoz,Ormoš,Ormož', 46.4113900, 16.1544400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124524, 'Oplotnica', 'Oplotnica', 'Obcina Oplotnica,Občina Oplotnica,Oplotnica,opurotonitsu~a,オプロトニツァ', 46.3877800, 15.4466700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124525, 'Odranci', 'Odranci', 'Adorjanfalva,Adorjanhaza,Adorjánfalva,Adorjánháza,Obcina Odranci,Občina Odranci,Odrance,Odranci,odorantsu~i,オドランツィ', 46.5866700, 16.2802800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124526, 'Novo Mesto', 'Novo Mesto', 'Gorad Nova-Mesta,Nova Mesta,Nova Urbs,Novo Mestas,Novo Mesto,Novo mesto,Novo-Mesto,Rudolfswert,Rudolfswerth,nobomeseuto,nwbw mstw,nwfw mytsw,nww mstw,nww mystw,nx wx me s tx,xin mei si tuo,Νόβο Μέστο,Горад Нова-Места,Ново Место,Ново место,Ново-Место,נובו מסטו,نوفو ميتسو,نوو مستو,نوو مسٹو,نوو میستو,นอวอเมสตอ,ნოვო-მესტო,ノヴォ・メスト,新梅斯托,노보메스토', 45.8039700, 15.1688600, 'SI', '2014-05-11', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124527, 'Nova Vas', 'Nova Vas', 'Nova Vas', 45.7716700, 14.5058300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124528, 'Nova Gorica', 'Nova Gorica', 'Gnove Gurize,Gorad Nova-Goryca,Gorica,Goritia Nova,Nova Gorica,Nova Goricja,Nova Nkoritsa,Nova-Gorica,Nuova Gorizia,nobagolicha,nova gorica,nova-goritsa,nwa grytsa,nwbh gwryzh,nwfa jwrytsa,nwwa gwryka,nwwa gwrytsa,nx wa kx rit sa,xin ge li cha,Νόβα Γκόριτσα,Горад Нова-Горыца,Нова Горица,Нова Гориця,Нова-Горица,נובה גוריצה,نوا گریتسا,نوفا جوريتسا,نووا گوریتسا,نووا گوریکا,นอวากอรีตซา,ნოვა-გორიცა,ノヴァ・ゴリツァ,新戈里察,노바고리차', 45.9560400, 13.6483700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124529, 'Notranje Gorice', 'Notranje Gorice', 'Notranje Gorice', 45.9875000, 14.3988900, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124530, 'Naklo', 'Naklo', 'Naklas,Naklo', 46.2727800, 14.3172200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124531, 'Muta', 'Muta', 'Muta,Na Muti', 46.6113900, 15.1661100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124532, 'Murska Sobota', 'Murska Sobota', 'Mestna obcina Murska Sobota,Mestna občina Murska Sobota,Muraszombat,Murska Sobota,Murska Subota,Oisnitz,Olsnitz,Sobota,Szombat,Мурска Собота,ムルスカ・ソボタ', 46.6625000, 16.1663900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124533, 'Mozirje', 'Mozirje', 'Mozirje,Obcina Mozirje,Občina Mozirje,Prassberg,mojirye,モジリェ', 46.3394400, 14.9633300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124534, 'Moste', 'Moste', 'Moste', 46.1950000, 14.5513900, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124535, 'Morje', 'Morje', 'Morje', 46.4444400, 15.6213900, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124536, 'Moravske Toplice', 'Moravske Toplice', 'Moravci,Moravske-Toplice', 46.6831300, 16.2208000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124537, 'Moravče', 'Moravce', 'Moravce,Moravče', 46.1369400, 14.7450000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124538, 'Mokronog', 'Mokronog', 'Mokronog,Nassenfuss,Nassenfuß', 45.9341700, 15.1408300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124539, 'Mojstrana', 'Mojstrana', 'Mojstrana', 46.4238300, 13.8752000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124540, 'Mlaka pri Kranju', 'Mlaka pri Kranju', 'Mlaka,Mlaka pri Kranju', 46.2833300, 14.3500000, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124541, 'Mislinja', 'Mislinja', 'Mislinja,Mislinje,Missling,Velika Mislinja', 46.4414100, 15.2002700, 'SI', '2016-03-11', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124542, 'Mirna Peč', 'Mirna Pec', 'Mirna Pec,Mirna Peč,Obcina Mirna Pec,Občina Mirna Peč,ミルナ・ペチ', 45.8602800, 15.0833300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124543, 'Mirna', 'Mirna', 'Mirna,mileuna,miruna,Мирна,ミルナ,미르나', 45.9552800, 15.0619400, 'SI', '2016-11-23', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124544, 'Miren', 'Miren', 'Merna,Miren', 45.8955600, 13.6075000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124545, 'Miklavž na Dravskem Polju', 'Miklavz na Dravskem Polju', 'Miklavz,Miklavz na Dravskem Polju,Miklavž,Miklavž na Dravskem Polju,Sveti Miklavz,Sveti Miklavž', 46.5058300, 15.6972200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124546, 'Mežica', 'Mezica', 'Mezica,Mežica', 46.5213900, 14.8544400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124547, 'Metlika', 'Metlika', 'Metlika,Mottling,Möttling,Obcina Metlika,Občina Metlika,metorika,メトリカ', 45.6472200, 15.3141700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124548, 'Mengeš', 'Menges', 'Menges,Mengeš,Mengus,Menguš', 46.1669400, 14.5750000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124549, 'Mekinje', 'Mekinje', 'Mekinje', 46.2333300, 14.6166700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124550, 'Medvode', 'Medvode', 'Medvode,Медводе', 46.1422000, 14.4111400, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124551, 'Markovci', 'Markovci', 'Markovci,Sveti Marko', 46.3955700, 15.9283100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124552, 'Maribor', 'Maribor', 'MBX,Marburg an der Drau,Marburgo,Maribor,Maribora,Mariboras,Mariboro,Mestna obcina Maribor,Mestna občina Maribor,ma li bo er,mariboru,Марибор,マリボル,马里博尔', 46.5547200, 15.6466700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124553, 'Makole', 'Makole', 'Makole', 46.3172200, 15.6672200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124554, 'Majšperk', 'Majsperk', 'Majsperk,Majšperk,Obcina Majsperk,Občina Majšperk,maishuperuku,マイシュペルク', 46.3516700, 15.7336100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124555, 'Lukovica pri Domžalah', 'Lukovica pri Domzalah', 'Lukomitz,Lukovica,Lukovica pri Domzalah,Lukovica pri Domžalah,Lukowitz,Obcina Lukovica,Občina Lukovica,rukovu~itsu~a,ルコヴィツァ', 46.1698800, 14.6917900, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124556, 'Luče', 'Luce', 'Leutsch,Luce,Luče', 46.3561100, 14.7466700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124557, 'Lovrenc na Pohorju', 'Lovrenc na Pohorju', 'Lovrenc na Pohorju,Saint Larenzen,Sveti Lovrenc', 46.5405600, 15.3930600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124558, 'Loški Potok', 'Loski Potok', 'Laserbach,Loski Potok,Loški Potok', 45.7013900, 14.5802800, 'SI', '2015-11-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124559, 'Lokavec', 'Lokavec', 'Loavizza,Locavizza,Locavizza di Aidussina,Locavizza di Aidússina,Lokavec,Lokavitz,Lokovec', 45.9016700, 13.8797200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124560, 'Log pri Brezovici', 'Log pri Brezovici', 'Log,Log pri Brezovici', 46.0166700, 14.3666700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124561, 'Ljutomer', 'Ljutomer', 'Ljutomer,Luttenberg,Obcina Ljutomer,Občina Ljutomer,lywtwmyr,ryutomeru,Љутомер,Лютомер,ليوتومير,リュトメル', 46.5208300, 16.1975000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124562, 'Ljubno ob Savinji', 'Ljubno ob Savinji', 'Ljubno ob Savinji', 46.3435800, 14.8337700, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124563, 'Ljubljana', 'Ljubljana', 'Aemona,Gorad Ljubljana,Jubaljana,LJU,Laibach,Laiboch,Lioumpliana,Liubliana,Liublianne,Liublijana,Liuibleana,Liúibleána,Ljubljan,Ljubljana,Ljubljana osh,Ljubljanae,Ljubljano,Lubian-a,Lubiana,Lubiane,Lubiann-a,Lubjana,Lublan,Lublana,Lublaň,Lubliano,Lubljana,Luebiana,Lueblaen,Lueblana,Lyoubyana,Lyublyana,Lübiana,Lüblâna,Lüblän,li''ubali''ana,li''ubliyana,liubliana,liyubliyana,liyupliyana,lu bu er ya na,lub li ya na,lyubeullyana,lywblyana,ryuburyana,Ļubļana,Ľubľana,Łubiana,Λιουμπλιάνα,Љубљана,Горад Любляна,Люблян,Люблянæ,Любляна,Любляна ош,Люблꙗна,Լյուբլյանա,ליובליאנה,ليوبليانا,ليۇبليانا,لیوبلیانا,लियुब्लियाना,লিউব্লিয়ানা,ਲਿਊਬਲਿਆਨਾ,லியுப்லியானா,ลูบลิยานา,ལི་པོ་ཡ་ན།,ლიუბლიანა,ልዩብልያና,リュブリャナ,卢布尔雅那,盧布爾雅那,류블랴나', 46.0510800, 14.5051300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124564, 'Ljubečna', 'Ljubecna', 'Ljubecna,Ljubečna', 46.2556700, 15.3243000, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124565, 'Litija', 'Litija', 'Gmina Litija,Litija,Littai,Obcina Litija,Občina Litija,Opcina Litija,Općina Litija,li di ya,lytya,ritiya,Лития,Литија,Літія,لیتیا,ლიტია,リティヤ,利蒂亞', 46.0586100, 14.8225000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124566, 'Lipovci', 'Lipovci', 'Harsliget,Hársliget,Lipovci,Lippahoc,Lippahocz,Lippahócz', 46.6283300, 16.2280600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124567, 'Limbuš', 'Limbus', 'Limbus,Limbuš', 46.5536100, 15.5836100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124568, 'Leskovec pri Krškem', 'Leskovec pri Krskem', 'Huselbach,Leskovec,Leskovec pri Krskem,Leskovec pri Krškem,Leskovec''-pri-Krshkem,Лесковець-при-Кршкем', 45.9356600, 15.4718400, 'SI', '2014-04-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124569, 'Lesce', 'Lesce', 'Lees,Lesc,Lesce', 46.3611100, 14.1577800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124570, 'Lendava', 'Lendava', 'Alsolendva,Alsólendva,Dolnja Lendava,Donja Lendava,Donja Lendova,Lendava,Lendva,Obcina Lendava,Občina Lendava,Unter-Limbach,rendavu~a,レンダヴァ', 46.5649400, 16.4509100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124571, 'Lenart v Slov. Goricah', 'Lenart v Slov. Goricah', 'Lenart,Lenart v Slovenskih Goricah,Sankt Leonhard,Sent Lenart,Sveti Lenard,Sveti Lenart,Šent Lenart', 46.5761100, 15.8313900, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124572, 'Laško', 'Lasko', 'Gmina Lasko,Gmina Laško,Lashko,Laski Trg,Lasko,Laški Trg,Laško,Obcina Lasko,Občina Laško,Tueffer,Tüffer,la shen ke,rashuko,Лашко,לאשקו,ラーシュコ,拉什科', 46.1546300, 15.2355500, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124573, 'Kuzma', 'Kuzma', 'Kuzdoblanje,Kuzma', 46.8369400, 16.0833300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124574, 'Krško', 'Krsko', 'Gmina Krsko,Gmina Krško,Gurkfeld,Krshko,Krskas,Krsko,Krushko,Krškas,Krško,Obcina Krsko,Občina Krško,ke er shen ke,keuleusyuko,krshkw,krskw,kurushuko,qrsqw,Кршко,Кръшко,קרשקו,كرشكو,کرسکو,کرشکو,クルシュコ,克爾什科,크르슈코', 45.9591500, 15.4916700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124575, 'Kromberk', 'Kromberk', 'Komberg,Kromberk,Moncorona', 45.9608300, 13.6655600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124576, 'Krog', 'Krog', 'Korong,Krog', 46.6380600, 16.1413900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124577, 'Križevci pri Ljutomeru', 'Krizevci pri Ljutomeru', 'Kreuzdorf,Krizevci,Krizevci pri Ljutomeru,Križevci,Križevci pri Ljutomeru', 46.5683300, 16.1386100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124578, 'Kranjska Gora', 'Kranjska Gora', 'Gmina Kranjska Gora,Kran''ska-Gora,Kranjska Gora,Krans''ka Gora,Kranska Gora,Kranska gora,Kronau,Obcina Kranjska Gora,Občina Kranjska Gora,ke la ni si ka ge la,khra n ska kx ra,kranska gwra,Кранска гора,Кранська Гора,Краньска-Гора,Крањска Гора,کرانسکا گورا,ครานสกากอรา,クランスカ・ゴーラ,克拉尼斯卡戈拉', 46.4568900, 13.7782400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124579, 'Kranj', 'Kranj', 'Cragni,Krainburg,Kran'',Kranj,kurani,Крань,クラーニ', 46.2388700, 14.3556100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124580, 'Kozje', 'Kozje', 'Drachenburg,Kozje', 46.0750000, 15.5602800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124581, 'Kozina', 'Kozina', 'Cosina,Cosina d''Istria,Cosina d’Istria,Kozina', 45.6100000, 13.9355600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124582, 'Kotlje', 'Kotlje', 'Kotle,Kotlje', 46.5213900, 14.9869400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124583, 'Kostanjevica na Krki', 'Kostanjevica na Krki', 'Kostanevica na Krki,Kostanevicja-na-Krki,Kostanjevica na Krki,Kostanjevica ob Krki,Kostanjevjca,Landstrass,Landstraß,ke si ta nie wei cha,koseutanebichanakeuleuki,kstanywytsa na krky,kwstanywytsa na krky,Костанєвиця-на-Кркі,Костањевица на Крки,كوستانيويتسا نا كركي,کستانیویتسا نا کرکی,コンスタニェヴィツァ・ナ・クルキ,科斯塔涅維察,코스타네비차나크르키', 45.8461100, 15.4222200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124584, 'Koper', 'Koper', 'Capodistria,Grad Kopar,Kopar,Koper,Koperis,koperu,Копер,コペル', 45.5469400, 13.7294400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124585, 'Komen', 'Komen', 'Comen,Comeno,Komen', 45.8152800, 13.7483300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124586, 'Kokrica', 'Kokrica', 'Kokrica', 46.2702800, 14.3611100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124587, 'Kočevje', 'Kocevje', 'Gmina Kocevje,Gmina Kočevje,Gottschee,Koceve,Kocevje,Kochev''e,Kocheve,Kotsebie,Kočevje,Kočevė,Obcina Kocevje,Občina Kočevje,Opcina Kocevje,Općina Kočevje,ke qie wei,khx chewye,kochebe,kochevje,kochevu~ie,kochevu~i~e,Κοτσέβιε,Кочеве,Кочевье,Кочевє,Кочевје,คอเชวเย,コチェーヴィェ,コチェーヴィエ,科切維,코체베', 45.6433300, 14.8633300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124588, 'Kobilje', 'Kobilje', 'Brezovica,Kebele,Kebeleszentmarton,Kebeleszentmárton,Kobilje,Obcina Brezovica,Občina Brezovica,burezovu~itsu~a,ブレゾヴィツァ', 46.6847200, 16.3977800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124589, 'Kobarid', 'Kobarid', 'Caporeto,Caporett,Caporetto,Cjauret,Cjaurêt,Gmina Kobarid,Karfreit,Kobarid,Obcina Kobarid,Občina Kobarid,Opcina Kobarid,Općina Kobarid,kbaryd,ke ba li de,kobalideu,kobarido,kwbaryd,Кобарид,Кобарід,كوباريد,کبارید,コバリード,科巴里德,코바리드', 46.2476100, 13.5790700, 'SI', '2017-03-18', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124590, 'Kidričevo', 'Kidricevo', 'Kidricevo,Kidrichevo,Kidričevo,Strnisce,Strnišče,Кидричево', 46.4036100, 15.7911100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124591, 'Kanal', 'Kanal', 'Canale,Canale d''Isonzo,Canale d’Isonzo,Kanal', 46.0886100, 13.6397200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124592, 'Kamnik', 'Kamnik', 'Kamnik,Kamnikas,Lithopolis,Stein,ka mu ni ke,kamnikeu,kamnyk,kamuniku,kha mnik,Камник,كامنيك,کامنیک,คามนิก,კამნიკი,カムニーク,卡姆尼克,캄니크', 46.2258700, 14.6120700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124593, 'Kamnica', 'Kamnica', 'Kamnica', 46.5744400, 15.6141700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124594, 'Juršinci', 'Jursinci', 'Jursinci,Juršinci,Obcina Jursinci,Občina Juršinci,yurushintsu~i,ユルシンツィ', 46.4847200, 15.9713900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124595, 'Jurovski Dol', 'Jurovski Dol', 'Jurovski Dol,Sveti Jurij,Sveti Jurij v Slovenske Gorice', 46.6063900, 15.7847200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124596, 'Sveti Jurij ob Ščavnici', 'Sveti Jurij ob Scavnici', 'Comuna Sveti Jurij ob Scavnici,Comuna Sveti Jurij ob Ščavnici,Gmina Sveti Jurij ob Scavnici,Gmina Sveti Jurij ob Ščavnici,Jurij,Obcina Sveti Jurij ob Scavnici,Občina Sveti Jurij ob Ščavnici,Opcina Sveti Jurij ob Scavnici,Opshtina Sveti Jurij ob Shchavnici,Općina Sveti Jurij ob Ščavnici,Sankt-Georgen,Sveti Jurij,Sveti Jurij ob Scavnici,Sveti Jurij ob Ščavnici,Svetij Jurij-ob-Shhavnici,Vizlendva,seubetiyuliobeusyuchabeunichi,Општина Свети Јуриј об Шчавници,Светий Юрій-об-Щавниці,スヴェティ・ユリイ・オプ・シュチャヴニツィ,스베티유리오브슈차브니치', 46.5695000, 16.0234700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124597, 'Jesenice', 'Jesenice', 'Assling,Esenice,Jesenice,Jesenices,Jesenicės,Obcina Jesenice,Občina Jesenice,esenitse,i~esenitsu~e,jysyntsy,Єсеніце,Јесенице,Есенице,Йесенице,جيسينتسي,یسینیتسے، یسینیتسے,ესენიცე,イェセニツェ', 46.4305600, 14.0669400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124598, 'Izola', 'Izola', 'Isola,Isola d''Istria,Isola d’Istria,Izla,Izola,Ižla,Obcina Izola,Občina Izola,izora,Изола,イゾラ', 45.5369400, 13.6619400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124599, 'Izlake', 'Izlake', 'Izlake', 46.1500000, 14.9500000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124600, 'Ivančna Gorica', 'Ivancna Gorica', 'Hudo,Ivancna Gorica,Ivančna Gorica,Obcina Ivancna Gorica,Občina Ivančna Gorica,イヴァンチュナ・ゴリツァ', 45.9383300, 14.8044400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124601, 'Ilirska Bistrica', 'Ilirska Bistrica', 'Bisterza,Ilirska Bistrica,Illyrisch Feistritz,Obcina Ilirska Bistrica,Občina Ilirska Bistrica,Villa del Nevoso,イリルスカ・ビストリツァ', 45.5787800, 14.3065200, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124602, 'Ig', 'Ig', 'Ig,Ig pri Ljubljana,Ig-Studenec,Iggdorf,Studenec-Ig', 45.9602800, 14.5288900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124603, 'Idrija', 'Idrija', 'Idria,Idrija', 46.0027800, 14.0305600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124604, 'Hrvatini', 'Hrvatini', 'Crevatini,Hrvatin,Hrvatini', 45.5827800, 13.7566700, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124605, 'Hrušica', 'Hrusica', 'Hrusica,Hrušica', 46.4450000, 14.0177800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124606, 'Hrib-Loški Potok', 'Hrib-Loski Potok', 'Hrib,Hrib-Loski Potok,Hrib-Loški Potok', 45.7068800, 14.6167400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124607, 'Hrastnik', 'Hrastnik', 'Hrastnigg,Hrastnik,Khrastnik,Храстник', 46.1461100, 15.0813900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124608, 'Hrastje', 'Hrastje', '', 46.2166700, 14.4000000, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124609, 'Hotinja Vas', 'Hotinja Vas', 'Hotinja Vas', 46.4666700, 15.6666700, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124610, 'Horjul', 'Horjul', 'Horjul', 46.0236100, 14.2991700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124611, 'Hodoš', 'Hodos', 'Hodos,Hodosch,Hodoš,Obcina Hodos,Občina Hodoš,Orihodos,hodoshu,Őrihodos,ホドシュ', 46.8233300, 16.3341700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124612, 'Grosuplje', 'Grosuplje', 'Grosuple,Grosuplje,Opshtina Grosuple,ge luo su pu lie,geulosupeulle,grswplyh,gurosupurye,Гросуплє,Општина Гросупље,گرسوپلیه,グロースプリェ,格羅蘇普列,그로수플레', 45.9555600, 14.6588900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124613, 'Sv. Trojica v Slov. Goricah', 'Sv. Trojica v Slov. Goricah', 'Gradisce,Gradisce v Slovenskih Goricah,Gradišče,Gradišče v Slovenskih Goricah,Sveta Trojica,Sveta Trojica v Slovenskih Goricah,Sveta Trojica v Slovenskih goricah', 46.5766700, 15.8769400, 'SI', '2016-10-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124614, 'Grad', 'Grad', 'Felsolendva,Felsőlendva,Gornja Lendava,Grad,Kruplivnik,Oberlimbach,Oberlimpach,Vaskopard,Vaskopárd', 46.8000000, 16.1000000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124615, 'Gotovlje', 'Gotovlje', 'Gotovlje', 46.2741800, 15.1518600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124616, 'Gornji Petrovci', 'Gornji Petrovci', 'Gornji Petrovci,Peterhegy,Petrovci,Péterhegy', 46.8052800, 16.2225000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124617, 'Gornji Grad', 'Gornji Grad', 'Gornji Grad,Oberburg in Steiermark', 46.2952800, 14.8083300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124618, 'Gornja Radgona', 'Gornja Radgona', 'Gorna Radgona,Gornja Radgona,Radgona,Regede,ghrnya radghna,goleunyaladeugona,grnya radgna,shang la de ge na,Горня Радгона,Горња Радгона,غرنيا رادغنا,گرنیا رادگنا,ゴルニャ・ラドゴナ,上拉德戈納,고르냐라드고나', 46.6733300, 15.9922200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124619, 'Gorišnica', 'Gorisnica', 'Gorisnica,Gorišnica', 46.4147200, 16.0138900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124620, 'Gorenja Vas', 'Gorenja Vas', 'Goreinawas,Gorenja Vas', 46.1072200, 14.1480600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124621, 'Straža', 'Straza', 'Gorenja Straza,Gorenja Straža,Gornja Straza,Gornja Straža,Ober-Strascha,Straza,Straža', 45.7800000, 15.0727800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124622, 'Golnik', 'Golnik', 'Golnik', 46.3333300, 14.3333300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124623, 'Gančani', 'Gancani', 'Gancani,Ganicsa,Gančani,Gánicsa,Lendvarozsavolgy,Lendvarózsavölgy', 46.6325000, 16.2511100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124624, 'Fram', 'Fram', 'Fram', 46.4560000, 15.6300700, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124625, 'Dravograd', 'Dravograd', 'Dravograd,Obcina Dravograd,Občina Dravograd,Spodnji Dravograd,Unter-Drauburg,torabogurato,トラボグラート', 46.5880600, 15.0191700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124626, 'Dragomer', 'Dragomer', 'Dragomer', 46.0166700, 14.3833300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124627, 'Dornava', 'Dornava', 'Dornava,Dornova,Obcina Dornava,Občina Dornava,dorunavu~a,ドルナヴァ', 46.4366700, 15.9536100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124628, 'Domžale', 'Domzale', 'Domzale,Domzales,Domzhale,Domžale,Domžalės,Obcina Domzale,Občina Domžale,dmzhalh,domjalle,domujare,domzhale,duo mu zha lai,Домжале,דומזאלה,دمژاله,დომჟალე,ドムジャレ,多姆扎萊,돔잘레', 46.1377400, 14.5937100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124629, 'Dol pri Ljubljani', 'Dol pri Ljubljani', 'Dol,Dol pri Ljubljani,Lusttal,Obcina Dol pri Ljubljani,Občina Dol pri Ljubljani,ドル・プリ・リュブリャニ', 46.0886100, 14.6008300, 'SI', '2013-08-05', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124630, 'Dol pri Hrastniku', 'Dol pri Hrastniku', 'Dol,Dol pri Hrastniku', 46.1419400, 15.1127800, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124631, 'Dolenjske Toplice', 'Dolenjske Toplice', 'Toplice', 45.7565700, 15.0591700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124632, 'Dobrovo', 'Dobrovo', 'Castel Dobra,Dobrovo,Dobrovo v Brdih', 45.9963900, 13.5263900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124633, 'Dobrovnik', 'Dobrovnik', 'Dobronak,Dobrovnik,Dubrovnik', 46.6513900, 16.3525000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124634, 'Dobrova', 'Dobrova', 'Dobrova,Dobrova pri Ljubljani', 46.0458000, 14.3918600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124635, 'Dobrna', 'Dobrna', 'Doberna,Dobrna,Dobrno', 46.3375000, 15.2263900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124636, 'Dobje pri Planini', 'Dobje pri Planini', 'Dobje,Dobje pri Planini', 46.1374700, 15.3941200, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124637, 'Dob', 'Dob', 'Dob', 46.1519400, 14.6286100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124638, 'Divača', 'Divaca', 'Divaca,Divaccia,Divazza,Divača,divu~acha,ディヴァーチャ', 45.6847200, 13.9702800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124639, 'Destrnik', 'Destrnik', 'Desternik,Destrnik,Obcina Destrnik,Občina Destrnik,Sveti Urban,desutoruniku,デストルニク', 46.4925400, 15.8789300, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124640, 'Deskle', 'Deskle', 'Descla,Deskle', 46.0530700, 13.6138200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124641, 'Dekani', 'Dekani', 'Decani,Dekani,Pasja Vas,Villa Decani', 45.5497200, 13.8136100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124642, 'Črnomelj', 'Crnomelj', 'Chrnomel'',Crnomelj,Obcina Crnomelj,Občina Črnomelj,Tschernembl,cherunomeri,Črnomelj,Чрномель,チェルノメリ', 45.5711100, 15.1888900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124643, 'Črna na Koroškem', 'Crna na Koroskem', 'Crna,Crna na Koroskem,Črna,Črna na Koroškem', 46.4704500, 14.8500900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124644, 'Črenšovci', 'Crensovci', 'Crensovci,Cserencsocz,Cserencsócz,Cserfold,Cserföld,Črenšovci', 46.5579400, 16.3041000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124645, 'Černelavci', 'Cernelavci', 'Cernelavci,Crnelavci,Kisszombat,Černelavci,Črnelavci', 46.6666700, 16.1333300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124646, 'Cerkvenjak', 'Cerkvenjak', 'Cerkvenjak,Kirchberg,Sveti Anton', 46.5705600, 15.9436100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124647, 'Cerknica', 'Cerknica', 'Cerknica,Cerknicja,Circonio,Obcina Cerknica,Občina Cerknica,Zirknitz,cai er ke ni cha,cheleukeunicha,tsrknytsa,tsu~erukunitsu~a,tsyrknytsa,Церкница,Церкниця,تسركنيتسا,تسرکنیتسا,تسیرکنیتسا,ツェルクニツァ,采爾克尼察,체르크니차', 45.7930600, 14.3625000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124648, 'Cerklje na Gorenjskem', 'Cerklje na Gorenjskem', 'Cerklje,Cerklje na Gorenjskem,Zirklach', 46.2541700, 14.4886100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124649, 'Celje', 'Celje', 'Cel''e,Cele,Celeia,Celje,Celle,Celė,Cilli,Gorad Cehle,Tsel''e,Tselie,cai lie,chelle,se leiy,tselie,tslyh,tslyy,tsu~erye,zlyh,Τσέλιε,Горад Цэле,Целе,Целле,Цельє,Целје,Цеље,צליה,تسليي,تسلیه,تسیلیے,سیلیے,เซเลีย,ცელიე,ツェリェ,采列,첼레', 46.2309200, 15.2604400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124650, 'Cankova', 'Cankova', 'Cankova,Kaltenbrunn,Obcina Cankova,Občina Cankova,Vashidegkut,Vashidegkút,chankoba,tsankwwa,tsu~ankovu~a,Цанкова,تسانکووا,ツァンコヴァ,찬코바', 46.7208300, 16.0225000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124651, 'Britof', 'Britof', '', 46.2602400, 14.3903700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124652, 'Brezovica pri Ljubljani', 'Brezovica pri Ljubljani', 'Brezovica,Brezovica pri Ljubljani', 46.0333300, 14.4000000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124653, 'Brežice', 'Brezice', 'Brezhice,Brezice,Brežice,Gmina Brezice,Gmina Brežice,Obcina Brezice,Občina Brežice,Rann,beulejiche,brjytsy,brzhytsh,bu lei ri cai,burejitsu~e,Брежице,برجيتسي,برژیتسه,بریژیتسے,ブレージツェ,布雷日采,브레지체', 45.9033300, 15.5911100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124654, 'Bresternica', 'Bresternica', 'Bresternica,Brestrnica', 46.5697200, 15.5750000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124655, 'Braslovče', 'Braslovce', 'Braslovce,Braslovče,Male Braslovce,Male Braslovče,Obcina Braslovce,Občina Braslovče,burasurofuche,ブラスロフチェ', 46.2897200, 15.0388900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124656, 'Bovec', 'Bovec', 'Ampletium,Bovec,Bovecas,Flitsch,Gmina Bovec,Obcina Bovec,Občina Bovec,Plezzo,bo wei ci,bobecheu,bovu~etsu,bwts  aslwwny,bwwyts,bwwytsh,Бовец,بوتس، اسلوونی,بوويتش,بوویتس,ボヴェツ,博韋茨,보베츠', 46.3380800, 13.5524500, 'SI', '2017-03-18', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124657, 'Borovnica', 'Borovnica', 'Borovnica,Borovnicja,bo luo fu ni cha,bolobeunicha,borovunitsu~a,bwrwwnytsa  bwrwwnytsa,Боровница,Боровниця,بوروونیتسا، بوروونیتسا,ボロヴニツァ,博羅夫尼察,보로브니차', 45.9158300, 14.3630600, 'SI', '2016-05-05', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124064, 'Jonstorp', 'Jonstorp', 'Jonstorp', 56.2338000, 12.6718400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124065, 'Jönköping', 'Joenkoeping', 'Encheping,Gorad Jonchehping,Iunecopia,JKG,Jenceping,Jensepinga,Jensheping,Jenšēpinga,Jjonchjoping,Joenkoeping,Joenkoepings kommuna,Jonkoping,Jonsh''oping,Jonsiopingas,Jonšiopingas,Jönköping,Jönköpings kommuna,Jønkøping,jwnkwmng,yan xue ping,yein chex ping,yensyeping,yonshopingu shi,ywnshwbyngh,ywnshwpng,ywnshwpyn,ywnshwpyng,Єнчепінг,Јеншепинг,Јенћепинг,Горад Ёнчэпінг,Йоншьопинг,Йёнчёпинг,Йёньшөпин,جونکومنگ,يونشوبينغ,یونشوپنگ,یونشوپینگ,ܝܘܢܫܘܦܝܢ,เยินเชอปิง,იენჩეპინგი,ヨンショーピング市,延雪平,옌셰핑', 57.7814500, 14.1561800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124066, 'Jokkmokk', 'Jokkmokk', 'Jahkamahkke,Jockmock,Jokimukka,Jokkinokk,Jokkmokk,Jokmok,Jokmokk,Jåhkåmåhkke,Йоккмокк,Йокмок,Йокмокк', 66.6066500, 19.8232400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124067, 'Johannedal', 'Johannedal', 'Johannedal', 62.4342400, 17.3727300, 'SE', '2014-10-09', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124068, 'Järvsö', 'Jaervsoe', 'Jarfso,Jarvso,Järfsö,Järvsö,jarwsw,yarfsw,جاروسو,يارفسو', 61.7166700, 16.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124069, 'Järpen', 'Jaerpen', 'Hjerpen,Jaerpen,Jarpstrommen,Järpen', 63.3462000, 13.4657200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124070, 'Järna', 'Jaerna', '', 60.5333300, 14.3666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124071, 'Järna', 'Jaerna', 'Jarna,Järna', 59.0916500, 17.5661500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124072, 'Järbo', 'Jaerbo', 'Jarbo,Järbo', 60.7166700, 16.6000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124073, 'Jämshög', 'Jaemshoeg', 'Jamshog,Jämshög', 56.2333300, 14.5166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124074, 'Jämjö', 'Jaemjoe', 'Jamjo,Jämjö', 56.1918700, 15.8411500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124075, 'Jakobsberg', 'Jakobsberg', 'Jakobsberi,Якобсбери', 59.4226800, 17.8350800, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124076, 'Irsta', 'Irsta', '', 59.7000000, 16.9333300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124077, 'Irsta', 'Irsta', 'Irsta', 59.6000000, 16.7000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124078, 'Insjön', 'Insjon', 'Insjo,Insjoen,Insjon,Insjö,Insjön,Insjøn', 64.4000000, 17.4833300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124079, 'Insjön', 'Insjoen', 'Insjoen,Insjon,Insjön,Insjøn', 60.6768800, 15.0948700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124080, 'Ingelstad', 'Ingelstad', 'Ingelstad', 56.7500000, 14.9166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124081, 'Iggesund', 'Iggesund', 'Iggesund,Iggesunds Bruk', 61.6421900, 17.0747700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124082, 'Hyltebruk', 'Hyltebruk', '', 56.9989200, 13.2395800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124083, 'Hyllinge', 'Hyllinge', 'Hyllinge', 56.1000000, 12.8500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124084, 'Husum', 'Husum', 'Husum', 63.3333300, 19.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124085, 'Huskvarna', 'Huskvarna', 'Guskvarna,Huskvarna,Khuskvarna,hwskfarna,hwskwarna,hyusukuvu~ana,Гускварна,Хускварна,هوسكفارنا,هوسکوارنا,ヒュースクヴァーナ', 57.7859600, 14.3021400, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124086, 'Hunnebostrand', 'Hunnebostrand', '', 58.4412700, 11.3032000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124087, 'Hultsfred', 'Hultsfred', 'HLF,Khultsfred,hwltsfrd,Хултсфред,هولتسفرد', 57.4881500, 15.8435700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124088, 'Hudiksvall', 'Hudiksvall', 'Gudiksvall'',HUV,Hiudiksvalis,Hudicsovaldum,Khjudiksval,Khudiksval,Khudiksvall'',hu di ke si wa er,hudigseubal,hwdykswl,Гудіксвалль,Худиксвал,Худиксвалль,Хюдиксвал,هودیکسول,胡迪克斯瓦尔,후딕스발', 61.7274400, 17.1055800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124089, 'Huddinge', 'Huddinge', '', 59.2370500, 17.9819200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124090, 'Hovsta', 'Hovsta', 'Hovsta', 59.3500000, 15.2166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124091, 'Hovmantorp', 'Hovmantorp', '', 56.7868500, 15.1402300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124092, 'Höviksnäs', 'Hoeviksnaes', 'Hovik,Hoviksnas,Hövik,Höviksnäs', 58.0333300, 11.7666700, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124093, 'Hova', 'Hova', 'Hofva,Hova', 58.8536300, 14.2191400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124094, 'Horred', 'Horred', 'Horred', 57.3547500, 12.4777700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124095, 'Hörnefors', 'Hoernefors', 'Hoernefors,Hornefors,Hörnefors,Hørnefors', 63.6231200, 19.9085600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124096, 'Horndal', 'Horndal', 'Horndal,Horndals Bruk', 60.3000000, 16.4166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124097, 'Hörby', 'Hoerby', 'Hoerby,Horby,Hörby,Hørby,Kh''orbju,hwrbh,Хьорбю,هوربه', 55.8523800, 13.6609400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124098, 'Höör', 'Hoeoer', 'Hoeoer,Hoor,Höör,Høør,Kh''ojor,hwywr,Хьойор,هوئور', 55.9344400, 13.5385000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124099, 'Hönö', 'Hoenoe', 'Hoenoe,Hono,Hono Klava,Hönö,Hönö Klava,Hønø', 57.6897200, 11.6497200, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124100, 'Hölö', 'Holo', 'Hoeloe,Holo,Hölö,Hølø', 59.2833300, 18.6666700, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124101, 'Hölö', 'Hoeloe', 'Hoeloe,Holo,Hölö,Hølø', 59.0166700, 17.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124102, 'Höllviken', 'Hoellviken', 'Hoellviken,Hollviken,Hollviksnas,Höllviken,Höllviksnäs,Høllviken,Kh''olviken,Khelviken,hwlwykn,Хелвикен,Хьолвикен,هولویکن', 55.4098200, 12.9558000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124103, 'Hököpinge', 'Hoekoepinge', 'Hoekoepinge,Hokopinge,Hököpinge,Høkøpinge', 55.4941100, 13.0078200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124104, 'Hökåsen', 'Hoekasen', 'Hockasen,Hoekasen,Hokasen,Höckåsen,Hökåsen,Høkåsen', 59.6666700, 16.5833300, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124105, 'Högsby', 'Hoegsby', 'Hoegsby,Hogsby,Högsby,Høgsby', 57.1659700, 16.0256200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124106, 'Höganäs', 'Hoeganaes', 'Hioganesas,Kh''oganes,Kheganes,Khjoganes,hwgans,Хеганес,Хьоганес,Хёганес,هوگانس', 56.1997100, 12.5579500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124107, 'Hofterup', 'Hofterup', 'Hofterup', 55.8048500, 12.9797000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124108, 'Hofors', 'Hofors', 'Khuforsh,hwfwsh,Хуфорш,هوفوش', 60.5457300, 16.2866800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124109, 'Hjuvik', 'Hjuvik', 'Hjulvik,Hjuvik', 57.7016700, 11.7163900, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124110, 'Hjo', 'Hjo', 'Hiovia,JU,ywa,Ю,یوا', 58.3013300, 14.2878400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124111, 'Hjärnarp', 'Hjaernarp', 'Hjarnarp,Hjärnarp', 56.3166700, 12.9166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124112, 'Hittarp', 'Hittarp', '', 56.2833300, 14.1166700, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124113, 'Hittarp', 'Hittarp', 'Hiltarp,Hittarp', 56.1000000, 12.6333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124114, 'Hindås', 'Hindas', 'Hindas,Hindås', 57.7033800, 12.4465700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124115, 'Hillerstorp', 'Hillerstorp', '', 57.3129300, 13.8843700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124116, 'Hestra', 'Hestra', '', 57.9166700, 14.5833300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124117, 'Hestra', 'Hestra', 'Hestra,Hostro', 57.4423200, 13.5957500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124118, 'Herrljunga', 'Herrljunga', 'Kherjunga,XYC,Херюнга', 58.0773900, 13.0266200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124119, 'Herrestad', 'Herrestad', '', 58.3833300, 14.8000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124120, 'Henån', 'Henan', '', 58.2384800, 11.6759800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124121, 'Hemse', 'Hemse', 'Khemse,Хемсе', 57.2378800, 18.3744300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124122, 'Hemmesta', 'Hemmesta', 'Hemmesta', 59.3166700, 18.5000000, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124123, 'Helsingborg', 'Helsingborg', 'AGH,Chelsin''nkmpornk,Gel''sinborg,Gorad Khel''singbarg,Haelsingborg,Helsingborg,Helsingborgas,Helsingborja,Helsingjaborg,Helsingoburgum,Hälsingborg,Khel''sinborg,Khel''singborg,Khelsingborg,Khelsingbori,he er xin bao,hel si ngb xry,helsingboli,helsingborgi,herushinbori,hlsyngbwrg,hlsynghbwrgh,xi xing bao,Χέλσινγκμποργκ,Гельсінборг,Горад Хельсінгбарг,Хелсингборг,Хелсингбори,Хельсинборг,Хельсингборг,הלסינגבורג,هلسينغبورغ,هلسینگبورگ,ہلسنگبورگ,เฮลซิงบอรย์,ჰელსინგბორგი,ヘルシンボリ,希星堡,赫尔辛堡,헬싱보리', 56.0467300, 12.6943700, 'SE', '2017-04-02', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124124, 'Hedesunda', 'Hedesunda', 'Hedesunda', 60.4000000, 17.0000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124125, 'Hedemora', 'Hedemora', 'Hedemora,Hedemora gielda,Khedemura,XXU,Хедемура,هده‌مورا', 60.2797300, 15.9885500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124126, 'Heby', 'Heby', 'Khebi,Khebju,Хеби,Хебю', 59.9381500, 16.8621700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124127, 'Haverdal', 'Haverdal', 'Haverdal', 56.7222200, 12.6719400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124128, 'Hästveda', 'Haestveda', 'Hastveda,Hästveda', 56.2846800, 13.9354700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124129, 'Hasslö', 'Hassloe', 'Hasslo,Hassloe,Hasslö,Hasslø', 56.1166700, 15.4833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124130, 'Hässleholm', 'Haessleholm', 'Gorad Khehslekhal''m,Haessleholm,Hesleholmas,Hässleholm,Kheslekhol''m,Kheslekholm,XWP,hai si lei huo er mu,heseulleholleum,hslhwlm,Горад Хэслехальм,Хеслехолм,Хеслехольм,هسلهولم,海斯勒霍尔姆,헤슬레홀름', 56.1590500, 13.7663800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124131, 'Harplinge', 'Harplinge', 'Harplinge', 56.7449100, 12.7275800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124132, 'Härnösand', 'Haernoesand', 'Haernoesand,Herniosandas,Hernosandia,Hernusando,Härnösand,Khern''osand,Khernesand,Khernjosand,SDL,hai ne sang de,harnwsand,heleunoesandeu,hrnwsnd,Хернесанд,Херньосанд,Хернёсанд,هارنوساند,هرنوسند,海訥桑德,헤르뇌산드', 62.6322800, 17.9379400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124133, 'Haninge', 'Haninge', '', 59.1677500, 18.1447800, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124134, 'Handen', 'Handen', 'Khanden,Ханден', 59.1680900, 18.1379600, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124135, 'Hanaskog', 'Hanaskog', 'Hanaskog', 56.1606100, 14.0930700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124136, 'Hammerdal', 'Hammerdal', 'Hammerdal', 63.5761500, 15.3651600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124137, 'Hammarstrand', 'Hammarstrand', '', 63.1104100, 16.3537700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124138, 'Hammar', 'Hammar', 'Hammar', 56.0166700, 14.2166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124139, 'Halmstad', 'Halmstad', 'Gal''mstad,Gorad Khal''mstad,HAD,Halmostadium,Halmstad,Halmstadas,Hamstad,Khal''mstad,Khalmstad,ha er mu si ta de,halleumseutadeu,halms ta,halmstad,harumusutaddo,Гальмстад,Горад Хальмстад,Халмстад,Хальмстад,האלמסטד,هالمستاد,ہالمستا,ہالمسٹاڈ,ฮาล์มสตา,ჰალმსტადი,ハルムスタッド,哈尔姆斯塔德,할름스타드', 56.6744600, 12.8567600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124140, 'Hallstavik', 'Hallstavik', 'Hallstavik', 60.0500000, 18.6000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124141, 'Hallstahammar', 'Hallstahammar', 'Khalstakhamar,hlstwymmr,Халстахамар,هلستوئممر', 59.6139500, 16.2284600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124142, 'Hallsberg', 'Hallsberg', 'Khall''sberg,Khalsberi,XWM,hlzbryh,Халльсберг,Халсбери,هلزبریه', 59.0646300, 15.1099300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124143, 'Hällevik', 'Haellevik', 'Hallevik,Hällevik', 56.0166700, 14.7000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124144, 'Hälleforsnäs', 'Haelleforsnaes', 'Halleforsnas,Hälleforsnäs', 59.1520800, 16.4970000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124145, 'Hällefors', 'Haellefors', 'Kheleforsh,Хелефорш', 59.7838800, 14.5219700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124146, 'Hällbybrunn', 'Haellbybrunn', 'Hallbybrunn,Hällbybrunn', 59.3915200, 16.4222900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124147, 'Hällabrottet', 'Hallabrottet', 'Hallabrottet,Hallebrottet,Hällabrottet,Hällebrottet', 59.1166700, 15.2000000, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124148, 'Häljarp', 'Haeljarp', 'Haljarp,Häljarp', 55.8500000, 12.9166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124149, 'Hagfors', 'Hagfors', 'HFS,Hagsfors,Khagfors,Khagforsh,Khagfosh,ha ge fu shen,hagfwsh,haghfwrs,Хагфорс,Хагфорш,Хагфош,هاغفورس,هاگفوش,ᐊᒡᕗᕐᔅ,哈格福什', 60.0237800, 13.6721400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124150, 'Habo', 'Habo', 'Khabu,habw,Хабу,هابو,ہابو', 57.9118500, 14.0744400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124151, 'Gusum', 'Gusum', 'Gusum', 58.2688000, 16.4989400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124152, 'Gustavsberg', 'Gustavsberg', 'Gustarsberg,Gustavsberg,Gustavsberi,gwstawzby  wrmdw,Густавсберг,Густавсбери,گوستاوزبی، ورمدو', 59.3268400, 18.3897500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124153, 'Gunnebo', 'Gunnebo', 'Gunnebo,Gunnebobruk', 57.7166700, 16.5333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124154, 'Gullspång', 'Gullspang', '', 58.9861500, 14.0964400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124155, 'Gullbrandstorp', 'Gullbrandstorp', 'Gullbrandstorp', 56.7000000, 12.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124156, 'Grycksbo', 'Grycksbo', 'Grycksbo', 60.6875100, 15.4850700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124157, 'Grums', 'Grums', 'Grums,grwmz,Грумс,گرومز,ግሩምስ,ᒡᕈᒻᔅ', 59.3514100, 13.1110500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124158, 'Grillby', 'Grillby', 'Grillby', 59.6260300, 17.2578700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124159, 'Grebo', 'Grebo', 'Grebo', 58.3014500, 15.8708500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124160, 'Grebbestad', 'Grebbestad', 'Grabbestad,Grebbestad,Gräbbestad,Греббестад', 58.7024800, 11.2573800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124161, 'Grästorp', 'Graestorp', '', 58.3321900, 12.6812200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124162, 'Gränna', 'Graenna', 'Graenna,Grehnna,Grena,Gränna,Грена,Грэнна', 58.0166700, 14.4666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124163, 'Grängesberg', 'Graengesberg', 'Grangesberg,Grengesberg,Grengesberi,Grängesberg,Гренгесберг,Гренгесбери', 60.0746500, 15.0078400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124164, 'Gråbo', 'Grabo', '', 57.8362500, 12.2995400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124165, 'Götene', 'Goetene', 'Goetene,Gotene,Götene,Gøtene,Jjotene,Jotene,Йотене,Йётене', 58.5282400, 13.4945800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124166, 'Göteborg', 'Goeteborg', 'G''oteborg,GOT,Gautaborg,Geteborg,Geteborga,Geteborgas,Gjoteborg,Goeteborg,Goeteborq,Gorad Gjotehbarg,Goteborg,Goteburg,Gotemburgo,Gotenburg,Gothembourg,Gothenburg,Gothoburgum,Gotnburg,Gottenborg,Göteborg,Göteborq,Gøteborg,Gēteborga,Nketempornk,ge de bao,ghwtnbrgh,gtbwrg,jwtnbrj,kx then beirk,yeteboli,yohateborya,yotebori,ywtbry,Γκέτεμποργκ,Гетеборг,Горад Гётэбарг,Гьотеборг,Гётеборг,גטבורג,געטעבארג,جوتنبرج,غوتنبرغ,گووتھنبرگ,یوتبری,योहतेबोर्य,กอเทนเบิร์ก,გეტებორგი,ዬተቦርይ,ᐃᐅᑕᐳᕆ,ヨーテボリ,哥德堡,예테보리', 57.7071600, 11.9667900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124167, 'Göta', 'Goeta', 'Goeta,Gota,Göta,Gøta', 58.1061700, 12.1525400, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124168, 'Gnosjö', 'Gnosjoe', 'Gnosjo,Gnosjoe,Gnosjö,Gnosjø', 57.3585000, 13.7368600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124169, 'Gnesta', 'Gnesta', '', 59.0475100, 17.3119100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124170, 'Gnarp', 'Gnarp', 'Gnarp', 62.0487400, 17.2585800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124171, 'Glumslöv', 'Glumsloev', 'Glumsloev,Glumslov,Glumslöv,Glumsløv', 55.9409100, 12.8092900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124172, 'Glommen', 'Glommen', 'Glommen', 56.9333300, 12.3500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124173, 'Glimåkra', 'Glimakra', 'Glimakra,Glimåkra', 56.3000000, 14.1333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124174, 'Gislaved', 'Gislaved', 'Islaved,Jislaved,gyzlwyd,Иславед,Йиславед,گیزلوئد', 57.3044000, 13.5407800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124175, 'Getinge', 'Getinge', 'Getinge', 56.8166700, 12.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124176, 'Genarp', 'Genarp', 'Genarp', 55.5990700, 13.3982000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124177, 'Gemla', 'Gemla', 'Gemla', 56.8675300, 14.6437900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124178, 'Gävle', 'Gaevle', 'Evle,GVX,Gaefle,Gaevle,Gefle,Gevalia,Gorad Eule,Gäfle,Gävle,Jevle,Jevlė,Jēvle,evle,i~evure,yblh,ye fu lei,yebeulle,yefle,yflh,ywlh,Євле,Јевле,Горад Еўле,Евле,Йевле,יבלה,يفله,گاولے,یاولہ,یوله,เยฟเล,ევლე,イェヴレ,耶夫勒,예블레', 60.6745200, 17.1417400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124179, 'Gärsnäs', 'Gaersnaes', 'Garsnas,Gärsnäs', 55.5494900, 14.1792300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124180, 'Garphyttan', 'Garphyttan', '', 59.3042900, 14.9462300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124181, 'Gantofta', 'Gantofta', 'Ganntofta,Gantofta', 55.9872900, 12.8048200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124182, 'Gånghester', 'Ganghester', 'Ganghester,Gånghester', 57.7000000, 13.0166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124183, 'Gamleby', 'Gamleby', 'Gamleby', 57.8948500, 16.4050800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124184, 'Gamla Uppsala', 'Gamla Uppsala', 'Alt-Uppsala,Gamla Uppsala,Gamle Uppsala,Staraja Uppsala,Staraja Upsala,Vanha Uppsala,jmla awbsala,Старая Уппсала,Старая Упсала,جملا أوبسالا,ጋምላ ኡፕሳላ,ガムラ・ウプサラ', 59.8981700, 17.6338600, 'SE', '2014-10-12', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124185, 'Gagnef', 'Gagnef', '', 60.5985600, 15.0774500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124186, 'Fyllinge', 'Fyllinge', 'Fyllinge', 56.6500000, 12.9166700, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124187, 'Furulund', 'Furulund', '', 57.7166700, 12.1333300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124188, 'Furulund', 'Furulund', 'Furulund', 55.7738000, 13.0902200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124189, 'Frövi', 'Froevi', 'Froevi,Frovi,Frövi,Frøvi', 59.4666700, 15.3666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124190, 'Frösakull', 'Froesakull', 'Froesakull,Frosakull,Frösakull,Frøsakull', 56.6833300, 12.7333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124191, 'Fritsla', 'Fritsla', 'Frissla,Fritsla', 57.5565500, 12.7845700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124192, 'Fristad', 'Fristad', 'Fristad', 57.8248300, 13.0106400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124193, 'Frillesås', 'Frillesas', 'Frillesas,Frillesås', 57.3166700, 12.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124194, 'Fränsta', 'Fraensta', 'Fransta,Fränsta', 62.4985500, 16.1701600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124195, 'Förslöv', 'Foersloev', 'Foersloev,Foersloevsholm,Forslov,Forslovholm,Förslöv,Förslövholm,Förslövsholm,Førsløv', 56.3500000, 12.8166700, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124196, 'Forsheda', 'Forsheda', 'Forsheda', 57.1641500, 13.8301600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124197, 'Forshaga', 'Forshaga', '', 59.5254100, 13.4812700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124198, 'Forserum', 'Forserum', 'Forserum', 57.7000000, 14.4666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124199, 'Forsbacka', 'Forsbacka', 'Forsbacka', 60.6166700, 16.8833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124200, 'Floby', 'Floby', 'Floby', 58.1333300, 13.3333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124201, 'Flen', 'Flen', 'Flen,XYI,fln,Флен,فلن', 59.0583400, 16.5878100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124202, 'Fjugesta', 'Fjugesta', '', 59.1737500, 14.8722700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124203, 'Fjärås kyrkby', 'Fjaeras kyrkby', '', 57.4591300, 12.1750800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124204, 'Fjälkinge', 'Fjaelkinge', 'Fjalkinge,Fjälkinge', 56.0436400, 14.2756200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124205, 'Fittja', 'Fittja', '', 59.2486800, 17.8599100, 'SE', '2011-08-16', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124206, 'Finspång', 'Finspang', 'Finspong,Finspongas,fynspang,Финспонг,فینسپانگ', 58.7057800, 15.7673900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124207, 'Filipstad', 'Filipstad', 'Filipstad,Filipstad i Sverige,fei li pu si ta de,fylypstad,Филипстад,Філіпстад,فیلیپستاد,ᕕᓕᑉᔅᑕᑦ,菲利普斯塔德', 59.7123600, 14.1683100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124208, 'Fellingsbro', 'Fellingsbro', 'Fellingsbro', 59.4333300, 15.5833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124209, 'Färlöv', 'Faerloev', 'Farlov,Färlöv', 56.0666700, 14.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124210, 'Färjestaden', 'Faerjestaden', 'Ferestaden,Ферестаден', 56.6499000, 16.4685900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124211, 'Färila', 'Faerila', 'Farila,Färila', 61.8001100, 15.8442200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124212, 'Färgelanda', 'Faergelanda', '', 58.5681600, 11.9923500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124213, 'Falun', 'Falun', 'BLE,Fahlun,Faliunas,Falun,Faluna,Falunga,Fāluna,Gorad Falun,fa lun,faln,falwn,farun,pallun,paluni,Горад Фалун,Фалун,Ֆալուն,فالن,فالون,ฟาลุน,ფალუნი,ファールン,法倫,팔룬', 60.6035700, 15.6259700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124214, 'Falköping', 'Falkoeping', 'Fal''chjoping,Falceping,Falcopia,Falkoeping,Falkoping,Falköping,Falkøping,Falsh''oping,Falsiopingas,Falšiopingas,XYF,fa er xue ping,falkwpyng,falshwpyng,farushepingu,Фалшьопинг,Фальчёпинг,Фалћепинг,فالشوپینگ,فالکوپینگ,ファルシェーピング,法爾雪平', 58.1734700, 13.5506800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124215, 'Falkenberg', 'Falkenberg', 'Fal''kenberg,Falkenberg,Falkenbergas,Falkenbergs,Falkenberi,XYM,fa er ken bei li,falknbrgh,farukenberi,flknby,palkenbeli,Фалкенберг,Фалкенбери,Фалькенберг,فالكنبرغ,فلکنبی,ファルケンベリ,法尔肯贝里,팔켄베리', 56.9055200, 12.4911800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124216, 'Fagersta', 'Fagersta', 'Fagershha,Fagersta,Fagersta Bruk,Fagesta,Fagešta,fgshth,Фагерста,Фагерща,فاگیرسٹا,فگشته', 60.0041800, 15.7931600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124217, 'Eslöv', 'Esloev', 'Ehsljov,Esl''ov,Eslev,Esliovas,Esloev,Eslov,Eslöv,Esløv,aslw,eseulloebeu,Еслев,Есльов,Эслёв,اسلو,에슬뢰브', 55.8392800, 13.3039300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124218, 'Eskilstuna', 'Eskilstuna', 'EKT,Ehskil''stuna,Eshilstruna,Eskil''stuna,Eskilstiuna,Eskilstjuna,Eskilstouna,Eskilstuna,Eskilstūna,Gorad Ehskil''stuna,ai si ji er si di na,asklstwna,askylstwna,eseukilseutuna,eshirusuto~una,Εσκιλστούνα,Горад Эскільстуна,Ескилстюна,Ескільстуна,Ешилструна,Эскильстуна,إسكيلستونا,اسکلستونا,اسکیلستونا,ესკილსტუნა,エシルストゥーナ,埃斯基尔斯蒂纳,에스킬스투나', 59.3666100, 16.5077000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124219, 'Eriksberg', 'Eriksberg', '', 59.2424100, 17.8163100, 'SE', '2011-08-16', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124220, 'Enköping', 'Enkoeping', 'Ehnchjoping,Enceping,Enecopia,Enkoeping,Enkoping,Enköping,Enkøping,Ensh''oping,Ensiopingas,Enšiopingas,anshwpyng,enshepingu,Еншьопинг,Енћепинг,Энчёпинг,انشوپینگ,エンシェーピング', 59.6360700, 17.0776800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124221, 'Enebyberg', 'Enebyberg', 'Enebyberg,Enebybergs,Enebybergs Villastad', 59.4333300, 18.0500000, 'SE', '2017-02-24', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124222, 'Enbacka', 'Enbacka', '', 60.4099300, 15.5957500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124223, 'Emmaboda', 'Emmaboda', '', 56.6326800, 15.5364800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124224, 'Ellös', 'Elloes', 'Ehlljos,Elloes,Ellos,Ellös,Elløs,Эллёс', 58.1833300, 11.4666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124225, 'Eksjö', 'Eksjoe', 'Eksjo,Eksjoe,Eksjö,Eksjø', 57.6664300, 14.9720500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124226, 'Ekshärad', 'Ekshaerad', '', 60.1727500, 13.4964700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124227, 'Ekerö', 'Ekeroe', 'Ekero,Ekeroe,Ekerö,Ekerø', 59.2910000, 17.8121200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124228, 'Ekenässjön', 'Ekenaessjoen', 'Ekenassjon,Ekenässjön', 57.4917500, 15.0222600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124229, 'Ekeby-Almby', 'Ekeby-Almby', 'Ekeby-Almby', 59.2600000, 15.3300000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124230, 'Ekängen', 'Ekaengen', 'Ekangen,Ekängen', 58.4666700, 15.6333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124231, 'Edsbyn', 'Edsbyn', '', 61.3769200, 15.8174700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124232, 'Ed', 'Ed', '', 58.9124700, 11.9330800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124233, 'Dorotea', 'Dorotea', 'Bergvattnet,Doeoerte,Dorotea,Döörte', 64.2618500, 16.4130600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124234, 'Donsö', 'Donsoe', 'Donso,Donsoe,Donsö,Donsø', 57.6000000, 11.7991700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124235, 'Djursholm', 'Djursholm', 'Jurshkholm,Юршхолм', 59.3992600, 18.0561900, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124236, 'Djurö', 'Djuroe', 'Djuro,Djuroe,Djurö,Djurø', 59.3265300, 18.7115200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124237, 'Djurås', 'Djuras', 'Djuras,Djurås', 60.5606100, 15.1328100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124238, 'Diseröd', 'Diseroed', 'Diserod,Diseroed,Diseröd,Diserød', 57.9263600, 12.0259800, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124239, 'Dingtuna', 'Dingtuna', 'Dingtuna', 59.5727900, 16.3872200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124240, 'Delsbo', 'Delsbo', '', 61.8010400, 16.5557100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124241, 'Deje', 'Deje', 'Deje', 59.6030000, 13.4720000, 'SE', '2017-07-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124242, 'Degerfors', 'Degerfors', 'Degerforsh,Degerfosas,Degerfošas,dghrfwsh,dgrfwsh,Дегерфорш,دغرفوش,دگرفوش', 59.2379700, 14.4307700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124243, 'Degeberga', 'Degeberga', 'Degeberga', 55.8333300, 14.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124244, 'Dals Långed', 'Dals Langed', 'Dals Langed,Dals Långed,Langed,Långed', 58.9255500, 12.3086500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124245, 'Dalsjöfors', 'Dalsjoefors', 'Dalsjoefors,Dalsjofors,Dalsjöfors,Dalsjøfors', 57.7166700, 13.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124246, 'Dalby', 'Dalby', '', 55.6665500, 13.3497600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124247, 'Dalarö', 'Dalaroe', 'Dalaro,Dalaroe,Dalarö,Dalarø', 59.1330600, 18.4063900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124248, 'Charlottenberg', 'Charlottenberg', '', 59.8842200, 12.3039800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124249, 'Bunkeflostrand', 'Bunkeflostrand', 'Bunkeflostrand', 55.5447800, 12.9237500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124250, 'Bua', 'Bua', '', 57.2361500, 12.1139700, 'SE', '2017-07-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124251, 'Bua', 'Bua', 'Bua', 57.2333300, 12.1333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124252, 'Brunna', 'Brunna', '', 60.2625500, 16.0103400, 'SE', '2017-07-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124253, 'Brunna', 'Brunna', 'Brunna', 59.5166700, 17.7500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124254, 'Brunn', 'Brunn', '', 59.2800000, 18.4300000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124255, 'Brunflo', 'Brunflo', 'Brunflu,Брунфлу', 63.0758600, 14.8320300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124256, 'Bromölla', 'Bromoella', 'Bromoella,Bromolla,Bromölla,Bromølla,Brum''ola,Brumjolla,brwmwlla,Брумьола,Брумёлла,بروموللا', 56.0755100, 14.4695800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124257, 'Bromma', 'Bromma', 'Bromma,Bromma stadsdelsomrade,Bromma stadsdelsområde', 59.3400000, 17.9400000, 'SE', '2010-06-22', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124258, 'Broby', 'Broby', 'Broby kyrkoby,Brody Kyrkoby', 56.2552100, 14.0779700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124259, 'Bro', 'Bro', 'Bro', 59.5166700, 17.6333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124260, 'Brevik', 'Brevik', 'Brevik', 59.3500000, 18.2000000, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124261, 'Brevik', 'Brevik', 'Bredvik,Brevik', 59.2166700, 18.3833300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124262, 'Bredbyn', 'Bredbyn', '', 63.4465500, 18.1101900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124263, 'Bredaryd', 'Bredaryd', 'Bredaryd', 57.1734300, 13.7378900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124264, 'Brastad', 'Brastad', 'Brastad', 58.3833300, 11.4833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124265, 'Brålanda', 'Bralanda', 'Bralanda,Brålanda', 58.5634400, 12.3492300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124266, 'Bräkne-Hoby', 'Braekne-Hoby', 'Brakne-Hoby,Bräkne-Hoby', 56.2333300, 15.1166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124267, 'Bräcke', 'Braecke', '', 62.7506700, 15.4219300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124268, 'Braås', 'Braas', 'Braas,Braås', 57.0666700, 15.0500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124269, 'Boxholm', 'Boxholm', '', 58.1971900, 15.0537600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124270, 'Borlänge', 'Borlaenge', 'BLE,Borlaenge,Borlenge,Borlänge,Burlange,Burlenge,Burlengė,bolleng-e,burlenge,bwrlanj,bwrlnyh,Борленге,Бурленге,Бурлӓнге,بورلانج,بورلنیه,ბურლენგე,볼렝에', 60.4858000, 15.4371400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124271, 'Borgholm', 'Borgholm', 'Borgholm,Borgkhol''m,Borikholm,bwrghhwlm,Боргхольм,Борихолм,بورغهولم', 56.8793000, 16.6563400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124272, 'Borensberg', 'Borensberg', 'Borensberg,Burensberi,Буренсбери', 58.5666700, 15.2833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124273, 'Borås', 'Boras', 'Boerosia,Boras,Boros,Borås,Buros,Burosa,Burosas,Celfsborg,Gorad Buras,boloseu,borosu,bu luo si,bu ros,burosi,bwras,bwrws,Борос,Бурос,Горад Бурас,בורוס,بوراس,بوروس,บูโรส,ბუროსი,ボロース,布羅斯,보로스', 57.7210100, 12.9401000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124274, 'Bor', 'Bor', 'Bor', 57.1166700, 14.1666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124275, 'Bollstabruk', 'Bollstabruk', 'Bollsta,Bollstabruk', 62.9977700, 17.6734800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124276, 'Bollnäs', 'Bollnaes', 'Boll''nes,Bolnes,Bolnesas,bo er nai si,borunesu,bwlns,Болльнес,Болнес,بولنس,ボルネス,博爾奈斯', 61.3481700, 16.3946400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124277, 'Bollmora', 'Bollmora', 'Boollmora', 59.2419600, 18.2276200, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124278, 'Bollebygd', 'Bollebygd', '', 57.6686600, 12.5727200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124279, 'Bodafors', 'Bodafors', 'Bodafors', 57.5000000, 14.7000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124280, 'Boo', 'Boo', 'Bo,Boo', 59.3333300, 18.2833300, 'SE', '2017-04-07', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124281, 'Blomstermåla', 'Blomstermala', 'Blomstermala,Blomstermåla', 56.9833300, 16.3333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124282, 'Blentarp', 'Blentarp', 'Blentarp', 55.5833300, 13.6000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124283, 'Bjuv', 'Bjuv', '', 56.0837200, 12.9191400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124284, 'Bjursås', 'Bjursas', 'Bjursas,Bjursås', 60.7372600, 15.4529100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124285, 'Bjurholm', 'Bjurholm', '', 63.9302700, 19.2136900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124286, 'Björneborg', 'Bjoerneborg', 'Bjoerneborg,Bjorneborg,Bjorneborgs,Bjorneborgs bruk,Björneborg,Björneborgs,Björneborgs bruk,Bjørneborg', 59.2412200, 14.2494200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124287, 'Björlanda', 'Bjoerlanda', 'Bjoerlanda,Bjorlanda,Björlanda,Bjørlanda', 57.7666700, 11.8333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124288, 'Björkö', 'Bjoerkoe', 'Bjoerkoe,Bjorko,Björkö,Bjørkø', 57.7322100, 11.6791600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124289, 'Björklinge', 'Bjoerklinge', 'B''orklinge,Bjoerklinge,Bjorklinge,Björklinge,Bjørklinge,Бьорклинге', 60.0333300, 17.5500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124290, 'Björboholm', 'Bjoerboholm', 'Bjoerboholm,Bjorboholm,Björboholm,Bjørboholm', 57.8709600, 12.3254600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124291, 'Bjästa', 'Bjaesta', 'Bjasta,Bjästa', 63.2000000, 18.5000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124292, 'Bjärred', 'Bjaerred', 'Bjarred,Bjärred', 55.7166700, 13.0166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124293, 'Bjärnum', 'Bjaernum', 'Bjarnum,Bjärnum', 56.2903200, 13.7112800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124294, 'Billingsfors', 'Billingsfors', 'Billingsfors', 58.9833300, 12.2500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124295, 'Billesholm', 'Billesholm', 'Billesholm', 56.0500000, 13.0000000, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124296, 'Billeberga', 'Billeberga', 'Billeberga', 55.8833300, 13.0000000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124297, 'Billdal', 'Billdal', 'Billdal', 57.5666700, 11.9333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124298, 'Bergsjö', 'Bergsjoe', 'Bergsjo,Bergsjoe,Bergsjö,Bergsjø', 61.9825300, 17.0636800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124299, 'Bergshamra', 'Bergshamra', '', 59.3808300, 18.0342700, 'SE', '2010-03-28', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124300, 'Hoverberg', 'Hoverberg', 'Berg,Bergsbyn', 62.8138100, 14.4473500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124301, 'Bergkvara', 'Bergkvara', '', 56.3906300, 16.0727400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124302, 'Bergeforsen', 'Bergeforsen', 'Bergeforsen', 62.5307400, 17.3812300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124303, 'Bergby', 'Bergby', 'Bergby', 60.9293100, 17.0419400, 'SE', '2017-03-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124304, 'Berg', 'Berg', '', 58.4883100, 15.5296900, 'SE', '2010-05-05', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124305, 'Bengtsfors', 'Bengtsfors', 'Bengtsforsh,Бенгтсфорш', 59.0291200, 12.2320700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124306, 'Båstad', 'Bastad', 'Bostad,bashtad,bo si ta de,Бостад,باشتاد,博斯塔德', 56.4268900, 12.8533900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124307, 'Bårslöv', 'Barsloev', 'Barsloev,Barslov,Bårslöv,Bårsløv', 56.0091000, 12.8058000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124308, 'Barkarö', 'Barkaroe', 'Bakaroby,Barkaro,Barkaroe,Barkarö,Barkarø', 59.5493500, 16.5074000, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124309, 'Bara', 'Bara', '', 58.6833300, 17.0666700, 'SE', '2017-02-03', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124310, 'Bara', 'Bara', '', 55.5815500, 13.1786200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124311, 'Bankeryd', 'Bankeryd', 'Bankeryd', 57.8602100, 14.1240000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124312, 'Bålsta', 'Balsta', 'Bolsta,bwlsta,Болста,بولستا', 59.5671000, 17.5278100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124313, 'Bälinge', 'Baelinge', 'Balinge,Balingeby,Bälinge,Bälingeby', 59.9500000, 17.5333300, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124314, 'Axvall', 'Axvall', 'Axvall', 58.3833300, 13.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124315, 'Avesta', 'Avesta', 'Avesta,XYP', 60.1427400, 16.1629500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124316, 'Åtvidaberg', 'Atvidaberg', 'Atvid,Otvidabergas,Otvidaberi,awtwydbryh,Åtvid,Отвидабери,اوتویدبریه', 58.2015200, 15.9977000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124317, 'Åstorp', 'Astorp', 'Ostorp,awstwlp,Осторп,اوستولپ', 56.1356600, 12.9443000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124318, 'Asmundtorp', 'Asmundtorp', 'Asmundtorp,Assmundtorp', 55.8833300, 12.9333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124319, 'Askersund', 'Askersund', 'Askershund,Аскершунд', 58.8798800, 14.9023000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124320, 'Åsele', 'Asele', 'Asele,Osele,Sjeltie,Åsele,Оселе', 64.1602600, 17.3476200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124321, 'Åseda', 'Aseda', '', 57.1701000, 15.3443000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124322, 'Åsbro', 'Asbro', 'Asbro,Åsbro', 59.0000000, 15.0500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124323, 'Åsa', 'Asa', 'Asa,Åsa', 57.3500000, 12.1166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124324, 'Ås', 'As', '', 63.3666700, 16.5833300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124325, 'Ås', 'As', 'As,Ås', 63.2500000, 14.5666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124326, 'Arvika', 'Arvika', 'Arvika,Oscarsstad,XYY,a er wei ka,arwyka,Арвика,ارویکا,ᐊᕐᕕᑲ,阿爾維卡', 59.6552800, 12.5851800, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124327, 'Arvidsjaur', 'Arvidsjaur', 'AJR,Arvids''jaur,Arvidsjaur,Arvidsujaur,Арвидсъяур,Арвидсяур,Арвідсьяур', 65.5903300, 19.1668200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124328, 'Årsunda', 'Arsunda', 'Arsunda,Årsunda', 60.5164400, 16.7343600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124329, 'Årsta', 'Arsta', '', 59.2978000, 18.0514000, 'SE', '2010-08-28', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124330, 'Arnö', 'Arno', 'Arno,Arnoe,Arnö,Arnø', 60.1166700, 18.6333300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124331, 'Arnö', 'Arnoe', 'Arno,Arnoe,Arnö,Arnø', 58.7267500, 17.0232200, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124332, 'Arlöv', 'Arloev', 'Arl''ov,Arloev,Arlov,Arlöv,Arløv,Арльов', 55.6324800, 13.0714100, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124333, 'Ärla', 'AErla', 'Arla,Ärla', 59.2798300, 16.6789600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124334, 'Arjeplog', 'Arjeplog', '', 66.0517300, 17.8860600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124335, 'Årjäng', 'Arjaeng', 'Arjange,Arjeng,Oreng,Årjeng,Årjänge,Оренг,ᐅᕐᔭᖕ', 59.3921700, 12.1333600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124336, 'Arbrå', 'Arbra', 'Arbra,Arbrå', 61.4666700, 16.3833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124337, 'Arboga', 'Arboga', 'Arboga,Arbuga,Gorad Arbuga,XXT,a er bo jia,arbwga,arbwgha,Арбога,Арбуга,Горад Арбуга,أربوغا,اربوگا,阿尔博加', 59.3938700, 15.8388200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124338, 'Annelund', 'Annelund', 'Annelund', 57.9884300, 13.0748300, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124339, 'Ankarsrum', 'Ankarsrum', 'Ankarsrum', 57.6989600, 16.3340700, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124340, 'Angered', 'Angered', '', 57.7862800, 12.0985200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124341, 'Ängelholm', 'AEngelholm', 'AEngelholm,AEngelholms,AGH,Engelholm,Engelkholm,Ängelholm,Ängelholms,Енгелхолм', 56.2428000, 12.8621900, 'SE', '2017-04-02', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124342, 'Ånge', 'Ange', 'Onge,Онге', 62.5249500, 15.6590400, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124343, 'Aneby', 'Aneby', 'Anebju,Анебю', 57.8389500, 14.8101600, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124344, 'Anderstorp', 'Anderstorp', '', 58.8833300, 14.2833300, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124345, 'Anderstorp', 'Anderstorp', 'Anderstorp', 57.2833300, 13.6333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124346, 'Anderslöv', 'Andersloev', 'Andersloev,Anderslov,Anderslöv,Andersløv', 55.4383600, 13.3196600, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124347, 'Åmotfors', 'Amotfors', 'Amot,Amotfors,Amotsfors,Åmot,Åmotfors,Åmotsfors', 59.7619100, 12.3621100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124348, 'Åmål', 'Amal', 'Amalia,Omol,Omol'',amal,ao mo er,awmwl,Омол,Омоль,آمال,اومول,奧莫爾', 59.0510000, 12.7049200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124349, 'Älvkarleby', 'AElvkarleby', '', 60.5708100, 17.4489500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124350, 'Alvesta', 'Alvesta', 'Al''vesta,Alvesta,alwsta,Алвеста,Альвеста,الوستا', 56.8993500, 14.5555900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124351, 'Älvdalen', 'AElvdalen', '', 61.2277400, 14.0393500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124352, 'Älvängen', 'AElvaengen', 'Alfangen,Alvangen,Elvengen,Älfängen,Älvängen,Елвенген', 57.9587200, 12.1235000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124353, 'Alunda', 'Alunda', 'Alunda', 60.0666700, 18.0833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124354, 'Älta', 'Alta', 'Alta,Elta,alta,Älta,Елта,التا', 59.2666700, 18.1833300, 'SE', '2012-02-01', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124355, 'Alsike', 'Alsike', 'Alsike', 59.7532400, 17.7733100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124356, 'Älmsta', 'AElmsta', 'Almsta,Elmsta,Älmsta', 59.9666700, 18.8000000, 'SE', '2017-04-06', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124357, 'Älmhult', 'AElmhult', 'Elmkhult,almhwlt,erumufuruto,Елмхулт,المهولت,エルムフルト', 56.5514600, 14.1382700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124358, 'Alingsås', 'Alingsas', 'Alingsas,Alingsos,Alingsosas,Alingsosia,a ling suo si,alingsosi,alynsaws,Алингсас,Алингсос,Алінгсос,الینساوس,ალინგსოსი,阿灵索斯', 57.9303300, 12.5334500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124359, 'Alfta', 'Alfta', '', 61.3467500, 16.0749900, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124360, 'Åled', 'Aled', 'Aled,Åled', 56.7500000, 12.9333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124361, 'Alafors', 'Alafors', '', 57.9257900, 12.0783500, 'SE', '2011-12-20', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124362, 'Åkers Styckebruk', 'Akers Styckebruk', 'Akers Styckebruk,Åkers Styckebruk', 59.2500000, 17.0833300, 'SE', '2012-01-17', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124363, 'Åkersberga', 'Akersberga', 'Akersberga,Okersberga,Okershberja,Okeršberga,awkshbqya,Акерсберга,Окерсберга,Окершберя,اوکشبقیا', 59.4794400, 18.2996700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124364, 'Åkarp', 'Akarp', '', 58.2333300, 13.6500000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124365, 'Åkarp', 'Akarp', '', 55.6539600, 13.1110700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124366, 'Åhus', 'Ahus', 'Ahus,Okhus,ao hu si,awhws,Åhus,Охус,اوهوس,奧胡斯', 55.9166700, 14.2833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124367, 'Åby', 'Aby', 'Aby,Åby', 58.6666700, 16.1833300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124368, 'Abborrberget', 'Abborrberget', '', 60.1500000, 14.8000000, 'SE', '2011-10-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124369, 'Västra Hagen', 'Vaestra Hagen', 'Vastra Hagen,Västra Hagen', 57.4244400, 11.9358300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124370, 'Enhagen-Ekbacken', 'Enhagen-Ekbacken', 'Enhagen-Ekbacken', 59.5654300, 16.5304500, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124371, 'Saxtorpsskogen', 'Saxtorpsskogen', 'Saxtorpsskogen,Svanabacken', 55.8320800, 12.9442900, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124372, 'Andalen', 'Andalen', 'Andalen', 57.7003900, 11.7613600, 'SE', '2015-11-08', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124373, 'Nolvik', 'Nolvik', 'Nolvik', 57.7750000, 11.8333300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124374, 'Vi', 'Vi', 'Vi', 62.4333300, 17.4166700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124375, 'Fisksätra', 'Fisksaetra', 'Fisksatra,Fisksätra', 59.2915300, 18.2549000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124376, 'Ekeby', 'Ekeby', 'Ekeby', 56.0000000, 12.9666700, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124377, 'Skanör med Falsterbo', 'Skanoer med Falsterbo', 'Skanoer med Falsterbo,Skanor med Falsterbo,Skanör med Falsterbo,Skanør med Falsterbo', 55.4000000, 12.8500000, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124378, 'Nödinge-Nol', 'Noedinge-Nol', 'Nodinge-Nol,Noedinge-Nol,Nödinge-Nol,Nødinge-Nol', 57.9125900, 12.0559100, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124379, 'Ingared', 'Ingared', '', 57.8598900, 12.4516100, 'SE', '2017-03-19', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124380, 'Majorna', 'Majorna', '', 57.6919500, 11.9160500, 'SE', '2007-11-22', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124381, 'Onsala', 'Onsala', 'Onsala,awnsalh,Онсала,اونساله', 57.4253100, 12.0290300, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124382, 'Olstorp', 'Olstorp', '', 57.8227700, 12.2769600, 'SE', '2011-09-04', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124383, 'Björkskatan', 'Bjoerkskatan', '', 65.6137300, 22.1770200, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124384, 'Alby', 'Alby', '', 59.2335000, 17.8538000, 'SE', '2011-08-16', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124385, 'Hammarkullen', 'Hammarkullen', '', 57.7804900, 12.0360400, 'SE', '2012-05-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124386, 'Rannebergen', 'Rannebergen', '', 57.8023600, 12.0713100, 'SE', '2012-05-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124387, 'Eriksbo', 'Eriksbo', '', 57.7714100, 12.0418300, 'SE', '2012-05-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124388, 'Gårdsten', 'Gardsten', '', 57.8048000, 12.0288300, 'SE', '2012-05-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124389, 'Lövgärdet', 'Loevgaerdet', '', 57.8155500, 12.0386100, 'SE', '2012-05-15', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124390, 'Åre', 'Are', 'Are,Are i Sverige,OSD,Ore,Åre,Åre i Sverige,Оре', 63.3991100, 13.0799500, 'SE', '2017-03-18', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124391, 'Marielund', 'Marielund', '', 65.8530700, 24.1048600, 'SE', '2015-11-30', 215);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124936, 'Serravalle', 'Serravalle', 'Olnanum,Seravale,Seravalė,Seravałe,Serravalle,sai la wa lai,selaballe,seravu~arre,srwalh,syrafally,Серавале,Серравалле,סראוואלה,سرواله,سيرافاللي,セラヴァッレ,塞拉瓦莱,세라발레', 43.9689700, 12.4816700, 'SM', '2012-02-11', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124937, 'San Marino', 'San Marino', 'Agios Marinos,Altepetl San Marino,Cathair San Mairine,Cathair San Mairíne,Ceety o San Marino,Cidade de San Marino,Cita e San Marino,Citad da San Marino,Citta di San Marino,Città di San Marino,City of San Marino,Cità e San Marino,Ciuda de San Marino,Ciudad de San Marino,Ciudá de San Marino,Ciutat de San Marino,Civitas Sancti Marini,Dinas San Marino,Gorad San-Maryna,Ilu San Marino,Ker San Marino,Kêr San Marino,Orasul San Marino,Orașul San Marino,SAI,Saint-Marin,San Marinas,San Marino,San Marino Citta,San Marino Città,San Marino by,San Marino i San Marino,San Marino sehri,San Marino şehri,San Marins,San Maríno,San Marínó,San-Marino,Sanmarino,Sanmarīno,Sant Marin,Sao Marino,Sen Maren,Sita de San Marin,Sita ed San Marin,Sità de San Marin,Sità ëd San Marin,Stadt San Marino,São Marino,Thanh pho San Marino,Thành phố San Marino,Ville de Saint-Marin,ceyint marino nakaram,san ma ri no,san marynw almdynt,san-marino,sanmalino,sanmarino,sanmarino shi,sheng ma li nuo,sheng ma lian nu cheng,sn marynw,sn mrynw,Ìlú San Màrínò,Άγιος Μαρίνος,Горад Сан-Марына,Сан Марино,Сан-Марино,Սան Մարինո,סן מרינו,سان مارينو المدينة,سان مارینو شہر,سان مارینۆ,سان مرینو شہر,سن مارینو,செயின்ட் மரினோ நகரம்,ซานมารีโน,སན་མ་རི་ནོ།,სან-მარინო,ሳን ማሪኖ,サンマリノ,サンマリノ市,聖馬力諾,聖馬連奴城,산마리노', 43.9366700, 12.4463900, 'SM', '2014-03-27', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124938, 'Poggio di Chiesanuova', 'Poggio di Chiesanuova', 'Chiesanuova,Ciesanova,Ecclesia Nova,K''ezanuova,Kiezanuova,Kjezanuova,Podzhio K''ezanuova,Poggio Chiesanuova,Poggio di Chiesanuova,Puggiu Cresianova,Puggiu Crèsianova,ji ai sa nu ou wa,kiesanuoba,kiezanuovu~a,kyyzanwwa,kyzanwwa,qyyzʼnwʼwbh,К''єзануова,Кьезануова,Кјезануова,К’езануова,Поджіо К''єзануова,Կիեզանուովա,קייזאנואובה,کیئزانووا,کیزانووا,キエザヌオーヴァ,基埃萨努欧瓦,키에사누오바', 43.9045100, 12.4214200, 'SM', '2016-07-30', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124939, 'Monte Giardino', 'Monte Giardino', 'Mondesciardine,Mondesciardìne,Mons Viridarium,Montedzardinas,Montedzhardino,Montedžardinas,Montegiardino,Montehdzhardyna,Montejardin,Montejardino,Monteđardino,meng tai ji a di nuo,montejaleudino,montejarudino,mwntg''ʼrdynw,mwnth‌jyardynw,mwntےjardynw,Монтеджардино,Монтеджардіно,Монтеђардино,Монтэджардына,Մոնտեջարդինո,מונטג''ארדינו,مونته‌جیاردینو,مونتےجاردینو,モンテジャルディーノ,蒙泰吉阿迪诺,몬테자르디노', 43.9087800, 12.4820100, 'SM', '2016-02-23', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124940, 'Fiorentino', 'Fiorentino', 'F''jorehntyna,F''orentino,Fiorendine,Fiorendìne,Fiorentin,Fiorentinas,Fiorentino,Fjorentino,Florentinum,fei ao lun di nuo,fiorentino,fywrntynw,piolentino,pywrntynw,Фйорентіно,Фьорентино,Фјорентино,Ф’ёрэнтына,Ֆիորենտինո,פיורנטינו,فیورنتینو,フィオレンティーノ,菲奥伦蒂诺,피오렌티노', 43.9100100, 12.4573800, 'SM', '2016-07-30', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124941, 'Faetano', 'Faetano', 'Faehtana,Faehtano,Faetan,Faetanas,Faetano,Faetanum,fa er qi ya nuo,faetano,faytanw,fyٹanw,pa-etano,pʼtʼnw,Фаетано,Фаэтана,Фаэтано,Ֆաետանո,פאטאנו,فائتانو,فیٹانو,ファエターノ,法尔齐亚诺,파에타노', 43.9283100, 12.4979800, 'SM', '2016-07-30', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124942, 'Domagnano', 'Domagnano', 'Domagnano,Montelupo', 43.9496100, 12.4682800, 'SM', '2016-08-01', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124943, 'Borgo Maggiore', 'Borgo Maggiore', 'Borga-Madzhoreh,Borgo Madzore,Borgo Madžorė,Borgo Maggiore,Borgo Majore,Borgo Mađore,Borgo-Madzhore,Burgus Maior,Mercatale,Merkatale,bo er ge·ma ji ou lei,boleugomajole,borugo・majjore,bwrgw majywrh,bwrgw mg''wrh,Борга-Маджорэ,Борго Мађоре,Борго-Маджоре,Меркатале,בורגו מג''ורה,بورگو ماجیوره,ボルゴ・マッジョーレ,博尔戈·马吉欧雷,보르고마조레', 43.9419300, 12.4473800, 'SM', '2016-07-30', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124944, 'Acquaviva', 'Acquaviva', 'Acquaviva', 43.9459300, 12.4185000, 'SM', '2012-02-11', 193);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124945, 'Ziguinchor', 'Ziguinchor', 'ZIG,Zighinkor,Zigincor,Ziginshor,Ziginsor,Ziginsoras,Ziginĉor,Ziginšor,Ziginšoras,Zigiunchor,Ziguinchor,Zinguinhor,ji jin shao er,jiganshoru,jiginsyoleu,zygynchwr,Зигиншор,زیگینچور,ジガンショール,济金绍尔,지긴쇼르', 12.5680100, -16.2732600, 'SN', '2016-12-03', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124946, 'Vélingara', 'Velingara', 'Velingara,Vélingara', 13.1500000, -14.1166700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124947, 'Touba', 'Touba', 'Touba,Tub,Tuba,Tuubaa,to~uba,tu ba,tuba,Туба,トゥーバ,圖巴,투바', 14.8500000, -15.8833300, 'SN', '2012-07-14', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124948, 'Tionk Essil', 'Tionk Essil', '', 12.7855600, -16.5216700, 'SN', '2006-01-27', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124949, 'Tiébo', 'Tiebo', '', 14.6333300, -16.2333300, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124950, 'Tiadiaye', 'Tiadiaye', 'Tatadem,Thiadiaye,Tiadaye,Tiadiay,Tiadiaye', 14.4166700, -16.7000000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124951, 'Thiès Nones', 'Thies Nones', '', 14.7833300, -16.9666700, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124952, 'Thiès', 'Thies', '', 14.7894400, -16.9260200, 'SN', '2016-12-03', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124953, 'Tambacounda', 'Tambacounda', 'TUD,Tambacounda,Tambakunda,tambakunda,tambakwnda,tan ba kun da,tanbakunda,Тамбакунда,تامباکؤندا,タンバクンダ,坦巴昆達,탐바쿤다', 13.7707300, -13.6673400, 'SN', '2012-06-18', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124954, 'Sokone', 'Sokone', 'Sokon,Sokone', 13.8833300, -16.3666700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124955, 'Sémé', 'Seme', 'Seme,Semme,Semmé,Somme,Sommé,Sémé', 15.1942200, -12.9448200, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124956, 'Sédhiou', 'Sedhiou', 'Sedhiou,Sedhiu,Sédhiou', 12.7080600, -15.5569400, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124957, 'Saint-Louis', 'Saint-Louis', 'Gorad Sen-Lui,Ndar,Saint Louis,Saint-Louis,SanLuis,Sen Lui,Sen Luji,Sen-Lui,Senegalyn Sen-Lui,St-Louis,XLS,saenglu-i,san=rui,sant lwys,sen-lui,senta lu''isa dvipa,senta-lo''isa,sheng lu yi,Горад Сен-Луі,Сен-Луи,Сен-Луї,Сенегалын Сен-Луи,Սեն Լուի,סן-לואי,سانت لويس,سن‌لوئی,سینٹ-لوئیس، سینیگال,सेन्ट लुईस द्वीप,सेन्ट-लोइस,სენ-ლუი,サン＝ルイ,圣路易,생루이', 16.0179300, -16.4896200, 'SN', '2017-06-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124958, 'Rosso', 'Rosso', '', 16.4202800, -15.7983400, 'SN', '2013-10-30', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124959, 'Richard-Toll', 'Richard-Toll', 'RDT,Richard-Toll', 16.4625000, -15.7008300, 'SN', '2017-06-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124960, 'Ranérou', 'Ranerou', '', 15.3000000, -13.9666700, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124961, 'Pout', 'Pout', 'Pout,Put', 14.7709900, -17.0610700, 'SN', '2012-12-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124962, 'Pourham', 'Pourham', 'Poukham,Pourham', 14.3500000, -16.4166700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124963, 'Polel Diaoubé', 'Polel Diaoube', 'Polel Diaoube', 15.2666700, -13.0000000, 'SN', '2012-02-22', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124964, 'Pikine', 'Pikine', 'Pikin,Pikine,pi jin,pikin,Пикин,ピキン,皮金', 14.7645700, -17.3907100, 'SN', '2012-12-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124965, 'Passi', 'Passi', 'Passi,Passy', 13.9833300, -16.2666700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124966, 'Oussouye', 'Oussouye', '', 12.4850000, -16.5469400, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124967, 'Ouro Sogui', 'Ouro Sogui', 'Ouri Sogui,Ouro Soghy,Ouro Sogui,Ourossogui', 15.6058800, -13.3223000, 'SN', '2013-02-08', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124968, 'Waoundé', 'Waounde', 'Ouaounde,Ouaoundé,Waounde,Waoundé', 15.2636700, -12.8682100, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124969, 'Nioro du Rip', 'Nioro du Rip', 'Nioro,Nioro du Rip,Nioro-du Pup', 13.7500000, -15.8000000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124970, 'Nguékhokh', 'Nguekhokh', 'Nguekhokh,Nguekoh,Nguekohe,Nguekokh,Nguekorh,Nguékhokh,Nguékoh,Nguékohe,Nguékokh,Nguékorh', 14.5125500, -17.0044700, 'SN', '2012-12-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124971, 'Ndofane', 'Ndofane', 'N''Dofan,N''Doffane,Ndofane,N’Dofan,N’Doffane', 13.9166700, -15.9333300, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124972, 'Ndioum', 'Ndioum', 'N''diom,Ndioum,Ndioum-Oualo,N’diom', 16.5129300, -14.6470600, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124973, 'Ndibène Dahra', 'Ndibene Dahra', '', 15.3338000, -15.4766000, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124974, 'Mékhé', 'Mekhe', 'Mecke,Meckhe,Meckhé,Mecké,Meke,Mekhe,Mekke,Mekké,Mékhé,Méké', 15.1097000, -16.6218000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124975, 'Mbaké', 'Mbake', 'Mbacke,Mbacké', 14.7903200, -15.9080300, 'SN', '2007-11-01', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124976, 'Matam', 'Matam', 'MAX,Matam', 15.6558700, -13.2554400, 'SN', '2013-08-10', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124977, 'Marsassoum', 'Marsassoum', 'Mangri,Marassou,Marassu,Marsassoum,Marssassoum,Marssoum', 12.8275000, -15.9805600, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124978, 'Louga', 'Louga', 'Louga,Luga', 15.6186700, -16.2243600, 'SN', '2013-08-06', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124979, 'Koungheul', 'Koungheul', 'Koungheul,Koungueul', 13.9833300, -14.8000000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124980, 'Kolda', 'Kolda', 'KDA,Kolda,Колда', 12.8939000, -14.9412500, 'SN', '2016-12-03', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124981, 'Khombole', 'Khombole', 'Khombole,Kombole,Rhombol', 14.7666700, -16.7000000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124982, 'Kédougou', 'Kedougou', 'KGG,Kedougou,Kédougou', 12.5556100, -12.1807600, 'SN', '2017-06-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124983, 'Kayar', 'Kayar', 'Cayar,Kayar', 14.9189300, -17.1197800, 'SN', '2012-12-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124984, 'Kaolack', 'Kaolack', 'KLC,Kaolac,Kaolack,Kaolak', 14.1519700, -16.0725900, 'SN', '2016-12-09', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124985, 'Kanel', 'Kanel', 'Kanel,Karel', 15.4916000, -13.1762700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124986, 'Kaffrine', 'Kaffrine', '', 14.1059400, -15.5508000, 'SN', '2013-08-06', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124987, 'Joal-Fadiout', 'Joal-Fadiout', 'Fadiout,Fadiouth,Joal,Joal-Fadiout', 14.1666700, -16.8333300, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124988, 'Guinguinéo', 'Guinguineo', 'Guinguineo,Guinguinéo', 14.2666700, -15.9500000, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124989, 'Guéoul', 'Gueoul', 'Goumbo,Goumbo-Gueoul,Goumbo-Guéoul,Gueoul,Gueul,Guéoul', 15.4833300, -16.3500000, 'SN', '2013-05-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124990, 'Goléré', 'Golere', 'Golere,Gollene,Gollere,Golléné,Golléré,Goléré', 16.2557500, -14.1016500, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124991, 'Gandiaye', 'Gandiaye', 'Gandiaye', 14.2333300, -16.2666700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124992, 'Foundiougne', 'Foundiougne', 'Foundiougne,Foundjougne,Fundiun,Poundiougne', 14.1333300, -16.4666700, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124993, 'Fatick', 'Fatick', 'Fatick,Fatik', 14.3323600, -16.4051300, 'SN', '2016-12-03', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124994, 'Diourbel', 'Diourbel', 'Diourbei,Diourbel,Diurbel,Diurbel'',Diurbelis,Jurbel,diuleubel,dywrbl,dywrbyl,jiu er bei lei,Диурбел,Диурбель,דיורבל,دیوربیل,久爾貝勒,디우르벨', 14.6479200, -16.2436300, 'SN', '2015-03-31', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124995, 'Diofior', 'Diofior', '', 14.1833300, -16.6666700, 'SN', '2006-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124996, 'Diawara', 'Diawara', 'Diaouara,Diawara,Diawora', 15.0219600, -12.5437400, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124997, 'Dara', 'Dara', 'Dahra,Dar,Дар', 15.3484400, -15.4799300, 'SN', '2010-01-29', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124998, 'Dakar', 'Dakar', 'DKR,Dacar,Dacár,Dakaa,Dakar,Dakara,Dakaras,Dakaro,Gorad Dakar,Ndakaaru,Ntakar,da ka er,dakaleu,dakar,dakara,dakaru,dqr,takkar,Ντακάρ,Горад Дакар,Дакар,Դակար,דאקאר,דקר,داكار,داکار,ڈا کار,ڈاکار,डकार,ডাকার,ਡਾਕਾਰ,டக்கார்,ഡാക്കർ,ดาการ์,ཌ་ཀར།,დაკარი,ዳካር,ダカール,達喀爾,다카르', 14.6937000, -17.4440600, 'SN', '2011-03-04', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124999, 'Bignona', 'Bignona', 'Bignona,Pagnona', 12.8102800, -16.2263900, 'SN', '2012-01-17', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125000, 'Adéane', 'Adeane', 'Adeane,Adéane', 12.6300000, -16.0169400, 'SN', '2013-05-05', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125001, 'Warang', 'Warang', '', 14.3734900, -16.9436600, 'SN', '2008-01-03', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125002, 'Mermoz Boabab', 'Mermoz Boabab', '', 14.7064900, -17.4758100, 'SN', '2011-10-04', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125003, 'N’diareme limamoulaye', 'N''diareme limamoulaye', '', 14.7814800, -17.3841000, 'SN', '2016-03-15', 196);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124852, 'Zimmi', 'Zimmi', 'Zimi,Zimmi', 7.3135600, -11.3081800, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124853, 'Yonibana', 'Yonibana', 'Yonibana', 8.4434700, -12.2392900, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124854, 'Yengema', 'Yengema', 'WYE,Yengema', 8.7144100, -11.1705700, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124855, 'Wima', 'Wima', 'Wima', 8.3005200, -11.2045500, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124856, 'Waterloo', 'Waterloo', 'Waterloo', 8.3389000, -13.0709100, 'SL', '2014-11-05', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124857, 'Tongole', 'Tongole', 'Tongole', 7.4509200, -11.9007100, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124858, 'Tombu', 'Tombu', 'Tombu', 8.5399100, -10.7313200, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124859, 'Tombodu', 'Tombodu', 'Fobu,Tombodu', 8.1352600, -10.6196000, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124860, 'Tintafor', 'Tintafor', 'Tintafor,Tintfor', 8.6266700, -13.2150000, 'SL', '2012-01-18', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124861, 'Tefeya', 'Tefeya', 'Tefea,Tefee,Tefeya', 8.7039500, -11.2126000, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124862, 'Sumbuya', 'Sumbuya', 'Sumbuya', 7.6478900, -11.9606000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124863, 'Simbakoro', 'Simbakoro', 'Simbakoro', 8.6124300, -11.0075500, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124864, 'Serabu', 'Serabu', 'Serabu', 7.7931100, -12.0529400, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124865, 'Seidu', 'Seidu', 'Seidu', 9.0180100, -10.5949600, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124866, 'Segbwema', 'Segbwema', 'Segbwema', 7.9947100, -10.9502000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124867, 'Sawkta', 'Sawkta', 'Sawkta', 8.6323000, -13.2025000, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124868, 'Rotifunk', 'Rotifunk', 'Rotifunk', 8.2259100, -12.6776000, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124869, 'Rokupr', 'Rokupr', 'Rokupr', 8.6712100, -12.3849700, 'SL', '2015-03-08', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124870, 'Potoru', 'Potoru', 'Potoru', 7.5059600, -11.4789700, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124871, 'Port Loko', 'Port Loko', 'Port Loka,Port Lokko,Port Loko,Port-Loko,Порт-Локо', 8.7660900, -12.7869600, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124872, 'Koyima', 'Koyima', 'Koyima,Peyima', 8.7055200, -11.0224100, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124873, 'Pepel', 'Pepel', 'Pepel', 8.5861100, -13.0544400, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124874, 'Pendembu', 'Pendembu', 'Pendembu', 8.0980700, -10.6942900, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124875, 'Panguma', 'Panguma', 'Panguma', 8.1850700, -11.1329000, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124876, 'Giehun', 'Giehun', 'Giehun,Ngiehun', 8.5551800, -11.0427800, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124877, 'Moyamba', 'Moyamba', 'Moyamba', 8.1589800, -12.4316800, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124878, 'Motema', 'Motema', 'Motema', 8.6142700, -11.0125200, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124879, 'Mogbwemo', 'Mogbwemo', 'Mogbembo,Mogbwemo', 7.7623700, -12.3086400, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124880, 'Mobai', 'Mobai', 'Mobai', 7.9934300, -10.7535500, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124881, 'Masoyila', 'Masoyila', 'Masoyila', 8.6111900, -13.1910100, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124882, 'Masingbi', 'Masingbi', 'Masingbi', 8.7819700, -11.9517100, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124883, 'Masaka', 'Masaka', 'Masaka', 8.6649200, -11.8026000, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124884, 'Manowa', 'Manowa', 'Manowa', 8.1739200, -10.7483400, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124885, 'Mange', 'Mange', 'Mange', 8.9226200, -12.8568800, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124886, 'Mamboma', 'Mamboma', 'Mamboma', 8.0874200, -11.6884100, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124887, 'Mambolo', 'Mambolo', 'Mambola,Mambolo', 8.9186000, -13.0367400, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124888, 'Makeni', 'Makeni', 'Makeni,Makenis,ma ka ni,makeni,makyny,Μακένι,Макени,ماکینی,マケニ,馬卡尼,마케니', 8.8860500, -12.0441700, 'SL', '2015-03-08', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124889, 'Makali', 'Makali', 'Makali', 8.6296400, -11.6616800, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124890, 'Magburaka', 'Magburaka', 'Magburaka,Magburuka', 8.7230600, -11.9488000, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124891, 'Lunsar', 'Lunsar', 'Lansar,Lunsar,Lunsare,Лунсаре', 8.6843900, -12.5349900, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124892, 'Loma', 'Loma', 'Loma', 9.7593100, -12.0338300, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124893, 'Largo', 'Largo', 'Lago,Largo', 8.2790300, -12.1578000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124894, 'Kukuna', 'Kukuna', 'Kakuna,Kukuna', 9.3984100, -12.6647600, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124895, 'Koribundu', 'Koribundu', 'Koribundu', 7.7095200, -11.6935400, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124896, 'Koidu', 'Koidu', 'Koidu,Koidu Town,Koldu', 8.6438700, -10.9714000, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124897, 'Kenema', 'Kenema', 'KEN,Kenema,Keneme,kai nei ma,kenema,kynyma,Κενέμα,Кенема,Кенеме,کینیما,ケネマ,凯内马,케네마', 7.8768700, -11.1902500, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124898, 'Kayima', 'Kayima', 'Kayima', 8.8879000, -11.1593200, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124899, 'Kassiri', 'Kassiri', 'Karsarai,Kasiri,Kassiri', 8.9381400, -13.1154100, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124900, 'Kambia', 'Kambia', 'Kambia', 9.1250400, -12.9181600, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124901, 'Kamakwie', 'Kamakwie', 'Kamakwie,Makwi,Makwie', 9.4968900, -12.2406100, 'SL', '2013-03-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124902, 'Kailahun', 'Kailahun', 'Kailahun', 8.2789000, -10.5730000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124903, 'Kabala', 'Kabala', 'KBA,Kabala,Kaballa', 9.5889300, -11.5525600, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124904, 'Jojoima', 'Jojoima', 'Joioima,Jojoima', 7.8781500, -10.7897600, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124905, 'Hastings', 'Hastings', 'Hastings', 8.3799400, -13.1369300, 'SL', '2014-11-05', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124906, 'Hangha', 'Hangha', 'Hangha', 7.9397400, -11.1413200, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124907, 'Gorahun', 'Gorahun', 'Gorahun', 7.4643900, -11.2395200, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124908, 'Freetown', 'Freetown', 'Fritaun,Funkia,Godrich,Фритаун', 8.4319400, -13.2897200, 'SL', '2010-01-29', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124909, 'Giehun', 'Giehun', 'Giehun', 7.8840500, -11.0490800, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124910, 'Gberia Fotombu', 'Gberia Fotombu', 'Gberia Fotombu', 9.8785200, -11.1654800, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124911, 'Gandorhun', 'Gandorhun', 'Gandohun,Gandorhun', 7.5550200, -11.6926000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124912, 'Gandorhun', 'Gandorhun', 'Gandorhun', 7.4943100, -11.8306400, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124913, 'Freetown', 'Freetown', 'FNA,Freetown,Frijtaun,Fritaun,Fritauna,Fritaunas,Fritauno,Fritaŭno,Fritonn,Frītauna,Gorad Frytaun,Phritaoun,Saint George,Urbs Libera,farita''una,fri thawn,frita''una,frytawn,fu li dun,furitaun,peulitaun,phrita''una,phritaun,piritavun,zi you shi,Φρίταουν,Горад Фрытаўн,Фрийтаун,Фритаун,Фрітаун,Ֆրիթաուն,פריטאון,فريتاون,فری ٹاؤن,فریتاون,فری‌تاون,फ़्रीटाउन,फ्रीटाउन,ਫ਼ਰੀਟਾਊਨ,பிரீடவுன்,ಫ್ರೀಟೌನ್,ฟรีทาวน์,ཕིརི་ཊའུན།,ფრიტაუნი,ፍሪታውን,フリータウン,弗里敦,自由市,프리타운', 8.4840000, -13.2299400, 'SL', '2010-05-30', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124914, 'Foindu', 'Foindu', 'Foindu', 7.4090600, -11.5432800, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124915, 'Daru', 'Daru', 'Daru', 7.9897600, -10.8422300, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124916, 'Buedu', 'Buedu', 'Buedu,Bwedu', 8.2796000, -10.3713500, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124917, 'Bunumbu', 'Bunumbu', 'Bunumbu', 8.1742100, -10.8643200, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124918, 'Bumpe', 'Bumpe', 'Bumpe', 7.8920900, -11.9054100, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124919, 'Bumbuna', 'Bumbuna', 'Bumbuna', 9.0446600, -11.7457600, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124920, 'Bonthe', 'Bonthe', 'BTE,Bonth,Bonthe', 7.5263900, -12.5050000, 'SL', '2014-08-19', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124921, 'Bomi', 'Bomi', 'Bomi', 7.2461100, -11.5258300, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124922, 'Boajibu', 'Boajibu', 'Boajibu', 8.1876300, -11.3402600, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124923, 'Bo', 'Bo', 'Bo,KBS,bo,bo cheng,bw,bw  syralywn,Μπο,Бо,בו,بو، سیرالیون,ボー,博城,보', 7.9647200, -11.7383300, 'SL', '2012-01-18', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124924, 'Blama', 'Blama', 'Blama', 7.8748100, -11.3454800, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124925, 'Binkolo', 'Binkolo', 'Binkolo', 8.9522500, -11.9802900, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124926, 'Bindi', 'Bindi', 'Bindi', 9.9137600, -11.4466900, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124927, 'Barma', 'Barma', 'Barma', 8.3495900, -11.3305900, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124928, 'Baoma', 'Baoma', 'Baoma', 7.9934400, -11.7146800, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124929, 'Palima', 'Palima', 'Baiima,Palima', 8.1199600, -11.5070200, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124930, 'Baiima', 'Baiima', 'Baiima', 8.1082600, -11.8477200, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124931, 'Alikalia', 'Alikalia', 'Alikalia', 9.1535600, -11.3871200, 'SL', '2015-02-06', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124932, 'Konakridee', 'Konakridee', 'Konakridee', 8.6977800, -13.2391700, 'SL', '2015-01-07', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124933, 'Gbewebu', 'Gbewebu', 'Gbewebu', 7.5509100, -11.6075000, 'SL', '2014-12-03', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124934, 'Pujehun', 'Pujehun', 'Pujehun', 7.3580600, -11.7208300, 'SL', '2012-01-19', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124935, 'Kent', 'Kent', '', 8.3333300, -13.0666700, 'SL', '2015-08-15', 199);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124699, 'Žehra', 'Zehra', 'Schigra,Sygura,Zehra,Zhegra,Zhehgra,Zhekhra,Zsegra,Zsigra,z''hrh,Żehra,Žehra,Жегра,Жехра,Жэгра,ז''הרה', 48.9796000, 20.7917000, 'SK', '2017-07-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124700, 'Ždiar', 'Zdiar', 'Zar,Zdjar,Zdziar,Zhd''jar,Zhdjar,Zhdujar,Zár,Ždjar,Ждъяр,Ждьяр,Ждяр,Ждјар', 49.2710000, 20.2623900, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124701, 'Vysoké Tatry', 'Vysoke Tatry', 'Smokovec,Vysoke Tatry,Vysokie Tatry,Vysoké Tatry,Высокие Татры', 49.1363700, 20.2438600, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124702, 'Vyšné Ružbachy', 'Vysne Ruzbachy', 'Druzbaki Wyzny,Druzbaki Wyżny,Vyshne Ruzhbakhi,Vysne Ruzbachy,Vysnie Ruzbachy,Vyšnie Ružbachy,Vyšné Ružbachy,Вышне Ружбахи', 49.3038700, 20.5655800, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124703, 'Vrbov', 'Vrbov', 'Menhardsdorf,Vrbov,Врбов', 49.0876400, 20.4253000, 'SK', '2015-08-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124704, 'Vranov nad Topľou', 'Vranov nad Topl''ou', 'Varanno,Varannó,Voroniv nad Topljov,Vranov,Vranov na Toploj,Vranov nad Topl''ou,Vranov nad Toplou,Vranov nad Toplyou,Vranov nad Topľou,Vranov-nad-Topl''ou,Vranov-nad-Topljou,Vranova pie Toplas,Vranova pie Topļas,Vranovas prie Toplios,franwf nad twblwa,tuo pu la he pan fu la nuo fu,wranw nad tplyw,Воронів над Топлёв,Вранов на Топлој,Вранов-над-Топльоу,Вранов-над-Топлёу,فرانوف ناد توبلوا,ورانو ناد تپلیو,托普拉河畔弗拉諾夫', 48.8883600, 21.6847900, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124705, 'Vinné', 'Vinne', 'Vinna,Vinne,Vinná,Vinné,Винне', 48.8096500, 21.9675700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124706, 'Trebišov', 'Trebisov', 'Toketerebes,Trebishov,Trebisov,Trebisova,Trebisovas,Trebişov,Trebišov,Trebišova,Trebišovas,Tőketerebes,te lei bi shao fu,teulebisyopeu,trbyshw,trybyshwf,Требишов,Требішов,تربیشو,تريبيشوف,特雷比紹夫,트레비쇼프', 48.6285800, 21.7195400, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124707, 'Svit', 'Svit', 'Svit,Swit,Szvit,Świt,Свит', 49.0601400, 20.2069500, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124708, 'Svidník', 'Svidnik', 'Felsovizkoez,Felsővízköz,Svidnik,Svidník,Vysnyj Svidnik,Vyšnyj Svidnik,Свидник', 49.3081900, 21.5703000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124709, 'Stropkov', 'Stropkov', 'Stropkov,Stropkova,Stropkovas,Sztropko,Sztropkó,si te luo pu ke fu,strwbkwf,strwpkw,Стропков,סטראפקאוו,ستروبكوف,ستروپکو,斯特羅普科夫', 49.2021100, 21.6521600, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124710, 'Štrba', 'Strba', 'Shtrba,Strba,Штрба', 49.0591300, 20.0797500, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124711, 'Strážske', 'Strazske', 'Ormezo,Strashke,Straske,Strazhs''ke,Strazhske,Strazske,Straške,Strážske,Strāžske,si te la ri si kai,strajskh,strazhskh,Őrmező,Стражске,Стражське,Страшке,ستراجسكه,ستراژسکه,斯特拉日斯凱', 48.8735000, 21.8366800, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124712, 'Stará Ľubovňa', 'Stara L''ubovna', 'Lubowla,Olublo,Stara L''ubovna,Stara LJubovna,Stara Liubovnia,Stara Ljubovnja,Stara Lubovna,Stara Lyubovnya,Stara Ļubovņa,Stará Ľubovňa,jiu liu bo fu ni ya,stara lwbwfna,Ólubló,Стара Љубовња,Стара Любовня,ستارا لوبوفنا,舊柳博夫尼亞', 49.2985900, 20.6862000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124713, 'Spišské Podhradie', 'Spisske Podhradie', 'Gorad Spishske-Podgraddze,Spis''ke Podgrade,Spishke Podkhradje,Spishske-Podgrad''e,Spiskie Podgrodzie,Spiskie Podhradie,Spisske Podhradie,Spisske Podhradje,Spiśkie Podhradie,Spišske Podhradje,Spišské Podhradie,Szepesvaralja,Szepesváralja,sbyshskh bwdhraydh,si pi shen si kai bo de he la jie,spyshskh pdhradyh,spyssqh pwdhrdyyh,Горад Спішске-Подграддзе,Спиське Подградє,Спишке Подхрадје,Спишске-Подградье,ספישסקה פודהרדייה,سبيشسكه بودهرايده,سپیشسکه پدهرادیه,斯皮什斯凱波德赫拉傑', 49.0008800, 20.7530700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124714, 'Spišská Nová Ves', 'Spisska Nova Ves', 'Iglo,Igló,Neudorf,Spishska Nova Ves,Spiska Nowa Wies,Spiska Nowa Wieś,Spisska,Spisska Nova Ves,Spišská,Spišská Nová Ves,Спишска Нова Вес', 48.9446400, 20.5615300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124715, 'Spišská Belá', 'Spisska Bela', 'Biala Spiska,Biała Spiska,Spis''ka Bela,Spishka Bela,Spishska-Bela,Spiska Bela,Spisska Bela,Spiška Bela,Spišska Bela,Spišská Belá,Szepesbela,Szepesbéla,sbyshska byla,si pi shen si ka bei la,spyshska bla,Списька Бела,Спишка Бела,Спишска-Бела,Спіська Бела,سبيشسكا بيلا,سپیشسکا بلا,斯皮什斯卡貝拉', 49.1872500, 20.4594800, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124716, 'Sobrance', 'Sobrance', 'Sobrance,Sobranci,Szobranc,Szobránc,sbrantsh,sobeulanche,suo bu lan cai,swbrantsy,Собранце,Собранці,Собранцї,سبرانتسه,سوبرانتسى,索布蘭采,소브란체', 48.7445500, 22.1813600, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124717, 'Snina', 'Snina', 'Snina,Snjina,Szinna,si ni na,snyna,Снина,Сњина,سنينا,سنینا,斯尼納', 48.9885700, 22.1509900, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124718, 'Sečovce', 'Secovce', 'Galszecs,Gálszécs,Sechovce,Secovce,Sečovce,sai qiao fu cai,schwts,sytswfs,Сечовце,سيتسوفس,سچوتس,塞喬夫采', 48.7007400, 21.6610400, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124719, 'Sabinov', 'Sabinov', 'Kisseben,Kisszeben,Sabinau,Sabiniv,Sabinov,Sabinova,Sabinovas,Zeben,sa bi nuo fu,sabynw,sabynwf,Сабинов,Сабинів,Сабінаў,سابينوف,سابینو,薩比諾夫', 49.1030900, 21.0988000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124720, 'Rožňava', 'Roznava', 'Rosenau,Rozhnjava,Roznava,Rozsnyo,Rozsnyó,Rožňava,Рожнява', 48.6600900, 20.5375800, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124721, 'Rimavská Sobota', 'Rimavska Sobota', 'Rima-Szombat,Rimaszombat,Rimavska Sobota,Rimavská Sobota,Sobota Rimavska,Sobota Rimavská,Римавска Собота', 48.3828400, 20.0223900, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124722, 'Revúca', 'Revuca', 'Nagyroce,Nagyrőce,Revuca,Revúca,Revūca,lebucha,lei wu cha,rwfytsa,rwwtsa,Ревуца,روفيتسا,رووتسا,雷武察,레부차', 48.6834600, 20.1173400, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124723, 'Prešov', 'Presov', 'Eperjes,POV,Prasiv,Preshov,Presov,Presova,Preszow,Preszów,Prešov,Prešova,Prjashev,prswb,Прешов,Пряшев,Пряшів,פרשוב', 48.9983900, 21.2339300, 'SK', '2017-01-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124724, 'Poprad', 'Poprad', 'Deutschendorf,Poprad,TAT,Попрад', 49.0614400, 20.2979800, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124725, 'Podolínec', 'Podolinec', 'Podolin,Podolinec,Podolinec'',Podolineca,Podoliniec,Podolinjec,Podolínec,Podolīneca,bo duo li nei ci,bwdwlynyts,pdlynts,Подолинец,Подолинець,Подолињец,بودولينيتس,پدلینتس,波多利內茨', 49.2586900, 20.5360000, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124726, 'Nová Lesná', 'Nova Lesna', 'Neu-Walddorf,Nova-Lesna,Нова-Лесна', 49.1225300, 20.2673700, 'SK', '2014-04-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124727, 'Moldava nad Bodvou', 'Moldava nad Bodvou', 'Moldava na Bodvi,Moldava nad Bodvou,Moldava nad Bodvu,Moldava pie Bodvas,Moldava-nad-Bodvou,Szepsi,bo de wa he pan mo er da wa,mldawa nad bdww,mwldwfa nad bwdfwa,Молдава на Бодви,Молдава-над-Бодвоу,ملداوا ناد بدوو,مولدوفا ناد بودفوا,博德瓦河畔摩爾達瓦', 48.6142800, 20.9995700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124728, 'Michalovce', 'Michalovce', 'Gorad Mikhalaucy,Grossmichel,Großmichel,Michalovce,Michalovcė,Mihalovce,Mikhajlivci,Mikhajlovce,Mikhalovce,Mixalovtse,Nagymihaly,Nagymihály,mi ha luo fu cai,mihallopeuche,miharofutsu~e,mykhalwftsy,mykhalwtsh,Горад Міхалаўцы,Михайловце,Михайлівці,Михаловце,ميخالوفتسى,میخالوتسه,ミハロフツェ,米哈洛夫采,미할로프체', 48.7543400, 21.9195000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124729, 'Medzilaborce', 'Medzilaborce', 'Boro,Boró,Medzhilabirci,Medzilaborce,Medzilaborcė,Mezolaborc,Mezolaborcz,Mezőlaborc,Mezőlaborcz,Midzhilabirci,mdzylabrtsh,mei ji la bo er cai,mydzylabwrtsy,Меджилабірці,Медзилаборце,Міджілабірцї,מעזשילאבריץ,مدزیلابرتسه,ميدزيلابورتسى,梅濟拉博爾采', 49.2719500, 21.9007300, 'SK', '2013-09-14', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124730, 'Medzev', 'Medzev', 'Mecenzef,Mecenzéf,Medzev,Medzeva,Nizni Medzev,Nizny Medzev,Nižní Medzev,Nižný Medzev,Unter-Metzenseifen,mdzb,mdzw,mei ze fu,Медзев,מדזב,مدزو,梅澤夫', 48.7004100, 20.8936700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124731, 'Ľubica', 'Lubica', 'Leibitz', 49.1166700, 20.4500000, 'SK', '2009-06-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124732, 'Lipany', 'Lipany', 'Hethars,Héthárs,Lipani,Lipany,Lipiany,li pa ni,lybany,lypany,Липани,Липаны,ليباني,لیپانی,利帕尼', 49.1537600, 20.9638200, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124733, 'Levoča', 'Levoca', 'Gorad Levacha,Leutschau,Levoca,Levocha,Levoça,Levoča,Lewocza,Ljevocha,Locse,Löcse,Lőcse,lai wo qia,lbwzh,lebocha,levocha,lwcha,lyfwtsha,revu~ocha,Љевоча,Горад Левача,Левоча,לבוצה,لوچا,ليفوتشا,ლევოჩა,レヴォチャ,萊沃恰,레보차', 49.0217300, 20.5921200, 'SK', '2016-08-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124734, 'Krompachy', 'Krompachy', 'Korompa,Krompachi,Krompachy,Krompahi,Krompakhi,ke long pa xi,krmbakhy,krmpakhy,qrwmpky,Кромпахи,קרומפכי,كرمباخي,کرمپاخی,克龍帕希', 48.9144700, 20.8751400, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124735, 'Košice', 'Kosice', 'Cassovia,Gorad Koshycy,KSC,Kaschau,Kassa,Koesice,Koshice,Koshici,Kosice,Kositse,Koszyce,Koşitse,Košice,Košicė,Kösice,ke xi ce,koshitsu~e,kosiche,kositsa,kwshytsh,qwsyzh,Κόσιτσε,Горад Кошыцы,Кошице,Кошіцї,קושיצה,كوشيتسه,کوشیتسه,کوشیسہ,کوشیسے,कोशित्सा,კოშიცე,コシツェ,科希策,코시체', 48.7139500, 21.2580800, 'SK', '2016-11-24', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124736, 'Kežmarok', 'Kezmarok', 'Gorad Kezhmarak,Kaesmark,Kasmark,Kejmarok,Kesmark,Kezhmarok,Kezmarok,Kezmaroka,Kezmarokas,Kežmarok,Kežmaroka,Kežmarokas,Kiezmark,Kieżmark,Käsmark,Késmárk,kai ri ma luo ke,kejumalokeu,kejumaroku,kyjmarwk,kzhmark,Горад Кежмарак,Кежмарок,קעזמארק,كيجماروك,کژمارک,ケジュマロク,凱日馬羅克,케주마로크', 49.1357100, 20.4335200, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124737, 'Kavečany', 'Kavecany', 'Kavecani,Kavecany,Kavechani,Kavechany,Kavečani,Kavečany,Kavocsan,Kavocsán,Кавечани,Кавечаны', 48.7759200, 21.2058700, 'SK', '2017-06-27', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124738, 'Humenné', 'Humenne', 'Gumenne,Homonna,Humenne,Humenné,Гуменне', 48.9370700, 21.9162500, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124739, 'Giraltovce', 'Giraltovce', 'Giralt,Giraltivci,Giraltovce,Girált,Oiraltovce,ghyraltwtsy,gyraltwtsh,ji la er tuo fu cai,Гиралтовце,Ґіралтовце,Ґіралтівцї,غيرالتوتسي,گیرالتوتسه,吉拉爾托夫采', 49.1139800, 21.5173100, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124740, 'Gelnica', 'Gelnica', 'Gelnica,Gelnicja,Gelnjica,Goelnicbanya,Gollnitz,Gölnicbánya,gai er ni cha,ghylnytsa,glyntsa,Гелница,Гелњица,Ґелниця,غيلنيتسا,گلینتسا,蓋爾尼察', 48.8558400, 20.9371300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124741, 'Dobšiná', 'Dobsina', 'Dobschau,Dobshina,Dobsina,Dobszyna,Dobšina,Dobšiná,dbshyna,duo bu xi na,Добшина,دبشينا,دبشینا,多布希納', 48.8207300, 20.3698800, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124742, 'Čierna nad Tisou', 'Cierna nad Tisou', 'Agcsernyo,Cerna,Cherna,Cierna,Cierna nad Tisou,Cserno,Csernő,Černá,Čierna,Čierna nad Tisou', 48.4170400, 22.0886500, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124743, 'Chlmec', 'Chlmec', 'Chlmec,Chlumec', 48.8862800, 21.9393000, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124744, 'Bardejov', 'Bardejov', 'Bardejov,Bardejova,Bardejovas,Bardeyov,Bardiiv,Bardiow,Bardiów,Bardjejov,Bartfa,Bartfeld,Bártfa,Gorad Bardzejou,ba er dai yue fu,baleudeyopeu,bardeiovi,bardyw,barudeyofu,brdywb,brdywf,Бардейов,Бардеёв,Бардіїв,Бардјејов,Горад Бардзеёў,Բարդեյով,ברדיוב,باردیو,برديوف,ბარდეიოვი,バルデヨフ,巴爾代約夫,바르데요프', 49.2917500, 21.2727100, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124745, 'Zvolen', 'Zvolen', 'Altsohl,Zolyom,Zvolen,Zwolen,Zwoleń,Zólyom,zvolen,Зволен', 48.5744200, 19.1532400, 'SK', '2016-08-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124746, 'Zlaté Moravce', 'Zlate Moravce', 'Aranyosmarot,Aranyosmarót,Gorad Zlata-Moraucy,Zlate Moravce,Zlate Moravcė,Zlate Moravtse,Zlate-Moravce,Zlaté Moravce,zi la te mo la fu cai,zlath mrawtsh,zlaty mwraftsy,Горад Злата-Мораўцы,Злате Моравце,Злате-Моравце,زلاته مراوتسه,زلاتى مورافتسى,茲拉特莫拉夫采', 48.3855300, 18.4006300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124747, 'Žilina', 'Zilina', 'Gorad Zhylina,ILZ,Jilina,Silina,Sillein,Solna,Zhilina,Zhilinae,Zilina,Zsolna,Zylina,jillina,jirina,jylyna,ri li na,zhilina,zhylyna,zylyna,zylynh,Żylina,Žilina,Горад Жыліна,Жилинæ,Жилина,Жиліна,זילינה,جيلينا,زیلینا,ژیلینا,ჟილინა,ジリナ,日利納,질리나', 49.2231500, 18.7394100, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124748, 'Žiar nad Hronom', 'Ziar nad Hronom', 'Svaty Kriz nad Hronom,Svätý Kríž nad Hronom,Ziar nad Hronom,Žiar nad Hronom', 48.5918400, 18.8495800, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124749, 'Želiezovce', 'Zeliezovce', 'Zeliezovce,Zeljezovce,Zhel''ezovce,Zhelezovce,Zseliz,Zselíz,jylyzwftsy,re lie zuo fu cai,Želiezovce,Željezovce,Жельезовце,Жељезовце,جيليزوفتسي,ژلیه‌زوتسه,热列佐夫采', 48.0507500, 18.6542100, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124750, 'Žarnovica', 'Zarnovica', 'Zarnovica,Zarovnica,Zharnovica,Zsarnoca,Zsarnóca,jarnwfytsa,zha er nuo wei cha,zharnwytsa,Žarnovica,Žarovnica,Жарновица,جارنوفيتسا,ژارنویتسا,扎爾諾維察', 48.4812300, 18.7156500, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124751, 'Vrútky', 'Vrutky', 'Ruttka,Vrutkai,Vrutki,Vrutky,Vrútky,Vrūtkai,Vrūtki,fu lu te ji,fwrtky,wrwtky,Врутки,فورتكي,وروتکی,弗魯特基', 49.1132800, 18.9171400, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124752, 'Vrbové', 'Vrbove', 'Verbo,Verbó,Vrbove,Vrbovje,Vrbové,fu er bo wei,fwrbwf,wrbwbh,wrbwh,Врбове,Врбовје,ורבובה,فوربوف,وربوه,弗爾博韋', 48.6197300, 17.7226000, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124753, 'Vráble', 'Vrable', 'Verebely,Verebély', 48.2437100, 18.3084600, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124754, 'Veľký Meder', 'Velky Meder', 'Calovo,Nagy Meder,Nagymegyer,Vel''ki-Meder,Veljki Medjer,Velki Medjer,da mei jie er,fylky mydar,wlky mdr,Čalovo,Вельки-Медер,Вељки Медјер,فيلكي ميدار,ولکی مدر,大梅傑爾', 47.8579800, 17.7688400, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124755, 'Veľký Krtíš', 'Velky Krtis', 'Gorad Vel''ki Krcish,Krtis,Krtíš,Nagykuertoes,Nagykürtös,Vel''ki Krtish,Vel''ki-Krtish,Vel''ky Krtis,Veljki Krtis,Veljki Krtiš,Velki Krtis,Velki Krtisa,Velki Krtish,Velki Krtiş,Veļki Krtīša,Veľký Krtíš,da ke er ji shen,fylky krtysh,wlky krtysh,Вельки Кртиш,Вельки-Кртиш,Вељки Кртиш,Горад Велькі Крціш,فيلكي كرتيش,ولکی کرتیش,大克爾季什', 48.2105900, 19.3504300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124756, 'Tvrdošín', 'Tvrdosin', 'Gorad Tvrdoshyn,Turdossin,Tvrdoshin,Tvrdosin,Tvrdosina,Tvrdošin,Tvrdošín,Tvrdošīna,Twardoszyn,te fu er duo xin,tfrdwshyn,twrdshyn,Горад Тврдошын,Тврдошин,تفردوشين,توردشین,特夫爾多辛', 49.3370000, 19.5560000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124757, 'Turzovka', 'Turzovka', 'Turzofalva,Turzovka,Turzowka,Turzófalva,Turzówka,tu er zuo fu ka,twrzwfka,twrzwka,Турзовка,تورزوفكا,تورزوکا,圖爾佐夫卡', 49.4042900, 18.6225800, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124758, 'Turčianske Teplice', 'Turcianske Teplice', 'Stubnianske Teplice,Stubnyafuerdo,Stubnyafürdő,Turcanske Teplice,Turch''janske-Teplice,Turchjanske Tjeplice,Turcianske Teplice,Turcjanske Tjeplice,Turčanske Teplice,Turčianske Teplice,Turčjanske Tjeplice,tu er qian si kai te pu li cai,twrchyanskh tplytsh,twrtshynsky tyblytsy,Štubnianske Teplice,Турчьянске-Теплице,Турчјанске Тјеплице,تورتشينسكى تيبليتسى,تورچیانسکه تپلیتسه,圖爾錢斯凱特普利采', 48.8622500, 18.8604800, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124759, 'Trstená', 'Trstena', 'Trstena,Trstená,Trsztena,Trzciana,te er si tai na,trstna,trystyna,Трстена,ترستنا,تريستينا,特爾斯泰納', 49.3610100, 19.6124900, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124760, 'Trnava', 'Trnava', 'Gorad Trnava,Nagyszombat,Trnava,Trnawa,Turnava,Tyrnau,te er na wa,teuleunaba,texr nawa,torunavu~a,trnafa,trnbh,Горад Трнава,Трнава,Търнава,טרנבה,ترنافا,เตอร์นาวา,トルナヴァ,特爾納瓦,트르나바', 48.3774100, 17.5872300, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124761, 'Trenčín', 'Trencin', 'Trenchin,Trencin,Trencsen,Trencsén,Trenczyn,Trentschin,Trentsen,Trenčin,Trenčín,Тренчин', 48.8945200, 18.0443600, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124762, 'Trenčianske Teplice', 'Trencianske Teplice', 'Trencanske Teplice,Trench''janske Teplice,Trench''janske-Teplice,Trenchinske Tjeplice,Trencianske Teplice,Trencinske Tjeplice,Trencsenteplic,Trencsénteplic,Trenczynskie Cieplice,Trenczyńskie Cieplice,Trenčanske Teplice,Trenčianske Teplice,Trenčinske Tjeplice,te lun qin wen quan zhen,trnchyanskh tplytsh,tryntshyasky tyblysy,Тренчинске Тјеплице,Тренчьянске Теплице,Тренчьянске-Теплице,ترنچیانسکه تپلیتسه,ترينتشياسكي تيبليسي,特倫欽溫泉鎮', 48.9106300, 18.1669100, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124763, 'Topoľčany', 'Topolcany', 'Gorad Topal''chany,Nagy Tapolcsan,Nagy Tapolcsán,Nagytapolcsany,Nagytapolcsány,Topol''cany,Topol''chani,Topolcani,Topolcany,Topolchani,Topolczany,Topoljcani,Topoljčani,Topolçanı,Topoļčani,Topoľčany,tplchany,tuo bo er qia ni,twbwltshany,Горад Топальчаны,Тополчани,Топольчани,Топољчани,טאפלישאן,טופולצאני,توبولتشاني,تپلچانی,托波爾恰尼', 48.5636100, 18.1671200, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124764, 'Tlmače', 'Tlmace', 'Garamtolmacs,Garamtolmács,Timac,Timace,Timač,Timače,Tlmace,Tlmače', 48.2892600, 18.5315200, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124765, 'Tisovec', 'Tisovec', 'Theissholz,Tisovec,Tisoveca,Tiszolc,Tiszolcz,ji suo wei ci,tyswfyts,tyswts,Тисовец,تيسوفيتس,تیسوتس,季索韋茨', 48.6773800, 19.9436400, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124766, 'Terchová', 'Terchova', 'Terhova', 49.2589500, 19.0293500, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124767, 'Svodín', 'Svodin', 'Seldin,Seldín,Svodin,Svodín,Szogyen,Szolgyen,Szölgyén,Szőgyén', 47.9105400, 18.4996700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124768, 'Svätý Jur', 'Svaty Jur', 'Gorad Svety-Jur,Jur pri Bratislave,Sanct Georgius,Sankt Georgen,Svaety Jur,Svaty Jur,Sveti Jur,Sveti-Jur,Svätý Jur,Szentgyoergy,Szentgyörgy,sfaty jwr,sheng qiao zhi,swty ywr,Горад Светы-Юр,Свети Јур,Свети-Юр,سفاتي جور,سوتی یور,聖喬治', 48.2521600, 17.2153900, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124769, 'Svätý Anton', 'Svaety Anton', 'Svaty Antol,Svaty Anton,Svätý Antol,Svätý Anton,Szentantal', 48.4192300, 18.9401000, 'SK', '2012-12-12', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124770, 'Šurany', 'Surany', 'Gorad Shurany,Nagysurany,Nagysurány,Shurani,Suran,Surani,Surany,Surány,shu la ni,shurani,shwran,Şuran,Šurani,Šurany,Горад Шураны,Шурани,شوران,シュラニ,舒拉尼', 48.0861300, 18.1844700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124771, 'Štúrovo', 'Sturovo', 'Gorad Shturava,Parkan,Parkany,Párkány,Shturovo,Sturovo,shen tu luo wo,shtwrwfw,shtwrww,Šturovo,Štúrovo,Štūrovo,Горад Штурава,Штурово,شتوروفو,شتوروو,什圖羅沃', 47.7949500, 18.7175000, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124772, 'Stupava', 'Stupava', 'Stampfen,Stomfa,Stupava,si tu pa wa,stwbafa,stwpawa  nahyh malatsky,Ступава,ستوبافا,ستوپاوا، ناحیه مالاتسکی,斯圖帕瓦', 48.2747400, 17.0317300, 'SK', '2015-12-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124773, 'Stará Turá', 'Stara Tura', 'Otura,Stara,Stara Tura,Stará,Stará Turá,Ótura', 48.7772100, 17.6943300, 'SK', '2017-01-09', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124774, 'Smolenice', 'Smolenice', 'Smolenice,Смоленице', 48.5047800, 17.4306700, 'SK', '2010-06-23', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124775, 'Sládkovičovo', 'Sladkovicovo', 'Diosek,Dioszeg,Diószeg,Kis-Dioszeg,Kis-Diószeg,Maly Diosek,Malý Diosek,Nagy-Dioszeg,Nagy-Diószeg,Sladkovicovo,Sládkovičovo,Vel''ky Diosek,Veldiosek,Veľký Diosek', 48.2013700, 17.6385200, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124776, 'Skalica', 'Skalica', 'Skalica', 48.8449000, 17.2263500, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124777, 'Senica', 'Senica', 'Gorad Senica,Senica,Senjica,Szenice,sai ni cha,senicha,snytsa,synytsa,Горад Сеніца,Сеница,Сењица,سنیتسا,سينيتسا,塞尼察,세니차', 48.6792200, 17.3669700, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124778, 'Senec', 'Senec', 'Senec,Senecas,Senets,Senjec,Szenc,sai nei ci,senecheu,snts  aslwaky,snz,synts,Сенец,Сењец,סנץ,سنتس، اسلواکی,سينتس,塞内茨,세네츠', 48.2195100, 17.4004300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124779, 'Šamorín', 'Samorin', 'Samorin,Shamorin,Somorja,sha mo lin,shamryn,shamwryn,smwryn,Şamorin,Šamorin,Šamorín,Шаморин,שמורין,شامرین,شامورين,沙莫林', 48.0301500, 17.3097200, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124780, 'Sellye', 'Sellye', 'Sal''a,Sala,Sala nad Vahom,Sellye,Selľye,Shalja,Vagsellye,Vágsellye,Šala nad Váhom,Šaľa,Шаля', 48.1512700, 17.8806200, 'SK', '2016-08-19', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124781, 'Šahy', 'Sahy', 'Ipoly Sagh,Ipoly Ságh,Ipolysag,Ipolyság,Sag,Sahi,Sahy,Shagi,Shakhi,Ság,sha xi,shahy,shahy  aslwaky,shy,Šahi,Šahy,Шаги,Шахи,סהי,شاهي,شاهی، اسلواکی,沙希', 48.0740800, 18.9494600, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124782, 'Ružomberok', 'Ruzomberok', 'Gorad Ruzhamberak,Rosenberg,Rozahegy,Rozsahegy,Roźahegy,Rujomberok,Ruzhomberok,Ruzomberk,Ruzomberok,Ruzomberoka,Ruzomberokas,Rużomberk,Ružomberok,Ružomberoka,Ružomberokas,Rózsahegy,lu rong bei luo ke,lujombelokeu,rujomuberoku,rwjwmbyrwk,rwzhmbrk,Горад Ружамберак,Ружомберок,روجومبيروك,روژمبرک,ルジョムベロク,鲁容贝罗克,루좀베로크', 49.0748000, 19.3075100, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124783, 'Rajec', 'Rajec', 'Rajec', 49.0889900, 18.6400700, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124784, 'Púchov', 'Puchov', 'Pucho,Puchov,Puchovas,Puho,Puhov,Puhova,Puhó,Pukhov,Puxov,Púchov,Pūchovas,Pūhova,bwkhwf,pu huo fu,puhopeu,pwkhw,Пухов,بوخوف,پوخو,普霍夫,푸호프', 49.1249400, 18.3259700, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124785, 'Prievidza', 'Prievidza', 'Gorad Previdza,Pr''evidza,Previdza,Prievidza,Privigye,Priеvidzа,Prjevidza,bryfydza,peuliebideuja,pu lie wei zha,purievu~idoza,Горад Превідза,Приевидза,Прьевидза,Прєвідза,Прјевидза,بريفيدزا,پریه‌ویدزا,プリエヴィドザ,普列維扎,프리에비드자', 48.7744600, 18.6275000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124786, 'Pribylina', 'Pribylina', 'Pribylina,Прибылина', 49.0995000, 19.7942700, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124787, 'Považská Bystrica', 'Povazska Bystrica', 'Bystrica,Gorad Pavazhska-Bistryca,Povajska Bistritsa,Povashka Bistrica,Povaska Bistrica,Povazhs''ka Bistricja,Povazhska-Bistrica,Povazska Bistrica,Povazska Bystrica,Povazske Bystraica,Povaška Bistrica,Považska Bistrica,Považská Bystrica,Powaska Bystrzyca,Vagbeszterce,Vágbeszterce,Waagbistritz,bwfajska bystrytsa,pobasyuseukabiseuteulicha,pwazhska bystrytsa,wa he he pan bi si te li cha,Горад Паважска-Бістрыца,Поважска-Бистрица,Поважська Бистриця,Повашка Бистрица,بوفاجسكا بيستريتسا,پواژسکا بیستریتسا,瓦赫河畔比斯特里察,포바슈스카비스트리차', 49.1215300, 18.4216900, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124788, 'Poltár', 'Poltar', 'Poltar,Poltara,Poltár,Poltāra,bo er ta er,bwltar,pltar,pwltar,Полтар,بولتار,پلتار,پولتار,波爾塔爾', 48.4309400, 19.7940800, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124789, 'Piešťany', 'Piestany', 'Gorad Peshcjany,P''eshtjani,PZY,Peshtjani,Pieshhjani,Piest''anoch,Piest''any,Piestany,Pieszczany,Piešťanoch,Piešťany,Pjeshtjani,Pjestjani,Pještjani,Poestyen,Pöstyén,byyshtany,pi ye shen jia ni,pieshuchani,piesyutani,Горад Пешцяны,Пиещяни,Пьештяни,Пєштяни,Пјештјани,بييشتاني,پیه‌شتانی,ピエシュチャニ,皮耶什佳尼,피에슈타니', 48.5947900, 17.8259100, 'SK', '2017-01-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124790, 'Pezinok', 'Pezinok', 'Bazin,Boesing,Bösing,Gorad Pezinak,Pezinok,Pеzinоk,byzynwk,pei ji nuo ke,pejinoku,pzynk,pzynwk,Горад Пезінак,Пезинок,بيزينوك,پزینوک,پزینک,ペジノク,佩濟諾克', 48.2898600, 17.2666400, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124791, 'Partizánske', 'Partizanske', 'Bat''ovany,Baťovany,Partizans''ke,Partizanske,Partizánske,Partizānske,Partyzanske,Partyzánske,Simonovany,Simony,bartyzansky,pa di zan si ke,partyzanskh,Šimonovany,Παρτίζανσκε,Партизанске,Партизанське,بارتيزانسكى,پارتیزانسکه,帕蒂贊斯克', 48.6286100, 18.3845500, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124792, 'Oravský Podzámok', 'Oravsky Podzamok', 'Oravsky Podzamok,Oravský Podzámok,Orawskie Zamki', 49.2593900, 19.3569000, 'SK', '2016-03-26', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124793, 'Nové Zámky', 'Nove Zamky', 'Ersekujvar,Neuhaeusel,Neuhaus,Neuhäusel,Nove Zamky,Nové Zámky,Uyvar,awywar,nove zamki,Érsekújvár,Нове Замки,اویوار', 47.9854400, 18.1619500, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124794, 'Nové Mesto nad Váhom', 'Nove Mesto nad Vahom', 'Nove Mesto nad Vagom,Nove Mesto nad Vahom,Nove-Mesto-nad-Vagom,Nové Mesto nad Váhom,Otura,Vagujhely,Vágújhely,Ótura,Нове Место над Вагом,Нове-Место-над-Вагом', 48.7576300, 17.8309000, 'SK', '2016-07-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124795, 'Nováky', 'Novaky', 'Navaky,Novaky,Nováky', 48.7110600, 18.5338900, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124796, 'Nová Dubnica', 'Nova Dubnica', 'Kiskelecseny,Kiskelecsény,Nova Dubnica,Nová Dubnica,Ujtoelgyes,Újtölgyes', 48.9347900, 18.1463200, 'SK', '2013-09-14', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124797, 'Nová Baňa', 'Nova Bana', 'Konigsberg,Königsberg,Nova Bana,Nova Banja,Nova Baņa,Nova-Banja,Nová Baňa,Ujbanya,nwa bana,nwfa bana,xin ba ni ya,Újbánya,Нова Бања,Нова-Баня,نوا بانا,نوفا بانا,新巴尼亞', 48.4230500, 18.6403700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124798, 'Nižná', 'Nizna', 'Nizna,Niznia,Nižnia,Nižná', 49.3104600, 19.5242800, 'SK', '2016-03-22', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124799, 'Nitra', 'Nitra', 'Gorad Nitra,Neutra,Nitra,Njitra,Nyitra,ni te la,niteula,nitora,nytra,nytrh,Њитра,Горад Нітра,Нитра,Нітра,ניטרה,נייטרא,نيترا,نیترا,ნიტრა,ニトラ,尼特拉,니트라', 48.3076300, 18.0845300, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124800, 'Nemšová', 'Nemsova', 'Nemsova,Nemšová', 48.9670200, 18.1189200, 'SK', '2012-02-02', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124801, 'Námestovo', 'Namestovo', 'Namestovo,Nameszto,Namiestow,Namiestów,Námestovo,Námesztó,Nāmestovo,na mei si tuo wo,namstww,namystwfw,Наместово,نامستوو,ناميستوفو,納梅斯托沃', 49.4079000, 19.4803200, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124802, 'Myjava', 'Myjava', 'Miava,Myjava', 48.7587600, 17.5686600, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124803, 'Modra', 'Modra', 'Gorad Modra,Modern,Modor,Modra,mdra,mo de la,mwdra,Горад Модра,Модра,Մոդրա,مدرا,مودرا,莫德拉', 48.3339700, 17.3071100, 'SK', '2014-01-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124804, 'Martin', 'Martin', 'Gorad Marcin,Martin,Martin i Slovakia,Martina,Martinas,Mаrtin,Turciansky Svaty Martin,Turocszentmarton,Turz-Sankt Martin,Turz-St. Martin,Turócszentmárton,Turčiansky Svätý Martin,ma ding,maleutin,martn,maruchin,Горад Марцін,Мартин,Мартін,مارتن,マルチン,马丁,마르틴', 49.0665100, 18.9239900, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124805, 'Marianka', 'Marianka', 'Mariatal,Mariavoelgy,Máriavölgy', 48.2490300, 17.0640000, 'SK', '2015-12-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124806, 'Malacky', 'Malacky', 'Gorad Malacki,Malacka,Malacke,Malacki,Malacky,Malaczka,Malatski,Malczka,Mаlаtski,ma la ci ji,malatsky,Горад Малацкі,Малацки,مالاتسكي,مالاتسکی,馬拉茨基', 48.4360400, 17.0218800, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124807, 'Lúčky', 'Lucky', 'Luchki,Lucky,Lúčky,Лучки', 49.1294400, 19.4022800, 'SK', '2017-07-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124808, 'Lučenec', 'Lucenec', 'LUE,Losonc,Losoncz,Lucenec,Luchenec,Lučenec,Лученец', 48.3324900, 19.6670800, 'SK', '2017-01-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124809, 'Liptovský Mikuláš', 'Liptovsky Mikulas', 'Liptau-Sankt-Nikolaus,Liptoszentmiklos,Liptovski-Mikulash,Liptovsky Mikulas,Liptovsky Svaty Mikulas,Liptovský Mikuláš,Liptovský Svätý Mikuláš,Liptowski Mikulasz,Liptószentmiklós,Липтовски-Микулаш', 49.0806100, 19.6221800, 'SK', '2017-07-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124810, 'Liptovský Hrádok', 'Liptovsky Hradok', 'Liptoujvar,Liptovski Hradok,Liptovski Hradoka,Liptovski Hrādoka,Liptovski Khradok,Liptovski-Gradok,Liptovsky Hradok,Liptovský Hrádok,Liptowski Grodek,Liptowski Gródek,Liptóújvár,li pu tuo fu bao,lybtwfsky hradwk,lyptwsky hradk,Липтовски Храдок,Липтовски-Градок,ليبتوفسكي هرادوك,لیپتوسکی هرادک,利普托夫堡', 49.0396200, 19.7233500, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124811, 'Levice', 'Levice', 'Gorad Leviceh,Leua,Leva,Levice,Levicė,Levitse,Ljevice,Léva,Lеvitsе,lai wei cai,lwh,lyfytsa,Љевице,Горад Левіцэ,Левице,لوه,ليفيتسا,萊維采', 48.2156300, 18.6070500, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124812, 'Leopoldov', 'Leopoldov', 'Leopoldov,Mestecko,Mestečko,Ujvaroska,Újvároska,Леополдов', 48.4457500, 17.7645800, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124813, 'Kysucké Nové Mesto', 'Kysucke Nove Mesto', 'Kisucke Nove Mesto,Kisucke-Nove-Mesto,Kisutske Nove Mesto,Kiszucaujhely,Kiszucaújhely,Kysucke Nove Mesto,Kysucké Nové Mesto,ku shu ji xin mei si tuo,kyswtskh nwh mstw,kyswtsky nwfy mystw,Кисуцке Нове Место,Кисуцке-Нове-Место,كيسوتسكى نوفى ميستو,کیسوتسکه نوه مستو,庫舒基新梅斯托', 49.3000000, 18.7833300, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124814, 'Krupina', 'Krupina', 'Korpona,Krupina,ke lu pi na,keulupina,krwbyna,krwpyna,Крупина,Крупіна,كروبينا,کروپینا,克魯皮納,크루피나', 48.3554000, 19.0647400, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124815, 'Kremnica', 'Kremnica', 'Gorad Krehmnica,Koermoecbanya,Kormoczbanya,Kremnica,Kremnicja,Kremnitz,Kremnjica,Körmöcbánya,Körmöczbánya,ke lei mu ni cha,krmnytsa,krymnyka,kuremunitsu~a,Горад Крэмніца,Кремница,Кремниця,Кремњица,كرمنيتسا,کرمنیتسا,کریمنیکا,クレムニツァ,克雷姆尼察', 48.7051900, 18.9183400, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124816, 'Krasňany', 'Krasnany', 'Krasnany,Krasňany', 49.2149100, 18.8871800, 'SK', '2013-04-01', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124817, 'Komárno', 'Komarno', 'Dvor Komarno,Dvor Komárno,Komarno,Komárno', 48.1166700, 18.3166700, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124818, 'Komárno', 'Komarno', 'Eszak-Komarom,Gorad Komarna,Komarnas,Komarno,Komarnom,Komarom,Komoran,Komorn,Komárno,Komárom,Komārno,ke ma er nuo,komaleuno,komaruno,kwmarnw,Észak-Komárom,Горад Комарна,Комарно,Коморан,كومارنو,コマールノ,科马尔诺,코마르노', 47.7635600, 18.1226300, 'SK', '2013-08-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124819, 'Kolárovo', 'Kolarovo', 'Guta,Gutta,Gúta,Kolarovo,Kolárovo,Kolārovo,ke la luo wo,klarwfw,klarww,Коларово,كلاروفو,کلاروو,科拉羅沃', 47.9229400, 17.9846700, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124820, 'Ivanka pri Dunaji', 'Ivanka pri Dunaji', 'Ivanka,Pozsonyivanka,Pozsonyivánka', 48.1867500, 17.2554000, 'SK', '2015-05-20', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124821, 'Ilava', 'Ilava', 'Hava,Ilava,Illava,alawa,aylafa,aylawa,yi la wa,Илава,الاوا,ايلافا,ایلاوا,伊拉瓦', 48.9976900, 18.2353000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124822, 'Hybe', 'Hybe', 'Hybe', 49.0443900, 19.8289500, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124823, 'Hurbanovo', 'Hurbanovo', 'Altdala,Gurbanovo,Khurbanovo,Ogyalla,Stara d''ala,Stará ďala,hu er ba nuo wo,hwrbanwfw,hwrbanww,Ógyalla,Гурбаново,Хурбаново,هوربانوفو,هوربانوو,ہربانووو,胡爾巴諾沃', 47.8698400, 18.1923300, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124824, 'Hrochoť,Slovakia', 'Hrochot,Slovakia', 'Horhat,Horhát,Hrochot'',Hrochoť', 48.6556700, 19.3128400, 'SK', '2014-04-20', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124825, 'Hriňová', 'Hrinova', 'Grinjova,Herencsvoelgy,Herencsvölgy,Hrinjova,Hrinova,Hriņova,Hriňová,Khrinova,he li ni ao wa,hrynwa,hrynwfa,Гринёва,Хрињова,هرينوفا,هرینوا,ہرینووا,赫里尼奧瓦', 48.5778700, 19.5257400, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124826, 'Holíč', 'Holic', 'Golich,Holic,Holics,Holič,Holíč,Kholich,hlych,hlytsh,huo li qi,Голич,Холич,هليتش,هلیچ,ہولیچ,霍利奇', 48.8110500, 17.1623800, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124827, 'Hlohovec', 'Hlohovec', 'Galgoc,Galgóc,Hlohovec,glogovec,Глоговец', 48.4317400, 17.8031000, 'SK', '2016-08-03', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124828, 'Handlová', 'Handlova', 'Gandlova,Gorad Gandlava,Handlova,Handlová,Khandlova,Mercatoria,Nyitrabanya,Nyitrabánya,han de luo wa,handlwa,handlwfa,Гандлова,Горад Гандлава,Хандлова,هاندلوا,هاندلوفا,ہینڈلووا,漢德洛瓦', 48.7276000, 18.7601200, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124829, 'Gbely', 'Gbely', 'Egbell,Gbely', 48.7180000, 17.1162800, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124830, 'Galanta', 'Galanta', 'Galanta,Galánta,Галанта', 48.1900100, 17.7274700, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124831, 'Gabčíkovo', 'Gabcikovo', 'Bes,Beš,Bos,Bös,Gabcikovo,Gabčíkovo', 47.8921100, 17.5788400, 'SK', '2012-12-12', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124832, 'Fiľakovo', 'Fil''akovo', 'Fil''akovo,Filakovo,Filek,Filjakovo,Fiļakovo,Fiľakovo,Fuelek,Fulek,Fülek,fei la ke wo,fylakwfw,fylakww,fylk,Филяково,Фиљаково,فيلاكوفو,فیلاکوو,فیلک,菲拉科沃', 48.2675700, 19.8247300, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124833, 'Bratislava - Vajnory', 'Bratislava - Vajnory', 'Pozsonyszolos,Pozsonyszőlős,Pracsa,Prácsa,Vajnory,Weinern', 48.2056300, 17.2075900, 'SK', '2015-05-20', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124834, 'Dunajská Streda', 'Dunajska Streda', 'Duna-Szerdahely,Dunaiska Streda,Dunajska Streda,Dunajska-Streda,Dunajská Streda,Dunaszerdahely,Dunayska Streda,Gorad Dunajska-Strehda,dunaiseukaseuteuleda,duo nao si te lei da,dwnyska stryda,Горад Дунайска-Стрэда,Дунайска-Стреда,Дунајска Стреда,דונאיסקה סטרדה,دونيسكا ستريدا,ドゥナイスカー・ストレダ,多瑙斯特雷達,두나이스카스트레다', 47.9926800, 17.6121100, 'SK', '2012-12-24', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124835, 'Dudince', 'Dudince', 'Dudince,Dugince,Duđince,Gorad Dudzincy,Gyugy,Gyűgy,do~udintsu~e,du ding xi,dwdynts,Горад Дудзінцы,Дудинце,Дудінце,دودينتس,دودینتس,ڈوڈینس,ドゥディンツェ,杜丁西', 48.1713500, 18.8878200, 'SK', '2012-12-12', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124836, 'Dubnica nad Váhom', 'Dubnica nad Vahom', 'Dubnica na Vakhu,Dubnica nad Vahom,Dubnica nad Váhom,Dubnica pie Vahas,Dubnica pie Vāhas,Dubnica prie Vaho,Dubnica-nad-Vagom,Dubnitsa nad Vahom,Dubnjica na Vahu,Gorad Dubnica-nad-Vagam,Mariatoelgyes,Máriatölgyes,dubeunichanateubahom,dwbnytsa nad fahwm,dwbnytsa nad wahm,wa he he pan du bu ni cha,Горад Дубніца-над-Вагам,Дубница-над-Вагом,Дубњица на Ваху,دوبنيتسا ناد فاهوم,دوبنیتسا ناد واهم,瓦赫河畔杜布尼察,두브니차나트바홈', 48.9598100, 18.1663400, 'SK', '2016-04-30', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124837, 'Dolný Kubín', 'Dolny Kubin', 'Alsokubin,Alsókubin,Dolni Kubin,Dolny Kubin,Dolny-Kubin,Dolní Kubín,Dolný Kubín,Долны-Кубин', 49.2098300, 19.3034100, 'SK', '2017-07-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124838, 'Detva', 'Detva', 'Detva,Djetva,Gyetva,dai te wa,dtwa,dytfa,Детва,Дјетва,دتوا,ديتفا,代特瓦', 48.5608200, 19.4195400, 'SK', '2011-02-22', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124839, 'Čierny Balog', 'Cierny Balog', 'Cierny Balog,Cierny Balok,Cierny Blh,Čierny Balog,Čierny Balok,Čierny Blh', 48.7472200, 19.6512500, 'SK', '2012-12-12', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124840, 'Čadca', 'Cadca', 'Cadca,Chadca,Csaca,Csacza,Czaca,Čadca,Чадца', 49.4350300, 18.7889500, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124841, 'Čachtice', 'Cachtice', 'Chakhtice,Чахтице', 48.7122600, 17.7870400, 'SK', '2017-01-09', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124842, 'Bytča', 'Bytca', 'Bitca,Bitcha,Bitča,Bytca,Bytča,Nagybiccse,bi te qia,bytcha,byttsha,bytzh,Битча,ביטצה,بيتتشا,بیتچا,ბიტჩა,比特恰', 49.2240400, 18.5587800, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124843, 'Brezová pod Bradlom', 'Brezova pod Bradlom', 'Berezo,Berezó,Brezova pod Bradlom,Brezová pod Bradlom', 48.6634900, 17.5390500, 'SK', '2016-01-28', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124844, 'Brezno', 'Brezno', 'Brezno,Brezno nad Hronom,Breznobanya,Breznon,Breznóbánya,Bries,Брезно', 48.8043100, 19.6363100, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124845, 'Bratislava', 'Bratislava', 'An Bhrataslaiv,An Bhratasláiv,BTS,Baratislawa,Bratislav,Bratislava,Bratislava osh,Bratislavae,Bratislavo,Bratislawa,Bratisllava,Bratisława,Bratyslawa,Bratysława,Bratîslava,Gorad Bracislava,Mpratislaba,Posonium,Pozsony,Presburg,Presporok,Prespurk,Pressburg,Preszburg,Preßburg,Prešporok,Prešpurk,beulatiseullaba,bra ti sla wa,bratisalava,bratislabha,bratislava,bratislavha,bratslawa,bratsylava,bratyslafa,bratyslava,bratyslaw,bratyslawa,bu la di si la fa,burachisuravu~a,pirattislava,Μπρατισλάβα,Братислав,Братиславæ,Братислава,Братислава ош,Братіслава,Братїслава,Горад Браціслава,Բրատիսլավա,בראטיסלאווא,ברטיסלאבה,براتسلاوا,براتسیلاڤا,براتىسلاۋا,براتيسلافا,براتیسلاو,براتیسلاوا,براٹیسلاوا,ܒܪܛܝܣܠܐܒܐ,ब्रातिस्लाभा,ब्रातिस्लाव्हा,ব্রাতিস্লাভা,ਬ੍ਰਾਤਿਸਲਾਵਾ,பிராத்திஸ்லாவா,ಬ್ರಾಟಿಸ್ಲಾವಾ,ബ്രാട്ടിസ്‌ലാവ,บราติสลาวา,བ་ར་ཏིསི་ལ་བ།,ბრატისლავა,ብራቲስላቫ,ブラチスラヴァ,布拉迪斯拉发,布拉迪斯拉發,브라티슬라바', 48.1481600, 17.1067400, 'SK', '2011-03-31', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124846, 'Bojnice', 'Bojnice', 'Bajmoc,Bajmóc,Bojnice,Bojnjice,Gorad Bojnicy,bo yi ni cai,boiniche,bwynytsy,bynytsh,Бойнице,Бојњице,Горад Бойніцы,بوينيتسى,بینیتسه,博伊尼采,보이니체', 48.7851100, 18.5864000, 'SK', '2012-01-18', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124847, 'Banská Štiavnica', 'Banska Stiavnica', 'Bans''ka Shtjavnicja,Banska Shhjavnica,Banska Shtjavnica,Banska Stiavnica,Banska Stiavnica a Banska Bela,Banska Stjavnica,Banska Szczawnica,Banska Štiavnica,Banska Štjavnica,Banska-Sht''javnica,Banská Štiavnica,Banská Štiavnica a Banská Belá,Bańska Szczawnica,Gorad Banska-Shc''jaunica,Schemnitz,Selmecbanya,Selmecbánya,Selmeczbanya,Selmeczbánya,ban si ka shen jia fu ni cha,banseukasyutiabeunicha,banska shtyawyntsa,banska shtyfnytsa,Банска Штјавњица,Банска Щявница,Банска-Штьявница,Банська Штявниця,Горад Банска-Шцьяўніца,באנסקה שטיאווניצה,بانسكا شتيفنيتسا,بانسکا شتیاوینتسا,ბანსკა-შტიავნიცა,バンスカー・シュチャヴニツァ,班斯卡什佳夫尼察,반스카슈티아브니차', 48.4485800, 18.9100300, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124848, 'Banská Bystrica', 'Banska Bystrica', 'Bans''ka Bistricja,Banska Bistrica,Banska Bistritsa,Banska Bystrica,Banska Bystrzyca,Banska-Bistrica,Banská Bystrica,Bańska Bystrzyca,Besztercebanya,Besztercebánya,Beszterczebanya,Beszterczebánya,Gorad Banska Bistryca,Neosolium,Neusohl,ban si ka-bi si te li cha,ban ska bi stri t sa,banseukabiseuteulicha,banska bystrytsa,Банска Бистрица,Банска-Бистрица,Банська Бистриця,Горад Банска Бістрыца,באנסקה ביסטריצה,بانسكا بيستريتسا,บันสกาบิสตรีตซา,バンスカー・ビストリツァ,班斯卡-比斯特里察,반스카비스트리차', 48.7394600, 19.1534900, 'SK', '2014-04-21', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124849, 'Bánovce nad Bebravou', 'Banovce nad Bebravou', 'Ban,Banovce,Banovce na Bebravi,Banovce nad Bebravou,Banovce pie Bebravas,Banovce-nad-Bebravou,Banovtse nad Bebravou,Bán,Bánovce nad Bebravou,Bānovce pie Bebravas,banovtse-nad-bebravou,banwfts nad bybrafw,banwtsh nad bbraww,bei bu la wa he pan ba nuo wei cai,Бановце на Бебрави,Бановце-над-Бебравоу,بانوتسه ناد ببراوو,بانوفتس ناد بيبرافو,ბანოვცე-ნად-ბებრავოუ,貝布拉瓦河畔巴諾維采', 48.7213000, 18.2575400, 'SK', '2015-10-16', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124850, 'Oravská Lesná', 'Oravska Lesna', 'Erdudka,Erdutka,Erdúdka,Erdútka,Lesna', 49.3667200, 19.1809300, 'SK', '2008-05-22', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124851, 'Dunajská Lužná', 'Dunajska Luzna', 'Dunajska Luzna,Dunajskaja Luzhnja,Dunajská Lužná,Дунайская Лужня', 48.0834700, 17.2607200, 'SK', '2013-09-14', 202);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124658, 'Bohinjska Bistrica', 'Bohinjska Bistrica', 'Bokhin''ska-Bystrica,Wochein Feistritz,Бохиньска-Быстрица', 46.2721600, 13.9535000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124659, 'Bled', 'Bled', 'Bled,Bledas,Obcina Bled,Občina Bled,Veldes,beulledeu,bld,bld  aslwwny,blyd,blyt,bu lai de,bureddo,Блед,בלד,بلد، اسلوونی,بليد,بلیت,ブレッド,布莱德,블레드', 46.3691700, 14.1136100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124660, 'Bistrica pri Tržiču', 'Bistrica pri Trzicu', 'Bistrica pri Trzicu,Bistrica pri Tržiču', 46.3547200, 14.2916700, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124661, 'Bistrica ob Sotli', 'Bistrica ob Sotli', 'Bistrica,Bistrica ob Sotli,Sent Peter,Sveti Peter,Sveti Peter pod Sveti Gorami,Šent Peter', 46.0588900, 15.6641700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124662, 'Bilje', 'Bilje', 'Biglia,Bilje', 45.8944400, 13.6322200, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124663, 'Benedikt', 'Benedikt', 'Benedicki Vrh,Benedikt,Benedikt v Slovenskih Goricah', 46.6086100, 15.8883300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124664, 'Beltinci', 'Beltinci', 'Belatinc,Belatincz,Beltinci,Obcina Beltinci,Občina Beltinci,beltinci,berutintsu~i,Белтинци,ベルティンツィ', 46.6052800, 16.2405600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124665, 'Bakovci', 'Bakovci', 'Bakovci,Barkoc,Barkocz,Barkóc,Barkócz', 46.6188900, 16.1502800, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124666, 'Apače', 'Apace', 'Abstall,Apace,Apače', 46.6972200, 15.9105600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124667, 'Ajdovščina', 'Ajdovscina', 'Agintobstsina,Aidussina,Ajdovscina,Ajdovshchina,Ajdovshhina,Ajdovščina,Gmina Ajdovscina,Gmina Ajdovščina,Haidenschaft,Hajdensaft,Hajdenšaft,Obcina Ajdovscina,Občina Ajdovščina,a yi duo fu shen qi na,aidofushuchina,aydwshchyna,aydwshtshyna,aydwwshchyna,Αγιντόβστσινα,Айдовшчина,Айдовщина,Ајдовшчина,آيدوشتشينا,آیدوشچینا,آیدووشچینا,アイドフシュチナ,阿伊多夫什契纳', 45.8860100, 13.9094600, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124668, 'Razkrižje', 'Razkrizje', 'Ligetfalva,Rackanizsa,Raczkanizsa,Raskrizje,Raskrižje,Razkrizje,Razkrižje,Ráckanizsa,Ráczkanizsa,Safarsko,Vegfalva,Vescica,Vešćica,Végfalva,Šafarsko', 46.5216700, 16.2811100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124669, 'Solkan', 'Solkan', 'Solkan', 45.9713900, 13.6494400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124670, 'Slovenski Javornik', 'Slovenski Javornik', '', 46.4261100, 14.0872200, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124671, 'Koroška Bela', 'Koroska Bela', 'Koroska-Bela,Koroška-Bela', 46.4491300, 14.1113500, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124672, 'Cerkno', 'Cerkno', 'Cerkno,Circhina', 46.1255600, 13.9816700, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124673, 'Leskova Dolina', 'Leskova Dolina', 'Leskova Dol,Leskova Dolina,Loska Dolina,Loška Dolina', 45.6213900, 14.4605600, 'SI', '2013-08-10', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124674, 'Logatec', 'Logatec', 'Logatec,Obcina Logatec,Občina Logatec,rogatetsu,ロガテツ', 45.9144400, 14.2258300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124675, 'Ankaran', 'Ankaran', 'Ancarano,Ancaria,Ankaran,ankalan,ankaran,xang kha ran,انکاران,อังคาราน,アンカラン,안카란', 45.5786100, 13.7361100, 'SI', '2016-11-23', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124676, 'Videm pri Ptuju', 'Videm pri Ptuju', 'Sankt Veit ueber Pettau,Sankt Veit über Pettau,Sveti Vid pri Ptuju,Treun ueber Pettau,Treun über Pettau,Videm,Videm pri Ptuju', 46.3686100, 15.9063900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124677, 'Legen', 'Legen', 'Legen', 46.5065100, 15.1442400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124678, 'Zreče', 'Zrece', '', 46.3822200, 15.3791700, 'SI', '2015-11-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124679, 'Radizel', 'Radizel', 'Radizel,Radizelj', 46.4744400, 15.6558300, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124680, 'Selnica ob Dravi', 'Selnica ob Dravi', 'Selnica,Selnica ob Dravi', 46.5500000, 15.4950000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124681, 'Lucija', 'Lucija', 'Lucia', 45.5052600, 13.6024000, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124682, 'Jagodje', 'Jagodje', 'Jagodje', 45.5284500, 13.6472100, 'SI', '2014-05-01', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124683, 'Pobegi', 'Pobegi', 'Pobegi', 45.5394400, 13.7961100, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124684, 'Spodnje Škofije', 'Spodnje Skofije', 'Spodnje Skofije,Spodnje Škofije', 45.5716700, 13.7925000, 'SI', '2014-04-25', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124685, 'Rožna Dolina', 'Rozna Dolina', 'Rozna Dolina,Rožna Dolina', 45.9419400, 13.6677900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124686, 'Kisovec', 'Kisovec', '', 46.1391100, 14.9629500, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124687, 'Cirkulane', 'Cirkulane', '', 46.3440800, 15.9947200, 'SI', '2015-11-26', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124688, 'Komenda', 'Komenda', '', 46.2048400, 14.5383900, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124689, 'Nazarje', 'Nazarje', 'Hodosch,Nazarje,Orihodos,Őrihodos', 46.3175700, 14.9467400, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124690, 'Kostel', 'Kostel', 'Comuna Kostel,Kostel,Municipality o Kostel,Municipality of Kostel,Obcina Kostel,Občina Kostel,Opcina Kostel,Opshtina Kostel,Općina Kostel,Костел,Општина Костел', 45.5084200, 14.9100500, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124691, 'Vir', 'Vir', 'Vir', 46.1532500, 14.6074100, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124692, 'Lavrica', 'Lavrica', 'Lavrica', 46.0000200, 14.5573000, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124693, 'Seča', 'Seca', 'Seca,Seča', 45.4958400, 13.6146600, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124694, 'Prade', 'Prade', 'Prade', 45.5400300, 13.7760700, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124695, 'Zasip', 'Zasip', 'Zasip', 46.3928400, 14.1086900, 'SI', '2014-04-24', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124696, 'Bistrica ob Dravi', 'Bistrica ob Dravi', 'Bistrica ob Dravi', 46.5541900, 15.5485500, 'SI', '2014-04-27', 203);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125004, 'Yeed', 'Yeed', 'Iet,Yed,Yeed,Yeid,Yēd', 4.5500000, 43.0333300, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125005, 'Xuddur', 'Xuddur', 'Huddur Hadama,Huddur Haddama,Hudur,Húddur Hadama,Húddur Haddama,Oddur,Xuddur,Xuddur Hadama,Xudur', 4.1212900, 43.8894500, 'SO', '2013-08-06', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125006, 'Xarardheere', 'Xarardheere', 'Adim,Harardera,Harardere,Harardére,Xarardheere', 4.6544000, 47.8575000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125007, 'Wanlaweyn', 'Wanlaweyn', 'Bahle Dogli,Uanle Uen,Wangleweyn,Wanla Uen,Wanla Weyne,Wanlaweyn,Wanle Weyne', 2.6185000, 44.8938000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125008, 'Waajid', 'Waajid', 'Uegit,Waajid,Wadjid,Wajid,Wājid', 3.8095800, 43.2462700, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125009, 'Tayeeglow', 'Tayeeglow', 'Tayeegle,Tayeeglow,Tayegle,Tayēgle,Tigheglo,Tigieglo,Tiyeglow,Trigieglo,Trijeglo', 4.0189700, 44.5111100, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125010, 'Saacow', 'Saacow', '', 1.6279400, 42.4406700, 'SO', '2012-02-28', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125011, 'Qoryooley', 'Qoryooley', 'Coriole,Coriolei,Koriolay,Qoreyole,Qoryolay,Qoryooley', 1.7878400, 44.5299900, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125012, 'Qandala', 'Qandala', 'CXN,Candala,Kandala,Qandala', 11.4719700, 49.8728200, 'SO', '2017-02-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125013, 'Oodweyne', 'Oodweyne', 'Codweyne,Odweina,Odweine,Odweyne,Oodweeyne,Oodweyne,Ōdwēyne', 9.4092000, 45.0639700, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125014, 'Mogadishu', 'Mogadishu', 'Gorad Magadysha,MGQ,Magadiscio,Maqdishu,Mogadiisho,Mogadis,Mogadisas,Mogadischu,Mogadiscio,Mogadish,Mogadisho,Mogadishu,Mogadisjoe,Mogadisju,Mogadisjû,Mogadiso,Mogadiss,Mogadisu,Mogadisxo,Mogadiszu,Mogadixo,Mogadiŝo,Mogadişu,Mogadiš,Mogadišas,Mogadišo,Mogadišu,Mogadíscio,Mogadīšo,Mogaidisiu,Mogaidisiú,Monkantisou,Moqadiso,Moqadişo,Moukdicho,Moukntiso,Mugadiccu,Mugadishu,Mugadiss,Muqdisho,Muqdishow,Muqdishu,Mógadisjú,Xamar,makadisu,meagadisu,mo jia di sha,mo jia di xiu,mo kadi chu,mogadisho,mogadishu,mogadisu,mogadisyu,mogarisu,mqdyshw,mqdyshyw,mukticu,mwgadyshw,mwgdysw,mwghadyshw,mۆgadyshۆ,Μογκαντίσου,Μουκντίσο,Горад Магадыша,Могадишо,Могадишу,Могадішо,Մոգադիշո,מאגאדישו,מוגדישו,مقديشو,مقديشيو,موغادیشو,موگادیشو,مۆگادیشۆ,मोगादिशू,मोगादीशू,মোগাদিশু,ਮਕਦੀਸ਼ੂ,ମୋଗାଡ଼ିସୁ,முக்தீசூ,മൊഗാദിഷു,โมกาดิชู,མོ་ག་དི་ཤུ།,მოგადიშო,ሞቃዲሾ,モガディシュ,摩加迪休,摩加迪沙,모가디슈', 2.0371100, 45.3437500, 'SO', '2012-05-03', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125015, 'Marka', 'Marka', 'Marca,Marka,Merca,Merka,mrkt‎,مركة‎', 1.7159400, 44.7716600, 'SO', '2014-05-28', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125016, 'Mahaddayweyne', 'Mahaddayweyne', 'Mahaddayweyne', 2.9726000, 45.5347000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125017, 'Luuq', 'Luuq', 'LGX,Lugh,Lugh Ferrandi,Lugh Ganana,Lugh Ganane,Lughferandi,Luk,Luuq,Лук', 3.8031500, 42.5441700, 'SO', '2014-11-02', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125018, 'Lughaye', 'Lughaye', 'Lughaye,Luqaya', 10.6857300, 43.9439700, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125019, 'Las Khorey', 'Las Khorey', 'Banden Laskhonai,LKR,Laasqoray,Laasqorey,Las Goni,Las Khonai,Las Khoreh,Las Khorey,Las Qoray,Lās Qóray,lasquray,لاسقُرَى', 11.1595000, 48.1967000, 'SO', '2013-11-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125020, 'Kismayo', 'Kismayo', 'Chisimaio,Chisimayu,KMU,Kisimayo,Kisimayu,Kismaanyo,Kismaayo,Kismanyo,Kismayo,Kismayu,Kismānyó,kisumayo,キスマヨ', -0.3581700, 42.5453600, 'SO', '2014-06-01', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125021, 'Jilib', 'Jilib', 'Dzhilib,Gelib,Jeelib,Jilib,Джилиб', 0.4882900, 42.7853500, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125022, 'Jawhar', 'Jawhar', 'Giohar,Jawhar,Johar,Joher,Joowhar,Jowhar,Jōwhar,Villa Duca Abruzzi,Villaggio Duca Abruzzi,Villaggio Duca degli Abruzzi', 2.7808700, 45.5004800, 'SO', '2015-11-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125023, 'Jamaame', 'Jamaame', 'Giamama,Giamame,Giamana,Giamane,Jamaame,Jamame,Jamāme,Margherita', 0.0696800, 42.7449700, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125024, 'Jalalaqsi', 'Jalalaqsi', 'Gialalassi,Jalalaqsi', 3.3766000, 45.5996000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125025, 'Iskushuban', 'Iskushuban', 'CMS,Iskushuban,Scusciuban,Skushuban', 10.2837000, 50.2300000, 'SO', '2016-12-03', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125026, 'Hobyo', 'Hobyo', 'CMO,Hobiya,Hobya,Hobyaa,Hobyo,Hobyā,Obbia', 5.3505000, 48.5268000, 'SO', '2017-02-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125027, 'Hargeysa', 'Hargeysa', 'HGA,Hargeisa,Hargesa,Hargeysa,Khargejse,Харгейсе', 9.5600000, 44.0650000, 'SO', '2016-10-22', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125028, 'Garoowe', 'Garoowe', 'GGR,Garoe,Garoowe,Garoueh,Garove,Garoway,Garowe,Geroweh,Gherroue,Gherrowe,Gherròue,Gorad Garoveh,Magiamacarscio,galowe,garoue,garou~e,gharwy,gharwy‎,jia luo wei,ka rowe,Гарове,Гароуэ,Горад Гаровэ,غاروي‎,غاروی,กาโรเว,გაროუე,ガローウェ,加罗韦,가로웨', 8.4020700, 48.4828400, 'SO', '2014-08-19', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125029, 'Garbahaarrey', 'Garbahaarrey', 'GBM,Garba Harey,Garba Harre,Garbahaarrey', 3.3289200, 42.2209100, 'SO', '2013-11-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125030, 'Gaalkacyo', 'Gaalkacyo', 'GLK,Gaal Kacyo,Gaalkacyo,Gaalkayo,Gal''kajo,Galcaio,Galka`yo'',Galkacyo,Galkajo,Galkayo,Galka‘yo’,Gallacai,Gallacaio,Rocca Littorio,galkayo,garukaiyo,jia lei ka yue,kal khak yo,Галькайо,جالكعيو,جالکعیو,กาลคักโย,გალკაიო,ガルカイヨ,加勒卡約,갈카요', 6.7697200, 47.4308300, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125031, 'Eyl', 'Eyl', 'Ayl,Ceel,Eeyl,Eil,Eyl,HCM', 7.9803000, 49.8164000, 'SO', '2017-02-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125032, 'Dujuuma', 'Dujuuma', 'Digiuma,Dugiuma,Dujuma,Dujuuma,Dùgiuma', 1.2531100, 42.5737700, 'SO', '2012-02-28', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125033, 'Dhuusamarreeb', 'Dhuusamarreeb', 'Dhuusa Mareeb,Dhuusamarreeb,Dusa Mareb,Dusa Marreb', 5.5359700, 46.3866600, 'SO', '2013-07-04', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125034, 'Ceerigaabo', 'Ceerigaabo', 'Ceerigaabo,Cerigaabo,ERA,Erigabo,Erigavo', 10.6161600, 47.3679500, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125035, 'Ceeldheer', 'Ceeldheer', 'Ceeldheer,Ceeldheere,El Dere', 3.8487800, 47.1806400, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125036, 'Ceelbuur', 'Ceelbuur', 'Ceelbuur,El Bur', 4.6850100, 46.6176000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125037, 'Ceek', 'Ceek', 'Aik,Ceek,Ceg,Eik,`Eg,‘Eg', 8.9990700, 45.3582400, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125038, 'Caluula', 'Caluula', 'ALU,Aeula,Alula,Bandar Alula,Calula,Caluula', 11.9661100, 50.7569400, 'SO', '2017-03-31', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125039, 'Cadale', 'Cadale', 'Adale,Cadale,Ilala,Itala', 2.7603000, 46.3222000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125040, 'Adado', 'Adado', 'AAD,Adado,Cadaado,Cadaadoo', 6.1360300, 46.6276100, 'SO', '2017-05-04', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125041, 'Buurhakaba', 'Buurhakaba', 'Bur Acaba,Bur Hacaba,Burhakaba,Buur Hakkaba,Buurhakaba', 2.8025700, 44.0780500, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125042, 'Buur Gaabo', 'Buur Gaabo', 'Bircao,Bur Gabo,Bur Gap,Bur Gavo,Burgao,Buur Gaabo,Būr Gābo,Port Dunford,Port Durnford', -1.2191700, 41.8372500, 'SO', '2016-10-07', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125043, 'Buulobarde', 'Buulobarde', 'Bulo Berde,Bulo Burti,Buulo,Buulo Berde,Buulo Burte,Buulobarde,Būlo Bérde', 3.8537500, 45.5674400, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125044, 'Burao', 'Burao', 'BUO,Bur `o,Bur ‘ó,Burao,Burco,Buruo,bu la ao,burao,Бурао,Буръо,برعو,ბურაო,ブラオ,布拉奧', 9.5221300, 45.5336300, 'SO', '2014-06-01', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125045, 'Bu’aale', 'Bu''aale', 'Bu''aale,Bu’aale', 1.0833300, 42.5833300, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125046, 'Bosaso', 'Bosaso', 'BSA,Bandar Kassim,Bandar Qasim,Bender Qaasin,Bender Qasin,Boosaaso,Boosaso,Bosasas,Bosaso,Bosasso,Bénder Qāsin,bo sa so,bo sa suo,bosaso,bwsasw,Босасо,بوساسو,بوصاصو,โบซาโซ,ბოსასო,ボサソ,博萨索,보사소', 11.2842100, 49.1815800, 'SO', '2015-04-24', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125047, 'Bereeda', 'Bereeda', 'Bareda,Bareeda,Barēdá,Bereda,Bereeda', 11.8703700, 51.0579500, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125048, 'Berbera', 'Berbera', 'BBO,Berbera,Berberah,Berbere,Gorad Berbera,bai pei la,beleubela,berbera,berubera,brbrh,brbrt,Бербера,Бербера қаласы,Горад Бербера,ברברה,بربرة,بربرہ,ბერბერა,ベルベラ,柏培拉,베르베라', 10.4395900, 45.0143200, 'SO', '2014-07-12', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125049, 'Beledweyne', 'Beledweyne', 'BLW,Balad Weyn,Belai-Wen,Beled Weyn,Beleduehjne,Beledueyne,Beledweyne,Belet Uen,Belet Wayne,Belet Wen,Belet Weyne,Bālad Weyn,bei lan de wen,beledueini,belledeuweine,beretou~ein,bld wyn,bldwyn,Беледуэйне,بلد وين,بلدوین,ბელედუეინი,ベレトウェイン,貝蘭德文,벨레드웨이네', 4.7358300, 45.2036100, 'SO', '2017-04-02', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125050, 'Baidoa', 'Baidoa', 'BIB,Baidabho,Baidabo,Baidoa,Bajdabo,Bajdoa,Baydhabo,Iscia Baidoa,Isha Baydabo,Isha Baydhaba,Isha Baydhabo,bai duo ya,baidabo,baidoa,bydwa,ri ben yu,Байдабо,Байдоа,بيدوا,بیدوا,ბაიდოა,バイドア,拜多亞,日本語,바이다보', 3.1138300, 43.6498000, 'SO', '2013-09-21', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125051, 'Bargaal', 'Bargaal', 'Baargaal,Bargaal,Bargal', 11.2863600, 51.0773000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125052, 'Bandarbeyla', 'Bandarbeyla', 'Bandarbeyla,Bender Bayla,Bender Beila,Bender Beyla,Bénder Bäylá', 9.4942000, 50.8122000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125053, 'Baardheere', 'Baardheere', '', 2.3446400, 42.2764400, 'SO', '2006-01-27', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125054, 'Afgooye', 'Afgooye', 'Afgoi,Afgoje,Afgooye,Afgoye,Afgōye,Asgoi,Афгойе', 2.1381000, 45.1212000, 'SO', '2012-01-16', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125055, 'Laascaanood', 'Laascaanood', 'Laascaanood,Las Anod', 8.4773800, 47.3597100, 'SO', '2012-01-19', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125056, 'Baki', 'Baki', 'Baki', 9.8920600, 43.3853100, 'SO', '2013-08-10', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125057, 'Baligubadle', 'Baligubadle', '', 9.0000000, 44.0002800, 'SO', '2014-08-13', 205);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125071, 'Yirol', 'Yirol', 'Yirol', 6.5525000, 30.4980600, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125072, 'Yei', 'Yei', 'Ej,Jej,Jejus,Jėjus,Yei,Yey,Yēy,iei,yay,ye yi,Јеј,Ей,ياي,یی، جنوبی سوڈان,იეი,耶伊', 4.0944400, 30.6763900, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125073, 'Yambio', 'Yambio', 'Jambio,Yambio,Yambiyo,Ямбио', 4.5708300, 28.3941700, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125074, 'Winejok', 'Winejok', 'Wanyjok', 9.0122200, 27.5708100, 'SS', '2017-06-17', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125075, 'Wau', 'Wau', 'Uau,Vau,Vav,WUU,Wau,Waw,Wāw,vau,wa wu,wau,waw,Вав,Вау,Уау,ואו,واو,واو، جنوبی سوڈان,ვაუ,ワーウ,瓦烏,와우', 7.7011100, 27.9897200, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125076, 'Waat', 'Waat', 'Wa`at,Wa`th,Wa‘at,Wa‘th', 8.1792500, 32.1520600, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125077, 'Aweil', 'Aweil', 'Aweil,Awel,Eweil,Uwayl', 8.7619400, 27.3919400, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125078, 'Torit', 'Torit', 'Torit,tuo li te,twryt,Торит,טוריט,توريت,توریت,托里特', 4.4117700, 32.5704600, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125079, 'Tonj', 'Tonj', 'At Tonj,Ibba,Ton''gh,Tonj,Ton’gh', 7.2738900, 28.6775000, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125080, 'Terekeka', 'Terekeka', 'Tarakaka,Terakeka,Terekeka,Terrakekka', 5.4438900, 31.7508300, 'SS', '2017-06-17', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125081, 'Tambura', 'Tambura', 'Tambura,Tembura,Tumbura', 5.6000000, 27.4666700, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125082, 'Rumbek', 'Rumbek', 'RBX,Rumbek,Rumbekas,Rumbeke,Rumbik,lumbekeu,lun bei ke,rmbk,rmbyk,runbeku,rwmbq,Румбек,Румбеке,רומבק,رمبيك,رمبک,რუმბეკი,ルンベク,倫貝克,룸베크', 6.8061900, 29.6774200, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125083, 'Raja', 'Raja', 'Raga,Ragaa,Raja', 8.4675000, 25.6783300, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125084, 'Pibor', 'Pibor', 'Fort Bruce,Pibor,Pibor Post', 6.7985300, 33.1304500, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125085, 'Nasir', 'Nasir', 'An Nasir,Nasir,Nasser,Nāşir', 8.6165800, 33.0621500, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125086, 'Mundri', 'Mundri', '', 5.3472000, 30.3243300, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125087, 'Maridi', 'Maridi', 'Maridi,Marīdi,Meridi,Merridi', 4.9166700, 29.4694400, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125058, 'Wageningen', 'Wageningen', 'AGI,Wageningen', 5.7601000, -56.6652300, 'SR', '2015-08-07', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125059, 'Totness', 'Totness', 'Corome,Coronie,Post Coronie,TOT,Todness,Totness', 5.8761800, -56.3257200, 'SR', '2015-08-07', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125060, 'Paramaribo', 'Paramaribo', 'Gorad Paramaryba,PBM,Paramaribas,Paramaribo,Paramaribô,Paramarimpo,Paramaríbó,ba la ma li bo,baramarybw,pa la ma li bo,pa rama ri bo,palamalibo,paramaribo,paramaripo,paramarybw,prmrybw,Παραμαρίμπο,Горад Парамарыба,Парамарибо,Парамарібо,Պարամարիբո,פאראמאריבא,פרמריבו,باراماريبو,پاراماریبو,पारामरिबो,पारामारिबो,ਪਾਰਾਮਾਰੀਬੋ,પારામારિબો,பரமாரிபோ,ปารามารีโบ,པེ་ར་མེ་རི་བོ།,პარამარიბო,ፓራማሪቦ,パラマリボ,巴拉馬利波,帕拉马里博,파라마리보', 5.8663800, -55.1668200, 'SR', '2010-05-30', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125061, 'Onverwacht', 'Onverwacht', 'Onverwacht,Unverwacht', 5.5898300, -55.1946200, 'SR', '2015-07-03', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125062, 'Nieuw Nickerie', 'Nieuw Nickerie', 'ICK,New Nickerie,Nickerie,Nieuw Nickerie', 5.9260600, -56.9729700, 'SR', '2016-05-11', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125063, 'Nieuw Amsterdam', 'Nieuw Amsterdam', 'Fort Amsterdam,Fort Neu-Amsterdam,Fort New Amsterdam,Nieuw Amsterdam,Nieuw-Amsterdam', 5.8857300, -55.0887100, 'SR', '2016-05-11', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125064, 'Moengo', 'Moengo', 'MOJ,Moengo', 5.6141100, -54.4012100, 'SR', '2016-10-30', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125065, 'Mariënburg', 'Marienburg', '', 5.8469100, -55.0215900, 'SR', '2010-07-06', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125066, 'Lelydorp', 'Lelydorp', 'Lelydorp', 5.7000000, -55.2333300, 'SR', '2016-05-11', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125067, 'Groningen', 'Groningen', 'Groningen', 5.8000000, -55.4666700, 'SR', '2016-05-11', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125068, 'Brownsweg', 'Brownsweg', 'Bronsweg,Brownsweg', 5.0043500, -55.1533300, 'SR', '2015-08-07', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125069, 'Brokopondo', 'Brokopondo', 'Brokopondo', 5.0559400, -54.9804300, 'SR', '2016-05-11', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125070, 'Albina', 'Albina', 'ABN,Albina', 5.4978800, -54.0552200, 'SR', '2017-02-01', 212);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124697, 'Longyearbyen', 'Longyearbyen', 'Gorad Longjir,LYR,Long''ir,Longijur,Longir,Longjerbiene,Longjir,Longjirbjuen osh,Longjyrbienas,Longjērbīene,Longyearbyen,Longyearbyur,Longyearbýur,Lonqyirbyuen,lang yi er cheng,langayrbyn,langyrbyn,lanyiyarpiyan,long-wiealeubwien,longiri,lwnghyarbyn,lwngyyrbyn,lxng yeiy r beiyn,rongui~erubin,Горад Лонгйір,Лонгийър,Лонгйир,Лонгйирбюен ош,Лонгьир,Лонгїр,Лонгјир,לונגיירבין,لانگایربین,لانگیربین,لونغياربين,லாங்யியர்பியன்,ลองเยียร์เบียน,ლონგირი,ロングイェールビーン,朗伊爾城,롱위에아르뷔엔', 78.2233400, 15.6468900, 'SJ', '2015-03-14', 213);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(124698, 'Olonkinbyen', 'Olonkinbyen', 'Olonkin City,Olonkinbienas,Olonkinbiene,Olonkinbjuehn,Olonkinbjuen,Olonkinbyen,Olonkinbīene,Olonkinstad,ao lun jin bai en,awlwnknbyn,Олонкинбюен,Олонкинбюэн,اولونکنبین,奥伦金拜恩', 70.9221000, -8.7187000, 'SJ', '2013-07-08', 213);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125108, 'Zaragoza', 'Zaragoza', 'Zaragoza', 13.5894400, -89.2888900, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125109, 'Zacatecoluca', 'Zacatecoluca', 'Zacateccoluca,Zacatecoluca', 13.5000000, -88.8666700, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125110, 'Victoria', 'Victoria', 'Chocoaique,Victoria,Villa Victoria,Villa Victorias', 13.9500000, -88.6333300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125111, 'Usulután', 'Usulutan', 'Ocelotlan,Ousouloutan,Usulutan,Usulutanas,Usulutane,Usulután,awswlwtan,usullutan,usulutana,wu su lu tan,Ουσουλουτάν,Усулутан,Усулутане,אוסולוטאן,اوسولوتآن,उसुलुतान,烏蘇盧坦,우술루탄', 13.3500000, -88.4500000, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125112, 'Tonacatepeque', 'Tonacatepeque', 'Tonacatepeque', 13.7811100, -89.1186100, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125113, 'Texistepeque', 'Texistepeque', 'Texistepeque', 14.1333300, -89.5000000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125114, 'Tenancingo', 'Tenancingo', 'Tenancingo', 13.8333300, -88.9833300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125115, 'Tecoluca', 'Tecoluca', '', 13.7891700, -89.0052800, 'SV', '2006-01-17', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125116, 'Tacuba', 'Tacuba', 'Tacuba,Taucba', 13.9011100, -89.9297200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125117, 'Suchitoto', 'Suchitoto', 'Suchioto,Suchitoto', 13.9380600, -89.0277800, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125118, 'Soyapango', 'Soyapango', 'Sojapangas,Sojapango,Soyapango,Soyopango,Zoyapanco,suo ya pan ge,swyapangw,Сояпанго,Сојапанго,سویاپانگو,索亞潘戈', 13.7102400, -89.1398900, 'SV', '2014-07-20', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125119, 'Sonzacate', 'Sonzacate', 'Sonzacate', 13.7341700, -89.7147200, 'SV', '2014-04-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125120, 'Sonsonate', 'Sonsonate', 'Centzonatl,Ciudad de Sonsonate,Sonsonate,Sonsonatė,snsnath,sonasonate,song suo na te,sonsonate,swnswnth,Σονσονάτε,Сонсонате,סונסונטה,سنسناته,سونسوناتے، ایل سیلواڈور,सोनसोनाते,松索納特,손소나테', 13.7188900, -89.7241700, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125121, 'Sociedad', 'Sociedad', 'Sociedad', 13.7000000, -88.0166700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125122, 'Sesori', 'Sesori', 'Sesori', 13.7166700, -88.3666700, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125123, 'Sensuntepeque', 'Sensuntepeque', 'Sensuntepeque,Sensuntepque,Sensutepeke,Сенсутепеке', 13.8666700, -88.6333300, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125124, 'San Vicente', 'San Vicente', 'San Vicente,San Vincente', 13.6333300, -88.8000000, 'SV', '2013-06-30', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125125, 'Santo Tomás', 'Santo Tomas', 'Santo Tomas,Santo Tomás', 13.6408300, -89.1333300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125126, 'Santiago Nonualco', 'Santiago Nonualco', 'Santiago,Santiago Nonualco', 13.5166700, -88.9500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125127, 'Santiago de María', 'Santiago de Maria', 'Santiago,Santiago de Maria,Santiago de María', 13.4833300, -88.4666700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125128, 'Santa Rosa de Lima', 'Santa Rosa de Lima', 'Santa Rosa,Santa Rosa de Lima', 13.6247200, -87.8936100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125129, 'Santa Elena', 'Santa Elena', 'Santa Elena', 13.3833300, -88.4166700, 'SV', '2012-05-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125130, 'Santa Ana', 'Santa Ana', 'Cihuatehuahcan,Gorad Santa-Ana,Santa Ana,Santa-Ana,Santaana,sanata-ana,santaana,sheng an na,Σάντα Άνα,Горад Санта-Ана,Санта Ана,Санта-Ана,Սանտա Անա,סנטה אנה,سانتا آنا، ایل سیلواڈور,सानता-आना,サンタ・アナ,聖安娜,산타아나', 13.9941700, -89.5597200, 'SV', '2013-06-30', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125131, 'San Sebastián', 'San Sebastian', 'San Sebastian,San Sebastián', 13.7333300, -88.8333300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125132, 'San Salvador', 'San Salvador', 'Gorad San-Sal''vador,SAL,Salvador,San Salbador,San Salvado,San Salvador,San Salvadoras,San Salvadori,San Salvadò,San Salwador,San-Sal''vador,San-Salvador,San-Salvadoro,Sansalvadora,Urbs Sancti Salvatoris,can calvator,san salvadwr,san salwadwr,san slfadwr,san-salvadori,sana salavadora,sana salvhadora,sana-salvadora,sansalbadoleu,sansalwadxr,sansarubadoru,sheng sa er wa duo,sn slwwdwr,Σαν Σαλβαδόρ,Горад Сан-Сальвадор,Сан Салвадор,Сан-Сальвадор,Սան Սալվադոր,סאן סאלוואדאר,סן סלוודור,سان سالوادور,سان سالۋادور,سان سلفادور,سان سلواڈور,सान साल्व्हाडोर,सान-साल्वाडोर,ਸਾਨ ਸਾਲਵਾਦੋਰ,சான் சல்வடோர்,ซันซัลวาดอร์,སན་སལ་ཝ་ཌོར།,სან-სალვადორი,ሳን ሳልቫዶር,サンサルバドル,聖薩爾瓦多,산살바도르', 13.6893500, -89.1871800, 'SV', '2015-06-04', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125133, 'San Rafael Oriente', 'San Rafael Oriente', 'San Rafael Oriente,San Rafael de Oriente', 13.3833300, -88.3500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125134, 'San Pedro Masahuat', 'San Pedro Masahuat', 'San Pedro Masahuat', 13.5436100, -89.0386100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125135, 'San Pablo Tacachico', 'San Pablo Tacachico', 'San Pablo Tacachico,Tacachico', 13.9755600, -89.3400000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125136, 'San Miguel', 'San Miguel', 'San Miguel,San Miquel', 13.4833300, -88.1833300, 'SV', '2013-10-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125137, 'San Martín', 'San Martin', '', 13.7833300, -88.9166700, 'SV', '2006-01-17', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125138, 'San Marcos', 'San Marcos', 'San Marcos', 13.6588900, -89.1830600, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125139, 'San Juan Opico', 'San Juan Opico', 'Opico,San Juan Opico', 13.8761100, -89.3597200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125140, 'San Francisco Menéndez', 'San Francisco Menendez', 'San Francisco Menendez,San Francisco Menéndez', 13.8430600, -90.0158300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125141, 'San Francisco', 'San Francisco', 'Gotera,San Francisco,San Francisco Gotera', 13.7000000, -88.1000000, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125142, 'San Antonio del Monte', 'San Antonio del Monte', 'San Antonio del Monte', 13.7163900, -89.7383300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125143, 'San Alejo', 'San Alejo', 'San Alejo', 13.4313900, -87.9630600, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125144, 'San Agustín', 'San Agustin', 'San Agustin,San Agustín', 13.4333300, -88.6000000, 'SV', '2013-04-04', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125145, 'Rosario de Mora', 'Rosario de Mora', 'Rosario de Mora', 13.5752800, -89.2088900, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125146, 'Quezaltepeque', 'Quezaltepeque', 'Kesal''tepeke,Quezaltepeque,Quezaltepque,Кесальтепеке', 13.8312400, -89.2722100, 'SV', '2014-10-04', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125147, 'Puerto El Triunfo', 'Puerto El Triunfo', 'Puerto Del Triunfo,Puerto El Triunfo', 13.2833300, -88.5500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125148, 'Pasaquina', 'Pasaquina', 'Pasaguina,Pasaquina', 13.5844400, -87.8411100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125149, 'Panchimalco', 'Panchimalco', 'Panchimalco', 13.6127800, -89.1800000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125150, 'Ozatlán', 'Ozatlan', 'Ozatlan,Ozatlán', 13.3833300, -88.5000000, 'SV', '2013-04-04', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125151, 'Olocuilta', 'Olocuilta', 'Olocuilta', 13.5697200, -89.1172200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125152, 'Nuevo Cuscatlán', 'Nuevo Cuscatlan', 'Nuevo Cuscatlan,Nuevo Cuscatlán', 13.6486100, -89.2652800, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125153, 'Santa Tecla', 'Santa Tecla', 'Ciudad de Nueva San Salvador,La Ciudad de Nueva San Salvador,Nuehva-San-Sal''vador,Nueva San Salvador,Santa Tecla,Santa Tekla,Santa-Tekla,santatekeulla,sheng te ke la,Σάντα Τέκλα,Нуэва-Сан-Сальвадор,Санта Текла,Санта-Текла,سانتا تکلا، ایل سیلواڈور,聖特克拉,산타테클라', 13.6769400, -89.2797200, 'SV', '2012-01-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125154, 'Nueva Guadalupe', 'Nueva Guadalupe', 'Nueva Guadalupe', 13.5333300, -88.3500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125155, 'Nueva Esparta', 'Nueva Esparta', 'Nueva Esparta', 13.7836100, -87.8386100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125156, 'Nueva Concepción', 'Nueva Concepcion', 'Chicunhuexo,Nueva Concepcion,Nueva Concepción', 14.1333300, -89.3000000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125157, 'Nahuizalco', 'Nahuizalco', 'Nahuizalco,Nauizalco', 13.7775000, -89.7366700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125158, 'Moncagua', 'Moncagua', 'Moncagua', 13.5333300, -88.2500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125159, 'Metapán', 'Metapan', 'Metapan,Metapán,Metlapan,mei ta pan,mytapan,Метапан,میتاپان,梅塔潘', 14.3333300, -89.4500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125160, 'Mejicanos', 'Mejicanos', 'Mejicanos,Mekhikanos,Mexicanos,Мехиканос', 13.7402800, -89.2130600, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125161, 'Lolotique', 'Lolotique', 'Lolotique', 13.5500000, -88.3500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125162, 'La Unión', 'La Union', 'La Union,La Unión,San Carlos de La Union,San Carlos de La Unión', 13.3369400, -87.8438900, 'SV', '2013-06-30', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125163, 'La Libertad', 'La Libertad', 'La Libertad,Puerto La Libertad', 13.4883300, -89.3222200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125164, 'Jujutla', 'Jujutla', 'Jujutla', 13.7869400, -89.8572200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125165, 'Jucuarán', 'Jucuaran', 'Jucuaran,Jucuarán', 13.2538900, -88.2477800, 'SV', '2012-05-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125166, 'Jucuapa', 'Jucuapa', 'Jucuapa', 13.5166700, -88.3833300, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125167, 'Juayúa', 'Juayua', 'Juayua,Juayúa', 13.8413900, -89.7455600, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125168, 'Jocoro', 'Jocoro', 'Jocoro', 13.6166700, -88.0166700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125169, 'Jiquilisco', 'Jiquilisco', 'Ilquilisco,Jiquilisco', 13.3166700, -88.5833300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125170, 'Izalco', 'Izalco', 'Gorad Isal''ka,Isal''ko,Izalco,Izalko,Yzalco,yi sa er ke,Горад Ісалька,Изалко,Исалько,伊薩爾科', 13.7447200, -89.6730600, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125171, 'Intipucá', 'Intipuca', 'Intipuca,Intipucá', 13.1969400, -88.0544400, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125172, 'Ilopango', 'Ilopango', 'Ilopango,Ylopango,Илопанго', 13.7016700, -89.1094400, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125173, 'Guazapa', 'Guazapa', 'Guasapa,Guazapa', 13.8769400, -89.1730600, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125174, 'Guaymango', 'Guaymango', 'Guaymango', 13.7502800, -89.8422200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125175, 'Guatajiagua', 'Guatajiagua', 'Guatajiagua', 13.6666700, -88.2000000, 'SV', '2012-05-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125176, 'El Tránsito', 'El Transito', 'El Transito,El Tránsito', 13.3500000, -88.3500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125177, 'El Rosario', 'El Rosario', 'El Rosario,Rosario de la Paz', 13.4977800, -89.0297200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125178, 'El Paisnal', 'El Paisnal', 'El Paisnal,Paisnal', 13.9736100, -89.2186100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125179, 'El Congo', 'El Congo', 'El Congo,ai er kong ge,埃爾孔戈', 13.9088900, -89.4958300, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125180, 'Delgado', 'Delgado', 'Del''gado,Delgado,Villa Delcado,Villa Delgado,Дельгадо', 13.7241700, -89.1702800, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125181, 'Cuscatancingo', 'Cuscatancingo', 'Cuscatancingo', 13.7361100, -89.1813900, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125182, 'Corinto', 'Corinto', 'Corinto', 13.8108300, -87.9713900, 'SV', '2012-05-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125183, 'Conchagua', 'Conchagua', 'Conchagua', 13.3077800, -87.8647200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125184, 'Concepción de Ataco', 'Concepcion de Ataco', 'Ataco,Concepcion de Ataco,Concepción de Ataco', 13.8702800, -89.8486100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125185, 'Concepción Batres', 'Concepcion Batres', 'Concepcion Batres,Concepción Batres', 13.3500000, -88.3666700, 'SV', '2012-05-06', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125186, 'Cojutepeque', 'Cojutepeque', 'Cojutepeque', 13.7166700, -88.9333300, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125187, 'Coatepeque', 'Coatepeque', 'Coatepeque', 13.9286100, -89.5041700, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125188, 'Ciudad Barrios', 'Ciudad Barrios', 'Ciudad Barrios,Villa de Cacahuatique', 13.7666700, -88.2666700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125189, 'Ciudad Arce', 'Ciudad Arce', 'Chilamatal,Ciudad Arce,El Chilamatal', 13.8402800, -89.4472200, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125190, 'Chirilagua', 'Chirilagua', 'Chirilagua', 13.2202800, -88.1386100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125191, 'Chinameca', 'Chinameca', 'Chinameca', 13.5000000, -88.3500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125192, 'Chapeltique', 'Chapeltique', 'Chapelpique,Chapeltique', 13.6333300, -88.2666700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125193, 'Chalchuapa', 'Chalchuapa', 'Chalchuapa', 13.9866700, -89.6811100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125194, 'Chalatenango', 'Chalatenango', 'Calatenangas,Chalatenanga,Chalatenango,Gorad Chalatehnanga,Tsalatenan''nko,Xalatenanco,cha la te nan ge,chalatenanago,challatenang-go,shalatnangw  shalatnangw,Čalatenangas,Τσαλατενάνγκο,Горад Чалатэнанга,Чалатенанго,شالاتنانگو، شالاتنانگو,छालातेनानगो,查拉特南戈,찰라테낭고', 14.0333300, -88.9333300, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125195, 'Candelaria de La Frontera', 'Candelaria de La Frontera', 'Candelaria,Candelaria de La Frontera,Candelario', 14.1166700, -89.6500000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125196, 'Cacaopera', 'Cacaopera', 'Cacaopera', 13.7666700, -88.0833300, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125197, 'Berlín', 'Berlin', 'Berlin,Berlín', 13.5000000, -88.5333300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125198, 'Ayutuxtepeque', 'Ayutuxtepeque', 'Ayutuxtepegue,Ayutuxtepeque', 13.7455600, -89.2063900, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125199, 'Atiquizaya', 'Atiquizaya', 'Atiquizaya', 13.9769400, -89.7525000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125200, 'Armenia', 'Armenia', 'Armenia,Guaymoco', 13.7436100, -89.4988900, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125201, 'Apopa', 'Apopa', 'Apopa', 13.8072200, -89.1791700, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125202, 'Apastepeque', 'Apastepeque', 'Apastepeq,Apastepeque', 13.6666700, -88.7833300, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125203, 'Antiguo Cuscatlán', 'Antiguo Cuscatlan', 'Antiguo Cuscatlan,Antiguo Cuscatlán,an di guo ku si ka te lan,antygw kwskatlan,انتیگؤ کوسکاتلان,安蒂果庫斯卡特蘭', 13.6649200, -89.2531900, 'SV', '2014-07-20', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125204, 'Anamorós', 'Anamoros', 'Anamoros,Anamorós', 13.7405600, -87.8736100, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125205, 'Ahuachapán', 'Ahuachapan', 'Achuachapan,Ahuachapan,Ahuachapán,Ачуачапан', 13.9213900, -89.8450000, 'SV', '2012-01-14', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125206, 'Aguilares', 'Aguilares', 'Aguilares', 13.9572200, -89.1897200, 'SV', '2012-02-02', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125207, 'Acajutla', 'Acajutla', 'Acajutla,Akakhutla,Puerto Acajutla,Акахутла', 13.5927800, -89.8275000, 'SV', '2012-01-18', 67);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125105, 'São Tomé', 'Sao Tome', 'Gorad San-Tameh,Salazar,San Tomas,San Tome,San Tomé,San Tomė,San-Tome,Santo Tome,Santo Tomé,Santome,Sao Thome,Sao Tome,Sao Tomee,Sao Tomé,Sao-Tomeo,Soeo Tome,Svaety Tomas,Svätý Tomáš,Sào Thomé,São Tomé,Söo Tomé,TMS,Urbs Sancti Thomae,cavo tome,sa''o tome,sangtume,santome,savea team,saw twmy,saywtwmh,sea tu me,sheng duo mei,Σάο Τομέ,Горад Сан-Тамэ,Сан-Томе,Сао Томе,Սան Տոմե,סאו טומה,ساؤ ٹومے,سائوتومه,ساو تومي,ساو تۆمێ,ساو ٹومے,साओ टोमे,সাও টোমে,ਸਾਓ ਤੋਮੇ,சாவோ தொமே,സാവോ ടോം,เซาตูเม,སའོ་ཊོ་མེ།,სან-ტომე,ሳን ቶሜ,サントメ,圣多美,聖多美,상투메', 0.3365400, 6.7273200, 'ST', '2017-07-03', 194);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125106, 'Santo António', 'Santo Antonio', 'Cidade de Santo Antonio,Cidade de Santo António,Gorad Santu-Anton''ju,San Antonio,Santo Antonijus,Santo Antonio,Santo António,Santu-Anton''ju,Sao Antonio,São Antõnio,sang tu xang tx ni xu,santuantoniu,santw antwnyw,sheng an dong ni ao,Горад Санту-Антонью,Санто Антонио,Санту-Антонью,سانتو آنتونیو,سانتو انتونیو,ซังตูอังตอนีอู,サント・アントニオ,聖安東尼奧,산투안토니우', 1.6372600, 7.4178300, 'ST', '2014-08-19', 194);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125107, 'São João dos Angolares', 'Sao Joao dos Angolares', '', 0.1333300, 6.6500000, 'ST', '2016-07-13', 194);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125208, 'Philipsburg', 'Philipsburg', 'Filip''smpournk,Filipsburg,Filipsburgas,Gorad Filipsburg,Great Bay,Philipsburg,fei li pu si bao,fi lipsburkh,firippusuburufu,flpsbrg,fylypsbwrg  synt martn,pilipcuparku,pillibseubwileuheu,Φίλιπσμπουργκ,Горад Філіпсбург,Филипсбург,Філіпсбург,فلپسبرگ,فیلیپسبورگ، سینت مارتن,பிலிப்சுபர்கு,ฟีลิปส์บืร์ค,ფილიპსბურგი,フィリップスブルフ,菲利普斯堡,필립스뷔르흐', 18.0260000, -63.0458200, 'SX', '2011-02-06', 201);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125209, 'Lower Prince’s Quarter', 'Lower Prince''s Quarter', 'Beneden Prinsen,Beneden Prinsen Kwartier,Lower Prince''s Quarter,Lower Prince’s Quarter', 18.0498700, -63.0378900, 'SX', '2016-11-28', 201);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125210, 'Cul de Sac', 'Cul de Sac', 'Cul de Sac,Duth Cul de Sac', 18.0485200, -63.0651300, 'SX', '2016-11-28', 201);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125211, 'Koolbaai', 'Koolbaai', 'Cole Bay,Koolbaai', 18.0404800, -63.0839700, 'SX', '2016-11-28', 201);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125088, 'Malakal', 'Malakal', 'MAK,Malakal,Malakal'',Malakalis,Malakál,ma la ka er,mallakal,marakaru,mlkal,Малакал,Малакаль,מלקאל,ملكال,ملکال,მალაკალი,マラカル,馬拉卡爾,말라칼', 9.5334200, 31.6604900, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125089, 'Maiwut', 'Maiwut', 'Fami,Maiwut', 8.6097500, 33.9262100, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125090, 'Leer', 'Leer', 'Leer,Ler,Lir,Līr', 8.3030600, 30.1405600, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125091, 'Kuacjok', 'Kuacjok', 'Kajok,Kuacjok,Kuajok,Kwacjok,Kwajok', 8.3027800, 27.9800000, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125092, 'Kodok', 'Kodok', 'Fashoda,Kodak,Kodok', 9.8888900, 32.1094400, 'SS', '2017-06-17', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125093, 'Kapoeta', 'Kapoeta', 'Kabuyta,Kapoeta', 4.7722200, 33.5913900, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125094, 'Juba', 'Juba', 'Djouba,Dschuba,Dzhuba,Goba,JUB,Juba,Uula,g''wbh,Джуба,ג''ובה', 4.8516500, 31.5824700, 'SS', '2017-06-17', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125095, 'Gogrial', 'Gogrial', 'Gogrial,Gogriale,Qaqriyal,Гогриале', 8.5332400, 28.1003700, 'SS', '2017-06-12', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125096, 'Pajok', 'Pajok', 'Farajok,Pajok,Parajok,Parjok', 3.8651200, 32.4821200, 'SS', '2017-06-12', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125097, 'Cueibet', 'Cueibet', 'Cheibet,Chweibet,Cueibet,Shwai Bet', 7.0266700, 29.2461100, 'SS', '2017-06-16', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125098, 'Bor', 'Bor', 'Bor,Boras,bo er,boleu,bori,boru,bwr,Бор,בור,بور,بور، جنوبی سوڈان,ბორი,ボル,波爾,보르', 6.2088900, 31.5586100, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125099, 'Bentiu', 'Bentiu', 'Bantiyo,Bentiju,Bentiu,Kilwal,Meshra` Bentiu,Meshra‘ Bentiu,ban ti wu,bantyw,bntyw,Бентиу,Бентију,בנטיו,بانتيو,بانتیو,ბენტიუ,班提烏', 9.2572200, 29.7983300, 'SS', '2017-06-09', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125100, 'Ayod', 'Ayod', 'Ayod,Duk Ayod,Duk Yod', 8.1219300, 31.4090400, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125101, 'Renk', 'Renk', 'Al Runk,Ar Rank,El Renk,Er Renk,Renk', 11.7431000, 32.8049000, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125102, 'Akobo', 'Akobo', 'Akobo,Akobo Post,Akubu,Akūbū', 7.7911100, 33.0044400, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125103, 'Pariang', 'Pariang', '', 9.9154200, 29.9810900, 'SS', '2017-06-17', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125104, 'Mayen Abun', 'Mayen Abun', 'Mayen Abun', 9.1363900, 28.3458300, 'SS', '2017-06-15', 208);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125212, '‘Ayn Ḩalāqīm', '`Ayn Halaqim', 'Ain HalaqIm,Aïn HalâqÎm,`Ayn Halaqim,عين حلاقيم,‘Ayn Ḩalāqīm', 34.9399800, 36.3221200, 'SY', '2012-07-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125213, 'Al Karāmah', 'Al Karamah', 'Al Karamah,Al Karāmah,Fatsat ath Thayb,Faţsat ath Thayb,alkramt,ftst althyb,الكرامة,فطسة الثيب', 35.8686500, 39.2780300, 'SY', '2013-09-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125214, '‘Arīqah', '`Ariqah', 'Arika,`Ariqah,tl ʿmar,Арика,تل عمار,عريقة,‘Arīqah', 32.8898100, 36.4833600, 'SY', '2014-03-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125215, 'Aş Şūrah aş Şaghīrah', 'As Surah as Saghirah', 'As Sawarah as Sughra,As Surah as Saghirah,As Surah as Sughra,Aş Şawarah aş Şughrá,Aş Şūrah aş Şaghīrah,Aş Şūrah aş Şughrá,Savara-ehs-Segira,alswrt alsghry,alswrt alsghyrt,Савара-эс-Сегира,الصورة الصغرى,الصورة الصغيرة', 33.0324700, 36.5742000, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125216, 'Mūḩ Ḩasan', 'Muh Hasan', 'Mouhassane,Muh Hasan,Muhasan,Muhassan,Muḩassan,Muḩaşşan,Mūḩ Ḩasan,Mūḩasan,mwh hsn,mwhsn,موح حسن,موحسن', 35.2334900, 40.3166000, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125217, 'Yabrūd', 'Yabrud', 'Gebru,Jabrud,Jebru,Jebrud,Yabroud,Yabroûd,Yabrud,Yabrūd,ybrwd,Ябруд,يبرود', 33.9692100, 36.6572900, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125218, 'Wādī al ‘Uyūn', 'Wadi al `Uyun', 'Wadi Al ''Uyun,Wadi al ''Uyun,Wādī al ‘Uyūn,وادي العيون', 35.0011900, 36.1868300, 'SY', '2011-11-09', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125219, '‘Uqayribāt', '`Uqayribat', 'Aaqerbate,Aaqerbâte,Aquerbate,Uzeribat,`Aqrabat,`Iqarbat,`Oqeiribat,`Uqayribat,عقيربات,‘Aqrabāt,‘Iqarbāt,‘Oqeiribāt,‘Uqayribāt', 35.0431000, 37.4644200, 'SY', '2012-07-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125220, 'Ţayyibat al Imām', 'Tayyibat al Imam', 'Taibet el Imam,Taybat al Imam,Taybat al Imam `Ali,Tayyibat al Imam,Taïbet el Imâm,Tibbat al Imam,Tibbat al Imām,Tibet Iman,tybt alamam,Ţaybat al Imām,Ţaybat al Imām ‘Alī,Ţayyibat al Imām,طيبة الامام', 35.2659200, 36.7121900, 'SY', '2012-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125221, 'Tasīl', 'Tasil', 'Tasil,Tasil'',Tasīl,Tsil,Tsîl,tsyl,Тасиль,تسيل', 32.8339500, 35.9697300, 'SY', '2015-06-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125222, 'Tartouss', 'Tartouss', 'Antaradus,Tartous,Tartouss,Tartoûs,Tartus,mhafzt trtws,trtws,Ţarţūs,Тартус,טרטוס,طرطوس,محافظة طرطوس', 34.8890200, 35.8865900, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125223, 'Tall Tamr', 'Tall Tamr', 'Tall Tamir,Tall Tamr,Tall Tāmir,Tell Tamer,Tell Tâmer,tl tamr,tl tmr,تل تامر,تل تمر', 36.6555600, 40.3707900, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125224, 'Tall Salḩab', 'Tall Salhab', 'Tall Salhab,Tall Salḩab,Tallsalhab,Tallsalḩab,Tell Salhab,tl slhb,tlslhb,تل سلحب,تلسلحب', 35.2588400, 36.3846100, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125225, 'Tall Rif‘at', 'Tall Rif`at', 'Tal Refaat,Tall Rif`at,Tall Rif‘at,Tell Arfad,Tell Refaat,Tell Rifaate,Tell Rifat,Tell Rifaâte,تل رفعت', 36.4722900, 37.0947100, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125226, 'Tallkalakh', 'Tallkalakh', 'Talkalakh,Tall Kalakh,Tallkalakh,Telkalakh,Tell Kalakh,tl klkh,tlklkh,تل كلخ,تلكلخ', 34.6684200, 36.2599500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125227, 'Tall Ḩamīs', 'Tall Hamis', 'Tall Hamis,Tall Ḩamīs,Tell Hamis,Tell Hamîs,tl hmys,تل حميس', 36.7567800, 41.3994300, 'SY', '2013-08-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125228, 'Talldaww', 'Talldaww', 'Kheurbet Nasriye,Kheurbet Nâsriyé,Khirbat Nasiriyah,Khirbat Nāşirīyah,Khirbat an Nasiriyah,Khirbat an Nāşirīyah,Tall Daww,Talldaww,Tell Daou,khrbt alnasryt,tl dw,tldw,تل دو,تلدو,خربة الناصرية', 34.8763200, 36.5240000, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125229, 'Tall aḑ Ḑamān', 'Tall ad Daman', 'Tall Daman,Tall Dāmān,Tall ad Daman,Tall aḑ Ḑamān,Tall Ḑamān,Tell Damane,Tell ed Damane,Tell ed Damâne,tl aldman,tl daman,tl dman,تل الضمان,تل دامان,تل ضمان', 35.8077600, 37.2537800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125230, 'Tall Abyaḑ', 'Tall Abyad', 'Tal-Abyad,Tall Abyad,Tall Abyaḑ,Tell Abiad,Tell Abyad,tl abyd,تل أبيض', 36.6964800, 38.9538200, 'SY', '2013-07-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125231, 'Tālīn', 'Talin', 'Talin,Taline,Tâlîne,Tālīn,talyn,تالين', 35.1484900, 36.0328800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125232, 'Tallbīsah', 'Tallbisah', 'Talbisah,Talbiseh,Talbīsah,Tall Bisih,Tall Bissah,Tall Bīsih,Tallbisah,Tallbīsah,Tel Bisi,Telbeiseh,Telbise,Tell Bise,Tell Bisse,Tell Bîsse,Tell Bîssé,Tell Bīse,tlbyst,تلبيسة', 34.8407200, 36.7309200, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125233, 'Taftanāz', 'Taftanaz', 'Taftanaz,Taftanāz,Teftanaz,Teftanâz,Teftenaz,tftnaz,تفتناز', 35.9983200, 36.7857900, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125234, 'Ţafas', 'Tafas', 'Tafas,Tafass,tfs,Ţafas,Тафас,طفس', 32.7370900, 36.0665400, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125235, 'Tadmur', 'Tadmur', 'PMS,Pal''mira,Palmira,Palmuera,Palmyra,Palmyre,Palmüra,Palmýra,Tadmor,Tadmur,Tedmor,ba er mi la,parumira yi ji,tdmr,tdmwr,Палмира,Пальмира,תדמור,تدمر,パルミラ遺跡,巴尔米拉', 34.5624000, 38.2840200, 'SY', '2017-02-09', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125236, 'Tādif', 'Tadif', 'Tadef,Tader,Tadif,Teft,Tâdef,Tâder,Tādif,tadf,تادف', 36.3481400, 37.5309000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125237, 'Şūrān', 'Suran', 'Sawran,Sourane,Soûrâne,Suran,swran,Şawrān,Şūrān,صوران', 36.5657900, 37.2127000, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125238, 'Souran', 'Souran', 'Sawran,Soran,Souran,Sourane,Soûrâne,Suran,swran,Şawrān,Şūrān,Суран,صوران', 35.2919300, 36.7484800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125239, 'As Suqaylibīyah', 'As Suqaylibiyah', 'Al-Skeilbyeh,As Suqaylibiyah,As Suqaylibīyah,Saglabiye,Saqlabiyah,Saqlabīyah,Skalebie,Skalebié,Skeilbieh,Sqalbiye,Sqalbiyé,Suqaylabiyah,Suqaylibiyah,Suqaylibīyah,alsqylbyt,sqlbyt,sqylbyt,Şaqlabīyah,Şuqaylabīyah,Şuqaylibīyah,السقيلبية,سقيلبية,صقلبية,صقيلبية', 35.3667400, 36.3935900, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125240, 'Subaykhān', 'Subaykhan', 'Sabikhan,Soubeikhane,Soubeïkhâne,Subaykhan,Subaykhān,sbykhan,سبيخان', 34.8530500, 40.5998700, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125241, 'Şlinfah', 'Slinfah', 'Dalnafah,Salinfah,Silenfih,Slennfe,Slennfé,Slinfah,slnft,Şalinfah,Şlinfah,صلنفة,Ḑalnafah', 35.5982200, 36.1877000, 'SY', '2015-11-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125242, 'Şirrīn ash Shamālīyah', 'Sirrin ash Shamaliyah', 'Serrin,Serrīn,Sirrin,Sirrin ash Shamaliyah,Sirrine,Sirrine ech Chemaliye,Sirrine ech Chimaliye,Sirrîne,Sirrîne ech Chimâliye,Sirrîne ech Chémâlîyé,Sirrīn ash Shamālīyah,sryn alshmalyt,Şirrīn,Şirrīn ash Shamālīyah,سرين الشمالية,صرين الشمالية', 36.5883800, 38.2978800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125243, 'Sirghāyā', 'Sirghaya', 'Serghaya,Serrhaya,Serrhâya,Sirgaya,Sirghaya,Sirghāyā,srghaya,سرغايا', 33.8104000, 36.1578700, 'SY', '2016-02-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125244, 'Sinjār', 'Sinjar', 'Sendjar,Senjar,Senjār,Sinjar,Sinjār,Sinnjar,Sinnjâr,snjar,سنجار', 35.5901100, 37.0047200, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125245, 'Shuyūkh Taḩtānī', 'Shuyukh Tahtani', 'Chioukh Tahtani,Shuyukh Tahtani,Shuyūkh Taḩtānī,shywkh thtany,شيوخ تحتاني', 36.7505900, 38.0767600, 'SY', '2015-01-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125246, 'Shīn', 'Shin', 'Chine,Chîne,Shin,Shīn,shyn,شين', 34.7786300, 36.4236600, 'SY', '2012-07-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125247, 'Ash Shaykh Miskīn', 'Ash Shaykh Miskin', 'Ash Shaykh Maskin,Ash Shaykh Maskīn,Ash Shaykh Miskin,Ash Shaykh Miskīn,Cheikh Meskine,Cheïkh Meskîne,Chikh Meskine,Shaykh Maskin,Shaykh Maskīn,Shaykh Miskin,Shaykh Miskīn,Sheikh Miskin,Sheikh Miskīn,Shejkh-Miskin,alshykh mskyn,shykh mskyn,Шейх-Мискин,الشيخ مسكين,شيخ مسكين', 32.8294400, 36.1593300, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125248, 'Shaykh al Ḩadīd', 'Shaykh al Hadid', 'Cheikh el Hadid,Cheïkh el Hadîd,Shaykh al Hadid,Shaykh al Ḩadīd,Sheikh el Hadid,Sheikh el Hadīd,shykh alhdyd,شيخ الحديد', 36.5006900, 36.5994500, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125249, 'Shaţḩah', 'Shathah', 'Chat'' ha ett Tahta,Chat’ ha ett Tahta,Shathah,Shathah at Tahta,Shathah at Tahta'',Shathat at Tahta,Shaţḩah,Shaţḩah at Taḩtā,Shaţḩah at Taḩtā’,Shaţḩat at Taḩtā,shtht,shtht althta,شطحة,شطحة التحتا', 35.5050900, 36.2437700, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125250, 'Sharān', 'Sharan', 'Charannli,Cheranli,Chéranli,Sharan,Sharanli,Sharanlī,Sharān,Sharānlī,shran,shranly,شران,شرانلي', 36.6233600, 36.9365900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125251, 'Shaqqā', 'Shaqqa', 'Chakka,Chaqqa,Shakka,Shaqqa,Shaqqah,Shaqqā,shqa,Шакка,شقّا', 32.8977300, 36.6965300, 'SY', '2014-01-10', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125252, 'Shahbā', 'Shahba', 'Chahba,Philippopolis,Phillipopolis,Philppopolis,Shaba,Shahaba,Shahba,Shahba'',Shahbah,Shahbā,Shahbā’,Shakhba,shhba,Шахба,شهبا', 32.8551400, 36.6289600, 'SY', '2014-01-10', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125253, 'Şaydnāyā', 'Saydnaya', 'Said Naya,Said Nâya,Saydnaya,Sednaya,Seidnaya,Seyd Naya,sydnaya,Şaydnāyā,صيدنايا', 33.6947300, 36.3714600, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125254, 'Sa‘sa‘', 'Sa`sa`', 'Sa`sa`,Saasa,Saassa,Saassaa,Sassa,Sa‘sa‘,Сааса,سعسع', 33.2819800, 36.0194700, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125255, 'Sarmīn', 'Sarmin', 'Sarmin,Sarmine,Sarmîne,Sarmīn,Sermin,Sermīn,srmyn,سرمين', 35.9040300, 36.7250100, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125256, 'Sarāqib', 'Saraqib', 'Sarakeb,Saraqeb,Saraqib,Saraquib,Sarâqeb,Sarāqib,Seraikin,Serakab,Seraqab,Seraqib,Serāqab,sraqb,سراقب', 35.8644700, 36.8059100, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125257, 'Sulūk', 'Suluk', 'Saluq,Salūq,Sloug,Slouq,Sloûq,Suluk,Suluq,Sulūk,Sulūq,slwk,slwq,سلوق,سلوك', 36.5959600, 39.1299000, 'SY', '2012-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125258, 'Salqīn', 'Salqin', 'Salkine,Salkîne,Salqin,Salqine,Salqîne,Salqīn,Selkin,Silkin,slqyn,سلقين', 36.1386500, 36.4524400, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125259, 'Şalkhad', 'Salkhad', 'Sal''khad,Salakhad,Salakhed,Salka,Salkas,Salkhad,Salkhade,Salâkhed,slkhd,Şalkhad,Şalākhad,Сальхад,صلخد', 32.4920000, 36.7111400, 'SY', '2014-01-24', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125260, 'As Salamīyah', 'As Salamiyah', 'As Salamiyah,As Salamīyah,Salamias,Salamiyah,Salamiyeh,Salamīyah,Selemie,Selemiya,Selemiye,Selemié,Selemīya,Sélémîyé,alslmyt,slmyt,السلمية,سلمية', 35.0112700, 37.0532400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125261, 'Şalākhid', 'Salakhid', 'Salakhed,Salakhid,Salâkhed,slakhd,Şalākhid,صلاخد', 32.8727100, 36.5727100, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125262, 'Sahnaiya', 'Sahnaiya', 'Sahnaiya,Sahnaya,shnaya,Şaḩnāyā,صحنايا', 33.4253100, 36.2255200, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125263, 'Satita', 'Satita', 'Borj Safita,Borj Sâfîta,Burj Safita,Burj Şāfītā,Khokhu,Safita,Satita,brj safyta,safyta,Şāfītā,برج صافيتا,صافيتا', 34.8209900, 36.1177300, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125264, 'Şadad', 'Sadad', 'Sadad,sdd,Şadad,صدد', 34.3124800, 36.9256200, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125265, 'Şabbūrah', 'Sabburah', 'Sabboura,Sabboûra,Sabburah,Sabura,Saburah,sbwrt,Şabbūrah,Şabūrah,صبورة', 35.1559500, 37.2090800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125266, 'As Sab‘ Biyār', 'As Sab` Biyar', 'As Sab` Abar,As Sab` Biyar,As Sab‘ Biyār,As Sab‘ Ābār,Sab` Abar,Sab` Biyar,Saba Biar,Saba Bjar,Sabaa Biar,Sabaa Biâr,Sab‘ Biyār,Sab‘ Ābār,Saobo Biar,Saobo Biâr,alsbʿ byar,السبع آبار,السبع بيار,سبع بيار', 33.7797400, 37.6835700, 'SY', '2015-04-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125267, 'Ar Riqāmā', 'Ar Riqama', 'Ar Riqama,Ar Riqamah,Ar Riqāmah,Ar Riqāmā,Arqamah,Arqāmah,Irgama,Irghama,Irgāma,Irqama,Irqāma,Raqamah,Raqāmah,Riqama,Riqamah,Riqâma,Riqāmah,alrqama,alrqamt,الرقاما,الرقامة', 34.5387900, 36.9190900, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125268, 'Rasm al Ḩarmal', 'Rasm al Harmal', 'Rasm al Harmal,Rasm al Harmal al Imam,Rasm al Hirmil,Rasm al Ḩarmal,Rasm al Ḩarmal al Imām,Rasm el Harme,Rasm el Hermel,rsm alhrml,rsm alhrml alamam,رسم الحرمل,رسم الحرمل الإمام', 36.2448600, 37.7160700, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125269, 'Ra’s al ‘Ayn', 'Ra''s al `Ayn', 'Ra''s al `Ayn,Ras el Ain,Rass el Ain,Rass-el-Ein,Ra’s al ‘Ayn,Râs el Aïn,Râss el Aïn,رأس العين', 36.8503400, 40.0705500, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125270, 'Rankūs', 'Rankus', 'Rankus,Rankūs,Rannkous,Rannkoûs,rnkws,رنكوس', 33.7562300, 36.3883000, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125271, 'Radjun', 'Radjun', 'Radjou,Radjun,Raju,Rājū,rajw,راجو', 36.6759800, 36.6641500, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125272, 'Al Quţaylibīyah', 'Al Qutaylibiyah', 'Al Qutaylibiyah,Al Quţaylibīyah,Qtailbiye,Qtaïlbîyé,Qutaylibiyah,Quţaylibīyah,alqtylbyt,qtylbyt,القطيلبية,قطيلبية', 35.2920300, 36.0159200, 'SY', '2014-02-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125273, 'Qarqania', 'Qarqania', 'Kourkania,Qarqania,Qurqanya,Qurqina,Qūrqanyā,Qūrqānyā,Qūrqīnā,qwrqnya,qwrqyna,قورقنيا,قورقينا', 36.1384900, 36.6124700, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125274, 'Al Qaḩţānīyah', 'Al Qahtaniyah', 'Al Qahtaniyah,Al Qaḩţānīyah,Koubour el Bid,Qoubour el Bid,Qouboûr el Bîd,Qubur al Bid,Qubūr al Bīḑ,Turbe Sipi,Turbé Sipi,alqhtanyt,qbwr albyd,القحطانية,قبور البيض', 37.0290000, 41.5459600, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125275, 'Qaţanā', 'Qatana', 'Katana,Qatana,Qatanah,Qaţanah,Qaţanā,qtna,قطنا', 33.4375700, 36.0788800, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125276, 'Qasţal Ma‘āf', 'Qastal Ma`af', 'Qastal Ma`af,Qastal Ma`f,Qastal Maaf,Qastal al Ma`af,Qasţal Ma‘f,Qasţal Ma‘āf,Qasţal al Ma‘āf,قسطل المعاف,قسطل معاف,قسطل معف', 35.8243900, 35.9519300, 'SY', '2015-02-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125277, 'Jāsim', 'Jasim', 'Dzhasim,Jacem,Jasem,Jasim,Jassem,Jassim,Jâssem,Jāsim,Qasim,Qāsim,jasm,Джасим,جاسم', 32.9923300, 36.0601800, 'SY', '2016-11-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125278, 'Qārah', 'Qarah', 'Kara,Karra,Qara,Qarah,Qārah,Qārā,qart,قارة', 34.1555800, 36.7428400, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125279, 'Al Qamşīyah', 'Al Qamsiyah', 'Al Qamsiyah,Al Qamşīyah,Qamsiyah,Qamsiye,Qamsîyé,Qamsīyah,Qamşīyah,alqmsyt,qmsyt,القمصية,قمسية', 35.0335700, 36.0145500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125280, 'Qal‘at al Maḑīq', 'Qal`at al Madiq', 'Kal''at al Madik,Kalaat Moudik,Kalat el Mudik,Kal’at al Madik,Qal`at al Madiq,Qal`at al Mudiq,Qal`at el Madhiq,Qal`at el Mudiq,Qalaat el Moudiq,Qal‘at al Maḑīq,Qal‘at al Muḑīq,Qal‘at el Madhiq,Qal‘at el Mudiq,قلعة المضيق', 35.4146500, 36.3908500, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125281, 'Qadsayyā', 'Qadsayya', 'Adsaya,Adsâya,Edsaya,Koudsaya,Qadisiya,Qadisiyā,Qadsayya,Qadsayyā,Qadsiya,Qadsīyā,Qudsayya,Qudsayyā,Qudsiya,Qudsīyā,qdsya,قدسيا', 33.5483200, 36.2156300, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125282, 'Nubl', 'Nubl', 'Noubbel,Noubbol,Nubl,nbl,نبل', 36.3786700, 36.9929400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125283, 'Nawá', 'Nawa', 'Naoua,Nava,Nawa,Nawá,nwy,Нава,نوى', 32.8904400, 36.0399000, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125284, 'Al Muzayrīb', 'Al Muzayrib', 'Al Muzayrib,Al Muzayrīb,Bouta,Mezerib,Muzayrib,Muzayrīb,Muzeirib,Muzeirīb,Mzairib,Mzaïrîb,Mzerib,Mzérib,almzyryb,المزيريب', 32.7093800, 36.0263500, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125285, 'Al Muzayri‘ah', 'Al Muzayri`ah', 'Al Muzayri`ah,Al Muzayri‘ah,Muzayri`ah,Muzayri‘ah,Mzairaa,Mzaïraâ,المزيرعة,مزيرعة', 35.5318000, 36.0700300, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125286, 'Al Jalā’', 'Al Jala''', 'Al Jala'',Al Jalā’,Al Musallakhah,Moussallakha,Musallakhah,aljlaʾ,almslkht,الجلاء,المسلّخة', 34.6334600, 40.8405400, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125287, 'Mūrak', 'Murak', 'Morek,Mork,Mourek,Moûrek,Murak,Murk,Mūrak,mwrk,مورك', 35.3761500, 36.6897000, 'SY', '2015-03-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125288, 'Mukharram al Fawqānī', 'Mukharram al Fawqani', 'Al-Mukharram Fokani,Moukharram Faouqani,Moukharrem el Fouqani,Muharram,Muharrem,Mukharram Fawqani,Mukharram Fawqānī,Mukharram Fokani,Mukharram al Fawqani,Mukharram al Fawqānī,Muḩarram,mkhrm alfwqany,مخرم الفوقاني', 34.8152100, 37.0867700, 'SY', '2012-08-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125289, 'Muḩradah', 'Muhradah', 'Al Karmah,Mahardah,Maharde,Mahardih,Maḩardah,Maḩarde,Maḩardih,Muhardeh,Muhradah,Muḩradah,alkrmt,mhrdt,الكرمة,محردة', 35.2479000, 36.5725000, 'SY', '2012-05-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125290, 'Muḩambal', 'Muhambal', 'Mhannbel,Muhambal,Muhanbal,Muḩambal,Muḩanbal,mhmbl,mhnbl,محمبل,محنبل', 35.7873500, 36.4721000, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125291, 'Mazra‘at Bayt Jinn', 'Mazra`at Bayt Jinn', 'Mazra`at Bay Jinn,Mazra`at Bayt Jinn,Mazraat Bein Jinn,Mazraat Beit Jinn,Mazraat Beïn Jînn,Mazraat Beït Jinn,Mazraat Beït Jînn,Mazra‘at Bay Jînn,Mazra‘at Bayt Jinn,مزرعة بيت جن', 33.3283600, 35.9214400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125292, 'Maşyāf', 'Masyaf', 'Imranie,Massiaf,Massiyaf,Massiâf,Massyaf,Masyab,Masyad,Masyaf,Masyāb,Maşyāf,Maşşīyaf,Misiaf,Omranie,Omranié,`Omraniye,`Umraniya,msyaf,مصياف,‘Omrānīye,‘Umraniya', 35.0653000, 36.3406000, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125293, 'Maskanah', 'Maskanah', 'Balis,Bālis,Maskanah,Maskanih,Meshseneh,Meskene,Meskeneh,Meskéné,bals,msknt,بالس,مسكنة', 35.9657700, 38.0416500, 'SY', '2017-03-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125294, 'Mashtá al Ḩulw', 'Mashta al Hulw', 'Machta Heilou,Machta Helou,Machta Hélou,Mashta al Hulw,Mashtá al Ḩulw,mshty alhlw,مشتى الحلو', 34.8746200, 36.2509900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125295, 'Mas‘adah', 'Mas`adah', 'El Mes `ade,El Mes ‘ade,El Mesadi,Mas`adah,Massaade,Massaadé,Masuada,Mas‘adah,Messadi,Масъада,مسعدة', 33.2320300, 35.7557200, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125296, 'Markadah', 'Markadah', 'Markada,Markadah,Marqada,Marqadah,Marqadā,mrkdt,mrqda,mrqdt,مرقدا,مرقدة,مركدة', 35.7460700, 40.7530400, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125297, 'Māri‘', 'Mari`', 'Daftardar,Daftardār,Defterdar,Ma`ratah,Maareh,Mar`a,Mare''`,Mareaa,Mare’‘,Mari`,Mar‘ā,Ma‘rātah,Mraa,Mâréaa,Māri‘,مارع', 36.4825900, 37.1970900, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125298, 'Manbij', 'Manbij', 'Bambyce,Giyerapol,Hierapolis,Manbej,Manbi,Manbidsch,Manbidz,Manbidzh,Manbidż,Manbidž,Manbij,Manbiy,Membidj,Membij,Memdidge,Menbidj,Menbij,Mennbidj,Minbej,Muenbic,Münbiç,man bi ji,manbiji,mnbj,Манбидж,Манбідж,منبج,ማንቢጅ,マンビジ,曼比季', 36.5281500, 37.9549500, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125299, 'Ma‘lūlā', 'Ma`lula', 'Ma''aloula,Ma''alula,Ma`lula,Ma`lulah,Maaljulja,Maaloula,Maaloûla,Ma‘lūlah,Ma‘lūlā,Ma’aloula,Ma’alula,Маалюля,معلولا', 33.8452900, 36.5451400, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125300, 'Malaḩ', 'Malah', 'Malah,Malaḩ,Mallah,Mallaḩ,Mallāḩ,Mellah,Mellakh,Mellan,Mellâh,Mellân,Milh,Milḩ,mlh,Меллах,ملح', 32.5079500, 36.8571900, 'SY', '2014-01-20', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125301, 'Mahīn', 'Mahin', 'Maheen,Mahin,Mahire,Mahīn,Mehin,Mehine,Mehīn,Mheen,Mhine,Mihine,Mihîne,Méhine,mhyn,مهين', 34.2416800, 37.0584300, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125302, 'Ma‘dān', 'Ma`dan', 'Khan Maddan,Ma`dan,Ma`din Jadid,Maadann,Ma‘dan,Ma‘din Jadīd,Ma‘dān,mʿdan,معدان,معدن جديد', 35.7552000, 39.5983500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125303, 'Medaya', 'Medaya', 'Madaya,Maḑāyā,Medaya,mdaya,مضايا', 33.6903200, 36.1035400, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125304, 'Al Ma‘baţlī', 'Al Ma`batli', 'Al Ma`batli,Al Ma‘baţlī,Ma`batli,Maabatli,Mabadli,Ma‘baţlī,almʿbtly,المعبطلي,معبطلي', 36.5624600, 36.7429200, 'SY', '2016-09-25', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125305, 'Ma‘arratmişrīn', 'Ma`arratmisrin', 'Ma''arrat Shemarin,Ma`arrat Misrin,Ma`arrat Misriyn,Ma`arratmisrin,Maarat Missrin,Maarrat al Masrin,Maarret Misrine,Maarret el Mesrine,Marshemarin,Ma‘arrat Misriyn,Ma‘arrat Mişrīn,Ma‘arratmişrīn,معرة مصرين,معرتمصرين', 36.0115200, 36.6718300, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125306, 'Ma‘arrat an Nu‘mān', 'Ma`arrat an Nu`man', 'Ma`arat an Na`man,Ma`arrat an Nu`man,Ma`arret en Nu`man,Maaret el Noman,Maarret enn Naamane,Maarret enn Naamâne,Maret en Na`man,Maret en Na‘man,Ma‘arat an Na‘mān,Ma‘arrat an Nu‘mān,Ma‘arret en Nu‘mān,Mo''aret-Nu''man,Mo’aret-Nu’man,معرة النعمان', 35.6483000, 36.6769300, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125307, 'Kuwayris Sharqī', 'Kuwayris Sharqi', 'Kawbris ash Sharqi,Kawbrīs ash Sharqī,Khuwayrat ash Sharqi,Khuwayrat ash Sharqī,Kouaires ech Chargi,Kouaires ech Charqui,Kouaïres ech Charqui,Kouaïrès ech Chargi,Koueir es Charqiye,Kouéïr ès Charqiyé,Kuwayris Sharqi,Kuwayris Sharqī,Kuwayris ash Sharqi,Kuwayris ash Sharqī,kwyrs shrqy,كويرس شرقي', 36.1668500, 37.5381500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125308, 'Kurnāz', 'Kurnaz', 'Kornaz,Kornâz,Kurnaz,Kurnāz,Qurnaz,Qurnāz,krnaz,كرناز', 35.3897200, 36.4877300, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125309, 'Kinnsibbā', 'Kinnsibba', 'Kensiya,Kinnsibba,Kinnsibbah,Kinnsibbā,Kinsiba,Kinsibba,Kinsibbā,Kinsibā,Qansiba,Qānsībā,knsba,كنّسبّا', 35.7441000, 36.1640000, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125310, 'Rabī‘ah', 'Rabi`ah', 'Gebelli,Guebelli,Guébelli,Kaybilali,Kaybilalī,Kaybilli,Kaybillī,Kibiliyah,Kibilli,Kibillī,Kibilīyah,Rabi`ah,Rabī‘ah,kblyt,kyblly,rbyʿt,ربيعة,كبلية,كيبللي', 35.7865600, 36.0382500, 'SY', '2013-10-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125311, 'Khushām', 'Khusham', 'Khusham,Khushām,khsham,خشام', 35.3008800, 40.2891600, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125312, 'Khirbat Tīn Nūr', 'Khirbat Tin Nur', 'Khan,Kharabat et Tin,Kheurbet Tine Naduar,Kheurbet Tine Naour,Kheurbet Tîne Naduar,Kheurbet et Tine,Kheurbet et Tiné,Kheurbet ett Tine,Kheurbet ett Tîne,Khirbat Tin Nur,Khirbat Tīn Nūr,Khirbat at Tin,Khirbat at Tīn,Khirbet et Tin,Khirbet et Tīn,khrbt tyn nwr,خربة تين نور', 34.7012200, 36.5565800, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125313, 'Al Qabw', 'Al Qabw', 'Al Qabw,Kheurbet el Qabou,Khirbat al Qabw,alqbw,khrbt alqbw,القبو,خربة القبو', 34.8432400, 36.4549300, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125314, 'Khirbat al Ma‘azzah', 'Khirbat al Ma`azzah', 'Kheurbet el Maaze,Kheurbet el Maazé,Khirbat Ma`zzah,Khirbat Ma‘zzah,Khirbat al Ma`azzah,Khirbat al Ma`zah,Khirbat al Ma‘azzah,Khirbat al Ma‘zah,خربة المعزة,خربة معزة', 34.8045400, 36.0007700, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125315, 'Khirbat Ghazālah', 'Khirbat Ghazalah', 'Ghazale,Kheurbet Rhazale,Kheurbet Rhazâlé,Khirbat Ghazalah,Khirbat Ghazālah,Khirbat al Ghazalah,Khirbat al Ghazālah,Khirbet el Ghazale,Khirbet el Ghazāle,Khirbet-ehl''-Gazala,Rhazale,Rhazâle,khrbt alghzalt,khrbt ghzalt,Хирбет-эль-Газала,خربة الغزالة,خربة غزالة', 32.7337600, 36.2045500, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125316, 'Khān Shaykhūn', 'Khan Shaykhun', 'Khan Cheykoun,Khan Shaykhun,Khan Sheikhun,Khan-Sheikhoun,Khane Chaikhoun,Khane Cheikhoun,Khâne Chaïkhoun,Khâne Cheïkhoûn,Khān Shaykhūn,Khān Sheikhūn,khan shykhwn,خان شيخون', 35.4420800, 36.6509500, 'SY', '2014-11-14', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125317, 'Khanāşir', 'Khanasir', 'Khamassir,Khanasir,Khanasser,Khanâsser,Khanāşir,Qunasira,Qunāsira,khnasr,خناصر', 35.7815900, 37.4991900, 'SY', '2012-07-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125318, 'Khān Arnabah', 'Khan Arnabah', 'Khan Arnabah,Khan Uraynibah,Khan ar Raubah,Khan ar Rinbah,Khane Erennbe,Khâne Erennbé,Khān Arnabah,Khān Uraynibah,Khān ar Raubah,Khān ar Rinbah,khan arnbt,khan arynbt,خان أرنبة,خان أرينبة', 33.1837800, 35.8915800, 'SY', '2012-12-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125319, 'Al Khafsah', 'Al Khafsah', 'Al Khafsah,Hafse Kebir,Hafse Kebīr,Khafre Kebire,Khafré Kébiré,Khafsah,Khafsah Kabir,Khafsah Kabīr,Khafse,Khafse el Kebire,Khafsé,Khafsé el Kébîré,alkhfst,khfst,الخفسة,خفسة', 36.2311000, 38.0217200, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125320, 'Al Ghandūrah', 'Al Ghandurah', 'Al Ghandurah,Al Ghandūrah,Al `Alkanah,Al ‘Alkānah,Ghandurah,Ghandūrah,Guiaour Elli,Guiaoûr Elli,Kaour Elli,Kawur Illi,Kawurayli,Kāwur Illī,Kāwurāylī,alghndwrt,ghndwrt,العلكانة,الغندورة,غندورة', 36.6694500, 37.7325100, 'SY', '2015-07-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125321, 'Kassab', 'Kassab', 'Kassab,Kesab,Keseb,Kessab,Kiseb,Qasab,ksb,كسب', 35.9263900, 35.9897000, 'SY', '2015-02-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125322, 'Ra’s al Khashūfah', 'Ra''s al Khashufah', 'Al Kashfah,Kachfe,Kachfé,Kashfah,Ra''s al Khashufah,Ra’s al Khashūfah,alkshft,kshft,ras alkhshwft,الكشفة,رأس الخشوفة,كشفة', 34.8265300, 36.0516700, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125323, 'Al Karīmah', 'Al Karimah', 'Al Karimah,Al Karīmah,Karimah,Karto,Kartu,Kartū,Karīmah,alkrymt,krtw,krymt,الكريمة,كرتو,كريمة', 34.6694100, 36.0754600, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125324, 'Kafr Zaytā', 'Kafr Zayta', 'Az Zaytiyah,Az Zaytīyah,Kafer Zaita,Kafer Zaïta,Kafer Zita,Kafer ez Zaita,Kafer ez Zaïta,Kaferzita,Kafr Zayta,Kafr Zaytah,Kafr Zaytā,Kafr Zita,Kafr Zīta,alzytyt,kfr zyta,kfr zytt,الزيتية,كفر زيتا,كفر زيتة', 35.3742500, 36.6033000, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125325, 'Kafr Takhārīm', 'Kafr Takharim', 'Kafar Takharim,Kafer Harut,Kafer Taharim,Kafer Tahârim,Kafer Takharim,Kafer Takhârim,Kafer Tkherim,Kafr Taharim,Kafr Takharim,Kafr Takhārīm,Kafr Taḩārīm,kfr tkharym,كفر تخاريم', 36.1168000, 36.5152200, 'SY', '2012-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125326, 'Kafranbel', 'Kafranbel', 'Kafr Nabl,Kafr Nubl,Kafr Nubul,Kafr nabel,Kafranbel,Kafranbel'',Kufer Nabel,kfr nbl,kfrnbl,Кафранбель,كفر نبل,كفرنبل,کفر نبل,کفرنبل', 35.6137600, 36.5644900, 'SY', '2016-09-02', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125327, 'Kafr Lāhā', 'Kafr Laha', 'Houla,Hula,Kafer Laha,Kafer Lâha,Kafr Laha,Kafr Lahah,Kafr Lāhā,Kafr Lāḩah,Kefrlehe,Kufer Laha,al-Hulah,al-Ḥūlāh,alhwlt‎‎,kfr laha,الحولة‎‎,كفر لاها', 34.8946900, 36.4958200, 'SY', '2016-12-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125328, 'Kafr Baţnā', 'Kafr Batna', 'Kafar Batna,Kafer Batna,Kafr Batna,Kafr Baţnā,Kefer Batna,kfr btna,كفر بطنا', 33.5116800, 36.3727300, 'SY', '2013-02-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125329, 'Junaynat Raslān', 'Junaynat Raslan', 'Jnainet Raslane,Jnaïnet Raslâne,Junaynat Raslan,Junaynat Raslān,jnynt rslan,جنينة رسلان', 34.9278900, 36.1240000, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125330, 'Jubb Ramlah', 'Jubb Ramlah', 'Joub Ramle,Joubb Ramle,Joubb Ramlé,Jubb Ramlah,jb rmlt,جب رملة', 35.2092200, 36.4310400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125331, 'Jubb al Jarrāḩ', 'Jubb al Jarrah', 'Djoubb ej Jarrah,Joubb ej Jarrah,Joubb ej Jarrâh,Jubb al Jarrah,Jubb al Jarrāḩ,jb aljrah,جب الجرّاح', 34.8344400, 37.3239600, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125332, 'Al Jīzah', 'Al Jizah', 'Al Jizah,Al Jīzah,Jizah,Jize,Jizzah,Jîzé,Jīzah,aljyzt,الجيزة', 32.5690900, 36.3155100, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125333, 'Jisr ash Shughūr', 'Jisr ash Shughur', 'Djisr el Choghour,Jisr Al-Shughour,Jisr Shagour,Jisr ash Shaghur,Jisr ash Shughur,Jisr ash Shughūr,Jisr ash Shāghūr,Jisr ech Chorhour,Jisr esh Shaur,Jisr esh Shughur,Jisr esh Shughūr,Jisr-esh-Shughour,jsr alshghwr,جسر الشغور', 35.8141800, 36.3198300, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125334, 'Jayrūd', 'Jayrud', 'Djeroud,Djerud,Djéroud,Jairoud,Jairud,Jayrud,Jayrūd,Jaïroud,Jerud,Jerūd,jyrwd,جيرود', 33.8070900, 36.7386100, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125335, 'Jawbat Burghāl', 'Jawbat Burghal', 'Jaoubet Borrhal,Jaoubet Borrhâl,Jaoubet Bour''rhal,Jaoubet Bourrhat,Jaoubet Bour’rhâl,Jawbat Burghal,Jawbat Burghāl,jwbt brghal,جوبة برغال', 35.4899500, 36.1747300, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125336, 'Tchoban Bey', 'Tchoban Bey', 'Ar Ra`i,Ar Rā‘ī,Choban Bey,Jawban Bak,Jawban Bayk,Jawbān Bak,Jawbān Bayk,Shawban Bayk,Shawbān Bayk,Tchoban Bey,Tchobane Bey,Tchobâne Bey,jwban bk,الراعي,جوبان بك', 36.6118200, 37.4478000, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125337, 'Al Jarnīyah', 'Al Jarniyah', 'Al Jarniyah,Al Jarnīyah,Jarniyah,Jarniye,Jarniyé,Jarnīyah,Jerniye,Jernîye,aljrnyt,jrnyt,الجرنية,جرنية', 36.1605400, 38.2333700, 'SY', '2016-11-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125338, 'Jaramānā', 'Jaramana', 'Djaramana,Djaramānā,Jaramana,Jaramanah,Jaramānah,Jaramānā,Jeramana,Jurmana,Jurmānā,Jéramâna,jrmana,جرمانا', 33.4862000, 36.3461400, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125339, 'Jarābulus', 'Jarabulus', 'Carablus,Djarablous,Djerablous,Djérâbloûs,Jarablos,Jarablus,Jarabulus,Jarābulus,Jerablus,Jirablus,Jirāblus,jrabls,جرابلس', 36.8175000, 38.0111100, 'SY', '2015-01-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125340, 'Jindayris', 'Jindayris', 'Dindaris,Djennderess,Djenndéress,Djinnderess,Djinndéress,Dīndaris,Genderesse,Jandaris,Jandarīs,Jandayris,Jenderess,Jendéress,Jindaras,Jindayris,Jundayris,dyndrs,jndyrs,جنديرس,ديندرس', 36.3949600, 36.6889000, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125341, 'Jablah', 'Jablah', 'Djeble,Djéblé,Jablah,Jableh,Jebele,Jebeleh,Jebelli,Jeble,jblt,جبلة', 35.3621100, 35.9275900, 'SY', '2013-05-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125342, 'Izra‘', 'Izra`', 'Ezra,Ezraa,Ezrra,Izra,Izra`,Izra`a,Izra‘,Izra‘a,Lorava,Zoraia,Zorava,Изра,ازرع', 32.8706000, 36.2545300, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125343, '‘Irbīn', '`Irbin', 'Aarbil,Aarbîl,Arbine,Irbin,Irbine,`Irbin,عربين,‘Irbīn', 33.5371900, 36.3663500, 'SY', '2013-02-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125344, 'Inkhil', 'Inkhil', 'Ankhel,Enkhel,Enn Nakhl,Ennkhel,Inkhel,Inkhil,ankhl,انخل', 33.0180900, 36.1282800, 'SY', '2016-11-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125345, 'Idlib', 'Idlib', 'Idleb,Idlib,Idlibas,Idlip,adlb,idaliba,ideullibeu,idoribu,mhafzt adlb,yi de li bo,İdlib,İdlip,Ідліб,Идлиб,Իդլիբ,אדלב,إدلب,ادلب,محافظة إدلب,इदलिब,イドリブ,伊德利卜,이들리브', 35.9306200, 36.6339300, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125346, 'Hisya', 'Hisya', 'Hasiya,Hassie,Hassié,Hassye,Hassyé,Hasyah,Hisiyah,Hisya,Hisya'',Hisyah,hsya,hsyaʾ,hsyt,حسيا,حسياء,حسية,Ḩasyah,Ḩisyah,Ḩisyā,Ḩisyā’,Ḩisīyah', 34.4119700, 36.7586700, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125347, 'Ḩīsh', 'Hish', 'Haysh,Hich,Hish,Hîch,Hīsh,hysh,حيش,Ḩaysh,Ḩīsh', 35.5479300, 36.6435600, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125348, 'Homs', 'Homs', 'Choms,Emesa,Gorad Khoms,Hims,Himsa,Homs,Homsas,Homsz,Houmousse,Hums,Humus,Kh''oms,KhIums,Khoms,QHS,h xms,himasa,hms,homsa,homseu,homsi,homusu,huo mu si,hwms,mdynt hms,Χομς,Горад Хомс,ХІумс,Хомс,Хьомс,Հոմս,חומס,حمص,مدينة حمص,ܚܡܨ,होम्स,ਹਿਮਸ,ฮอมส์,ჰომსი,Ḩimş,Ἔμεσα,ホムス,霍姆斯,홈스', 34.7268200, 36.7233900, 'SY', '2014-05-31', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125349, 'Ḩimmīn', 'Himmin', 'Himmin,Himmine,Himmîne,Himmīne,hmyn,حمين,Ḩimmīn', 34.9003500, 36.0401000, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125350, 'Ḩarrān al ‘Awāmīd', 'Harran al `Awamid', 'Harran al `Awamid,Harrane el-Aouamid,Harrâne el-Aouâmîd,حرّان العواميد,Ḩarrān al ‘Awāmīd', 33.4488500, 36.5600100, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125351, 'Ḩuraytān', 'Huraytan', 'Haratan,Hareitane,Hareïtane,Haritan,Harithan,Hraitane,Hraytan,Hraïtâne,Hreitan,Hritan,Huraytan,hrytan,حريتان,Ḩarītān,Ḩuraytān,Ḩāratān,Ḩārithān,Ḩāritān', 36.2886100, 37.0852700, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125352, 'Ḩārim', 'Harim', 'Harem,Harim,harm,حارم,Ḩārim', 36.2117600, 36.5207800, 'SY', '2012-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125353, 'Ḩarf al Musaytirah', 'Harf al Musaytirah', 'Harf al Musaytirah,Harf el Msaitra,Harf el Msaïtra,hrf almsytrt,حرف المسيترة,Ḩarf al Musaytirah', 35.3880800, 36.1343900, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125354, 'Ḩarbinafsah', 'Harbinafsah', 'Harb Nafsah,Harb Nafse,Harb Nafsih,Harb Nafsou,Harb Nafsé,Harb Nefsi,Harbinafsah,Harbinafsih,Harbnafsah,Harbnessi,Hurbinafsuh,Hurr Binafsah,Kharbnefih,Kharibnafih,hrbnfsh,حربنفسه,Ḩarb Nafsah,Ḩarb Nafsih,Ḩarbinafsah,Ḩarbinafsih,Ḩarbnafsah,Ḩurbinafsuh,Ḩurr Binafsah', 34.9374500, 36.6224300, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125355, 'Ḩarastā', 'Harasta', 'Arasta Bassal,Harasta,Harasta al Basal,Harasta el Bassal,Harastah al Basal,Harastah al Başal,Hirista,hrsta,حرستا,Ḩarastā,Ḩarastā al Başal,Ḩiristā', 33.5586900, 36.3651500, 'SY', '2012-11-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125356, 'Ḩammām Wāşil', 'Hammam Wasil', 'Hammam Ouassel,Hammam Wasil,Hammâm Ouâssel,hmam wasl,حمام واصل,Ḩammām Wāşil', 35.0743700, 36.0867700, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125357, 'Ḩamāh', 'Hamah', 'Epiphaneia,Epiphania,Hama,Hamah,Hamao,Hamath,Khama,hmah,hmat,Хама,حماة,حماه,Ḥamāh,Ḩamāh', 35.1317900, 36.7578300, 'SY', '2015-04-02', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125358, 'Ḩalfāyā', 'Halfaya', 'Halfaya,hlfaya,حلفايا,Ḩalfāyā', 35.2601400, 36.6058100, 'SY', '2012-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125359, 'Aleppo', 'Aleppo', 'ALP,Alep,Alepas,Alepo,Aleppe,Aleppo,Aleppu,Aleppó,Alèp,Berea,Beroea,Chalepi,Gorad Khaleb,Halab,Haleb,Haleba,Halep,Heleb,Hələb,Khaleb,Khaleb khot,Khalepion,Madinat Halab,Madīnat Ḩalab,Xalab,a lei po,aleppea,aleppo,allepo,areppo,halaba,hlb,xa lep po,Χαλέπι,Алеп,Алеппо,Горад Халеб,Халеб,Халеб хот,ХӀалаб,Хәлеб,Հալեպ,חאלב,حلب,ܚܠܒ,अलेप्पो,हलब,আলেপ্পো,ਹਲਬ,அலெப்போ,അലെപ്പോ,อะเลปโป,ალეპო,Ḥaleb,Ḩalab,アレッポ,阿勒颇,알레포', 36.2012400, 37.1611700, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125360, 'Ḩadīdah', 'Hadidah', 'Hadidah,Hadide,Hadîdé,hdydt,حديدة,Ḩadīdah', 34.6733700, 36.3973400, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125361, 'Al Ḩāḑir', 'Al Hadir', 'Al Hadir,Al Hādir,Al Ḩāḑir,Hader,Hâder,alhadr,الحاضر,الهادر', 35.9902400, 37.0508600, 'SY', '2016-11-15', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125362, 'Ghabāghib', 'Ghabaghib', 'Gabagib,Ghabaghib,Ghabāghib,Rhabarheb,Rhabârheb,ghbaghb,Габагиб,غباغب', 33.1823500, 36.2253400, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125363, 'Al Furqlus', 'Al Furqlus', 'Al Furqlus,Farqalus,Farqalūs,Forkloss,Forqloss,Fourgloss,Fourqloss,Furqlus,alfrqls,frqls,الفرقلس,فرقلس', 34.6063800, 37.0874500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125364, 'Fīq', 'Fiq', 'Feeq,Fick,Fig,Fik,Fiq,Fīq,fyq,Фик,فيق', 32.7793500, 35.7003200, 'SY', '2014-07-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125365, 'Al Fākhūrah', 'Al Fakhurah', 'Al Fakhurah,Al Fākhūrah,Fakhaura,Fakhoura,Fakhurah,Fâkhoura,Fākhūrah,alfakhwrt,الفاخورة', 35.4984600, 36.0095500, 'SY', '2014-02-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125366, 'Duwayr Raslān', 'Duwayr Raslan', 'Douair Raslane,Douaïr Raslâne,Duwayr Raslan,Duwayr Raslān,dwyr rslan,دوير رسلان', 34.9491000, 36.1817900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125367, 'Ad Duraykīsh', 'Ad Duraykish', 'Ad Duraykish,Ad Duraykīsh,Bermana,Dere Kish,Draikich,Draykikh,Draykīkh,Draïkich,Draïkîch,Dreikich,Duraykish,Duraykīsh,Dureikish,Dureikīsh,aldrykysh,drykysh,الدريكيش,دريكيش', 34.8951400, 36.1430300, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125368, 'Aḑ Ḑumayr', 'Ad Dumayr', 'Ad Dumayr,Al-Dumayr,Aḑ Ḑumayr,Damir,Dumair,Dumayr,aldmyr,dmyr,الضمير,ضمير,Ḑamīr,Ḑumayr', 33.6438900, 36.6937600, 'SY', '2016-11-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125369, 'Douma', 'Douma', 'Douma,Duma,Dūmā,dwma,Дума,دوما', 33.5717500, 36.4027000, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125370, 'Damascus', 'Damascus', 'Al-Sham,Al-Shām,An Damaisc,Cham,DAM,Damas,Damasc,Damasch,Damasco,Damascu,Damascus,Damasek,Damashq,Damasiko,Damask,Damask",Damaska,Damaskas,Damasko,Damaskos,Damaskosy,Damasku,Damaskus,Damaszek,Damaszkusz,Damašek,Dameski,Dammeseq,Damsyik,Dimaejk,Dimaesq,Dimashk,Dimashk al-Sham,Dimashk al-Shām,Dimashku,Dimashq,Dimeshki esh Sham,Dimishiq,Dimishku,Dimishq,Dimäjk,Dimäşq,Domas,Domás,Dàmáskù,Dəməşq,Esh Sham,Esh Shām,Gorad Damask,Kamakeko,Ndamako,Ndamáko,Sam,d mshq,da ma shi ge,damasaka,damasakasa,damaseukuseu,damaskas,damaskasa,damasukasu,dameska,damiska,dimisqu,dmshq,dmsq,drmswq,timisku,Şam,Δαμασκός,Горад Дамаск,Дамаск,Дамаскус,Дамаскъ,Димашкъ,Димишкъ,Димишқ,Դամասկոս,דמשק,د مشق,دمشق,دیمەشق,دەمەشىق,ܕܪܡܣܘܩ,ދިމިޝްޤު,दमास्कस,दमिश्क,দামেস্ক,ਦਮਸ਼ਕ,ଡାମାସକସ,திமிஷ்கு,ಡಮಾಸ್ಕಸ್,ദമാസ്കസ്,ดามัสกัส,དྷ་མ་སི་ཁོ་སི།,ဒမားစကပ်မြို့,დამასკი,ደማስቆ,ダマスカス,大馬士革,大马士革,다마스쿠스,', 33.5102000, 36.2912800, 'SY', '2010-05-30', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125371, 'Dhībīn', 'Dhibin', 'Dhibbin,Dhibin,Dhībbīn,Dhībīn,Dibbin,Dibbine,Dibbîne,Dibbīn,Dibin,Dibine,Dîbîne,Dībīn,dhybyn,Дибин,ذيبين', 32.4384200, 36.5655100, 'SY', '2014-01-24', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125372, 'Dhībān', 'Dhiban', 'Dabyan,Dhiban,Dhībān,Diban,Dibane,Dîbâne,Dībān,dhyban,dyban,ديبان,ذيبان', 35.0149800, 40.5102800, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125373, 'Dayr Ḩāfir', 'Dayr Hafir', 'Dayr Hafir,Dayr Ḩāfir,Deir Hafer,Deir Hafero,Deir Hafir,Deir Hâfero,Deir Hâfir,Deïr Hâfer,dyr hafr,دير حافر', 36.1569400, 37.7077800, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125374, 'Deir ez-Zor', 'Deir ez-Zor', 'Azaura,DEZ,Dair az-Zaur,Dair az-Zaŭr,Dajr az-Zaur,Dajr ez-Zaur,Dajr-ehz-Zaur,Dayr al-Zawr,Dayr al-Zor,Dayr az Zawr,Dayr az Zur,Dayr az Zūr,Dayr az-Zawr,Dayr uz-Zur,Deir Azzor,Deir Zzor,Deir al-Zor,Deir al-Zour,Deir el-Zor,Deir ez Zoar,Deir ez Zor,Deir ez Zoras,Deir ez-Zor,Dejr ez-Zor,Dejr-ehz-Zor,Dejr-ez-Zor,Der Ezzor,Deyr-el-Zor,Deyrizor,Deïr ez Zor,Nteir al-Zor,Ter Zor  Der Zor  Ter Zor,dai er zu er,deileuejeujoleu,deileuejoleu,deir-el-zori,derizoru,dyr alzwr,dyralzwr,dyrʾ zʿwrtʾ,Ντέιρ αλ-Ζορ,Дайр-эз-Заур,Дейр ез-Зор,Дейр-ез-Зор,Дейр-эз-Зор,Դեյր-էլ-Զոր,Տէր Զօր  Դեր Զոր  Ter Zor,דיר א-זור,دير الزور,دیر الزور,دیرالزور,ܕܝܪܐ ܙܥܘܪܬܐ,დეირ-ელ-ზორი,デリゾール,代尔祖尔,데이르에조르,데이르에즈조르', 35.3358800, 40.1408400, 'SY', '2017-01-10', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125375, 'Dayr ‘Aţīyah', 'Dayr `Atiyah', 'Dayr `Atiyah,Dayr ‘Aţīyah,Deir Aatiye,Deir Atieh,Deir `Atiye,Deir ‘Atīye,Deïr Aatiyé,دير عطية', 34.0954100, 36.7679100, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125376, 'Dayr al ‘Aşāfīr', 'Dayr al ''Asafir', 'Dayr al `Asafir,Dayr al ‘Aşāfīr,Dayr al-Assafir,Deir Al-Asaffir,Deir al-Asafir,Deir el Aassafir,Deir el Assifir,Deïr el Aassâfîr,Deïr el Assifir,دير العصافير', 33.4658500, 36.4204400, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125377, 'Dārat ‘Izzah', 'Darat `Izzah', 'Dar Azza,Dar Ja''zeh,Dar Ja’zeh,Dar Ta`izah,Dar Ta`izzah,Dar Taazze,Dar Taâzze,Dar al `Izzah,Dar el `Izze,Darat Azza,Darat `Izzah,Daret Azza,Dart Azze,Dart Azzé,Dār Ta‘izah,Dār Ta‘izzah,Dār al ‘Izzah,Dār el ‘Izze,Dārat ‘Izzah,dart ʿzt,دار تعزة,دارة عزة', 36.2824700, 36.8521600, 'SY', '2016-12-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125378, 'Darkūsh', 'Darkush', 'Darkouch,Darkoûch,Darkush,Darkūsh,Deir Kush,Derkouch,Derkouk,Derkush,drkwsh,دركوش', 35.9918000, 36.3936100, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125379, 'Ad Darbāsīyah', 'Ad Darbasiyah', 'Ad Darbasiyah,Ad Darbāsīyah,Darbasiyah,Darbāsīyah,Derbassiye,Derbisiye,Derbisīye,Dirbassiyeh,aldrbasyt,drbasyt,الدرباسية,درباسية', 37.0727900, 40.6519900, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125380, 'Dārayyā', 'Darayya', 'Daraiya,Daraje,Daraya,Daraye,Darayya,Darayyah,Dareiya,Deraya,Dâraiya,Dārayyah,Dārayyā,Dārayā,Dāreiya,darya,Дарайе,داريّا', 33.4583500, 36.2325600, 'SY', '2012-11-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125381, 'Dar‘ā', 'Dar''a', 'Adraa,Dar`a,Dar‘ā,Der`a,Deraa,Deraâ,Derua,Der‘ā,Деръа,درعا', 32.6188900, 36.1021300, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125382, 'Dā‘il', 'Da`il', 'Da`il,Daail,Daal,Dael,Dail'',Daél,Dâail,Dā‘il,Даиль,داعل', 32.7546600, 36.1295800, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125383, 'Buşrá ash Shām', 'Busra ash Sham', 'Bosra,Bosra Eski Sham,Bosra ech Cham,Bosra ech Châm,Bostra,Busra,Busra Sham,Busra ash Sham,Busrah ash Sham,Buşrah ash Shām,Buşrá,Buşrá ash Shām,bsry,bsry alsham,Босра,Бусра,بصرى,بصرى الشام', 32.5201300, 36.4825600, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125384, 'Bulbul', 'Bulbul', 'Bulbul,blbl,بلبل', 36.7694700, 36.8196900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125385, 'Brummānat al Mashāyikh', 'Brummanat al Mashayikh', 'Birmathat al Mashayikh,Birmāthat al Mashāyikh,Broummanet el Machayekh,Broummânet el Machâyekh,Brummanat al Masha''ikh,Brummanat al Mashayikh,Brummānat al Mashāyikh,Brummānat al Mashā’ikh,brmant almshaykh,برمانة المشايخ', 35.0188300, 36.1708300, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125386, 'Bi’r al Ḩulw al Wardīyah', 'Bi''r al Hulw al Wardiyah', 'Bi''r Hulw,Bi''r al Hulw al Wardiyah,Bir Helou,Bir Hulw,Bi’r al Ḩulw al Wardīyah,Bi’r Ḩulw,Bîr Hélou,Bīr Ḩulw,byr alhlw alwrdyt,byr hlw,بئر الحلو الوردية,بير حلو', 36.6969400, 41.0352800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125387, 'Binnish', 'Binnish', 'Binnesh,Binnich,Binnish,bnsh,بنش', 35.9566400, 36.7138000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125388, 'Bdāmā', 'Bdama', 'Badama,Badāmā,Barama,Barāmā,Bdama,Bdamah,Bdâma,Bdāmah,Bdāmā,bdama,بداما', 35.8115100, 36.1964900, 'SY', '2015-11-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125389, 'Ar Rawḑah', 'Ar Rawdah', 'Ar Rawdah,Ar Rawḑah,Bazzaq,Bazzāq,Bezzaq,Bezzâq,alrwdt,bzaq,الروضة,بزاق', 35.0720400, 35.9137500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125390, 'Barrī ash Sharqī', 'Barri ash Sharqi', 'Barri Charqi,Barri ash Sharqi,Barri ech Charqi,Barrī ash Sharqī,bry alshrqy,برّي الشرقي', 34.9809900, 37.2009600, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125391, 'Bāniyās', 'Baniyas', 'Banias,Banijas,Baniyas,Bulunyas,Bulunyās,Bâniâs,Bāniyās,banyas,Банияс,بانياس', 35.1818800, 35.9487100, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125392, 'Banān', 'Banan', 'Banan,Banān,Benan,Benān,Bnan,Bnane,Bnâne,Bnān,bnan,بنان', 35.9735800, 37.3023400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125393, 'Babīlā', 'Babila', 'Bab Bila,Babila,Babīlā,Bāb Bīlā,bab byla,bbyla,باب بيلا,ببيلا', 33.4710100, 36.3307600, 'SY', '2013-02-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125394, 'Az Ziyārah', 'Az Ziyarah', 'Az Ziyarah,Az Ziyārah,Ez Ziara,Ez Ziâra,alzyart,الزيارة', 35.6848200, 36.3386700, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125395, 'Az Zarbah', 'Az Zarbah', 'Az Zarbah,Ez Zerbe,Ez Zerbé,Zarbah,Zerbe,alzrbt,zrbt,الزربة,زربة', 36.0677100, 36.9801200, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125396, 'Az Zabadānī', 'Az Zabadani', 'Az Zabadani,Az Zabadānī,Zabadani,Zabadany,Zabdani,Zabdānī,Zebdani,Zebdāni,Zebedani,Zibdani,Zibdānī,alzbdany,الزبداني', 33.7248800, 36.1005000, 'SY', '2016-11-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125397, 'I‘zāz', 'I`zaz', 'A`zaz,Aazaz,Aazâz,Azaz,A‘zāz,E''zaz,Ezzaz,I`zaz,Izaz,I‘zāz,aʿzaz,Аазаз,Азаз,أعزاز,إعزاز', 36.5866200, 37.0462800, 'SY', '2016-12-22', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125398, '‘Ayn ‘Īsá', '`Ayn `Isa', 'Ain Aissa,Aïn Aïssa,`Ayn `Isa,عين عيسى,‘Ayn ‘Īsá', 36.3855000, 38.8622800, 'SY', '2012-12-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125399, '‘Ayn at Tīnah', '`Ayn at Tinah', 'Ain Tin,Ain ett Tine,Aïn ett Tîné,`Ayn at Tinah,عين التينة,‘Ayn at Tīnah', 35.5644500, 36.1009800, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125400, 'Sabbah', 'Sabbah', 'Ain ett Tine,Aïn ett Tîné,Sabbah,`Ayn at Tinah,sbt,سبة,عين التينة,‘Ayn at Tīnah', 34.9029200, 36.2371100, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125401, '‘Ayn Shiqāq', '`Ayn Shiqaq', '''Ain el Shegag,Ain ech Cheqaq,Aïn ech Chéqâq,`Ayn Shiqaq,`Ayn ash Shiqaq,ʿyn shqaq,عين الشقاق,عين شقاق,‘Ayn Shiqāq,‘Ayn ash Shiqāq,’Ain el Shegag', 35.3944100, 36.0301200, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125402, '‘Ayn ash Sharqīyah', '`Ayn ash Sharqiyah', 'Ain ech Charqiye,Ain ech Charuiye,Ain ech Charuiyé,Aïn ech Charqîyé,`Ain esh Sharqiye,`Ayn ash Sharqiyah,عين الشرقية,‘Ain esh Sharqīye,‘Ayn ash Sharqīyah', 35.3316900, 36.0997300, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125403, '‘Ayn al Fījah', '`Ayn al Fijah', 'Ain Figeh,Ain Fije,Ain el Fije,Aïn Fîjé,Aïn el Fîjé,`Ayn al Fijah,عين الفيجة,‘Ayn al Fījah', 33.6152900, 36.1828500, 'SY', '2012-11-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125404, '‘Ayn al Bayḑā', '`Ayn al Bayda', 'Ain el Beida,Aïn el Beida,Ein El-Bayda,`Ayn al Bayda,`Ayn al Bayda'',`Ayn al Baydah,ʿyn albydt,عين البيضا,عين البيضة,‘Ayn al Bayḑah,‘Ayn al Bayḑā,‘Ayn al Bayḑā’', 35.6559900, 35.8887100, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125405, '‘Ayn al ‘Arab', '''Ayn al ''Arab', 'Aarab Peunar,Aarab Peunâr,Ain el Aarab,Arab Peunar,Aïn el Aarab,Ein-al-Arab,Kobane,Kobani,`Arab Binar,`Arab Bunar,`Ayn al `Arab,ʿrb bynar,عرب بينار,عين العرب,‘Arab Bīnār,‘Arab Būnār,‘Ayn al ‘Arab', 36.8909500, 38.3534700, 'SY', '2014-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125406, '‘Awaj', '`Awaj', 'A`waj,Aaouaj,Aouaj,A‘waj,`Awaj,عوج,‘Awaj', 34.9070400, 36.4044400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125407, 'At Tibnī', 'At Tibni', 'At Tibni,At Tibnī,Tibnah,Tibne,Tibné,altbny,التبني', 35.6117000, 39.8181000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125408, 'Aţ Ţawāḩīn', 'At Tawahin', 'At Tawahin,Aţ Ţawāḩīn,Tawahin,Touahine,Touâhîne,altwahyn,twahyn,Ţawāḩīn,الطواحين,طواحين', 35.1275100, 36.2144400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125409, 'At Tamāni‘ah', 'At Tamani`ah', 'At Tamani`ah,At Tamāni‘ah,Tamana,Tamanaa,Tamanat,Tamani`ah,Tamâna,Tamânat,Tamânaâ,Tamāni‘ah,التمانعة,تمانعة', 35.4584600, 36.7481600, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125410, 'At Tall', 'At Tall', 'Al-Tal,At Tall,Ett Tell,Tal,Tall,Tell,al-Tell,altl,التل', 33.6103300, 36.3107000, 'SY', '2016-12-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125411, 'Ath Thawrah', 'Ath Thawrah', 'Al Tabaqah,Al-Tabbaqah,Al-Thawra,At Tabaqah,At Tabqah,Ath Thawrah,Aţ Ţabaqah,Aţ Ţabqah,Madinat ath Thawrah,Madīnat ath Thawrah,Medinat Al Thawra,Revolution City,Tabaqah,Tabqa,Thawrah,altbqt,althwrt,thwrt,Ţabaqah,الثورة,الطبقة,ثورة', 35.8375800, 38.5482800, 'SY', '2017-01-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125412, 'As Suwaydā’', 'As Suwayda''', 'Al-Sweida,As Suwayda'',As Suwaydah,As Suwaydā’,Dionysia,Ehs-Suvejda,Es Suweida,Es Suweidiya,Es Suweidīya,Soueida,Soueïda,Suwaydah,Sweida,Эс-Сувейда,السويداء', 32.7089600, 36.5695100, 'SY', '2014-01-12', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125413, 'As Sūsah', 'As Susah', 'As Susa,As Susah,As Sūsah,As Sūsá,Es Soussa,Es Soûssa,Soussa,Sousse,Susah,Sūsah,alswst,السوسة', 34.5336600, 40.9581900, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125414, 'As Sukhnah', 'As Sukhnah', 'As Sukhnah,Es Sukhne,Soukhne,Soukhné,Sukhnah,alskhnt,السخنة', 34.8846000, 38.8749100, 'SY', '2015-02-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125415, 'As Sīsnīyah', 'As Sisniyah', 'As Sisniyah,As Sīsnīyah,Sisaniyah,Sisniyah,Sisniye,Sisniyé,Sisnîyé,Sīsanīyah,Sīsnīyah,alsysnyt,sysnyt,السيسنية,سيسنية', 34.7810800, 36.1429800, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125416, 'Al Mazra‘ah', 'Al Mazra`ah', 'Al Mazra`ah,Al Mazra‘ah,As Sajin,As Sajīn,As Sijn,Ehs-Sidzhn,Es Sijine,Es Sijn,Sajin,Sajīn,Sejen,Sejene,Sejine,Sijine,Sijn,Sijnah,Séjine,Séjéne,almzrʿt,alsjn,Эс-Сиджн,السجن,المزرعة', 32.7839800, 36.4769500, 'SY', '2014-02-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125417, 'As Sawdā', 'As Sawda', 'As Sawda,As Sawda'',As Sawdah,As Sawdā,As Sawdā’,Es Soda,Saouda,Sauda,Sawda'',Sawdah,Sawdā’,alswda,alswdt,السودا,السوداء,السودة', 34.9815100, 35.9441400, 'SY', '2012-05-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125418, 'Aş Şanamayn', 'As Sanamayn', 'Aere,Aeré,As Sanamayn,Aş Şanamayn,Ehs-Sanamejn,Es Sanamein,Es Sannamain,Sanamayn,Sanamein,Sanameine,Sanameïne,Sanmayn,alsnmyn,snmyn,Şanamayn,Эс-Санамейн,الصنمين,صنمين', 33.0718600, 36.1831600, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125419, '‘Assāl al Ward', '`Assal al Ward', 'Aassal el Ouard,Aassâl el Ouard,Assal el Ouard,Assal el Ward,`Asal al Ward,`Asal el Ward,`Assal al Ward,`Isal al Ward,عسال الورد,‘Asal al Ward,‘Assāl al Ward,‘Asāl el Ward,‘Isāl al Ward', 33.8645300, 36.4139000, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125420, 'Aş Şafşāfah', 'As Safsafah', 'As Safsafah,Aş Şafşāfah,Safsaf,Safsafah,Safsafe,Safsafih,Safsâfe,Sofsafe,Sofsâfé,alsfsaft,sfsaft,Şafşāf,Şafşāfah,Şafşāfih,الصفصافة,صفصافة', 34.7348100, 36.0531800, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125421, 'As Safīrah', 'As Safirah', 'Al-Safira,As Safirah,As Safīrah,Safir,Safira,Safirah,Safīrah,Sfaireh,Sfira,Sfire,Sfiré,Sfīra,alsfyrt,sfyrt,Şafīr,السفيرة,سفيرة', 36.0769600, 37.3725100, 'SY', '2016-12-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125422, 'As Sabkhah', 'As Sabkhah', 'As Sabkhah,Sabkha,Sabkhah,alsbkht,السبخة', 35.8118200, 39.2626800, 'SY', '2012-08-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125423, 'As Si‘in', 'As Si`in', 'As Sa`an,As Sa‘an,As Seen,As Si`in,As Si‘in,Es Sa`an,Es Saane,Es Saene,Es Saëne,Es Sā‘ān,Saane,Saane ech Chajara,Saene,السعن', 35.2637500, 37.3740200, 'SY', '2012-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125424, 'Ash Shaykh Badr', 'Ash Shaykh Badr', 'Al-Sheikh-Bader,Ash Shaykh Badr,Cheikh Bader,Cheikh Beder,Cheïkh Bader,Cheïkh Beder,Ech Cheikh Bader,Ech Cheikh Badr,Ech Cheïkh Bader,Shaykh Badr,Sheikh-Bader,alshykh bdr,shykh bdr,الشيخ بدر,شيخ بدر', 34.9917400, 36.0835000, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125425, 'Ash Shajarah', 'Ash Shajarah', 'Ash Shajarah,Chajara,Shajarah,alshjrt,الشجرة', 32.7741100, 35.8820200, 'SY', '2015-06-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125426, 'Ash Shaddādah', 'Ash Shaddadah', 'Ash Shaddadah,Ash Shaddādah,Ath Tharadi,Ath Tharādī,Chaddade,Chaddadi,Chaddâde,Chaddâdi,Jisr ash Shadadi,Jisr ash Shadādï,Shadadi,Shadādī,Tall Shadadi,Tall Shadādī,Tell Shedadi,Tell Shedādi,alshdadt,jsr alshdady,الشدادة,جسر الشدادي', 36.0575600, 40.7347800, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125427, 'Arwād', 'Arwad', 'Arwad,Arwād,Rawad,Rawāḑ,Rouad,Rouâd,arwad,أرواد', 34.8560400, 35.8585400, 'SY', '2012-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125428, 'Ar Ruḩaybah', 'Ar Ruhaybah', 'Ar Ruhaybah,Ar Ruḩaybah,Rouhaibe,Rouhaïbe,Ruhaibeh,Ruhaybah,Ruḩaybah,alrhybt,rhybt,الرحيبة,رحيبة', 33.7442400, 36.7039400, 'SY', '2012-07-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125429, 'Ar Rastan', 'Ar Rastan', 'Al-Rastan,Ar Rastan,Arethousa,Arethus,El Rastane,Er Rastan,Rastan,Rastane,Rastâne,alrstn,الرستن', 34.9266700, 36.7324100, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125430, 'Ar Raqqah', 'Ar Raqqah', 'Al-Rakka,Ar Raqqah,Ar-Rakka,Ar-Raqqah,Nicephorium,Rakka,Raqqa,Raqqah,alrqt,Ар-Ракка,الرقة', 35.9528300, 39.0078800, 'SY', '2017-07-21', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125431, 'Armanāz', 'Armanaz', 'Armanaz,Armanāz,armnaz,أرمناز', 36.0836300, 36.5031000, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125432, 'Arīḩā', 'Ariha', 'Ariha,Arihah,Arīḩah,Arīḩā,Eriha,Erîha,Riha,Rīḩā,aryha,أريحا', 35.8137400, 36.6096400, 'SY', '2012-05-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125433, 'An Nashābīyah', 'An Nashabiyah', 'Al-Nashabiyah,An Nashabiyah,An Nashshabiyah,An Nashshābīyah,An Nashābīyah,En Nishabiye,Nachabie,Nachabiye,Nachâbîyé,Nashabieh,Nashabiyah,Nashabiye,Nashābīyah,Nashābīye,Nechabye,Nechabyé,alnshabyt,النشابية', 33.5105100, 36.4856900, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125434, 'An Nabk', 'An Nabk', 'Al-Nabek,An Nabk,En Nebk,Kalamom,Nabak,Nabaq,Nabek,Nebeck,Nebek,Nebk,Nébeck,alnbk,النبك', 34.0240300, 36.7284800, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125435, 'Amude', 'Amude', 'Aamouda,Amouda,Amude,Aâmoûda,`Amuda,`Amudah,ʿamwda,عامودا,عامودة,‘Āmūdah,‘Āmūdā', 37.1041700, 40.9300000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125436, 'Al Ghanţū', 'Al Ghantu', 'Al Ghanta,Al Ghantu,Al Ghanţā,Al Ghanţū,Al Rhannto,Al-Ghantoo,Al-Ghantu,El Rhannta,El Rhannto,Ghantto,alghntw,الغنطو', 34.8220200, 36.6961300, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125437, 'Al Quţayfah', 'Al Qutayfah', 'Al Qutayfah,Al Quţayfah,Al-Kutaifeh,El Qtaife,El Qtaïfé,Kouteife,Kouteifé,Kutayfa,Kuteife,Qtaife,Qtaïfé,Qutayfah,Quteifa,Quteife,Quteifeh,Quţayfah,alqtyft,qtyft,القطيفة,قطيفة', 33.7384800, 36.6007100, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125438, 'Al Quşayr', 'Al Qusayr', 'Al Qusayr,Al Quşayr,Al''-Kusajra,Al-Kuseir,El Qoussair,El Quseir,Kouseir,Koussaie,Kousseir,Kuseir,Qosair,Qoussair,Qoussaïr,Qusair,Qusayr,Qusir,Quşayr,alqsyr,Аль-Кусайра,القصير', 34.5078000, 36.5802900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125439, 'Al Qurayyā', 'Al Qurayya', 'Al Qrayyah,Al Qurayya,Al Qurayyah,Al Qurayyā,Ehl''-Kurajja,El Kraiye,El Kraïyé,El Kreye,El Qraiye,El Qraïyé,alqrya,Эль-Курайя,القريا', 32.5433700, 36.5977600, 'SY', '2014-01-24', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125440, 'Al Qunayţirah', 'Al Qunaytirah', 'Al Qunaytirah,Al Qunayţirah,Ehl''-Kunejtra,El Kuneitra,El Qnaitra,El Qnaïtra,El Quneitra,Kuneitra,Kuneïtra,Qhaitra,Qnaitra,Qnaytra,Qnayţra,Qnaïtra,Qunaytirah,Qunayturah,Qunayţirah,Qunayţurah,Quneitra,alqnytrt,Эль-Кунейтра,القنيطرة', 33.1259500, 35.8246100, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125441, 'Al Qaryatayn', 'Al Qaryatayn', 'Al Qaryatayn,El Qaryatein,Kariatein,Kariateine,Karyatein,Kuriatein,Kuryatein,Nezala,Qariateine,Qariateïne,Qaryatayn,Quayatein,Quraytayn,alqrytyn,القريتين', 34.2295600, 37.2406600, 'SY', '2017-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125442, 'Al Qardāḩah', 'Al Qardahah', 'Al Qardahah,Al Qardāḩah,Al-Kurdaha,Kerdaha,Kirdaha,Kirdatcha,Kurdaha,Qardaha,Qardahah,Qardāha,Qardāḩah,Qerdaha,Qerdâha,Qurdaha,alqrdaht,qrdaht,القرداحة,قرداحة', 35.4564400, 36.0590900, 'SY', '2017-02-10', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125443, 'Al Qāmishlī', 'Al Qamishli', 'Al Qamishli,Al Qāmishlī,Al-Kamishly,Al-Qamishli,Ehl''-Kamyshly,El Qamishliye,KAC,Kamechlie,Kamichlieh,Kamishli,Kamishlie,Kamishlié,Qameshli,Qamichliyah,Qamichliye,Qamichlîyé,Qamichlīyah,Qamischli,Qamishliyah,Qamislo,Qamişlo,Qāmeshli,Qāmishlīyah,alqamshly,qamshly,Эль-Камышлы,القامشلي,قامشلی', 37.0521500, 41.2314200, 'SY', '2017-02-09', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125444, 'Al Qadmūs', 'Al Qadmus', 'Al Qadmus,Al Qadmūs,El Qadmus,El Qadmūs,Kadmous,Qadmous,Qadmouss,Qadmoûs,Qadmus,Qadmūs,alqdmws,القدموس', 35.0985500, 36.1598400, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125445, 'Al Mushannaf', 'Al Mushannaf', 'Al Mushannaf,El Mouchannaf,El Mushennef,Mouchannaf,Mushannaf,almshnf,mshnf,المشنف,مشنف', 32.7393100, 36.7747300, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125446, 'Al Musayfirah', 'Al Musayfirah', 'Al Musayfirah,El Museifire,Moussaifrat,Moussaifre,Moussaïfrat,Moussaïfre,Mousseifre,Mousseifré,Musayrifah,Museifre,Musejfra,almsyfrt,Мусейфра,المسيفرة', 32.6320500, 36.3393400, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125447, 'Al Mulayḩah', 'Al Mulayhah', 'Al Malihah,Al Malīḩah,Al Mleha,Al Mulayhah,Al Mulayḩah,Meleha,Mlaiha,Mlaihah,Mlaiḩah,Mlaïha,Mleiha,Mulayhah,Mulayḩah,Muleiha,almlyht,المليحة', 33.4852200, 36.3756100, 'SY', '2013-02-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125448, 'Mismīyah', 'Mismiyah', 'Al Mismiyah,Al Mismīyah,El Mesmiye,El Mesmiyé,Mesmiye,Mismiyah,Mismīyah,almsmyt,msmyt,المسمية,مسمية', 33.1290200, 36.3940200, 'SY', '2016-10-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125449, 'Al Mayādīn', 'Al Mayadin', 'Al Mayadin,Al Mayādīn,Al-Mayadeen,Audattha,Mayadin,Mayadine,Mayādīn,Meyadin,Meyadine,Meyedine,Meyādīn,almyadyn,myadyn,الميادين,ميادين', 35.0198200, 40.4515400, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125450, 'Al Mālikīyah', 'Al Malikiyah', 'Al Malikiyah,Al Mālikīyah,Darik,Dayrik,Dayrīk,Deirik,Derik,Deïrîk,Dêrik,Dêrîk,Guir Zerik,Guir Zérik,Kir Dhayrik,Kir Zerik,Kīr Dhayrīk,Kīr Zérik,Malikiyeh,Malkieh,almalkyt,dyryk,dێryk,kyr dhyryk,المالكية,ديريك,دێريك,كير ذيريك', 37.1770100, 42.1400600, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125451, 'Al Buţayḩah', 'Al Butayhah', 'Al Butayhah,Al Buţayḩah,Al Mahjar,Al Maḩjar,Al Maḩjār,Al `Amiriyah,Al ‘Āmirīyah,El Mahjar,Mahjar,Minjar,Minjār,Minnjar,albtyht,almhjar,mnjar,البطيحة,العامرية,المحجار,منجار', 32.9087100, 35.6319900, 'SY', '2014-07-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125452, 'Latakia', 'Latakia', 'Al Ladhiqiyah,Al Lādhiqīyah,Al-Laziqiyah,El Ladhaqiye,El Ladhiqiya,El Lādhaqiyé,El Lādhiqīya,Gorad Latakija,LTK,Ladhiqiye,Ladikija,Ladikis,Ladikiya,Laodicea,Laodicea ad Mare,Laodicee,Laodicée,Laodikeia,Latakia,Latakieh,Latakija,Latakija shaary,Latakio,Latakiya,Lataqiae,Lataqiä,Lataquia,Lattakeia,Lattakia,Lattaquie,Lattaquié,Latʻakia,Lazikija,Lazkiye,Lázikíja,Lādikīja,alladhqyt,la ta ji ya,ladhqyh,ladhqyt,ladhqyہ,latakia,latakiya,ltqyh,ratakia,Əl-Laziqiyyə,Λαττάκεια,Горад Латакія,Латакия,Латакия шаары,Латакија,Латакія,Լաթակիա,לטקיה,اللاذقية,لاذقية,لاذقیه,لاذقیہ,लताकिया,ლათაკია,ラタキア,拉塔基亚,라타키아', 35.5316800, 35.7901100, 'SY', '2013-01-10', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125453, 'Al Kiswah', 'Al Kiswah', 'Al Kiswah,Kesweh,Kisoue,Kisoué,Kissoue,Kisswa,Kiswah,Kiswe,Kisweh,alkswt,kswt,الكسوة,كسوة', 33.3581000, 36.2419000, 'SY', '2016-12-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125454, 'Al Khushnīyah', 'Al Khushniyah', 'Al Khushniyah,Al Khushnīyah,Couchenie,Couchenié,Ehl''-Khushnija,El Khushniye,El Khushnīye,El Kushniye,Khochniye,Khochniyé,Khushniyah,Khushnīyah,alkhshnyt,Эль-Хушния,الخشنية', 32.9994100, 35.8108400, 'SY', '2014-01-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125455, 'An Nāşirah', 'An Nasirah', 'Al Khuraybah,An Nasirah,An Nāşirah,Kheraibi,Khraibe,Khraïbé,Khuraybah,Nasirah,Nāşirah,alnasrt,khrybt,nasrt,الناصرة,خريبة,ناصرة', 34.7876900, 36.2855900, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125456, 'Al Jawādīyah', 'Al Jawadiyah', 'Al Jawadiyah,Al Jawādīyah,Chil Agha,Cil Axa,Jabal Agha,Jabal Āghā,Jil Agha,Jīl Āghā,aljwadyt,chl yagha,jbl agha,jl agha,Çil Axa,الجوادية,جبل آغا,جل أغا,چل ئاغا', 36.9866000, 41.8201500, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125457, 'Al Jānūdīyah', 'Al Janudiyah', 'Al Janudiyah,Al Jānūdīyah,Ej Janoudiye,Ej Jânoûdîyé,El Janoudiye,El Jânoûdiyé,Jabudiyah,Janudiyah,Jenudi,Jnoudiye,Jnoudîye,Jābūdīyah,Jānūdīyah,aljanwdyt,janwdyt,الجانودية,جانودية', 35.8846900, 36.2910800, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125458, 'Al Hinādī', 'Al Hinadi', 'Al Hannadi,Al Hannādī,Al Hinadi,Al Hinādī,Hanadi,Hennadi,Hennâdi,Hinadi,Hinādī,alhnady,hnady,الهنادي,هنادي,Ḩanādī', 35.5132400, 35.8744000, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125459, 'Al Ḩawl', 'Al Hawl', 'Al Hal,Al Hawl,Al Hul,Al Hāl,Al Ḩawl,Al Ḩūl,El Haul,El Hol,El Hool,El Hôl,alhwl,الحول', 36.3904200, 41.1498300, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125460, 'Al Ḩawāsh', 'Al Hawash', 'Al Hawash,Al Ḩawāsh,Haouach,Haouâch,Hawash,alhwash,hwash,الحواش,حواش,Ḩawāsh', 34.7600400, 36.3212700, 'SY', '2016-06-04', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125461, 'Al Ḩasakah', 'Al Hasakah', 'Al Hasakah,Al Ḩasakah,Al-Hasakeh,El Haseke,Hasakeh,Hasijih,Hassetche,Hasskih,alhskt,الحسكة,Ḩasijih,Ḩasskih', 36.5023700, 40.7477200, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125462, 'Al Ḩarāk', 'Al Harak', 'Al Harak,Al Ḩarāk,El Hrak,El Hrâk,alhrak,الحراك', 32.7493200, 36.3099400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125463, 'Al Ḩamrā’', 'Al Hamra''', 'Al Hamra'',Al Hamrah,Al Ḩamrah,Al Ḩamrā’,El Hamra,Hamra,Qaraqol,Qichlet el Hamra,alhmraʾ,alhmrt,الحمراء,الحمرة', 35.3150000, 37.0863200, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125464, 'Al Ḩamīdīyah', 'Al Hamidiyah', 'Al Hamidiyah,Al Ḩamīdīyah,Hamide,Hamidieh,Hamidiya,Hamidiyah,Hamidiye,Hamîdiyé,Hamīdīya,alhmydyt,hmydyt,الحميدية,حميدية,Ḩamīdīyah', 34.7125500, 35.9449500, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125465, 'Al Ḩājib', 'Al Hajib', 'Al Hajib,Al Ḩājib,El Hajeb,Hajeb,Hajib,Hâjeb,alhajb,الحاجب,Ḩājib', 35.8640900, 37.3968000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125466, 'Al Ḩaffah', 'Al Haffah', 'Al Haffah,Al Jaffah,Al Ḩaffah,Al-Haffeh,Al-Hiffeh,Haffah,Haffe,alhft,الحفة,Ḩaffah', 35.5982400, 36.0300600, 'SY', '2012-01-17', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125467, 'Al Ghizlānīyah', 'Al Ghizlaniyah', 'Al Ghizlaniyah,Al Ghizlānīyah,Al Ghuzlaniyah,Al Ghuzlānīyah,El Ghuzlaniye,El Ghuzlānīye,Ghazlaniye,Ghizlaniyah,Ghizlānīyah,Ghuzlaniyah,Ghuzlānīyah,Gozlanie,Gozlanié,Rhozlaniye,Rhozlanye,Rhozlanyé,alghzlanyt,ghzlanyt,الغزلانية,غزلانية', 33.3967100, 36.4549100, 'SY', '2012-11-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125468, 'Al Ghāriyah', 'Al Ghariyah', 'Al Ghariyah,Al Ghāriyah,Ehl''-Garija,Ghariyah,Ghāriyah,Rhariye,Rhârîyé,algharyt,Эль-Гария,الغارية', 32.3933200, 36.6506700, 'SY', '2014-01-24', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125469, 'Al Buşayrah', 'Al Busayrah', 'Al Busayrah,Al Buşayrah,Bassira,Bessireh,Boussaira,Boussaïra,Bseira,Bseïra,Busayrah,Buseira,Buseire,Buşayrah,Circesium,albsyrt,البصيرة', 35.1561800, 40.4271600, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125470, 'Al Bāriqīyah', 'Al Bariqiyah', 'Al Bariqiyah,Al Bāriqīyah,Bariqiyah,Barqiyah,Barqiye,Barqîyé,Barqīyah,Bāriqīyah,albarqyt,barqyt,brqyt,البارقية,بارقية,برقية', 34.8292400, 36.2286300, 'SY', '2017-02-03', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125471, 'Al Bahlūlīyah', 'Al Bahluliyah', 'Al Bahluliyah,Al Bahlūlīyah,Bahlawaniyeh,Bahloulie,Bahlouliye,Bahloulié,Bahloûlîyé,Bahluliyah,Baḩlūlīyah,Behlulia,El Bahluliye,El Bahlūlīye,albhlwlyt,البهلولية', 35.6367900, 35.9602200, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125472, 'Al Bāb', 'Al Bab', 'Al Bab,Al Balo,Al Bāb,Al Bālo,Bab,Bâb,El Bab,El Bāb,albab,الباب', 36.3705100, 37.5157000, 'SY', '2015-06-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125473, 'Al Atārib', 'Al Atarib', 'Al Atarib,Al Atārib,Atarib,Atharib,Athārib,Atārib,El Atareb,El Atâreb,Tarib,Terib,Térib,alatarb,atarb,اتارب,الأتارب', 36.1390700, 36.8250400, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125474, 'Al ‘Ashārah', 'Al `Asharah', 'Acharat,Al Asharah,Al Ashārah,Al `Asharah,Al ‘Ashārah,Charra,El Aachara,El Aachâra,El Achara,El Achâra,Qasr el `Ashara,Qasr el ‘Ashara,Sharra,Tirya,alashart,الأشارة,العشارة', 34.9213300, 40.5600700, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125475, 'Al ‘Arīmah', 'Al `Arimah', 'Aajami,Adjimi,Al `Arimah,Al ‘Arīmah,`Ajami,`Arime,alʿrymt,ʿjmy,العريمة,عجمي,‘Ajamī,‘Arime', 36.4729600, 37.7211300, 'SY', '2016-11-18', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125476, 'Al ‘Annāzah', 'Al `Annazah', 'Aannaze,Aannâzé,Al `Annazah,Al ‘Annāzah,An Nazi,`Annazah,`Annazih,`Anz,`Anzah,`Aunaz,العنازة,عنازة,‘Annāzah,‘Annāzih,‘Anz,‘Anzah,‘Aunāz', 35.1950300, 36.0657100, 'SY', '2012-02-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125477, 'Akhtarīn', 'Akhtarin', 'Akhtareen,Akhtareine,Akhtareïne,Akhtarin,Akhtarīn,Akhterin,Akhtreen,Akhtrin,Akterine,Aktérine,akhtryn,أخترين', 36.5107200, 37.3357100, 'SY', '2016-12-16', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125478, 'Iḩsim', 'Ihsim', 'Ahsim,Aḩsim,Ihsim,Iḩsim,ahsm,إحسم', 35.7207800, 36.5563100, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125479, '‘Afrīn', '`Afrin', 'Aafrine,Aafrîne,Afrin,Afrine,`Afrin,`Ifrin,عفرين,‘Afrīn,‘Ifrīn', 36.5119400, 36.8695400, 'SY', '2012-05-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125480, 'Ad Dīmās', 'Ad Dimas', 'Ad Dimas,Ad Dīmās,Dimas,Dīmās,Khan Dimez,aldymas,dymas,الديماس,ديماس', 33.5873900, 36.0926200, 'SY', '2012-11-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125481, 'Ad Dānā', 'Ad Dana', 'Ad Dana,Ad Danah,Ad Dānah,Ad Dānā,Dana,Dānā,Ed Dana,Ed Dâna,aldana,الدانا', 36.2125400, 36.7699800, 'SY', '2017-06-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125482, 'Ad Dālīyah', 'Ad Daliyah', 'Ad Dali,Ad Daliyah,Ad Dāliyah,Ad Dālī,Ad Dālīyah,Dali,Delibi,Dâli,Ed Dali,Ed Dâli,aldaly,aldalyt,الدالي,الدالية', 35.2360500, 36.1437100, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125483, 'Abū Qalqal', 'Abu Qalqal', 'Abou Qalqal,Abu Kalkal,Abu Qalqal,Abū Kalkal,Abū Qalqal,abw qlql,أبو قلقل', 36.4380600, 38.1198400, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125484, 'Ālbū Kamāl', 'Albu Kamal', 'Abou Kemal,Abu Kamal,Abu Kemal,Abu Kemāl,Abu-Kamal'',Abū Kamāl,Al-Bukamal,Al-bu-Kamal,Albu Kamal,Bukmal,Hindane,Hindané,abw kmal,albw kmal,Ālbū Kamāl,Абу-Камаль,أبو كمال,البو كمال', 34.4522600, 40.9185400, 'SY', '2016-11-13', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125485, 'Hajīn', 'Hajin', 'Abou Hardane,Abou Hardâne,Abu Hardan,Abu Hardub,Abū Ḩardān,Abū Ḩardūb,Bou Hardane,Hajin,Hajine,Hajîne,Hajīn,hjyn,هجين', 34.6950800, 40.8313800, 'SY', '2015-03-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125486, 'Abū az̧ Z̧uhūr', 'Abu az Zuhur', 'Abou ed Douhour,Abou ed Douhoûr,Aboudouhour,Abu ad Duhur,Abu az Zuhur,Abu ed Duhur,Abu ed Duhūr,Abu edh Dhahur,Abū az̧ Z̧uhūr,Abū aḑ Ḑuhūr,abw aldhwr,abw alzhwr,أبو الظهور,ابو الضهور', 35.7405800, 37.0448000, 'SY', '2013-09-06', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125487, 'Al Ya‘rubīyah', 'Al Ya`rubiyah', 'Al Ya`rubiyah,Al Ya‘rubīyah,Al Ya‘rūbīyah,Tall Kuchak,Tall Kuchik as Saghir,Tall Kujik,Tall Kujik Saghir,Tall Kūchak,Tall Kūchik aş Şaghīr,Tall Kūjik,Tall Kūjik Şaghīr,Tel Kocek,Tel Kochek,Tel Koçek,Tell Kotchek,Tell Kushik,Tell Kūshik,tl kwchk alsghyr,tl kwjk sghyr,tl kwshk,tەl kۆchەk,اليعربية,تل كوجك صغير,تل كوشك,تل كوچك الصغير,تەل كۆچەك', 36.8113800, 42.0620600, 'SY', '2014-06-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125522, 'Iriba', 'Iriba', 'Iriba', 15.1166700, 22.2500000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125523, 'Goz Béïda', 'Goz Beida', 'Goz Beida,Goz Béïda', 13.9456300, 20.5468000, 'TD', '2017-05-08', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125524, 'Goz Beïda', 'Goz Beida', 'Goz Beida,Goz Beïda', 12.2248400, 21.4103400, 'TD', '2014-09-05', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125525, 'Fada', 'Fada', 'Fada,Fort de Fada', 17.1853500, 21.5811400, 'TD', '2014-09-05', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125526, 'Biltine', 'Biltine', 'Biltine', 14.5279100, 20.9274900, 'TD', '2017-05-08', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125527, 'Am Timan', 'Am Timan', 'AMC,Am Timan,Am Timane,Am Timmane,Umm Timman', 11.0297000, 20.2827000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125528, 'Adré', 'Adre', 'Adre,Adré', 13.4664800, 22.1987500, 'TD', '2017-06-07', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125529, 'Abéché', 'Abeche', 'AEH,Abacher,Abeche,Abecher,Abese,Abeshe,Abeşe,Abešė,Abécher,Abéché,Gorad Abesheh,a bei xie,abeshe,abesye,abshy,Абеше,Горад Абешэ,أبشي,ابشی,アベシェ,阿贝歇,아베셰', 13.8291600, 20.8324000, 'TD', '2017-05-30', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125530, 'Sarh', 'Sarh', 'Archambault,Fort-Archambault,SRH,Sagh,Sahr,Sarh,Sarkh,Shar,Сарх', 9.1429000, 18.3923000, 'TD', '2017-05-30', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125531, 'Pala', 'Pala', 'PLF,Pala,Palla,Пала', 9.3642000, 14.9046000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125532, 'Oum Hadjer', 'Oum Hadjer', 'OUM,Oum Hadjer', 13.2954000, 19.6966000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125533, 'Ngama', 'Ngama', 'Ngama Yakoud', 11.7833300, 17.1666700, 'TD', '2006-01-17', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125534, 'N''Djamena', 'N''Djamena', 'Fort-Lamy,Lamy,N''Djamena,NDJ,Ndjamena,Ndjemena,Ndzamena,Ndzhamena,Ndżamena,Ndžamena,Njameno,Nĵameno,N’Djamena,N’Dj·amèna,Tzamena,Yamena,anjmyna,en jia mei na,eunjamena,ng''mnh,njamena,Τζαμένα,Нджамена,נג''מנה,أنجمينا,ንጃሜና,ンジャメナ,恩賈梅納,은자메나', 12.1067200, 15.0444000, 'TD', '2012-04-13', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125535, 'Moussoro', 'Moussoro', 'Bahr el Ghazal,Moussoro', 13.6414300, 16.4894100, 'TD', '2014-09-05', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125536, 'Moundou', 'Moundou', 'Gorad Mundu,MQQ,Mondou,Mondu,Moundou,Moundu,Mundu,meng du,mun du,mundo~u,mundu,mwndw,Горад Мунду,Мунду,مؤندؤ,มูนดู,ムンドゥ,蒙杜,문두', 8.5666700, 16.0833300, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125537, 'Mongo', 'Mongo', 'MVO,Mongo,Монго', 12.1844100, 18.6930300, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125538, 'Moïssala', 'Moissala', 'Moissaia,Moissala,Moïssala', 8.3404000, 17.7663000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125539, 'Melfi', 'Melfi', 'MEF,Melfi', 11.0598000, 17.9355000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125540, 'Mboursou Léré', 'Mboursou Lere', '', 9.7639000, 14.1539000, 'TD', '2010-11-29', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125541, 'Massenya', 'Massenya', 'Chekna,Massenia,Massenya,Tchekna', 11.4039000, 16.1705000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125542, 'Massakory', 'Massakory', 'Dagana,Massakori,Massakory', 12.9960000, 15.7292700, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125543, 'Massaguet', 'Massaguet', 'Massa Gueit,Massaguet,Massaguete,Massaguette,Massaquet', 12.4755400, 15.4364700, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125544, 'Mao', 'Mao', 'AMO,Mao', 14.1211600, 15.3103000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125545, 'Laï', 'Lai', 'Behagie,Behagle,LTC,Lai,Laï', 9.3972000, 16.3006600, 'TD', '2017-07-16', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125546, 'Kyabé', 'Kyabe', 'Kiyabe,Kiyabi,Kiyabé,Kyabe,Kyabé', 9.4514900, 18.9449300, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125547, 'Koumra', 'Koumra', 'Koumbra,Koumra', 8.9125600, 17.5539200, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125548, 'Kelo', 'Kelo', 'Kel,Kelo,Кел', 9.3085900, 15.8065800, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125549, 'Guelendeng', 'Guelendeng', 'Gelengdeng,Guelendeng,Guelengdeng,Guélengdeng,Gélengdeng', 10.9176200, 15.5501100, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125550, 'Gounou Gaya', 'Gounou Gaya', 'Gounou,Gounou Foursoum,Gounou Gaya', 9.6294000, 15.5132000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125551, 'Goundi', 'Goundi', 'Goundi,Gundi', 9.3626700, 17.3659700, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125552, 'Faya-Largeau', 'Faya-Largeau', 'FYT,Faja Larzo,Faja Laržo,Faja-Larzho,Fajja-Larzho,Faya,Faya Largeau,Faya-Largeau,Largeau,fa ya-la ruo,faya-largyaw,Файя-Ларжо,Фая-Ларжо,فایا-لارگیاو,ファヤ・ラルジョー,法亞-拉若', 17.9257000, 19.1042800, 'TD', '2014-05-29', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125553, 'Dourbali', 'Dourbali', 'Dourbali,Ndourbali', 11.8090900, 15.8632300, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125554, 'Doba', 'Doba', 'Doba,Доба', 8.6500000, 16.8500000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125555, 'Bousso', 'Bousso', 'Bousso,Fort Bretonnet,OUT', 10.4847300, 16.7107600, 'TD', '2013-05-09', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125556, 'Bongor', 'Bongor', 'Bongor,OGR,Бонгор', 10.2805600, 15.3722200, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125557, 'Bol', 'Bol', 'Bol,Bol I,OTC', 13.4586100, 14.7147200, 'TD', '2017-05-30', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125558, 'Bokoro', 'Bokoro', 'BKR,Bokoro', 12.3781300, 17.0587600, 'TD', '2014-06-28', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125559, 'Bitkine', 'Bitkine', 'Bitkin,Bitkine', 11.9801000, 18.2138000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125560, 'Béré', 'Bere', '', 9.3202000, 16.1552000, 'TD', '2006-01-17', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125561, 'Benoy', 'Benoy', 'Benoy,Benoye,Bénoye', 8.9832700, 16.3199100, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125562, 'Beïnamar', 'Beinamar', 'Beinamar,Beïnamar', 8.6698000, 15.3813000, 'TD', '2013-04-04', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125563, 'Béboto', 'Beboto', 'Beboto,Béboto', 8.2668100, 16.9389800, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125564, 'Bébédja', 'Bebedja', 'Bebedja,Bebedjia,Bebeidja,Bebeidjia,Bebiya,Bébédja,Bébédjia', 8.6761000, 16.5660000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125565, 'Bardaï', 'Bardai', 'Bardai,Bardaï', 21.3549400, 17.0012100, 'TD', '2014-09-05', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125566, 'Ati', 'Ati', 'ATV,Ati,Ати', 13.2154000, 18.3353000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125567, 'Aozou', 'Aozou', 'Aozou,Ozu', 21.8375000, 17.4275000, 'TD', '2012-01-18', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125568, 'Am Djarass', 'Am Djarass', 'Am Djarass,Amdjarass', 16.0658900, 22.8430800, 'TD', '2014-09-08', 44);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125569, 'Port-aux-Français', 'Port-aux-Francais', 'Port o Franse,Port o Fransė,Port-o-Franse,Port-o-Franseh,Portofranse,Portofransē,fa lan xi gang,porutofuranse,Порт-о-Франсе,Порт-о-Франсэ,ปอโรฟร็องแซ,ポルトーフランセ,法兰西港', -49.3500000, 70.2166700, 'TF', '2010-08-06', 79);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125498, 'Tshaneni', 'Tshaneni', 'Tahaneni,Tshaneni', -25.9833300, 31.7166700, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125499, 'Siteki', 'Siteki', 'Siteki,Stegi', -26.4500000, 31.9500000, 'SZ', '2016-05-11', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125500, 'Sidvokodvo', 'Sidvokodvo', '', -26.6282000, 31.4202100, 'SZ', '2010-03-20', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125501, 'Piggs Peak', 'Piggs Peak', 'Piggs Peak', -25.9608200, 31.2466600, 'SZ', '2017-01-05', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125502, 'Nsoko', 'Nsoko', 'Nsoka,Nsoko', -27.0333300, 31.9500000, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125503, 'Nhlangano', 'Nhlangano', 'Goedgegun,Nhlangano', -27.1166700, 31.2000000, 'SZ', '2016-05-11', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125504, 'Mhlume', 'Mhlume', 'Mhlume', -26.0333300, 31.8500000, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125505, 'Mhlambanyatsi', 'Mhlambanyatsi', 'Mhlambanyati,Mhlambanyatsi', -26.4500000, 31.0166700, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125506, 'Mbabane', 'Mbabane', 'Embabane,Gorad Mbabaneh,Mabane,Mbaban,Mbabane,Mbabano,Mbabanė,Mbabàn,Mpampane,QMN,ababane,ambabane,ambabany,eumbabane,impapan,mbaban,mbabane,mbabanh,mbabyn,mbbnh,mo ba ben,mubabane,xam ba bane,Μπαμπάνε,Горад Мбабанэ,Мбабане,Մբաբանե,מבאבאנע,מבבנה,امبابانی,مبابان,مبابانه,مبابانێ,مبابین,अंबाबाने,ਅੰਬਾਬਾਨੇ,இம்பபான்,อัมบาบาเน,མ་པ་པན།,მბაბანე,ምባባኔ,ムババーネ,墨巴本,음바바네', -26.3166700, 31.1333300, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125507, 'Manzini', 'Manzini', 'Bremersdorp,MTS,Maneini,Manzini,Manzinis,Manêini,man qi ni,manjini,mnzyny,Μανζίνι,Манзини,Манзіні,מנזיני,マンジニ,曼齐尼,만지니', -26.4988400, 31.3800400, 'SZ', '2013-04-13', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125508, 'Malkerns', 'Malkerns', '', -26.5666700, 31.1833300, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125509, 'Lobamba', 'Lobamba', 'Gorad Labamba,Lobamba,Lobambo,Lobomba,lobamba,luo ban ba,lwbama,lwbamba,lwbmbh,robanba,Горад Лабамба,Лобамба,לובמבה,لوباما,لوبامبا,لۆبامبا,ლობამბა,ロバンバ,洛班巴,로밤바', -26.4666700, 31.2000000, 'SZ', '2010-12-23', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125510, 'Lavumisa', 'Lavumisa', 'Gollel,Lavumisa', -27.3100500, 31.8919800, 'SZ', '2011-08-30', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125511, 'Kwaluseni', 'Kwaluseni', 'Kwaluseni', -26.4833300, 31.3333300, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125512, 'Kubuta', 'Kubuta', 'Kubuta', -26.8833300, 31.4833300, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125513, 'Hluti', 'Hluti', '', -27.2166700, 31.6166700, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125514, 'Hlatikulu', 'Hlatikulu', 'Hlatikulu', -26.9666700, 31.3166700, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125515, 'Darkton', 'Darkton', 'Darkton,Darktown', -26.2333300, 31.0333300, 'SZ', '2012-01-18', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125516, 'Bulembu', 'Bulembu', 'Bulembu,Compound,Emhlembi,Emlembe', -25.9666700, 31.1333300, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125517, 'Big Bend', 'Big Bend', 'Big Bend', -26.8166700, 31.9333300, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125518, 'Bhunya', 'Bhunya', 'Bhunya,Bunya', -26.5500000, 31.0166700, 'SZ', '2013-03-02', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125519, 'Vuvulane', 'Vuvulane', '', -26.0742700, 31.8767200, 'SZ', '2012-05-16', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125520, 'Ntfonjeni', 'Ntfonjeni', '', -25.8265900, 31.3273000, 'SZ', '2014-07-10', 214);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125488, '‘Arīshah', '`Arishah', 'Al `Arishah,Al ‘Arīshah,`Arishah,alʿrysht,العريشة,عريشة,‘Arīshah', 36.2315400, 40.7721400, 'SY', '2013-09-09', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125489, 'Kaff al-Jaa', 'Kaff al-Jaa', 'kaf aljaʿ,كاف الجاع', 35.0863800, 36.2060500, 'SY', '2015-08-05', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125490, '‘Ayn an Nasr', '`Ayn an Nasr', '`Ayn Dat,`Ayn Zata,`Ayn an Nasr,عين النسر,عين دات,عين ظاطا,‘Ayn Dāt,‘Ayn Z̧āţā,‘Ayn an Nasr', 34.8411300, 36.9283700, 'SY', '2012-06-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125491, 'Nāḩiyat as Sab‘ Biyār', 'Nahiyat as Sab` Biyar', 'Nahiyat as Sab` Biyar,Nāḩiyat as Sab‘ Biyār,ناحية السبع بيار', 33.5322800, 38.0081800, 'SY', '2012-01-21', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125492, 'Al Kasrah', 'Al Kasrah', 'Al Kasra,Al Kasrah,Al Kasrā,alksra,alksrt,الكسرا,الكسرة', 35.5674300, 39.9202000, 'SY', '2012-09-07', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125493, 'Al Ḩajar al Aswad', 'Al Hajar al Aswad', 'Al Hajar al Aswad,Al Ḩajar al Aswad,Hajar Aswad,Hajar al Aswad,alhjr alaswd,hjr alaswd,الحجر الأسود,حجر الأسود,Ḩajar al Aswad', 33.4575900, 36.3041900, 'SY', '2016-12-01', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125494, 'Al Manşūrah', 'Al Mansurah', 'Al Mansurah,Al Manşūrah,almnswrt,المنصورة', 35.8391700, 38.7428800, 'SY', '2013-07-08', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125495, 'Bayt Yāshūţ', 'Bayt Yashut', 'Bayt Yashut,Bayt Yāshūţ,byt yashwt,بيت ياشوط', 35.3102500, 36.1152300, 'SY', '2013-09-11', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125496, 'Tremseh', 'Tremseh', 'Al Treimseh,Taramsah,Taramseh,Treimsa,Treimseh,Tremseh,al-Turaymisah', 35.2718100, 36.5039500, 'SY', '2014-11-14', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125497, 'Qenterê', 'Qentere', '', 36.5635000, 36.7284100, 'SY', '2016-09-25', 217);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125591, 'Don Sak', 'Don Sak', 'Amphoe Don Sak,Don Sak,King Amphoe Don Sak,dxnsak,ดอนสัก', 9.3167600, 99.6918400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125592, 'Thung Sai', 'Thung Sai', 'Amphoe Sai Thong Watthana,Ban Thung Sai,King Amphoe Sai Thong Watthana,Thung Sai,thung thray,ทุ่งทราย', 16.3148900, 99.8326700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125593, 'Tham Phannara', 'Tham Phannara', 'Amphoe Tham Phannara,Ban Tham Phan Nara,King Amphoe Tham Phannara,Tham Phannara,tha phrrn ra,ถ้ำพรรณรา', 8.4204500, 99.3951700, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125594, 'Ban Talat Yai', 'Ban Talat Yai', 'Talat Yai,Talat-Jai,Талат-Яи', 7.8848100, 98.4000800, 'TH', '2011-07-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125595, 'Ban Talat Nua', 'Ban Talat Nua', 'Talat-Nua,Талат-Нуа', 7.8848900, 98.3855700, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125596, 'Sam Roi Yot', 'Sam Roi Yot', 'Amphoe Sam Roi Yot,Ban Sam Roi Yot,King Amphoe Sam Roi Yot,Sam Roi Yot,sam rxy yxd,สามร้อยยอด', 12.2708100, 99.8720300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125597, 'Nopphitam', 'Nopphitam', 'Amphoe Nopphitam,Ban Nop,King Amphoe Nopphitam,Nopphitam,nb phi ta,นบพิตำ', 8.7220600, 99.7487800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125598, 'Lam Thap', 'Lam Thap', 'Amphoe Lam Thap,Ban Lam Thap,King Amphoe Lam Thap,Lam Thap,la thab,ลำทับ', 8.0722800, 99.2922500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125599, 'Ban Huai I Huak', 'Ban Huai I Huak', '', 18.0786100, 98.0350000, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125600, 'Phrao', 'Phrao', 'Phrao,phraw,พร้าว', 19.3658600, 99.2018700, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125601, 'Mae Taeng', 'Mae Taeng', 'Mae Taeng,แม่แตง', 19.1171200, 98.9417600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125602, 'Mae Ai', 'Mae Ai', 'Ban Mae Ai Luang,Mae Ai,บ้านแม่อายหลวง,แม่อาย', 20.0288300, 99.2983300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125603, 'Phetchaburi', 'Phetchaburi', 'Amphoe Khlong Krachaeng,Amphoe Muang Phet Buri,Bejraburi,Bhej Buri,Changwat Phet Buri,Moeang Bhejburi,Muang Bheja Buri,Muang Pecha Buri,Muang Petchaboun,Mueang Phetchaburi,Pechaburi,Petchaburi,Phet Buri,Phetchaburi,Pkhetchaburi,meuxng phechrburi,phechrburi,Пхетчабури,เพชรบุรี,เมืองเพชรบุรี', 13.1118900, 99.9446700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125604, 'Mae Chai', 'Mae Chai', 'Amphoe Mae Chai,Ban Mae Chai Tai,Ban Mea Jai Tai,Bān Mea Jāi Tāi,King Amphoe Mae Chai,Mae Chai,Mae Chai Tai,Mechai,Mēchai,แม่ใจ', 19.3459700, 99.8140000, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125605, 'Yan Ta Khao', 'Yan Ta Khao', 'Amphoe Yan Ta Khao,King Amphoe Yan Ta Khao,Yan Ta Khao,yantakhaw,ย่านตาขาว', 7.3862200, 99.6669200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125606, 'Wiang Sa', 'Wiang Sa', 'Amphoe Khlong Tan,Amphoe Wiang Sa,King Amphoe Wiang Sa,Mueang Wiang Sa,Wiang Sa,weiyngsra,เวียงสระ', 8.6358500, 99.3666000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125607, 'Wiang Pa Pao', 'Wiang Pa Pao', 'Amphoe Wiang Pa Pao,Amphoe Wiengpapao,Ban Hua Wiang,Ban Nai Wiang,Ma,Muang Vieng Papao,Wiang Pa Pao,Wiang Pa Rao,Wieng Papa,Wieng Papao,weiyngpapea,เวียงป่าเป้า', 19.3477800, 99.5072200, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125608, 'Wiang Haeng', 'Wiang Haeng', 'Ban Muang Haeng,Ban Wiang Haeng,Heng,Hēng,King Amphoe Wiang Haeng,Maung Haeng,Moeang Heng,Moēang Hēng,Muang Haeng,Mueang Haeng,Wiang Haeng,กิ่งอำเภอเวียงแหง,บ้านเวียงแหง,เมืองแหง', 19.5570000, 98.6425000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125609, 'Wiang Chai', 'Wiang Chai', 'Wiang Chai,weiyngchay,เวียงชัย', 19.8836100, 99.9331400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125610, 'Wat Phleng', 'Wat Phleng', 'Amphoe Wat Phleng,Amphoe Wat Pradu,Ban Rong Wi,King Amphoe Wat Phleng,Rong Wi,Wat Phleng,wadphelng,วัดเพลง', 13.4540700, 99.8863700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125611, 'Wang Wiset', 'Wang Wiset', 'Amphoe Wang Wiset,King Amphoe Wang Wiset,Wang Wiset,วังวิเศษ', 7.7363100, 99.3987000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125612, 'Wang Nuea', 'Wang Nuea', 'Amphoe Wang Nua,Wang Nua,Wang Nuea,wanghenux,วังเหนือ', 19.1467800, 99.6193300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125613, 'U Thong', 'U Thong', 'Amphoe Chorache Sam Phan,Amphoe U-Thong,Ban Tha Phra,Ban U-Thong,U Thong,xuthxng,อู่ทอง', 14.3751400, 99.8922500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125614, 'Umphang', 'Umphang', 'Amphoe Mae Klong,Amphoe Umphang,King Amphoe Umphang,King Um Phang,Umphang,xumphang,อุ้มผาง', 16.0162200, 98.8627000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125615, 'Trang', 'Trang', 'Amphoe Muang Trang,Changwat Trang,TST,Trang,trang,Транг,ตรัง', 7.5563300, 99.6114100, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125616, 'Thung Yai', 'Thung Yai', 'Amphoe Thung Yai,Ban Tha,Ban Tha Yang,King Amphoe Ku Rae,King Amphoe Tha Yang,King Amphoe Thung Song,King Amphoe Yang Thung Song,King Tha Yang,Tha Yang,Thung Sang,Thung Song,Thung Yai,ทุ่งใหญ่', 8.3011900, 99.3661100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125617, 'Thung Tako', 'Thung Tako', 'Amphoe Thung Tako,Ban Thung Takhai,King Amphoe Thung Tako,Thung Tako,thungtako,ทุ่งตะโก', 10.1102200, 99.0830600, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125618, 'Thung Song', 'Thung Song', 'Amphoe Dhung Song,Amphoe Thung Song,Amphoe Tungsong,Ban Chamai,Chamai,Dhung Song,Dhūng Song,Thung Song,Tungsong,thungsng,ทุ่งสง', 8.1645300, 99.6803900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125619, 'Thung Saliam', 'Thung Saliam', 'Amphoe Thung Saliam,Ban Thung Saliam,Ban Thung Salian,Ban Thung Saliyan,Bān Thung Saliyan,Dhungsaliem,Dhungsaliēm,King Amphoe Thung Saliam,Thung Saliam,Thung Salian,thungseliym,ทุ่งเสลี่ยม', 17.3210600, 99.5609200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125620, 'Thong Pha Phum', 'Thong Pha Phum', 'Amphoe Sangkhlaburi,Amphoe Sangkla Buri,Amphoe Songkla Buri,Amphoe Thong Pha Phum,Ban Tha Khanun,Dha Khanun,King Amphoe Sangkhla,King Amphoe Sangkhlaburi,King Amphoe Thong Pha Phum,Sangkhla,Sangkhla Buri,Ta Kanun,Tha Khanun,Thong Pha Phum,thxngphaphumi,ทองผาภูมิ', 14.7434500, 98.6310100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125621, 'Thoen', 'Thoen', 'Amphoe Moeang Theun,Amphoe Moeangthenn,Amphoe Muang Thoen,Amphoe Thoen,Ban Laum Read,Ban Lohm Red,Ban Lom Raet,Lau Raet,Lohm Red,Muang Tern,Muang Teun,Muang Tharn,Muang Thoen,Thoen,thein,เถิน', 17.6128900, 99.2161200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125622, 'Tha Song Yang', 'Tha Song Yang', 'Amphoe Tha Song Yang,Ban Mae Tan,King Amphoe Tha Song Yang,Mae Tan,Metan,Pa-ba-le,Tha Song Yang,To Song Yang,thasxngyang,ท่าสองยาง', 17.2270800, 98.2257200, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125623, 'Tha Sala', 'Tha Sala', 'Amphoe Klai,Amphoe Tha Sala,Ban Tha Sala,Tha Sala,thasala,ท่าศาลา', 8.6673300, 99.9307800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125624, 'Tha Sae', 'Tha Sae', 'Amphoe Tha Sae,Ban Tharsak,King Amphoe Tha Sae,King Tha Sae,Mueang Tha Sae,Tha Sae,ท่าแซะ', 10.6646100, 99.1728100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125625, 'Thap Than', 'Thap Than', 'Amphoe Thap Than,Amphu Tap Tan,Ban Thap Than,Dhapdhan,Nong Kradi,Thap Than,thaphthan,ทัพทัน', 15.4606300, 99.8916600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125626, 'Thap Sakae', 'Thap Sakae', 'Amphoe Thap Sakae,Ban Thap Sakae,Dhab Sake,King Amphoe Thap Sakae,Thap Sakae,ทับสะแก', 11.4996400, 99.6217000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125627, 'Thap Put', 'Thap Put', 'Amphoe Dhab Put,Amphoe Thap Pot,Amphoe Thap Put,Ban Marui,Ban Murui,Ban Thap Put (1),Dhab Pud,Ma-rui,Thap Put,thabpud,ทับปุด', 8.5162500, 98.6397200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125628, 'Tha Phae', 'Tha Phae', 'Amphoe Tha Phae,King Amphoe Tha Phae,Tha Phae,ท่าแพ', 6.7901400, 99.9700500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125629, 'Tha Muang', 'Tha Muang', 'Amphoe Tai,Amphoe Tha Muang,Amphoe Wang Khanai,Ban Tha Muang,Tha Muang,Wang Kanai,Wang Khanai,thamwng,ท่าม่วง', 13.9611800, 99.6412200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125630, 'Tha Maka', 'Tha Maka', 'Amphoe Tha Maka,Tha Maka', 13.9000000, 99.7666700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125631, 'Thalang', 'Thalang', 'Amphoe Moeang Thalang,Amphoe Muang Thalang,Amphoe Thalang,Ban Khian,Ban Takhian,Muang Thalang,Mueang Thalang,Ta Khian,Thalang,Ujong Salang,thlang,ถลาง', 8.0316900, 98.3340800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125632, 'Thai Mueang', 'Thai Mueang', 'Amphoe Dhaihmoeang,Amphoe Thai Muang,Ban Dhai Hmoeang,Ban Thai Muang,Dhai Hmoeang,Tai Muang,Thai Muang,Thai Mueang,thayhemuxng,ท้ายเหมือง', 8.3991400, 98.2606100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125633, 'Tha Chang', 'Tha Chang', 'Amphoe King Tha Chang,Amphoe Tha Chang,Ban Tan Chang,Ban Tha Chang,Dhashang,King Amphoe Chaiya,King Amphoe Dhashang,King Amphoe Tha Chang,King Tha Chang,Tan Chang,Tha Chang,thachang,ท่าฉาง', 9.2641800, 99.1921800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125634, 'Tha Chana', 'Tha Chana', 'Amphoe Tha Chana,Ban Tha Chana,King Amphoe Prasong,King Amphoe Tha Chana,Prasong,Tha Chana,thachna,ท่าชนะ', 9.5720300, 99.1658600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125635, 'Takua Thung', 'Takua Thung', 'Amphoe Takua Thung,Amphoe Takuadhung,Amphoe Takuatung,Ban Krasom,Kasom,Krasome,Ta-Kua Dhung,Takua Tung', 8.3837300, 98.4512300, 'TH', '2008-10-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125636, 'Takua Pa', 'Takua Pa', 'Amphoe Takuapa,Amphoe Talad Yai,Ban Takua Pa,Ban Yan Yao,Kopah,Mong Takuapa,Muang Takoua Pa,Muang Takuapa,Muang Takuk Pa,Muang Taukopah,Möng Takuapa,Takkolam,Takola,Takua Pa,Takuapah,Takuwapa,Taukopa,Taukopah,takawpa,ตะกั่วป่า', 8.8705000, 98.3438300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125637, 'Tak', 'Tak', 'Amphoe Mueang Tak,Baheng,Ban Rahaeng,Ban Raheang,Changwat Tak,Muang Raheng,Muang Tak,Rahaeng,Rahaong,Raheng,TKT,Tak,Takas,Tark,tak,thesbal meuxng tak,ttag,Так,ตาก,เทศบาลเมืองตาก,딱', 16.8696800, 99.1289800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125638, 'Surat Thani', 'Surat Thani', 'Amphoe Ban Don,Amphoe Muang Surat Thani,Ban Dohn,Ban Don,Ban Makham Tia,Ban Makham Tir,Bandaun,Changwat Surat,Changwat Surat Thani,Makham Tia,Mueang Surat Thani,Suras,Surashtradhani,Surat Thani,Surathanis,Surattkhani,Szuratthani,URT,su le ta ni,sulastani,suratotani,thesbal nkhr surasʹdrthani,Сураттхани,סוראט טהאני,سورات تھانی,سورت تھانی,สุราษฎร์ธานี,เทศบาลนครสุราษฎร์ธานี,སུ་ར་ཊི་ཐ་ནི།,スラートターニー,素叻他尼,수랏타니', 9.1401100, 99.3331100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125639, 'Sukhothai', 'Sukhothai', 'Amphoe Muang Sukhothai,Amphoe Mueang Sukhothai,Amphoe Sukhodhai,Amphoe Sukhothai,Ban Thani,Changwat Sukhobhai,Changwat Sukhodhai,Changwat Sukhothai,Muang Soukotai,Muang Sukotai,Sukanthai,Sukauthai,Sukhobhai,Sukhodhai,Sukhothai,Sukhothai Thani,Sukhothaj,Sukhothat,Sukhothaï,Sukkhotaj,Sukkhotkhaj,Sukodhai,Sukotajus,THS,sukhothay,sukotai,Сукхотай,Сукхотхай,สุโขทัย,スコータイ,수코타이', 17.0077800, 99.8230000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125640, 'Suan Phueng', 'Suan Phueng', 'Amphoe Suan Phueng,Ban Suan Phung,King Amphoe Suan Phueng,Suan Phoeng,Suan Phueng,Suan Phung,Suan Pung,swnphung,สวนผึ้ง', 13.5429000, 99.3396100, 'TH', '2013-08-25', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125641, 'Sop Prap', 'Sop Prap', 'Amphoe Sop Prap,Amphu Sopwa,Ban Sob Prap,Ban Sop Prap,Bān Sob Prāp,King Amphoe Sop Prap,Sob Prap,Sobprab,Sobprah,Sop Prap,sbprab,สบปราบ', 17.8805300, 99.3370000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125642, 'Soem Ngam', 'Soem Ngam', 'Amphoe Soem Ngam,King Amphoe Soem Ngam,Soem Ngam,serimngam,เสริมงาม', 18.0650600, 99.2453700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125643, 'Si Sawat', 'Si Sawat', 'Amphoe Si Sawat,Amphu Sri Sawas,Ban Si Sawat,King Amphoe Si Sawat,King Si Sawat,King Srisawat,Si Sawat,Sri Sawas,sriswasdi,ศรีสวัสดิ์', 14.5992200, 99.1140600, 'TH', '2013-02-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125644, 'Si Satchanalai', 'Si Satchanalai', 'Amphoe Si Satchanalai,Hat Siao,Si Satchanalai,srisachnalay,ศรีสัชนาลัย', 17.5169200, 99.7597800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125645, 'Si Samrong', 'Si Samrong', 'Amphoe Khlong Tan,Amphoe Si Samrong,Ban Khlong Tan,Ban Khlong Trang,Ban Klaung Tan,Bān Klaung Tān,Glohngtan,Glōhngtān,Khlaung Tan,Khlong Tan,Si Samrong,srisarong,ศรีสำโรง', 17.1640000, 99.8622200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125646, 'Si Nakhon', 'Si Nakhon', 'Amphoe Si Nakhon,King Amphoe Si Nakhon,Si Nakhon,srinkhr,ศรีนคร', 17.3490700, 99.9856300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125647, 'Sikao', 'Sikao', 'Amphoe Sikao,Ban Sikao,Ban Siko,Sikao,sikea,สิเกา', 7.5715800, 99.3449400, 'TH', '2016-12-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125648, 'Si Banphot', 'Si Banphot', 'Amphoe Si Banphot,King Amphoe Si Banphot,Si Ban Phot,Si Banphot,sri brrpht,ศรีบรรพต', 7.7213600, 99.8843000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125649, 'Sawi', 'Sawi', 'Amphoe Sawi,Ban Na Pho,Mueang Sawi,Sawi,banna phothi,swi,บ้านนาโพธิ์,สวี', 10.2366800, 99.1093800, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125650, 'Sawankhalok', 'Sawankhalok', 'Amphoe Sawankhalok,Ban Wang Mai Kaun,Ban Wang Mai Khon,Changwat Muang Sawarngalok,Changwat Sawankhalok,Muang Savankulok,Muang Sawan Kalok,Muang Sawankalauk,Muang Sawarngalok,Mueang Sawankhalok,Mueang Wang Mai Khon,Sawankalauk,Sawankaloke,Sawankhalok,Sawankhalor,Sawarngalok,Swankalauk,Swankhalok,Wang Mai Kuan,swrrkhlok,สวรรคโลก', 17.3159700, 99.8318600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125651, 'Sawang Arom', 'Sawang Arom', 'Amphoe Sawang Arom,Ban Noen Kao,King Amphoe Sawang Arom,Sawang Aram,Sawang Arom,swangxarmn,สว่างอารมณ์', 15.5839400, 99.8608900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125652, 'Saraphi', 'Saraphi', 'Amphoe Saraphi,Amphoe Yang Noeng,Ban Sarape,Ban Saraphi,Sarabhi,Saraphi,Sārabhi,sarphi,สารภี', 18.7141700, 99.0352800, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125653, 'San Sai', 'San Sai', 'Amphoe San Sai,Amphoe Sanzai,Ban San Sai Hluang,Ban San Sai Luang,Ban Sun Tri Luang,San Sai,San Sai Hluang,San Sai Luang,San Saiv,Sanzaihluang,Sanzāihlūang,santhray,สันทราย', 18.8479200, 99.0450800, 'TH', '2013-05-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125654, 'San Pa Tong', 'San Pa Tong', 'Amphoe San Pa Tong,San Pa Tong,sanpatxng,สันป่าตอง', 18.6282800, 98.8957200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125655, 'San Kamphaeng', 'San Kamphaeng', 'Amphoe San Kamphaeng,Ban San Gampheang,Ban San Kamphaeng,Ban San Kamphaeng Luang,Bān San Gampheang,Kwaeng Mae Om,San Kamphaeng,Sankambheng,Sankambhēng,สันกำแพง', 18.7448600, 99.1195300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125656, 'Sangkhla Buri', 'Sangkhla Buri', 'Amphoe Sangkhla Buri,Amphoe Wang Ka,Ban Wang Ga,Ban Wang Kabon,Ban Wangka,Bān Wang Ga,King Amphoe Sangkhla,King Amphoe Sangkhla Buri,Sang Kla Buri,Sangkhla,Sangkhla Buri,sangkhlaburi,สังขละบุรี', 15.1555300, 98.4536100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125657, 'Samoeng', 'Samoeng', 'Amphoe Samoeng,Ban Samarng Dai,Ban Samoeng Tai,Bān Samarng Dāi,King Amphoe Samoeng,Sameungtai,Sameūngtai,Samoeng,Samoeng Tai,sameing,สะเมิง', 18.8480600, 98.7324200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125658, 'Sam Ngao', 'Sam Ngao', 'Amphoe Sam Ngao,Sam Ngao,samngea,สามเงา', 17.2433100, 99.0225600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125659, 'Sai Yok', 'Sai Yok', 'Amphoe Sai Yok,Ban Wang Pho,King Amphoe Sai Yok,Nam Tok Sai Yok,Sai Yok,thiryokh,ไทรโยค', 14.1189900, 99.1420000, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125660, 'Sai Ngam', 'Sai Ngam', 'Amphoe Sai Ngam,King Amphoe Sai Ngam,Sai Ngam,thirngam,ไทรงาม', 16.4686200, 99.8884300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125661, 'Ron Phibun', 'Ron Phibun', 'Amphoe Ron Phibun,Ban Romphi Bull,Ban Ron Phibun,Raun Phibun,Ron Phibun,Ronipibon,rxnphibuly,ร่อนพิบูลย์', 8.1791100, 99.8542500, 'TH', '2016-11-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125662, 'Ratchaburi', 'Ratchaburi', 'Amphoe Muang Rat Buri,Changwat Rat Buri,Mondhol Rajburi,Muang Rajburi,Muang Ratburi,Mueang Ratchaburi,Rajburi,Rat Buri,Ratchaburi,rachburi,Ратчабури,ราชบุรี', 13.5367100, 99.8171200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125663, 'Ranong', 'Ranong', 'Amphoe Muang Ranong,Changwat Ranong,Muang Ra Nohng,Muang Ranawng,Muang Ranong,Ranaong,Ranaung,Ranawng,Ranohng,Ranong,Renawng,Renong,UNN,ranxng,Ранонг,ระนอง', 9.9658300, 98.6347600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125664, 'Pran Buri', 'Pran Buri', 'Amphoe Pranburi,Ban Pak O Pran,Meuangpran,Muang Pran,Muang Pran Kao,Mueang Pran,Mueang Pran Buri,Pran,Pran Buri,pranburi,ปราณบุรี', 12.3848700, 99.9015700, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125665, 'Prachuap Khiri Khan', 'Prachuap Khiri Khan', 'Changwat Prachuap Khiri Khan,PRACHUAB KHIRI KHAN,Prachuab,Prachuab Girikhan,Prachuab Khirakhanda,Prachuab Kirikan,Prachuap,Prachuap Giri Khan,Prachuap Khiri Khan,Prachuap Kirikan,Prachuapgirikhand,Prachūab Gīrīkhan,pracwbkhirikhanth,ประจวบคีรีขันธ์', 11.8209800, 99.7841000, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125666, 'Plai Phraya', 'Plai Phraya', 'Amphoe Plai Phraya,King Amphoe Plai Phraya,Plai Phraya,playphraya,ปลายพระยา', 8.5327800, 98.8637000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125667, 'Tha Kham', 'Tha Kham', 'Tha Kham,tha kham,thesbal meuxng tha kham,ท่าข้าม,เทศบาลเมืองท่าข้าม', 9.1107200, 99.2320800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125668, 'Phuket', 'Phuket', 'Amphoe Muang Phuket,Bhuket,Changwat Phuket,HKT,Phuket,Phuketas,Pkhuket,Pxuket,Tongka,Tongkah,bu ji shi,fwkyt,phuket,pu ji shi,pukes,pukkes,pukkit,pwqt,tesaban''nakon・puketto,thesbal nkhr phuket,Пхукет,פוקט,فوكيت,پھوکیت,புக்கிட்,ภูเก็ต,เทศบาลนครภูเก็ต,པུ་ཁེཊ་གྲོང་ཁྱེར​།,テーサバーンナコーン・プーケット,布吉市,普吉市,푸껫,푸켓', 7.8905900, 98.3981000, 'TH', '2017-06-29', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125669, 'Phrom Khiri', 'Phrom Khiri', 'Amphoe Phrom Khiri,King Amphoe Phrom Khiri,Phrom Khiri,Phrommakhiri,phrhmkhiri,พรหมคีรี', 8.5233300, 99.8227500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125670, 'Phrasaeng', 'Phrasaeng', 'Amphoe Phra Saeng,Ban Yan Din Daeng,King Amphoe Phrasaeng,Phra Saeng,Phrasaeng,พระแสง', 8.5678100, 99.2475600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125671, 'Phran Kratai', 'Phran Kratai', 'Amphoe Phran Kratai,Ban Phran Gatai,Ban Phran Katai,Ban Pran Kratai,Bhrankratai,Bhrānkratai,Phran Katai,Phran Kratai,phrankratay,พรานกระต่าย', 16.6651100, 99.5889400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125672, 'Photharam', 'Photharam', 'Amphoe Photharam,Amphu Po Ta-ram,Ban Photharam,Bhodharam,Bhōdhārām,Kwaeng Photharam,Photharam,Pkhotkharam,photharam,Пхотхарам,โพธาราม', 13.6923400, 99.8496900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125673, 'Phop Phra', 'Phop Phra', 'Amphoe Phop Phra,Ban Phoe Pha,King Amphoe Phop Phra,Phop Phra,phbphra,พบพระ', 16.3846100, 98.6902800, 'TH', '2013-05-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125674, 'Phipun', 'Phipun', 'Amphoe Phipun,King Amphoe Phipun,Phipun,phipun,พิปูน', 8.5603600, 99.6070300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125675, 'Phayao', 'Phayao', 'Amphoe Moeang Bha Yao,Amphoe Muang Phayao,Amphoe Muang Pra Yao,Amphoe Phayao,Ban Nai Wiang,Bhayao,Changwat Phayao,Moeangbhayao,Muang Phayao,Muang Prao,Muang Prayao,Mueang Chang Wat Pha Yao,Mueang Phayao,Phayao,Pkhajao,Prayao,canghwad phayea,phayea,Пхаяо,จังหวัดพะเยา,พะเยา', 19.1920300, 99.8788300, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125676, 'Phato', 'Phato', 'Amphoe Phato,Ban Tha Sai,King Amphoe Phato,Phato,phatoa,พะโต๊ะ', 9.7908900, 98.7765800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125677, 'Phanom Thuan', 'Phanom Thuan', 'Amphoe Ban Thuan,Amphoe Nuea,Amphoe Phanom Thuan,Ban Thuan,Ban Tuan,Bandhuan,Bāndhūan,Phanom Thuan,phnmthwn,พนมทวน', 14.1303100, 99.6985800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125678, 'Phanom', 'Phanom', 'Amphoe Khlong Cha Un,Amphoe Phak Phanom,Amphoe Phanom,Ban Phanom,King Amphoe Phanom,Phanom,phnm,พนม', 8.8547500, 98.8126700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125679, 'Phang Nga', 'Phang Nga', 'Amphoe Mueang Phangnga,Bhangnga,Changwat Phangnga,Muang Bhang-nga,Muang Pha Nga,Pan Nga,Panga,Phang Nga,Phangnga,Phung Nga,Pkhangnga,Pungah,phangnga,Пхангнга,พังงา', 8.4509100, 98.5298500, 'TH', '2013-11-11', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125680, 'Phan', 'Phan', 'Phan,phan,พาน', 19.5539500, 99.7404500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125681, 'Pathio', 'Pathio', 'Amphoe Padhio,Amphoe Pathio,Amphoe Pathiu,Amphoe Patilieu,Ban Bang Son,Ban Sam,Bang San,Bang Son,Banson,Muang Patiou,Pathio,Pathiu,Patiyu,pathiw,ปะทิว', 10.7090800, 99.3182000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125682, 'Pa Sang', 'Pa Sang', 'Amphoe Pa Sang,Ban Pa Sang,Pa Sang,pasang,ป่าซาง', 18.5261700, 98.9393600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125683, 'Palian', 'Palian', 'Amphoe Palian,Amphoe Yong Sata,Ban Tha Kham,Palian,ban tha kham,paheliyn,บ้านท่าข้าม,ปะเหลียน', 7.1723700, 99.6862400, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125684, 'Pak Tho', 'Pak Tho', 'Amphoe Mae Nam Om,Amphoe Pak Tho,Amphoe Tha Nat Wat Pradu,Ban Pak Tho,Pak Thau,Pak Tho,pakthx,ปากท่อ', 13.3726300, 99.8393800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125685, 'Pai', 'Pai', 'Amphoe Pai,Ban Wiang Tai,Ban Wieng Tai,Muang Pai,PYY,Pai,Wiang Tai,Wieng Tai,Паи', 19.3616800, 98.4397300, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125686, 'Om Koi', 'Om Koi', 'Amphoe Omkoi,Ban Lim,Ban Om Koi,Om Koi,Um Koi,xmkxy,อมก๋อย', 17.8012200, 98.3593300, 'TH', '2016-12-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125687, 'Nong Ya Plong', 'Nong Ya Plong', 'Amphoe Nong Ya Plong,Ban Naung Ya Plaung,King Amphoe Nong Ya Plong,Nong Ya Plong,hnxnghyaplxng,หนองหญ้าปล้อง', 13.1628800, 99.6972300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125688, 'Nong Kha Yang', 'Nong Kha Yang', 'Amphoe Nong Kha Yang,Ban Naung Ka Yang,Ban Nong Kha Yang,Bān Naung Ka Yāng,Hnohngkhayang,Hnōhngkhāyāng,Naung Kha Yang,Nong Kha Yang,Nong Luang,hnxngkhahyang,หนองขาหย่าง', 15.3640000, 99.9293900, 'TH', '2012-10-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125689, 'Nong Chang', 'Nong Chang', 'Amphoe Nong Chang,Ban Naung Chang,Ban Nong Chang,Ban Uthai Kao,Bān Naung Chāng,Hnohngshang,Hnōhngshāng,Naung Chang,Nong Chang,Uthai Kao,hnxngchang,หนองฉาง', 15.3914700, 99.8414700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125690, 'Ngao', 'Ngao', 'Amphoe Moeang Ngao,Amphoe Muang Gao,Amphoe Muang Ngao,Amphoe Ngao,Ban Amphoe Ngao,Ban Hluang Hnoea,Ban Luang Nua,Ban Luang Nuah,Luang Nua,Muang Ngad,Muang Ngao,Muang Ngau,Ngao,ngaw,งาว', 18.7567800, 99.9781400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125691, 'Nakhon Si Thammarat', 'Nakhon Si Thammarat', 'Amphoe Muang Nakhon Si Thammarat,Changwat Nakhon Si Thammarat,Lakawn,Lakon,Ligor,Muang Nagorn Sridharmaraj,Muang Nakawn Sri Tamarat,Mueang Nakhon Si Thammarat,NST,Nagara Sridharmaraj,Nagor Sridhamaraj,Nagorn Sridharmrat,Nagorri Sridharmrat,Nakawn Sitamarat,Nakawn Sritamarat,Nakhaun Si Thammarat,Nakhon Si Tammarat,Nakhon Si Thammarat,Nakhon Si Thammarht,Nakhon Sritamarai,Nakhon Srithamarat,Nakhon Srithamrat,Nakhon Szi Thammarat,Nakhonsithamrat,Nakkhonsitkhammarat,Nakon,Nakon Si Tham Rat,Nakon Sitamarat,Nakon Sri Tammarat,Nakon Sritamaraj,Nakon Sritamarat,Nakorn Si Thamarat,Nakorn Sridamaraja,na kong shi tan ma le,nakonshitanmarato,nakonsitammalas,nkhrsrithrrmrach,thesbal nkhr nkhrsrithrrmrach,Накхонситхаммарат,נאקון סי טמרט,ناکھون سی تھامارات,نکھون سی تھاماراٹ,นครศรีธรรมราช,เทศบาลนครนครศรีธรรมราช,ན་ཁཱོན་སི་ཐམ་མ་ར་ཊི།,ナコーンシータンマラート,那空是贪玛叻,나콘시탐마랏', 8.4333300, 99.9666700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125692, 'Na Bon', 'Na Bon', 'Amphoe Na Bon,Ban Na Bon,King Amphoe Na Bon,Na Baun,Na Bon,nabxn,นาบอน', 8.2616700, 99.5947200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125693, 'Mueang Pan', 'Mueang Pan', 'Muang Pan,Mueang Pan,meuxng pan,เมืองปาน', 18.7680300, 99.5025000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125694, 'Mae Tha', 'Mae Tha', 'Amphoe Mae Tha,Amphu Metar,Ban Mae Tha,Ban Mea Tha,Ban Sala Mae Tha,Bān Mea Tha,King Amphoe Mae Tha,King Mae Tha,Mae Tha,Medha,Mēdha,Sala Mae Tha,Sala Meh Tha,แม่ทา', 18.4645600, 99.1402600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125695, 'Mae Tha', 'Mae Tha', 'Amphoe Mae Tha,Ban Mae Tha,Ban Mea Tha,Ban Meta,Bān Mea Tha,Mae Tha,Medha,Mēdha,แม่ทะ', 18.1341100, 99.5138900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125696, 'Mae Suai', 'Mae Suai', 'Amphoe Mae Suai,Ban Mae Suai,Ban Mea Suai,Ban Mesrewy,Bān Mea Suai,Mae Suai,Mae Suai Muang Pok,Mesuai,Mēsūai,แม่สรวย', 19.6563300, 99.5436700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125697, 'Mae Sot', 'Mae Sot', 'Amphoe Ban Mae Sot,Amphoe Mae Saut,Amphoe Mae Sot,Amphoe Mesoht,Ban Mae Sot,Ban Me Ramat,Ban Me Sohd,Ban Mesod,Branch Amphoe Me Sohd,Branch Amphoe Mē Sōhd,MAQ,Mae Saut,Mae Sord,Mae Sot,Mehsord,Mesod,Mesoht,Mesort,Mēsoht,แม่สอด', 16.7166700, 98.5666700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125698, 'Mae Sai', 'Mae Sai', 'Amphoe Mae Sai,King Amphoe Mae Sai,Mae Sai,แม่สาย', 20.4335300, 99.8761700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125699, 'Mae Ramat', 'Mae Ramat', 'Amphoe Mae Ramat,Ban Mae Ramat,King Amphoe Mae Ramat,Mae Ramat,Meramas,Meramat,Mēramat,Mēramās,Tambon Mae Ramat,แม่ระมาด', 16.9840300, 98.5166500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125700, 'Mae Phrik', 'Mae Phrik', 'Amphoe Mae Phrik,Amphu Me Plick,Ban Mae Phlik,Ban Mae Phrik,Ban Mea Phlik,Bān Mea Phlik,Mae Phlik,Mae Phrik,Mebhlik,Mēbhlik,แม่พริก', 17.4468800, 99.1142000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125701, 'Mae Mo', 'Mae Mo', 'Ban Mae Mo,Ban Mea Mo,Bān Mea Mo,Mae Mo,Mae Moh,แม่เมาะ', 18.2756100, 99.6504500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125702, 'Mae La Noi', 'Mae La Noi', 'Ban Mae La Noi,Ban Mae Na Loi,Ban Melanoy,King Amphoe Mae La Noi,Mae La Noi,Melanoi,Mēlānoi,บ้านแม่ลาน้อย,แม่ลาน้อย', 18.3818100, 97.9437200, 'TH', '2017-07-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125703, 'Mae Hong Son', 'Mae Hong Son', 'Amphoe Muang Mae Hong Son,Ban Me Tau,Ban Muai Tau,Ban Muai To,Ban Muai Toh,Changwat Mae Hong Son,Changwat Me Hohng Sohn,HGN,Haung Saun,Mae Hingsorn,Mae Hong Son,Mae Hung Son,Mae Khong Son,Me Hawng Sawn,Me Hong Sawn,Mea Haung Saun,Mehawnghsawn,Mehkhongson,Mehohngsohn,Mehongsonas,Mehungsong,Muai Tau,maehongson,may hwngh swn,mæhxngsxn,Мае Хонг Сон,Мэхонгсон,مائے ہانگ سن,مائے ہونگ سون,ماي هونغ سون,เทศบาลเมืองแม่ฮ่องสอน,แม่ฮ่องสอน,མའེ་ཧོང་སཱོན།,매홍손', 19.3002900, 97.9685200, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125704, 'Mae Chan', 'Mae Chan', 'Amphoe Chiang Saen,Amphoe Mae Chan,Ban Gasa,Ban Kasa,Ban Mae Chan,Ban Mea Jan,Bān Gāsa,Bān Mea Jan,Chiang Saen,Chieng Sean,Chiengsen,Mae Chan,Mehchan,Pong Hong,Мэчан,แม่จัน', 20.1467500, 99.8525600, 'TH', '2016-01-19', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125705, 'Mae Chaem', 'Mae Chaem', 'Amphoe Mae Chaem,King Amphoe Mae Chaem,Mae Chaem,แม่แจ่ม', 18.4992600, 98.3649400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125706, 'Long', 'Long', 'Amphoe Laung,Amphoe Long,Amphoe Moeang Lohng,Amphoe Muang Long,Ban Huai Au,Ban Huai O,Ban Huai Oh,Huai Au,Huaioh,Hui Oh,Hūaioh,Long,Muang Laung,Muang Long,lxng,ลอง', 18.0742200, 99.8307300, 'TH', '2012-09-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125707, 'Li', 'Li', 'Amphoe Li,Ban Li Nua,Li,Li Hnoea,Linua,Lī Hnoēa,li,ลี้', 17.8026900, 98.9509700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125708, 'La-Un', 'La-Un', 'Amphoe La-un,Ban Laun,Khao Fachi,King Amphoe La-Un,La-Un,La-oun,Laun,Laun Tai,Muang Laun,laxun,ละอุ่น', 10.1164600, 98.7500000, 'TH', '2012-05-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125709, 'Lat Yao', 'Lat Yao', 'Amphoe Lat Yao,Ban Lad Yao,Ban Lat Yao,Ban Lat Yau,Bān Lād Yao,Bān Lāt Yāu,Lat Yao,ladyaw,ลาดยาว', 15.7510000, 99.7892500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125710, 'Lao Khwan', 'Lao Khwan', 'Amphoe Lao Khwan,King Amphoe Lao Khwan,Lao Khwan,leakhway,เลาขวัญ', 14.5952200, 99.7743100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125711, 'Lan Saka', 'Lan Saka', 'Amphoe Lan Saka,Ban Talat Amphoe Lan Saka,King Amphoe Khao Kaeo,King Amphoe Lan Saka,Lan Saka,lan ska,ลานสกา', 8.3709700, 99.8056400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125712, 'Lan Sak', 'Lan Sak', 'Lan Sak,lansak,ลานสัก', 15.4528900, 99.5760600, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125713, 'Lan Krabue', 'Lan Krabue', 'Amphoe Lan Krabue,King Amphoe Lan Krabue,Lan Krabu,Lan Krabue,lan krabux,ลานกระบือ', 16.6000300, 99.8488900, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125714, 'La-ngu', 'La-ngu', 'Amphoe La-ngu,Amphoe Sangu,Ban Pak Langu,Ban Pāk Langu,King Amphoe La-ngu,King Amphoe Langu,La-ngu,Langu,Pak Langu,langu,ละงู', 6.8849200, 99.7883600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125715, 'Lang Suan', 'Lang Suan', 'Amper Khan Ngern,Amphoe Khan Ngoen,Amphoe Khanngeun,Amphoe Lang Suan,Ban Khan Ngoen,Khan Ngden,Khan Ngoen,Lang Suan,Moeang Hlang Suan,Moeang Hlang Sūan,Muang Hlang Suan,Muang Lang Suan,Mueang Lang Suan,hlangswn,หลังสวน', 9.9456100, 99.0784700, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125716, 'Lamphun', 'Lamphun', 'Amphoe Muang Lamphun,Amphoe Mueang Lamphun,Changwat Lamphun,Changwat Muang Lamphun,Lambhun,Lamphun,Lampkhun,Lampoon,Lampun,Muang Lam Poun,Muang Lamphun,Muang Lampun,Mueang Lamphun,laphun,Лампхун,ลำพูน', 18.5805400, 99.0074500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125717, 'Lampang', 'Lampang', 'Amphoe Muang Lampang,Amphoe Mueang Lampang,Changwat Lampang,Changwat Muang Lampang,Changwat Muang Nagorn Lambang,LPT,Lakhon,Lakhon Lampang,Lampang,Lampangas,Muang Lakhon Lampang,Muang Lampang,Muang Nagorn Lambang,Muang Nakon Lampang,Mueang Lampang,Nakawn,Nakawn Lampang,Nakhon Lampang,Nakon Lampang,Nakorn Lampang,lampang,lamppang,lapang,lympyng,thesbal nkhr lapang,Лампанг,لامپانگ,لیمپینگ,ลำปาง,เทศบาลนครลำปาง,ལམ་པང་།,람빵', 18.2923200, 99.4927700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125718, 'Lamae', 'Lamae', 'Amphoe Lamae,King Amphoe Lamae,Lamae,ละแม', 9.7678900, 99.0925600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125719, 'Kui Buri', 'Kui Buri', 'Amphoe Kui Buri,Ban Kui Buri,Ban Kui Kao,Ban Kui Nua,King Amphoe Kui Buri,Kui,Kui Buri,Kui Kao,Kui Nua,Kuwi,Menangkuwi,Meng Kui,Moeang Kui,Muang Gui Gao,Muang Kui,Muang Kui Kao,Muang Kuwi,kuyburi,กุยบุรี', 12.0828300, 99.8543100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125720, 'Kra Buri', 'Kra Buri', 'Amphoe Kra Buri,Ban Nam Choed Yai,Ban Nam Choet Yai,Ban Nam Chut Yai,Ban Nam Jeut Yai,Kra,Kra Buri,Mueang Tra,Nam Choed Yai,Nam Chut,kraburi,กระบุรี', 10.4042900, 98.7726600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125721, 'Krabi', 'Krabi', 'Amphoe Muang Krabi,Amphoe Mueang Krabi,Amphoe Pak Nam,Changwat Krabi,Ghirbi,KBV,Krabi,Krampi,Moeang Kra-bi,Muang Krabi,Mueang Krabi,canghwad krabi,jia mi,kkeulabi,krabi,kraby,meuxng krabi,thesbal meuxng krabi,Κράμπι,Краби,کرابی,กระบี่,จังหวัดกระบี่,เทศบาลเมืองกระบี่,เมืองกระบี่,甲米,끄라비', 8.0725700, 98.9105200, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125722, 'Ko Yao', 'Ko Yao', 'Amphoe Ko Yao,Ban Ko Yao Noi,Ban Yai,King Amphoe Ko Yao,King Ko Yao,Ko Yao,Thai Chang,keaayaw,เกาะยาว', 8.1101300, 98.5923100, 'TH', '2012-06-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125723, 'Kong Ra', 'Kong Ra', 'Amphoe Kong Ra,King Amphoe Kong Ra,Kong Ra,knghra,กงหรา', 7.4027200, 99.9497200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125724, 'Kong Krailat', 'Kong Krailat', 'Amphoe Ban Krai,Amphoe Kong Krai Lat,Ban Gong,Ban Kong,Ban Krai,Ban Krong,Kong,Kong Krailat,Krai,kngkirlas,กงไกรลาศ', 16.9519700, 99.9776900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125725, 'Ko Lanta', 'Ko Lanta', 'Amphoe Kau Lanta,Amphoe Ko Lanta,Amphoe Kohlanta,Ban Go Lanta,Ban Ko Lanta,Ban Ko Lanta Yai,Ban Koh Lanta,Ban Koklanta Yai,Kau Lanta Yai,Ko Lanta Yai,Koh Lanta,Koklanta Yai,Lanta,Lanta Jai,keaalanta,Ланта Яи,เกาะลันตา', 7.5336200, 99.0864700, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125726, 'Ko Kha', 'Ko Kha', 'Amphoe Ko Kha,Ban Go Ka,Ban Ko Kha,Ban Koknar,Bān Go Ka,Kau Kha,Ko Kha,Kohga,keaakha,เกาะคา', 18.1922500, 99.3943300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125727, 'Khura Buri', 'Khura Buri', 'Amphoe Ko Kho Khao,Amphoe Mueang Takua Pa,Amphoe Pak Nam,Khura Buri,King Amphoe Khara Buri,King Amphoe Ko Kho Khao,khuraburi,คุระบุรี', 9.1939700, 98.4151400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125728, 'Khun Yuam', 'Khun Yuam', 'Amphoe Khun Yuam,Ban Khun Yuam,Khun Yuam,Mong Kum Yuam,Möng Kum Yuam,khunywm,ขุนยวม', 18.8295800, 97.9334700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125729, 'Khlong Thom', 'Khlong Thom', 'Amphoe Khlong Phon,Amphoe Khlong Thom,Ban Khlong Thom Tai,Khlaung Thaun,Khlaung Thun Tai,Khlong Thom,Tiwakan Kao,khlxngthxm,คลองท่อม', 7.9375000, 99.1445700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125730, 'Khlong Lan', 'Khlong Lan', 'Amphoe Khlong Lan,Khlong Lan,King Amphoe Khlong Lan,khlxnglan,คลองลาน', 16.2033100, 99.3199700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125731, 'Khlong Khlung', 'Khlong Khlung', 'Amphoe Kanu,Amphoe Khanu,Amphoe Khlong Khlung,Ban Khlong Khlung,Ban Klaung Klung,Ban Klong Klung,Kan,Khanu,Khlaung Khlung,Khlong Khlung,khlxngkhlung,คลองขลุง', 16.2163300, 99.7190600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125732, 'Tha Khanon', 'Tha Khanon', 'Amphoe Dha Khanohn,Amphoe Khiri Rat Nikhom,Amphoe Tha Khanon,Ban Tha Khanon,Dha Khanohn,Dhā Khanōhn,Khiri Rat Nikhom,Khiri Ratthanikhom,King Amphoe Tha Khanon,Mueang Khiri Rat Nikhom,Tah Kanon,Tha Khanaun,Tha Khanon,khirirathnikhm,คีรีรัฐนิคม', 9.0302000, 98.9528600, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125733, 'Khiri Mat', 'Khiri Mat', 'Amphoe Khiri Mat,Khiri Mat,khirimas,คีรีมาศ', 16.8333300, 99.8000000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125734, 'Khian Sa', 'Khian Sa', 'Amphoe Khian Sa,Ban Khian Sa,Khian Sa,King Amphoe Khian Sa,kheiyn sa,เคียนซา', 8.8429500, 99.1985600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125735, 'Khao Yoi', 'Khao Yoi', 'Amphoe Huai Luang,Amphoe Khao Yoi,Khao Yoi,kheayxy,เขาย้อย', 13.2402500, 99.8242800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125736, 'Khao Phanom', 'Khao Phanom', 'Amphoe Khao Phanom,Khao Phanom,King Amphoe Khao Phanom,kheaphnm,เขาพนม', 8.2654900, 99.0512400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125737, 'Khanu Woralaksaburi', 'Khanu Woralaksaburi', 'Amphoe Khanuworalak Buri,Khanu Woralaksaburi,Khanworalak Buri,King Amphoe Khanu Woralaksaburi,ขาณุวรลักษบุรี', 16.0617000, 99.8605800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125738, 'Kathu', 'Kathu', 'Ban Talat Kathu,Kathu,Katu,Tambon Kathu,tabl kathu,Кату,ตำบลกะทู้', 7.9177900, 98.3332200, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125739, 'Kapong', 'Kapong', 'Amphoe Kapong,Ban Kapong,Kapong,Pong,kapng,กะปง', 8.6969700, 98.4091400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125740, 'Kapoe', 'Kapoe', 'Amphoe Kapoe,Kapoe,King Amphoe Kapoe,kapexr,กะเปอร์', 9.5852200, 98.5961100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125741, 'Kantang', 'Kantang', 'Amphoe Kantang,Ban Gantang,Ban Kantang,Gantam,Gantang,Kantang,kantang,Кантанг,กันตัง', 7.4054200, 99.5156100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125742, 'Kanchanadit', 'Kanchanadit', 'Amphoe Kanchanadit,Ban Kanchanadit,Ban Kradae,Ban Kradek,Kanchanadit,Kradek,Mueang Kanchanadit,Thathong,กาญจนดิษฐ์', 9.1661100, 99.4701400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125743, 'Kanchanaburi', 'Kanchanaburi', 'Changwat Kanchanaburi,Kanburi,Kanchana,Kanchanaburi,Kancsanaburi,Kanpuri,Moeang Kanchana Buri,Muang Kanchana Buri,kancanapuri,kanchanaburi,kanchanabwry,kaycnburi,kkanjjanabuli,qnznbwry,thesbal meuxng kaycnburi,Канчанабури,קנצנבורי,کانچانابوری,காஞ்சனபுரி,กาญจนบุรี,เทศบาลเมืองกาญจนบุรี,ཀཱན་ཅ་ན་བུ་རི།,カーンチャナブリー,깐짜나부리', 14.0041200, 99.5483200, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125744, 'Kamphaeng Phet', 'Kamphaeng Phet', 'Amphoe Muang Kamphaeng Phet,Amphoe Mueang Kamphaeng Phet,Changwat Kamphaeng Phet,Changwat Muang Kam Bheng Bhej,Gamphaeng Phet,Gampheang Phet,Kam Baeng Bejr,Kambheng Bhej,Kamphaeng Phet,Meuangkamphayng,Muang Kam Bheng Bhej,Muang Kam Phaeng Phet,Muang Kum Pang Pet,กำแพงเพชร', 16.4834400, 99.5215300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125745, 'Huai Yot', 'Huai Yot', 'Amphoe Huai Yot,Amphoe Khao Khao,Amphoe Khau Khaw,Ban Kao Kau,Ban Khaokao,Ban Nam Phrai,Ban Nem Phrai,Bān Kāo Kāu,Huai Yot,Khao Khao,Khaokao,Khou Khaw,Nam Phrai,ban na phray,hwyyxd,บ้านน้ำพราย,ห้วยยอด', 7.7893700, 99.6346900, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125746, 'Huai Khot', 'Huai Khot', 'Amphoe Huai Khot,Huai Khot,King Amphoe Huai Khot,hwy kht,ห้วยคต', 15.2909500, 99.6166100, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125747, 'Hua Hin', 'Hua Hin', 'Amphoe Hua Hin,Ban Hua Hin,HHQ,Hau Hin,Hua Hin,King Amphoe Ban Hua Hin,King Amphoe Hua Hin,fuwahin,hawhin-pranburi,xaphex hawhin,หัวหิน-ปราณบุรี,อำเภอหัวหิน,フワヒン', 12.5706500, 99.9587600, 'TH', '2014-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125748, 'Hot', 'Hot', 'Amphoe Hoht,Amphoe Hot,Ban Muang Haut,Ban Muang Hawt,Ban Muang Hot,Hohd,Hot,Hōhd,Moeang Hohd,Muang Haut,Muang Hawt,Muang Hot,hxd,ฮอด', 18.1931700, 98.6103900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125749, 'Hang Dong', 'Hang Dong', 'Amphoe Hang Dong,Ban Hang Dong,Hang Dong,Khwaeng Mae Tha Chang,King Amphoe Hang Dong,hangdng,หางดง,แขวงแม่ท่าช้าง', 18.6870300, 98.9193900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125750, 'Hang Chat', 'Hang Chat', 'Amphoe Hang Chat,Ban Hang Sad,Ban Hang Sat,Hang Chat,Hang Chate,Hang Sad,Hang Sat,hangchatr,ห้างฉัตร', 18.3288300, 99.3462100, 'TH', '2012-05-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125751, 'Fang', 'Fang', 'Amphoe Fang,Amphoe Moeang Bhang,Amphoe Moeangfhang,Amphoe Muang Fang,Ban Nai Wiang,Fang,Fhang,Fhāng,Moeang Fhang,Muang Fang,Muang Pang,fang,Фанг,ฝาง', 19.9168900, 99.2145000, 'TH', '2015-03-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125752, 'Dok Kham Tai', 'Dok Kham Tai', 'Amphoe Dok Kham Tai,Ban Dauk Kam Tai,Ban Dauk Kam Tāi,Ban Dok Kham Tai,Dauk Kham Tai,Dok Kham Tai,King Amphoe Dok Kham Tai,ดอกคำใต้', 19.1624200, 99.9934200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125753, 'Doi Tao', 'Doi Tao', 'Ban Doi Tao,Doi Tao,King Amphoe Doi Tao,dxytea,ดอยเต่า', 17.9528600, 98.6845800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125754, 'Dan Chang', 'Dan Chang', 'Amphoe Dan Chang,Dan Chang,King Amphoe Dan Chang,danchang,ด่านช้าง', 14.8418300, 99.6975600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125755, 'Damnoen Saduak', 'Damnoen Saduak', 'Amphoe Damnoen Saduak,Ban Damnoen Saduak,Ban Khlong Damnoen Saduak,Damnoen Saduak,Damnoensaduak,daneinsadwk,Дамноенсадуак,ดำเนินสะดวก', 13.5182500, 99.9546900, 'TH', '2014-08-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125756, 'Chumphon', 'Chumphon', 'Amphoe Muang Chumphon,CJM,Champawn,Changwat Chumphon,Chumphaun,Chumphon,Chumpkhon,Chumpon,Chumporn,Csumphon,Cumphonas,Jumbhorn,Jumbor,Muang Champawn,Muang Choum Pon,Muang Chum Pon,Muang Chumporn,Muang Jum Bhorn,Mueang Chumphon,chumphr,chumpon,thesbal meuxng chumphr,Čumphonas,Чумпхон,چمپھون,ชุมพร,เทศบาลเมืองชุมพร,ཅུམ་ཕཱོན།,춤폰', 10.4957000, 99.1797100, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125757, 'Chom Thong', 'Chom Thong', 'Amphoe Chohm Dhohng,Amphoe Chom Thong,Amphoe Chomtong,Ban Hluang,Ban Luang,Ban Luang Chom Thong,Ban Som-Luang,Chaum Thaung,Chom Thong,Hluang,Jaum Thaung,cxmthxng,จอมทอง', 18.4174200, 98.6742800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125758, 'Chom Bueng', 'Chom Bueng', 'Amphoe Chom Bueng,Amphoe Chom Bung,Ban Chom Bung,Chaum Boeng,Chohm Boeng,Chom Bueng,Chom Bung,King Amphoe Chom Bueng,King Chom Bung,cxmbung,จอมบึง', 13.6200000, 99.5916900, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125759, 'Chiang Rai', 'Chiang Rai', 'Amphoe Chiang Rai,Amphoe Muang Chiang Rai,CEI,Chang Rai,Changwat Chiang Rai,Changwat Muang Chiang Rai,Changwat Muang Jieng Rai,Chiang Rai,Chiangraj,Chiengrai,Ciangrajus,Cziang Raj,Jieng Rai,Muang Chiang Rai,Muang Chieng Rai,Muang Jieng Rai,Mueang Chiang Rai,Propinsi Chiang Rai,Thanh pho Chiang Rai,Thành phố Chiang Rai,Xieng Rai,cheiyngray,chianglai,chienrai,chyang rayy,qing lai,thesbal nkhr cheiyngray,zyʼng rʼy,Čiangrajus,Чианграй,ציאנג ראי,چیانگ رائی,เชียงราย,เทศบาลนครเชียงราย,ཆེང་རཱེ།,チエンラーイ,清萊,치앙라이', 19.9085800, 99.8325000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125760, 'Chiang Mai', 'Chiang Mai', 'Amphoe Muang Chiang Mai,CNX,Changwat Chiang Mai,Chiang Mai,Chiang-Maj,Chiangmai,Chiengmai,Cziang Maj,Kiangmai,Muang Chieng Mai,Muang Jieng Hmai,Mueang Chiang Mai,Xieng Mai,Zimme,Zimmé,chiangmai,chienmai,qing mai,Чианг-Май,צ''אנג מאי,צ''יאנג מאי,เชียงใหม่,แม่ริม เชียงใหม่,チエンマイ,清迈,清邁,치앙마이', 18.7903800, 98.9846800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125761, 'Chiang Dao', 'Chiang Dao', 'Amphoe Ban Chiang Dao,Amphoe Chiang Dao,Amphoe Jieng Dao,Ban Chiang Dao,Chiang Dao,Chieng Dao,Jieng Dao,Muang Chieng Dao,cheiyngdaw,เชียงดาว', 19.3654200, 98.9645300, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125762, 'Chawang', 'Chawang', 'Amphoe Chawang,Ban Chawang,Ban Tambon Chawang,Chawang,chwang,ฉวาง', 8.4261400, 99.5047200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125763, 'Chaiya', 'Chaiya', 'Amphoe Chaiya,Amphoe Moeang Jaiya,Ban Bhum Rieng,Ban Phummariang,Ban Phumrieng,Ban Pum Riang,Ban Pun Riang,Cahaya,Chaija,Chaiya,Jaiya,Muang Chaiya,Muang Chaya,Phum Riang,Pumreang,Pumriang,Srivijaya,chiya,ไชยา', 9.3862500, 99.1986100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125764, 'Chai Buri', 'Chai Buri', 'Amphoe Chai Buri,Chai Buri,King Amphoe Chai Buri,chay buri,ชัยบุรี', 8.4622200, 99.0763100, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125765, 'Chae Hom', 'Chae Hom', 'Amphoe Cha Hom,Amphoe Chae Hom,Amphoe Che Hom,Ban Chae Hom Tai,Ban Che Hom Tai,Ban Jea Hom Dai,Chae Hom,Chai Hom Tai,Che Hom Tai,Muang Wa,แจ้ห่ม', 18.7126700, 99.5575800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125766, 'Cha-am', 'Cha-am', 'Amphoe Cha-am,Amphoe Na Yang,Amphoe Nong Chok,Ban Chaam,Cha-am,Sha-am,chaxa,Ча-ам,ชะอำ', 12.8000000, 99.9666700, 'TH', '2014-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125767, 'Bo Phloi', 'Bo Phloi', 'Amphoe Bo Phloi,Ban Bo Phloi,Bo Phloi,King Bau Phloi,King Bo Phloi,bxphlxy,บ่อพลอย', 14.3251700, 99.5146700, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125768, 'Wiang Nuea', 'Wiang Nuea', 'Ban Hong Wing Nua,Ban Wiang Nua,Hongwing Hnoea,Hōngwing Hnoēa,Wiang Nuea,weiyng henux,เวียงเหนือ', 19.3797200, 98.4464400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125769, 'Wang Chin', 'Wang Chin', 'Amphoe Wang Chin,Ban Wang Bar,Ban Wang Boe,Ban Wang Chin,Bān Wang Bar,King Amphoe Wang Chin,Wang Chin,wang chin,วังชิ้น', 17.8802000, 99.6105000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125770, 'Wang Chao', 'Wang Chao', 'Amphoe Wang Chao,Ban Wang Chao (4),Gosamphi,King Amphoe Wang Chao,Kosambhi,Kosamphi,Muang Gausam Phi,Muang Kosambhi,Muang Kosamphi,Wang Chao,wang cea,วังเจ้า', 16.6744100, 99.2690300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125771, 'Thung Wa', 'Thung Wa', 'Amphoe Thung Wa,Ban Dhunghwa,Ban Thung Wa,Ban Tung Waar,King Amphoe Thung Wa,Thung Wa,thunghwa,ทุ่งหว้า', 7.1095700, 99.7558600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125772, 'Thung Hua Chang', 'Thung Hua Chang', 'Amphoe Thung Hua Chang,Ban Thung Hua Chang,Ban Tung Hua Chang,Dhunghuajang,Dhunghūajāng,King Amphoe Thung Hua Chang,Thung Hua Chang,thunghawchang,ทุ่งหัวช้าง', 18.0030100, 99.0278000, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125773, 'Tha Maka', 'Tha Maka', 'Amphoe Lat Bua Khao,Amphoe Phra Thaen,Amphoe Tha Maka,Ban Tha Maka,Champa Nin,Dhamaka,Dhāmakā,Tha Maka,thamaka,ท่ามะกา', 13.9208100, 99.7655300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125774, 'Ban Tak', 'Ban Tak', 'Amphoe Ban Tak,Ban Tak,Tak,bantak,บ้านตาก', 17.0432500, 99.0812800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125775, 'Ko Samui', 'Ko Samui', 'Amphoe Ko Samui,Amphoe Koh Sa-mui,Amphoe Koksamui,Ban Na Dhaun,Ban Na Thaun,Ban Na Thon,Ban Natawn,Ban Naton,Ban Suan Yang,Ko Samui,Na Thaun,Naton,keaasmuy,เกาะสมุย', 9.5356700, 99.9356700, 'TH', '2014-07-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125776, 'Rawai', 'Rawai', 'Ban Ra Wai,Ban Rawei,Rawai,ra wiy,ราไวย์', 7.7796500, 98.3253200, 'TH', '2010-08-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125777, 'Ban Rai', 'Ban Rai', 'Amphoe Ban Rai,Amphoe Khok Khwai,Ban Rai,banri,บ้านไร่', 15.0841700, 99.5210800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125778, 'Ban Pong', 'Ban Pong', 'Amphoe Ban Pong,Ban Pong,Pan-pong,banpong,Пан-понг,บ้านโป่ง', 13.8162900, 99.8773900, 'TH', '2012-07-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125779, 'Banphot Phisai', 'Banphot Phisai', 'Ambheu Barnbhot,Amphoe Banphot Phisai,Amphoe Banpot Pi Sai,Amphoe Barnbhot Bhi Sai,Ban Banpot Pisai,Ban Hu Gwang,Ban Hu Kwang,Banphot Phisai,Banpot,Barnbhotbhisai,Hu Khwang,ban hukwang,brrphtphisay,บรรพตพิสัย,บ้านหูกวาง', 15.9355800, 99.9812900, 'TH', '2012-07-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125780, 'Ban Phru Nai', 'Ban Phru Nai', 'Ban Cho Pla Lai,Ban Phlu Nai,Ban Phru Nai,Ban Pru Nai,Pru-Nai,Пру-Наи,บ้านพรุใน', 7.9545800, 98.5898900, 'TH', '2012-07-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125781, 'Nuea Khlong', 'Nuea Khlong', 'Amphoe Nuea Khlong,Ban Nua Khlong,King Amphoe Nuea Khlong,Nuea Khlong,henux khlxng,เหนือคลอง', 8.0714300, 98.9993300, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125782, 'Nong Prue', 'Nong Prue', 'Amphoe Nong Prue,Ban Hnong Proe,Ban Nong Pru,King Amphoe Nong Prue,Naung Proe,Nong Prue,hnxng prux,หนองปรือ', 14.6078400, 99.4578300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125783, 'Nong Mamong', 'Nong Mamong', 'Amphoe Nong Mamong,Ban Naung Mamaung,Ban Nong Mamong,Bān Naung Mamaung,King Amphoe Nong Mamong,Nong Mamong,hnxng ma mong,หนองมะโมง', 15.2761300, 99.8664000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125784, 'Noen Kham', 'Noen Kham', 'Amphoe Noen Kham,Ban Noen Kham,King Amphoe Noen Kham,Noen Kham,nein kham,เนินขาม', 14.9501000, 99.9389900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125785, 'Ban Na San', 'Ban Na San', 'Amphoe Ban Na,Ban Na San,Na Sau,Nasan,bannasar,บ้านนาสาร', 8.8003600, 99.3637200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125786, 'Ban Na Doem', 'Ban Na Doem', 'Amphoe Ban Na Doem,Ban Na Doem,King Amphoe Ban Na Doem,bannadeim,บ้านนาเดิม', 8.8836100, 99.3101400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125787, 'Ban Na', 'Ban Na', 'Ban Na,banna,บ้านนา', 17.0171700, 99.7328300, 'TH', '2012-11-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125788, 'Ban Lat', 'Ban Lat', 'Amphoe Ban Lat,Amphoe Tha Chang,Ban Lat,Ban Tha Chang,Dhajang,Dhājāng,Tha Chang,banlad,บ้านลาด', 13.0515000, 99.9170100, 'TH', '2012-05-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125789, 'Ban Laem', 'Ban Laem', 'Amphoe Ban Laem,Ban Laem,Banhlem,Bānhlēm,Khwaeng Khun Chamnan,Khwaeng Phrommasan,Laem,บ้านแหลม', 13.2046800, 99.9795900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125790, 'Ban Ko Kaeo', 'Ban Ko Kaeo', 'Ban Khok Kaeo,Ban Kok Kew,Ko Kaeo,Ko-Kaeo,Ко-Каео,บ้านเกาะแก้ว', 7.9359900, 98.3966400, 'TH', '2011-07-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125791, 'Ban Khao Lak', 'Ban Khao Lak', 'Ban Khao Lak,Ban Kou Lak,Khao Lak,ban khea hlak,khea hlak,บ้านเขาหลัก,เขาหลัก', 8.6150100, 98.2399400, 'TH', '2014-04-15', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125792, 'Ban Kha', 'Ban Kha', 'Amphoe Ban Kha,Ban Kha,Ban Pong Ho,Ban Ponghoh,King Amphoe Ban Kha,Pong Hau,ban kha,บ้านคา', 13.4304700, 99.4096700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125793, 'Kathu', 'Kathu', 'Amphoe Kathu,Ban Gathu,Ban Kathu,Ban Kathu (1),Ban Katu,Bān Gathu,Ka Hu,Kathu,Katu,King Amphoe Kathu,kathu,กะทู้', 7.9090300, 98.3332000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125794, 'Ban Karon', 'Ban Karon', 'Ka Rorn', 7.8476900, 98.2985000, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125795, 'Kaeng Krachan', 'Kaeng Krachan', 'Amphoe Kaeng Krachan,Ban Kaeng Kachan,Ban Kaeng Kalan,Kaeng Krachan,Keng Kachan,King Amphoe Kaeng Krachan,Kēng Kachan,แก่งกระจาน', 12.9074200, 99.6479500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125796, 'Huai Krachao', 'Huai Krachao', 'Amphoe Huai Krachao,Ban Huai Kachao,Ban Huai Krachao,Ban Hui Ka Chao,Huai Kachao,Huai Krachao,King Amphoe Huai Krachao,hwy kracea,ห้วยกระเจา', 14.3275000, 99.6676700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125797, 'Ban Hong', 'Ban Hong', 'Amphoe Ban Hong,Ban Haung,Ban Hong,Bān Haung,King Amphoe Ban Hong,banhong,บ้านโฮ่ง', 18.3308600, 98.8192500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125798, 'Bang Saphan Noi', 'Bang Saphan Noi', 'Amphoe Bang Saphan Noi,Ban Bang Saphan Noi,Ban Bangspanoi,Bang Saphan Noi,Bangsabbannoi,Bāngsabbānnoi,King Amphoe Bang Saphan Noi,bangsaphan nxy,บางสะพานน้อย', 11.0753500, 99.4415200, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125799, 'Bang Saphan', 'Bang Saphan', 'Amphoe Bang Saphan,Amphu Bangspan,Ban Bang Saphan Yai,Bang Saphan Yai,Bangsabhan', 11.2125900, 99.5116700, 'TH', '2008-10-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125800, 'Bang Phae', 'Bang Phae', 'Amphoe Bang Phae,Amphoe Hua Pho,Amphoe Lam Phraya,Ban Bang Phae,Ban Bang Phae Tai,Bang Phae,Bang Phae Tai,Tha Rap,บางแพ', 13.6915700, 99.9298200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125801, 'Bang Khon Thi', 'Bang Khon Thi', 'Amphoe Bang Khon Thi,Amphoe Si Muen,Ban Bang Khonthi,Bang Khon Thi,Banggondhi,Bānggondhi,bangkhnthi,บางคนที', 13.4690600, 99.9402100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125802, 'Bang Khan', 'Bang Khan', 'Amphoe Bang Khan,Bang Khan,King Amphoe Bang Khan,bang khan,บางขัน', 8.0268900, 99.4737200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125803, 'Don Tum', 'Don Tum', 'Amphoe Don Tum,Ban Don Tum,Don Tum,King Amphoe Don Tum,dxntum,ดอนตูม', 13.9609000, 100.0788800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125804, 'Doi Lo', 'Doi Lo', 'Amphoe Doi Lo,Ban Doi Lau,Ban Doi Lo,Bān Doi Lau,Doi Lo,King Amphoe Doi Lo,dxy hlx,ดอยหล่อ', 18.4609800, 98.7776700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125805, 'Dan Makham Tia', 'Dan Makham Tia', 'Amphoe Dan Makham Tia,Ban Dan Makham Tia,Ban Nong Makham Tia,Dan Makham Tia,King Amphoe Dan Makham Tia,dan makham teiy,ด่านมะขามเตี้ย', 13.8533900, 99.4104200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125806, 'Ban Dan Lan Hoi', 'Ban Dan Lan Hoi', 'Amphoe Ban Dan Lan Hoi,Ban Dan Lan Hoi,King Amphoe Ban Dan Lan Hoi,bandanlanhxy,บ้านด่านลานหอย', 17.0068300, 99.5749700, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125807, 'Ban Ao Nang', 'Ban Ao Nang', 'Ao Nang,Ao-Nang,Ао-Нанг', 8.0458000, 98.8103500, 'TH', '2014-06-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125808, 'Ao Luek', 'Ao Luek', 'Amphoe Ao Luek,Amphoe Ao Luk,Ao Loek,Ao Loek Tai,Ao Luek,Ao Luk,Ban Ao Luk Tai,Ban Auluek,xawluk,อ่าวลึก', 8.3780300, 98.7211700, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125809, 'Amphawa', 'Amphawa', 'Ambhawa,Amphawa,Amphoe Amphawa,Ban Amphawa,Khwaeng Bang Chang,xamphwa,อัมพวา', 13.4243600, 99.9568800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125810, 'Sa Bot', 'Sa Bot', 'Amphoe Sa Bot,Ban Sa Bot,King Amphoe Sa Bot,Sa Bot,Sabost,sra bosth,สระโบสถ์', 15.2100600, 100.8307600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125811, 'Phatthana Nikhom', 'Phatthana Nikhom', 'Amphoe Phatthana Nikhom,King Amphoe Phatthana Nikhom,Phatthana Nikhom,พัฒนานิคม', 14.8564700, 100.9845900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125812, 'Nong Kung Si', 'Nong Kung Si', '', 16.6500000, 103.3000000, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125813, 'Na Dun', 'Na Dun', 'Amphoe Na Dun,King Amphoe Na Dun,Na Dun,nadun,นาดูน', 15.7166800, 103.2278100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125814, 'Ko Pha-Ngan', 'Ko Pha-Ngan', 'Amphoe Ko Pha Ngan,Amphoe Ko Pha-ngan,Ko Pha-Ngan,Ko Phangan,keaaphangan,เกาะพะงัน', 9.7194500, 99.9951100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125815, 'Yang Si Surat', 'Yang Si Surat', 'Amphoe Yang Si Surat,Ban Yang Si Surat,King Amphoe Yang Si Surat,Yang Si Surat,yang si su rach,ยางสีสุราช', 15.6836100, 103.1031100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125816, 'Mueang Yang', 'Mueang Yang', 'Amphoe Mueang Yang,Ban Yang,King Amphoe Mueang Yang,Mueang Yang,meuxng yang,เมืองยาง', 15.4206000, 102.8928200, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125817, 'Siao', 'Siao', 'Amphoe Benchalak,Ban Siao,Ban Sieo,Benchalak,King Amphoe Benchalak,Siao,ban seiyw,seiyw,บ้านเสียว,เบญจลักษ์,เสียว', 14.7958300, 104.6701700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125818, 'Samran', 'Samran', 'Amphoe Sam Chai,Ban Samran,King Amphoe Sam Chai,Sam Chai,Samran,saray,สำราญ', 16.8632200, 103.5410600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125819, 'Thepharak', 'Thepharak', 'Amphoe Thepharak,Ban Samnak Takhro,Ban Takhro,Ban Thepharak,King Amphoe Thepharak,Samnak Takhrau,Samnak Takhro,Thepharak,เทพารักษ์', 15.3086800, 101.5504500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125820, 'Sak Lek', 'Sak Lek', 'Amphoe Sak Lek,Ban Sak Lek,King Amphoe Sak Lek,Sak Lek,sak helk,สากเหล็ก', 16.5052800, 100.4710300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125821, 'Phayu', 'Phayu', 'Amphoe Phayu,Ban Phayu,King Amphoe Phayu,Phayu,phyuh,พยุห์', 14.9085100, 104.3910100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125822, 'Pha Khao', 'Pha Khao', 'Amphoe Pha Khao,Ban Pha Khao,King Amphoe Pha Khao,Pha Khao,pha khaw,ผาขาว', 17.0650700, 102.0296500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125823, 'Non Suwan', 'Non Suwan', 'Amphoe Non Suwan,Ban Non Suwan,King Amphoe Non Suwan,Non Suwan,non suwrrn,โนนสุวรรณ', 14.5804400, 102.5968900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125824, 'Ban Nong Wua So', 'Ban Nong Wua So', '', 17.2675000, 103.2247200, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125825, 'Nong Wua So', 'Nong Wua So', 'Amphoe Nong Wua So,Ban Nong Wua So,King Amphoe Nong Wua So,Nong Wua So,hnxngwawsx,หนองวัวซอ', 17.1626100, 102.5727200, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125826, 'Nong Na Kham', 'Nong Na Kham', 'Amphoe Nong Na Kham,Ban Nong Na Kham,King Amphoe Nong Na Kham,Nong Na Kham,hnxng na kha,หนองนาคำ', 16.8043000, 102.3364700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125827, 'Nong Muang', 'Nong Muang', 'Amphoe Nong Muang,Ban Nong Muang,King Amphoe Nong Muang,Nong Muang,hnxng mwng,หนองม่วง', 15.2459200, 100.6555600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125828, 'Nong Hin', 'Nong Hin', 'Amphoe Nong Hin,Ban Nong Hin,King Amphoe Nong Hin,Nong Hin,hnxng hin,หนองหิน', 17.1235600, 101.8578900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125829, 'Nong Hi', 'Nong Hi', 'Amphoe Nong Hi,Ban Nong Hi,King Amphoe Nong Hi,Nong Hi,hn xnghi,หนองฮี', 15.6111700, 103.9948400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125830, 'Na Yung', 'Na Yung', 'Amphoe Na Yung,Ban Na Yung,King Amphoe Na Yung,Na Yung,na yung,นายูง', 17.8974700, 102.1498100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125831, 'Na Tan', 'Na Tan', 'Amphoe Na Tan,Ban Na Tan,King Amphoe Na Tan,Na Tan,na tal,นาตาล', 15.8974900, 105.2931800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125832, 'Ban Nam Yuen', 'Ban Nam Yuen', 'Ban Nam Yuen,ban nayun,บ้านน้ำยืน', 9.8768600, 98.8659200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125833, 'Na Mom', 'Na Mom', 'Amphoe Na Mom,Ban Na Mom,Ban Na Muang,King Amphoe Na Mom,Na Mom,Tambon Thung Phra Khian,banna hmxm,na hmxm,นาหม่อม,บ้านนาหม่อม', 6.9585600, 100.5568300, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125834, 'Mueang Chan', 'Mueang Chan', 'Amphoe Mueang Chan,Ban Muang Chan,King Amphoe Mueang Chan,Mueang Chan,meuxng canthr,เมืองจันทร์', 15.1595100, 104.0361500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125835, 'Ban Mai', 'Ban Mai', 'Ban Mai,บ้านใหม่', 7.2041100, 100.5450800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125836, 'Lam Sonthi', 'Lam Sonthi', 'Amphoe Lam Sonthi,Ban Lam Sonthi,King Amphoe Lam Sonthi,Lam Sonthi,la snthi,ลำสนธิ', 15.3015400, 101.3636500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125837, 'Ban Huai Thalaeng', 'Ban Huai Thalaeng', '', 14.9833300, 102.6500000, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125838, 'Huai Rat', 'Huai Rat', 'Amphoe Huai Rat,Ban Huai Rat,Huai Rat,King Amphoe Huai Rat,hwy rach,ห้วยราช', 14.9603900, 103.1891100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125839, 'Ban Haet', 'Ban Haet', 'Amphoe Ban Haet,Ban Haet,King Amphoe Ban Haet,บ้านแฮด', 16.1964800, 102.7595900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125840, 'Fao Rai', 'Fao Rai', 'Amphoe Fao Rai,Ban Fao Rai,Fao Rai,King Amphoe Fao Rai,fea ri,เฝ้าไร่', 18.0179100, 103.3038800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125841, 'Ban Dan', 'Ban Dan', 'Amphoe Ban Dan,Ban Dan,King Amphoe Ban Dan,bandan,บ้านด่าน', 15.1083900, 103.1755100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125842, 'Charoen Sin', 'Charoen Sin', 'Amphoe Charoen Sin,Ban Charoen Sin,Charoen Sin,King Amphoe Charoen Sin,ceriysilp,เจริญศิลป์', 17.5792500, 103.5403300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125843, 'Ban Khlong Bang Sao Thong', 'Ban Khlong Bang Sao Thong', 'Ban Bang Sao Thong,Ban Khlong Bang Sao Thong,ban khlxng bangseathng,บ้านคลองบางเสาธง', 13.6417200, 100.8327200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125844, 'Waeng', 'Waeng', 'Amphoe Waeng,King Amphoe Waeng,Waeng,แว้ง', 5.9280000, 101.8838200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125845, 'Thepha', 'Thepha', 'Thepha,Tiba,thepha,เทพา', 6.8293600, 100.9643100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125846, 'Tak Fa', 'Tak Fa', 'Tak Fa,takfa,ตากฟ้า', 15.3491700, 100.4952200, 'TH', '2016-11-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125847, 'Prakhon Chai', 'Prakhon Chai', 'Prakhon Chai,prakhon chay,ประโคนชัย', 14.6107300, 103.0792300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125848, 'Na Klang', 'Na Klang', 'Na Klang,naklang,นากลาง', 17.3072000, 102.1888600, 'TH', '2010-08-13', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125849, 'Bacho', 'Bacho', 'Amphoe Ba Cho,Ba Cho,Bacho,King Amphoe Bacho,baceaa,บาเจาะ', 6.5167800, 101.6510000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125850, 'Yi-ngo', 'Yi-ngo', 'Amphoe Yingo,Ban Yi-ngo,Ban Yigo,Ban Yingau,Ban Yingo,Jingo,Yi-Ngau,Yi-ngo,ban yingx,yingx,บ้านยี่งอ,ยี่งอ', 6.4029700, 101.7062500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125851, 'Yasothon', 'Yasothon', 'Amphoe Muang Yasothon,Amphoe Yasodhom,Amphoe Yasodhorn,Amphoe Yasothon,Ban Nai Muang,Ban Singh Tha,Changwat Yasothon,Jasotkhon,Muang Iott-so Ton,Muang Yasothaun,Muang Yasothon,Mueang Yasothon,Yasodhorn,Yasotawn,Yasothon,Yasotorn,ysothr,Ясотхон,ยโสธร', 15.7940800, 104.1451000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125852, 'Yaring', 'Yaring', 'Amphoe Yamu,Amphoe Yaring,Ban Yamu,Jaring,Muang Yaring,Muang Yering,Yamu,Yaring,yahring,ยะหริ่ง', 6.8661700, 101.3689400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125853, 'Yan Nawa', 'Yan Nawa', 'Yan Nava,Yan Nawa,yannawa,ยานนาวา', 13.6963400, 100.5421200, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125854, 'Yang Talat', 'Yang Talat', 'Amphoe Ban Bang Talat,Amphoe Ban Yang Talat,Amphoe Yangtalat,Ban Bang Talat,Ban Yang Talat,Bang Talat,Koulan Tiane,Muang Koulan Tiane,Muang Kulan Tiane,Muang Phu Laen Chang,Yang Talat,yangtlad,ยางตลาด', 16.3998200, 103.3678500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125855, 'Yang Chum Noi', 'Yang Chum Noi', 'Amphoe Yang Chum Noi,Ban Yang Chum Noi,King Amphoe Yang Chum Noi,Yang Chum Noi,yangchumnxy,ยางชุมน้อย', 15.2645300, 104.3976900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125856, 'Yarang', 'Yarang', 'Amphoe Yarang,Kampong Naeraning,King Amphoe Yarang,Na Rang,Yanang,Yarang,yarang,ยะรัง', 6.7598600, 101.2933900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125857, 'Yala', 'Yala', 'Amphoe Mueang Yala,Amphoe Yala,Ban Yala,Changwat Yala,Jala,Muang Yala,Mueang Yala,Yala,yala,Яла,ยะลา', 6.5399500, 101.2812800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125858, 'Yaha', 'Yaha', 'Amphoe Yaha,Ban Yaha,Yaha,yaha,ยะหา', 6.4797000, 101.1320000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125859, 'Wiset Chaichan', 'Wiset Chaichan', 'Amphoe Phai Cham Sin,Amphoe Wiset Chai Chan,Wises Jai-jan,Wises Jai-jān,Wiset Chai Chan,Wiset Chaichan,วิเศษชัยชาญ', 14.5945000, 100.3382500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125860, 'Wihan Daeng', 'Wihan Daeng', 'Amphoe Wihan Daeng,Ban Nong Pho (2),King Amphoe Nong Mu,Nong Mu,Wihan Daeng,วิหารแดง', 14.3458600, 100.9894200, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125861, 'Wichian Buri', 'Wichian Buri', 'Amphoe Tha Rong,Amphoe Wichian,Amphoe Wichian Buri,Amphoe Wijiern,Ban Wichian,Tha Rong,Wi-jiern,Wi-jiērn,Wichian,Wichian Buri,wicheiyrburi,วิเชียรบุรี', 15.6577800, 101.1060300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125862, 'Wiang Sa', 'Wiang Sa', 'Amphoe Sa,Sa,Wiang Sa,weiyng sa,เวียงสา', 18.5985600, 100.7410300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125863, 'Watthana Nakhon', 'Watthana Nakhon', 'Amphoe Watthana Nakhon,Ban Wathana Nakhon,Ban Watthana Nakhon,King Amphoe Watthana Nakhon,Wadhana,Watana,Watana Nakhaun,Watthana,Watthana Nakhon,Whatthana Na Khom,วัฒนานคร', 13.7446200, 102.3186300, 'TH', '2016-11-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125864, 'Wat Sing', 'Wat Sing', 'Amphoe Wat Sing,Ban Wat Sing,Wad Sing,Wat Sing,wadsingh,วัดสิงห์', 15.2598700, 100.0404000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125865, 'Wat Bot', 'Wat Bot', 'Amphoe Wat Bot,King Amphoe Wat Bot,Wat Bot,wadbosth,วัดโบสถ์', 16.9811400, 100.3319500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125866, 'Warin Chamrap', 'Warin Chamrap', 'Amphoe Thaksin Ubon,Amphoe Warin Chamrap,Amphoe Warinjamrap,Ban That,Varindra,Warim Chamrap,Warin Chamrap,warincharab,วารินชำราบ', 15.1931900, 104.8628000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125867, 'Warichaphum', 'Warichaphum', 'Amphoe Waritchaphum,Ban Muang Waritchaphum,King Amphoe Barijabhum,King Amphoe Waritchaphum,King Waritchaphum,Muang Ouarit Poum,Muang Uarit Pom,Muang Waritchaphum,Ouarit Poum,Warichaphum,Waritchaphum,warichphumi,วาริชภูมิ', 17.2940900, 103.6381600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125868, 'Wapi Pathum', 'Wapi Pathum', 'Amphoe Muang Wapi Pathum,Amphoe Muang Wapipthum,Amphoe Wapi Pathum,Ban Nong Saeng,Muang Wapi Pathum,Muang Wapi Pra Tum,Muang Wapipthum,Mueang Wapi Pathum,Mung Vapi Phia Thum,Muong Vapi Phia Thoum,Naung Saeng,Wapi,Wapi Pathum,Wapi Pradhum,wapipthum,วาปีปทุม', 15.8452300, 103.3767800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125869, 'Wan Yai', 'Wan Yai', 'Amphoe Wan Yai,King Amphoe Wan Yai,Wan Yai,หว้านใหญ่', 16.7222900, 104.7413500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125870, 'Wanon Niwat', 'Wanon Niwat', 'Amphoe Wanon Niwat,Ban Wanon Niwat,Mong Wanon Niwas,Möng Wanon Niwas,Wanon Niwat,wanrniwas,วานรนิวาส', 17.6339100, 103.7524100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125871, 'Wang Thong', 'Wang Thong', 'Amphoe Wang Thong,Ban Wang Thaung,Bān Wang Thaung,Nakhon Pa Mak,Pa Mak,Pahmak,Pāhmāk,Wang Thaung,Wang Thong,wangthxng,วังทอง', 16.8245800, 100.4293600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125872, 'Wang Saphung', 'Wang Saphung', 'Amphoe Wang Saphung,Ban Wang Sa Pung,Ban Wang San Phung,Ban Wang Saphung,Khwaeng Wang Saphung,Wang Saphung,Wangsabhung,wangsaphung,วังสะพุง', 17.3009700, 101.7685000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125873, 'Wang Sam Mo', 'Wang Sam Mo', 'Amphoe Wang Sam Mo,King Amphoe Wang Sam Mo,Wang Sam Mo,wangsamhmx,วังสามหมอ', 16.9529400, 103.4365000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125874, 'Wang Noi', 'Wang Noi', 'Amphoe Uthai Noi,Amphoe Wang Noi,Ban Bang Pla Kot Noi,Ban Wang Noi,Wang Noi,wangnxy,วังน้อย', 14.2268900, 100.7155000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125875, 'Wang Nam Yen', 'Wang Nam Yen', 'Amphoe Wang Nam Yen,King Amphoe Wang Nam Yen,Wang Nam Yen,wangnayen,วังน้ำเย็น', 13.5032500, 102.1811500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125876, 'Wang Hin', 'Wang Hin', 'Amphoe Wang Hin,King Amphoe Wang Hin,Wang Hin,wang hin,วังหิน', 14.9478300, 104.2309700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125877, 'Wang Chan', 'Wang Chan', 'Amphoe Wang Chan,King Amphoe Wang Chan,Wang Chan,wang canthr,วังจันทร์', 12.9364600, 101.5230300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125878, 'Wang Sai Phun', 'Wang Sai Phun', 'Amphoe Wang Sai Phun,King Amphoe Wang Sai Phun,Wamg Sai Phun,Wang Sai Phun,wangthrayphun,วังทรายพูน', 16.3885000, 100.5380100, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125879, 'Waeng Yai', 'Waeng Yai', 'Amphoe Waeng Yai,King Amphoe Waeng Yai,Waeng Yai,แวงใหญ่', 15.9554700, 102.5469000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125880, 'Waeng Noi', 'Waeng Noi', 'Amphoe Waeng Noi,King Amphoe Waeng Noi,Waeng Noi,แวงน้อย', 15.8035000, 102.4161400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125881, 'Uttaradit', 'Uttaradit', 'Amphoe Mueang Uttaradit,Changwat Muang Utaradith,Changwat Uttaradit,Muang Utaradit,Muang Utaradith,Outaradit,UTR,Utaradit,Utaraditas,Utaraditra,Uttaradit,Uttradit,cheng yi,thesbal meuxng xutrditth,uttaladis,xutrditth,Уттарадит,اٹاراڈٹ,อุตรดิตถ์,เทศบาลเมืองอุตรดิตถ์,程逸,우따라딧', 17.6255700, 100.0942100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125882, 'Uthumphon Phisai', 'Uthumphon Phisai', 'Amphoe Phachim Sisaket,Amphoe Udhumbhornbhisai,Amphoe Uthumphon Phisai,Ban Samrong Yai,Ban Tamyae,Ban Tha Mai,Mueang Uthumphon Phisai,Samrong Yai,Uthom Phon Phisai,Uthumphon Phisai,xuthumphrphisay,อุทุมพรพิสัย', 15.1116100, 104.1401100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125883, 'Uthai Thani', 'Uthai Thani', 'Amphoe Nam Sum,Ban Nam Sum,Changwat Muang Uthai Thani,Changwat Uthai Thani,Muang Udhai Dhani,Muang Utai Tani,Muang Uthai Thani,Mueang Uthai Thani,Udhaidhani,Uthai Thani,xuthaythani,อุทัยธานี', 15.3793900, 100.0245000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125884, 'Uthai', 'Uthai', 'Amphoe U Thai,Amphoe Uthai Yai,Ban Utai,Ban Uthai,Udhai,Uthai,xuthay,อุทัย', 14.3627800, 100.6720300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125885, 'Udon Thani', 'Udon Thani', 'Ban Dua Makeng,Ban Ma Keng,Ban Mak Khaeng,Bar Deua Ma Khong,Changwat Udaunthani,Changwat Udon Thani,Mak Khaeng,Mueang Udon Thani,UTH,Udaun Thani,Udon,Udon Tani,Udon Thani,Udonthani,Udonthanis,Udontkhani,Udorn,Udorndhani,Udornthani,thesbal nkhr xudrthani,udontani,wdwn tany,wu long ta ni,xudrthani,Удон Тани,Удонтхани,אודון תאני,اودون تھانی,ودون تاني,อุดรธานี,เทศบาลนครอุดรธานี,ཨུ་ཌོན་ཐ་ནི།,テーサバーンナコーン・ウドーンターニー,乌隆他尼,우돈타니', 17.4156700, 102.7858900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125886, 'Ubon Ratchathani', 'Ubon Ratchathani', 'Changwat Muang Ubon,Changwat Ubon Ratchathani,Muang Ubol,Muang Ubon,Muang Ubon Ratcha-Thani,Muang Ubun,Mueang Ubon Ratchathani,Oubon,UBP,Ubol,Ubol Rachatani,Ubol Rajadhani,Ubolrajdhani,Ubon,Ubon Rachatani,Ubon Rachpani,Ubon Ratchathani,Ubon Ratczathani,Ubonrajathani,Ubonrajdhani,Ubonrajthani,Ubonratcathanis,Ubonratčathanis,awbwn ratshathany,tesaban''nakon・ubonrachatani,thesbal nkhr xublrachthani,ubonlaschatani,wu wen le cha ta ni,xublrachthani,ywbwn ratchatany,Убон Рачатані,أوبون راتشاثاني,ابون راتچاتھانی,اوبون راٹچاتھانی,یوبون راتچاتانی,อุบลราชธานี,เทศบาลนครอุบลราชธานี,ཨུ་བཱོན་ར་ཊི་ཅ་ཐ་ནི།,テーサバーンナコーン・ウボンラーチャターニー,乌汶叻差他尼,우본랏차타니', 15.2384400, 104.8486600, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125887, 'Khuean Ubonrat', 'Khuean Ubonrat', 'Amphoe Ubolratana,Khuean Ubonrat,King Amphoe Ubolratana,Ubolratana,Ubonrat,Ubonrathana,kheuxn xublratn,xublratn,อุบลรัตน์,เขื่อนอุบลรัตน์', 16.7526900, 102.6324500, 'TH', '2014-04-29', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125888, 'Tron', 'Tron', 'Amphoe Tron,Ban Geang,Ban Kaeng,Keng,Kēng,Mong Trawn,Möng Trawn,Traun,Tron,trxn,ตรอน', 17.4818100, 100.1128100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125889, 'Trat', 'Trat', 'Ban Bang Phra,Ban Prah,Bang Phra,Changwat Trat,Krat,Muang Krat,TDX,Trad,Trat,Трат', 12.2436400, 102.5151400, 'TH', '2010-01-29', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125890, 'Trakan Phut Phon', 'Trakan Phut Phon', 'Amphoe Khulu,Amphoe Phana Nikhon,Amphoe Trakan Phut Phon,Mueang Phana Nikhon,Trakan Phuetphon,Trakan Phut Phon,trakarphuchphl,ตระการพืชผล', 15.6118300, 105.0214700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125570, 'Vogan', 'Vogan', 'Voga,Vogan,Woga,Wogan,Воган', 6.3333300, 1.5333300, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125571, 'Tsévié', 'Tsevie', 'Tsevie,Tsevye,Tsévié,Tsévyé,Tzevie', 6.4261100, 1.2133300, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125572, 'Tchamba', 'Tchamba', 'Kouboni,Kuboni,Tchamba', 9.0333300, 1.4166700, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125573, 'Tabligbo', 'Tabligbo', 'Awesi,Awési,Tabligbo,Tablizhbo,Таблигбо', 6.5833300, 1.5000000, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125574, 'Sotouboua', 'Sotouboua', 'Sotouboua', 8.5634000, 0.9839900, 'TG', '2013-01-10', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125575, 'Sokodé', 'Sokode', 'Sokode,Sokodé,Sokodė,Sokonte,sokode,suo ke de,Σοκοντέ,Сокоде,سوکودے,ソコデ,索科德,소코데', 8.9833300, 1.1333300, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125576, 'Notsé', 'Notse', 'Notse,Notsé,Nouatja,Nuatia,Nuatja,Nuatya', 6.9500000, 1.1666700, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125577, 'Niamtougou', 'Niamtougou', 'LRL,Niamtougou,Niamtugu,Niamtuu,Njamtuu,Njamtūu,Nyamtouhou,Ниамтугу', 9.7680600, 1.1052800, 'TG', '2014-08-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125578, 'Sansanné-Mango', 'Sansanne-Mango', 'Mango,N''Zara,Nsara,N’Zara,Sansane-Mangu,Sansanne-Mango,Sansanné-Mango,Sanssane-Mango,Sanssané-Mango', 10.3591700, 0.4708300, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125579, 'Lomé', 'Lome', 'Gorad Lameh,LFW,Lome,Lomee,Lomeo,Lomé,Lomė,lome,luo mei,lwm,lwmh,lwmy,lwmyh,rome,Λομέ,Горад Ламэ,Ломе,Լոմե,לאמע,לומה,لوم,لومه,لومي,لوميه,لومې,لومے,لۆمێ,लोमे,ਲੋਮੇ,லோமே,โลเม,ལཱོ་མེ།,ლომე,ሎሜ,ロメ,洛美,로메', 6.1374800, 1.2122700, 'TG', '2014-08-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125580, 'Kpalimé', 'Kpalime', 'Agome-Palime,Agomé-Palimé,Kpalime,Kpalimé,Palime,Palimé,pa li mei,帕利梅', 6.9000000, 0.6333300, 'TG', '2013-08-17', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125581, 'Pagouda', 'Pagouda', 'Kpagouda,Pagouda', 9.7525000, 1.3277800, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125582, 'Kara', 'Kara', 'Kara,Lama,Lama-Kara,Кара', 9.5511100, 1.1861100, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125583, 'Kandé', 'Kande', 'Kande,Kandé,Kante,Kanté', 9.9577800, 1.0447200, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125584, 'Dapaong', 'Dapaong', 'Dapango,Dapaon,Dapaong,Dapaongas,Dapaonge,Dapong,da pang,dapangu,dapaong,dapawng,Дапаон,Дапаонге,داپاونگ,ダパング,达庞,다파옹', 10.8622500, 0.2076200, 'TG', '2013-01-10', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125585, 'Bassar', 'Bassar', 'Basar,Bassar,Bassari,ba sa,Басар,巴萨', 9.2502500, 0.7821300, 'TG', '2014-09-03', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125586, 'Bafilo', 'Bafilo', 'Bafilo,Бафило', 9.3500000, 1.2666700, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125587, 'Badou', 'Badou', 'Bad,Badou,Badu,Bādu,Бад', 7.5833300, 0.6000000, 'TG', '2013-10-30', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125588, 'Atakpamé', 'Atakpame', 'Atakpame,Atakpamé,Atakpamė,a ta pa mei,atakeupame,atakupame,Ατακπαμέ,Атакпаме,اتاکپامے,アタクパメ,阿塔帕梅,아타크파메', 7.5333300, 1.1333300, 'TG', '2012-02-02', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125589, 'Aného', 'Aneho', 'Anecho,Aneho,Anekho,Anerho,Anécho,Aného,Klein-Popo,Little Popo,Petit Popo', 6.2279800, 1.5919000, 'TG', '2014-10-17', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125590, 'Amlamé', 'Amlame', 'Amlame,Amlamé,Emla', 7.4666700, 0.9000000, 'TG', '2012-01-18', 223);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125521, 'Cockburn Town', 'Cockburn Town', 'Cockburn Town,Gorad Kobern-Taun,Kobern Taun,Kobern Taunas,Kobern-Taun,Kobərn Taun,Kokburn Taun,Kokburno,Kokmpern Taoun,kakpern nakaram,ke bo en cheng,kh xk beir ntha wn,kobeontaun,kokabarna ta''una,kokkubantaun,kwk brn tawn  bahama,Κόκμπερν Τάουν,Горад Коберн-Таўн,Коберн Таун,Коберн-Таун,Кокбърн Таун,קוקבורן טאון,کاک برن ٹاؤن,کوک برن تاون، باهاما,कॉकबर्न टाउन,காக்பேர்ண் நகரம்,ค็อกเบิร์นทาวน์,კოკბერნ-ტაუნი,コックバーンタウン,科伯恩城,코번타운', 21.4612200, -71.1418800, 'TC', '2010-10-06', 230);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125891, 'Thung Fon', 'Thung Fon', 'Amphoe Thung Fon,Ban Thung Fon,King Amphoe Thung Fon,Thung Fon,thungfn,ทุ่งฝน', 17.4716700, 103.2603300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125892, 'Thon Buri', 'Thon Buri', 'Amphoe Thon Buri,Changwat Thon Buri,Dhonburi,Dhonhuri,Thon Buri,Thonhuri,thnburi,ธนบุรี', 13.7250000, 100.4851100, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125893, 'Thoeng', 'Thoeng', 'Amphoe Dheung,Amphoe Moeang Dheung,Amphoe Thoeng,Ban Nai Wiang,Ban Thoeng,Ban Wiang Thoeng,Dhewng,Dhēwng,Moeang Dheung,Muang Tern,Muang Teun,Tharng,Thoeng,theing,เทิง', 19.6850800, 100.1945600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125894, 'Thep Sathit', 'Thep Sathit', 'Amphoe Thep Sathit,King Amphoe Thep Sathit,Thep Sathit,thephsthit,เทพสถิต', 15.3924700, 101.4506100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125895, 'Tha Yang', 'Tha Yang', 'Amphoe Tha Yang,Ban Tha Yang', 12.9577200, 99.9055500, 'TH', '2008-09-24', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125896, 'Tha Wung', 'Tha Wung', 'Amphoe Pho Wi,Amphoe Tha Wung,Ban Tha Wung,Dha Wung,Dhā Wung,Tha Wung,thawung,ท่าวุ้ง', 14.8110000, 100.5033300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125897, 'Thawat Buri', 'Thawat Buri', 'Amphoe Ban Phon Thong,Amphoe Ban Phong Thong,Amphoe Bhondhohng,Amphoe Phon Thong,Amphoe Tawat Buri,Amphoe Thawat Buri,Ban Phon Thong,Bouri,Muang Bouri,Muang Ruri,Muang Taratburi,Muang Tawaj Buri,Muang Thawat Buri,Phon Thong,Phonthaung,Saeng Badan,Thawat Buri,Thawatchaburi,Uthai Roi Et,thwachburi,ธวัชบุรี', 16.0385000, 103.7464700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125898, 'Tha Wang Pha', 'Tha Wang Pha', 'Amphoe Tha Wang Pha,Ban Tha Wang Pha,Ban Wang Pha,Tha Wang Pha,thawangpha,ท่าวังผา', 19.1218900, 100.8110600, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125899, 'Tha Uthen', 'Tha Uthen', 'Amphoe Ban Tha Uthen,Amphoe Dha Udhen,Amphoe Tha Uthen,Ban Tha Uthen,Houthene,Muang Tau Ten,Mueang Tha Uthen,Tauten,Tha Uthen,Tha-uthen,Uthen,thaxuthen,ท่าอุเทน', 17.5760500, 104.5990600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125900, 'Tha Tum', 'Tha Tum', 'Amphoe Tha Tum,Ban Tha Tum,Tha Tum,Tha-Tume,Thatoom,thatum,ท่าตูม', 15.3195000, 103.6754200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125901, 'That Phanom', 'That Phanom', 'Amphoe Renu Nakhon,Amphoe That Phanom,Ban That Phanom,Ban Thatphnom,Ban Thatuphanom,Renu Nakhon,That Phanom,thatuphnm,ธาตุพนม', 16.9363600, 104.7103900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125902, 'Tha Tako', 'Tha Tako', 'Amphoe Tha Tako,Tha Tako,thatako,ท่าตะโก', 15.6421800, 100.4783900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125903, 'Tha Ruea', 'Tha Ruea', 'Amphoe Nakhon Noi,Amphoe Tha Rua,Ban Tah Roea,Ban Tha Rua,Dha Roea,Dhā Roēa,Tha Rha,Tha Rua,Tha Ruea,thareux,ท่าเรือ', 14.5673900, 100.7259800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125904, 'Tha Pla', 'Tha Pla', 'Amphoe Tha Pla,Ban Hha Pla,Ban Ta Pla,Ban Tha Pla,Bān Hha Pla,Dhapla,Dhāpla,Tha Pla,thapla,ท่าปลา', 17.7911200, 100.3761100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125905, 'Thap Khlo', 'Thap Khlo', 'Amphoe Thap Khlo,King Amphoe Thap Khlo,Thap Khlo,thab kh lx,ทับคล้อ', 16.1600300, 100.5965600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125906, 'Thanyaburi', 'Thanyaburi', 'Amphoe Thanyaburi,Amphoe Thung Luang,Mueang Thanyaburi,Than Buri,Thanya Buri,Thanyaburi,thayburi,ธัญบุรี', 14.0211400, 100.7343300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125907, 'Than To', 'Than To', 'Amphoe Than To,King Amphoe Than To,Than To,tharto,xaphex tharto,ธารโต,อำเภอธารโต', 6.1673900, 101.1800800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125908, 'Tha Mai', 'Tha Mai', 'Amphoe Khamong,Amphoe Phloi Waen,Amphoe Tha Mai,Ban Tha Mai,Talat Amphoe Tha Mai,Tha Mai,ท่าใหม่', 12.6213700, 102.0048100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125909, 'Tha Luang', 'Tha Luang', 'Amphoe Tha Luang,King Amphoe Tha Luang,Tha Luang,tha hlwng,ท่าหลวง', 15.0712400, 101.0980100, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125910, 'Tha Li', 'Tha Li', 'Amphoe Tha Li,Ban Ta Li,Ban Tha Li,Dhali,Dhāli,Tha Li,thali,ท่าลี่', 17.6235500, 101.4209900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125911, 'Tha Khantho', 'Tha Khantho', 'Amphoe Tha Khantho,King Amphoe Tha Khantho,Tha Khantho,thakhantho,ท่าคันโท', 16.9395300, 103.2458600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125912, 'Tha Chang', 'Tha Chang', 'Amphoe Tha Chang,Ban Thon Samo,King Amphoe Tha Chang,Tha Chang,Thaun Samau,thachang,ท่าช้าง', 14.7614200, 100.3898900, 'TH', '2016-10-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125913, 'Tha Bo', 'Tha Bo', 'Amphoe Tha Bo,Ban Tha Bau,Ban Tha Bo,Mong Ta Bo,Mueang Tha Bo,Möng Ta Bo,Tha Bo,Tha Bor,thabx,ท่าบ่อ', 17.8500300, 102.5813900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125914, 'Ta Phraya', 'Ta Phraya', 'Amphoe Ta Phraya,Ban Ta Phaya,Ban Ta Phraya,King Amphoe Ta Phraya,Ta Phraya,Ta Phya,taphraya,ตาพระยา', 14.0030800, 102.8054100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125915, 'Taphan Hin', 'Taphan Hin', 'Amphoe Taphan Hin,Ban Saphan Hin,King Amphoe Taphan Hin,Taphan Hin,taphanhin,ตะพานหิน', 16.2209500, 100.4197800, 'TH', '2013-02-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125916, 'Tao Ngoi', 'Tao Ngoi', 'Amphoe Tao Ngoi,King Amphoe Tao Ngoi,Tao Ngoi,tea ngxy,เต่างอย', 16.9968900, 104.1667200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125917, 'Tan Sum', 'Tan Sum', 'Amphoe Tan Sum,King Amphoe Tan Sum,Tan Sum,tal sum,ตาลสุม', 15.3156900, 105.1546400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125918, 'Tamot', 'Tamot', 'Amphoe Tamot,King Amphoe Tamot,Ta Mot,Tamot,ta homd,ตะโหมด', 7.3392200, 100.1116700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125919, 'Taling Chan', 'Taling Chan', 'Amphoe Taling Chan,Tahng Jan,Taling Chan,tlingchan,ตลิ่งชัน', 13.7769800, 100.4567000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125920, 'Takhli', 'Takhli', 'Amphoe Ta Khli,Ban Ta Khli,Ban Takli,Bān Tākli,TKH,Takhli,takhli,ตาคลี', 15.2633600, 100.3437800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125921, 'Tak Bai', 'Tak Bai', 'Amphoe Kampong Chehe,Amphoe Tak Bai,Ampur Takbai,Ban Takbai,Chavhay,Chayhay,Che He,Kampong Chehe,Tak Bai,Takbar,ตากใบ', 6.2594700, 102.0546100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125922, 'Suwannaphum', 'Suwannaphum', 'Amphoe Suwanapum,Amphoe Suwannaphum,Amphoe Suwannphum,Amphoe Suwarnbhum,Ban Sa Khu,Ban Sra Ku,King Amphoe Suwannaphum,Muang Suvanapum,Sa Khu,Souodnapoum,Souvanapoum,Suvanapum,Suwannaphum,Suwanphum,suwrrnphumi,สุวรรณภูมิ', 15.6034800, 103.8020700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125923, 'Suwannakhuha', 'Suwannakhuha', 'Amphoe Suwan Khu Ha,Amphoe Suwannakhuha,King Amphoe Suwannakhuha,Suwannakhuha,suwrrnkhuha,สุวรรณคูหา', 17.5629200, 102.2798900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125924, 'Surin', 'Surin', 'Changwat Surin,Muang Sourin,Muang Surin,Mueang Surin,PXR,Surin,Surindr,Surindra,surinthr,Сурин,สุรินทร์', 14.8818100, 103.4936400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125925, 'Suphan Buri', 'Suphan Buri', 'Amphoe Muang Suphan Buri,Ban Tha Phi Liang,Changwat Suphan Buri,Muang Subharn,Muang Supan,Muang Suphan,Mueang Suphan Buri,Subhan Buri,Subharn,Sufan Buri,Supan,Supanburi,Supham Buri,Suphan Buri,Thaphi Liang,suphrrnburi,Суфан Бури,สุพรรณบุรี', 14.4741800, 100.1221800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125926, 'Sung Noen', 'Sung Noen', 'Amphoe Sung Noen,Ban Sung Noen,Sung Noen,sungnein,สูงเนิน', 14.8992000, 101.8207500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125927, 'Sung Men', 'Sung Men', 'Amphoe Sung Men,Ban Sung Men,Soong Men,Sung Men,Sungmen,sungmen,สูงเม่น', 18.0494000, 100.1145700, 'TH', '2012-09-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125928, 'Ban Su-ngai Pa Di', 'Ban Su-ngai Pa Di', 'Ban Su-ngai Pa Di,Ban Suhong Padi,Sungai Padi,Sungei Padi,ban suhingpadi,บ้านสุไหงปาดี', 6.0723900, 101.8717200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125929, 'Su-ngai Kolok', 'Su-ngai Kolok', 'Amphoe Sungai Kolok,King Amphoe Su-ngai Kolok,Kolok,Su-ngai Kolok,Sungai Kolok,Sungei Kolok,suhingko-lk,สุไหงโก-ลก', 6.0297700, 101.9658600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125930, 'Sukhirin', 'Sukhirin', 'Amphoe Sukhirin,King Amphoe Sukhirin,Sukhirin,sukhirin,สุคิริน', 5.9388900, 101.7707700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125931, 'So Phisai', 'So Phisai', 'Amphoe So Phisai,King Amphoe So Phisai,So Phisai,sophisay,โซ่พิสัย', 18.0772000, 103.4432000, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125932, 'Song Phi Nong', 'Song Phi Nong', 'Amphoe Song Phi Nong,Ban Bang Len,Song Phi Nong,sxngphinxng,สองพี่น้อง', 14.2240800, 100.0209400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125933, 'Songkhla', 'Songkhla', 'Amphoe Muang Songkhla,Changwat Songkhla,Monthon Nakhon Si Thamarat,Monthon Nakhon Si Thammarat,Muang Sawng Kla,Muang Songkla,SGZ,Sawng Kla,Senggora,Singgora,Singora,Singorra,Songkhla,Songkkhla,Songkla,Sung Kla,Thanh pho Songkhla,Thành phố Songkhla,sngkhla,song ka,song ka shi,songkeulla,swnjkhla,thesbal nkhr sngkhla,Сонгкхла,سونجخلا,سونگکھلا,สงขลา,เทศบาลนครสงขลา,སོང་ཁ་ལ།,宋卡,宋卡市,송클라', 7.1988200, 100.5951000, 'TH', '2015-06-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125934, 'Song', 'Song', 'Amphoe Song,Ban Glang,Ban Klang,Bān Glāng,Mueang Song,Song,sxng,สอง', 18.4720400, 100.1834600, 'TH', '2012-09-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125935, 'Somdet', 'Somdet', 'Amphoe Somdet,King Amphoe Somdet,Somdet,smdec,สมเด็จ', 16.7046200, 103.7493500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125936, 'Soeng Sang', 'Soeng Sang', 'Ban Soeng Sang,Soeng Sang,seingsang,เสิงสาง', 14.4264200, 102.4605800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125937, 'Si Thep', 'Si Thep', 'Amphoe Si Thep,King Amphoe Si Thep,Si Thep,sritheph,ศรีเทพ', 15.4521400, 101.0666700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125938, 'Si That', 'Si That', 'Amphoe Sang Khom,King Amphoe Sang Khom,Si That,srithatu,ศรีธาตุ', 16.9736100, 103.2164400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125939, 'Si Songkhram', 'Si Songkhram', 'Amphoe Si Songkhram,Ban Pak Un,King Amphoe Akat Amnui,King Amphoe Si Songkhram,Si Songkhram,srisngkhram,ศรีสงคราม', 17.6274500, 104.2506900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125940, 'Si Sakhon', 'Si Sakhon', 'Amphoe Si Sakhon,King Amphoe Si Sakhon,Si Sakhon,srisakhr,ศรีสาคร', 6.2313700, 101.5004800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125941, 'Si Sa Ket', 'Si Sa Ket', 'Amphoe Muang Sisaket,Amphoe Sisaket,Cangwat Khukhan,Changwat Khu Khan,Changwat Si Sa Ket,Khukhan,Muang Sisaket,Muang Srisaket,Mueang Si Sa Ket,Si Sa Ket,Si Saket,Sisakate,Sisaket,Srisakesa,Srisaket,Си Са Кет,ศรีสะเกษ', 15.1148100, 104.3293800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125942, 'Si Rattana', 'Si Rattana', 'Amphoe Si Rattana,King Amphoe Si Rattana,Si Rattana,sri ratna,ศรีรัตนะ', 14.7932800, 104.4692200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125943, 'Si Racha', 'Si Racha', 'Amphoe Si Racha,Amphu Sri Maha Raja,Ban Si Racha,Ban Sriracha,Si Racha,Sri Maha Raja,Sri Mahā Rājā,Sriracha,Srirachi,sriracha,ศรีราชา', 13.1737200, 100.9311100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125944, 'Si Prachan', 'Si Prachan', 'Amphoe Si Prachan,Ban Si Prachan,Ban Sri Prachan,Si Prachan,Sri Pra Chan,sripracant,ศรีประจันต์', 14.6199200, 100.1448300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125945, 'Sing Buri', 'Sing Buri', 'Amphoe Muang Sing Buri,Ban Bang Phutsa,Ban Bang Putsa,Bang Phutsa,Changwat Sing Buri,Muang Sing,Mueang Sing Buri,Sing,Sing Buri,Singburi,Singha Buri,singhburi,Синг Бури,สิงห์บุรี', 14.8878600, 100.4046400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125946, 'Si Mueang Mai', 'Si Mueang Mai', 'Amphoe Si Muang Mai,Amphoe Suwan Warin,Khwaeng Mueang Khong Chiam,Si Muang Mai,Si Mueang Mai,ศรีเมืองใหม่', 15.4931500, 105.2762400, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125947, 'Si Maha Phot', 'Si Maha Phot', 'Amphoe Si Maha Phot,Ban Tha Prachum Chon,Si Maha Phot,Srimahabhot,Srimahapho,Srimahābhot,Tha Prachumchon,srimhaphothi,ศรีมหาโพธิ', 13.9659700, 101.5130300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125948, 'Si Khoraphum', 'Si Khoraphum', 'Amphoe Si Khoraphum,Amphoe Si Koraphum,Amphoe Srihohrabhum,Amphoe Srikhohrabhum,Amphoe Srikhonphum,Ban Yang,Muang Sikarapum,Si Kara Poum,Si Khoraphum,Sri Khon Phoom,Sri Kra Pum,sikhrphumi,ศีขรภูมิ', 14.9441800, 103.7970400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125949, 'Sikhio', 'Sikhio', 'Amphoe Chanthuek,Amphoe Chanthuk,Amphoe Si Khiu,Ban Si Khiu,Chan Thuk,Mueang Nakhon Chantuek,Si Khiu,Si Khiu (2),Sikhio,si khiw,สี่คิ้ว', 14.8922500, 101.7231400, 'TH', '2014-06-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125950, 'Si Chomphu', 'Si Chomphu', 'Amphoe Si Chomphu,King Amphoe Si Chomphu,Si Chomphu,sichmphu,สีชมพู', 16.7987800, 102.1846600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125951, 'Si Chiang Mai', 'Si Chiang Mai', 'Amphoe Si Chiang Mai,Ban Chiang Mai,Ban Si Chiang Mai,Si Chiang Mai,Sri Chiang Mai,ศรีเชียงใหม่', 17.9563900, 102.5866700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125952, 'Si Bun Rueang', 'Si Bun Rueang', 'Amphoe Si Bun Ruang,King Amphoe Si Bun Rueang,Si Bun Ruang,Si Bun Rueang,sribuyreuxng,ศรีบุญเรือง', 16.9670500, 102.2760700, 'TH', '2013-02-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125953, 'Senangkhanikhom', 'Senangkhanikhom', 'Amphoe Senangkhanikhom,King Amphoe Senangkhanikhom,Senangkhanikhom,senangkhnikhm,เสนางคนิคม', 16.0397200, 104.6693900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125954, 'Sena', 'Sena', 'Amphoe Sena,Amphu Sena,Ban Sena,Khwaeng Sena,Sena,sena,Сена,เสนา', 14.3270000, 100.4043300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125955, 'Selaphum', 'Selaphum', 'Amphoe Selabhum,Amphoe Selaphum,Amphoe Selephum,Amphoe Slephum,Ban Klang,Klang,Muang Selapum,Mueang Selaphum Nikhom,Sala Poum Nikom,Sala Pum Nikom,Selaphum,Slephum,selphumi,เสลภูมิ', 16.0299200, 103.9382600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125956, 'Seka', 'Seka', 'Amphoe Seka,King Amphoe Seka,Seka,seka,เซกา', 17.9285100, 103.9551900, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125957, 'Sawang Daen Din', 'Sawang Daen Din', 'Amphoe Sawang Daen Din,Ban Han,Mueang Sawang Daen Din,Sawang Daen Din,Sawang Din Daen,สว่างแดนดิน', 17.4753100, 103.4575300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125958, 'Sawaeng Ha', 'Sawaeng Ha', 'Amphoe Sawaeng Ha,Ban Sawaeng Ha,Ban Saweng Ha,King Amphoe Sawaeng Ha,Sawaeng Ha,Sawaengha,บ้านแสวงหา,แสวงหา', 14.7464200, 100.3294200, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125959, 'Satun', 'Satun', 'Changwat Satun,Satul,Satun,Setul,stul,Сатун,สตูล', 6.6231400, 100.0667600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125960, 'Satuek', 'Satuek', 'Amphoe Satuek,Amphoe Satuk,King Amphoe Satuek,Satuek,Satuk,So Tuk,stuk,สตึก', 15.2970300, 103.2919200, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125961, 'Sattahip', 'Sattahip', 'Amphoe Sattahip,Ban Sata Hib,Ban Satahip,Ban Sattahip,King Amphoe Sattahip,Satahib,Sattaheeb,Sattaheep,Sattahib,Sattahiep,Sattahip,sathib,สัตหีบ', 12.6664400, 100.9007300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125962, 'Sathing Phra', 'Sathing Phra', 'Amphoe Chathing Phra,Amphoe Sathing Phra,Ban Cha Thing Phra,Ban Jathing Phra,Cha Thing Phra,Khing Jating Prah,King Amphoe Chathing Phra,King Amphoe Muang Songkhla,King Cha Thing Phra,Sathing Phra,sthingphra,สทิงพระ', 7.4730300, 100.4390800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125963, 'Saraburi', 'Saraburi', 'Ban Pak Phrieo,Changwat Sara Buri,Muang Sara Buri,Pak Phrieu,Pak Phrio,Pak Preo,Sita,Sraburi', 14.5333300, 100.9166700, 'TH', '2010-05-24', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125964, 'Sao Hai', 'Sao Hai', 'Amphoe Sao Hai,Amphu Sao-hai,Ban Sa Kaeo,Bau Sao Hai,Sao Hai,seahi,เสาไห้', 14.5508300, 100.8443600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125965, 'Sapphaya', 'Sapphaya', 'Amphoe Sapphaya,Ban Sanphaya,Sanphaya,Saphaya,Sapphaya,Sarbha-Ya,Sarbha-Yā,srrphya,สรรพยา', 15.1461600, 100.2421500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125966, 'Sanom', 'Sanom', 'Amphoe Sanom,Ban Nong Sanom,Ban Sanam,Ban Sanom,King Amphoe Sanom,Sanam,Sanom,snm,สนม', 15.2036000, 103.7605400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125967, 'Sankhaburi', 'Sankhaburi', 'Amphoe San Buri,Amphoe Sankhaburi,Amphoe Sarn Buri,Ban Na Phra Lan,Na Phra Lan,San Buri,Sankhaburi,Sarn Buri,srrkhburi,สรรคบุรี', 15.0473300, 100.1617800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125968, 'Sangkhom', 'Sangkhom', 'Amphoe Sangkhom,Ban Sangkhom,King Amphoe Sangkhom,Sangkhom,sangkhm,สังคม', 18.0638900, 102.2736400, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125969, 'Sang Khom', 'Sang Khom', 'Amphoe Sang Khom,Ban Sang Khom,King Amphoe Sang Khom,Sang Khom,srangkhxm,สร้างคอม', 17.8264900, 103.0926200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125970, 'Sangkha', 'Sangkha', 'Amphoe Sangkha,Amphoe Sangkhah,Ban Khwao,Ban Muang Sangkha,Ban Muang Sangkhah,Ban Sang Ke,Khwao,Muang Sang Ke,Muang Sangkea,Mueang Sangkha,Sangka,Sangkeak,Sangkha,sangkha,สังขะ', 14.6362000, 103.8527800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125971, 'Sanam Chai Khet', 'Sanam Chai Khet', 'Amphoe Sanam Chai Khet,King Amphoe Sanam Chai,King Amphoe Sanam Chai Khet,Mueang Sanam Chai Khet,Sanam Chai Khet,snamchaykhet,สนามชัยเขต', 13.6586400, 101.4390600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125972, 'Samut Songkhram', 'Samut Songkhram', 'Amphoe Ban Prok,Amphoe Lam Thuan,Changwat Samut Songkkhram,Mae Khlaung,Mae Klong,Maikulaung,Maklong,Me Klawng,Me-klohng,Meh Klong,Meklong,Muang Samudh Songgram,Muang Samut Sang Khran,Muang Samut Songgram,Mueang Samut Songkhram,Samudh Songgram,Samudh Sŏnggrām,Samut Songkhram,Samut Songkram,Smut Songkhram,smuthrsngkhram,สมุทรสงคราม', 13.4145600, 100.0026400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125973, 'Samut Sakhon', 'Samut Sakhon', 'Ban Maha Chai,Ban Tachin,Changwat Samut Sakhon,Dha-chin,Mahachai,Muang Samudh Sagorn,Muang Samut Sakawn,Muang Samut Sakhon,Mueang Sakhon Buri,Mueang Samut Sakhon,Mueang Tha Chin,Samudh Sagorn,Samut Sakhon,Smutsakhon,Taachin,Tachin,Tanchin,Tha Chin,smuthrsakhr,สมุทรสาคร', 13.5475300, 100.2736200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125974, 'Samut Prakan', 'Samut Prakan', 'Ban Pak Nam,Paakunamu,Pakham,Paknam,Samudh Prakarn,Samut,Samut Prakan,Samutprakan,Samutpraken,Smutprakan,samuttopurakan,smuthrprakar,Самутпракан,สมุทรปราการ,サムットプラーカーン', 13.5993400, 100.5967500, 'TH', '2017-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125975, 'Samrong Thap', 'Samrong Thap', 'Amphoe Samrong Thap,Ban Samrong Thap,Ban Samrong Tiap,King Amphoe Samrong Thap,Sam Rong Tiep,Samrong Thap,sarongthab,สำโรงทาบ', 15.0225800, 103.9363100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125976, 'Sam Phran', 'Sam Phran', 'Amphoe Sam Phran,Amphoe Talat Mai,Ban Sam Phran,Sam Phran,samphran,สามพราน', 13.7269800, 100.2152600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125977, 'Samphanthawong', 'Samphanthawong', 'Samphanthawong,samphanthwngs,สัมพันธวงศ์', 13.7314700, 100.5141400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125978, 'Sam Ngam', 'Sam Ngam', 'Amphoe Sam Ngam,Ban Sam Ngam,Sam Ngam,samngam,สามง่าม', 16.5065300, 100.2049700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125979, 'Sam Ko', 'Sam Ko', 'Amphoe Sam Ko,Ban Sam Ko,King Amphoe Sam Ko,Sam Ko,samko,สามโก้', 14.6073500, 100.2186000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125980, 'Sam Khok', 'Sam Khok', 'Amphoe Sam Khok,Mueang Sam Khok,Sam Khok,samkhok,สามโคก', 14.0655000, 100.5226400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125981, 'Sam Chuk', 'Sam Chuk', 'Amphoe Nang Buat,Amphoe Sam Chuk,Amphu Nang Buai,Ban Nang Buat,Ban Sam Chuk,Ban Samsuk,Ban Talat Sam Chuk,Nang Buai,Nang Buaj,Nang Buat,Nāng Būai,Sam Chuk,samchuk,สามชุก', 14.7576300, 100.0899200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125982, 'Sakon Nakhon', 'Sakon Nakhon', 'Amphoe Muang Sakhon Nakhon,Ban That Choeng Chum,Changwat Muang Sakhon Nakhon,Changwat Sakon Nakhon,Muang Sakol Nakorn,Muang Sakon Lakon,Muang Sakon Nakawn,Muang Sakon Nakon,Mueang Sakon Nakhon,SNO,Sakhon Nakhon,Sakol,Sakol Nagorn,Sakol Nakorn,Sakon Nakawn,Sakon Nakhaun,Sakon Nakhon,Sakon Nakorn,Skol Nakon,Thatchoengchum,sklnkhr,สกลนคร', 17.1611600, 104.1472500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125983, 'Sa Kaeo', 'Sa Kaeo', 'Amphoe Mueang Sa Kaeo,Amphoe Sa Kaeo,Ban Sa Kaeo,King Amphoe Sa Kaeo,Mueang Sa Kaeo,Sa Kaeo,Sa Kaew,Sa Keo,Sakaeo,Sara Kaeo,Srakeo,สระแก้ว', 13.8141100, 102.0722200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125984, 'Sai Noi', 'Sai Noi', 'Amphoe Sai Noi,Ban Sai Noi,King Amphoe Sai Noi,Sai Noi,ban thirnxy,thirnxy,บ้านไทรน้อย,ไทรน้อย', 13.9791500, 100.3120900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125985, 'Sai Mun', 'Sai Mun', 'Amphoe Sai Mun,Ban Sai Mun,King Amphoe Sai Mun,Sai Mun,thraymul,ทรายมูล', 15.9449500, 104.2081200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125986, 'Sai Buri', 'Sai Buri', 'Amphoe Sai Buri,Amphoe Taluban,Ban Taluban,Muang Saiburi,Sai Buri,Selindung Bayu,Taluban,Telupin,sayburi,สายบุรี', 6.7013100, 101.6167500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125987, 'Sahatsakhan', 'Sahatsakhan', 'Amphoe Sahatsakhan,Sahatkhan,Sahatsakhan,shaskhanth,สหัสขันธ์', 16.7123600, 103.5202000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125988, 'Sadao', 'Sadao', 'Ban Sadao,Sadao,Sendawa,sadea,Садао,สะเดา', 6.6388300, 100.4234200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125989, 'Saba Yoi', 'Saba Yoi', 'Amphoe Saba Yoi,Ban Buyong,Bu Yong,King Amphoe Ba Hoi,King Amphoe Saba Yoi,Saba Yoi,Sebayu,sabayxy,สะบ้าย้อย', 6.6175000, 100.9518900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125990, 'Rueso', 'Rueso', 'Amphoe Rueso,Amphoe Ruso,Ban Ruasau,King Amphoe Rueso,King Amphoe Tanyong Mat,Resok,Roe Sau,Rueso,Rusaw,Ruso,Tanyong Mat,ruxseaa,รือเสาะ', 6.3936400, 101.5184700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125991, 'Rong Kwang', 'Rong Kwang', 'Amphoe Rong Kwang,Ban Raung Gwang,Ban Rong Kiem,Ban Rong Kwang,Bān Raung Gwang,King Amphoe Rong Kwang,Raung Kwang,Rohngkwang,Rong Kwang,Rōhngkwāng,rxngkwang,ร้องกวาง', 18.3390300, 100.3173600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125992, 'Rong Kham', 'Rong Kham', 'Amphoe Rong Kham,King Amphoe Rong Kham,Rong Kham,rxngkha,ร่องคำ', 16.2694300, 103.7468900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125993, 'Roi Et', 'Roi Et', 'ROI,Rio Et,Roi Ech,Roi Eht,Roi Et,Roi-ed,Roiet,rxyxed,Рои Эт,ร้อยเอ็ด', 16.0567000, 103.6530900, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125994, 'Renu Nakhon', 'Renu Nakhon', 'Amphoe Renu Nakhon,Amphoe That Phanom,King Amphoe Renu Nakhon,Mueang Renu Nakhon,Renu Nakhon,renunkhr,เรณูนคร', 17.0515700, 104.6770900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125995, 'Rayong', 'Rayong', 'Rajong,Rayaung,Rayohng,Rayong,layong,luo yong shi,raywng,rayxng,thesbal nkhr rayxng,Районг,رایونگ,ระยอง,เทศบาลนครระยอง,རེ་ཡོང་།,羅勇市,라용', 12.6809500, 101.2579800, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125996, 'Rattaphum', 'Rattaphum', 'Amphoe Kamphaeng Phet,Amphoe Rattaphum,Ban Kamphaeng Phet,Gampheang Phet,Kam Phaeng Phet,King Amphoe Rattaphum,Ratabhum,Rattaphum,ratphumi,รัตภูมิ', 7.1347800, 100.2564700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125997, 'Rattanaburi', 'Rattanaburi', 'Amphoe Rattanaburi,Ban Rattanaburi,Ban Rattanabuyi,Mong Ratana Buri,Muang Ratana Buri,Mueang Rattanaburi,Möng Ratana Buri,Ratanaburi,Rattanaburi,ratnburi,รัตนบุรี', 15.3178800, 103.8485900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125998, 'Rat Burana', 'Rat Burana', 'Amphoe Rat Burana,Raiabuna,Rasdorn Burana,Rat Burana,Ratburanah,ราษฎร์บูรณะ', 13.6821900, 100.5060300, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(125999, 'Rasi Salai', 'Rasi Salai', 'Amphoe Gong,Amphoe Khong,Amphoe Muang Khong,Amphoe Rasi Saila,Amphoe Rasi Salai,Ban Muang Khong,Muang Khong,Muang Si Chalai,Muang Sisalai,Muang Sri Chalai,Rasi Saila,Rasi Salai,Sisalai,ราษีไศล', 15.3446600, 104.1547600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126000, 'Ranot', 'Ranot', 'Amphoe Ranot,Ban Rahnot,Ban Ranok,Ban Ranot,Cha Thing Phra,King Amphoe Cha Thing Phra,Rahnot,Ranod,Ranot,Renut,ranod,ระโนด', 7.7776800, 100.3213400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126001, 'Ra-ngae', 'Ra-ngae', 'Amphoe Rangae,Ban Tanyong Mat,Kampong Bangae,Kampong Bangek,Mueang Ra-ngae,Ra-ngae,Rangek,Tanyong Mas,Tanyong Mat,ระแงะ', 6.2967800, 101.7284400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126002, 'Raman', 'Raman', 'Amphoe Kotabaru,Amphoe Raman,Ban Kauta Baru,Ban Kauta Bāru,Ban Kota Baru,Kota Baru,Kota Bharu,Raman,Reman,raman,รามัน', 6.4786200, 101.4241400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126003, 'Pueai Noi', 'Pueai Noi', 'Amphoe Phueai Noi,King Amphoe Phueai Noi,Puai Noi,Pueai Noi,peuxynxy,เปือยน้อย', 15.8697800, 102.9076700, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126004, 'Pua', 'Pua', 'Amphoe Pua,Ban Pua,Pua,paw,ปัว', 19.1750300, 100.9162200, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126005, 'Prathai', 'Prathai', 'Amphoe Prathai,Ban Prathai,King Amphoe Prathai,Prathai,prathay,ประทาย', 15.5331900, 102.7228300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126006, 'Prasat', 'Prasat', 'Amphoe Prasat,Prasat,prasath,ปราสาท', 14.6403900, 103.4044700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126007, 'Prang Ku', 'Prang Ku', 'Amphoe Prang Ku,Ban Tom,Ban Tum,King Amphoe Prang Ku,Prang Ku,prangkhku,ปรางค์กู่', 14.8567200, 104.0398100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126008, 'Prakhon Chai', 'Prakhon Chai', 'Amphoe Prakhon Chai,Amphoe Talung,Ban Pradonchai,Makong Xai,Muang Makong Se,Muang Makong Xai,Muang Nakawn Chai,Muang Nakhaun Chai,Muang Nakhon Chai,Muang Pa Khon Thai,Pakenejai,Pradonchai,Prakhan Chai,Prakhon Chai,Talung', 14.6059200, 103.1208100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126009, 'Pakham', 'Pakham', 'Amphoe Pakham,Ban Prakham,King Amphoe Pakham,Pakham,Prakham,pa kha,ปะคำ', 14.4381700, 102.7255800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126010, 'Prachin Buri', 'Prachin Buri', 'Amphoe Muang Prachin Buri,Changwat Prachin Buri,Muang Prachin Buri,Mueang Prachin Buri,Pachim,Prachim,Prachin,Prachin Buri,pracinburi,ปราจีนบุรี', 14.0499200, 101.3686400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126011, 'Prachantakham', 'Prachantakham', 'Amphoe Prachantakham,Ban Kob Chae,Ban Prachantakham,Mueang Prachantakham,Prachan Tagam,Prachan Tagām,Prachantakham,pracantkham,ประจันตคาม', 14.0644200, 101.5150300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126012, 'Pong Nam Ron', 'Pong Nam Ron', 'Amphoe Pong Nam Ron,King Amphoe Pong Nam Ron,Pong Nam Ron,pongnarxn,โป่งน้ำร้อน', 12.9057500, 102.2622500, 'TH', '2013-12-13', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126013, 'Pong', 'Pong', 'Amphoe Ban Meung,Amphoe Ban Muang,Amphoe Pong,Ban Muang,Ban Muang Pong,Muang Pong,Pong,png,ปง', 19.1493100, 100.2752200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126014, 'Pom Prap Sattru Phai', 'Pom Prap Sattru Phai', 'Pom Prap,Pom Prap Sattru Phai,pxmprabsatruphay,ป้อมปราบศัตรูพ่าย', 13.7582200, 100.5132500, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126015, 'Pluak Daeng', 'Pluak Daeng', 'Amphoe Pluak Daeng,Ban Pluak Daeng,King Amphoe Pluak Daeng,Pluak Daeng,ปลวกแดง', 12.9712200, 101.2146300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126016, 'Pla Pak', 'Pla Pak', 'Amphoe Pla Pak,King Amphoe Pla Pak,Pla Pak,Tambon Pla Pak,plapak,ปลาปาก', 17.1806400, 104.5260600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126017, 'Plaeng Yao', 'Plaeng Yao', 'Amphoe Plaeng Yao,King Amphoe Plaeng Yao,Plaeng Yao,แปลงยาว', 13.5846700, 101.2840300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126018, 'Phu Wiang', 'Phu Wiang', 'Amphoe Bhuwieng,Amphoe Phu Wiang,Ban Nai Muang,Muang Pou Vieng,Muang Pu Wieng,Nai Muang,Phu Wiang,Pou Vieng,phuweiyng,ภูเวียง', 16.6525900, 102.3755500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126019, 'Phutthaisong', 'Phutthaisong', 'Amphoe Phutthaisong,Phutthaisong,phuththisng,พุทไธสง', 15.5478300, 103.0246700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126020, 'Phu Ruea', 'Phu Ruea', 'Amphoe Phu Rua,King Amphoe Phu Rua,Phu Rua,Phu Ruea,phureux,ภูเรือ', 17.4538000, 101.3623100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126021, 'Phu Pha Man', 'Phu Pha Man', 'Amphoe Phupa Man,King Amphoe Phupa Man,Phu Pha Man,phupha man,ภูผาม่าน', 16.6488800, 101.9009700, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126022, 'Phu Luang', 'Phu Luang', 'Amphoe Phu Luang,King Amphoe Phu Luang,Phu Luang,phu hlwng,ภูหลวง', 17.1392000, 101.6639200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126023, 'Phu Kradueng', 'Phu Kradueng', 'Amphoe Phu Kradueng,Ban Wong Wian,King Amphoe Phu Kradueng,Phu Kradueng,Phu Kradung,phukradung,ภูกระดึง', 16.8842500, 101.8846700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126024, 'Phu Khiao', 'Phu Khiao', 'Amphoe Phu Khieo,Ban Phak Pang,Mueang Phu Khiao,Phak Pang,Pho Khieo,Phu Khiao,Phu Khieo,phukheiyw,ภูเขียว', 16.3765000, 102.1285300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126025, 'Phrom Phiram', 'Phrom Phiram', 'Amphoe Phrom Phiram,Ban Grap Phuang,Phrom Phiram,phrhmphiram,พรหมพิราม', 17.0335200, 100.2019000, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126026, 'Phrom Buri', 'Phrom Buri', 'Amphoe Bhromburi,Amphoe Phrom Buri,Ban Kum Bhrom,Ban Phrom Buri,Bān Kum Bhrōm,Muang Bhrom,Muang Phrom Buri,Muang Prom,Mueang Phrom Buri,Phrom,Phrom Buri,Prome,phrhmburi,พรหมบุรี', 14.7908600, 100.4532500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126027, 'Phra Yuen', 'Phra Yuen', 'Amphoe Phra Yuen,Ban Phra Yun,King Amphoe Phra Yuen,Phra Yuen,Phra Yun,phrayun,พระยืน', 16.3293000, 102.6518200, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126028, 'Phra Pradaeng', 'Phra Pradaeng', 'Amphoe Bhra Pradeng,Amphoe Bhra Pradēng,Amphoe Phra Padaeng,Amphoe Phra Pradaeng,Bhra Pradeng,Khoan Khan,Muang Nagorn Khoean Khan,Muang Nakawn Khoan Khan,Muang Nakhon Khaun Khan,Muang Nakhon Khuan Khan,Nakhon Khuan Khan,Nakhon Khuen Khan,Phra Pradaeng,purapuraden jun,พระประแดง,อำเภอพระประแดง,プラプラデーン郡', 13.6585500, 100.5336200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126029, 'Phra Phutthabat', 'Phra Phutthabat', 'Amphoe Phra Phutthabat,Ban Khun Khlon,Bhra Bhudhabadh,Bhra Bhudhābadh,Khun Khlon,King Amphoe Phra Phutthabat,King Phra Phutthabat,Phra Phutthabat,Phra Phutthabet,phraphuththbath,พระพุทธบาท', 14.7252600, 100.7953600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126030, 'Phra Nakhon Si Ayutthaya', 'Phra Nakhon Si Ayutthaya', 'Ajuthaja,Ajuttkhaja,Amphoe Krung Kao,Amphoe Phra Nakhon Si Ayutthaya,Amphoe Rop Krung,Ayouthia,Ayudhya,Ayuthaya,Ayuthia,Ayuthya,Ayutia,Ayutthaya,Ayutthaya - phrankhrsrixyuthya,Ayutthaya - พระนครศรีอยุธยา,Ayutthia,Ayutya,Changwat Phra Nakhon Si Ayutthaya,Krung Kao,Monthon Ayutthaya,Phra Nakhon Si Ax Ayutthaya,Phra Nakhon Si Ayutthaya,phrankhrsrixyuthya,tesaban''nakon・puranakonshiayuttaya,thesbal nkhr phrankhrsrixyuthya,Аюттхая,พระนครศรีอยุธยา,เทศบาลนครพระนครศรีอยุธยา,テーサバーンナコーン・プラナコーンシーアユッタヤー', 14.3516700, 100.5773900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126031, 'Phra Khanong', 'Phra Khanong', 'Amphoe Phra Khanong,Bhra Khanong,Phra Khanong,Phrakanhong,Phrakhnong,Prakanong,phra khi nng,พระไขนง', 13.7018500, 100.6015700, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126032, 'Phrai Bueng', 'Phrai Bueng', 'Amphoe Phrai Bueng,Ban Phrai Bung,King Amphoe Phrai Bueng,Phrai Bueng,Phrai Bung,phirbung,ไพรบึง', 14.7483300, 104.3626100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126033, 'Phrae', 'Phrae', 'Amphoe Muang Phrae,Amphoe Mueang Phrae,Bhre,Changwat Muang Bhre,Changwat Muang Bhré,Changwat Muang Phrae,Changwat Phrae,Muang Bhre,Muang Phrae,Muang Pre,Mueang Phrae,PRH,Phrae,Phrea,Pkhrae,Prae,Pre,Пхрае,แพร่', 18.1458900, 100.1410300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126034, 'Pho Thong', 'Pho Thong', 'Amphoe Huai Ling Tok,Amphoe Pho Thong,Ban Khlong Sarai,Bho Dhohng,Khlaung Sarai,Pho Thong,phothithxng,โพธิ์ทอง', 14.6673100, 100.4087800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126035, 'Pho Thale', 'Pho Thale', 'Amphoe Ban Khlan,Amphoe Pho Thale,Pho Thale,phothale,โพทะเล', 16.0926900, 100.2608900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126036, 'Pho Sai', 'Pho Sai', 'Amphoe Pho Sai,Ban Pho Chai,Ban Pho Sai,King Amphoe Pho Sai,Pho Sai,phothi thir,โพธิ์ไทร', 15.8258600, 105.2606400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126037, 'Waeng', 'Waeng', 'Amphoe Phon Thong,Ban Waeng,Phon Thong,Phon Tong,Waeng,phonthxng,แวง,โพนทอง', 16.3000600, 103.9778600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126038, 'Phon Sai', 'Phon Sai', 'Amphoe Phon Sai,Ban Phon Sai,King Amphoe Phon Sai,Phon Sai,phonthray,โพนทราย', 15.4879700, 103.9964200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126039, 'Phon Phisai', 'Phon Phisai', 'Amphoe Bhonbhisai,Amphoe Phon Phisai,Amphoe Pon Pi Sai,Ban Bom Nang,Ban Chum Phon,Ban Chumpol Muang,Chumphon,Muang Pon Pi Sai,Muang Ponpissay,Phon Phisai,Pon Pi Sal,Tiom Nang,phonphisay,โพนพิสัย', 18.0210600, 103.0766400, 'TH', '2016-12-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126040, 'Phon Charoen', 'Phon Charoen', '', 18.0333300, 103.1666700, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126041, 'Phon', 'Phon', 'Amphoe Phon,Ban Muang Phon,Moengphol,Mong Pol,Muang Phon,Möng Pol,Phon,phl,พล', 15.8160000, 102.5998100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126042, 'Pho Chai', 'Pho Chai', 'Amphoe Pho Chai,King Amphoe Pho Chai,Pho Chai,phothichay,โพธิ์ชัย', 16.3282700, 103.7703300, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126043, 'Phitsanulok', 'Phitsanulok', 'Amphoe Muang Phitsanulok,Amphoe Mueang Phitsanulok,Bhisanulok,Bisanulok,Bisnulok,Changwat Phitsanulok,Muang Phitsanulok,Muang Pitsanulok,PHS,Philtsanuloke,Phisanulauk,Phitsanulok,Phitsanulokas,Phitszanulok,Pisanuloke,Pitsanoulok,Pitsanulok,Pitsanuloke,Pkhitsanulok,fytsanwlwk,peng shi luo,pis-sanullog,Пхитсанулок,فیتسانولوک,پھسٹانولوک,پھیتسانولوک,พิษณุโลก,เทศบาลนครพิษณุโลก,เมืองพิษณุโลก,ཕི་ཊི་ཙ་ནུ་ལོཀ།,彭世洛,핏사눌록', 16.8248100, 100.2585800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126044, 'Phimai', 'Phimai', 'Amphoe Muang Phimai,Amphoe Phimai,Ban Nai Muang,Ban Nai Wiang,Moeang Bhimai,Moeang Bhimaj,Muang Phimai,Muang Pi Mai,Muang Pi Me,Nai Muang,Phimai,Pi Mai,Vimai,Vimayapura,phimay,พิมาย', 15.2232400, 102.4947300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126045, 'Phichit', 'Phichit', 'Amphoe Muang Phichit,Amphoe Ta Luang,Amphoe Tha Luang,Ban Nai Muang,Bhichit,Changwat Muang Bichit,Changwat Muang Phichit,Changwat Phichit,Muang Bhichit,Muang Phichit,Muang Phijit,Muang Pitchit,Okhaburi,Phichit,Pichit,Pkhichit,Sra Luang,Tha Luang,phicitr,Пхичит,พิจิตร', 16.4418400, 100.3487900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126046, 'Phichai', 'Phichai', 'Amphoe Phichai,Bhijai,Muang Phichai,Muang Pichai,Muang Pichāi,Phichai,phichay,พิชัย', 17.2876400, 100.0867000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126047, 'Phibun Mangsahan', 'Phibun Mangsahan', 'Amphoe Bhimunmangsaharn,Amphoe Phibun Mangsahan,Amphoe Phimun Mangahan,Amphoe Phimun Mangsahan,Ban Phimun,Muang Phi Moun,Muang Pimour,Phi Moun,Phibun Mangdshan,Phibun Mangsahan,Phimun,Phimun Mangsahan,Phinum Mangsahan,Pibulmangsahan,Pimool,Pimul,Pimun,phibulmangsahar,พิบูลมังสาหาร', 15.2446700, 105.2290800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126048, 'Phetchabun', 'Phetchabun', 'Amphoe Muang Phetchabun,Bhejaburn,Changwat Muang Bheia Burn,Changwat Muang Bhĕia Būrn,Changwat Muang Phetchabun,Changwat Phetchabun,Muang Bheia Burn,Muang Petchboun,Muang Phecha Bun,Muang Phetchabun,PHY,Pechabun,Petchabun,Phetchabun,Pkhetchabun,phechrburn,Пхетчабун,เพชรบูรณ์', 16.4190400, 101.1605600, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126049, 'Phen', 'Phen', 'Amphoe Bhen,Amphoe Phen,Ban Moeang Pen,Ban Muang Phen,Muang Phen,Mueang Phen,Phen,phey,เพ็ญ', 17.6961400, 102.9068900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126050, 'Phayuha Khiri', 'Phayuha Khiri', 'Amphoe Bhayuha Giri,Amphoe Peiyua Kiri,Amphoe Phayuhakhiri,Ban Phayu Dean,Ban Phayuhadaen,Bhayuha Giri,Payuha,Phayu Daen,Phayu Kiri,Phayua Khiri,Phayuha Khiri,phyuhakhiri,พยุหะคีรี', 15.4552500, 100.1353300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126051, 'Phayakkhaphum Phisai', 'Phayakkhaphum Phisai', 'Amphoe Phayakkhaphum Phisai,Amphu Piak Puin Pisai,Ban Palan,Muong Kantigavise,Palan,Phayak Phu Phisai,Phayakkhaphum Phisai,phyakhkhphumiphisay,พยัคฆภูมิพิสัย', 15.5163100, 103.1936700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126052, 'Phatthalung', 'Phatthalung', 'Amphoe Klang Mueang,Amphoe Lampam,Amphoe Muang Phatthalung,Badalung,Bhadhalung,Changwat Phattalung,Changwat Phatthalung,Muang Patalung,Mueang Phatthalung,Patalung,Phatalung,Phathalung,Phattalung,Phatthalung,Pkhetchabun,phathlung,Пхетчабун,พัทลุง', 7.6178600, 100.0779200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126053, 'Phasi Charoen', 'Phasi Charoen', 'Amphoe Phasi Charoen,Bhasi Chareun,Paseecharoen,Phasi Charoen,ภาษีเจริญ', 13.7146600, 100.4369100, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126054, 'Phan Thong', 'Phan Thong', 'Amphoe Phan Thong,Amphoe Tha Ta Kut,Phan Thong,phanthxng,พานทอง', 13.4680400, 101.0953200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126055, 'Phanom Sarakham', 'Phanom Sarakham', 'Amphoe Phanom Sarakham,Amphu Panom Sarakam,Ban Phanom Sarakham,Bhanom Saragam,PMM,Phanom Sarakham,phnmsarkham,พนมสารคาม', 13.7478700, 101.3553000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126056, 'Phanom Phrai', 'Phanom Phrai', 'Amphoe Phanom Phrai,Ban Phanom Phrai,Ban Phnom Phrai,Phanom Phrai,phnm phir,พนมไพร', 15.6778300, 104.1102500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126057, 'Phanna Nikhom', 'Phanna Nikhom', 'Amphoe Muang Phannanikhom,Amphoe Phannanikhom,Amphoe Phannikhom,Bharnnani,Muang Pana Nigom,Muang Phannanikhom,Pana Nagom,Phanna Nikhom,phrrnanikhm,พรรณานิคม', 17.3524500, 103.8503200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126058, 'Phang Khon', 'Phang Khon', 'Amphoe Phang Khon,Ban Phany Khon,Bang Khone,King Amphoe Phang Khon,Phang Khon,phangkhon,พังโคน', 17.3905100, 103.7169200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126059, 'Phanat Nikhom', 'Phanat Nikhom', 'Amphoe Phanat Nikhom,Amphu Panas Nikom,Ban Phanat Nikhom,Bhanasnigom,Mueang Phanat Nikhom,Phanat Nikhom,Phanatikhom,phnasnikhm,พนัสนิคม', 13.4458100, 101.1844500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126060, 'Phana', 'Phana', 'Amphoe Phana,King Amphoe Phana,Mueang Phana Nikhon,Phana,phna,พนา', 15.6823100, 104.8460300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126061, 'Phak Hai', 'Phak Hai', 'Amphoe Phak Hai,Amphoe Sena Yai,Amphu Phak Hai,Ban Phakhai,Khwaeng Sena Yai,Phak Hai,phakhi,ผักไห่', 14.4573600, 100.3698900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126062, 'Phai Sali', 'Phai Sali', 'Amphoe Phaisali,Ban Khok Dua,King Amphoe Phaisali,Phai Sali,phisali,ไพศาลี', 15.6000300, 100.6493700, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126063, 'Phachi', 'Phachi', 'Amphoe Phachi,Ban Bhaui,Ban Phachi,Ban Phaji,Banbhaji,Banpaji,Bhaji,Bhāji,Bon Phaji,King Amphoe Ban Phachi,Phachi,phachi,ภาชี', 14.4491400, 100.7283300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126064, 'Pa Bon', 'Pa Bon', 'Amphoe Pa Bon,King Amphoe Pa Bon,Pa Bon,Pha Bon,pa bxn,ป่าบอน', 7.2694200, 100.1703600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126065, 'Phaya Mengrai', 'Phaya Mengrai', 'Paya Meng Rai,Phaya Mengrai,phya meng ray,พญาเม็งราย', 19.8492200, 100.1535800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126066, 'Pattani', 'Pattani', 'Changwat Pattani,Muang Patani,Muang Tara,PAN,Patani,Pattam,Pattani,Pattām,ftany,pattani,Паттани,فطاني,ปัตตานี,パッターニー', 6.8681400, 101.2500900, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126067, 'Pa Tio', 'Pa Tio', 'Amphoe Pa Tio,Amphoe Pa Tiu,Amphoe Tio,King Amphoe Pa Tio,Pa Tio,Pa Tiu,patiw,ป่าติ้ว', 15.8328100, 104.3867300, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126068, 'Pathum Thani', 'Pathum Thani', 'Amphoe Bang Kadi,Amphoe Muang Pathum Thani,Amphoe Pathum Thani,Ban Bang Kadi,Ban Patok,Bang Kadi,Changwat Pathum Thani,Muang Pradhum Dhani,Muang Prathum Tani,Muang Prathum Thani,Mueang Pathum Thani,Padumdhani,Pathum Rani,Pathum Thani,Pathumthani,Pradhum Dhani,Prathum Thani,Pthumthani,Ratkhum Tkhani,ppatumtani,pthumthani,thesbal meuxng pthumthani,Ратхум Тхани,پاتھم تھانی,ปทุมธานี,เทศบาลเมืองปทุมธานี,빠툼타니', 14.0134600, 100.5304900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126069, 'Pathum Rat', 'Pathum Rat', 'Amphoe Pathum Rat,King Amphoe Pathum Rat,Pathum Rat,pthumratt,ปทุมรัตต์', 15.6345000, 103.3432500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126070, 'Panare', 'Panare', 'Amphoe Panare,Ban Panare,Pa Na Le,Pak Narek,Panare,Pata Tare,Penarik,panarea,ปะนาเระ', 6.8619200, 101.4910300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126071, 'Pa Mok', 'Pa Mok', 'Amphoe Pa Mok,Ban Bang Pla Kot,Bang Pla Kot,Pa Mok,pamok,ป่าโมก', 14.4898900, 100.4484700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126072, 'Pak Thong Chai', 'Pak Thong Chai', 'Amphoe Ban Pak Thong Chai,Amphoe Pak Thong Chai,Amphoe Pakdhongjai,Ban Muang Pak Thong Chai,Ban Pak Thong Chai,Dan Chapo,Muang Pak,Muang Patong Chai,Muang Patong Se,Muang Patong Xai,Muang Patongai,Mueang Pak,Pak Thong Chai,Patong Xai,pakthngchay,ปักธงชัย', 14.7226000, 102.0251200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126073, 'Pak Phli', 'Pak Phli', 'Amphoe Bung Rai,Amphoe Khao Yai,Amphoe Nong Pho,Amphoe Pak Phli,Pak Phli,pakphli,ปากพลี', 14.1630800, 101.2688600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126074, 'Pak Phayun', 'Pak Phayun', 'Amphoe Pak Phayun,Amphoe Taksin,Ban Laem Fat,Ban Pak Phayun,Pak Pa Yun,Pak Phayum,Pak Phayun,ban pakphayun,pakphayun,บ้านปากพะยูน,ปากพะยูน', 7.3421900, 100.3174700, 'TH', '2012-02-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126075, 'Pak Phanang', 'Pak Phanang', 'Amphoe Bia Sad,Amphoe Pak Phanang,Ban Pak Phanang,Ban Pakpenang,Pak Phanang,Pakpenang,Pākpenang,pakphnang,ปากพนัง', 8.3510900, 100.2019500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126076, 'Pak Kret', 'Pak Kret', 'Amphoe Pak Kret,Ban Pak Kret,Pak Kred,Pak Kret,pakkerd,ปากเกร็ด', 13.9130100, 100.4988300, 'TH', '2016-06-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126077, 'Pak Khat', 'Pak Khat', 'Amphoe Pak Khat,Ban Pak Khat,King Amphoe Pak Khat,Pak Khat,pak khad,ปากคาด', 18.3055600, 103.3044100, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126078, 'Pak Chong', 'Pak Chong', 'Amphoe Pak Chong,Ban Pak Chong,Ban Par Chong,King Amphoe Pak Chong,Pak Chong,Tambon Pak Chong,pakchxng,ปากช่อง', 14.7080200, 101.4161400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126079, 'Pa Daet', 'Pa Daet', 'Ban Pa Daet,Ban Pa Deat,Bān Pa Deat,Pa Daet,ป่าแดด', 19.5048900, 99.9924100, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126080, 'Ongkharak', 'Ongkharak', 'Amphoe Ongkharak,Ban Ongkharak,Ongkharak,องครักษ์', 14.1211700, 101.0036400, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126081, 'Non Thai', 'Non Thai', 'Amphoe Non Lao,Amphoe Non Thai,Amphoe San Thia,Khwaeng San Thia,Non Thai,nonthiy,โนนไทย', 15.1958000, 102.0714500, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126082, 'Mueang Nonthaburi', 'Mueang Nonthaburi', 'Non Buri,Nondaburi,Nondha Buri,Nonthaburi,Nontkhaburi,thesbal nkhr nnthburi,Нонтхабури,เทศบาลนครนนทบุรี', 13.8607500, 100.5147700, 'TH', '2017-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126083, 'Non Sung', 'Non Sung', 'Amphoe Non Sung,Amphoe Non Wat,Ban Non Sung,Non Sung,nonsung,โนนสูง', 15.1801400, 102.2569500, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126084, 'Non Sang', 'Non Sang', 'Amphoe Non Sang,King Amphoe Non Sang,Non Sang,nonsang,โนนสัง', 16.8687000, 102.5664200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126085, 'Non Sa-at', 'Non Sa-at', 'Amphoe Non Sa-at,Ban Non Sa-at,King Amphoe Non Sa-at,Non Sa-at,nonsaxad,โนนสะอาด', 16.9791400, 102.8936900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126086, 'Non Kho', 'Non Kho', 'Amphoe Non Khun,King Amphoe Non Khun,Non Kho,Non Khun,non khun,non khx,โนนคูณ,โนนค้อ', 14.9166600, 104.7252200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126087, 'Nong Yai', 'Nong Yai', 'Amphoe Nong Yai,Ban Nong Yai,King Amphoe Nong Yai,Naung Yai,Nong Yai,หนองใหญ่', 13.1551500, 101.3722600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126088, 'Nong Sung', 'Nong Sung', 'Amphoe Nong Sung,Ban Nong Sung,King Amphoe Nong Sung,Nong Sung,hnxng sung,หนองสูง', 16.4829900, 104.3471200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126089, 'Nong Suea', 'Nong Suea', 'Amphoe Nong Sua,Ban Bung Ba,Ban Bung Pa,Boeng Ba,Nong Sua,Nong Suea,hnxngseux,หนองเสือ', 14.1347800, 100.8250300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126090, 'Nong Saeng', 'Nong Saeng', 'Amphoe Nong Saeng,Ban Nong Saeng,King Amphoe Nong Saeng,Nong Saeng,หนองแสง', 17.1673900, 102.7808100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126091, 'Nong Saeng', 'Nong Saeng', 'Amphoe Nong Saeng,Ban Nong Saeng,King Amphoe Nong Saeng,Nong Saeng,หนองแซง', 14.4920800, 100.7843100, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126092, 'Nong Ruea', 'Nong Ruea', 'Amphoe Nong Ruea,Ban Nong Rua,King Amphoe Nong Ruea,Nong Rua,Nong Ruea,hnxngreux,หนองเรือ', 16.4933300, 102.4333900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126093, 'Nong Phok', 'Nong Phok', 'Amphoe Nong Phok,King Amphoe Nong Phok,Nong Phok,hnxngphxk,หนองพอก', 16.3100600, 104.2024700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126094, 'Nong Phai', 'Nong Phai', 'Amphoe Nong Phai,Ban Nong Phai,King Amphoe Nong Phai,Nong Phai,hnxngphi,หนองไผ่', 15.9902500, 101.0618300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126095, 'Nong Ki', 'Nong Ki', 'Amphoe Nong Ki,King Amphoe Nong Ki,Nong Ki,hnxngki,หนองกี่', 14.6867900, 102.5380000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126096, 'Nong Khai', 'Nong Khai', 'Amphoe Muang Nong Khai,Ban Mi Chai,Changwat Nang Khai,Changwat Nong Khai,Hnohnggai,Michai,Muang Nawng Kai,Muang Nong Khay,Mueang Nong Khai,Naung Khai,Nawng Kai,Nong Hai,Nong Kai,Nong Khai,Nongkkhaj,QJX,hnxngkhay,nongkai,nonkai,thesbal meuxng hnxngkhay,Нонгкхай,نونگ کھائی,หนองคาย,เทศบาลเมืองหนองคาย,ནོང་ཁའི།,ノーンカーイ,농카이', 17.8784700, 102.7420000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126097, 'Nong Khaem', 'Nong Khaem', 'Ban Nong Khaem,King Amphoe Nang Khaem,Naung Khaem,Nong Khaem,หนองแขม', 13.7052800, 100.3492300, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126098, 'Nong Khae', 'Nong Khae', 'Amphoe Nong Khae,Ban Na Roeng,Hnohng Ga,Hnōhng Gā,Na Roeng,Naung Khae,Nong Khae,หนองแค', 14.3406200, 100.8673300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126099, 'Nong Hong', 'Nong Hong', 'Amphoe Nong Hong,King Amphoe Nong Hong,Nong Hong,hnxng hngs,หนองหงส์', 14.8478200, 102.6840100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126100, 'Nong Han', 'Nong Han', 'Amphoe Nong Han,Ban Nong Han,Mong Nawng Han,Mueang Nong Han,Muong Nong Han,Möng Nawng Han,Naung Han,Nong Han,hnxnghan,หนองหาน', 17.3608300, 103.1053300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126101, 'Nong Chok', 'Nong Chok', 'Amphoe Nong Chok,Ban Nong Chok,Hnohng Chohk,Hnongchok,Hnōhng Chōhk,Naung Chauk,Nong Chok,hnxngcxk,หนองจอก', 13.8558500, 100.8621600, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126102, 'Nong Chik', 'Nong Chik', 'Amphoe Nong Chik,Amphoe Tu Yong,Amphoe Tuyong,Ban Tujong,Ban Tuyong,Maung Nawng Chik,Muang Nawng Chik,Muang Nong Chik,Mueang Nong Chik,Naung Chik,Nong Chik,Tujong,Tuyong,Umper Nong Chick,Umper Nong Chik,hnxngcik,หนองจิก', 6.8435600, 101.1780300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126103, 'Nong Bun Nak', 'Nong Bun Nak', 'Ban Nong Bun Nak,Naung Bunnak,Nong Bun Nak,hn xng bun nak,หนองบุนนาก', 14.7394700, 102.3656400, 'TH', '2013-01-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126104, 'Nong Bua Rawe', 'Nong Bua Rawe', 'Amphoe Nong Bua Rawe,Ban Naun Rawiang,Ban Non Rawiang,Ban Nong Bua Rawe,Bān Naun Rawiang,King Amphoe Nong Bua Rawe,Non Rawiang,Nong Bua Rawe,Nong Buaraheo,hnxngbaw ra hew,หนองบัวระเหว', 15.7531400, 101.7639600, 'TH', '2012-08-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126105, 'Nong Bua Lamphu', 'Nong Bua Lamphu', 'Amphoe Nong Bua Lamphu,Ban Nong Bua,Changwat Nong Bua Lamphu,Kamouttasai,Kmuthasai,Muang Gamutra Sai,Muang Kamatdhasai,Muang Kamouttasai,Muang Kamuta Sai,Muang Kamutthasai,Muang Kmuthasai,Mueang Nong Bua Lamphu,Naung Bua,Nong Bua Lamphu,hnxngbawlaphu,หนองบัวลำภู', 17.2040600, 102.4406800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126106, 'Nong Bua Daeng', 'Nong Bua Daeng', 'Amphoe Nong Bua Daeng,King Amphoe Nong Bua Daeng,Nong Bua Daeng,หนองบัวแดง', 16.0797800, 101.8022500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126107, 'Nong Bua', 'Nong Bua', 'Amphoe Nong Bua,Ban Naung Bua,Ban Nong Bua,Bān Naung Bua,Naung Bua,Nong Bua,hnxngbaw,หนองบัว', 15.8645800, 100.5858100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126108, 'Noen Maprang', 'Noen Maprang', 'Amphoe Noen Maprang,Ban Noen Maprang,King Amphoe Noen Maprang,Noen Maprang,neinmaprang,เนินมะปราง', 16.5666700, 100.6333300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126109, 'Nikhom Nam Un', 'Nikhom Nam Un', 'Amphoe Nikhom Nam Un,King Amphoe Nikhom Nam Un,Nikhom Nam Un,nikhmnaxun,นิคมน้ำอูน', 17.1831400, 103.7184200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126110, 'Nikhom Kham Soi', 'Nikhom Kham Soi', 'Amphoe Nikhom Kham Soi,King Amphoe Nikhom Kham Soi,Nikhom Kham Soi,nikhmkhasrxy,นิคมคำสร้อย', 16.3716700, 104.5514700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126111, 'Na Wa', 'Na Wa', 'Amphoe Na Wa,Ban Na Wa,King Amphoe Na Wa,Na Wa,nahwa,นาหว้า', 17.4897000, 104.1005600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126112, 'Na Thawi', 'Na Thawi', 'Amphoe Na Thawi,Ban Na Thawi,Ban Nadhawi,Ban Natawi,Chana,King Amphoe Chana,King Amphoe Na Thawi,King Amphoe Nadhawi,Na Tawi,Na Thawi,Nadhawk,Nawi,nathwi,นาทวี', 6.7419200, 100.6913900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126113, 'Narathiwat', 'Narathiwat', 'Ban Bangnara,Bang Nara,Changwat Naradhiwas,Changwat Narathiwat,NAW,Naradhivas,Naradhiwas,Narathiwat,Narativas,Narativat,Naratkhivat,nrathiwas,Наратхиват,นราธิวาส', 6.4263900, 101.8230800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126114, 'Na Pho', 'Na Pho', 'Amphoe Na Pho,King Amphoe Na Pho,Na Pho,na phothi,นาโพธิ์', 15.6411300, 102.9546200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126115, 'Na Noi', 'Na Noi', 'Amphoe Na Noi,Ban Na Noi,Na Noi,nanxy,นาน้อย', 18.3263900, 100.7141700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126116, 'Nang Rong', 'Nang Rong', 'Amphoe Nang Rong,Ban Nang Rong,Mong Nang Rawng,Mueang Nang Rong,Muong Nang Rong,Möng Nang Rawng,Nang Raung,Nang Rong,nangrxng,นางรอง', 14.6377000, 102.7913800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126117, 'Nan', 'Nan', 'Amphoe Muang Nam,Amphoe Mueang Nam,Ban Muang Nan,Changwat Muang Nan,Changwat Nan,Changwat Nana,Muang Nan,Mueang Nan,NNT,Nagor Nan,Nan,Nanas,nan,thesbal meuxng nan,Нан,نان، تھائی لینڈ,น่าน,เทศบาลเมืองน่าน,ནཱན་གྲོང་ཁྱེར།,난', 18.7837800, 100.7789900, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126118, 'Na Muen', 'Na Muen', 'Amphoe Na Muen,Ban Na Lak Meun,Ban Na Lak Mun,Bān Na Lak Meun,King Amphoe Na Muen,Na Muen,Na Mun,na hmun,นาหมื่น', 18.1893100, 100.6604700, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126119, 'Nam Som', 'Nam Som', 'Amphoe Nam Som,King Amphoe Nam Som,Nam Som,nasom,น้ำโสม', 17.7703600, 102.1894700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126120, 'Nam Phong', 'Nam Phong', 'Amphoe Nam Phong,Amphoe Tha Wa,Nam Phong,Nam Pong,Tha Wa,naphxng,น้ำพอง', 16.7022800, 102.8556900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126121, 'Nam Pat', 'Nam Pat', 'Amphoe Nam Pat,Amphoe Saen To,Nam Pat,napad,น้ำปาด', 17.7280600, 100.6843300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126122, 'Na Mon', 'Na Mon', 'Amphoe Na Mon,Ban Na Mon,Ban Na Mun,King Amphoe Na Mon,Na Mon,namn,นามน', 16.5765300, 103.7871100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126123, 'Nam Nao', 'Nam Nao', 'Amphoe Nam Nao,King Amphoe Nam Nao,Nam Nao,na hnaw,น้ำหนาว', 16.7675300, 101.6691700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126124, 'Nam Kliang', 'Nam Kliang', 'Amphoe Nam Kliang,King Amphoe Nam Kliang,Nam Kliang,na keliyng,น้ำเกลี้ยง', 14.9273100, 104.5130300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126125, 'Nakhon Thai', 'Nakhon Thai', 'Amphoe Moeang Nagorn Dhai,Amphoe Muang Nakawn Tai,Amphoe Muang Nakhon Thai,Amphoe Muang Nakorn Thai,Amphoe Nakhon Thai,Ban Naun Jan,Muang Nakaun Thai,Muang Nakawn Tai,Muang Nakhon Thai,Nagorndhai,Nakhon Thai,Nakon Thai,Noan Chanta,Non Chan,nkhrthiy,นครไทย', 17.1005600, 100.8373900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126126, 'Nakhon Sawan', 'Nakhon Sawan', 'Amphoe Muang Nakhon Sawan,Changwat Muang Nakhon Sawan,Changwat Nakhon Sawan,Muang Nagorn Sawarn,Muang Nakawn Sawan,Muang Nakhon Savan,Muang Nakhon Sawan,Mueang Nakhon Sawan,Nagara Sawan,Nagor Svarga,Nagorn Sawarn,Nakaun Sawan,Nakawan Sawn,Nakawn Sawan,Nakhaun Sawan,Nakhon Sawan,Nakhonsavanas,Nakkhonsavan,Naklon Sawan,Nakon Sawan,Nakorn Sawan,bei lan po,nakonsawan,nkhrswrrkh,thesbal nkhr nkhrswrrkh,Накхонсаван,نکھون سوان,นครสวรรค์,เทศบาลนครนครสวรรค์,ན་ཁཱོན་ས་ཝན།,ナコーンサワン,北欖坡,나콘사완', 15.7047200, 100.1371700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126127, 'Nakhon Ratchasima', 'Nakhon Ratchasima', 'Amphoe Muang Nakhon Ratchasima,Changwat Nakhon Rarchasima,Changwat Nakhon Rat Sima,Corat,Khorat,Korat,Koyat,Lungsod ng Nakhon Ratchasima,Muang Nakawn Rachasima,NAK,Nagara Rajasima,Nagor Rajashima,Nagor Rajasima,Nakhaun Rachasima,Nakhon Ratcasima,Nakhon Ratchasim,Nakhon Ratchasima,Nakhon Ratchsima,Nakhon Ratcsaszima,Nakhon Ratczasima,Nakhon Ratčasima,Nakhonratcasim,Nakhonratcasima,Nakhonratsima,Nakhonratčasim,Nakhonratčasima,Nakkhonratchasima,Nakonrajsima,Nakonratchasima,Nakorn Rajsima,a le,nakhwn ratshasyma,nakonlaschasima,nakonrachashima,nkhrrachsima,thesbal nkhr nkhrrachsima,Накхонратчасима,ناخون راتشاسيما,ناکھون راتچاسیما,نکھون راٹچاسیما,นครราชสีมา,เทศบาลนครนครราชสีมา,ན་ཁཱོན་ར་ཊི་ཅ་སི་མ།,នគររាជសីមា,ナコーンラーチャシーマー,呵叻,나콘랏차시마', 14.9706600, 102.1019600, 'TH', '2011-05-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126128, 'Nakhon Phanom', 'Nakhon Phanom', 'Amphoe Muang Nakhon Phanom,Amphoe Nong Buek,Ban Nakhon Phnom,Changwat Muang Nakhon Phanom,Changwat Nakhon Phanom,KOP,Lakhon,Muang Nakhon Phanom,Mueang Nakhon Phanom,Nagorn Bhanom,Nakawn Panom,Nakhaun Phanom,Nakhon Phanom,Nakol Phanom,Nakon Panom,Nakorn Panom,Naung Bua,Nong Buk,nkhrphnm,นครพนม', 17.4108100, 104.7785600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126129, 'Nakhon Pathom', 'Nakhon Pathom', 'Amphoe Muang Nakhon Pathom,Changwat Nakhon Chai Si,Changwat Nakhon Pathom,Monthon Nakhon Chai Si,Mueang Nakhon Pathom,Nagara Pathom,Nagorn Pathom,Nakawn Patom,Nakhaun Pathom,Nakhon Chai Si,Nakhon Pathom,Nakkhonpatkhom,Nakon Patom,fu tong,nakhwn batwm,nakonpatomu,nakonppatom,nkhrpthm,thesbal nkhr nkhrpthm,Накхонпатхом,ناخون باتوم,ناکھون پاتھوم,นครปฐม,เทศบาลนครนครปฐม,ナコーンパトム,佛统,나콘빠톰', 13.8196000, 100.0442700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126130, 'Nakhon Nayok', 'Nakhon Nayok', 'Amphoe Muang Nakhon Nayok,Amphoe Nakhon Nayok,Changwat Nakhon Nayok,Muang Nagorn Nayok,Muang Nakawn Nayok,Muang Nakhon Nayok,Mueang Lablae,Mueang Nakhon Nayok,Nagorn Nayok,Nakaunnayok,Nakaunnoyok,Nakhaun Nayok,Nakhon Nauok,Nakhon Nayok,Nakon Nayok,Nayok,nkhrnayk,นครนายก', 14.2046300, 101.2129500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126131, 'Nakhon Luang', 'Nakhon Luang', 'Amphoe Nakhon Klang,Amphoe Nakhon Luang,Amphu Luang,Ban Nakhon Luang,Hluang,Hlūang,Nakhon Luang,nkhrhlwng,นครหลวง', 14.4628100, 100.6083200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126132, 'Nakhon Chai Si', 'Nakhon Chai Si', 'Amphoe Nakhon Chai,Amphoe Nakhon Chai Si,Ban Pak Nam,Mueang Nakhon Chai Si,Nagorn Jaisri,Nakhon Chai Si,Talat Amphoe Nakhon Chai Si,nkhrchaysri,นครชัยศรี', 13.8012600, 100.1845100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126133, 'Na Kae', 'Na Kae', 'Amphoe Ban Na Kae,Amphoe Na Kae,Amphoe Nakel,Amphoe Nong Sun,Ban Na Kae,Ban Na Ke,King Amphoe Na Kae,Mueang Kabin,Na Kae,Nakel,nahwa,นาหว้า', 16.9464500, 104.5008100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126134, 'Na Chueak', 'Na Chueak', 'Amphoe Na Chueak,Ban Na Chuak,King Amphoe Na Chueak,Na Chuak,Na Chueak,nacheuxk,นาเชือก', 15.7933900, 103.0318400, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126135, 'Na Chaluai', 'Na Chaluai', 'Amphoe Na Chaluai,Ban Na Chaluai,King Amphoe Na Chaluai,Na Chaluai,nacahlwy,นาจะหลวย', 14.5204600, 105.2447800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126136, 'Mukdahan', 'Mukdahan', 'Amphoe Mueang Mukdahan,Amphoe Mukdahan,Ban Mouk,Ban Si Mongkhon,Ban Srimongkhon,Makdaharn,Mokdaharn,Muang Ban Muk Dahan,Muang Muk Da Han,Mueang Mukdahan,Mueng Mukdahan,Muk,Mukdahan,Mukdaharn,Mukdakhan,Mukdatarn,Si Mongkhon,Srimongkhon,mukdahar,Мукдахан,มุกดาหาร', 16.5453100, 104.7235100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126137, 'Mueang Suang', 'Mueang Suang', 'Amphoe Muang Suang,Amphoe Mueang Suang,King Amphoe Mueang Suang,Mueang Suang,meuxngsrwng,เมืองสรวง', 15.8219200, 103.7288400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126138, 'Muang Sam Sip', 'Muang Sam Sip', 'Amphoe Kasem Sima,Amphoe Muang Sam Sip,Amphoe Utara Ubon,Ban Muang Samsip,Muang Nam Sip,Muang Sam Sip,mwngsamsib,ม่วงสามสิบ', 15.5130700, 104.7256500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126139, 'Min Buri', 'Min Buri', 'Amphoe Min Buri,Min Buri,minburi,มีนบุรี', 13.8140700, 100.7313500, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126140, 'Moeiwadi', 'Moeiwadi', 'Amphoe Moei Wadi,King Amphoe Moei Wadi,Meyawadi,Moei Wadi,Moeiwadi,mey wdi,เมยวดี', 16.3894400, 104.1572000, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126141, 'Mayo', 'Mayo', 'Amphoe Ma Yo,Amphoe Rako,Ban Majo,Ban Mayau,Ban Mayo,Ban Māyau,Kampong Ma Yau,Kampong Mayo,Ma Yau,Ma Yo,Mayo,mayx,มายอ', 6.7186400, 101.4098300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126142, 'Manorom', 'Manorom', 'Amphoe Manorom,Ban Khung Samphao,Ban Kung Samphao,Ban Manorom Nua,Khung Samphao,King Amphoe Manorom,Manorom,Muang Manorom,mnormy,มโนรมย์', 15.3099700, 100.0828300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126143, 'Mancha Khiri', 'Mancha Khiri', 'Amphoe Kut Kao,Amphoe Kut Khao,Amphoe Mancha Khiri,Ban Han,Koot Kao,Kut Khao,Mancha Khiri,maycakhiri,มัญจาคีรี', 16.1304800, 102.5371200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126144, 'Makham', 'Makham', 'Amphoe Makham,Amphoe Tha Luang,Ban Makham,Makham,makham,มะขาม', 12.6729200, 102.1957500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126145, 'Mai Kaen', 'Mai Kaen', 'Amphoe Mai Kaen,Ban Mai Kaen,Ban Maiken,King Amphoe Mai Kaen,Mai Kaen,ไม้แก่น', 6.6097500, 101.6668600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126146, 'Maha Sarakham', 'Maha Sarakham', 'Amphoe Muang Maha Sarakham,Ban Khlong Khleng,Ban Lat,Ban Talat,Changwat Maha Sarakham,Maha Saragam,Maha Sarakam,Maha Sarakham,Mueang Maha Sarakham,Talat,Uthai Sarakham,mhasarkham,มหาสารคาม', 16.1848300, 103.3006700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126147, 'Maha Rat', 'Maha Rat', 'Amphoe Maharat,Ban Hua Phai,Ban Maha Rat (2),Khwaeng Nakhon Yai,Maha Rat,Maharaj,Mahāraj,mharach,มหาราช', 14.5336700, 100.5267200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126148, 'Maha Chana Chai', 'Maha Chana Chai', 'Amphoe Fa Yat,Amphoe Maha Chana Chai,Han Chai Chana,Maha Chana Chai,Mueang Maha Chana Chai,mhachnachay,มหาชนะชัย', 15.5293500, 104.2384700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126149, 'Mae Charim', 'Mae Charim', 'Mae Charim,แม่จริม', 18.7061400, 101.0057000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126150, 'Lop Buri', 'Lop Buri', 'Amphoe Muang Lop Buri,Ban Tha Hin,Changwat Lop Buri,Changwat Thahanbok Lop Buri,KKM,Lava Pura,Lavo,Lobh Buri,Lop Buri,Lopburi,Muang Lobh Buri,Muang Lopburi,Muang Xop Buri,Mueang Lop Buri,Tha Hin,lphburi,robburi,Лопбури,ลพบุรี,ロッブリー', 14.7980800, 100.6539700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126151, 'Lom Sak', 'Lom Sak', 'Amphoe Lom Sak,Amphoe Wat Pa,Ban Lom Sak,Changwat Muang Hlom Sak,Changwat Muang Lom Sak,Hlomsak,Lom Sak,Muang Hlom Sak,Muang Lom Sak,Wat Pa,hlmsak,หล่มสัก', 16.7798300, 101.2422500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126152, 'Lom Kao', 'Lom Kao', 'Amphoe Lom Kao,Ban Lom Gao,Ban Lom Kao,Bān Lom Gāo,Hlomkao,Lom Kao,Mong Lom Kao,Möng Lom Kao,hlmkea,หล่มเก่า', 16.8861400, 101.2289400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126153, 'Loeng Nok Tha', 'Loeng Nok Tha', 'Amphoe Loeng Nok Tha,King Amphoe Loeng Nok Tha,Loeng Nok Tha,leingnktha,เลิงนกทา', 16.2075000, 104.5552800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126154, 'Loei', 'Loei', 'Amphoe Muang Loei,Changwat Loei,Changwat Muang Lai,Changwat Muang Loei,LOE,Leui,Loeh,Loei,Loey,Muang Lai,Muang Leoi,Muang Loei,Muang Loeui,Muang Loi,Mueang Loei,ley,Лоэ,เลย', 17.4905200, 101.7274900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126155, 'Lat Lum Kaeo', 'Lat Lum Kaeo', 'Amphoe Lat Hlumkeo,Amphoe Lat Lum Kaeo,Amphoe Rahaeng,Ban Rahaeng (1),Lat Lum Kaeo,ลาดหลุมแก้ว', 14.0372800, 100.4048600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126156, 'Lat Bua Luang', 'Lat Bua Luang', 'Amphoe Lat Bua Luang,Ban Khlong Phraya Ban,Ban Khlong Phraya Banru,Ban Klong Phya Banroe,Ban Lat Bua Luang,Khlong Phraya Banlu,King Amphoe Lat Bua Luang,Lat Bua Luang,ladbawhlwng,ลาดบัวหลวง', 14.1657200, 100.3078900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126157, 'Lap Lae', 'Lap Lae', 'Amphoe Lap Lae,Amphu Lubla,Ban Yang Gadai,Ban Yang Kadai,Bān Yāng Gadāi,Lap Lae,Lap Lea,Lap Lēa,Yang Kadai,ลับแล', 17.6521100, 100.0389200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126158, 'Lam Plai Mat', 'Lam Plai Mat', 'Amphoe Lam Plai Mat,Ban Lam Plai Mat,King Amphoe Lam Plai Mat,Lam Plai Mat,la playmas,ลำปลายมาศ', 15.0252000, 102.8389400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126159, 'Lam Luk Ka', 'Lam Luk Ka', 'Amphoe Lam Luk Ka,Ban Lam Luk Ka,Lam Luk Ka,Luk Ka,Lūk Ka,lalukka,ลำลูกกา', 13.9322600, 100.7493700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126160, 'Lamduan', 'Lamduan', 'Amphoe Lamduan,Ban Lamduan,King Amphoe Lamduan,Lamduan,Muang Sarapin,Muang Suraphin,Muang Surapin,Mueang Suraphi Nathon Nikhom,Surapin,ladwn,ลำดวน', 14.7220500, 103.6693400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126161, 'Lahan Sai', 'Lahan Sai', 'Amphoe Lahan Sai,Ban Lahan Sai,Ban Laharn Sai,King Amphoe Lahan Sai,Lahan Sai,lahanthray,ละหานทราย', 14.4114200, 102.8593600, 'TH', '2014-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126162, 'Laem Sing', 'Laem Sing', 'Amphoe Laem Sing,Amphoe Phlio,Laem Sing,Naiamphur,แหลมสิงห์', 12.4816400, 102.0737500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126163, 'Laem Ngop', 'Laem Ngop', 'Amphoe Kau Chang,Amphoe Ko Chang,Amphoe Kohjang,Amphoe Laem Ngop,Ban Laem Ngop,Ban Rian Va,Kau Chang,Laem Ngaup,Laem Ngop,Laem Ngorb,Lem Ngop,แหลมงอบ', 12.1716900, 102.3948900, 'TH', '2016-10-26', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126164, 'Kut Khaopun', 'Kut Khaopun', 'Amphoe Kut Khaopun,King Amphoe Kut Khaopun,Kut Khaopun,kudkhawpun,กุดข้าวปุ้น', 15.7926700, 104.9981400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126165, 'Kut Chum', 'Kut Chum', 'Amphoe Kut Chum,Ban Kut Chum,King Amphoe Kut Chum,Kut Chum,kudchum,กุดชุม', 16.0328900, 104.3393600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126166, 'Kut Chap', 'Kut Chap', 'Amphoe Kut Chap,Ban Kut Chap,King Amphoe Kut Chap,Kut Chap,kudcab,กุดจับ', 17.4257000, 102.5669200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126167, 'Kut Bak', 'Kut Bak', 'Amphoe Kut Bak,Ban Kot Bak,Ban Kut Bak,King Amphoe Kut Bak,Kudpak,Kut Bak,kudbak,กุดบาก', 17.0888200, 103.8187500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126168, 'Kusuman', 'Kusuman', 'Amphoe Kusuman,Ban Kusuman,Ban Muang Kusuman,King Amphoe Kusuman,Kusuman,Muang Kusuman,Mueang Kusuman,Muong Kout Sa Man,Tambon Kusuman,kusumaly,กุสุมาลย์', 17.3325900, 104.3314700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126169, 'Kumphawapi', 'Kumphawapi', 'Amphoe Kumphawapi,Kumphawapi,Mueang Kumphawapi,kumphwapi,กุมภวาปี', 17.1087500, 103.0148700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126170, 'Kuchinarai', 'Kuchinarai', 'Amphoe Kuchinarai,Ban Bua Khao,Bua Khao,Kuchinarai,ku chin a ray n,กุฉินารายณ์', 16.5410000, 104.0500400, 'TH', '2013-12-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126171, 'Bangkok', 'Bangkok', 'Amphoe Phra Nakhon,BKK,Ban''nkok,Bancac,Bancocum,Bancoque,Bancác,Banghok,Bangkok,Bangkok Metropolis,Bangkoka,Bangkòk,Banguecoque,Bankok,Bankokas,Bankoko,Banqkok,Changwat Phra Nakhon,Krung Thep,Krung Thep Maha Nakhon,Krung Thep Maha Nakhon Amon Rattanakosin Mahintarayutthaya Maha Dilok Phop Noppharat Ratchathani Buri Rom Udom Ratchaniwet Maha Sathan Amon Phiman Awatan Sathit Sakka Thattiya Witsanukam Prasit,Krungdeb,Man-kuk,Màn-kuk,Phra Nakhon,Siayuthia,The City of Angels,bainkaka,bainkoka,bamkoka,bangkog,bangkwk,bankeakk,bankoku,bankwk,bngqwq,bnkak,byankak,byankaka,camraata byankaka,krungtheph,krungthephmhankhr,krungtheph‡,man gu,penkak,Μπανγκόκ,Бангкок,Банкок,Баҥкок,Բանգկոկ,באנגקאק,בנגקוק,بانكوك,بانکوک,بانکۆک,بانګکوک,بانگكوك,بنکاک,बँकॉक,बैंकक,बैंकॉक,চাংৱাত ব্যাংকক,ব্যাংকক,ਬੈਂਕਾਕ,பேங்காக்,ಬ್ಯಾಂಕಾಕ್,ബാങ്കോക്ക്,බැංකොක්,กรุงเทพ,กรุงเทพมหานคร,กรุงเทพฯ,ບາງກອກ,པན་ཀོག,ဘန်ကောက်မြို့,ბანგკოკი,ባንኮክ,バンコク,曼谷,방콕', 13.7539800, 100.5014400, 'TH', '2017-03-29', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126172, 'Krok Phra', 'Krok Phra', 'Amphoe Krok Phra,Amphu Krok Pra,Ban Grauk Phra,Ban Krok Phra,Bān Grauk Phra,Krok Bhra,Krok Phra,Noen Sala,korkphra,โกรกพระ', 15.5558900, 100.0715300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126173, 'Krathum Baen', 'Krathum Baen', 'Amphor Kathum Baen,Ban Krathum Baen,Ban Talat Kathum Baen,Kathum Baen,Krathu Baen,Krathum Baen,Krathumban,Talat Kathum Baen,กระทุ่มแบน', 13.6533000, 100.2597200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126174, 'Krasang', 'Krasang', 'Amphoe Krasang,King Amphoe Krasang,Krasang,krasang,กระสัง', 14.9237500, 103.3036900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126175, 'Krasae Sin', 'Krasae Sin', 'Amphoe Krasae Sin,King Amphoe Krasae Sin,Kra Sae Sin,Krasae Sin,กระแสสินธุ์', 7.6154800, 100.3284200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126176, 'Kranuan', 'Kranuan', 'Amphoe Kranuan,King Amphoe Kranuan,Kranuan,kranwn,กระนวน', 16.7067200, 103.0787800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126177, 'Kosum Phisai', 'Kosum Phisai', 'Amphoe Kosum Phisai,Ban Hua Khwang,Kosum Phisai,Kosumbhisai,Mahasarakam,Muang Kossoum,Muang Kossum,Muang Kosum,kosumphisay,โกสุมพิสัย', 16.2485800, 103.0673900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126178, 'Ko Si Chang', 'Ko Si Chang', 'Amphoe Ko Si Chang,King Amphoe Ko Si Chang,Ko Si Chang,keaasichang,เกาะสีชัง', 13.1638900, 100.8054700, 'TH', '2017-04-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126179, 'Klaeng', 'Klaeng', 'Amphoe Klaeng,Ban Sam Yan,Ban Thang Kwian,Klaeng,Kleng,Klēng,Mueang Klaeng,Thang Kwian,ต.แกลง,แกลง', 12.7797200, 101.6483100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126180, 'Khun Han', 'Khun Han', 'Amphoe Khun Han,Ban Kabin Han,Ban Kabintharahan,Ban Khun Han,Khun Han,King Amphoe Khun Han,khunhay,ขุนหาญ', 14.6173900, 104.4250600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126181, 'Khu Mueang', 'Khu Mueang', 'Amphoe Khu Mueang,Khu Muang,Khu Mueang,King Amphoe Khu Mueang,khumeuxng,คูเมือง', 15.2716000, 103.0016700, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126182, 'Khu Khan', 'Khu Khan', 'Amphoe Huai Nua,Amphoe Huaihnoea,Amphoe Khukhan,Amphoe Kukhan,Ban Chan,Ban Huai Nua,Huai Nua,Khu Khan,Kokhan,Muang Khan,Muang Khukhan,Muang Ku Kan,khukhanth,ขุขันธ์', 14.7135800, 104.1983600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126183, 'Khuan Niang', 'Khuan Niang', 'Amphoe Khuan Niang,Ban Khuan Niang,Ban Khuan Niang Nai,Khuan Niang,King Amphoe Khuan Niang,khwn neiyng,ควนเนียง', 7.1913800, 100.3535500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126184, 'Khuan Khanun', 'Khuan Khanun', 'Amphoe Khuan Khanun,Amphoe Makok Tai,Amphoe Pak Phra,Amphoe Phanang Tung,Amphoe Tale Noi,Amphoe Udon,Khuan Khanun,khwnkhnun,ควนขนุน', 7.7347000, 100.0093100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126185, 'Khuan Kalong', 'Khuan Kalong', 'Amphoe Khuan Kalong,Khuan Ka Long,Khuan Kalong,King Amphoe Khuan Kalong,khwnkahlng,ควนกาหลง', 6.8453800, 100.0714800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126186, 'Khueang Nai', 'Khueang Nai', 'Amphoe Khuang Nai,Amphoe Pachin Udon,Amphoe Trakan Phuet Phon,Ban Khuang Nai,Khuang Nai,Khueang Nai,เขื่องใน', 15.3898900, 104.5508300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126187, 'Khuan Don', 'Khuan Don', 'Amphoe Khuan Don,Duson,Khuan Don,King Amphoe Khuan Don,khwndon,ควนโดน', 6.7875800, 100.0777800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126188, 'Kho Wang', 'Kho Wang', 'Amphoe Kho Wang,Ban Non Kho,Kho Wang,khxwang,ค้อวัง', 15.3699800, 104.3523100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126189, 'Khon Sawan', 'Khon Sawan', 'Amphoe Khon Sawan,Ban Chok Don Sawan,Khon Sawan,Mueang Ka Long,khxnswrrkh,คอนสวรรค์', 15.9319200, 102.2810300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126190, 'Khon San', 'Khon San', 'Amphoe Khon San,Ban Nam Phrom,Ban Nam Phron,Khon San,King Amphoe Khon San,khxn sar,คอนสาร', 16.6128600, 101.9194400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126191, 'Khon Kaen', 'Khon Kaen', 'Amphoe Muang Khon Kaen,Amphoe Phralap,Amphoe Pralap,Changwat Khon Kaen,Changwat Muang Khon Kaen,KKC,Kawn Ken,Khohn Ken,Khon Kaen,Khon Kan,Khon Khen,Khonkean,Khonken,Khonkenas,Khonkhaen,Kkhonkehn,Konkahen,Muang Kaun Gean,Muang Khaunkaen,Muang Khon Kaen,Mueang Khon Kaen,khxnkæn,kong jing,konkkaen,kun jing shi,Кхонкэн,קון קאן,کھون کائن,کھون کیئن,ขอนแก่น,เทศบาลนครขอนแก่น,เมืองขอนแก่น,坤敬市,孔敬,콘깬', 16.4467100, 102.8330000, 'TH', '2015-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126192, 'Khong Chiam', 'Khong Chiam', 'Amphoe Khong Chiam,Ban Dan,Ban Dan Kao,Khon Chiam,Khong Chiam,Khwaeng Khong Chiam,King Amphoe Ban Dan,khongceiym,โขงเจียม', 15.3185600, 105.4950600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126193, 'Khong', 'Khong', 'Amphoe Khong,Khong,King Amphoe Khong,Mueang Khong,khng,คง', 15.4439300, 102.3286200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126194, 'Khon Buri', 'Khon Buri', 'Amphoe Khon Buri,Ban Khon Buri,Khon Buri,King Amphoe Chae,Mueang Khon,khrburi,ครบุรี', 14.5254100, 102.2459100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126195, 'Khok Si Suphan', 'Khok Si Suphan', 'Amphoe Khok Si Suphan,Khok Si Suphan,King Amphoe Khok Si Suphan,khok srisuphrrn,โคกศรีสุพรรณ', 17.0450700, 104.2756000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126196, 'Khok Samrong', 'Khok Samrong', 'Amphoe Khok Samrong,Khok Samrong,King Amphoe Khok Samrong,khoksarong,โคกสำโรง', 15.0664900, 100.7223300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126197, 'Khok Pho', 'Khok Pho', 'Amphoe Khok Pho,Amphoe Makrut,Khok Pho,Mueang Kao,khokphothi,โคกโพธิ์', 6.7306400, 101.0961900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126198, 'Khok Charoen', 'Khok Charoen', 'Amphoe Khok Charoen,Ban Khok Charoen,Khok Charoen,King Amphoe Khok Charoen,khok ceriy,โคกเจริญ', 15.3792700, 100.8187000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126199, 'Khlung', 'Khlung', 'Amphoe Khlung,Ban Khlung,Khlung,Kkhlung,khlung,Кхлунг,ขลุง', 12.4546700, 102.2214200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126200, 'Khlong Yai', 'Khlong Yai', 'Amphoe Khlong Yai,Ban Khlong Yai,Khlaung Yai,Khlong,Khlong Yai,King Amphoe Khlong Yai,King Khlong Yai,Klongyai,khlxnghıy,คลองใหญ่', 11.7764500, 102.8856700, 'TH', '2015-03-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126201, 'Khlong San', 'Khlong San', 'Amphoe Khlong San,Khlong San,khlxngsan,คลองสาน', 13.7308600, 100.5090300, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126202, 'Khlong Luang', 'Khlong Luang', 'Amphoe Bang Wai,Amphoe Khlong Luang,Ban Bang Wai,Ban Khlong Song (3),Bang Wai,Khlong Luang,khlxnghlwng,คลองหลวง', 14.0646700, 100.6457800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126203, 'Khlong Hat', 'Khlong Hat', 'Amphoe Khlong Hat,Ban Khlong Mahat,Khlong Had,Khlong Hat,King Amphoe Khlong Hat,khlxng had,คลองหาด', 13.4517700, 102.2982300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126204, 'Khemarat', 'Khemarat', 'Amphoe Ban Khemmarat,Amphoe Khemmarat,Amphoe Khemrat,Ban Kemmerat,Ban Khemmarat,Ban Khemrat,Kemarat,Kemmarat,Khemarat,Khemmarat,Muang Kemmarat,Mueang Khemarat,khemrath,เขมราฐ', 16.0425200, 105.2183600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126205, 'Khao Wong', 'Khao Wong', 'Amphoe Khao Wong,Khao Wong,King Amphoe Khao Wong,kheawng,เขาวง', 16.7000800, 104.0901900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126206, 'Khao Saming', 'Khao Saming', 'Amphoe Khao Saming,Amphoe Si Bua Thong,Amphoe Thung Yai,Ban Khao Saming,Khao Saming,kheasming,เขาสมิง', 12.3535300, 102.4355000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126207, 'Khao Chaison', 'Khao Chaison', 'Amphoe Khao Chai Son,Khao Chai Son,Khao Chaison,King Amphoe Chaison,King Amphoe Lampam,kheachaysn,เขาชัยสน', 7.4612500, 100.1337200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126208, 'Kham Thale So', 'Kham Thale So', 'Amphoe Kham Thale So,Ban Kham Tale So,Ban Kham Thale So,Kham Thale So,King Amphoe Kham Thale So,khamthalesx,ขามทะเลสอ', 14.9608300, 101.9478900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126209, 'Kham Ta Kla', 'Kham Ta Kla', 'Amphoe Kham Ta Kla,Ban Kham Ta Kla,Ban Kham Takra,Kham Ta Kla,King Amphoe Kham Ta Kla,khatakla,คำตากล้า', 17.8523100, 103.7565700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126210, 'Kham Sakae Saeng', 'Kham Sakae Saeng', 'Amphoe Kham Sakae Saeng,Kham Sakae Saeng,King Amphoe Kham Sakae Saeng,ขามสะแกแสง', 15.3322100, 102.1727800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126211, 'Kham Muang', 'Kham Muang', 'Amphoe Kham Muang,Kham Muang,King Amphoe Kham Muang,khamwng,คำม่วง', 16.9290200, 103.6351800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126212, 'Kham Khuean Kaeo', 'Kham Khuean Kaeo', 'Amphoe Kham Khuan Kaeo,Amphoe Lumphuk,Ban Lumphuk,Kham Khuan Kaeo,Kham Khuean Kaeo,Lum Phuk,คำเขื่อนแก้ว', 15.6523300, 104.3086100, 'TH', '2016-11-15', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126213, 'Khamcha-i', 'Khamcha-i', 'Amphoe Kham Cha-i,Ban Nam Thiang,Khamcha-i,King Amphoe Khamcha-i,khachaxi,คำชะอี', 16.5776400, 104.4195600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126214, 'Kaset Wisai', 'Kaset Wisai', 'Amphoe Kaset Wisai,Kaset Wisai,Nong Waeng,เกษตรวิสัย', 15.6555800, 103.5836100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126215, 'Kaset Sombun', 'Kaset Sombun', 'Amphoe Kaset Sombun,Ban Yang,Kaset Sombun,King Amphoe Kaset Sombun,เกษตรสมบูรณ์', 16.2805300, 101.9542200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126216, 'Kao Liao', 'Kao Liao', 'Amphoe Kao Liao,Kao Liao,Kao Lieo,King Amphoe Kao Liao,kealeiyw,เก้าเลี้ยว', 15.8505300, 100.0791400, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126217, 'Kantharawichai', 'Kantharawichai', 'Amphoe Kantharawichai,Kantharawichai,kanthrwichay,กันทรวิชัย', 16.3271900, 103.2986400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126218, 'Kanthararom', 'Kanthararom', 'Amphoe Kanthararom,Kanthararom,Uthai Sisaket,kanthrarmy,กันทรารมย์', 15.1032300, 104.5734300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126219, 'Kantharalak', 'Kantharalak', 'Amphoe Kantharalak,Amphoe Nam Om,Ban Nam Om,Kanthanalak,Kantharalak,Kantkharalak,Muang Uthumpa,Muang Uthumpau,Mueang Uthumphon Phisai,Muong Utumpar,Nam Aum,Кантхаралак,กันทรลักษณ์', 14.6405600, 104.6499200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126220, 'Krong Pi Nang', 'Krong Pi Nang', 'Amphoe Krong Pinang,Ban Krong Pi Nang,Kampong Pinang,Kampung Pinang,King Amphoe Krong Pinang,Krong Pi Nang,Krong Pinang,ba nk rng pinang,krng pinang,กรงปินัง,บ้านกรงปินัง', 6.4112000, 101.2739400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126221, 'Su-ngai Padi', 'Su-ngai Padi', 'Amphoe Sungai Padi,Ban Su-ngai Pa Di,Kampong Padai,Su-ngai Pa Di,Su-ngai Padi,Sungai Padi,ban suhingpadi,suhingpadi,บ้านสุไหงปาดี,สุไหงปาดี', 6.0857000, 101.8795900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126222, 'Ka Bang', 'Ka Bang', 'Amphoe Kabang,Ban Ka Bang,Ka Bang,Kabae,Kabang,Kabe,Kampong Kebang,King Amphoe Kabang,ban ka bang,ka bang,กาบัง,บ้านกาบัง', 6.4153600, 101.0545600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126223, 'Cho-airong', 'Cho-airong', 'Amphoe Cho-airong,Ban Cho-airong,Cho-airong,Kampong Chae Raung,Kampong Chaerong,King Amphoe Cho-airong,ban ceaa xi rxng,ceaa xi rxng,บ้านเจาะไอร้อง,เจาะไอร้อง', 6.2255300, 101.8112800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126224, 'Kamphaeng Saen', 'Kamphaeng Saen', 'Amphoe Kamphaeng Saen,KDT,Kamphaeng Saen,Kamphaeng Soen,กำแพงแสน', 13.9996600, 99.9898100, 'TH', '2013-05-10', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126225, 'Kamalasai', 'Kamalasai', 'Amphoe Kamalasai,Ban Amphoe Kamalasai,Ban Komlasai,Kamalasai,Komlasai,Kramalasai,kmla siy,kra mala siy,กมลาไสย,กระมาลาไสย', 16.3383900, 103.5756400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126226, 'Kalasin', 'Kalasin', 'Amphoe Hlup,Amphoe Kalasin,Amphoe Lup,Amphoe Muang Kalasin,Ban Neur,Changwat Kalasin,Changwat Muang Kalasin,Kalasim,Kalasin,Kalasindhu,Lup,Muang Kalasim,Muang Kalasin,Muang Kalassim,Muang Kansin,Mueang Kalasin,kalsinthu,Каласин,กาฬสินธุ์', 16.4328100, 103.5065800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126227, 'Kaeng Khoi', 'Kaeng Khoi', 'Amphoe Kaeng Khoi,Kaeng Khoi,Khwaeng Kaeng Khoi,แก่งคอย', 14.5861700, 100.9975800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126228, 'Kaeng Khro', 'Kaeng Khro', 'Amphoe Kaeng Khlo,Amphoe Kaeng Khro,Kaeng Khlo,Kaeng Khro,แก้งคร้อ', 16.1086400, 102.2580800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126229, 'Kae Dam', 'Kae Dam', 'Amphoe Kae Dam,Kae Dam,King Amphoe Kae Dam,แกดำ', 16.0239700, 103.3844400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126230, 'Kabin Buri', 'Kabin Buri', 'Amphoe Kabin Buri,Ban Kabin Buri,Kabin Buri,Mong Krabin,Mueang Kabin Buri,kbinthrburi,กบินทร์บุรี', 13.9511400, 101.7176900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126231, 'In Buri', 'In Buri', 'Amphoe In Buri,Amphoe Muang In Buri,Ban In Buri,In,In Buri,Muang Inburi,Mueang In Buri,xinthrburi,อินทร์บุรี', 15.0078700, 100.3269100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126232, 'Hua Taphan', 'Hua Taphan', 'Amphoe Hua Taphan,Ban Hua Tapan,Ban Hua Taphan,Hua Taphan,King Amphoe Hua Taphan,ban hawtaphan,hawtaphan,บ้านหัวตะพาน,หัวตะพาน', 15.6971000, 104.4916000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126233, 'Hua Sai', 'Hua Sai', 'Amphoe Hua Sai,Amphoe Khao Phang Krai,Ban Hua Sai,Ban Hua Zai,Hua Sai,Hua Zai,King Amphoe Hua Sai,hawthir,หัวไทร', 8.0440800, 100.3058600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126234, 'Huai Thap Than', 'Huai Thap Than', 'Amphoe Huai Thap Than,Huai Thap Than,King Amphoe Huai Thap Than,hwythabthan,ห้วยทับทัน', 15.0533300, 104.0275400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126235, 'Huai Thalaeng', 'Huai Thalaeng', 'Amphoe Huai Thalaeng,Ban Huai Thalaeng,Huai Thalaeng,King Amphoe Huai Thalaeng,Tambon Huai Thalaeng,ห้วยแถลง', 14.9970100, 102.6474600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126236, 'Huai Phueng', 'Huai Phueng', 'Amphoe Huai Phueng,Huai Phueng,Huai Phung,King Amphoe Huai Phueng,hwy phung,ห้วยผึ้ง', 16.6503800, 103.9100500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126237, 'Huai Mek', 'Huai Mek', 'Amphoe Huai Mek,Ban Huai Mek,Huai Mek,King Amphoe Huai Mek,hwymek,ห้วยเม็ก', 16.5897500, 103.2354700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126238, 'Hat Yai', 'Hat Yai', 'Amphoe Hat Yai,Ban Haad Yai,Ban Hat Yai,HDY,Haad Yai,Had Yai,Hat Yai,Hatjaj,Hatjajus,Khat Jai,Khatujaj,has-yai,hat yay,hatoyai jun,he ai,Хат Јаи,Хатъяй,האד-יאי,هات ياي,ہات یائی,หาดใหญ่,เทศบาลนครหาดใหญ่,ཧ་ཊི་ཡའི།,ハートヤイ郡,合艾,핫야이', 7.0083600, 100.4766800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126239, 'Hankha', 'Hankha', 'Amphoe Hankha,Ban Han Kha,Ban Handa,Doem Bang Kao,Hankha,hankha,หันคา', 14.9812200, 100.0147000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126240, 'Fak Tha', 'Fak Tha', 'Amphoe Fak Tha,Ban Bung,Fak Tha,faktha,ฟากท่า', 17.9994800, 100.8801400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126241, 'Dusit', 'Dusit', 'Amphoe Dusit,Dusit,dusit,ดุสิต', 13.7775000, 100.5197700, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126242, 'Don Tan', 'Don Tan', 'Amphoe Don Tan,Don Tan,King Amphoe Don Tan,Tambon Don Tan,dxntal,ดอนตาล', 16.3169700, 104.9200000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126243, 'Dong Luang', 'Dong Luang', 'Amphoe Dong Luang,Ban Dong Luang,Dong Luang,King Amphoe Dong Luang,dnghlwng,ดงหลวง', 16.8158900, 104.5380000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126244, 'Don Chedi', 'Don Chedi', 'Amphoe Don Chedi,Ban Don Chedi,Don Chedi,King Amphoe Don Chedi,dxncediy,ดอนเจดีย์', 14.6349700, 100.0209700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126245, 'Doembang Nangbuat', 'Doembang Nangbuat', 'Amphoe Doem Bang,Amphoe Doembang Nangbuat,Amphu Deum Bang,Ban Cha-on,Ban Doem Bang,Ban Khao Cha-oi,Ban Khao Cha-on,Ban Tha Chang,Deum Bang,Deūm Bāng,Doem Bang,Doembang Nangbuat,Tha Chang,deimbangnangbwch,เดิมบางนางบวช', 14.8333300, 100.1000000, 'TH', '2016-11-15', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126246, 'Det Udom', 'Det Udom', 'Amphoe Det Udom,Amphoe Det Udon,Ban Muang Det,Ban Muang Detudom,Det,Det Udom,Det Udon,Muang Det,Mueang Det Udom,dechxudm,เดชอุดม', 14.9059800, 105.0783600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126247, 'Den Chai', 'Den Chai', 'Amphoe Den Chai,Ban Den Chai,Den Chai,denchay,เด่นชัย', 17.9837200, 100.0521700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126248, 'Dan Sai', 'Dan Sai', 'Amphoe Dan Sai,Amphoe Dan Zai,Daen Sai,Dan Sai,Dan Zai,Muang Daen Sai,Muang Dansai,dansay,ด่านซ้าย', 17.2801100, 101.1468600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126249, 'Dan Khun Thot', 'Dan Khun Thot', 'Amphoe Ban Han,Amphoe Dan Khun Thot,Amphoe Phan Chana,Dan Khun Thot,dankhunthd,ด่านขุนทด', 15.2085000, 101.7713800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126250, 'Chum Phuang', 'Chum Phuang', 'Amphoe Chum Phuang,Ban Kham,Chum Phuang,Chumpuang,King Amphoe Chum Phuang,chumphwng,ชุมพวง', 15.3486100, 102.7416100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126565, 'Yovon', 'Yovon', 'Jovon,Yavan,Yovan,Yovon,Ёвон', 38.3140800, 69.0378400, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126566, 'Vose’', 'Vose''', 'Aral,Imeni Vose,Kal Khaz,Kolkhozabad,Paytok,Vose'',Voseu,Vose’,Восеъ', 37.8039600, 69.6441700, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126567, 'Vorukh', 'Vorukh', 'Kalacha,Varukh,Vorukh,Ворух', 39.8512500, 70.5801200, 'TJ', '2012-09-06', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126568, 'Varzob', 'Varzob', 'Obi-Dzhuk,Varzob', 38.7736900, 68.8177600, 'TJ', '2011-08-04', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126569, 'Vanj', 'Vanj', 'Kala-i-Vanch,Rokharv,Vanch,Vanj,Ванҷ', 38.3707800, 71.4547400, 'TJ', '2012-01-17', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126570, 'Vakhsh', 'Vakhsh', 'Vakhsh,Vakhshstroi,Vakhshstroy,Вахш', 37.7148500, 68.8345600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126571, 'Istaravshan', 'Istaravshan', 'Bundzhikat,Istaravchan,Istaravsan,Istaravsanas,Istaravshan,Istaravsjan,Istaravson,Istaravŝan,Istaravšan,Istaravšanas,Istaravšon,Istaravșan,Istarawschan,Istarawshan,Istarawszan,Ura-Tyube,Uroteppa,astrwshn,iseuteulabeusyan,isutarafushan,yi si ta la fu shang,İstərövşən,Ŭroteppa,Істаравшан,Истаравшан,Истәраушан,استروشن,イスタラフシャン,伊斯塔拉夫尚,이스트라브샨', 39.9142000, 69.0032800, 'TJ', '2017-07-21', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126572, 'Tursunzoda', 'Tursunzoda', 'Regar,Tursunzade,Tursunzoda,Турсунзаде', 38.5143700, 68.2332700, 'TJ', '2013-10-29', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126573, 'Tavildara', 'Tavildara', 'Tavil''-Dara,Tavildara,Tavil’-Dara,Tovil''-Dora,Tovildara,Tovil’-Dora,Тавилдара', 38.6952900, 70.4842200, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126574, 'Tartiki', 'Tartiki', 'Tartiki,Tartki,Tartku,Тартики', 37.5822100, 68.1334700, 'TJ', '2012-07-04', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126575, 'Tagob', 'Tagob', 'Tabok,Tagob,Takob', 38.8382700, 68.8984700, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126576, 'Tajikobod', 'Tajikobod', 'Kalai-Lyabi-Ob,Tadzhikabad,Tajikobod', 39.1240500, 70.8400900, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126577, 'Sovet', 'Sovet', 'Kizyl-Mazar,Kizyl-Mazar-Bolo,Kyzul-Mazar-Bolo,Kyzyl-Mazar,Kyzyl-Mazar-Bolo,Kzyl-Mazar,Kzyl-Mazar-Bolo,Sovet,Sovetskiy,Sovetskoye,Sovety,Совет', 38.0467000, 69.5882200, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126578, 'Shŭrobod', 'Shurobod', 'Shurabad,Shuroabad,Shurobod,Shŭrobod,Шӯробод', 37.8413700, 70.0486500, 'TJ', '2012-11-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126579, 'Shahrinav', 'Shahrinav', 'Cheptura,Schachrinau,Shahr-e Now,Shahrinav,Shakhrinau,Shakhrinav,Shakhrinay,shhr nw,Шаҳринав,شهر نو', 38.5708500, 68.3349800, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126580, 'Shahriston', 'Shahriston', 'Shahriston,Shakhrislan,Shakhristan,Verkhne-Dal''yan,Verkhne-Dal’yan,Шаҳристон', 39.7744700, 68.8092900, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126581, 'Shahritus', 'Shahritus', 'Shaarfuz,Shaartuz,Shahritus,Shahrtuz,Шаҳритус', 37.2620600, 68.1384900, 'TJ', '2012-07-04', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126582, 'Rŭshon', 'Rushon', 'Kala-i-Warma,Kalai-Vamar,Rushan,Rushon,Rŭshon,Рӯшон', 37.9448700, 71.5574500, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126583, 'Roshtqal’a', 'Roshtqal''a', 'Rosht-Kala,Roshtqal''a,Roshtqal’a,Роштқалъа', 37.2582700, 71.8259100, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126584, 'Roghun', 'Roghun', 'Ragun,Roghun,Rogun', 38.7825700, 69.8708100, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126585, 'Qŭrghonteppa', 'Qurghonteppa', 'KQT,Kurgan Tjube,Kurgan-Tyube,Qurghan Tyube,Qurghonteppa,Qurghān Tyube,Qŭrghonteppa,Курган Тюбе,Қӯрғонтеппа', 37.8339900, 68.7818600, 'TJ', '2017-02-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126586, 'Panj', 'Panj', 'Baumanabad,Kirovabad,Kirowabad,Panj,Pyandzh,Sarai,Sarai-Kamar,Saray Komar,Saray-Kamar,Панҷ', 37.2363400, 69.0991100, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126587, 'Panjakent', 'Panjakent', 'Pandschakent,Pandzakent,Pandżakent,Pandžakent,Panjakent,Panjkent,Panxaquent,Pendjikent,Pendshikent,Pendzhakent,Pendzhikent,Pendzikentas,Pendzjikent,Pendžikentas,Penjikent,bnjknt,panjakenta,panjakenteu,panjikento,peng ji ken te,pnjknt,Панҷакент,Пенджикент,Пәнҗәкәнт,بنجكنت,پنجکنت,पंजाकॅन्त,パンジケント,彭吉肯特,판자켄트', 39.4952400, 67.6093100, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126588, 'Farkhor', 'Farkhor', 'Farkhor,Parkbar,Parkhar,Фархор', 37.4921900, 69.4035600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126589, 'Orzu', 'Orzu', 'Orzu,Орзу', 37.5582000, 68.8195200, 'TJ', '2013-09-06', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126590, 'Vahdat', 'Vahdat', 'Kofarnihon,Kofarnikhon,Kofarnikhona,Ordhonikidzeabad,Ordzhonikidzeabad,Orjonikidzeabad,Orjonikidzeobod,Vahdat,Vakhdat,Yangi-Bazar,Ваҳдат,Кофарнихона', 38.5563200, 69.0135400, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126591, 'Ismoili Somoní', 'Ismoili Somoni', 'Alchin,Chichka,Chichkhar,Ismoili Somon,Ismoili Somoni,Ismoili Somoní,Oktyabr''sh,Oktyabrsk,Oktyabr’sh,Исмоили Сомон', 37.7662700, 68.8012600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126592, 'Obikiik', 'Obikiik', 'Obikiik,Обикиик', 38.1603300, 68.6660500, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126593, 'Obigarm', 'Obigarm', 'Obigarm', 38.7173100, 69.7088500, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126594, 'Norak', 'Norak', 'Norak,Nurek,Норак', 38.3891700, 69.3227200, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126595, 'Novobod', 'Novobod', 'Navabad,Novabad,Novobod,Nusratobod,Nusstatobad,Shul''mak,Shul’mak', 39.0108400, 70.1508200, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126596, 'Murghob', 'Murghob', 'Margab,Murgab,Murghab,Murghabi,Murghob,Murghāb,Murghābi,Murgob,Pamir Post,Pamirski Post,Pamīrski Post,Post Pamirskiy,Pāmir Post,Мурғоб', 38.1702300, 73.9667400, 'TJ', '2012-12-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126597, 'Moskva', 'Moskva', 'Chubek,Moskovskiy,Moskva,Москва', 37.6610100, 69.6284900, 'TJ', '2012-11-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126598, 'Somoniyon', 'Somoniyon', 'Imeni Sardarova Karakhana,Koktasch,Koktash,Lenin,Leninskiy,Somonijon,Somoniyon,Сомониён', 38.4417300, 68.7745800, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126599, 'Mŭ’minobod', 'Mu''minobod', 'Leningrad,Leningradskiy,Mu''minobod,Muminabad,Muminobod,Mumynabad,Muuminobod,Mŭminobod,Mŭ’minobod,Мӯминобод,Мӯъминобод', 38.1071400, 70.0321300, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126600, 'Abdurahmoni Jomí', 'Abdurahmoni Jomi', 'Abdurahmoni Jomi,Abdurahmoni Jomí,Abduraҳmoni Ҷomi,Aral,Kuibyshevabad,Kujbishev,Kuybishev,Kuybishevsk,Kuybyshevabad,Kuybyshevsk,Kuybyshevskiy,Kŭybishev,Абдураҳмони Ҷомӣ,Куйбишев,Кӯйбишев', 37.9463600, 68.8087800, 'TJ', '2012-11-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126601, 'Kŭlob', 'Kulob', 'Kulab,Kuljab,Kulob,Kulyab,Kŭlob,TJU,Куляб,Кӯлоб', 37.9145900, 69.7845400, 'TJ', '2017-02-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126602, 'Darband', 'Darband', 'Darand,Darband,Komsomolabad,Komsomolbad,Komsomolobod,Pombachi,Даранд', 38.8677600, 69.9664200, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126603, 'Kolkhozobod', 'Kolkhozobod', 'Kaganovichabad,Kaganowtschab,Kolkhozabad,Kolkhozobod,Tugalan,Tugolan,Колхозобод', 37.5882300, 68.6588600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126604, 'Kirov', 'Kirov', 'Imeni Kirova,Kirov,Kirovskiy,Sovkhoz Imeni Kirova,Киров', 37.8190800, 68.8590500, 'TJ', '2013-03-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126605, 'Khovaling', 'Khovaling', 'Khovaling,Ховалинг', 38.3419400, 69.9753100, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126606, 'Khorugh', 'Khorugh', 'Khorog,Khorug,Khorugh,Хорог,Хоруғ', 37.4897400, 71.5530400, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126607, 'Khodzha-Maston', 'Khodzha-Maston', '', 38.7445700, 68.6270200, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126608, 'Karakenja', 'Karakenja', 'Kara-Gendzha,Kara-Gendzhe,Karakendzha,Karakenja,Kurz-Genje', 39.2358500, 71.5241200, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126609, 'Sarband', 'Sarband', 'Kalininabad,Sarband,Сарбанд', 37.8713600, 68.9223300, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126610, 'Qalaikhumb', 'Qalaikhumb', 'Kala Khumb,Kala-I-Khamb,Kalai Khumb,Kalaikhum,Qala-i-Khum,Qalaikhum,Qalaikhumb,Қалаихум,Қалаихумб', 38.4537300, 70.7890200, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126611, 'Qubodiyon', 'Qubodiyon', 'Imeni Nasir Khisrav,Kabadian,Kabodiyen,Kabodiyon,Kabodiyën,Mikoyanabad,Nosir Khisrav,Qabodiyon,Qubodiyon,Қубодиён', 37.4097300, 68.1864400, 'TJ', '2016-09-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126612, 'Ishqoshim', 'Ishqoshim', 'Ishkashim,Ishkashim Post,Ishkāshīm Post,Ishqoshim,Nud,Nuda,Ишкашим,Ишқошим', 36.7248400, 71.6133100, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126613, 'Hisor', 'Hisor', 'Gissar,Hisor,Khisor,Staryy Gissar,Гиссар,Ҳисор', 38.5250400, 68.5512400, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126614, 'Rasht', 'Rasht', 'Garm,Gharm,Rasht,Рашт', 39.0287100, 70.3744600, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126615, 'Gharavŭtí', 'Gharavuti', 'Garavuti,Gharavuti,Gharavŭtí,Ғаравӯтӣ', 37.5670300, 68.4466800, 'TJ', '2012-11-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126616, 'Ghonchí', 'Ghonchi', 'Ganchi,Ghonchi,Ghonchí,Gonchi,Granchi,Ғончи', 39.9623800, 69.1296600, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126617, 'Fayzobod', 'Fayzobod', 'Daragion,Daragizy,Faizabad,Fajzobod,Fayzabad,Fayzobod,Файзобод', 38.5473100, 69.3198000, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126618, 'Jirghatol', 'Jirghatol', 'Dzhergatol,Dzhirgatal'',Dzhirgatal’,Dzhirgital'',Dzhirgital’,Jirgatal'',Jirgatal’,Jirgatol,Jirghatol,Ҷирғатол', 39.2196600, 71.1915500, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126619, 'Jilikŭl', 'Jilikul', 'Dzhil''kul'',Dzhilikol,Dzhilikul'',Dzhilikul’,Dzhil’kul’,Jilikul,Jilikŭl,Ҷиликӯл', 37.4916700, 68.5310600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126620, 'Dŭstí', 'Dusti', 'Dusti,Dusty,Dŭsty,Dŭstí,Molotovabad,Pyandzh,Дӯстӣ', 37.3481200, 68.6639800, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126621, 'Dushanbe', 'Dushanbe', 'DYU,Djuschambe,Doesjanbe,Douchanbe,Douchanbé,Dusanbe,Dusanbeo,Duschanbe,Dushambe,Dushanbe,Dusjanbe,Duszanbe,Duŝanbeo,Duşanbe,Dušanbe,Dušanbė,Dušhanbe,Dyushambe,Düşənbə,Jushambe,Ntousanmpe,Stalinabad,do~ushanbe,du shang bie,dusyanbe,dwshnbh,dwsnbh,Ντουσάνμπε,Душанбе,דושנבה,دوشنبه,ዱሻንቤ,ドゥシャンベ,杜尚别,두샨베', 38.5357500, 68.7790500, 'TJ', '2016-10-19', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126622, 'Danghara', 'Danghara', 'Dangar,Dangara,Danghara,Дангара,Данғара', 38.0957800, 69.3399800, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126623, 'Chubek', 'Chubek', 'Chubek,Moskovskiy,Чубек', 37.6145300, 69.7052500, 'TJ', '2012-11-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126624, 'Boshchorbogh', 'Boshchorbogh', 'Boshchorbog,Boshchorbogh,Boshgorbog,Chorbog,Бошчорбоғ', 37.5202700, 68.1282500, 'TJ', '2016-09-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126625, 'Bŭstonqal’a', 'Bustonqal''a', 'Bustonkala,Bustonkˌala,Bustonqal''a,Bŭstonqal’a,Бӯстонқала', 37.8478300, 68.8312500, 'TJ', '2013-03-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126626, 'Boshkengash', 'Boshkengash', 'Bashkyngash,Boshkengash,Boshkengosh', 38.4661300, 68.8053300, 'TJ', '2016-10-19', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126627, 'Baljuvon', 'Baljuvon', 'Bal''dzhuan,Bal''dzhuvon,Bal''juan,Baldshuan,Baljuvon,Bal’dzhuan,Bal’dzhuvon,Bal’juan,Bol''dzhuan,Bol’dzhuan,Балҷувон', 38.3083800, 69.6767200, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126628, 'Ayní', 'Ayni', 'Aini,Ajni,Ayni,Ayny,Ayní,Varziminor,Varzominor,Zakhmatabad,Айнӣ', 39.3940600, 68.5376600, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126629, 'Tursunzoda', 'Tursunzoda', 'Tursunsoda,Tursunzade,Tursunzadė,Tursunzoda,Turszunzoda,to~urusunzoda,tu er sun zha de,tuleusunjoda,twrswnzadh,Турсунзаде,Турсунзода,تورسونزاده,تورسونزادہ,تورسون‌زاده,トゥルスンゾダ,圖爾孫扎德,투르순조다', 38.5127100, 68.2316300, 'TJ', '2016-11-22', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126630, 'Roghun', 'Roghun', 'Maydon,Roghun,Rogun,Роғун', 38.6933100, 69.7369200, 'TJ', '2016-11-23', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126631, 'Bahorí', 'Bahori', 'Bahori,Bahorí,Sovkhoz Beshkent-2,Баҳорӣ', 37.4019500, 67.9944600, 'TJ', '2013-12-14', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126632, 'Zafarobod', 'Zafarobod', 'Ayni,Imeni Ayni,Zafapobod,Zafarabad,Zafarabod,Zafarobod,Зaфapoбoд', 40.1760300, 68.8467900, 'TJ', '2012-06-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126633, 'Taboshar', 'Taboshar', 'Taboshar,Taboshary,Табошар', 40.5701700, 69.6417500, 'TJ', '2012-05-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126634, 'Shŭrob', 'Shurob', 'Schurab,Shorab,Shurab,Shurob,Shŭrob,Шӯроб', 40.0460500, 70.5411700, 'TJ', '2012-08-04', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126635, 'Proletar', 'Proletar', 'Dragomirovo,Jabar Rasulov,Jabbor Rasulov,Proletar,Proletarsk,Пролетар', 40.1671300, 69.5016300, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126636, 'Palos', 'Palos', 'Palas,Palos,Палос', 40.3162800, 69.7374300, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126637, 'Pakhtakoron', 'Pakhtakoron', 'Pakhtakoron,Paxtakoron,Пахтакорон', 40.1570900, 68.7465900, 'TJ', '2016-09-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126638, 'Neftobod', 'Neftobod', 'Nefteabad,Nefteobod,Neftobod,Predyvak,Нефтобод', 40.2152400, 70.5719300, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126639, 'Nov', 'Nov', 'Nau,Nov,Нов', 40.1522000, 69.3707600, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126640, 'Quruqsoy', 'Quruqsoy', 'Kuruksay,Kurusay,Quruqsoy,Қуруқсой', 40.5764800, 69.3796200, 'TJ', '2012-05-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126641, 'Kim', 'Kim', 'Kim,Nefteprom Kim,Santo,Ким', 40.2079800, 70.4688200, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126642, 'Khŭjand', 'Khujand', 'Choedzjand,Chudschand,Chudzandas,Chudzjand,Chudžandas,Hodjent,Hudzand,Hudžand,Khodjent,Khodyent,Khodzhent,Khojend,Khudzhand,Khujand,Khuzhant,Khŭjand,Kojend,LBD,Leninabad,Leninobod,Ursaten,Xo''jand,Xoʻjand,hojendo,khjnd,ku zhan,Ходжент,Худжанд,Хужант,Хуҷанд,Хӯҷвнд,خجند,ホジェンド,苦盏', 40.2825600, 69.6221600, 'TJ', '2014-05-29', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126643, 'Konsoy', 'Konsoy', 'Kaindisoy,Kansai,Kansay,Konsoj,Konsoy,Svints,Консой', 40.4915500, 69.7024500, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126644, 'Konibodom', 'Konibodom', 'Kanibadam,Konibodom,Konibodomas,Qənibadam,kan badam,kany badam,ke ni bo duo mu,konibodom,Кoнибодом,Канибадам,Канібадам,Конибодом,کان بادام,کانی بادام,科尼博多姆,코니보돔', 40.2941400, 70.4312200, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126645, 'Isfara', 'Isfara', 'Isfara,asfrh,asfrt,iseupala,isufara,yi si fa la,İsfərah,Ісфара,Исфара,Исфәрә,اسفرة,اسفره,اسفرہ,イスファラ,伊斯法拉,이스파라', 40.1264900, 70.6252600, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126646, 'Ghafurov', 'Ghafurov', 'Gafurob,Gafurov,Ghafurov,Khodzhent,Sovetabad,Stantsiya Leninabad,Ғафуроб', 40.2157100, 69.7286700, 'TJ', '2012-02-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126647, 'Bŭston', 'Buston', 'Bustan,Buston,Bŭston,Yantak,Бӯстон', 40.5228600, 69.3330700, 'TJ', '2016-09-08', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126648, 'Shaydon', 'Shaydon', 'Asht,Shaidan,Shajdon,Shaydan,Shaydon,Шайдон', 40.6699200, 70.3502000, 'TJ', '2012-05-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126649, 'Oltintopkan', 'Oltintopkan', 'Altyn-Topkan,Oltintopkan,Олтинтопкан', 40.6542500, 69.5981100, 'TJ', '2012-04-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126650, 'Adrasmon', 'Adrasmon', 'Adrasman,Adrasmon,Адрасмон', 40.6492800, 69.9847200, 'TJ', '2012-05-05', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126651, 'Chkalov', 'Chkalov', 'Chkalov,Chkalovsk,Чкалов', 40.2341700, 69.6948100, 'TJ', '2012-04-06', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126652, 'Mehron', 'Mehron', 'Mehron,Меҳрон', 39.4169100, 69.2867700, 'TJ', '2012-02-29', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126653, 'Moskovskiy', 'Moskovskiy', 'Moskovskij,Moskovskiy,Московский', 37.6093100, 68.5809400, 'TJ', '2015-10-28', 219);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126251, 'Chumphon Buri', 'Chumphon Buri', 'Amphoe Chumphon Buri,Chumphon Buri,King Amphoe Chumphon Buri,Mueang Chumphon Buri,chumphlburi,ชุมพลบุรี', 15.3486200, 103.3921700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126252, 'Chum Phae', 'Chum Phae', 'Amphoe Chum Phae,Ban Chum Phae,Chum Phae,ชุมแพ', 16.5443000, 102.0992400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126253, 'Chonnabot', 'Chonnabot', 'Ban Chonabot,Ban Chonbot,Ban Chonnabot,Chenobot,Chonaboti,Chonnabot,Mong Chonlabot,Mueang Chonbot,Möng Chonlabot,chnbth,ชนบท', 16.0886100, 102.6217800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126254, 'Chon Daen', 'Chon Daen', 'Amphoe Chon Daen,Ban Chon Daen,Ban Chon Dean,Bān Chon Dean,Chon Daen,Jonden,Jondēn,King Amphoe Chon Daen,King Chon Daen,ชนแดน', 16.1895300, 100.8595800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126255, 'Chon Buri', 'Chon Buri', 'Amphoe Muang Chon Buri,Baanburaisoi,Ban Bang Pla Soi,Ban Pla Sai,Ban Pla Soi,Bang Pla Soi,Bang Pla Soil,Changwat Chon Buri,Cholburi,Chon Buri,Chonburi,Chor Buri,Jilburi,Jīlburi,Muang Jol Buri,Muang Xonburi,Mueang Chon Buri,chlburi,Чонбури,ชลบุรี', 13.3622000, 100.9834500, 'TH', '2015-07-13', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126256, 'Chom Phra', 'Chom Phra', 'Amphoe Chom Phra,Ban Chom Phra,Chom Phra,King Amphoe Chom Phra,cxmphra,จอมพระ', 15.1181400, 103.6074300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126257, 'Chok Chai', 'Chok Chai', 'Amphoe Chok Chai,Ban Chok Chai,Choc Chai,Chok Chai,Kra Thok,chokhchay,โชคชัย', 14.7284400, 102.1652400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126258, 'Chian Yai', 'Chian Yai', 'Amphoe Chian Yai,Chian Yai,King Amphoe Chian Yai,เชียรใหญ่', 8.1693600, 100.1446900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126259, 'Chiang Yuen', 'Chiang Yuen', 'Amphoe Chiang Yuen,Ban Chiang Yun,Chiang Yuen,Chiang Yun,King Amphoe Chiang Yun,cheiyngyun,เชียงยืน', 16.4104200, 103.0976700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126260, 'Chiang Saen', 'Chiang Saen', 'Amphoe Chiang Saen,Chang Saen,Chiang Saen,Chiang Saen Luang,Chiang Saen Office,Chiangsehn,Chieng Sen,Ging Chieng Sean,Ging Chiensen,Jiengsen,Jiēngsēn,Keng Sen,Muang Jieng Sen,Чиангсэн,เชียงแสน', 20.2751100, 100.0868900, 'TH', '2016-11-15', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126261, 'Chiang Klang', 'Chiang Klang', 'Amphoe Chiang Klang,Ban Chiang Klang,Chiang Klang,cheiyngklang,เชียงกลาง', 19.2937800, 100.8616900, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126262, 'Chiang Khong', 'Chiang Khong', 'Amphoe Chiang Khaung,Amphoe Chiang Khong,Amphoe Jieng Khohng,Ban Hwei Sai,Ban Nai Wiang,Chiang Khong,Chiangkkhong,Chieng Kaung,Chieng Kong,Jieng Khohng,Muang Jieng Khohng,Nai Wiang,Xieng Khong,cheiyngkhxng,Чиангкхонг,เชียงของ', 20.2612500, 100.4046100, 'TH', '2016-01-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126263, 'Chiang Khan', 'Chiang Khan', 'Amphoe Chiang Khan,Amphoe Jieng Kan,Amphoe Jienggan,Amphoe Muang Chiang,Amphoe Muang Chiang Khan,Chiang Khan,Chieng Kan,Chienggan,Chienggān,Muang Chiang Kan,Muang Chiang Khan,Muang Chieng Kan,Xieng Khan,cheiyngkhan,เชียงคาน', 17.8938200, 101.6599700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126264, 'Chiang Kham', 'Chiang Kham', 'Amphoe Chiang Kham,Amphoe Chieng Kum,Amphoe Jieng Gam,Ban Chiang Kham,Ban Juan,Ban Yuan,Chiang Kham,Chieng Kam,Chieng Kum,Chienggam,Jieng Gam,Xieng Kham,cheiyngkha,เชียงคำ', 19.5233100, 100.3000000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126265, 'Cha-uat', 'Cha-uat', 'Amphoe Cha-uat,Ban Cha Uat,Cha-uat,King Amphoe Cha-uat,chaxwd,ชะอวด', 7.9677300, 99.9998500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126266, 'Chaturaphak Phiman', 'Chaturaphak Phiman', 'Amphoe Chaturaphak Phiman,Chaturaphak Phiman,Hua Chang,Muang Cha Tao,Muang Tia Tao,Muang Tia-tou,Tia Tao,ctur phaktr phiman,จตุรพักตรพิมาน', 15.8457200, 103.5571900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126267, 'Chatturat', 'Chatturat', 'Amphoe Chatturat,Amphoe Chaturat,Ban Kok,Chatturat,Chatuaras,Chaturat,Muang Chaturas,Muang Chaturat,Muang Chetturach,Muang Jatu Rat,Muang Tiattorak,caturas,จัตุรัส', 15.5654200, 101.8454700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126268, 'Chat Trakan', 'Chat Trakan', 'Amphoe Chat Trakan,Ban Chat Trakan,Chat Trakan,King Amphoe Chat Trakan,Mueang Chat Trakan,chatitrakar,ชาติตระการ', 17.2760600, 100.6002200, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126269, 'Chanuman', 'Chanuman', 'Amphoe Chanuman,Ban Chanuman,Chanuman,King Amphoe Chanuman,Mueang Chanuman Monthon,ban chanuman,chanuman,ชานุมาน,บ้านชานุมาน', 16.2335600, 105.0005000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126270, 'Chanthaburi', 'Chanthaburi', 'Amphoe Muang Chanthaburi,Canthaburis,Chandaburi,Chandha Buri,Changwat Chanthaburi,Chantaboun,Chantabun,Chantaburi,Chanthaburi,Chantkhaburi,Chentabun,Chiyandburii,Mueang Chanthaburi,canthburi,jjantabuli,thesbal meuxng canthburi,zhuang ta wu li,Čanthaburis,Чантхабури,چانتھابوری,จันทบุรี,เทศบาลเมืองจันทบุรี,ཅཱན་ཐ་བུ་རི།,庄他武里,짠타부리', 12.6096100, 102.1044700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126271, 'Chanae', 'Chanae', 'Amphoe Chanea,Chanae,King Amphoe Chanae,จะแนะ', 6.0991400, 101.6935300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126272, 'Chana', 'Chana', 'Amphoe Ban Na,Amphoe Chana,Ban Banna,Ban Chana,Ban Na,Chana,Chanok,Jana,cana,จะนะ', 6.9154200, 100.7403900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126273, 'Chaloem Phra Kiat', 'Chaloem Phra Kiat', 'Amphoe Chakkarat,Amphoe Chaloem Phra Kiat,Ban Non Mai Daeng,Ban Tha Chang,Chakkarat,Chakkrarat,Chaloem Phra Kiat,Tha Chang,chelimphrakeiyrti,thachang,ท่าช้าง,เฉลิมพระเกียรติ', 15.0050800, 102.2703300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126274, 'Chaiyo', 'Chaiyo', 'Amphoe Ban Makham,Amphoe Chaiyo,Ban Charake Rong,Ban Chorakhe Rong,Chaiyo,Chaurakhe Raung,Cheiyo,chiyo,ไชโย', 14.6487800, 100.4787800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126275, 'Chaiyaphum', 'Chaiyaphum', 'Amphoe Muang Chaiyaphum,Ban Hin Tang,Chai Phum,Chaiaphum,Chaiapum,Chaiyaphum,Chaiyaphun,Chaiyapoom,Chajjapkhum,Chalyaphum,Changwat Chaiyaphum,Changwat Chaiyaphun,Jaibhum,Jaiyabhum,Jayabhumi,Muang Chaiyapum,Muang Jaiyabhum,Tchaiapoum,chayphumi,Чайяпхум,ชัยภูมิ', 15.8104700, 102.0288100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126276, 'Chaiwan', 'Chaiwan', 'Amphoe Chai Wan,Ban Chai Wan,Chaiwan,King Amphoe Chai Wan,chiywan,ไชยวาน', 17.2944700, 103.2338500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126277, 'Chai Nat', 'Chai Nat', 'Amphoe Ban Kluai,Amphoe Muang Chainat,Ban Kluai,Chai Nad,Chai Nat,Chainat,Changwat Chainat,Changwat Muang Chainat,Cheinat,Jai-Nadh,Jai-Nādh,Jainat,Muang Chainat,Muang Jai Nadh,Muang Xai Nat,Mueang Chai Nat,chaynath,ชัยนาท', 15.1863600, 100.1235300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126278, 'Chai Badan', 'Chai Badan', '', 15.2000000, 101.1333300, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126279, 'Chai Badan', 'Chai Badan', 'Amphoe Chai Badan,Amphu Chai Badal,Ban Chai Badan,Bān Chāi Bādān,Chai Badan,Jai Badal,Jai Bādāl,chaybadal,ชัยบาดาล', 15.2061400, 101.1368300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126280, 'Chachoengsao', 'Chachoengsao', 'Amphoe Muang Chachoengsao,Chacherngsao,Chachoengsao,Chachurngsao,Changwat Chachoengsao,Chaxerngsao,Chaxoengsao,Muang Chachurngsao,Muang Shajeungdhrao,Muang Shajeungtrao,Mueang Chachoengsao,Muong Chaxungsao,Paet Riu,Petrin,Petriou,Petriu,Shacheungzao,Shajeungdhrao,Shajeungdrao,Shajeungzao,chacheingthera,meuxng chacheingthera,Чачоенгсао,ฉะเชิงเทรา,เมืองฉะเชิงเทรา', 13.6882000, 101.0715600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126281, 'Buri Ram', 'Buri Ram', 'Amphoe Muang Buriram,Amphoe Mueang Buriram,Buri Ram,Buriram,Changwat Buriram,Muang Buriram,Muang Pae,Mueang Buri Ram,bulilam,buriramy,bwry ram,bwryram,thesbal meuxng buriramy,Бурирам,בורי ראם,بوريرام,بوری رام,بوریرام,บุรีรัมย์,เทศบาลเมืองบุรีรัมย์,부리람', 14.9943300, 103.1039200, 'TH', '2017-07-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126282, 'Buntharik', 'Buntharik', 'Amphoe Buntharik,Ban Phon Ngam,Buntharik,King Amphoe Ban Phon Ngam,King Amphoe Bhonngam,King Amphoe Buntharik,King Amphoe Phon Ngam,Muang Bua,Muang Pua,Phon Ngam,bunthrik,บุณฑริก', 14.7563900, 105.4114700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126283, 'Bueng Sam Phan', 'Bueng Sam Phan', 'Ban Bung Sam Phan Nok,Bueng Sam Phan,Bung Sam Phan,bungsamphan,บึงสามพัน', 15.8302400, 100.9193800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126284, 'Bueng Khong Long', 'Bueng Khong Long', 'Amphoe Bueng Khong Long,Bueng Khong Long,Bung Khong Long,King Amphoe Bueng Khong Long,bung khong hlng,บึงโขงหลง', 17.9612900, 104.0466700, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126285, 'Bueng Kan', 'Bueng Kan', 'Amphoe Bung Kan,Amphoe Chai Buri,Amphoe Jaiburi,Amphoe Shai Buri,Ban Beung Kal,Ban Bung Kan,Bueng Kan,Bung Kan,Chai Buri,bungkal,บึงกาฬ', 18.3630300, 103.6519400, 'TH', '2013-08-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126286, 'Bua Yai', 'Bua Yai', 'Amphoe Bua Yai,Bua Yai,Dan Nok,บัวใหญ่', 15.5855200, 102.4258700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126287, 'Bua Chet', 'Bua Chet', 'Amphoe Buachet,Bua Chet,King Amphoe Buachet,baw ched,บัวเชด', 14.5281400, 103.9456700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126288, 'Bo Thong', 'Bo Thong', 'Amphoe Bo Thong,Bo Thong,King Amphoe Bo Thong,bx thxng,บ่อทอง', 13.2782500, 101.4402800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126289, 'Bo Rai', 'Bo Rai', 'Ban Bo Rai,Bau Rai,Bo Rai,bxri,บ่อไร่', 12.5728300, 102.5371400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126290, 'Borabue', 'Borabue', 'Amphoe Borabu,Ban Borabu,Borabu,Borabue,brbux,บรบือ', 16.0417900, 103.1150600, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126291, 'Bo Kluea', 'Bo Kluea', 'Bo Klua,Bo Kluea,King Amphoe Bo Kluea,bx kelux,บ่อเกลือ', 19.1502900, 101.1556000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126292, 'Betong', 'Betong', 'Amphoe Betong,Amphoe Yarom,Ban Betong,Betong,Kampong Betong,betng,xaphex betng,Бетонг,อำเภอเบตง,เบตง', 5.7743400, 101.0723100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126293, 'Wang Pong', 'Wang Pong', 'Amphoe Wang Pong,Ban Wang Paung,Ban Wang Pong (1),King Amphoe Wang Pong,Wang Pong,wang pong,วังโป่ง', 16.3414700, 100.7931700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126294, 'Wang Muang', 'Wang Muang', 'Amphoe Wang Muang,Ban Wang Muang,King Amphoe Wang Muang,Wang Muang,wang mwng,วังม่วง', 14.8422800, 101.1255000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126295, 'Ban Thai Tan', 'Ban Thai Tan', 'Ban Thai Tan,ban thay tal,บ้านท้ายตาล', 14.6216100, 100.4873900, 'TH', '2012-02-01', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126296, 'Ban Thaen', 'Ban Thaen', 'Amphoe Ban Thaen,Ban Thaen,King Amphoe Ban Thaen,บ้านแท่น', 16.4050600, 102.3423900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126297, 'Song Khwae', 'Song Khwae', 'Ban Saung Keo,Ban Song Khwae,Bān Saung Keo,Song Khwae,Song Khwaeo,สองแคว', 19.3596400, 100.7004200, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126298, 'Ban Selaphum', 'Ban Selaphum', '', 16.0166700, 103.9500000, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126299, 'Sawang Wirawong', 'Sawang Wirawong', 'Amphoe Sawang Wirawong,Amphoe Suwan Warin,Ban Kaeng Sao On,Ban Kaeng Sao-an,Ban Sawang,Kaeng Samran,Khwaeng Mueang Khong Chiam,King Amphoe Sawang Wirawong,Sawang Wirawong,swang wir wngs,สว่างวีรวงศ์', 15.2415800, 105.0922000, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126300, 'Ban Sang', 'Ban Sang', 'Amphoe Ban Sang,Ban Bang Kabao,Ban Chang,Ban Sang,Bang Kabao,bansrang,บ้านสร้าง', 13.9950300, 101.2209500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126301, 'Ban Sam Chuk', 'Ban Sam Chuk', 'Ban Sam Chuk,Ban Sam Jok,Bān Sām Jok,ban samchuk,บ้านสามชุก', 14.7421900, 100.0953100, 'TH', '2014-01-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126302, 'Ratchasan', 'Ratchasan', 'Amphoe Ratchasan,Ban Ratchasan,King Amphoe Ratchasan,Ratchasan,rach sasn,ราชสาส์น', 13.7821100, 101.2813300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126303, 'Ban Phue', 'Ban Phue', 'Amphoe Ban Phu,Ban Phu,Ban Phue,ban phux,บ้านผือ', 17.6887700, 102.4787800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126304, 'Ban Phraek', 'Ban Phraek', 'Amphoe Ban Phraek,Ban Phraek,Ban Prag,King Amphoe Ban Phraek,Phraek,บ้านแพรก', 14.6468100, 100.5761700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126305, 'Ban Pho', 'Ban Pho', 'Ampho Ban Pho,Amphoe Khao Din,Amphoe Sanam Chan,Ban Pho,Banbho,Bānbhō,banphothi,บ้านโพธิ์', 13.5986400, 101.0795600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126306, 'Phatthaya', 'Phatthaya', 'Ban Hat Phatthaya (2),Ban Phatthaya,PYX,Pataja,Pattajja,Pattaya,Phattaya,Phatthaya,Port Phattaya,ba da ya,pataya,pattaya,phathya,Патая,Паттайя,พัทยา,パッタヤー,芭達亞,파타야', 12.9333300, 100.8833300, 'TH', '2017-07-28', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126307, 'Ban Phan Don', 'Ban Phan Don', 'Amphoe Kumbhawapi,Amphoe Kumphawapi,Ban Nam Khong,Ban Phan Don,Koumpa Ouapi,Kumpawapi,Kumphawapi,Muang Kumpawapi,Muang Kumpu Kwapi,Nam Khaung,ban phan dxn,บ้านพันดอน', 17.1427200, 102.9726100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126308, 'Ban Phai', 'Ban Phai', 'Amphoe Ban Phai,Ban Keng,Ban Phai,King Amphoe Ban Phai,banphi,บ้านไผ่', 16.0599700, 102.7309700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126309, 'Ban Phaeo', 'Ban Phaeo', 'Amphoe Ban Phaeo,Ban Phaeo,Ban Pheo,บ้านแพ้ว', 13.5907200, 100.1074800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126310, 'Ban Phaeng', 'Ban Phaeng', 'Amphoe Ban Phaeng,Ban Paeng,Ban Phaeng,Ban Pheng,King Amphoe Ban Phaeng,Paeng,บ้านแพง', 17.9650700, 104.2153400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126311, 'Pak Chom', 'Pak Chom', 'Amphoe Pak Chom,Ban Pak Chom,Ban Pak Sohm,King Amphoe Pak Chom,Pak Chaum,Pak Chom,Pāk Chaum,pakchm,ปากชม', 18.0206100, 101.8982800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126312, 'Nong Muang Khai', 'Nong Muang Khai', 'Amphoe Nong Muang Khai,Ban Naung Maung Kai,Ban Nong Muang Khai,Bān Naung Maung Kāi,King Amphoe Nong Muang Khai,Naung Muang Kai,Nong Muang Khai,hnxng mwng khi,หนองม่วงไข่', 18.2646400, 100.1896700, 'TH', '2012-09-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126313, 'Nong Don', 'Nong Don', 'Amphoe Nong Don,Ban Nong Don,Hnohng Don,Hnōhng Don,King Amphoe Nong Don,Naung Don,Nong Don,hnxngdon,หนองโดน', 14.6848800, 100.7094000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126314, 'Na Yia', 'Na Yia', 'Amphoe Na Yia,Ban Na Ya,Ban Na Yia,King Amphoe Na Yia,Na Ma,Na Yia,na yeiy,นาเยีย', 15.0636700, 105.0599400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126315, 'Na Yai Am', 'Na Yai Am', 'Amphoe Na Yai Am,Ban Na Yai Am,King Amphoe Na Yai Am,Na Yai Am,na yay xam,นายายอาม', 12.7815300, 101.8225600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126316, 'Na Thom', 'Na Thom', 'Amphoe Na Thom,Ban Na Thom,King Amphoe Na Thom,Na Thom,na thm,นาทม', 17.7849100, 104.0908200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126317, 'Ban Nang Sata', 'Ban Nang Sata', 'Amphoe Ba Cho,Amphoe Ban Nang Sata,Ban Ban Nang Sata,Ban Nang Sata,Ban Panang Star,Ban Pannang Sata,Bannangsta,Benang Setar,Pannang Sata,ban bannangsta,bannangsta,บันนังสตา,บ้านบันนังสตา', 6.2663800, 101.2646100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126318, 'Na Khu', 'Na Khu', 'Amphoe Na Khu,Ban Na Khu,King Amphoe Na Khu,Na Khu,na khu,นาคู', 16.7638400, 104.0262600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126319, 'Na Haeo', 'Na Haeo', 'Amphoe Na Haeo,Ban Na Haeo,Ban Na Heo,Bān Na Heo,King Amphoe Na Haeo,Na Haeo,Nahai,นาแห้ว', 17.4853600, 101.0680800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126320, 'Na Di', 'Na Di', 'Amphoe Na Di,Ban Na Di,King Amphoe Na Di,Na Di,Nadi,nadi,นาดี', 14.1151700, 101.7818900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126321, 'Ban Na', 'Ban Na', 'Amphoe Ban Na,Amphoe Tha Chang,Ban Na,Ban Phikun Ok,Bang Na,Phikum Auk,banna,บ้านนา', 14.2623800, 101.0711100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126322, 'Ban Muang', 'Ban Muang', 'Amphoe Ban Muang,Ban Muang,King Amphoe Ban Muang,banmwng,บ้านม่วง', 17.8508000, 103.5693900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126323, 'Muak Lek', 'Muak Lek', 'Ban Muak Lek,Muak Lek,Muaklek,mwk helk,มวกเหล็ก', 14.6528700, 101.2002200, 'TH', '2014-04-29', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126324, 'Ban Mo', 'Ban Mo', 'Amphoe Ban Mo,Ban Mo,banhmx,บ้านหมอ', 14.6154400, 100.7273100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126325, 'Ban Mi', 'Ban Mi', 'Amphoe Ban Mi,Amphoe Ban Sao,Amphoe Huay Kaew,Amphoe Sanam Chaeng,Ban Mi,banhmi,บ้านหมี่', 15.0442800, 100.5368100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126326, 'Mae Lan', 'Mae Lan', 'Amphoe Mae Lan,Ban Mae Lan,Ban Mehlan,King Amphoe Mae Lan,Mae Lan,Mae Ran,แม่ลาน', 6.6611400, 101.2395800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126327, 'Chiang Muan', 'Chiang Muan', 'Amphoe Chiang Muan,Ban Chiang Muan,Ban Chieng Muang,Ban Luang,Bān Chieng Muang,Chiang Muan,Chiengmuan,King Amphoe Chiang Muan,King Amphoe Chiang Mun,cheiyng mwn,เชียงมวน', 18.8896900, 100.3058900, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126328, 'Ban Luang', 'Ban Luang', 'Amphoe Ban Luang,Ban Luang,Ban Pa Kha Luang,Hluang,Hlūang,King Amphoe Ban Luang,Mea Saut,Muang Sot,banhlwng,บ้านหลวง', 18.8496900, 100.4372500, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126329, 'Ban Lueam', 'Ban Lueam', 'Amphoe Ban Lueam,Ban Luam,Ban Lueam,King Amphoe Ban Lueam,Luam,banheluxm,บ้านเหลื่อม', 15.6091600, 102.1292800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126330, 'Lao Suea Kok', 'Lao Suea Kok', 'Amphoe Lao Suea Kok,Ban Lao Sua Kho,Ban Lao Sua Kok,Ban Lao Sua Kuk,King Amphoe Lao Suea Kok,Lao Suea Kok,Laosuakho,hela seux ko k,เหล่าเสือโก้ก', 15.4183000, 104.9236300, 'TH', '2012-06-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126331, 'Ban Lam Luk Ka', 'Ban Lam Luk Ka', 'Lam Luk Ka,Luk Ka,Lūk Ka', 13.9773800, 100.7777600, 'TH', '2008-07-11', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126332, 'Kut Rang', 'Kut Rang', 'Amphoe Kut Rang,Ban Kot Rang,Ban Kut Rang,King Amphoe Kut Rang,Kut Rang,kud rang,กุดรัง', 16.0939800, 103.0099800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126333, 'Ban Kruat', 'Ban Kruat', 'Ban Kruat,King Amphoe Ban Kruat,ba nkrwwd,บ้านกรววด', 14.4231300, 103.0997400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126334, 'Ban Ko Lan', 'Ban Ko Lan', 'Ban Ko Lan,Ban Ko San,Ban Kok San,Ko Lan,ban keaa lan,Ко Лан,บ้านเกาะล้าน', 12.9241900, 100.7879400, 'TH', '2013-06-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126335, 'Ban Khwao', 'Ban Khwao', 'Amphoe Ban Khwao,Ban Khwao,King Amphoe Ban Khwao,bankhewa,บ้านเขว้า', 15.7777200, 101.9072000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126336, 'Khok Sung', 'Khok Sung', 'Amphoe Khok Sung,Ban Khok Sung,Khok Sung,King Amphoe Khok Sung,khok sung,โคกสูง', 13.8382400, 102.6225400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126337, 'Bang Rachan', 'Bang Rachan', 'Ban Khok Phrao (1),Ban Rachan,ban ra can,บ้านระจัน', 14.7971700, 100.3065000, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126338, 'Ban Khok', 'Ban Khok', 'Amphoe Ban Khok,Ban Khok,King Amphoe Ban Khok,ban khok,บ้านโคก', 18.0261400, 101.0677200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126339, 'Khlong Khuean', 'Khlong Khuean', 'Amphoe Khlong Khuean,Ban Khlong Khuan,Khlaung Khuan,Khlong Khuean,King Amphoe Khlong Khuean,khlxng kheuxn,คลองเขื่อน', 13.7913100, 101.1635300, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126340, 'Khlong Hoi Khong', 'Khlong Hoi Khong', 'Amphoe Khlong Hoi Khong,Ban Khlong Hoi Khong,Ban Klaung Hoi Kaung,Ban Klong Hoy Kong,Khlaung Hoi Khaung,Khlong Hoi Khong,King Amphoe Khlong Hoi Khong,khlxng hxy khong,คลองหอยโข่ง', 6.8986500, 100.3888500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126341, 'Khao Chakan', 'Khao Chakan', 'Amphoe Khao Chakan,Ban Khao Chakan,Khao Cha Kan,Khao Chakan,King Amphoe Khao Chakan,khea chkrrc,เขาฉกรรจ์', 13.6535000, 102.0882500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126342, 'Ban Khai', 'Ban Khai', 'Amphoe Ban Khai,Ban Khai,bankhay,บ้านค่าย', 12.7826100, 101.2963900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126343, 'Kap Choeng', 'Kap Choeng', 'Amphoe Kap Choeng,Ban Kapchoeng,Kap Choeng,King Amphoe Kap Choeng,kabcheing,กาบเชิง', 14.4748600, 103.5943900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126344, 'Kapho', 'Kapho', 'Ban Gala Phau,Ban Kalabhoh,Ban Kalapho,Ban Kelapa,Ban Klapor,Ka La Pau,Kalapho,Kapho,King Amphoe Kalabhoh,King Amphoe Kapho,King Amphoe Taluban,Taluban,kaphx,กะพ้อ', 6.5596800, 101.5342600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126345, 'Kaeng Sanam Nang', 'Kaeng Sanam Nang', 'Amphoe Kaeng Sanam Nang,Ban Kaeng Sanam,Ban Kaeng Sanam Nang,Kaeng Sanam Nang,King Amphoe Kaeng Sanam Nang,แก้งสนามนาง', 15.7495400, 102.2548400, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126346, 'Kaeng Hang Maeo', 'Kaeng Hang Maeo', 'Amphoe Kaeng Hang Maeo,Ban Kaeng,Ban Kaeng Han Maeo,Ban Kaeng Hang Maeo,Kaeng Hang Maeo,Kaeng Hang Meo,King Amphoe Kaeng Hang Maeo,แก่งหางแมว', 13.0082500, 101.9060800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126347, 'Bang Yai', 'Bang Yai', 'Amphoe Bang Yai', 13.8434100, 100.3625100, 'TH', '2008-10-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126348, 'Bang Sai', 'Bang Sai', 'Amphoe Bang Sai,Bang Sai,King Amphoe Bang Sai,bangsay,บางซ้าย', 14.3343300, 100.3037800, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126349, 'Bang Rakam', 'Bang Rakam', 'Amphoe Bang Rakam,Amphoe Chum Saeng,Amphu Bang Raka,Ban Bang Ragam,Ban Bang Rakam,Bang Rakam,Bān Bāng Ragam,Chum Saeng,Rakam,bangraka,บางระกำ', 16.7584700, 100.1174200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126350, 'Bang Rak', 'Bang Rak', 'Amphoe Bang Rak,Bang Rak,Bangrak,bangrak,บางรัก', 13.7305800, 100.5238800, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126351, 'Bang Racham', 'Bang Racham', 'Amphoe Bang Rachan,Amphoe Sing,Ban Sing,Ban Wang Wua,Bang Racham,Mueang Sing,bangracan,บางระจัน', 14.8920000, 100.3172800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126352, 'Bang Pla Ma', 'Bang Pla Ma', 'Amphoe Bang Pla Ma,Ban Khok Khram,Bang Pla Ma,Khok Khram,bangplama,บางปลาม้า', 14.3960400, 100.1587000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126353, 'Bang Pakong', 'Bang Pakong', 'Amphoe Bang Pakong,Ban Tha Saan,Bang Pakong,Tha Sa-an,bangpakng,บางปะกง', 13.5429700, 100.9933300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126354, 'Bang Pa-in', 'Bang Pa-in', 'Amphoe Bang Pa-In,Amphoe Phra Ratchawang,Ban Ko Bang Pa-in,Ban Len,Bang Pa-in,Khwaeng U Thai,bangpaxin,บางปะอิน', 14.2278300, 100.5758900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126355, 'Bang Pahan', 'Bang Pahan', 'Amphoe Bang Pa Han,Amphoe Nakhon Luang Nai,Bang Pa Han,Bang Pahan,bangpahan,บางปะหัน', 14.4621700, 100.5447800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126356, 'Bang Nam Priao', 'Bang Nam Priao', 'Amphoe Bang Nam Prieo,Ban Bang Nam Prieo,Bang Nam Priao,Bang Nam Prieo,Bang Nam Prio,Bang Nam-priew,bangnaperiyw,บางน้ำเปรี้ยว', 13.8473900, 101.0530600, 'TH', '2013-12-13', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126357, 'Bang Mun Nak', 'Bang Mun Nak', 'Amphoe Bang Mun Nak,Amphoe Mueang Phum,Ban Bang Mun Nak,Ban Mun Nak,Bang Mun Nak,bangmulnak,บางมูลนาก', 16.0278100, 100.3791700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126358, 'Bang Len', 'Bang Len', 'Amphoe Bang Len,Amphoe Bang Phai Nat,Amphoe Bang Pla,Ban Bang Len,Bang Len,banglen,บางเลน', 14.0218800, 100.1718300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126359, 'Bang Lamung', 'Bang Lamung', 'Amphoe Ban Lamung,Amphoe Bang Lamung,Amphoe Naklua,Ban Na Kloea,Ban Na-Glua,Ban Naklua,Bang La-muang,Bang Lamung,Na Klua,banglamung,บางละมุง', 13.0470400, 100.9289100, 'TH', '2008-09-18', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126360, 'Bang Kruai', 'Bang Kruai', 'Amphoe Bang Kruai,Amphoe Bang Yai,Ban Bang Yai,Bang Krai,Bang Kruai,Bang Yai,bangkrwy,บางกรวย', 13.8050000, 100.4728300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126361, 'Bang Krathum', 'Bang Krathum', 'Amphoe Bang Krathum,Ban Bang Gathum,Ban Bang Krahtum,Bang Kathum,Bang Krathem,Bang Krathum,Bān Bang Gathum,Kathum,King Amphoe Bang Krathum,King Bang Kathum,bangkrathum,บางกระทุ่ม', 16.5783100, 100.3003400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126362, 'Bangkok Yai', 'Bangkok Yai', 'Amphoe Bangkok Yai,Bangkok Yai,King Amphoe Bang Kok Yai,บางกอกใหญ่', 13.7231900, 100.4760000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126363, 'Bangkok Noi', 'Bangkok Noi', 'Amphoe Bangkok Noi,Bangkok Noi,Khet Bangkok Noi,bangkxknxy,บางกอกน้อย', 13.7626600, 100.4779800, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126364, 'Bang Khun Thian', 'Bang Khun Thian', 'Amphoe Bang Khun Thian,Bang Khun Thian,Bangkhunthien,bangkhuntheiyn,บางขุนเทียน', 13.6630200, 100.4341600, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126365, 'Bang Khla', 'Bang Khla', 'Amphoe Bang Khla,Ban Bang Khla,Bang Gla,Bang Khla,Bāng Glā,bangkhla,บางคล้า', 13.7214400, 101.2081400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126366, 'Bang Kapi', 'Bang Kapi', 'Amphoe Bang Kapi,Bang Kapi,bang ka pi,บางกะปี', 13.7653000, 100.6470000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126367, 'Bang Bua Thong', 'Bang Bua Thong', 'Amphoe Bang Bua Thong,Bang Bua Thong,bangbawthxng,บางบัวทอง', 13.9178300, 100.4240300, 'TH', '2010-08-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126368, 'Bang Bo', 'Bang Bo', 'Amphoe Bang Bo,Amphoe Bang Hia,Ban Bang Bo,Bang Bau,Bang Bo,Bang Hia,bangbx,บางบ่อ', 13.5742800, 100.8353300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126369, 'Bang Ban', 'Bang Ban', 'Amphoe Bang Ban,Amphoe Sena Nai,Ban Bang Bal,Ban Bang Ban,Bang Bal,Bang Ban,Bāng Bāl,bangbal,บางบาล', 14.3739500, 100.4852800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126370, 'Ban Fang', 'Ban Fang', 'Ban Fang,King Amphoe Ban Fang,banfang,บ้านฝาง', 16.4533100, 102.6389200, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126371, 'Ban Dung', 'Ban Dung', 'Amphoe Ban Dung,Ban Dung,King Amphoe Ban Dung,bandung,บ้านดุง', 17.6990000, 103.2595700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126372, 'Don Phut', 'Don Phut', 'Amphoe Don Phut,Ban Don Phut,Don Phut,King Amphoe Don Phut,dxnphud,ดอนพุด', 14.5917500, 100.6282800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126373, 'Ban Chang', 'Ban Chang', 'Amphoe Ban Chang,Ban Chang,King Amphoe Ban Chang,banchang,บ้านฉาง', 12.7254300, 101.0553100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126374, 'Chamni', 'Chamni', 'Amphoe Chamni,Ban Cham Nit,Ban Chamni,Chamni,King Amphoe Chamni,chani,ชำนิ', 14.7862900, 102.8227700, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126375, 'Chakkarat', 'Chakkarat', 'Amphoe Chakkarat,Ban Chakkarat,Ban Chakkrarat,Ban Chakrarat,Ban Non Mai Daeng,Ban Tha Chang,Chakkarat,King Amphoe Chakkarat,King Amphoe Tha Chang,Tha Chang,cakrach,จักราช', 15.0135300, 102.4128900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126376, 'Ban Bueng', 'Ban Bueng', 'Amphoe Ban Bueng,Amphoe Ban Bung,Ban Ban Bung,Ban Boeng,Ban Bueng,Ban Bung (1),Boeng,King Amphoe Ban Bueng,banbung,บ้านบึง', 13.3110000, 101.1121400, 'TH', '2013-12-12', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126377, 'Bueng Na Rang', 'Bueng Na Rang', 'Amphoe Beung Na Rang,Ban Beung Na Rang,Ban Bung Na Rang,Boeng Narang,Bueng Na Rang,Bung Narang,Bān Beung Na Rāng,King Amphoe Beung Na Rang,bung na rang,บึงนาราง', 16.1712000, 100.1253100, 'TH', '2013-12-13', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126378, 'Ban Talat Bueng', 'Ban Talat Bueng', 'Ban Boeng,Ban Bung,Ban Talat Bueng,Boeng,ban tlad bung,บ้านตลาดบึง', 13.0714700, 101.0031400, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126379, 'Bang Na', 'Bang Na', 'Ban Bang Na,Bang Na,bangna,บางนา', 13.6674400, 100.6420600, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126380, 'Bang Klam', 'Bang Klam', 'Ban Bang Klam,Ban Bang Klam Ban Tai,Bang Klam,bang kla,บางกล่ำ', 7.0895300, 100.4107500, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126381, 'Bang Kaeo', 'Bang Kaeo', 'Amphoe Bang Kaeo,Ban Bang Kaeo,Ban Kew,Bang Kaeo,King Amphoe Bang Kaeo,บางแก้ว', 7.4294700, 100.1780300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126382, 'Ban Bang Kadi Pathum Thani', 'Ban Bang Kadi Pathum Thani', '', 13.9990400, 100.5496200, 'TH', '2008-07-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126383, 'Bang Bua Thong', 'Bang Bua Thong', 'Amphoe Bang Bua Thong,Ban Bang Bua Thong,Ban Bau Thong,Bang Bua Dhohng,Bang Bua Thaung,Bang Bua Thong,Bāng Būa Dhōhng,ban bangbawthxng,bangbawthxng,บางบัวทอง,บ้านบางบัวทอง', 13.9102000, 100.4258100, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126384, 'Bang Bo District', 'Bang Bo District', 'Bang Bo,bangbx,บางบ่อ', 13.5833300, 100.8166700, 'TH', '2014-01-03', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126385, 'Lue Amnat', 'Lue Amnat', 'Amnat,Amphoe Bung,Amphoe Lue Amnat,Ban Amnaj,Ban Amnat,Ban Bung,Ban Hamat Tierin,Bung,Hamat Tierin,King Amphoe Lue Amnat,Lue Amnat,Muang Amach Chareum,Muang Amnat,lux xanac,ลืออำนาจ', 15.6947600, 104.6484600, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126386, 'Bamnet Narong', 'Bamnet Narong', 'Amphoe Bamnet Narong,Bamhnech Narong,Bamnech Narong,Bamnet Narong,Ban Bamhnetnarong,Ban Chuan,Dan Chuan,King Amphoe Bamnet Narong,King Amphoe Ban Chuan,Muang Bamhnech Narong,Muang Bamhnesh Narong,Mueang Bamnet Narong,Tambon Ban Chuan,bahencnrngkh,บำเหน็จณรงค์', 15.5018900, 101.6898200, 'TH', '2012-08-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126387, 'At Samat', 'At Samat', 'Amphoe At Samat,At Samat,Ban Ardsamard,Ban At Samat,Sabut,xacsamarth,อาจสามารถ', 15.8430800, 103.8783900, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126388, 'Aranyaprathet', 'Aranyaprathet', 'Amphoe Aranpradbet,Amphoe Aranya Prathet,Amphoe Aranyaprathet,Amphoe Ban Aranyaprathet,Aran Pradhesa,Aran Pradhet,Aran Prathet,Aran''japratkhet,Aranh,Aranya Pradesa,Aranya Pradhesa,Aranyaprathet,Ban Aran,Ban Aranyaprathet,Muang Aran Pradhet,Muang Aran Pratet,Muang Aranyapraphet,aran''yapurateto jun,xaphex xray pra ths,xaphex xrayprathes,xrayprathes,Араньяпратхет,อรัญประเทศ,อำเภออรัญประทศ,อำเภออรัญประเทศ,アランヤプラテート郡', 13.6927600, 102.5012800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126389, 'Ang Thong', 'Ang Thong', 'Amphoe Bang Kaeo,Amphoe Muang Ang Thong,Ang Thaung,Ang Thong,Ang Thong - xangthxng,Ang Thong - อ่างทอง,Angdhohng,Ban Bang Kaeo,Bang Kaeo,Bang Keo,Changwat Ang Thong,Muang Ang Dhohng,Muang Ang Tawng,Muang Ang Thong,Muang Ang Ton,xangthxng,อ่างทอง', 14.5883900, 100.4528300, 'TH', '2013-08-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126390, 'Amnat Charoen', 'Amnat Charoen', 'Amanat Charoem,Amnat Charoen,Amphoe Amnat Charoen,Amphoe Bung,Ban Bung,Mueang Amnat Charoen,meuxng xanacceriy,xanacceriy,Амнат Чароен,อำนาจเจริญ,เมืองอำนาจเจริญ', 15.8585100, 104.6288300, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126391, 'Akat Amnuai', 'Akat Amnuai', 'Akat Amnuai,Amphoe Akat Amnuai,Ban Akat,King Amphoe Akat Amnuai,xakasxanwy,อากาศอำนวย', 17.5963900, 103.9816000, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126392, 'Phon Charoen', 'Phon Charoen', 'Amphoe Phon Charoen,King Amphoe Phon Charoen,Phon Charoen,phrceriy,พรเจริญ', 18.0314300, 103.7099600, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126393, 'Chaiyo', 'Chaiyo', 'Amphoe Chaiyo,Chaiyo,Cheiyo', 14.6763900, 100.4686100, 'TH', '2010-08-10', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126394, 'Samrong', 'Samrong', 'Amphoe Samrong,Ban Samrong,King Amphoe Samrong,Samrong,sarong,สำโรง', 15.0078100, 104.7841900, 'TH', '2012-01-19', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126395, 'Bueng Bun', 'Bueng Bun', 'Amphoe Bueng Bun,Amphoe Bung Bun,Bueng Bun,Bung Bun,King Amphoe Bueng Bun,King Amphoe Bung Bun,bung burn,บึงบูรณ์', 15.3303000, 104.0448500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126396, 'Song Dao', 'Song Dao', 'Amphoe Song Dao,King Amphoe Song Dao,Song Dao,sxngdaw,ส่องดาว', 17.3362800, 103.4754700, 'TH', '2012-01-19', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126397, 'Thung Yang Daeng', 'Thung Yang Daeng', 'Amphoe Thung Yang Daeng,King Amphoe Thung Yang Daeng,Thung Yang Daeng,ทุ่งยางแดง', 6.6182200, 101.4265000, 'TH', '2012-01-20', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126398, 'Amphoe Sikhiu', 'Amphoe Sikhiu', '', 14.8994400, 101.7083300, 'TH', '2006-01-17', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126399, 'Phanom Dong Rak', 'Phanom Dong Rak', 'Amphoe Phanom Dong Rak,Ban Phanom Dong Rak,King Amphoe Phanom Dong Rak,Phanom Dong Rak,ban phnm dng rak,phnm dng rak,บ้านพนมดงรัก,พนมดงรัก', 14.4457500, 103.3050800, 'TH', '2014-04-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126400, 'Saladan', 'Saladan', 'Ban Saladan,Saladan,Саладан', 7.6134200, 99.0365100, 'TH', '2010-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126401, 'Wichit', 'Wichit', '', 7.8894000, 98.3852300, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126402, 'Ko Pha Ngan', 'Ko Pha Ngan', 'Ko Pha Ngan,Koh Pha Ngan,Koh Phangan,Pangan,keaaphangan,Панган,เกาะพะงัน', 9.7577800, 100.0291400, 'TH', '2010-05-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126403, 'Koh Tao', 'Koh Tao', 'Koh Tao,Tao,keaa tea,Тао,เกาะเต่า', 10.0980800, 99.8380900, 'TH', '2012-05-30', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126404, 'Bang Sue', 'Bang Sue', 'Bang Sue,bangsux,บางซื่อ', 13.8100300, 100.5371400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126405, 'Don Mueang', 'Don Mueang', 'Don Mueang,dxnmeuxng,ดอนเมือง', 13.9139200, 100.5899400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126406, 'Salaya', 'Salaya', 'Amphoe Phutthamonthon,Ban Salaya,King Amphoe Phutthamonthon,Phuttha Monthon,Salaya,ban sala ya,sala ya,บ้านศาลายา,ศาลายา', 13.8020000, 100.3211100, 'TH', '2012-01-20', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126407, 'Khlong Toei', 'Khlong Toei', 'Khlong Toei,khlxngtey,คลองเตย', 13.7166900, 100.5715900, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126408, 'Patong', 'Patong', 'PBS,Patong,had pa txng,pa txng,Патонг,ป่าตอง,หาดป่า ตอง', 7.8960700, 98.2966100, 'TH', '2014-05-11', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126409, 'Chun', 'Chun', 'Amphoe Chun,Ban Huai Chun,Chun,Mueang Wiang Lo,cun,จุน', 19.3369500, 100.1347800, 'TH', '2012-01-16', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126410, 'Thung Chang', 'Thung Chang', 'Amphoe Lae,Ban Thung Chang,Lae,Thung Chang,thungchang,ทุ่งช้าง', 19.3878600, 100.8761900, 'TH', '2012-04-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126411, 'Lat Krabang', 'Lat Krabang', 'Amphoe Lat Kabang,Amphoe Lat Krabang,Khet Lat Krabang,Lartkrabang,Lat Kabang,Lat Kabing,Lat Krabang,ladkrabang,ลาดกระบัง', 13.7234100, 100.7843600, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126412, 'Bang Khae', 'Bang Khae', 'Bang Khae,Khet Bang Khae,Khwaeng Bang Khae,Tambon Bang Khae,บางแค', 13.6919600, 100.4069100, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126413, 'Bang Kho Laem', 'Bang Kho Laem', 'Amphoe Yan Nawa,Bang Kho Laem,Khwaeng Bang Kho Laem,บางคอแหลม', 13.6934700, 100.5022000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126414, 'Bueng Kum', 'Bueng Kum', 'Bueng Kum,bungkum,บึงกุ่ม', 13.7852800, 100.6695800, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126415, 'Chatuchak', 'Chatuchak', 'Chatuchak,ctucakr,จตุจักร', 13.8289300, 100.5598500, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126416, 'Chom Thong', 'Chom Thong', 'Chom Thong,cxmthxng,จอมทอง', 13.6771700, 100.4840700, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126417, 'Huai Khwang', 'Huai Khwang', 'Huai Khwang,hwykhwang,ห้วยขวาง', 13.7767800, 100.5790000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126418, 'Khan Na Yao', 'Khan Na Yao', 'Khan Na Yao,khannayaw,คันนายาว', 13.8260900, 100.6793300, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126419, 'Khlong Sam Wa', 'Khlong Sam Wa', 'Khlong Sam Wa,khlxng sam wa,คลองสามวา', 13.8361600, 100.7352400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126420, 'Lat Phrao', 'Lat Phrao', 'Lat Phrao,ladphraw,ลาดพร้าว', 13.8034900, 100.6074900, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126421, 'Pathum Wan', 'Pathum Wan', 'Pathum Wan,pthumwan,ปทุมวัน', 13.7364900, 100.5239000, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126422, 'Phaya Thai', 'Phaya Thai', 'Phaya Thai,phyathi,พญาไท', 13.7800500, 100.5427500, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126423, 'Ratchathewi', 'Ratchathewi', 'Ratchathewi,rachthewi,ราชเทวี', 13.7590000, 100.5335800, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126424, 'Sai Mai', 'Sai Mai', 'Sai Mai,sayhim,สายไหม', 13.9206800, 100.6455200, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126425, 'Saphan Sung', 'Saphan Sung', 'Saphan Sung,saphan sung,สะพานสูง', 13.7701900, 100.6853100, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126426, 'Sathon', 'Sathon', 'Khet Sathon,Sathon,khet sathr,sathr,สาทร,เขตสาทร', 13.7085000, 100.5261900, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126427, 'Suan Luang', 'Suan Luang', 'Suan Luang,swnhlwng,สวนหลวง', 13.7302800, 100.6513800, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126428, 'Thawi Watthana', 'Thawi Watthana', 'Thawi Watthana,ทวีวัฒนา', 13.7885100, 100.3333400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126429, 'Thung Khru', 'Thung Khru', 'Thung Khru,thung khru,ทุ่งครุ', 13.6287500, 100.5096400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126430, 'Wang Thonglang', 'Wang Thonglang', 'Wang Thonglang,wangthxnghlang,วังทองหลาง', 13.7854600, 100.6116500, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126431, 'Watthana', 'Watthana', 'Vadhana,Watthana,วัฒนา', 13.7297800, 100.5853600, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126432, 'Sop Pong', 'Sop Pong', 'Ban Sop Pong,Sop Pong,ban sb pxng,sb pxng,บ้านสบป่อง,สบป่อง', 19.5188100, 98.2604200, 'TH', '2012-01-20', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126433, 'Ban Chalong', 'Ban Chalong', 'Chalong,ban chlxng,tabl chlxng,ตำบลฉลอง,บ้านฉลอง', 7.8446800, 98.3389700, 'TH', '2011-07-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126434, 'Ban Ratsada', 'Ban Ratsada', 'Ratsada,Ратсада,บ้านรัษฎา', 7.9096300, 98.4024800, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126435, 'Mueang Phuket', 'Mueang Phuket', 'meuxng phuket,เมืองภูเก็ต', 7.8633800, 98.3643700, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126436, 'Bang Sao Thong', 'Bang Sao Thong', 'Amphoe Bang Sao Thong,Bang Sao Thong,King Amphoe Bang Sao Thong,bangseathng,บางเสาธง', 13.5950000, 100.8304200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126437, 'Ko Chang Tai', 'Ko Chang Tai', 'Ko-Chang-Tai,Ко-Чанг-Таи', 12.0017100, 102.3726700, 'TH', '2010-03-04', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126438, 'Nai Harn', 'Nai Harn', 'Nai-Kharn,Наи-Харн', 7.7785900, 98.3066100, 'TH', '2010-06-08', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126439, 'Mae Fa Luang', 'Mae Fa Luang', 'Mae Fa Luang,แม่ฟ้าหลวง', 20.2662800, 99.7984600, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126440, 'Wiang Chiang Rung', 'Wiang Chiang Rung', 'Wiang Chiang Rung,weiyng cheiyng rung,เวียงเชียงรุ้ง', 20.0132800, 100.0563900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126441, 'Wiang Kaen', 'Wiang Kaen', 'Wiang Kaen,เวียงแก่น', 20.1129700, 100.5133100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126442, 'Khun Tan', 'Khun Tan', 'Amphoe Khun Tan,Khun Tan,King Amphoe Khun Tan,khun tal,ขุนตาล', 19.8335300, 100.2585800, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126443, 'Chaloem Phra Kiat', 'Chaloem Phra Kiat', 'Chaloem Phra Kiat,chelimphrakeiyrti,เฉลิมพระเกียรติ', 19.5788100, 101.0801100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126444, 'Mae Lao', 'Mae Lao', 'Mae Lao,แม่ลาว', 19.7900300, 99.6996700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126445, 'Suk Samran', 'Suk Samran', 'Amphoe Suk Samran,King Amphoe Suk Samran,Suk Samran,sukh saray,สุขสำราญ', 9.3445800, 98.4290300, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126446, 'Wiang Nuea', 'Wiang Nuea', 'Wiang Nuea,weiyng henux,เวียงเหนือ', 19.3797200, 98.4464400, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126447, 'Ban Takhun', 'Ban Takhun', 'Amphoe Ban Takhun,Ban Takhun,King Amphoe Ban Takhun,bantakhun,บ้านตาขุน', 8.9036400, 98.8845000, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126448, 'Takuk Nuea', 'Takuk Nuea', 'ta kuk henux,ตะกุกเหนือ', 9.2389400, 98.9786100, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126449, 'Wiang Nong Long', 'Wiang Nong Long', 'King Amphoe Wiang Nong Long,Wiang Nong Long,weiyng hnxng lxng,เวียงหนองล่อง', 18.4204300, 98.7496700, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126450, 'Mae Poen', 'Mae Poen', 'Mae Poen,แม่เปิน', 15.6578900, 99.4698100, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126451, 'Pang Sila Thong', 'Pang Sila Thong', 'Amphoe Pang Sila Thong,King Amphoe Pang Sila Thong,Pang Sila Thong,pang sila thxng,ปางศิลาทอง', 16.0963100, 99.4890600, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126452, 'Kosamphi Nakhon', 'Kosamphi Nakhon', 'Amphoe Kosamphi Nakhon,King Amphoe Kosamphi Nakhon,Kosamphi Nakhon,kosa m phi nkhr,โกสัมพีนคร', 16.6313100, 99.3497500, 'TH', '2012-09-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126453, 'Ban Thi', 'Ban Thi', 'Ban Thi,King Amphoe Ban Thi,ban thi,บ้านธิ', 18.6318600, 99.1166100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126454, 'Manang', 'Manang', 'Amphoe Manang,King Amphoe Manang,Manang,ma nang,มะนัง', 6.9993300, 99.9216100, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126455, 'Ratsada', 'Ratsada', 'Amphoe Ratsada,King Amphoe Ratsada,Ratsada,รัษฎา', 7.9746700, 99.6335300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126456, 'Phra Phrom', 'Phra Phrom', 'Amphoe Phra Phrom,King Amphoe Phra Phrom,Phra Phrom,phra phrhm,พระพรหม', 8.3391100, 99.9009200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126457, 'Chulabhorn', 'Chulabhorn', 'Amphoe Chulabhorn,Amphoe Chulaphon,Chulabhorn,Chulaphon,cula ph rn,จุฬาภรณ์', 8.0759700, 99.8694700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126458, 'Chang Klang', 'Chang Klang', 'Amphoe Chang Klang,Chang Klang,King Amphoe Chang Klang,chang klang,ช้างกลาง', 8.3709400, 99.5624900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126459, 'Nong Yasai', 'Nong Yasai', 'Amphoe Nong Ya Sai,King Amphoe Nong Ya Sai,Nong Yasai,hnxng hya si,หนองหญ้าไซ', 14.7798800, 99.9107300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126460, 'Chum Ta Bong', 'Chum Ta Bong', 'Amphoe Chum Ta Bong,Chum Ta Bong,King Amphoe Chum Ta Bong,chum ta bng,ชุมตาบง', 15.6319400, 99.5523100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126461, 'Mae Wong', 'Mae Wong', 'Mae Wong,แม่วงก์', 15.7816400, 99.5186400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126462, 'Bueng Samakkhi', 'Bueng Samakkhi', 'Amphoe Bueng Samakkhi,Bueng Samakkhi,King Amphoe Bueng Samakkhi,bung samakhkhi,บึงสามัคคี', 16.1872800, 99.9752500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126463, 'Phu Kam Yao', 'Phu Kam Yao', 'Amphoe Phu Kam Yao,King Amphoe Phu Kam Yao,Phu Kam Yao,phu kam yaw,ภูกามยาว', 19.2705000, 99.9701100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126464, 'Chaloem Phra Kiat', 'Chaloem Phra Kiat', 'Chaloem Phra Kiat,chelimphrakeiyrti,เฉลิมพระเกียรติ', 8.1768900, 100.0358100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126465, 'Sawaengha', 'Sawaengha', 'Sawaengha,แสวงหา', 14.7518600, 100.3248100, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126466, 'Doem Bang Nang Buat', 'Doem Bang Nang Buat', 'Doem Bang Nang Buat,deimbangnangbwch,เดิมบางนางบวช', 14.8542800, 100.0977200, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126467, 'Chumsaeng', 'Chumsaeng', 'Chumsaeng,ชุมแสง', 15.8915200, 100.3079500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126468, 'Wachira Barami', 'Wachira Barami', 'Wachira Barami,wchir barmi,วชิรบารมี', 16.5231400, 100.1446400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126469, 'Thong Saen Khan', 'Thong Saen Khan', 'Amphoe Thong Saen Khan,King Amphoe Thong Saen Khan,Thong Saen Khan,ทองแสนขัน', 17.4706500, 100.3314600, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126470, 'Laplae', 'Laplae', 'Laplae,ลับแล', 17.6521100, 100.0389200, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126471, 'Chaloem Phra Kiat', 'Chaloem Phra Kiat', 'Chaloem Phra Kiat,chelimphrakeiyrti,เฉลิมพระเกียรติ', 14.6115000, 100.9082500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126472, 'Santi Suk', 'Santi Suk', 'Amphoe Santi Suk,King Amphoe Santi Suk,Santi Suk,santisukh,สันติสุข', 18.9137000, 100.9416900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126473, 'Phu Phiang', 'Phu Phiang', 'Amphoe Phu Phiang,Phu Phiang,phu pheiyng,ภูเพียง', 18.7426400, 100.7995100, 'TH', '2016-08-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126474, 'Nikhom Phattana', 'Nikhom Phattana', 'Amphoe Nikhom Phattana,King Amphoe Nikhom Phattana,Nikhom Phattana,นิคมพัฒนา', 12.8273600, 101.2027300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126475, 'Ko Chan', 'Ko Chan', 'Amphoe Ko Chan,King Amphoe Ko Chan,Ko Chan,keaa canthr,เกาะจันทร์', 13.4165800, 101.3345800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126476, 'Si Mahosot', 'Si Mahosot', 'Amphoe Khok Pip,Amphoe Si Mahosot,King Amphoe Khok Pip,Si Mahosot,sri mhosth,ศรีมโหสถ', 13.8878000, 101.4050100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126477, 'Phakdi Chumphon', 'Phakdi Chumphon', 'Amphoe Phakdi Chumphon,King Amphoe Phakdi Chumphon,Phakdi Chumphon,phakdi chumphl,ภักดีชุมพล', 15.9051700, 101.4222800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126478, 'Khao Chamao', 'Khao Chamao', 'Amphoe Khao Chamao,Khao Chamao,King Amphoe Khao Chamao,khea cha mea,เขาชะเมา', 12.9758600, 101.6851100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126479, 'Tha Takiap', 'Tha Takiap', 'Amphoe Tha Takiap,King Amphoe Tha Takiap,Tha Takiap,tha takeiyb,ท่าตะเกียบ', 13.4454700, 101.6113300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126480, 'Wang Nam Khiao', 'Wang Nam Khiao', 'Amphoe Wang Nam Khiao,King Amphoe Wang Nam Khiao,Wang Nam Khiao,wang na kheiyw,วังน้ำเขียว', 14.4180100, 101.8611300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126481, 'Prachamtakham', 'Prachamtakham', 'Prachamtakham,pracantkham,ประจันตคาม', 14.0644200, 101.5150300, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126482, 'Sap Yai', 'Sap Yai', 'Amphoe Sap Yai,King Amphoe Sap Yai,Sap Yai,ซับใหญ่', 15.6373900, 101.6167100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126483, 'Erawan', 'Erawan', 'Amphoe Erawan,Ban Erawan,Erawan,King Amphoe Erawan,xerawan,เอราวัณ', 17.3018100, 101.9538200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126484, 'Khao Khitchakut', 'Khao Khitchakut', 'Amphoe Khao Khitchakut,Khao Khitchakut,King Amphoe Khao Khitchakut,khea khichch kud,เขาคิชฌกูฎ', 12.8048100, 102.1151400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126485, 'Soi Dao', 'Soi Dao', 'Amphoe Soi Dao,King Amphoe Soi Dao,Soi Dao,sxydaw,สอยดาว', 13.1289400, 102.2140200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126486, 'Wang Sombun', 'Wang Sombun', 'Amphoe Wang Sombun,King Amphoe Wang Sombun,Wang Sombun,wang smburn,วังสมบูรณ์', 13.3617600, 102.1910500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126487, 'Noen Sa-nga', 'Noen Sa-nga', 'Amphoe Noen Sa-nga,King Amphoe Noen Sa-nga,Noen Sa-nga,nein snga,เนินสง่า', 15.5642800, 102.0012800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126488, 'Khok Pho Chai', 'Khok Pho Chai', 'Amphoe Khok Pho Chai,Khok Pho Chai,King Amphoe Khok Pho Chai,khokphothi chay,โคกโพธิ์ชัย', 16.0837500, 102.3990000, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126489, 'Na Wang', 'Na Wang', 'Amphoe Na Wang,King Amphoe Na Wang,Na Wang,na wang,นาวัง', 17.3244400, 102.0782900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126490, 'Suwanna Khuha', 'Suwanna Khuha', 'Suwanna Khuha,suwrrnkhuha,สุวรรณคูหา', 17.5629200, 102.2798900, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126491, 'Non Din Daeng', 'Non Din Daeng', 'Amphoe Non Din Daeng,King Amphoe Non Din Daeng,Non Din Daeng,โนนดินแดง', 14.3135300, 102.7481400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126492, 'Pa Kham', 'Pa Kham', 'Pa Kham,pa kha,ปะคำ', 14.4381700, 102.7255800, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126493, 'Chaloem Phra Kiat', 'Chaloem Phra Kiat', 'Chaloem Phra Kiat,chelimphrakeiyrti,เฉลิมพระเกียรติ', 14.5583900, 102.9247500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126494, 'Lam Thamen Chai', 'Lam Thamen Chai', 'Amphoe Lam Thamen Chai,King Amphoe Lam Thamen Chai,Lam Thamen Chai,la tha men chay,ลำทะเมนชัย', 15.3535000, 102.9180300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126495, 'Non Daeng', 'Non Daeng', 'Amphoe Non Daeng,King Amphoe Non Daeng,Non Daeng,Tambon Non Daeng,xaphex non dæng,อำเภอโนนแดง,โนนแดง', 15.4106100, 102.5402500, 'TH', '2014-07-09', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126496, 'Ban Mai Chaiyaphot', 'Ban Mai Chaiyaphot', 'Amphoe Ban Mai Chaiyaphot,Ban Mai Chaiyaphot,King Amphoe Ban Mai Chaiyaphot,บ้านใหม่ไชยพจน์', 15.5736100, 102.8333100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126497, 'Non Sila', 'Non Sila', 'Amphoe Non Sila,King Amphoe Non Sila,Non Sila,non sila,โนนศิลา', 15.9743900, 102.6698300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126498, 'Ubonratana', 'Ubonratana', 'Ubonratana,xublratn,อุบลรัตน์', 16.7526900, 102.6324500, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126499, 'Ban Na Muang', 'Ban Na Muang', 'Amphoe Prachak Sinlapakhom,Ban Na Muang,King Amphoe Prachak Sinlapakhom,Prachak Sinlapakhom,banna mwng,บ้านนาม่วง,ประจักษ์ศิลปาคม', 17.2382400, 103.0089200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126500, 'Sa Khrai', 'Sa Khrai', 'Amphoe Sa Khrai,King Amphoe Sa Khrai,Sa Khrai,สระใคร', 17.6754400, 102.7506900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126501, 'Phlapphla Chai', 'Phlapphla Chai', 'Amphoe Phlapphla Chai,King Amphoe Phlapphla Chai,Phlapphla Chai,phlabphla chay,พลับพลาชัย', 14.7301100, 103.1672800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126502, 'Si Somdet', 'Si Somdet', 'Amphoe Si Somdet,King Amphoe Si Somdet,Si Somdet,sri smdec,ศรีสมเด็จ', 15.9979700, 103.4878900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126503, 'Khong Chai', 'Khong Chai', 'Amphoe Khong Chai,Khong Chai,King Amphoe Khong Chai,khxng chay,ฆ้องชัย', 16.2602500, 103.4582800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126504, 'Chuen Chom', 'Chuen Chom', 'Chuen Chom,King Amphoe Chuen Chom,chunchm,ชื่นชม', 16.5548800, 103.1766100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126505, 'Sam Sung', 'Sam Sung', 'Amphoe Sam Sung,King Amphoe Sam Sung,Sam Sung,sa sung,ซำสูง', 16.5432000, 103.0799200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126506, 'Ku Kaeo', 'Ku Kaeo', 'Amphoe Ku Kaeo,King Amphoe Ku Kaeo,Ku Kaeo,กู่แก้ว', 17.1721400, 103.1530300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126507, 'Phibun Rak', 'Phibun Rak', 'Amphoe Phibun Rak,King Amphoe Phibun Rak,Phibun Rak,พิบูลย์รักษ์', 17.5531200, 103.0579400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126508, 'Pakkhat', 'Pakkhat', 'Pakkhat,pak khad,ปากคาด', 18.2978900, 103.3068900, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126509, 'Phonphisai', 'Phonphisai', 'Phonphisai,phonphisay,โพนพิสัย', 18.0210600, 103.0766400, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126510, 'Si Narong', 'Si Narong', 'Amphoe Si Narong,King Amphoe Si Narong,Si Narong,sri nrngkh,ศรีณรงค์', 14.7673600, 103.8739200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126511, 'Non Narai', 'Non Narai', 'Amphoe Non Narai,King Amphoe Non Narai,Non Narai,non narayn,โนนนารายณ์', 15.2376400, 103.9133300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126512, 'Khwao Sinarin', 'Khwao Sinarin', 'Amphoe Khwao Sinarin,Khwao Sinarin,King Amphoe Khwao Sinarin,khe wasin ri nthr,เขวาสินรินทร์', 15.0024400, 103.5915400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126513, 'Thung Khao Luang', 'Thung Khao Luang', 'Amphoe Thung Khao Luang,King Amphoe Thung Khao Luang,Thung Khao Luang,thung khea hlwng,ทุ่งเขาหลวง', 15.9939700, 103.8626400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126514, 'Chiang Khwan', 'Chiang Khwan', 'Amphoe Chiang Khwan,Chiang Khwan,King Amphoe Chiang Khwan,cheiyng khway,เชียงขวัญ', 16.1632800, 103.7535900, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126515, 'Changhan', 'Changhan', 'Amphoe Changhan,Changhan,King Amphoe Changhan,cang har,จังหาร', 16.1387300, 103.6038800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126516, 'Don Chan', 'Don Chan', 'Amphoe Don Chan,Don Chan,King Amphoe Don Chan,dxn can,ดอนจาน', 16.4571100, 103.6955800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126517, 'Phu Phan', 'Phu Phan', 'King Amphoe Phu Phan,Phu Phan,phu phan,ภูพาน', 16.9989100, 103.9734700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126518, 'Si Wilai', 'Si Wilai', 'Si Wilai,sriwili,ศรีวิไล', 18.1818800, 103.7479300, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126519, 'Phu Sing', 'Phu Sing', 'Amphoe Phu Sing,King Amphoe Phu Sing,Phu Sing,phu singh,ภูสิงห์', 14.5474400, 104.1316700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126520, 'Pho Si Suwan', 'Pho Si Suwan', 'Amphoe Pho Si Suwan,King Amphoe Pho Si Suwan,Pho Si Suwan,phothi sri suwrrn,โพธิ์ศรีสุวรรณ', 15.2292900, 104.0767000, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126521, 'Sila Lat', 'Sila Lat', 'Amphoe Sila Lat,King Amphoe Sila Lat,Sila Lat,sila lad,ศิลาลาด', 15.4715600, 104.0715300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126522, 'Thai Charoen', 'Thai Charoen', 'Amphoe Thai Charoen,King Amphoe Thai Charoen,Thai Charoen,thiy ceriy,ไทยเจริญ', 16.0664500, 104.4401800, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126523, 'Phon Na Kaeo', 'Phon Na Kaeo', 'Amphoe Phon Na Kaeo,King Amphoe Phon Na Kaeo,Phon Na Kaeo,โพนนาแก้ว', 17.2212200, 104.2899500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126524, 'Wang Yang', 'Wang Yang', 'Amphoe Wangyang,King Amphoe Wangyang,Wang Yang,wang yang,วังยาง', 17.0575100, 104.4533300, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126525, 'Bueng Khong Long', 'Bueng Khong Long', 'Bueng Khong Long,bung khong hlng,บึงโขงหลง', 17.9668100, 104.0447800, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126526, 'Nathom', 'Nathom', 'Nathom,na thm,นาทม', 17.7853600, 104.0907200, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126527, 'Thung Si Udom', 'Thung Si Udom', 'Amphoe Thung Si Udom,King Amphoe Thung Si Udom,Thung Si Udom,thung sri xudm,ทุ่งศรีอุดม', 14.7330300, 104.9089700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126528, 'Nam Khun', 'Nam Khun', 'Amphoe Nam Khun,King Amphoe Nam Khun,Nam Khun,na khun,น้ำขุ่น', 14.5838600, 104.9248100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126529, 'Benchalak', 'Benchalak', 'Amphoe Benchalak,Benchalak,King Amphoe Benchalak,เบญจลักษ์', 14.7958300, 104.6701700, 'TH', '2011-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126530, 'Lao Suea Kok', 'Lao Suea Kok', 'Lao Suea Kok,hela seux ko k,เหล่าเสือโก้ก', 15.4066100, 104.9235800, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126531, 'Pathum Ratchawongsa', 'Pathum Ratchawongsa', 'Pathum Ratchawongsa,pthum rach wngsa,ปทุมราชวงศา', 15.8922400, 104.9056300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126532, 'Don Mot Daeng', 'Don Mot Daeng', 'Amphoe Don Mot Daeng,Don Mot Daeng,King Amphoe Don Mot Daeng,ดอนมดแดง', 15.3790300, 105.0278600, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126533, 'Mae Wang', 'Mae Wang', 'Mae Wang,แม่วาง', 18.6160400, 98.7729200, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126534, 'Khao Kho', 'Khao Kho', 'Khao Kho,khea khx,เขาค้อ', 16.6579100, 101.0220800, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126535, 'Phra Thong Kham', 'Phra Thong Kham', 'Amphoe Phra Thong Kham,King Amphoe Phra Thong Kham,Phra Thong Kham,phrathxng kha,พระทองคำ', 15.2668600, 102.0202400, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126536, 'Wiang Kao', 'Wiang Kao', 'Amphoe Wiang Kao,King Amphoe Wiang Kao,Wiang Kao,weiyng kea,เวียงเก่า', 16.6824700, 102.2851100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126537, 'Khaen Dong', 'Khaen Dong', 'Amphoe Khaen Dong,Khaen Dong,King Amphoe Khaen Dong,แคนดง', 15.3247600, 103.1334300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126538, 'Sirindhorn', 'Sirindhorn', 'Amphoe Sirindhorn,Sirindhorn,Sirindon,Sirinthon,si rin thr,สิรินธร', 15.2008400, 105.3922200, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126539, 'Sida', 'Sida', 'Amphoe Sida,King Amphoe Sida,Sida,si da,สีดา', 15.5499400, 102.5667500, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126540, 'Srinagarindra', 'Srinagarindra', 'Amphoe Srinagarindra,King Amphoe Chumphon,King Amphoe Srinagarindra,Sinakharin,Srinagarindra,srinkhrinthr,ศรีนครินทร์', 7.5699100, 99.9435300, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126541, 'Sam Chai', 'Sam Chai', 'King Amphoe Sam Chai,Sam Chai,sam chay,สามชัย', 16.8632200, 103.5410600, 'TH', '2010-08-14', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126542, 'Dong Charoen', 'Dong Charoen', 'Amphoe Dong Charoen,Dong Charoen,King Amphoe Dong Charoen,dng ceriy,ดงเจริญ', 16.0205800, 100.6628600, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126543, 'Chaem Luang', 'Chaem Luang', 'Chaem Luang,แจ่มหลวง', 19.0319300, 98.2876700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126544, 'Rattanawapi', 'Rattanawapi', 'Amphoe Rattanawapi,King Amphoe Rattanawapi,Rattanawapi,ratn wapi,รัตนวาปี', 18.2136500, 103.1796700, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126545, 'Hat Samran', 'Hat Samran', 'Amphoe Hat Samran,Hat Samran,King Amphoe Hat Samran,had saray,หาดสำราญ', 7.2403400, 99.5762100, 'TH', '2012-01-21', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126546, 'Ban Pa Pae', 'Ban Pa Pae', 'Ban Pa Pae,บ้านป่าแป๋', 18.2842500, 98.0568300, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126547, 'Bung Khla', 'Bung Khla', 'Amphoe Bung Khla,Bung Khla,King Amphoe Bung Khla,bung khla,บุ่งคล้า', 18.3023200, 103.9741800, 'TH', '2012-02-02', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126548, 'Chai Prakan', 'Chai Prakan', 'Amphoe Chai Prakan,Chai Prakan,King Amphoe Chai Prakan,chiy prakar,ไชยปราการ', 19.7313600, 99.1399700, 'TH', '2012-06-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126549, 'Doi Luang', 'Doi Luang', 'Doi Luang,dxy hlwng,ดอยหลวง', 20.1178300, 100.0991900, 'TH', '2012-06-06', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126550, 'Mae On', 'Mae On', 'Amphoe Mae On,King Amphoe Mae On,Mae On,แม่ออน', 18.7768100, 99.2486100, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126551, 'Sop Moei', 'Sop Moei', 'Amphoe Sop Moei,King Amphoe Sop Moei,Sop Moei,sb mey,สบเมย', 17.9620900, 97.9328800, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126552, 'Bua Lai', 'Bua Lai', 'Amphoe Bua Lai,Bua Lai,King Amphoe Bua Lai,baw lay,บัวลาย', 15.6654800, 102.4988100, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126553, 'Phra Samut Chedi', 'Phra Samut Chedi', 'Amphoe Phra Samut Chedi,King Amphoe Phra Samut Chedi,Phra Samut Chedi,phra smuthr cediy,พระสมุทรเจดีย์', 13.6022200, 100.5721000, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126554, 'Singhanakhon', 'Singhanakhon', 'Amphoe Singhanakhon,King Amphoe Singhanakhon,Singhanakhon,singh nkhr,สิงหนคร', 7.2390300, 100.5527200, 'TH', '2012-06-07', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126555, 'Phu Sang', 'Phu Sang', 'Amphoe Phu Sang,King Amphoe Phu Sang,Phu Sang,phu sang,ภูซาง', 19.5990300, 100.3244400, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126556, 'Mae Hi', 'Mae Hi', 'Mae Hi,แม่ฮี้', 19.3428600, 98.4502300, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126557, 'Pa Phayom', 'Pa Phayom', 'Amphoe Pa Phayom,King Amphoe Pa Phayom,Pa Phayom,pa ph yxm,ป่าพยอม', 7.8403100, 99.9177300, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126558, 'Na Yong', 'Na Yong', 'Amphoe Na Yong,King Amphoe Na Yong,Na Yong,na yong,นาโยง', 7.5616700, 99.6948300, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126559, 'Pho Tak', 'Pho Tak', 'Amphoe Pho Tak,King Amphoe Pho Tak,Pho Tak,phothi tak,โพธิ์ตาก', 17.8748600, 102.4040600, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126560, 'Ko Kut', 'Ko Kut', 'Amphoe Ko Kut,King Amphoe Ko Kut,Ko Kut,keaa kud,เกาะกูด', 11.6585600, 102.5419700, 'TH', '2012-08-05', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126561, 'Bang Bon', 'Bang Bon', 'Bang Bon,bang bxn,บางบอน', 13.6618500, 100.3956700, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126562, 'Din Daeng', 'Din Daeng', 'Din Daeng,dindæng,ดินแดง', 13.7699400, 100.5529900, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126563, 'Phra Nakhon', 'Phra Nakhon', 'Phra Nakhon,phrankhr,พระนคร', 13.7651200, 100.4986400, 'TH', '2017-03-23', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126564, 'Na Kluea', 'Na Kluea', '', 12.9619900, 100.8971500, 'TH', '2017-03-22', 221);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126657, 'Viqueque', 'Viqueque', 'VIQ,Vikeke,Viqueque,bikeke,wei ke ke,Викеке,維克克,비케케', -8.8575000, 126.3647200, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126658, 'Suai', 'Suai', 'Soeai,Suai,Swai,UAI,su ai,swayy,Суаи,سوائی,蘇艾', -9.3128600, 125.2564800, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126659, 'Pante Makasar', 'Pante Makasar', 'Pante Macassar,Pante Makasar,Pante-Makassar,Vila Taveiro', -9.2000000, 124.3833300, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126660, 'Metinaro', 'Metinaro', 'Met Naro,Metinaro', -8.5305600, 125.7447200, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126661, 'Maubara', 'Maubara', 'Maubara,Maubaru,Maubarú', -8.6119400, 125.2061100, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126662, 'Manatuto', 'Manatuto', 'Manatoetoe,Manatuto,Manatutu,Vila de Manatuto', -8.5113900, 126.0130600, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126663, 'Maliana', 'Maliana', 'MPT,Maliana,ma li ya na,malliana,malyana,mariana,مالیانا,マリアナ,瑪利亞娜,말리아나', -8.9916700, 125.2197200, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126664, 'Liquica', 'Liquica', 'Likisa,Likisia,Liquica,Liquissa,Liquiçá,Vila de Liquica,Vila de Liquiçá,Vila de liquissa', -8.5875000, 125.3419400, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126665, 'Dili', 'Dili', 'DIL,Delhi,Dilhi,Dili,Dili khot,Dilis,Dilli,Dilly,Dilo,Dily,Díli,Gorad Dyli,Nova Dili,Ntili,di li,dili,dilli,diri,dyly,tili,Ντίλι,Горад Дылі,Дили,Дили хот,Ділі,Դիլի,דילי,دىلى,ديلي,دیلی,ڈلی,दिली,দিলি,ਦੀਲੀ,டிலி,ಡಿಲಿ,ദിലി,ดิลี,དྷི་ལི།,ဒီလီမြို့,დილი,ディリ,帝力,딜리', -8.5586100, 125.5736100, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126666, 'Baucau', 'Baucau', 'BCH,Bacau,Baucau,Baukau,Vila Salazar,bao kao,baukau,baw khaw,khet bea kea,Баукау,באוקאו,บาวคาว,เขตเบาเกา,包考,바우카우', -8.4711100, 126.4583300, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126667, 'Ainaro', 'Ainaro', 'Ainaro,Ainaru,Builico,Dystrykt Ainaro,Hato-Builico,Vila de Ainaro', -8.9924100, 125.5081600, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126668, 'Aileu', 'Aileu', 'Aileou,Aileu,Ajleu,Vila General Camona,Vila General Carmona,a yi lai wu,aylyw,Αϊλέου,Айлеу,Աիլեու,אילאו,ایلئو,阿伊萊烏', -8.7280600, 125.5663900, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126669, 'Same', 'Same', 'Same,sa mu,Саме,ساہمے، مشرقی تیمور,薩姆', -9.0058100, 125.6461700, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126670, 'Lospalos', 'Lospalos', 'Lospalos,loseupalloseu,rosuparosu,sheng bao luo,Лоспалос,ロスパロス,聖保羅,로스팔로스', -8.5186100, 127.0025000, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126671, 'Gleno', 'Gleno', 'Glenas,Gleno', -8.7238900, 125.4361100, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126672, 'Venilale', 'Venilale', 'Venilale,Vila Vicosa,Vila Viçosa', -8.6430600, 126.3783300, 'TL', '2016-11-27', 222);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126654, 'Fale old settlement', 'Fale old settlement', 'Fakaofu Village,Fale', -9.3851600, -171.2467500, 'TK', '2013-08-11', 224);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126655, 'Nukunonu', 'Nukunonu', 'Nukunonu Village', -9.2004500, -171.8480400, 'TK', '2013-08-11', 224);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126656, 'Atafu Village', 'Atafu Village', 'Atafu,Atafu Village', -8.5421200, -172.5159100, 'TK', '2012-05-30', 224);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126704, 'Matmata', 'Matmata', 'Kalaa Matmata,Matmata,Matmatah,Maţmāţah,Матмата', 33.5444500, 9.9715700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126705, 'Zaouiat Djedidi', 'Zaouiat Djedidi', 'Sidi Djedid,Sidi Djedidi,Zaouiat Djedidi,Zaouiet Djedidi,Zaouit Djedidi,Zawiyat al Jadidi,Zāwiyat al Jadīdī', 36.6437500, 10.5742800, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126706, 'Zahānah', 'Zahanah', 'Zahanah,Zahānah,Zana,Зана', 37.0395900, 10.0387600, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126707, 'Zaghouan', 'Zaghouan', 'Zaghouan,Zaghouane,Zaghwan,Zaghwān,Zaguan,Zagvan,Zankouan,Zarhouan,Zağvan,Zaɣwan,jaguwan,zai ge wan,zghwan,Ζαγκουάν,Загуан,زغوان,宰格萬,자구완', 36.4029100, 10.1429200, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126708, 'Oued Meliz', 'Oued Meliz', 'Oued Meliz,Wadi Maliz,Wādī Malīz', 36.4681300, 8.5495100, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126709, 'Oued Lill', 'Oued Lill', 'Oued Ellil,Oued Lill,Wadi al Layl,Wādī al Layl', 36.8340800, 10.0405700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126710, 'Touza', 'Touza', 'Touza,Tuza,Tuzah,Ţūzah', 35.6354400, 10.8273200, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126673, 'Balkanabat', 'Balkanabat', 'BKN,Balkanabad,Balkanabat,Balkanabatas,Bolqonobod,Nebit-Dag,Nebitdag,Neftedag,ba er kan na ba de,balaqanabata,balkanabateu,barukanabato,blkhan abad,Балканабат,Небит-Даг,بلخان آباد,بلخان‌آباد,बलक़ानाबात,ბალკანაბადი,バルカナバート,巴尔坎纳巴德,발카나바트', 39.5107500, 54.3671300, 'TM', '2013-11-28', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126674, 'Kaka', 'Kaka', 'Chaacha,Kaakcha,Kaakhka,Kaka,Каахка,Кака', 37.3482100, 59.6143100, 'TM', '2014-03-06', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126675, 'Serdar', 'Serdar', 'Gyzylarbat,Kizil-Arvat,Kizyl-Arvat,Kyzyl-Arvat,Serdar,Кизил-Арват,Кизыл-Арват', 38.9764400, 56.2757500, 'TM', '2014-03-06', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126676, 'Gumdag', 'Gumdag', 'Gumdag,Gumdage,Khudaidag,Khuday-Dag,Kum-Dag,Гумдаге', 39.2061100, 54.5905600, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126677, 'Gazanjyk', 'Gazanjyk', 'Gazandzhyk,Gazanjyk,Kasandshik,Kazandzhik,Kazanjik,Газанджык', 39.2446300, 55.5153600, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126678, 'Magtymguly', 'Magtymguly', 'Garrygala,Kara-Kala,Magtymguly,Кара-Кала', 38.4374900, 56.2808100, 'TM', '2014-02-07', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126679, 'Arçabil', 'Arcabil', 'Arcabil,Arçabil,Firjuza,Firyuza,Pewrize,Фирюза', 37.9150000, 58.0898700, 'TM', '2014-04-30', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126680, 'Abadan', 'Abadan', 'Abadan,Bezmein,Buezmeyin,Büzmeýin,Безмеин', 38.0541500, 58.1972100, 'TM', '2014-10-15', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126681, 'Baharly', 'Baharly', 'Baharly,Baherden,Bakharden,Bäherden,Бахарден', 38.4362400, 57.4315800, 'TM', '2014-07-08', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126682, 'Ashgabat', 'Ashgabat', 'ASB,Achgabat,Achkhabad,Aschabad,Aschabadas,Aschchabad,Aschgabat,Asgabat,Asgabata,Asgabate,Asgabato,Ashabad,Ashabat,Ashgabat,Ashkabad,Ashkhabad,Ashkhabad osh,Ashkˌobod,Ashqabad,Ashxabad,Ashxobod,Asjabad,Asjchabad,Asjchabat,Asjkhabad,Askabad,Askabat,Askhabad,Asnkampat,Asqabad,Asxabad,Aszchabad,Aŝgabato,Aşgabat,Aşkabat,Aşqabad,Aşğabat,Ašchabad,Ašchabadas,Ašgabat,Ašgabata,Ašhabad,Așgabat,GIashkuabad,Gorad Ashgabad,Poltoratsk,a shen ha ba de,acukapat,asagabata,asakhabada,asgabad,asgabada,asgabat,ashigabato,ashk abad,ashkhabadi,asigabateu,asqabada,asyuhabateu,xa chka bat,yashkhabad,ʼsgbʼt,ʿەshqabad,Ασγκαμπάτ,Ашгабат,Ашкабад,Ашхабад,Ашхабад ош,Ашқобод,ГІашкъабад,Горад Ашгабад,Աշխաբադ,אשגאבאט,אשגבאט,ئاشخاباد,اشک آباد,عاشق‌آباد,عشق آباد,عشق اباد,عشق‌آباد,عەشقاباد,अश्क़ाबाद,अश्गाबाद,আশখাবাদ,ਅਸ਼ਗ਼ਾਬਾਤ,அசுகாபாத்,ಅಶ್ಗಾಬಾತ್,അഷ്ഗാബാദ്,อาชกาบัต,ཨ་ཧྲི་ཁ་པད།,აშხაბადი,አሽጋባት,アシガバート,阿什哈巴德,아슈하바트,아시가바트', 37.9500000, 58.3833300, 'TM', '2017-06-22', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126683, 'Annau', 'Annau', 'Anau,Anew,Annau,Enev,Änew', 37.8875700, 58.5160000, 'TM', '2014-03-07', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126684, 'Yylanly', 'Yylanly', 'Il''yaly,Ilyanli,Il’yaly,Iyanli,Yylanly', 41.8333300, 59.6500000, 'TM', '2013-10-29', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126685, 'Tagta', 'Tagta', 'Tagta,Takhta', 41.6504100, 59.9164000, 'TM', '2013-10-30', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126686, 'Akdepe', 'Akdepe', 'Ak-Tepe,Ak-Tyube,Akdepe,Leninsk,Акдепе', 42.0551300, 59.3787700, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126687, 'Türkmenbaşy', 'Turkmenbasy', 'Gorad Turkmenbashy,KRW,Krasnovodsk,Krasnowodsk,Krassnowodsk,Tourkmenmpasi,Tuerkmenbasi,Tuerkmenbasy,Turkmanboshi,Turkmenbachi,Turkmenbashi,Turkmenbashy,Turkmenbasi,Turkmenbasis,Turkmenbasy,Turkmenbaszy,Turkmenbaši,Turkmėnbašis,Türkmenbashy,Türkmenbaşy,Türkmenbaşî,Türkmenbaşı,Türkmənbaşı,torukumenbashi,trkman bashy,trkmanbashy,trkmnbashy  trkmanstan,tu ku man ba xi,tuleukeumenbasi,turkmenbashi,Τουρκμένμπασι,Горад Туркменбашы,Красноводск,Туркменбаши,Туркменбашы,Туркменбаші,Төрекмәнбашы,Թուրքմենբաշի,טורקמנבאשי,تركمانباشي,ترکمان باشی,ترکمنباشی، ترکمانستان,ترکمن‌باشی,თურქმენბაში,トルクメンバシ,土庫曼巴希,투르크멘바시', 40.0221600, 52.9551700, 'TM', '2017-01-20', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126688, 'Köneürgench', 'Koeneuergench', 'Koeneuergenc,Koneurgench,Konye-Urgench,Kounia-Ourguentch,Kunja-Urgench,Kunja-Urgentj,Kunya-Urgen,Kunya-Urgench,Köneürgench,Köneürgenç,khnh‌grganj,kone-uleugenchi,Куня-Ургенч,کهنه‌گرگانج,코네우르겐치', 42.3277300, 59.1544200, 'TM', '2013-08-18', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126689, 'Boldumsaz', 'Boldumsaz', 'Boldumsaz,Kalinin,Kalininsk,Porsu,Porsy,Болдумсаз', 42.1282400, 59.6710100, 'TM', '2013-10-30', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126690, 'Daşoguz', 'Dasoguz', 'Dashhowuz,Dashkhovuz,Dashoguz,Dashowuz,Dasoguz,Dasoguzas,Daszoguz,Daşoguz,Daşoğuz,Dašhowuz,Dašoguz,Dašoguzas,Dașoguz,Gorad Dashaguz,TAZ,Tashauz,Tasjauz,Toshhovuz,da sha gu ci,dash awghwz,dashoguzi,dashoguzu,dashwghwz,dasoguza,dasyogujeu,Горад Дашагуз,Дашогуз,داش اوغوز,داشوغوز,داش‌اغوز,दाशोग़ुज़,დაშოგუზი,ダショグズ,达沙古兹,다쇼구즈', 41.8362500, 59.9666100, 'TM', '2015-03-07', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126691, 'Yolöten', 'Yoloeten', 'Iolotan'',Iolotan’,Joljoten,Yolotan,Yoloten,Yolöten,Ёлётен,Иолотань', 37.2988600, 62.3597500, 'TM', '2013-10-29', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126692, 'Tejen', 'Tejen', 'Tedjen,Tedzen,Tedzhen,Tedżen,Tejen,Tejend,Теджен', 37.3833800, 60.5054500, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126693, 'Seydi', 'Seydi', 'Neftezavodsk,Sejdi,Seydi,Сейди', 39.4816000, 62.9137400, 'TM', '2013-10-30', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126694, 'Saýat', 'Sayat', 'Sayat,Saýat', 38.7839300, 63.8803500, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126695, 'Murgab', 'Murgab', 'Murgab,Stalino', 37.4965600, 61.9714200, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126696, 'Mary', 'Mary', 'MYP,Maras,Margiana,Mari,Mary,Mary shaary,Marı,Merv,ma lei,ma ri,mali,mari,maru,mary,mary  trkmanstan,mrw,Мари,Мары,Мары шаары,ماری,ماری، ترکمانستان,مرو,मरी,มารี,მარი,マル,马雷,마리', 37.5937800, 61.8303100, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126697, 'Atamyrat', 'Atamyrat', 'Atamyrat,Kerki,Qarki,Qārki,Атамырат', 37.8357300, 65.2105800, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126698, 'Serhetabat', 'Serhetabat', 'Gusgy,Gushgy,Guşgy,Kushk Post,Kushka,Kushkinskiy Post,Serhetabat,Serkhetabat,Серхетабат', 35.2799200, 62.3438300, 'TM', '2014-04-06', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126699, 'Gowurdak', 'Gowurdak', 'Gaurdak,Gaurdakstroy,Gaurdstroi,Gaurdstroy,Gowurdak', 37.8124400, 66.0465600, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126700, 'Farap', 'Farap', 'Farab,Farap,Фарап', 39.1703700, 63.6116500, 'TM', '2012-01-17', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126701, 'Türkmenabat', 'Turkmenabat', 'CRZ,Chardzha,Chardzhev,Chardzhou,Chardzhui,Chardzhuy,Charjew,Charjou,Chärjew,Leninsk-Turkmenski,Leninsk-Turmenski,Nov Charjui,Nov Chārjui,Novo Chardzhou,Novo-Chardzhuy,Tuerkmenabat,Turkmanobod,Turkmenabad,Turkmenabat,Turkmenabatas,Türkmenabat,Türkmənabad,te~yurukumenabato,trkman abad,trkmn abad,tu ku man na ba de,tuleukeumenabateu,turkamenabata,turkmenabadi,Туркменабад,Туркменабат,Түркменабат,Չարզոու,ترکمان آباد,ترکمن آباد,ترکمن‌آباد,तुर्कमेनाबात,თურქმენაბადი,テュルクメナバート,土庫曼納巴德,투르크메나바트', 39.0732800, 63.5786100, 'TM', '2014-08-19', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126702, 'Bayramaly', 'Bayramaly', 'Bairam Ali,Bajramali,Bayram-Ali,Bayramaly,Байрамали', 37.6185200, 62.1671500, 'TM', '2016-04-04', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126703, 'Gazojak', 'Gazojak', 'Gaz-Achak,Gazojak', 41.1874600, 61.4036000, 'TM', '2014-01-20', 229);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126847, 'Vaini', 'Vaini', '', -21.1929200, -175.1767800, 'TO', '2013-05-07', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126848, 'Pangai', 'Pangai', 'Bagai,Bangai,Pangai', -19.8146800, -174.3542300, 'TO', '2013-06-30', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126849, '‘Ohonua', '`Ohonua', '', -21.3333300, -174.9500000, 'TO', '2013-05-05', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126850, 'Nuku‘alofa', 'Nuku''alofa', 'Niukalofa,Noukoualopha,Nucualofa,Nukalofa,Nuku''alofa,Nuku`alofa,Nuku`aloia,Nukualofa,Nukuʻalofa,Nuku‘alofa,Nuku‘aloia,Nuku’alofa,TBU,nu ku a luo fa,nu kuxalofa,nukuallopa,nukuarofa,Νουκουαλόφα,Нукуалофа,נוקואלופה,นูกูอะโลฟา,ኑኩአሎፋ,ヌクアロファ,努库阿洛法,努庫阿洛發,누쿠알로파', -21.1393800, -175.2018000, 'TO', '2015-12-19', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126851, 'Neiafu', 'Neiafu', 'Neafu,Nei-afo,Neiafu', -18.6506000, -173.9840400, 'TO', '2015-08-31', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126852, 'Hihifo', 'Hihifo', '', -15.9544000, -173.7961600, 'TO', '2013-05-05', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126853, 'Haveluloto', 'Haveluloto', 'Havelu,Haveluloto', -21.1521600, -175.2133300, 'TO', '2013-05-07', 225);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126711, 'Tunis', 'Tunis', 'Gorad Tunis,TUN,Tinis,Tiwnis,Tuenis,Tuinis,Tunes,Tunes tamaneɣt,Tunez,Tunis,Tunis khot,Tunis shaary,Tunis-Ville,Tunisa,Tunisas,Tunisi,Tunisin Orn,Tunisz,Tunixi,Tuniz,Tunizo,Tunus,Tynida,Tùnis,Tùnisi,Túinis,Túnez,Túnis,Túnixi,Túniz,Tûnis,Tünis,chunisu,tu ni si,tu ni si shi,tunis,tunis''s,tunisa,twiniseu,twns,twnys,twwns,tyunisa,Τύνιδα,Горад Туніс,Тунис,Тунис хот,Тунис шаары,Тунисин Орн,Туніс,Թունիս,תוניס,تونس,تونس شہر,توونس,تۇنىس شەھىرى,ٹیونس نگر,ܬܘܢܣ,ट्युनिस,ट्यूनिस,ਤੂਨਿਸ,தூனிஸ்,ടൂണിസ്സ്,ตูนิส,ཊུ་ནིསི།,ტუნისი,ቱኒስ,チュニス,突尼斯,突尼斯市,튀니스', 36.8189700, 10.1657900, 'TN', '2010-05-30', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126712, 'Tozeur', 'Tozeur', 'TOE,Tauzar,Tauzaras,Tawzar,Thusuros,Tozer,Tozeur,Tuzer,tojoeleu,tozuru,tuo ze er,twzr,Таузар,Тозер,توزر,トズール,托泽尔,토죄르', 33.9196800, 8.1335200, 'TN', '2014-07-16', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126713, 'Tataouine', 'Tataouine', 'Foum Tatahouine,Foum Tataouine,Fum Tatawin,Fum Taţāwīn,Fumm Tattauin,Tatahouine,Tatahouïne,Tataouine,Tatauin,Tatavin,Tatavinas,Tatawin,Taţāwīn,tai ta wen,tatau-in,tatauinu,ttawyn,Татавин,Татауїн,تطاوين,تطاوین,タタウイヌ,泰塔溫,타타우인', 32.9296700, 10.4517700, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126714, 'Testour', 'Testour', 'Tastur,Tastūr,Testour,Tichilla', 36.5513000, 9.4430700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126715, 'Tamaghzah', 'Tamaghzah', 'Tamaghzah,Tamerza,Тамерза', 34.3884900, 7.9431300, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126716, 'Thala', 'Thala', 'Tala,Talah,Thala,Tālah', 35.5724400, 8.6703100, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126717, 'Takelsa', 'Takelsa', 'Takelsa,Taklisah,Tāklisah', 36.7833300, 10.6333300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126718, 'Tajerouine', 'Tajerouine', 'Tadjerouine,Tadjrouine,Tadjrouïne,Tajerouine', 35.8917400, 8.5527600, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126719, 'Tabursuq', 'Tabursuq', 'Tabursuq,Teboursouk,Teboursouq', 36.4569200, 9.2475100, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126720, 'Tabarka', 'Tabarka', 'TBJ,Tabarca,Tabarka,Tabarqa,Tabarqah,Thabraca,ta ba ka,tabaleuka,tbrqt,Ţabarqah,Табарка,طبرقة,塔巴卡,타바르카', 36.9544200, 8.7580100, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126721, 'Sousse', 'Sousse', 'Gorad Sus,Hadrumetum,QSO,Sousa,Souse,Soussa,Sousse,Sus,Susa,Susah,Susas,Suss,Sussa,Szusza,Szúsza,Súsa,Sūsah,su sai,suseu,susi,susu,swsh,swst,xi lan ni,Горад Сус,Сус,Сусс,Սուս,סוסה,سوسة,سوسه,სუსი,スース,昔兰尼,苏塞,수스', 35.8253900, 10.6369900, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126722, 'Siliana', 'Siliana', 'Siliana,Silyanah,Silyānah,Souk el Kremis,slyant,Силиана,سليانة', 36.0849700, 9.3708200, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126723, 'Sidi Alouane', 'Sidi Alouane', 'Sidi Allouane,Sidi Alluan,Sidi Alouane,Sidi Eluan,Sidi `Ulwan,Sīdī ‘Ulwān', 35.3750500, 10.9389900, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126724, 'Sidi Bouzid', 'Sidi Bouzid', 'Gammouda,Qamudah,Qamūdah,Sidi Bou Zid,Sidi Bouzid,Sidi Bu Zajd,Sidi Bu Zayd,Sidi Bu Zeyd,Sidi Bu Zid,Sidi-Bouzid,Sidi-Bu-Zid,Sidi-Buzid,Sinti Bouzint,Szidi Bu Zid,Szidi Bú Zid,Sídí Bú Zíd,Sīdī Bū Zayd,sidibujideu,sydy bwzyd,xi di bu ji de,Σιντί Μπουζίντ,Сиди-Бу-Зид,Сиди-Бузид,Сіді-Бузід,سيدي بوزيد,西迪布濟德,시디부지드', 35.0382300, 9.4849400, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126725, 'Sidi Bou Ali', 'Sidi Bou Ali', 'Sidi Bou Ali,Sidi Bu `Ali,Sīdī Bū ‘Alī', 35.9566700, 10.4730600, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126726, 'Sidi Ben Nour', 'Sidi Ben Nour', 'Sidi Ben Nour,Sidi Ben Nur,Sidi Bin Nur,Sīdī Bin Nūr', 35.5333300, 10.9166700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126727, 'Sidi el Hani', 'Sidi el Hani', 'Camp de Sidi el Hani,El Hani,Sidi al Hani'',Sidi ehl'' Ehni,Sidi el Hani,Sīdī al Hāni’,Сиди эль Эни', 35.6713900, 10.3158300, 'TN', '2014-11-01', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126728, 'Sidi Bou Saïd', 'Sidi Bou Said', 'Sidi Abi Sa`id,Sidi Bou Said,Sidi Bou Saïd,Sidi Bu Said,Sidi Bu Saïd,Sīdī Abī Sa‘īd,sydy bw sʿyd,Сиди Бу Саид,سيدي بو سعيد', 36.8687000, 10.3417400, 'TN', '2016-10-24', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126729, 'Chorbane', 'Chorbane', 'Chorbane,Chourbane,Shurban,Shurbān', 35.2858100, 10.3858000, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126730, 'Chebika', 'Chebika', 'Chebica,Chebika,Chebikha,Shabikah,Shabīkah,Чебика', 34.3190900, 7.9351900, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126731, 'Sakiet Sidi Youssef', 'Sakiet Sidi Youssef', 'Sakiet Sidi Youssef,Sakiet Sidi Youssof,Saqiyat Sidi Yusuf,Sidi Youssef,Sāqiyat Sīdī Yūsuf', 36.2229200, 8.3554700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126732, 'Skanes', 'Skanes', 'Chekanes,Saqanis,Skanes,Şaqānis', 35.7833300, 10.8000000, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126733, 'Salakta', 'Salakta', 'Salakta,Salaqtah,Salaqţah,slqtt,سلقطة', 35.3944400, 11.0436100, 'TN', '2016-10-09', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126734, 'Sejenane', 'Sejenane', 'Sajanan,Sajanān,Sajnan,Sajnān,Sedjenane,Sejenane', 37.0572200, 9.2380600, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126735, 'Sfax', 'Sfax', 'Gorad Sfaks,SFA,Safakes,Safakis,Safaqis,Sfaks,Sfaksas,Sfakso,Sfaqes,Sfax,Sfvks,Szfaksz,Taparura,Thaenae,s fak s,seupagseu,sfaqs,si fa ke si,spaksi,spqs,sufakkusu,Şafāqis,Σφαξ,Горад Сфакс,Сфакс,Сфвкс,ספקס,صفاقس,สฟักซ์,სფაქსი,Ṣfaqes,スファックス,斯法克斯,스팍스', 34.7405600, 10.7602800, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126736, 'Sbiba', 'Sbiba', 'Sabibah,Sabībah,Sbiba', 35.5433200, 9.0737000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126737, 'La Sebala du Mornag', 'La Sebala du Mornag', 'Cebala-du-Mornag,La Cebala,La Cebala du Mornag,La Sebala du Mornag,Sabalat Murnaq,Sabālat Murnāq', 36.6793100, 10.2919500, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126738, 'Remada', 'Remada', 'Ramadah,Ramādah,Remada', 32.3166200, 10.3955100, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126739, 'Rafrāf', 'Rafraf', '', 37.1904300, 10.1836500, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126740, 'Radès', 'Rades', 'Maxula,Maxula-Rades,Maxula-Radès,Rades,Radesas,Radis,Radès,Rādis,la di si,ladeseu,radesu,rads,Радес,رادس,ラデス,拉迪斯,라데스', 36.7680600, 10.2752800, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126741, 'Ksour Essaf', 'Ksour Essaf', 'Ksour Essaf,Ksour Essef,Ksursef,Qsour Essaf,Qusur as Saf,Quşūr as Sāf', 35.4180800, 10.9947500, 'TN', '2013-03-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126742, 'Ksibet el Mediouni', 'Ksibet el Mediouni', 'Ksib-el-Mediouni,Ksiba-el-Mediouni,Ksibet el Mediouni,Qusaybat al Madyuni,Quşaybat al Madyūnī,Sieba,Xiebah,qsybt almdywny,قصيبة المديوني', 35.6856100, 10.8425600, 'TN', '2016-10-09', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126743, 'Korbous', 'Korbous', 'Korbous,Korbous Dar el Oudiane,Korbus,Qurbus,Qurbuş,Корбус', 36.8166800, 10.5686500, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126744, 'Korba', 'Korba', 'Korba,Kourba,Kurba,Qurbah,Корба', 36.5786100, 10.8586100, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126745, 'Kélibia', 'Kelibia', 'Clupea,Kelibia,Kelibija,Kélibia,Qulaybiyah,Qulaybīyah,qlybyt,Келибия,قليبية', 36.8475700, 11.0938600, 'TN', '2016-10-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126746, 'Goubellat', 'Goubellat', 'Goubellat,Quballat,Quballāţ', 36.5417800, 9.6633400, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126747, 'Kebili', 'Kebili', 'Kebili,Qibili,Qibilī,qbly,Кебили,قبلي', 33.7043900, 8.9690300, 'TN', '2014-11-01', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126748, 'Ksar Hellal', 'Ksar Hellal', 'Kassar el Hal,Kesser el Hal,Ksar Hellal,Qasr Hallal,Qaşr Hallāl', 35.6477300, 10.8904600, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126749, 'Carthage', 'Carthage', 'Karfagen,Qartajannah,Qarţājannah,Карфаген', 36.8610800, 10.3316100, 'TN', '2010-07-10', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126750, 'El Fahs', 'El Fahs', 'Al Fahs,Al Faḩş,El Fahs,Fahs,Pont du Fas,Pont-du-Fahs,Port-du-Fachs,Qantarat al Fahs,Qanţarat al Faḩş', 36.3741900, 9.9065100, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126751, 'Galaat el Andeless', 'Galaat el Andeless', 'El Gelaah,Galaat el Andeless,Galaat el Andless,Galaat el Anndles,Galaat el Anndlès,Galas el Andeless,Guelaat el Andeless,Guelaat-el-Andless,Kalaat-El-Andaleus,Kalaat-el-Andleus,Kalat-al''-Andalus,Qal`at al Andalus,Qal‘at al Andalus,Калат-аль-Андалус', 37.0629000, 10.1182900, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126752, 'Gafour', 'Gafour', 'Gaffour,Gafour,Qa`fur,Qa‘fūr', 36.3204500, 9.3242400, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126753, 'Gafsa', 'Gafsa', 'Capsa,GAF,Gafsa,Gafsah,Gafso,Gafşah,Justiniania,Kafsa,Qafsah,Qafşah,gafusa,gapeusa,jia fu sa,kaf sa,qfsh,qfst,vfst,Κάφσα,Гафса,גאפסה,قفصة,قفصه,ڤفصة,กัฟซา,ガフサ,加夫薩,가프사', 34.4250000, 8.7841700, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126754, 'Gabès', 'Gabes', 'Abes,GAE,Gabes,Gabesas,Gabis,Gabès,Gābis,Kabis,Kābis,Nkampes,Qabes,Qabis,Qābis,Tacapae,Tacape,gabeseu,gabesu,jia bei si,ka bæs,qabs,vabs,wlayt qabs,Γκαμπές,Габес,قابس,ولاية قابس,ڤابس,กาแบ็ส,ガベス,加貝斯,가베스', 33.8814600, 10.0982000, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126755, 'Nibbar', 'Nibbar', 'Nebeur,Nibbar', 36.2941100, 8.7665700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126756, 'Nefta', 'Nefta', 'Aggarset Nepte,Naftah,Nafţah,Nefta,Netta,Нефта', 33.8730900, 7.8776500, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126757, 'Nabeul', 'Nabeul', 'Nabeul,Naboel,Nabul,Nābul,nabl,Набул,نابل', 36.4560600, 10.7376300, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126758, 'Midoun', 'Midoun', 'Midoun,Midun,Mīdūn,Мидун', 33.8081300, 10.9922800, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126759, 'Mateur', 'Mateur', 'Matem,Mateur,Matir,Māţir', 37.0404500, 9.6655700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126760, 'Msaken', 'Msaken', 'M''saken,Masakin,Masākin,Msaken,Msaker,msakn,Мсакен,مساكن', 35.7291700, 10.5808200, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126761, 'Menzel Salem', 'Menzel Salem', 'Manzil Salim,Manzil Sālim,Menzel Salem,Sidi Amor Ben Salem,Sidi `Umar Bin Salim,Sīdī ‘Umar Bin Sālim', 35.8567300, 8.4765400, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126762, 'Menzel Kamel', 'Menzel Kamel', 'Manzil Kamil,Manzil Kāmil,Menzel Kamel', 35.6247700, 10.6672700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126763, 'Menzel Jemil', 'Menzel Jemil', 'Djemil,Manzil Jamil,Manzil Jamīl,Menjel Djemil,Mennzel Djemil,Menzel Djemil,Menzel Jemil', 37.2361800, 9.9144800, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126764, 'Menzel Heurr', 'Menzel Heurr', 'Manzil Hurr,Manzil Ḩurr,Men-zel Huerr,Mennzel Heur,Menzel Heur,Menzel Heurr,Menzel Horr,Menzel el Heurr', 36.7281800, 10.9575700, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126765, 'Mennzel Bou Zelfa', 'Mennzel Bou Zelfa', 'Manzil Bu Zalafah,Manzil Bū Zalafah,Mennzel Bou Zelfa,Menzel Bou Zelfa', 36.6831200, 10.5843100, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126766, 'Menzel Bourguiba', 'Menzel Bourguiba', 'Bourguiba,Ferryville,Manzil Bu Ruqaybah,Manzil Bū Ruqaybah,Menzel Bourguiba,Sidi Fath Allah,Sīdī Fatḩ Allāh,mnzl bwrqybt,منزل بورقيبة', 37.1536800, 9.7859400, 'TN', '2016-10-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126767, 'Menzel Abderhaman', 'Menzel Abderhaman', 'Manzil `Abd ar Rahman,Manzil ‘Abd ar Raḩmān,Mennzel Abd er Rahmane,Mennzel-Abd-er-Ralmane,Menzel Abd er Rahmane,Menzel Abd-er-Raman,Menzel Abderhaman,Menzel Abderrahman,mnzl ʿbd alrhman,منزل عبد الرحمان', 37.2373700, 9.8631300, 'TN', '2016-10-15', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126768, 'Manouba', 'Manouba', 'La Manouba,La Manoumpa,Manouba,Manuba,Manubah,Manūbah,ma nu ba,manuba,mnwbt,Λα Μανουμπά,Мануба,منوبة,馬努巴,마누바', 36.8080300, 10.0972100, 'TN', '2011-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126769, 'Melloulèche', 'Mellouleche', 'Mallulash,Mallūlash,Meliouneche,Meliounèche,Melloulech,Mellouleche,Melloulèche,Mellouneche,Mellounêche,Mellulesh,mlwlsh‎,ملولش‎', 35.1661700, 11.0350400, 'TN', '2016-10-09', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126770, 'Maktar', 'Maktar', 'Mactaris,Maktar,Makthar', 35.8579800, 9.2007200, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126771, 'Medjez el Bab', 'Medjez el Bab', 'Majaz al Bab,Majāz al Bāb,Medjez el Bab', 36.6496400, 9.6123100, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126772, 'Medenine', 'Medenine', 'Madanin,Madanīn,Medenin,Medenina,Medeninas,Medenine,Mednin,Mentenin,Médenine,mdnyn,medeunin,mei de ning,Μεντενίν,Меденин,Меденін,مدنين,مدنین,梅德寧,메드닌', 33.3549500, 10.5054800, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126773, 'Lemta', 'Lemta', 'Lampta,Lamta,Lamtah,Lamţah,Lemta', 35.6666700, 10.8833300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126774, 'Kesra', 'Kesra', 'Kasra,Kesra,Kessera,Kisrah', 35.8136300, 9.3643400, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126775, 'Jendouba', 'Jendouba', 'Dzhenduba,Jendouba,Jundubah,Jundūbah,Souk el Arba,Souq el Arba,Suq al Arba`a'',Sūq al Arba‘ā’,jndwbt,Джендуба,جندوبة', 36.5011400, 8.7802400, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126776, 'Jilma', 'Jilma', 'Djilma,Jilma,Jilmah', 35.2731100, 9.4238500, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126777, 'Zarzis', 'Zarzis', 'Dzardzis,Dzsardzsisz,Dzsardzsísz,Dżardżis,Jarjis,Jarjīs,Zarzia,Zarzis,Zerzis,jaleujiseu,jie er ji si,jrjys,zarujisu,Зарзис,Зарзіс,جرجيس,جرجیس,ザルジス,傑爾吉斯,자르지스', 33.5039800, 11.1121500, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126778, 'Jemna', 'Jemna', 'Djemma,Djemna,Dzhemna,Jamnah,Jemna,Джемна', 33.5777800, 9.0147200, 'TN', '2014-11-01', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126779, 'Djemmal', 'Djemmal', 'Djemal,Djemmal,Djemmel,Dzhamal'',Jammal,Jammāl,Jemmal,Джамаль', 35.6223100, 10.7569600, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126780, 'Djebeniana', 'Djebeniana', 'Djebaniana,Djebeliana,Djebeniana,Djebiniana,Jabinyanah,Jabinyānah,Jebeniana,Jebiniana', 35.0350000, 10.9080900, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126781, 'Houmt Souk', 'Houmt Souk', 'Djerba,Hawmat as Suq,Houmet Es Souk,Houmet Essouk,Houmt El Souk,Houmt Souk,Houmt Souq,Humk-Suk,Humt-Suk,Khumt-Suk,hao mai te su ge,hwmh alswq,hwmt alswq,Хумт-Сук,حومة السوق,حومه السوق,حومۃ السوق,Ḩawmat as Sūq,豪邁特蘇格', 33.8757600, 10.8574500, 'TN', '2014-07-15', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126782, 'Harqalah', 'Harqalah', 'Harqalah,Hergla,Herkla,hrqlt,هرقلة', 36.0302700, 10.5090400, 'TN', '2016-10-09', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126783, 'Hammam Sousse', 'Hammam Sousse', 'Hadrumete,Hadrumète,Hammam Sousse,Hammam Susa,Hammam Susah,Hamman-Sousse,Justiniapolis,Khammam Sus,Хаммам Сус,Ḩammām Sūsah', 35.8609000, 10.6031300, 'TN', '2014-11-01', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126784, 'Hammam-Lif', 'Hammam-Lif', 'Hammam al Anf,Hammam-Lif,Hamman-Lif,Khammam-Lif,Хаммам-Лиф,Ḩammām al Anf', 36.7286600, 10.3416300, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126785, 'La Goulette', 'La Goulette', 'Chalk el Uedas,El Aouina,Goleta,Goletta,Goulette,Halk el Oued,Halq al Wadi,Halq el Oued,Khal''k-ehl''-Uehd,La Goleta,La Goletta,La Gouletta,La Goulette,La-Gulet,hlq alwady,la gwlyty,lagulleteu,lh gwlt,Ла-Ґулєт,Хальк-эль-Уэд,לה גולט,حلق الوادي,حلق الوادی,لا گولیتی,Ḩalq al Wādī,ラ・グレット,라굴레트', 36.8180600, 10.3050000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126786, 'Haffouz', 'Haffouz', 'Haffouz,Haffuz,Pichon,Ḩaffūz', 35.6323500, 9.6762400, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126787, 'Rhar el Melah', 'Rhar el Melah', 'Gar-ehl''-Mela,Ghar al Milh,Ghar el Melah,Ghār al Milḩ,Porto Farina,Rar el Melah,Rhar el Melah,Ruscania,ras zbyb,Гар-эль-Мела,رأس زبيب', 37.1693900, 10.1906400, 'TN', '2016-10-15', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126788, 'Douz', 'Douz', 'Douz,Duz,Dūz,Дуз', 33.4663200, 9.0203000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126789, 'Degache', 'Degache', 'Degache,Deguach', 33.9760600, 8.2081000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126790, 'Douar Tindja', 'Douar Tindja', 'Dawwar Tinjah,Dawwār Tīnjah,Douar Tindja', 37.1666700, 9.7500000, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126791, 'Dar Chabanne', 'Dar Chabanne', 'Dar Chabane,Dar Chabanne,Dar Sha`ban,Dar-Chaabane,Dar-Chaabane-el-Fehri,Dār Sha‘bān', 36.4679800, 10.7516700, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126792, 'Bou Arkoub', 'Bou Arkoub', 'Bou Arkoub,Bu `Urqub,Bū ‘Urqūb', 36.5385300, 10.5509300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126793, 'Bou Attouche', 'Bou Attouche', 'Bou Atouch,Bou Attouche,Bu `Attush,Bū ‘Aţţūsh', 33.8992700, 9.7849600, 'TN', '2014-11-29', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126794, 'Bou Arada', 'Bou Arada', 'Bou Arada,Bu `Aradah,Bū ‘Arādah', 36.3525100, 9.6217500, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126795, 'Bir Ali Ben Khalifa', 'Bir Ali Ben Khalifa', 'Bi''r `Ali Bin Khalifah,Bir Ali Ben Khalifa,Bir Ali Ben Khalifat,Bi’r ‘Alī Bin Khalīfah', 34.7359200, 10.0924000, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126796, 'Bir el Hafey', 'Bir el Hafey', 'Bi''r al Hufayy,Bir el Afey,Bir el Hafey,Bi’r al Ḩufayy', 34.9321200, 9.1932100, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126797, 'Ben Gardane', 'Ben Gardane', 'Ben Gardan,Ben Gardane,Ben-Gardan,Ben-Gardán,Bin Qirdan,Bin Qirdān', 33.1378300, 11.2196500, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126798, 'Ben Arous', 'Ben Arous', 'Ben Arous,Ben Arus,Ben Arusas,Ben-Arus,Bin Arous,Bin Arus,Bin `Arus,Bin ‘Arūs,ben a lu si,ben-aluseu,Μπιν Αρούς,Бен-Арус,بن عروس,本阿鲁斯,벤아루스', 36.7530600, 10.2188900, 'TN', '2013-08-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126799, 'Bizerte', 'Bizerte', 'Banzart,Biserta,Bizerta,Bizerte,Hippo Diarrhytus,Hippou Aksa,QIZ,bi sai da,bijeleute,bizeruto,bnzrt,byzrth,Μπιζέρτα,Бизерта,Бизерта қаласы,Бізерта,ביזרטה,بنزرت,ビゼルト,比塞大,비제르테', 37.2744200, 9.8739100, 'TN', '2016-12-15', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126800, 'Beni Khiar', 'Beni Khiar', 'Bani Khiyar,Banī Khiyār,Beni Khaar,Beni Khiar,Beni Kriar', 36.4691700, 10.7822200, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126801, 'Beni Khalled', 'Beni Khalled', 'Bani Khallad,Banī Khallād,Beni Khalled,Beni Kraled', 36.6503800, 10.5900400, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126802, 'Beni Kheddache', 'Beni Kheddache', 'Bani Khaddash,Banī Khaddāsh,Beni Kheddache,Beni Kreddache,El Ben Kheddaone,Kreddache', 33.2527900, 10.1988300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126803, 'Beni Hassane', 'Beni Hassane', 'Bani Hassan,Banī Ḩassān,Beni Hassan,Beni Hassane', 35.5672000, 10.8086900, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126804, 'Banbalah', 'Banbalah', 'Banbalah,Bembla', 35.7000000, 10.8000000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126805, 'Béja', 'Beja', 'Bace,Badza,Badża,Badža,Bajah,Batza,Bedja,Bedzha,Beja,Béja,Bājah,ba jie,bajh,bajt,beja,Μπατζά,Беджа,باجة,باجه,巴杰,베자', 36.7256400, 9.1816900, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126806, 'Zouila', 'Zouila', 'Az Zawilah,Az Zawīlah,Zouila,Zuila', 35.5005600, 11.0605600, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126807, 'Skhira', 'Skhira', 'As Sukhayrah,Aş Şukhayrah,Cekhira,El Skhirra,La Skhira,La Skhirra,La Skhrira,La Srira,Sekhira,Shkhira,Skhira,Skhrira,Skira,Srira,alskhyrt,Шхира,الصخيرة', 34.2992000, 10.0699900, 'TN', '2016-10-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126808, 'Sbikha', 'Sbikha', 'As Subaykhah,Sbikha,Sbikra', 35.9332500, 10.0208100, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126809, 'Seïada', 'Seiada', 'As Sayyadah,Aş Şayyādah,Saiada,Saiadah,Sayada,Saïada,Seiada,Seïada,syadt,صيادة', 35.6688700, 10.8924600, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126810, 'As Sars', 'As Sars', 'As Sars,Le Sers,Les Sers,Sers', 36.0764000, 9.0211700, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126811, 'As Sanad', 'As Sanad', 'As Sanad,Es Send,Es Sened,Sened', 34.4628000, 9.2640400, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126812, 'Sahline', 'Sahline', 'Ain Sahalin,As Sahilin,As Sāḩilīn,Sahalin,Sahaline,Sahline', 35.7516600, 10.7110900, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126813, 'Chebba', 'Chebba', 'Ash Shabbah,Ash Shābbah,Chebba,La Chebba,Sheba', 35.2372200, 11.1150000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126814, 'Ariana', 'Ariana', 'Ar''jana,Ariana,Arjana,Aryana,Aryanah,Aryānah,El Ariana,L''Ariana,L’Ariana,ai er ya nai,aliana,aryanh,aryant,aryant‎,Αρυάνα,Арьяна,Аряна,أريانة,أريانة‎,اریانه,艾尔亚奈,아리아나', 36.8601200, 10.1933700, 'TN', '2013-08-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126815, 'Ar Rudayyif', 'Ar Rudayyif', 'Ar Rudayyif,Redevef,Redevel,Redeyef', 34.3827000, 8.1554900, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126816, 'Er Regueb', 'Er Regueb', 'Ar Riqab,Ar Riqāb,El Regueb,Er Regueb,Gounifida,Hennchir el Gounifida,Regueb', 34.8593200, 9.7865400, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126817, 'Rohia', 'Rohia', 'Ar Rawhiyah,Ar Rawḩīyah,Rohia,Souk et Tnine', 35.6512900, 9.0530600, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126818, 'Ouardenine', 'Ouardenine', 'Al Wardanin,Al Wardānīn,Ouadenine,Ouardanine,Ouardenine,Uardenine', 35.7091500, 10.6739700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126819, 'El Ksour', 'El Ksour', 'Al Qusur,Al Quşūr,Ebba-Ksour,El Ksour,El-Bak-Ksour,Ksour', 35.8960700, 8.8849300, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126820, 'Kairouan', 'Kairouan', 'Al Qayrawan,Al Qayrawān,Al-Kayrawan,Al-Kayrawān,Al-Qayrawan,Al-Qayrawān,Cairuao,Cairuão,Kairouan,Kairuan,Kairuanas,Kairuán,Kairwan,Kajruan,Kajruano,Kayravan,Keruan,QKN,Qairawan,Qairawān,Qairouan,Qairwan,Qayrawan,Qayruvon,alqyrwan,kai lu wan,kaileuwan,keruan,qyrwan,Καϊρουάν,Кайруан,Қайруан қаласы,קירואן,القيروان,قیروان,კაირუანი,ケルアン,凯鲁万,카이르완', 35.6781000, 10.0963300, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126821, 'Kasserine', 'Kasserine', 'Al Kasrayn,Al Qasrayn,Al Qaşrayn,Al-Kasrajn,Kaserin,Kaserinas,Kassarin,Kasserin,Kasserine,Qasserine,alqsryn,ka sai lin,kaselin,kasurinu,Αλ Κασράυν,Касерін,Кассерин,القصرين,القصرین,カスリーヌ,卡塞林,카세린', 35.1675800, 8.8365100, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126822, 'Gremda', 'Gremda', 'Al Qarmadah,Gremda', 34.7500000, 10.7833300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126823, 'El Golaa', 'El Golaa', 'Al Qal`ah,Al Qal‘ah,El Golaa,El Kalaa,Galaa', 33.4848500, 9.0067800, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126824, 'Monastir', 'Monastir', 'Al Munastir,Al Munastīr,El Menstir,Gorad Manascir,Hadrumetum,MIR,Monastir,Monastyr,Monastyras,Monastır,Monasztir,Munastir,Munastır,Ruspina,almnstyr,mnstyr,mnstyr  tywns,mo na si ti er,monaseutileu,monasutiru,Μοναστίρ,Горад Манасцір,Монастир,Монастір,Մոնաստիր,المنستير,المنستیر,منستير,منستیر، تیونس,მონასტირი,モナスティル,莫纳斯提尔,모나스티르', 35.7779900, 10.8261700, 'TN', '2012-05-16', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126825, 'La Mohammedia', 'La Mohammedia', 'Al Muhammadiyah,Al Muḩammadīyah,La Mohammedia,Mohamedia,Mohamedla,Mohammedia', 36.6744600, 10.1563300, 'TN', '2016-09-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126826, 'El Mida', 'El Mida', 'Al Midah,Al Mīdah,El Mida,El Midda,Mida', 36.7255600, 10.8552800, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126827, 'Metlaoui', 'Metlaoui', 'Al Metlaoui,Matlaoui,Metlaoni,Metlaoui', 34.3208100, 8.4015700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126828, 'Mezzouna', 'Mezzouna', 'Al Mazzunah,Al Mazzūnah,Merzouna,Mezzouna', 34.5775800, 9.8419300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126829, 'Al Matlīn', 'Al Matlin', 'Al Matlin,Al Matlīn,El Metline,Metlin,Metline,Метлин', 37.2451600, 10.0500000, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126830, 'Mesdour', 'Mesdour', 'Al Masdur,Al Maşdūr,El Masdour,Mesdour', 35.6820600, 10.7274600, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126831, 'Al Marsá', 'Al Marsa', 'Al Marsa,Al Marsá,El Marsa,La Marsa', 36.8781800, 10.3246600, 'TN', '2010-08-03', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126832, 'El Maamoura', 'El Maamoura', 'Al Ma`murah,Al Ma‘mūrah,El Maamoura,El Mamoura,Maamoura,Mahmur,Marmora', 36.4649900, 10.8061200, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126833, 'Mahdia', 'Mahdia', 'Africa,Al Mahdiyah,Al Mahdīyah,Al Mantigia,Al-Mahdijja,Madhia,Mahdia,Mahdija,Mahedia,Makhdija,Mehdia,Mehdiye,Zella,almhdyh,almhdyt,ma he di ye,madia,Αλ Μαντίγια,Махдия,Махдія,المهدية,المهدیه,مہدیہ,マーディア,马赫迪耶,마디아', 35.5047200, 11.0622200, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126834, 'Le Krib', 'Le Krib', 'Al Karib,Al Karīb,Le Krib', 36.3280200, 9.1361300, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126835, 'El Kef', 'El Kef', 'Al Kaf,Al Kāf,Chakbanaria,Chikka Benar,Ehl''-Kef,El Kef,Kef,Le Kef,Sicca Veneria,alkaf,Эль-Кеф,الكاف', 36.1742400, 8.7048600, 'TN', '2014-03-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126836, 'El Jem', 'El Jem', 'Al Jamm,Ehl'' Dzhem,El Djem,El Jem,El Jemm,Sidi el Djem,Thysdrus,Эль Джем', 35.3000000, 10.7166700, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126837, 'El Haouaria', 'El Haouaria', 'Al Huwariyah,Al Huwwariyah,Al Huwwārīyah,Al Hūwārīyah,Aquilaria,Ehl''-Khauarija,El Aouaria,El Awaria,El Haouaria,El-Haouaria,Эль-Хауария', 37.0500200, 11.0144200, 'TN', '2013-08-04', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126838, 'Hammamet', 'Hammamet', 'Al Hammamat,Al Ḩammāmāt,Al-Hammamat,Gorad Khamamet,Hamametas,Hammamet,Khamamet,Khammamet,alhmamat,ha ma ma te,hammameteu,hanmametto,hmamat  tywns,Горад Хамамет,Хамамет,Хаммамет,الحمامات,حمامات، تیونس,ハンマメット,哈马马特,함마메트', 36.4000000, 10.6166700, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126839, 'El Hamma', 'El Hamma', 'Al Hammah,Al Ḩāmmah,Ehl''-Khamma,El Hamma,El Hamma de l''Arad,El Hamma de l’Arad,Эль-Хамма', 33.8915200, 9.7962900, 'TN', '2014-11-29', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126840, 'Fernana', 'Fernana', 'Al Firnanah,Al Firnānah,Fernana,Fernara', 36.6554700, 8.6960200, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126841, 'El Battan', 'El Battan', 'Al Batan,Al Baţān,El Batane,El Bathan,El Bathane,El Battan', 36.8036800, 9.8442400, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126842, 'Bekalta', 'Bekalta', 'Al Baqalitah,Al Baqāliţah,Bekalta,Mkalta', 35.6173900, 10.9946600, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126843, 'El Alia', 'El Alia', 'Al `Aliyah,Al ‘Āliyah,Ehl''-Alija,El Alia,Uzalis,Эль-Алия', 37.1691100, 10.0347800, 'TN', '2015-09-06', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126844, 'Akouda', 'Akouda', 'Akkudah,Akkūdah,Akouda,Akuda', 35.8691000, 10.5653000, 'TN', '2012-01-18', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126845, 'Douane', 'Douane', '', 36.4476600, 10.7557000, 'TN', '2011-02-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126846, 'Port el Kantaoui', 'Port el Kantaoui', 'mrsy alqntawy,مرسى القنطاوي', 35.8923900, 10.5943400, 'TN', '2016-10-08', 227);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126854, 'Demre', 'Demre', 'Demre,Eynihal,Gokyazi,Gökyazı,Kale,Zumrutkaya,Zümrütkaya,Кале', 36.2444400, 29.9850000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126855, 'Zeytinliova', 'Zeytinliova', 'Palamut,Yavakoy,Yavaköy,Yayakoy,Yayaköy,Zeytinliova', 38.9911800, 27.6763500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126856, 'Zeytindağ', 'Zeytindag', 'Resadiye,Reşadiye,Zeytindag,Zeytindağ', 38.9672200, 27.0722200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126857, 'Zara', 'Zara', 'Kocgiri,Koçgiri,Zara', 39.8977800, 37.7583300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126858, 'Yunak', 'Yunak', 'Yunak', 38.8141800, 31.7322300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126859, 'Yumurtalık', 'Yumurtalik', 'Aegoe,Ayas,Yumurtalik,Yumurtalık', 36.7738600, 35.7929700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126860, 'Yumurtalık', 'Yumurtalik', 'Jumurtalyk,Jumurtalyku,Vimourtalic,Yumurtalik,Yumurtalık,you mu er ta lei ke,ywmartalyk,ywmwrtalyq,Юмурталык,Юмурталыкъ,ضلع یومورتالیک,یومارتالیک,یومورتالیق,尤穆爾塔勒克', 36.7666700, 35.7833300, 'TR', '2010-08-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126861, 'Yüksekova', 'Yuksekova', 'Dize,Gever,Juksekova,YKO,Yueksekova,Yuksekova,Yusekova,Yüksekova,Yüsekova,yu ke sai ke wa,ywksk awwa,ywkskwfa,ywksykwwa,Йӱксекова,Юксекова,ضلع یکسیکووا,يوكسكوفا,گەڤەر,یوکسک اووا,یوکسیکووا,یوک‌سکوا,于克塞科瓦', 37.5736200, 44.2871600, 'TR', '2013-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126862, 'Salat', 'Salat', 'Salat,Salatiulya,Sinan,Yukarisalat,Yukary-Salat,Yukarısalat', 37.8417200, 40.8865000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126863, 'Kozak', 'Kozak', 'Kozak,Yukaribey,Yukarıbey', 39.2512400, 27.0902100, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126864, 'Yücebağ', 'Yucebag', 'Yucebag,Yücebağ', 38.3936700, 41.2671300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126865, 'Yozgat', 'Yozgat', 'Gioznkat,Jozgat,Jozgatas,Saralus,Yozgad,Yozgat,Yozqat,Yuzgat,iozgati,yojeugateu,yozgata,yozugato,yue zi jia te,ywzgat,ywzghad,ywzghat,ywzgt,Γιοζγκάτ,Йозгат,Յոզղատ,يوزغات,یوزغاد,یوزگات,یوزگت,योज़्गत,იოზგათი,ヨズガト,約茲加特,요즈가트', 39.8200000, 34.8044400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126866, 'Yoncalı', 'Yoncali', 'Birik,Sotik,Yoncali,Yoncalı,Şotik', 39.0091300, 38.2532000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126867, 'Yolboyu', 'Yolboyu', 'Kirgali,Kirkali,Kırgalı,Kırkali,Pirinclik,Pirinçlik,Yolboyu', 37.8976400, 40.0008600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126868, 'Yolbaşı', 'Yolbasi', 'Keferallap,Yolbasi,Yolbaşı', 37.3871700, 41.3177800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126869, 'Yolağzı', 'Yolagzi', 'Derindip,Dirindip,Yolagzi,Yolağzı', 37.5255400, 41.3534000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126870, 'Yıldızeli', 'Yildizeli', 'Yenihan,Yildizeli,Yıldızeli', 39.8663900, 36.5988900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126871, 'Yiğityolu', 'Yigityolu', 'Karbeyaz,Karbeyaz Bucagi,Karbeyaz Bucağı,Yigityolu,Yiğityolu', 35.9956300, 36.2600400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126872, 'Yiğitler', 'Yigitler', 'Yigitaliler,Yigitler,Yiğitaliler,Yiğitler', 39.8675000, 26.6111100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126873, 'Yeşilyurt', 'Yesilyurt', 'Yesilyurt,Yeşilyurt', 38.3397200, 28.6644400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126874, 'Yeşilyurt', 'Yesilyurt', 'Cirmikti,Ismetpasa,Yesilyurt,Yeşilyurt,Çırmıktı,İsmetpaşa', 38.2960200, 38.2452600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126875, 'Yeşilyurt', 'Yesilyurt', 'Yesilyurt,Yeşilyurt', 37.1932400, 28.2753700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126876, 'Yeşilyazı', 'Yesilyazi', 'Havacor,Havaçor,Yesilyazi,Yeşilyazı,Zeranik,Zerenik,Zeronik', 39.3347300, 39.0812200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126877, 'Yeşilova', 'Yesilova', 'Acem,Yesilova,Yeşilova', 38.4095000, 33.8380400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126878, 'Yeşilova', 'Yesilova', 'Satilar,Satirlar,Satılar,Satırlar,Yesilova,Yeşilova', 37.5080600, 29.7547200, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126879, 'Yeşilli', 'Yesilli', 'Rismil,Rişmil,Yesilli,Yeşilli', 37.3381300, 40.8173900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126880, 'Erzin', 'Erzin', 'Ehrzin,Erzin,Yesilkent,Yeşilkent,Эрзин', 36.9534800, 36.1983900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126881, 'Yeşilhisar', 'Yesilhisar', 'Karahisar,Karahısar,Yesilhisar,Yeşilhisar', 38.3497200, 35.0866700, 'TR', '2015-04-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126882, 'Misli', 'Misli', 'Akpinar,Akpınar,Golcuk,Gölcük,Misli,Yesilgolcuk,Yeşilgölcük', 38.2311900, 34.7767100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126883, 'Yeşildere', 'Yesildere', 'Ibrala,Yesildere,Yeşildere,İbrala', 37.1566800, 33.5144700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126884, 'Yeşilalan', 'Yesilalan', 'Barman,Yesilalan,Yeşilalan', 37.4606600, 40.7844100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126885, 'Yerköy', 'Yerkoy', 'Yerkoy,Yerköy', 39.6380600, 34.4672200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126886, 'Yerkesik', 'Yerkesik', 'Yerkesik', 37.1362500, 28.2840300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126887, 'Yenişarbademli', 'Yenisarbademli', 'Bademli,Yenisarbademli,Yenişarbademli', 37.7077800, 31.3863900, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126888, 'Yenişakran', 'Yenisakran', 'Yenisakran,Yenişakran', 38.8863900, 27.0669400, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126889, 'Yenipınar', 'Yenipinar', 'Asagi Keferzo,Ashagy-Keferzo,Aşağı Keferzo,Yenipinar,Yenipınar', 37.8429100, 41.3013700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126890, 'Yenipazar', 'Yenipazar', 'Yenipazar', 39.4636100, 35.0830600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126891, 'Yenipazar', 'Yenipazar', 'Distretto di Yenipazar,Enipazar,Yenipazar,ynpzar  ydyn,Енипазар,ینپزار، یدین', 37.8233200, 28.1957300, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126892, 'Yenimehmetli', 'Yenimehmetli', 'Yenimehmet,Yenimehmetli', 39.4200000, 32.1688900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126893, 'Yeniköy', 'Yenikoy', 'Yenikoy,Yeniköy', 39.7787400, 28.0029900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126894, 'Yeniköy', 'Yenikoy', 'Yenikly,Yenikoy,Yeniköy', 37.8804200, 41.0500400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126895, 'Yenicekale', 'Yenicekale', 'Yenicekale,Yenikoy,Yeniköy', 37.5987400, 36.6326400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126896, 'Yeniköy', 'Yenikoy', 'Haraberes,Harabereş,Harabresik,Harabreşik,Kharabreshik,Yenikoy,Yeniköy', 37.2707400, 42.4247200, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126897, 'Didim', 'Didim', 'Didim,Didimy,Yenihisar,Yoran,Дидимы', 37.3849600, 27.2564300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126898, 'Yenifoça', 'Yenifoca', 'Foggia Nova,Naes Foyes,Yenice,Yenicefoca,Yenifoca,Yenifoça', 38.7333300, 26.8333300, 'TR', '2013-11-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126899, 'Yenifakılı', 'Yenifakili', 'Fakili,Fakılı,Karafakili,Karafakılı,Yenifakili,Yenifakılı', 39.2114200, 35.0003600, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126900, 'Altpınar', 'Altpinar', 'Altpinar,Altpınar,Torunlar,Yenicik', 39.2041700, 32.7477800, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126901, 'Yeniceoba', 'Yeniceoba', 'Yeniceoba', 38.8697200, 32.7883300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126902, 'Yenice', 'Yenice', 'Yenice,Yenice Koyu,Yenice Köyü', 39.9308300, 27.2580600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126903, 'Yenice', 'Yenice', 'Yenice', 39.7608900, 28.9072900, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126904, 'Yenice', 'Yenice', 'Yenice', 37.8283700, 28.5711500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126905, 'Yenice', 'Yenice', 'Yenice', 36.9774400, 35.0519700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126906, 'Yenibaşak', 'Yenibasak', 'Ardusin,Arduşin,Yenibasak,Yenibaşak', 38.8041400, 40.9922200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126907, 'Reşadiye', 'Resadiye', 'Resadiye,Reşadiye,Yelkenli', 38.4887900, 42.5350100, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126908, 'Yeditepe', 'Yeditepe', 'Bezge,Yeditepe', 35.9675300, 36.0145200, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126909, 'Yedisu', 'Yedisu', 'Yedisu', 39.4327700, 40.5336800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126910, 'Yazyurdu', 'Yazyurdu', 'Celikanliyurd,Celikanliyurt,Celikânlıyurd,Celikânlıyurt,Gobekviran,Göbekviran,Yazyurdu', 38.7992600, 36.9319000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126911, 'Yazıhan', 'Yazihan', 'Yazihan,Yazıhan', 38.5929200, 38.1732700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126912, 'Yayvantepe', 'Yayvantepe', 'Kartmin,Katmin,Yayvantepe', 37.3013100, 41.5206100, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126913, 'Yaylı', 'Yayli', 'Kavs,Kavuz,Yayli,Yaylı', 37.2029300, 40.7537500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126914, 'Yaylak', 'Yaylak', 'Baziki,Hevenk,Yaylak', 37.3826800, 38.3389200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126915, 'Yayladere', 'Yayladere', 'Conek,Cönek,Holhol,Jajladere,Xorxol,Yayladere,Яйладере,ضلع یالادیر', 39.2261400, 40.0695000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126916, 'Yayladağı', 'Yayladagi', 'Ordu,Yayladag,Yayladagi,Yayladağ,Yayladağı,Yayladgi,Yayladği', 35.9025000, 36.0627200, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126917, 'Yayla', 'Yayla', 'Yayla', 38.6309200, 40.5279300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126918, 'Yaygın', 'Yaygin', 'Migdi,Miğdi,Yaygin,Yaygın,Ziyaret', 38.8974800, 41.3061300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126919, 'Yavuzeli', 'Yavuzeli', 'Cingife,Yarimca,Yarımca,Yavuzeli', 37.3177200, 37.5682400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126920, 'Yavu', 'Yavu', 'Belcik,Yavi,Yavu', 39.7920200, 36.2060300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126921, 'Yatağan', 'Yatagan', 'Ahikoy,Ahiköy,Yatagan,Yatağan', 37.3402500, 28.1427900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126922, 'Yarpuzlu', 'Yarpuzlu', 'Yarpuzlu', 38.0541400, 38.5213000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126923, 'Yarpuz', 'Yarpuz', 'Cebel,Cebelibereket,Yarpuz', 37.0482400, 36.4306600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126924, 'Yarma', 'Yarma', 'Yarma', 37.8114900, 32.8827800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126925, 'Yardımcı', 'Yardimci', 'Cabirulensar,Cabirülensar,Dzhabiryuleksar,Sumatar,Yardimci,Yardymdzhi,Yardımcı', 37.0209100, 39.0053300, 'TR', '2016-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126926, 'Yarbasan', 'Yarbasan', 'Yarbasan,Yarbasanisiklar,Yarbasanışıklar', 38.9888900, 28.8080600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126927, 'Yaprakbaşı', 'Yaprakbasi', 'Bari,Yaprakbasi,Yaprakbaşı', 37.6540900, 40.5463500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126928, 'Yanarsu', 'Yanarsu', 'Garzan,Yanarsu,Zok', 38.0364100, 41.5522700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126929, 'Yamaç', 'Yamac', 'Yamac,Yamaç', 38.7762300, 40.4389400, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126930, 'Yalvaç', 'Yalvac', 'Jalvach,Yalvac,Yalvaç,Ялвач', 38.2955600, 31.1777800, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126931, 'Yalınca', 'Yalinca', 'Dim,Dimkoy,Dimköy,Yalinca,Yalinizca,Yalınca,Yalınızca', 37.8565700, 43.5223000, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126932, 'Yalıhüyük', 'Yalihuyuk', 'Yalihuyuk,Yalıhüyük', 37.3007700, 32.0854800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126933, 'Yalangöz', 'Yalangoz', 'Yalangoz,Yalangöz,Yalankoz', 36.5768000, 36.5076600, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126934, 'Yakapınar', 'Yakapinar', 'Misis,Yakapinar,Yakapınar', 36.9734200, 35.6204300, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126935, 'Yakacık', 'Yakacik', 'Aya,Baiae,Karacami,Karsi,Karşı,Payas,Yakacik,Yakacık', 36.7560000, 36.2143200, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126936, 'Yahyalı', 'Yahyali', 'Gazibenli,Jakh''jaly,Yahyali,Yahyalı,Яхьялы', 38.1022800, 35.3570400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126937, 'Yahşihan', 'Yahsihan', 'Yahsihan,Yahsiyan,Yahşihan,Yahşiyan', 39.8502800, 33.4529400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126938, 'Yağcılar', 'Yagcilar', 'Yagcilar,Yağcılar', 39.4171200, 28.3810900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126939, 'Viranşehir', 'Viransehir', 'Antoninopolis,Veeranshahr,Viransehir,Viranshekhire,Viranşehir,Wiranschehir,Вираншехире', 37.2234900, 39.7551900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126940, 'Varto', 'Varto', 'Gumgum,Gümgüm,Varto', 39.1737500, 41.4540200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126941, 'Van', 'Van', 'Gorad Van,Thospia,Urartu,VAN,Van,Van i Tyrkia,Vana,Vanas,Wan,ban,bhyana,fan cheng,van,vani,vu~an,wan,wan  trky,Βαν,Ван,Горад Ван,Վան,ואן,وان,وان، ترکی,भ्यान,வான்,วาน,ვანი,ヴァン,凡城,반', 38.4945700, 43.3832300, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126942, 'Uzunkuyu', 'Uzunkuyu', 'Uzunkoyu,Uzunkuyu', 38.2785800, 26.5431500, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126943, 'Uzungeçit', 'Uzungecit', 'Derahin,Derakhin,Dirahini,Uzungecit,Uzungeçit', 37.4905200, 42.9903600, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126944, 'Cimin', 'Cimin', 'Cimin,Uzumlu,Üzümlü', 39.7094700, 39.7001500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126945, 'Üzümlü', 'Uzumlu', 'Manastir,Manastır,Uzumlu,Uzumlu Manastir,Uzumlu Manastır,Üzümlü', 37.5405700, 31.6038000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126946, 'Yeşilüzümlü', 'Yesiluzumlu', 'Ozumlu,Uzumlu,Yesiluzumlu,Yeşilüzümlü,Özümlü,Üzümlü', 36.7336100, 29.2333300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126947, 'Uşak', 'Usak', 'Flaviopolis,Gorad Ushak,Ouchak,Ousak,Temenothyrae,USQ,Usak,Usakas,Uschak,Ushak,Ushaq,Uşak,Ušakas,awshak,usaka,ushaki,ushaku,usyakeu,wu sha ke,Ουσάκ,Горад Ушак,Ушак,أوشاك,اوشاک,عشاق,ਉਸ਼ਾਕ,უშაქი,ウシャク,烏沙克,우샤크', 38.6735100, 29.4058000, 'TR', '2017-01-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126948, 'Urla', 'Urla', 'Urla,Vourla,Vourlah Skala,awrla  azmyr,Βουρλά,Урла,اورلا، ازمیر', 38.3229200, 26.7640300, 'TR', '2017-01-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126949, 'Ürgüp', 'UErguep', 'UErguep,Urgup,Ürgüp', 38.6296000, 34.9119900, 'TR', '2015-10-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126950, 'Şanlıurfa', 'Sanliurfa', 'Antiocheia,Edesa,Edessa,Ehdessa,Orfa,Ourfa,SFQ,Sanliurfa,Urfa,Urfeh,Şanlıurfa,Αντιόχεια,Эдесса', 37.1670800, 38.7939200, 'TR', '2017-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126951, 'Umurlu', 'Umurlu', 'Umurlu', 37.8500300, 27.9627500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126952, 'Umraniye', 'Umraniye', 'Batik,Batık,Umraniye', 39.1750000, 31.2344400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126953, 'Uluyatır', 'Uluyatir', 'Mizar,Uluyatir,Uluyatır', 36.9633300, 37.6936100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126954, 'Ulukışla', 'Ulukisla', 'Faustinopolis,Halala,Suecaeddin,Ulukisla,Ulukışla,awlwqshla,Şücaeddin,اولوقشلا,شجاع‌الدین', 37.5477600, 34.4852800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126955, 'Uludere', 'Uludere', 'Goyan,Guyan,Göyan,Güyan,Helet,Kalhesanan,Kalkhesnan,Kilaban,Kylaban,Kılaban,Uludere', 37.4407400, 42.8523600, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126956, 'Arsuz', 'Arsuz', 'Arsus,Arsuz,Aruz,Arúz,Kabevli,Kapevli,Rhossus,Ulucinar,Uluçınar', 36.4130500, 35.8903300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126957, 'Uluborlu', 'Uluborlu', 'Uluborlu,Uluborru', 38.0782500, 30.4501900, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126958, 'Ulubey', 'Ulubey', 'Gobek,Göbek,Ulubei,Ulubey,Улубеи', 38.4198700, 29.2912900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126959, 'Ulaş', 'Ulas', '', 39.4449200, 37.0390000, 'TR', '2006-01-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126960, 'Ula', 'Ula', 'Ula', 37.1049100, 28.4166700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126961, 'Kerh', 'Kerh', 'Karhidicle,Karkhydidzhle,Kerh,Kerhidicle Koyu,Kerhidicle Köyü,Kârhidicle,Uctepe,Üçtepe', 37.8257000, 40.5440200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126962, 'Üçpınar', 'Ucpinar', 'Hocakoy,Hocaköy,Ucpinar,Üçpınar', 37.1341300, 32.2614600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126963, 'Reshidi', 'Reshidi', 'Rasidi,Raşidi,Reshidi,Residi,Reşidi,Uckavak,Üçkavak', 37.4947100, 40.9680600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126964, 'Üçdam', 'Ucdam', 'Esil,Eşil,Ucdam,Üçdam', 39.5630800, 40.1757000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126965, 'Tuzlukçu', 'Tuzlukcu', 'Tuzlukcu,Tuzlukçu', 38.4777800, 31.6263900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126966, 'Melefan', 'Melefan', 'Melefan,Tuzlagozu,Tuzlagözü', 38.1802200, 41.5687000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126967, 'Tutak', 'Tutak', 'Tutak', 39.5385400, 42.7658700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126968, 'Tut', 'Tut', 'Tut,Tût,twt  trky,twt  trkyh,twwt,Тут,توت، ترکی,توت، ترکیه,تووت,ضلع ٹٹ', 37.7952900, 37.9161000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126969, 'Turunçova', 'Turuncova', 'Turuncova,Turunçova', 36.3688900, 30.1375000, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126970, 'Türkoğlu', 'Turkoglu', 'Turkoglu,Türkoğlu', 37.3864900, 36.8426200, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126971, 'Turgutlu', 'Turgutlu', 'Caesarea Trocetta,Cassaba,Kasaba,Turgutlu', 38.4953300, 27.6997000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126972, 'Turgut', 'Turgut', 'Turgut', 38.6269400, 31.8108300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126973, 'Turgut', 'Turgut', 'Leyna,Leyne,Turgut', 37.3750000, 28.0311100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126974, 'Tunceli', 'Tunceli', 'Kalan,Mameki,Mamekiye,Mamekî,Mamiki,Tunceli,Tuncəli,Tundzheli,tnjyly,tong jie li,to~unjeri,tunjelli,twnjly,Тунджели,Тунджелі,تنجیلی,تونجلي,تونجلی,مامەکی,トゥンジェリ,通傑利,툰젤리', 39.0992100, 39.5435100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126975, 'Sütlüce', 'Sutluce', 'Sutluce,Sütlüce,Tulluk,Tüllük', 39.1622800, 39.5440000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126976, 'Tufanbeyli', 'Tufanbeyli', 'Hoket,Hoketce,Höket,Höketçe,Magara,Mağara,Tufanbejli,Tufanbeyli,Туфанбейли,ضلع توفانبیلی', 38.2633300, 36.2205600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126977, 'Torbalı', 'Torbali', 'Tepekoey,Tepeköy,Torbali,Torbaly,Torbalı,Торбалы', 38.1519000, 27.3622300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126978, 'Toptepe', 'Toptepe', 'Nebil,Toptepe', 37.2611300, 41.2494800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126979, 'Toprakkale', 'Toprakkale', 'Toprakkale', 37.0685500, 36.1466100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126980, 'Topaklı', 'Topakli', 'Topakli,Topaklı', 39.0055500, 34.8264400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126981, 'Pınarbaşı', 'Pinarbasi', 'Elvanli,Elvanlı,Pinarbasi,Pınarbaşı,Tomuk,Tömük', 36.7034000, 34.3627000, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126982, 'Tomarza', 'Tomarza', 'Gostere,Goztere,Göstere,Tomarza', 38.4472200, 35.7991700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126983, 'Toklar', 'Toklar', 'Toklar', 38.4180600, 36.0150000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126984, 'Tire', 'Tire', 'Arcadiopolis,Teira,Teıra,Theda,Thireh,Tira,Tire,tyrh,تیره', 38.0887700, 27.7350800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126985, 'Tercan', 'Tercan', 'Mamahatun,Mamhatun,Tercan,trjan,ترجان', 39.7770900, 40.3778300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126986, 'Telminar', 'Telminar', 'Habap,Telmimar,Telminar,Tepeustu,Tepeüstü', 37.1112900, 41.3835900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126987, 'Tepehan', 'Tepehan', 'Sinan,Tepehan', 38.1178800, 38.7262200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126988, 'Tepecikören', 'Tepecikoren', 'Tepecikoren,Tepecikören', 37.3613500, 35.6262700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126989, 'Tepecik', 'Tepecik', 'Tepecik', 37.8235800, 27.8749600, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126990, 'Tepebaşı', 'Tepebasi', 'Halimiye,Tepebasi,Tepebaşı', 36.6662800, 32.7221400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126991, 'Tepealtı', 'Tepealti', 'Telyakup,Tepealti,Tepealtı', 37.0959500, 41.3683400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126992, 'Tepe', 'Tepe', 'Behramki,Bekhramki,Tepe,Tepekey,Tepekoy,Tepekëy,Tepeköy', 37.7894300, 40.7716100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126993, 'Temelli', 'Temelli', 'Samutlu,Temelli,Yukari Samutlu,Yukarı Samutlu', 39.7275000, 32.3552800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126994, 'Tekman', 'Tekman', 'Takos,Tatos,Tekman', 39.6411100, 41.5054200, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126995, 'Tekirova', 'Tekirova', 'Celcikli,Celtikli,Phaselis,Tekirova,Tekrova,Tekróva,Çeltikli,Текирова', 36.5017000, 30.5272300, 'TR', '2008-11-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126996, 'Tefenni', 'Tefenni', 'Tefenni', 37.3096800, 29.7753800, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126997, 'Tecirli', 'Tecirli', 'Degirmenocagi,Değirmenocağı,Tecirli', 37.1618300, 36.1097800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126998, 'Tavşanlı', 'Tavsanli', 'Taushanli,Tavsanli,Tavşanlı', 39.5423700, 29.4986600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(126999, 'Tavas', 'Tavas', 'Tavas,Yarangum,Yarangume,Yarangüm,Yarangüme,ta wa si,tawas,Тавас,تاواس,ضلع تاوواس,塔瓦斯', 37.5735100, 29.0705800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127000, 'Tatvan', 'Tatvan', 'Tatvan,Татван', 38.4922100, 42.2826900, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127001, 'Taşucu', 'Tasucu', 'Akiman,Balacale,Bolcali,Bolcalı,Bulacali,Holmi,Tasucu,Taşucu', 36.3214000, 33.8816500, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127002, 'Taşpınar', 'Taspinar', 'Taspinar,Taşpınar', 38.1796300, 34.0249900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127003, 'Taşlıçay', 'Taslicay', 'Asagitaslicay,Aşağıtaşlıçay,Taslicay,Taşlıçay', 39.6296600, 43.3687800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127004, 'Taşlı', 'Tasli', 'Gundukevir,Guntkevir,Gyundyukevir,Gündükevir,Güntkevir,Tasli,Taşlı', 37.9869900, 42.1351000, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127005, 'Taşkent', 'Taskent', 'Pirlerkondu,Taskent,Taşkent', 36.9243000, 32.4913100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127006, 'Taşdelen', 'Tasdelen', 'Mutmur,Tasdelen,Taşdelen', 38.8381000, 38.5045700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127007, 'Bakırdağı', 'Bakirdagi', 'Bakirdagi,Bakırdağı,Tasci,Taşçı', 38.2159700, 35.7902100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127008, 'Taşağıl', 'Tasagil', 'Tasagil,Taşağıl', 36.9224000, 31.2360800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127009, 'Tarsus', 'Tarsus', 'Antiochia ad Cydnum,Gorad Tarsus,Tars,Tarsas,Tarse,Tarso,Tarson,Tarsos,Tarsous,Tarsus,Tarsus i Mersin,Tersus,da shu,taleususeu,tarsusi,tarsws,tarususu,trsws,trsws  mrsyn,Ταρσός,Горад Тарсус,Тарс,Тарсус,Տարսոն,טרסוס,تارسوس,ضلع ٹارسس,طرسوس,طرسوس، مرسین,თარსუსი,タルスス,大數,타르수스', 36.9176600, 34.8927700, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127010, 'Taraksu', 'Taraksu', 'Golyurt,Gölyurt,Taraksu,Tillo', 38.1541600, 39.1483700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127011, 'Taraksu', 'Taraksu', 'Taraksu,Taraksukoyu,Taraksuköyü', 38.0166700, 39.0833300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127012, 'Tanyeri', 'Tanyeri', 'Tanyeri', 39.6113700, 39.8315100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127013, 'Tanır', 'Tanir', 'Tanir,Tanır', 38.4194400, 36.9122200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127014, 'Talas', 'Talas', 'Tafas,Talas,Талас', 38.6908000, 35.5538000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127015, 'Tahtaköprü', 'Tahtakopru', 'Tahtakopru,Tahtaköprü', 39.9500000, 29.6500000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127016, 'Tahir', 'Tahir', 'Tahir', 39.8558600, 42.4283400, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127017, 'Suvarlı', 'Suvarli', 'Suvarli,Suvarlı', 37.5386700, 37.6321000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127018, 'Şenocak', 'Senocak', 'Senocak,Shuti,Suti,Şenocak,Şuti', 37.6503500, 40.6944100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127019, 'Pavlu Cebel', 'Pavlu Cebel', 'Pavlu Cebel,Sutculer,Sütçüler', 37.4973700, 30.9772700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127020, 'Susurluk', 'Susurluk', 'Firt,Fırt,Susigirlik,Susughirli,Susugurlu,Susurluk,Susığırlık', 39.9136100, 28.1577800, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127021, 'Suruç', 'Suruc', 'Suruc,Suruch,Suruç,Syuryuch,Суруч', 36.9761200, 38.4253300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127022, 'Avine', 'Avine', 'Avine,Surgucu,Syurgyudzhyu,Sürgücü', 37.5737300, 40.7325200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127023, 'Sürgü', 'Surgu', 'Surgu,Sürgü', 38.0054800, 37.9635000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127024, 'Sulusaray', 'Sulusaray', 'Ciftlik,Sulusaray,Çiftlik', 39.9938900, 36.0840400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127025, 'Sülüklü', 'Suluklu', 'Suluklu,Sülüklü', 38.8811100, 32.3425000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127026, 'Suluçem', 'Sulucem', 'Musun,Sulucem,Suluçem', 39.6938600, 43.8147200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127027, 'Sultanhisar', 'Sultanhisar', 'Sultanhisar', 37.8898900, 28.1543600, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127028, 'Sultanhanı', 'Sultanhani', 'Sultanhani,Sultanhanı', 38.2471000, 33.5496100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127029, 'Sultandağı', 'Sultandagi', 'Isakli,Ishakli,Sultandagi,Sultandağı,İsaklı,İshaklı', 38.5311100, 31.2280600, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127030, 'Süleymanlı', 'Suleymanli', 'Suleymanli,Süleymanlı,Zeytunfirnis,Zeytünfırnıs', 37.8726400, 36.8171400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127031, 'Sulak', 'Sulak', 'Bafi,Sulak', 37.4134200, 41.9611400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127032, 'Sulak', 'Sulak', 'Mihrip,Nehrip,Nekhrip,Nihrip,Sulak', 37.2945800, 42.1363700, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127033, 'Şuhut', 'Suhut', 'Suhut,Şuhut', 38.5311100, 30.5458300, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127034, 'Sorgun', 'Sorgun', 'Buyukkohne,Büyükköhne,Kohne,Köhne,Sorgun,Sorgune,Yesilova,Yeşilova,Соргуне', 39.8101200, 35.1859600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127035, 'Soma', 'Soma', 'Distretto di Soma,Germe,Soma,Soma i Tyrkia,Somy,soma,suo ma,swmh,Σόμα,Сома,Сомы,סומה,ضلع سوما,ソマ,索馬,소마', 39.1855400, 27.6094500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127036, 'Solhan', 'Solhan', 'Boglan,Boğlan,Buglan,Solhan', 38.9652500, 41.0544300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127037, 'Söke', 'Soeke', 'Sjoke,So''ke,Sok,Soke,Sokia,Söke,se kai,swkh,Сок,Соьке,Сёке,Сӧке,سوکه,瑟凱', 37.7482000, 27.4061400, 'TR', '2011-09-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127038, 'Söğütlü', 'Sogutlu', 'Sogutlu,Söğütlü', 38.8001900, 40.6697100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127039, 'Kindirip', 'Kindirip', 'Kindirip,Sogutlu,Söğütlü', 37.4470600, 41.2197600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127040, 'Söğüt', 'Sogut', 'Sogut,Söğüt', 40.0143000, 30.1848600, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127041, 'Sivrihisar', 'Sivrihisar', 'Justinianapolis,Sivrihisar', 39.4503700, 31.5340900, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127042, 'Sivrice', 'Sivrice', 'Sivrice', 38.4422300, 39.3093800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127043, 'Sivrice', 'Sivrice', 'Sivrice', 37.2767500, 41.3356900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127044, 'Siverek', 'Siverek', 'Severek,Siverek,Sivereke,Suverek,Сивереке', 37.7550300, 39.3166700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127045, 'Sivaslı', 'Sivasli', 'Sivasli,Sivaslı', 38.4994400, 29.6836100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127046, 'Sivas', 'Sivas', 'Gorad Sivas,Megalopolis,Sebastea,Sebastia,Sevas,Sevasteia,Sewas,Sivas,Sivasas,Siwas,Sêwas,VAS,sibaseu,sivasi,su~ivu~asu,sywas,sywws,xi wa si,Σεβάστεια,Горад Сівас,Сивас,Сівас,Սեբաստիա,סיווס,سيواس,سیواس,سێواس,სივასი,スィヴァス,錫瓦斯,시바스', 39.7483300, 37.0161100, 'TR', '2012-08-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127047, 'Şirvan', 'Sirvan', 'Kufra,Kufre,Küfre,Sirvan,Şirvan', 38.0625100, 42.0251700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127048, 'Tililan', 'Tililan', 'Sirtkoy,Sırtköy,Telila,Telilâ,Tilila,Tililan', 37.3742800, 42.0338600, 'TR', '2013-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127049, 'Şırnak', 'Sirnak', 'Shirnak,Sirnak,Şırnak,Ширнак', 37.5139300, 42.4543200, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127050, 'Sındırgı', 'Sindirgi', 'Korukoy,Koruköy,Sindirgi,Sındırgı', 39.2412800, 28.1784200, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127051, 'Yenice', 'Yenice', 'Kurtgokozu,Kürtgökozü,Sindiran,Sındıran,Yenice', 39.2752800, 32.6802800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127052, 'Sincik', 'Sincik', 'Sincik', 38.0364500, 38.6125700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127053, 'Sincan', 'Sincan', 'Sincan', 39.4716700, 37.8708300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127054, 'Sinanpaşa', 'Sinanpasa', 'Sinanpasa,Sinanpaşa,Sincanli,Sincanlı', 38.7444400, 30.2427800, 'TR', '2017-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127055, 'Sinanköy', 'Sinankoy', 'Salat,Sinan,Sinankoy,Sinanköy', 37.8616600, 40.9928300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127056, 'Simav', 'Simav', 'Simav,Synaus', 39.0882000, 28.9776700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127057, 'Silvan', 'Silvan', 'Farqin,Farqîn,Martyropolis,Miyafarkin,Sil''van,Siliwan,Silvan,Sıliwan,farqyn,myafarqyn,sylwan,sylwan  dyar baqr,xi er wan,Силван,Сильван,سیلوان,سیلوان، دیار باقر,فارقین,ميافارقين,錫爾萬', 38.1370800, 41.0081700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127058, 'Silopi', 'Silopi', 'Girgimac,Girgimaç,Girikamo,Girikoma,Sil''opi,Silopi,Sil’opi,Силопи', 37.2437900, 42.4634500, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127059, 'Sille', 'Sille', 'Sille', 37.9273100, 32.4199500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127060, 'Silifke', 'Silifke', 'Selefke,Selefkeh,Seleucia,Seleucia ad Calycadnum,Silifka,Silifke,Sılıfka,shirifuke,slwkyh,sylyfky,xi li fu kai,Силифке,سلوکیه,سيليفكى,ضلع سلیفکے,シリフケ,錫利夫凱', 36.3777800, 33.9344400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127061, 'Siirt', 'Siirt', 'Gorad Siirt,SXZ,Sairt,Sert,Sgerd,Siirt,Sirt,Sirtas,Sêrt,siileuteu,siirti,su~iiruto,syrt,xi er te,Горад Сіірт,Сиирт,Сирт,Сіїрт,Սղերդ,سعرد,سیرت,سێرت,სიირთი,スィイルト,錫爾特,시이르트', 37.9293000, 41.9413400, 'TR', '2015-06-13', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127062, 'Seyitgazi', 'Seyitgazi', 'Seyitgazi', 39.4447200, 30.6947200, 'TR', '2013-07-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127063, 'Seyhan', 'Seyhan', 'Sejg''an,Sejkhan,Seyhan,syhan,Сейгьан,Сейхан,سيحان,ضلع سیحان', 36.9874700, 35.3059200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127064, 'Seydişehir', 'Seydisehir', 'Seydisehir,Seydişehir', 37.4192600, 31.8452700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127065, 'Sevinç', 'Sevinc', 'Sevinc,Sevinc Koy,Sevinç,Sevinç Köy', 39.7800000, 30.6888900, 'TR', '2014-02-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127066, 'Servi', 'Servi', 'Servi', 38.5703800, 40.3200400, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127067, 'Serinyol', 'Serinyol', 'Batirga,Bedirge,Serinyol', 36.3613900, 36.2136100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127068, 'Serik', 'Serik', 'Kokes,Koles,Kukes,Kükes,Serik,sai li ke,sryq,Серик,سریق,塞里克', 36.9169400, 31.0988900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127069, 'Şereflikoçhisar', 'Sereflikochisar', 'Kochisar,Koçhisar,Serefli,Sereflikochisar,Shereflikochkhisar,xie lei fu li ke qi xi sa er,Şerefli,Şereflikoçhisar,Шерефликочхисар,ШерефликъочхӀисар,شرفلی قوچ‌حصار,ضلع شیریفلیکوچیسار,謝雷夫利科奇希薩爾', 38.9392500, 33.5386000, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127070, 'Şenyurt', 'Senyurt', 'Derbesie,Derbesiye,Senyurt,Shen"yurt,Shen”yurt,Şenyurt', 37.0793200, 40.6424600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127071, 'Şenoba', 'Senoba', 'Sekerek,Senoba,Şenoba', 37.4643600, 42.7224800, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127072, 'Ebish', 'Ebish', 'Ebish,Ebsi,Ebşi,Epsi,Epşi,Senkoy,Şenköy', 37.4634700, 41.1886300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127073, 'Şenköy', 'Senkoy', 'Sehkoy,Senkoy,Seyhkoy,Seyhkoyu,Seyhköyü,Seyhler,Şehköy,Şenköy,Şeyhköy,Şeyhler', 36.0484100, 36.1436600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127074, 'Senirkent', 'Senirkent', 'Senikent,Senirkent', 38.1044400, 30.5486100, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127075, 'Şemdinli', 'Semdinli', 'Navsar,Navşar,Semdinli,Semdinni,Şemdinli,Şemdinni', 37.3051400, 44.5742000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127076, 'Selimiye', 'Selimiye', 'Mandalyat,Selimiye', 37.4003500, 27.6554300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127077, 'Side', 'Side', 'Eski Adalia,Eskiantalya,Selimiye,Sida,Side,Sidé,sydh,xi dai,Сиде,Сіде,سیده,سیدہ,西代', 36.7666700, 31.3888900, 'TR', '2014-07-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127078, 'Selendi', 'Selendi', 'Selendi', 38.7444400, 28.8677800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127079, 'Selçuk', 'Selcuk', 'Ayasoluk,Ephesus,Sel''chuk,Selchuk,Selcuk,Selçuk,sai er qiu ke,selchukeu,seruchuku,Селчук,Сельчук,セルチュク,塞尔丘克,셀추크', 37.9513700, 27.3684900, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127080, 'Selçikler', 'Selcikler', 'Selcikler,Selcuklar,Selçikler,Selçuklar', 38.4983700, 29.6548200, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127081, 'Seksenören', 'Seksenoren', 'Seksenoren,Seksenveren,Seksenviran,Seksenören,Suveren', 36.9725200, 39.0748400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127082, 'Sekili', 'Sekili', 'Orui,Orul,Sekili', 36.9787600, 37.6717400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127083, 'Seki', 'Seki', 'Seki', 36.8037800, 29.6515500, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127084, 'Şekerli', 'Sekerli', 'Karacaviran,Karaviran,Sekerli,Şekerli', 37.5705000, 39.3872000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127085, 'Şehit Nusretbey', 'Sehit Nusretbey', 'Haktanir,Haktanır,Harapresmenkus,Harapreşmenkuş,Kharapresh-Menkush,Nusratiye,Sehit Nusretbey,Şehit Nusretbey', 36.8466700, 38.7358300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127086, 'Seferihisar', 'Seferihisar', '', 38.1975000, 26.8388100, 'TR', '2016-03-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127087, 'Şefaatlı', 'Sefaatli', 'Hacisefaatli,Hacışefaatlı,Sefaatli,Şefaatli,Şefaatlı', 39.5043000, 34.7563000, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127088, 'Savur', 'Savur', 'Savur', 37.5354400, 40.8787600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127089, 'Savcılı', 'Savcili', 'Savcili,Savcilibuyukoba,Savcilioba,Savcılı,Savcılıbüyükoba,Savcılıoba', 39.2288900, 33.6813900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127090, 'Kayacık', 'Kayacik', 'Hezan,Kayacik,Kayacık,Savat', 38.3414200, 40.6133600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127091, 'Savaştepe', 'Savastepe', 'Giresun,Savastepe,Savaştepe', 39.3831900, 27.6561200, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127092, 'Sason', 'Sason', 'Kabilcevaz,Kabilcoz,Kabilcuz,Sason,Sasun', 38.3276700, 41.4137700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127093, 'Saruhanlı', 'Saruhanli', 'Sarihanli,Saruhanli,Saruhanlı,Sarıhanlı', 38.7345500, 27.5681100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127094, 'Edremit', 'Edremit', 'Edremit,Gumusdere,Gümüşdere,Sarmansuyu', 38.4206900, 43.2588900, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127095, 'Şarkışla', 'Sarkisla', 'Sarkisla,Tonus,Şarkışla', 39.3518600, 36.4097600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127096, 'Şarkîkaraağaç', 'Sarkikaraagac', 'Dogukaraagac,Doğukaraağaç,Karaagac,Karaağaç,Sarkikaraagac,Şarkîkaraağaç', 38.0794400, 31.3663900, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127097, 'Sarız', 'Sariz', 'Koyyeri,Köyyeri,Sariz,Sarız,Serez', 38.4791700, 36.4989800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127098, 'Sarıyahşi', 'Sariyahsi', 'Sariyahsi,Sarıyahşi', 38.9834900, 33.8413600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127099, 'Sarıveliler', 'Sariveliler', 'Sariveliler,Sarıveliler', 36.6970500, 32.6120300, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127100, 'Sarısu', 'Sarisu', 'Aktepe,Sarisu,Sarısu', 39.0188700, 42.9209200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127101, 'Sarıoğlan', 'Sarioglan', 'Sarioglan,Sarıoğlan', 39.0769400, 35.9667100, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127102, 'Seri', 'Seri', 'Sari,Sarikoy,Sarıköy,Seri', 37.3600100, 41.3005500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127103, 'Sarıkonak', 'Sarikonak', 'Sarikonak,Sarıkonak', 38.2430900, 41.9593300, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127104, 'Sarıkemer', 'Sarikemer', 'Sarikemer,Sarıkemer', 37.5660900, 27.3643000, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127105, 'Sarıkaya', 'Sarikaya', 'Hamam,Sarikaya,Sarıkaya', 39.4936100, 35.3769400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127106, 'Sarıgöl', 'Sarigol', 'Sarigol,Sarıgöl', 38.2395300, 28.6966300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127107, 'Sarıçam', 'Saricam', 'Saricah,Saricam,Sarıçah,Sarıçam', 37.1517200, 35.5076900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127108, 'Sarıbeyler', 'Saribeyler', 'Saribeyler,Sarıbeyler', 39.3983300, 27.5772200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127109, 'Sarayönü', 'Sarayonu', 'Sarayonu,Sarayönü', 38.2620100, 32.4045700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127110, 'Sarayköy', 'Saraykoy', 'Sarajkoj,Saraykoy,Sarayköy,Seraikeui,sa la yi ke yi,Сарайкӧй,سرای‌کوی,ضلع ساراکوۓ,薩拉伊柯伊', 37.9244800, 28.9251600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127111, 'Saraykent', 'Saraykent', 'Karamagara,Karamagra,Karamağara,Karamağra,Saraykent', 39.6936100, 35.5111100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127112, 'Saray', 'Saray', 'Kazimpasa,Kâzımpaşa,Saray', 38.6469100, 44.1611600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127113, 'Şaphane', 'Saphane', 'Abseker,Abşeker,Saphane,Şaphane', 39.0273000, 29.2221800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127114, 'Sandıklı', 'Sandikli', 'Sandikli,Sandykly,Sandıklı,sandyqly,sang de ke lei,Сандикли,Сандыклы,صاندیقلی,ضلع ساندیکی,桑德克勒', 38.4647200, 30.2694600, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127115, 'Sancak', 'Sancak', 'Hoskar,Hoşkâr,Sancak', 39.0922200, 40.3875300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127116, 'Samsat', 'Samsat', 'Samsat,Semisad,Semsat,Semîsad,sa mu sa te,samsat,Самсат,سامسات,سەمیساد,ضلع سامساٹ,萨姆萨特', 37.5819400, 38.4741700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127117, 'Şamlı', 'Samli', 'Samli,Şamlı', 39.8118400, 27.8455900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127118, 'Şambayat', 'Sambayat', 'Sambayat,Şambayat', 37.6844100, 38.0467600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127119, 'Samandağ', 'Samandag', 'Alevisik,Alevışık,As Suwaydiyah,As Suwaydīyah,Saman Daghi,Samandag,Samandagi,Samandağ,Samandağı,Seleucia,Seleucia Pieria,Seleukeia,Suwaydiyah,Suwaydīyah,Yukari Alevisik,Yukarı Alevışık,Zeugma,alswydyt,sman daghy,swydyt,Şamān Dāghī,السويدية,سويدية,صمان داغي', 36.0801200, 35.9760300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127120, 'Salihli', 'Salihli', 'Salihli', 38.4825800, 28.1477400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127121, 'Salavatlı', 'Salavatli', 'Salavatli,Salavatlı', 37.8912300, 28.1033300, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127122, 'Sakçagöz', 'Sakcagoz', 'Keferdiz,Sakcagoz,Sakcagoze,Sakcagozu,Sakçagöz,Sakçagöze,Sakçagözü', 37.1715200, 36.9163200, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127123, 'Saimbeyli', 'Saimbeyli', 'Hacin,Haçin,Rumlu,Saimbeyli', 37.9863200, 36.0905600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127124, 'Sağkaya', 'Sagkaya', 'Kirmit,Kırmıt,Sagkaya,Sağkaya', 37.1785200, 35.6884300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127125, 'Simos', 'Simos', 'Saginli,Sağınlı,Simos,Ucum,Uçum', 38.0573100, 42.5837500, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127126, 'Sabuncu', 'Sabuncu', 'Armudeli,Armuteli,Armutlu,Sabuncu,Sabuncupinar,Sabuncupınar', 39.5613100, 30.1881300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127127, 'Reyhanlı', 'Reyhanli', 'Airandji,Airanndji,Airinge,Ayranci,Aïrandji,Rayhaniyah,Rayḩānīyah,Rehaniye,Rejkhanly,Reyhaniye,Reyhanli,Reyhanlı,`Ayranj,ryhanyt,Рейханлы,ريحانية,‘Ayranj', 36.2679100, 36.5674700, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127128, 'Reis', 'Reis', 'Reis', 38.2713900, 31.5713900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127129, 'Refahiye', 'Refahiye', 'Gercanis,Refahiye', 39.8931500, 38.7660700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127130, 'Pütürge', 'Puturge', 'Imron,Imrun,Puturge,Pütürge,İmron,İmrun', 38.1992300, 38.8629600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127131, 'Pulumer', 'Pulumer', 'Plumur,Plurnur,Plümür,Pulumer,Pulumur,Pülümür', 39.4844900, 39.8953200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127132, 'Pozantı', 'Pozanti', 'Posenti,Pozanti,Pozanty,Pozantı,Pozenti,bo zan te,pwzanty,Позанты,ضلع پوزانتی,پوزانتی,波贊特', 37.4277800, 34.8716700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127133, 'Poyraz', 'Poyraz', 'Poyraz', 38.6859600, 39.0230000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127134, 'Polatlı', 'Polatli', 'Polath,Polatli,Polatly,Polatlî,Polatlı,bo la te lei,pwlatly,Полатли,Полатлы,ضلع پولاٹلی,پولاتلی,波拉特勒', 39.5771500, 32.1413200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127135, 'Razvaliny Ayinvan', 'Razvaliny Ayinvan', 'Ayinvan,Ayinvan Harap,Ayınvan,Ayınvan Harap,Pinaronu,Pınarönü,Razvaliny Ayinvan', 37.2798300, 42.3342700, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127136, 'Pınarlar', 'Pinarlar', 'Pasavenk,Paşavenk,Pinarlar,Pınarlar,Vasgirt', 38.8742400, 39.4726300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127137, 'Pınardere', 'Pinardere', 'El''fan,Elfan,El’fan,Pinardere,Pınardere', 37.4723100, 40.8340200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127138, 'Pınarbaşı', 'Pinarbasi', 'Aziziye,Pinarbasi,Pınarbaşı', 38.7228500, 36.3931400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127139, 'Pınarbaşı', 'Pinarbasi', 'Ayinser,Ayınser,Pinarbasi,Pınarbaşı', 37.2136800, 41.8868900, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127140, 'Pervari', 'Pervari', 'Hashir,Hashır,Pervari', 37.9357300, 42.5492700, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127141, 'Pertek', 'Pertek', 'Pertag,Pertage,Pertek,Pêrtag,Pêrtage,pei er tai ke,prtk,Пертек,ضلع پرتک,پرتک,پێرتاگە,佩爾泰克', 38.8657400, 39.3227300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127142, 'Akpazar', 'Akpazar', 'Akpazar,Carsancak,Peri,Çarsancak', 38.8462500, 39.6683300, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127143, 'Pazaryeri', 'Pazaryeri', 'Pazarcik,Pazarcık,Pazaryeri', 39.9939500, 29.9042400, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127144, 'Pazarören', 'Pazaroren', 'Pazaroren,Pazarviran,Pazarören', 38.6738900, 36.1594400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127145, 'Pazarlar', 'Pazarlar', 'Pazarcokyaka,Pazarlar,Pazarçokyaka', 38.9950000, 29.1258300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127146, 'Pazarköy', 'Pazarkoy', 'Pazarkoy,Pazarköy', 39.8532000, 27.4029900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127147, 'Pazarcık', 'Pazarcik', 'Pazarcik,Pazarcık,Pazardzhik,Пазарджик', 37.4868500, 37.2996100, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127148, 'Payallar', 'Payallar', '', 36.6016000, 31.8505700, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127149, 'Patnos', 'Patnos', 'Patnos', 39.2249300, 42.8569300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127150, 'Pasinler', 'Pasinler', 'Hasankale,Pasinler', 39.9797500, 41.6699700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127151, 'Pamukören', 'Pamukoren', 'Genevis,Geneviş,Gerenis,Gereniz,Pamukoren,Pamukören', 37.9231700, 28.5417500, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127152, 'Pamukkale', 'Pamukkale', 'Ecirli,Hierapolis,Hierapolis de Frigia,Hierapolis-Pamukkale,Hieropolis,Hieràpolis de Frígia,Hierápolis,Hierápolis-Pamukkale,Mien-fa-pau,Mièn-fâ-páu,Pamoukale,Pamukale,Pamukalė,Pamukkale,hieraporisu-pamukkare,mian hua bao,pa mu kkale,pamugkalle,pamuk-kale,pamukkale,pmwqlh,Παμούκαλε,Памукале,Памуккале,Փամուքքալե,פמוקלה,پاموک‌کاله,পামুক্কালে,பமுக்கலெ,ปามุกกาเล,ფამუქ-ქალე,ヒエラポリス-パムッカレ,棉花堡,파묵칼레', 37.9164400, 29.1172900, 'TR', '2015-04-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127153, 'Palu', 'Palu', 'Palu,Paluyah', 38.6913500, 39.9198400, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127154, 'Palamutlu', 'Palamutlu', 'Palamut,Palamutlu,Sas,Shoz,Soz,Sozkoy,Şaş,Şoz,Şozköy', 37.8958300, 42.2025000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127155, 'Özpınar', 'Ozpinar', 'Ozpinar,Özpınar', 38.0047800, 42.2438600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127156, 'Özonak', 'Ozonak', 'Genezin,Ozonak,Özonak', 38.8121300, 34.8409600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127157, 'Özdere', 'Ozdere', 'Kesre,OEzdere Cumhuriyet,Ozdere,Özdere,Özdere Cumhuriyet', 38.0161100, 27.1280600, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127158, 'Özbek', 'Ozbek', 'Ozbek,Tel''sikan,Telsakam,Telsakan,Telsekan,Telsekân,Telsikan,Telsikân,Tel’sikan,Özbek', 37.1770400, 41.6932200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127159, 'Özalp', 'Ozalp', 'Karakalli,Karakallı,Karkalli,Karkallı,Ozalp,Özalp', 38.6545500, 43.9886900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127160, 'Oymataş', 'Oymatas', 'Bediyan,Oymatas,Oymataş', 37.7985600, 41.0208300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127161, 'Oyalı', 'Oyali', 'Oyali,Oyalı', 37.2212600, 41.7386200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127162, 'Ovakışla', 'Ovakisla', 'Ovakisla,Ovakışla,Purhus', 38.8173300, 42.3164300, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127163, 'Ovakent', 'Ovakent', 'Abagide,Adagide,Ovakent', 38.1072200, 28.0211100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127164, 'Ovakavağı', 'Ovakavagi', 'Kavakli,Kavaklı,Ovakavagi,Ovakavağı', 37.7107900, 32.9348200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127165, 'Ovacık', 'Ovacik', 'Blur,Marasalcakmak,Maraşalçakmak,Maresalcakmak,Mareşalçakmak,Ovacik,Ovacık,Ovadzhyk,Pulur,awwajk  twnjyly,plwwr,Оваджык,Բլուր,اوواجک، تونجیلی,ضلع اوواجک,پلوور', 39.3525900, 39.2089000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127166, 'Ovacık', 'Ovacik', 'Hasanik,Ovacik,Ovacık', 37.5134300, 38.7793300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127167, 'Ovabağ', 'Ovabag', 'Asagihanik,Aşağıhanik,Kilvan,Ovabag,Ovabağ', 37.7084900, 39.9869700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127168, 'Otlukbeli', 'Otlukbeli', 'Karakulak,Otlukbeli', 39.9700000, 40.0187200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127169, 'Osmanpaşa', 'Osmanpasa', 'Osman Pasa Tekkesi,Osman Paşa Tekkesi,Osmanpasa,Osmanpaşa', 39.6247200, 34.9647200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127170, 'Osmaniye', 'Osmaniye', 'Cebelibereket,Gebelibereket,Gorad Asmanie,Kinikan,Osmanie,Osmanigie,Osmanije,Osmanijė,Osmaniye,Osmaniyə,ao si man ni ye,oseumaniye,osmanie,osumanie,Οσμανίγιε,Горад Асманіе,Османие,Османије,Османіє,אוסמניה,אסמאניע,عثمانية,عثمانیه,عثمانیہ,عثمانیے,ოსმანიე,オスマニエ,奧斯曼尼耶,오스마니예', 37.0741700, 36.2477800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127171, 'Osmancalı', 'Osmancali', 'Osmancali,Osmancalı', 38.7625000, 27.2530600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127172, 'Ortaköy', 'Ortakoy', 'Ortakoy,Ortaköy', 39.4215300, 36.2340300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127173, 'Ortaköy', 'Ortakoy', 'Ortakoy,Ortaköy', 38.7372800, 34.0386600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127174, 'Ortaköy', 'Ortakoy', 'Asagi Arus,Ashagi-Arush,Aşağı Aruş,Ortakoy,Ortaköy', 37.3274500, 43.2840300, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127175, 'Ortaköy', 'Ortakoy', 'Gulharin,Gulharrin,Gyul''kharin,Gyul’kharin,Gülharin,Gülharrin,Harrin,Harrın,Ortakej,Ortakoey,Ortakoy,Ortaköy,Ортакей', 37.2208900, 40.7847600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127176, 'Ortaklar', 'Ortaklar', 'Ortaklar,Ortaklar Nesetiye,Ortaklar Neşetiye,Resadiye,Reşadiye', 37.8878800, 27.5023400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127177, 'Ortyakent Yahşi', 'Ortyakent Yahsi', 'Musgebi,Muskebi,Müsgebi,Müskebi,Ortakent-Yahsi,Ortakent-Yahşi,Ortyakent Yahsi,Ortyakent Yahşi,Yahsikent,Yahşikent', 37.0494400, 27.3483300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127178, 'Ortaca', 'Ortaca', 'Hesterek,Heşterek,Kheshterek,Ortaca', 37.4739400, 41.5559800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127179, 'Ortaca', 'Ortaca', 'Ortaca', 36.8391500, 28.7645700, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127180, 'Ortabağ', 'Ortabag', 'Gerur,Glyan,Gurur,Gürur,Ortabag,Ortabağ', 37.3967100, 42.9101000, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127181, 'Orhaneli', 'Orhaneli', 'Adranos,Atranos,Beyce,Orhaneli,adrnws,atranws,atrnws,bkjh,ادرنوس,اطرانوس,اطرنوس,بكجه', 39.9033300, 28.9905600, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127182, 'Örenşehir', 'Orensehir', 'Orensehir,Viransehir,Viranşehir,Örenşehir', 38.9984300, 36.6492900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127183, 'Örencik', 'Orencik', 'Orencik,Virancik,Virancık,Örencik', 39.2625000, 29.5438900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127184, 'Ören', 'Oren', 'Oren,Pinar,Pınar,Ören', 37.0360900, 27.9672300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127185, 'Öncül', 'Oncul', 'Ille,Oncul,Öncül,İlle', 36.7122200, 39.0291700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127186, 'Ömerli', 'Omerli', 'Maserti,Omerli,Ömerli', 37.3990300, 40.9544200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127187, 'Ömerköy', 'Omerkoy', 'Omerkoy,Ömerköy', 39.8306300, 28.0668200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127188, 'Okçular', 'Okcular', 'Okcular,Okçular,Tiri', 37.7415200, 42.4407500, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127189, 'Oğuzeli', 'Oguzeli', 'Buyuk Kizilhisar,Büyük Kızılhisar,Oguzeli,Oğuzeli', 36.9657200, 37.5133900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127190, 'Oğuz', 'Oguz', 'Oguz,Oğuz', 39.5059000, 38.8836900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127191, 'Oğuz', 'Oguz', 'Oguz,Oğuz,Shimiz,Simiz,Şimiz', 37.8148700, 41.3742500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127192, 'Dara', 'Dara', 'Dara,Oguz,Oğuz', 37.1790200, 40.9545500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127193, 'Ödemiş', 'OEdemis', 'Eudemish,Hypaepa,OEdemis,Odemis,Ödemiş', 38.2278000, 27.9695500, 'TR', '2015-04-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127194, 'Obruk', 'Obruk', 'Oberuk,Obruk', 38.1844400, 33.1809500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127195, 'Nusaybin', 'Nusaybin', 'Antiocheia,Nasabina,Nisibin,Nisibis,Nissibine,Nusaybin,Nuseybin,Nuzajbin,Αντιόχεια,Нузайбин', 37.0702800, 41.2146500, 'TR', '2015-11-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127196, 'Nurhak', 'Nurhak', 'Nurhak', 37.9636600, 37.4404700, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127197, 'Nurettin', 'Nurettin', 'Konakkuran,Nureddin,Nurettin', 39.2810400, 42.5074600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127198, 'Nurettin', 'Nurettin', 'Nurettin', 39.2288300, 42.4183200, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127199, 'Nizip', 'Nizip', 'Nezip,Nizip,Nizipe,Низипе', 37.0097200, 37.7941700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127200, 'Niğde', 'Nigde', 'Gorad Nijdeh,Nigdah,Nigde,Nigdeh,Nigdi,Niide,Niğde,Niğdə,ni dai,nide,nigde,nyghdh,nyghdt,Νίγδη,Горад Нійдэ,Нигде,نيغدة,نگدے,نیغده,نیغدے,ნიგდე,ニーデ,尼代,니데', 37.9658300, 34.6793500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127201, 'Nevşehir', 'Nevsehir', 'Muskara,Muşkara,NAV,Nevsechir,Nevsehir,Nevshehr,Nevshekhir,Nevşehir,Nevşəhər,nebeusyehileu,nei fu xie xi er,nevshehiri,nevushehiru,nwshhr,Νεβσεχίρ,Невшехир,نو شہر,نوشهر,نیوشہر,ნევშეჰირი,ネヴシェヒル,內夫謝希爾,네브셰히르', 38.6250000, 34.7122200, 'TR', '2016-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127202, 'Nazimiye', 'Nazimiye', 'Nazimiye,Nazımiye', 39.1798600, 39.8284300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127203, 'Nazilli', 'Nazilli', 'Gorad Nazili,Nasly,Nazili,Nazilis,Nazilli,Pazarkoy,Pazarköy,na ji li,nazyly,Горад Назілі,Назили,Назилли,نازیلی,納濟利', 37.9163100, 28.3222500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127204, 'Demirci', 'Demirci', 'Demirci,Nasir,Nasır,Sergerti,Sergirti', 37.4126900, 39.7683800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127205, 'Narlıdere', 'Narlidere', 'Narlidere,Narlıdere', 38.2268000, 41.8901400, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127206, 'Narlı', 'Narli', 'Giresor,Narli,Narly,Narlı', 37.8844900, 42.9759700, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127207, 'Narlı', 'Narli', 'Narli,Narlı', 37.3914800, 37.1361400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127208, 'Narince', 'Narince', 'Merdis,Narinca,Narince', 37.8825300, 38.7592000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127209, 'Mutki', 'Mutki', 'Mutki', 38.4062400, 41.9201800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127210, 'Mut', 'Mut', 'Mut', 36.6438900, 33.4388500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127211, 'Musabeyli', 'Musabeyli', 'Musabeyli', 39.8330600, 34.6230600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127212, 'Musabeyli', 'Musabeyli', 'Murathuyugu,Murathüyüğü,Musabeyli', 36.8863900, 36.9186100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127213, 'Muş', 'Mus', 'MSR,Mus,Mush,Muş,Mûş,mu shen,mushi,mushu,musyu,mwsh,mwwsh,Муш,Մուշ,موش,مووش,მუში,ムシュ,穆什,무슈', 38.7316300, 41.4848200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127214, 'Mürşitpınar', 'Mursitpinar', 'Mursitpinar,Myurshitpynar,Mürşitpınar', 36.9030000, 38.3474600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127215, 'Mursal', 'Mursal', 'Mursal,Mursel,Mürsel,Vazildan,Vazıldan', 39.1677800, 37.9569400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127216, 'Muratlı', 'Muratli', 'Hirbetcay,Hırbetçay,Muratli,Muratlı', 36.9616700, 40.1005600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127217, 'Murat', 'Murat', 'Murat,Ziro', 39.6728100, 43.2395200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127218, 'Muradiye', 'Muradiye', 'Bagkiri,Bargiri,Muradiye', 38.9856800, 43.7531000, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127219, 'Muradiye', 'Muradiye', 'Muradiye', 38.6602500, 27.3383600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127220, 'Muncusun', 'Muncusun', 'Gunesli,Güneşli,Muncusun', 38.9025300, 35.6274300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127221, 'Karaova', 'Karaova', 'Karaova,Mumcular,Muncular', 37.1069900, 27.6657800, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127222, 'Muğla', 'Mugla', 'Mentese,Menteshe,Mobolla,Mougla,Mughla,Mughlah,Mugla,Muula,Muğla,mghla,mu la,mughla,mulla,mwghla,mwghlh,Μούγλα,Мугла,مغلا,موغلا,موغله,მუღლა,穆拉,물라', 37.2180700, 28.3665000, 'TR', '2012-01-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127223, 'Mucur', 'Mucur', 'Mucur', 39.0614700, 34.3828600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127224, 'Mordoğan', 'Mordogan', 'Iskele,Kucuk Mordogan,Küçük Mordoğan,Mordogan,Mordogan Iskelesi,Mordoğan,Mordoğan İskelesi,Mordugan,Morduğan,Murdagan,Murdağan,Murdogan,Murdoğan,Murdugan,Mürduğan', 38.5164800, 26.6244700, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127225, 'Elmalıdere', 'Elmalidere', 'Elmalidere,Elmalıdere,Mollaosman', 39.6372100, 42.3199600, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127226, 'Mollakendi', 'Mollakendi', 'Mollakendi', 38.5773500, 39.3329200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127227, 'Minare', 'Minare', 'Minare', 36.9308300, 39.0044400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127228, 'Balveren', 'Balveren', 'Balveren,Milli', 37.4835700, 42.5483400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127229, 'Milas', 'Milas', 'Milas,Mylasa,mi la si,mylas,Милас,ضلع ملاس,میلاس,米拉斯', 37.3163900, 27.7838900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127230, 'Mihalıçcık', 'Mihaliccik', 'Kuyucak,Mihaliccik,Mihalıçcık,Mihalıççık', 39.8659400, 31.4957200, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127231, 'Midyat', 'Midyat', 'Estil,Medeat,Mid''jat,Midyad,Midyat,Mityat,mdyad,mdyat,mdyd,mi di ya te,mydyat,Мидьят,Мідьят,ضلع مدیات,مديات,مدیاد,میدیات,ܡܕܝܕ,米迪亞特', 37.4190800, 41.3390900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127232, 'Mezraa', 'Mezraa', 'Kirmizikopru,Kırmızıköprü,Mezraa', 39.3859000, 39.8243900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127233, 'Mezraa', 'Mezraa', 'Mezra,Mezraa,Mezraa Koyu,Mezraa Köyü,Mezrea', 37.6625700, 43.1888500, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127234, 'Mezitli', 'Mezitli', 'Mezetli,Mezitli,Soli,Мезитли,ضلع مزیتلی', 36.7454100, 34.5225600, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127235, 'Meydankapı', 'Meydankapi', 'Hizan,Khizan,Meydankapi,Meydankapı', 36.7827800, 39.1583300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127236, 'Meydan', 'Meydan', 'Meydan', 38.3558500, 41.7694100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127237, 'Söylemez', 'Soylemez', 'Mescitli,Soylemez,Söylemez', 39.7604500, 41.8015300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127238, 'Mercin', 'Mercin', 'Icel,Mersin,Mersina,Mersine,Merson,Mersyna,Myrte,Mêrsîn,Zephyrium,İçel,Μερσίνη,Мерсин', 36.7952600, 34.6179200, 'TR', '2012-12-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127239, 'Mermer', 'Mermer', 'Mermer', 38.1182800, 40.4487400, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127240, 'Mercimekkale', 'Mercimekkale', 'Mercimekkale', 38.9294500, 41.5032500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127241, 'Meram', 'Meram', 'Meram', 37.8298500, 32.4677700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127242, 'Menemen', 'Menemen', 'Distretto di Menemen,Menemen,Menemeni,Temnos,Менемен,مینےمن', 38.6075400, 27.0693800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127243, 'Mazıdağı', 'Mazidagi', 'Mahallimentina,Mazidagi,Mazıdağı,Samarli,Samrah,Şamarlı,Şamrah', 37.4780100, 40.4815200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127244, 'Mazgirt', 'Mazgirt', 'Mazgirt,Mazkirt', 39.0178300, 39.6006400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127245, 'Marmaris', 'Marmaris', 'Mararis,Marmarice,Marmaris,Physcus,QRQ,ma er ma li si gang,maleumaliseu,marmaris,marmarys,marumarisu,mrmarys,mrmrys,Мармарис,מרמריס,ضلع مرمارس,مارماریس,مرماريس,マルマリス,马尔马里斯港,마르마리스', 36.8550000, 28.2741700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127246, 'Mardin', 'Mardin', 'MQM,Marde,Mardin,Marntin,Merdin,Mêrdin,Mêrdîn,ma er ding,maleudin,mardini,mardn,mardyn,marudin,mrdyn,Μαρντίν,Мардин,Мардін,Մարդին,ماردن,ماردين,ماردین,مێردین,ܡܪܕܝܢ,მარდინი,マルディン,馬爾丁,마르딘', 37.3130900, 40.7435700, 'TR', '2012-12-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127247, 'Mansurlu', 'Mansurlu', 'Mansurlu', 37.8485300, 35.6543600, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127248, 'Manisa', 'Manisa', 'Magnesia,Magnesia ad Sipylum,Magnesia am Sipylos,Magnisiyah,Magnēsıa,Mahnisa,Manisa,Manissa,Sarouhan,Saruhan,Маниса', 38.6120200, 27.4264700, 'TR', '2015-08-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127249, 'Manavgat', 'Manavgat', 'Manavgat,Манавгат', 36.7866700, 31.4430600, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127250, 'Mamak', 'Mamak', 'Mamak', 39.9404400, 32.9101200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127251, 'Malazgirt', 'Malazgirt', 'Kale,Malazgirt,Malazkirt,Malâzkirt', 39.1465000, 42.5353600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127252, 'Malatya', 'Malatya', 'Gorad Malatja,MLX,Malat''ja,Malateia,Malatia,Malatija,Malatiyah,Malatja,Malatya,Meleti,Meletiye,Meletî,Melitene,ma la di ya,malatia,mallatia,maratiya,mltyh,mltyt,Μαλάτεια,Горад Малатя,Малатия,Малатија,Малатья,Մալաթիա,מלטיה,مالاطیہ,ملطية,ملطیه,مەلەدی,მალათია,マラティヤ,馬拉蒂亞,말라티아', 38.3501800, 38.3166700, 'TR', '2016-02-13', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127253, 'Mahmutlar', 'Mahmutlar', 'Mahmutlar', 36.4946300, 32.0908500, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127254, 'Mahmudiye', 'Mahmudiye', 'Mahmudiye', 39.4977800, 30.9872200, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127255, 'Mağaralı', 'Magarali', 'Cukurgirlevik,Girlavik,Gırlavik,Magarali,Magaraly,Mağaralı,Çukurgirlevik', 36.9688900, 38.0744400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127256, 'Kırobası', 'Kirobasi', 'Kirobasi,Kirobasi-Mara,Kırobası,Kırobası-Mara,Magara,Magra,Mara,Mağara,Mağra', 36.7224000, 33.8671100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127257, 'Maden', 'Maden', 'Arghana Maden,Erganimadeni,Erganımadenı,Maden', 38.3866900, 39.6640800, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127258, 'Lice', 'Lice', 'Lice,Lijje', 38.4582100, 40.6388800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127259, 'Levent', 'Levent', 'Levent', 38.4370400, 37.8542500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127260, 'Kuzucubelen', 'Kuzucubelen', 'Kuzucubelen', 36.8399600, 34.4376500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127261, 'Kuyulusebil', 'Kuyulusebil', '', 38.6538900, 32.5297200, 'TR', '2011-07-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127262, 'Kuyucak', 'Kuyucak', 'Kayancuk,Kuyucak', 37.9133000, 28.4591700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127263, 'Kuyucak', 'Kuyucak', 'Kuyucak', 37.8630600, 38.3436500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127264, 'Kutlubey', 'Kutlubey', 'Kutlubey,Tinat', 37.3071900, 41.1772000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127265, 'Kütahya', 'Kutahya', 'Cotiaeum,Cotyaeum,Gorad Kjutakhja,KZR,Kioutacheia,Kiutahija,Kjutakh''ja,Kjutakhija,Kjutakhja,Kuetahiya,Kuetahj,Kuetahya,Kutahiyah,Kutahya,Kutaia,Kutakh''ja,Kutakhja,Kutaya,Kütahiya,Kütahj,Kütahya,kutahia,kwitahia,kwtahyh,kwtahyt,kwtaہya,kyutahiya,qu ta xi ya,Κιουτάχεια,Горад Кютахя,Кутахја,Кютахия,Кютахья,Кютахя,Кӱтахья,Кӳтахья,Քյոթահիա,كوتاهية,کتہیا,کوتاهیه,کوتاھیا,کوتاہیا,ქუთაჰია,キュタヒヤ,屈塔希亞,퀴타히아', 39.4241700, 29.9833300, 'TR', '2013-01-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127266, 'Kuşsarayı', 'Kussarayi', 'Bekirhuseyin,Bekirhüseyin,Izolu,Kussaray,Kussarayi,Kuşsaray,Kuşsarayı,İzolu', 38.4512100, 38.6791200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127267, 'Kuşkayası', 'Kuskayasi', 'Kuskaya Koyu,Kuskayasi,Kuşkaya Köyü,Kuşkayası', 39.0607600, 37.0792900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127268, 'Kuşadası', 'Kusadasi', 'Efes,Kusadasi,Kush Adasi,Kush Adası,Kushadasi,Kushadassi,Kushadasy,Kuushadasy,Kuşadası,Marathesium,Nea Ephesus,Scalanuova,Skala Nuova,Skalanova,ku sha da se,kushadas",kushadasi,kushadasu,kusyadaseu,Кушадаси,Кушадасъ,Кушадасы,Къушадасы,کوش‌آداسی,クシャダス,庫沙達瑟,쿠샤다스', 37.8556200, 27.2566000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127269, 'Kuruçay', 'Kurucay', 'Kurucay,Kuruçay', 39.6402400, 38.4742200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127270, 'Kurthasanlı', 'Kurthasanli', 'Kurthasanli,Kurthasanlı', 38.3261100, 32.1752800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127271, 'Kurtalan', 'Kurtalan', 'Kurtalan,Misirdic,Misric,Mısrıç', 37.9253300, 41.6849300, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127272, 'Kurşunlu', 'Kursunlu', 'Kursunlu,Kurşunlu', 38.6532800, 37.8508100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127273, 'Sarıkavak', 'Sarikavak', 'Kozak,Kurkcu,Kürkçü,Sarikavak,Sarıkavak', 36.5812700, 33.6429900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127274, 'Beykonak', 'Beykonak', '', 36.3257300, 30.3030200, 'TR', '2011-12-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127275, 'Kumluca', 'Kumluca', 'Kumluca', 36.3702800, 30.2869400, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127276, 'Kumlu', 'Kumlu', 'Dekok,Dikuk,Dikük,Dukuk,Dükük,Kumlu', 37.1722200, 40.7353600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127277, 'Kumlu', 'Kumlu', 'Iskan,Kumlu', 36.3635300, 36.4550200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127278, 'Kumköy', 'Kumkoey', '', 36.8828600, 30.9517800, 'TR', '2013-11-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127279, 'Kumdanlı', 'Kumdanli', 'Hoyran,Kumdanli,Kumdanlı', 38.3239000, 30.9764000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127280, 'Kumçatı', 'Kumcati', 'Dergul,Dergyul'',Dergyul’,Dergül,Kumcati,Kumçatı', 37.4659400, 42.2879100, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127281, 'Kuluncak', 'Kuluncak', 'Kuluncak', 38.8765600, 37.6627900, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127282, 'Kulu', 'Kulu', 'Kulu', 39.0951300, 33.0798900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127283, 'Kulp', 'Kulp', 'Kulp', 38.4975400, 41.0066800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127284, 'Kula', 'Kula', 'Kovla,Kul,Kula,Opsicium,Кул', 38.5472600, 28.6497600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127285, 'Kotum', 'Kotum', 'Kotom,Kotum,Kucuksu,Küçüksu', 38.4389900, 42.3190500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127286, 'Küçükkuyu', 'Kucukkuyu', 'Kucukkuyu,Küçükkuyu', 39.5488900, 26.6052800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127287, 'Denizgiren', 'Denizgiren', 'Denizgiren,Kucuk Bahce,Kucuk Bahcekoyu,Kucukbahce,Küçük Bahçe,Küçük Bahçeköyü,Küçükbahçe', 38.5573400, 26.3930500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127288, 'Kozluk', 'Kozluk', 'Kozluk', 38.1911800, 41.4777500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127289, 'Kozan', 'Kozan', 'Flaviopolis,Kozan,Sis', 37.4551700, 35.8157300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127290, 'Kozaklı', 'Kozakli', 'Hamamorta,Hamamortakoy,Hamamortaköy,Kozakli,Kozaklı', 39.2213900, 34.8505600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127291, 'Kozaklı', 'Kozakli', '', 39.2164300, 34.8490900, 'TR', '2006-01-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127292, 'Kovancılar', 'Kovancilar', 'Kovancilar,Kovancılar', 38.7188200, 39.8626800, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127293, 'Kösreli', 'Kosreli', 'Kosreli,Kösreli', 37.1625000, 35.9783400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127294, 'Köşk', 'Kosk', 'Kosk,Köşk', 37.8533300, 28.0516700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127295, 'Köseli', 'Koseli', 'Keseli,Koseli,Këseli,Köseli', 37.8387900, 40.6081100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127296, 'Kösefakılı', 'Kosefakili', 'Kosefakili,Kösefakılı', 39.5938600, 34.1362500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127297, 'Korucu', 'Korucu', 'Korucu', 39.4702800, 27.3652800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127298, 'Korkuteli', 'Korkuteli', 'Istanos,Korkudeli,Korkuteli,Kuorkuuteli,ke er ku tai li,kwkwtyly,qwrkhw tyly,qwrqwdaly,İstanos,Коркутели,Къоркъутели,قورخو تئلی,قورقودالی,کوکوتیلی,科爾庫泰利', 37.0649800, 30.1956500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127299, 'Korkut', 'Korkut', 'Korkut', 38.7339000, 41.7839600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127300, 'Köprüören', 'Kopruoren', 'Kopruoren,Kopruveran,Köprüveran,Köprüören', 39.5083200, 29.7623300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127301, 'Köprülü', 'Koprulu', 'Koprulu,Köprülü', 36.7323000, 32.1849700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127302, 'Köprüköy', 'Koprukoy', 'Cobandede,Koprukoy,Köprüköy,Çobandede', 39.9660000, 41.8684400, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127303, 'Köprübaşı', 'Koprubasi', 'Koprubasi,Köprübaşı', 38.7497200, 28.4047200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127304, 'Konyaaltı', 'Konyaalti', 'Konyaalti,Konyaaltı', 36.8664400, 30.6303100, 'TR', '2015-06-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127305, 'Konya', 'Konya', 'Conia,Gorad Kon''ja,Iconio,Iconium,Ikonio,Ikoniow,KYA,Ko''niya,Kon''ja,Koni,Konia,Konieh,Konija,Konja,Konjao,Konya,Koʻniya,Kuniyah,Kuon''ja,Qonia,Qonya,Qonye,ke ni ya,kean''ya,kon''ya,konia,qwnyh,qwnyt,Ικόνιο,Горад Конья,Кония,Конија,Конья,Къонья,Կոնիա,קוניה,قونية,قونیه,قونیہ,कोन्या,കോന്യ,კონია,コンヤ,科尼亞,코니아', 37.8713500, 32.4846400, 'TR', '2012-09-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127306, 'Konalga', 'Konalga', 'Konalga,Martanis', 37.8603500, 43.0967800, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127307, 'Konakpınar', 'Konakpinar', 'Konakpinar,Konakpınar', 39.4338900, 27.8362300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127308, 'Konakpınar', 'Konakpinar', 'Karadoruk,Konakpinar,Konakpınar', 38.9058300, 37.2969400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127309, 'Konaklı', 'Konakli', 'Konakli,Konaklı', 38.1127800, 27.9961100, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127310, 'Göcek', 'Goecek', 'Gocek,Gochek,Göcek,Kocek,Kucuk,Köçek,Küçük,Гочек', 36.7534500, 28.9457100, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127311, 'Kocatepe', 'Kocatepe', 'Desi,Deşi,Kocatepe,Meskinan,Meşkinan', 37.2292200, 40.1610400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127312, 'Koçarlı', 'Kocarli', 'Kocarli,Koçarlı', 37.7611300, 27.7058300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127313, 'Kocapınar', 'Kocapinar', 'Agi,Ağı,Kocapinar,Kocapınar', 39.0955300, 43.1961600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127314, 'Koçali', 'Kocali', 'Kocali,Koçali', 37.9230600, 38.2578800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127315, 'Kocaköy', 'Kocakoy', 'Kocakoy,Kocaköy', 38.2888900, 40.4978600, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127316, 'Kocakoç', 'Kocakoc', 'Kocakoc,Kocakoç', 39.1166400, 39.6593100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127317, 'Kocahasanlı', 'Kocahasanli', 'Kocahasanli,Kocahasanlı', 36.5841700, 34.2735900, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127318, 'Kocaaliler', 'Kocaaliler', 'Kocaaliler', 37.3169400, 30.7400000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127319, 'Kızılyaka', 'Kizilyaka', 'Kizilyaka,Kızılyaka', 36.9830100, 29.5284700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127320, 'Kızıltepe', 'Kiziltepe', 'Kiziltepe,Kochisar,Kochkhisar,Koçhisar,Kyzyltepe,Kızıltepe,Кызылтепе', 37.1883600, 40.5772300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127321, 'Kızılsu', 'Kizilsu', 'Kizilsu,Kızılsu,Sehres,Shekhresh,Sihras,Şehreş,Şıhraş', 37.4540200, 42.1963900, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127322, 'Kızılören', 'Kiziloren', 'Kiziloren,Kizilviran,Kızılviran,Kızılören', 38.2580600, 30.1516700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127323, 'Kızılören', 'Kiziloren', 'Kiziloren,Kizilviran,Kızılviran,Kızılören', 37.8684700, 32.1161800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127324, 'Kızılkaya', 'Kizilkaya', 'Kizilkaya,Kızılkaya,Pazaravdan', 37.3036100, 30.4441700, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127325, 'Serinhisar', 'Serinhisar', 'Kizilhisar,Kızılhisar,Serinhisar', 37.5810500, 29.2663900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127326, 'Kızılcasöğüt', 'Kizilcasogut', 'Kizilca,Kizilcasogut,Kızılca,Kızılcasöğüt', 38.6511100, 29.6661100, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127327, 'Kızılcadağ', 'Kizilcadag', 'Buyuk Piyadin,Büyük Piyadin,Kizilcadag,Kızılcadağ,Piyadin', 37.0172200, 29.9630600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127328, 'Kızılcabölük', 'Kizilcaboluk', 'Kizilcaboluk,Kızılcabölük', 37.6119100, 29.0183800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127329, 'Kızılağaç', 'Kizilagac', 'Kizilagac,Kızılağaç', 38.7801900, 41.3138500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127330, 'Kışlak', 'Kislak', 'Kislak,Kışlak', 35.9675000, 36.1574900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127331, 'Kırşehir', 'Kirsehir', 'Gorad Kyrshehkhir,Justinianopolis,Kirsechir,Kirsehir,Kirshahr,Kirshehr,Kirshekhir,Kurshekhir,Kyrshekhir,Kırşehir,Kırşəhər,Mocissus,Mokissus,Qirseher,Qırşeher,ke er xie xi er,kileusyehileu,kirasehara,kirshehiri,kurushehiru,qr shhr,qrshhr,Κιρσεχίρ,Горад Кыршэхір,Киршехир,Киршехір,Кършехир,Кыршехир,قر شهر,قر شہر,قرشهر,کرسیہر,ਕਿਰਸੇਹਰ,ქირშეჰირი,クルシェヒル,克爾謝希爾,키르셰히르', 39.1458300, 34.1638900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127332, 'Kırkgeçit', 'Kirkgecit', 'Kasrik,Kirkgecit,Kırkgeçit', 38.1355800, 43.4938700, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127333, 'Kırkağaç', 'Kirkagac', 'Kirkagac,Kırkağaç,Nacrasa', 39.1063800, 27.6692500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127334, 'Kırka', 'Kirka', 'Kirka,Kırka', 39.2794400, 30.5263900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127335, 'Kırıkkale', 'Kirikkale', 'Gorad Kyrykale,Kirikale,Kirikalė,Kirikkale,Kurukkale,Kyrykkale,Kırıkkale,Qirixqele,Qirqqalʼa,Qırıxqele,ke lei ke ka lai,kilikalle,kurukkare,kyrkaly,Κιρίκαλε,Горад Кырыкале,Кирикале,Кириккале,Къръккале,Кырыккале,قیریق قلعہ,قیریق‌قلعه,كيركالي,کیرک کلے,ქირიქკალე,クルッカレ,克勒克卡萊,키리칼레', 39.8452800, 33.5063900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127336, 'Kırıkhan', 'Kirikhan', 'Kirikhan,Kırıkhan', 36.4993900, 36.3575500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127337, 'Kireç', 'Kirec', 'Kirec,Kireç', 39.5551700, 28.3650600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127338, 'Kiraz', 'Kiraz', 'Kelasi,Keles,Kelez,Kiraz', 38.2305600, 28.2044400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127339, 'Kınık', 'Kinik', 'Kinik,Kınık', 39.0872200, 27.3833300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127340, 'Kilis', 'Kilis', 'Ciliza,Kilis,Kilisas,Kilita,Kilîs,Kılis,ji li si,kilisi,killiseu,kirisu,kls,kyls,kylys,Κιλίς,Килис,Кіліс,Քիլիս,كلس,کیلس,کیلیس,ქილისი,キリス,基利斯,킬리스', 36.7161100, 37.1150000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127341, 'Kılbasan', 'Kilbasan', 'Kilbasan,Kılbasan', 37.3248800, 33.1863400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127342, 'Kılavuz', 'Kilavuz', 'Halilan,Khalilan,Kilavuz,Kılavuz', 37.4796000, 41.7837400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127343, 'Kasaba', 'Kasaba', 'Kasaba,Kigi,Kiği,Kiğı', 39.3136100, 40.3502800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127344, 'Keskin', 'Keskin', 'Denek,Denekmadeni,Keskin,Maden,Кескин', 39.6730600, 33.6136100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127345, 'Kepsut', 'Kepsut', 'Kepsit,Kepsut', 39.6888900, 28.1522200, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127346, 'Kemerhisar', 'Kemerhisar', 'Kemerhisar', 37.8238800, 34.5714500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127347, 'Kemer', 'Kemer', 'Bebekler,Bobekler,Böbekler,Kemer,Sertac,Sertaç,Кемер', 37.3522200, 30.0630600, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127348, 'Kemer', 'Kemer', 'Kemer', 36.6481000, 29.3591000, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127349, 'Kemer', 'Kemer', 'Eskikoy,Eskiköy,Kemer,Кемер', 36.5977800, 30.5605600, 'TR', '2011-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127350, 'Kemalpaşa', 'Kemalpasa', 'Karabel,Kemal''pasha,Kemalpasa,Kemalpaşa,Nif,Nymphaeum,Кемальпаша', 38.4262100, 27.4173100, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127351, 'Kemaliye', 'Kemaliye', 'Egin,Kemaliye', 39.2628800, 38.4967400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127352, 'Kemah', 'Kemah', 'Camacha Theodosiopolis,Gamakh,Kemah,Kemakh,kmakh,کماخ', 39.5960600, 39.0232900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127353, 'Keles', 'Keles', 'Keles', 39.9136100, 29.2294400, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127354, 'Kelekçi', 'Kelekci', 'Kelekci,Kelekçi,Kelkelci', 37.2407300, 29.3042500, 'TR', '2014-02-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127355, 'Keçiborlu', 'Keciborlu', 'Keciborlu,Keçiborlu', 37.9425000, 30.3022200, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127356, 'Keban', 'Keban', 'Gumusmadeni,Gümüşmadeni,Keban', 38.7938000, 38.7351700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127357, 'Kazımkarabekir', 'Kazimkarabekir', 'Gaferiyat,Gaferîyat,Kazimkarabekir,Kazımkarabekir', 37.2302800, 32.9588900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127358, 'Kazanlı', 'Kazanli', 'Karghauli Kuyu Kazanli,Kazalu,Kazanli,Kazanli Koyu,Kazanlı,Kazanlı Koyu', 36.8156500, 34.7576100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127359, 'Kazancı', 'Kazanci', 'Hacigeyigi,Hacıgeyigi,Kazanci,Kazancı,Kurkhaci,Kurtaci,Kurthaci,Kyurtkhadzhi,Kürkhacı,Kürtacı,Kürthacı', 37.7710600, 40.6000000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127360, 'Kazancı', 'Kazanci', 'Kazanci,Kazancı', 36.5018800, 32.8612800, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127361, 'Kayseri', 'Kayseri', 'ASR,Caesarea,Caesarea in Cappadocia,Casarea,Cearee,Cesarea,Cesarea de Capadocia,Cesarea in Cappadocia,Cesaree,Céarée,Césarée,Eusebeia,Gorad Kajsery,Kaisareia,Kaisaria,Kaisarie,Kaisarije,Kaiseri,Kaiseris,Kaizarie,Kajseri,Kayseri,Kaīzarie,Khuajseri,Mazaca,Mazakʻ,Qaisariye,Qayseri,kai sai li,kaiseli,kaiseri,ki se ri,qysry,qysryh,qysryt,qyysry,Καισάρεια,Горад Кайсеры,Кaйсери,Кайсери,Кайсері,Кајсери,Хъайсери,Մաժաք,קייסרי,قيصرية,قیصری,قیصریه,قەیسەری,کیسری شہر,ไกเซรี,კაისერი,カイセリ,開塞利,카이세리', 38.7322200, 35.4852800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127362, 'Kaypak', 'Kaypak', 'Kaypak,Serdar', 37.1148700, 36.4651100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127363, 'Kaynar', 'Kaynar', 'Kaynar', 38.8991700, 36.4541700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127364, 'Kaynakkaya', 'Kaynakkaya', 'Kaynakkaya', 37.3396800, 40.9327400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127365, 'Kaymaz', 'Kaymaz', 'Kaymaz', 39.5166700, 31.1797200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127366, 'Kaymakçı', 'Kaymakci', 'Kaymakci,Kaymakçı', 38.1677800, 28.1152800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127367, 'Kayapınar', 'Kayapinar', 'Fayas,Kayapinar,Kayapınar', 37.9373300, 40.1775600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127368, 'Kayapınar', 'Kayapinar', 'Ayinkaf,Ayinkar,Ayinkef,Ayinkâf,Aynnkyaf,Ayınkâr,Habezbeni,Kayapinar,Kayapınar,Khabezbeni', 37.5576200, 41.1623100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127369, 'Kayapa', 'Kayapa', 'Kayapa', 39.4927100, 27.4454700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127370, 'Kayalıpınar', 'Kayalipinar', 'Kayalipinar,Kayalıpınar,Mikri', 37.3298300, 41.2276000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127371, 'Salmanlı', 'Salmanli', 'Kayadibi,Salmanli,Salmanlı', 39.9022200, 34.2547200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127372, 'Kayadibi', 'Kayadibi', 'Kayadibi', 39.4799300, 36.7124500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127373, 'Kayabağlar', 'Kayabaglar', 'Kayabaglar,Kayabağlar,Zokayit,Zokayıt', 37.9859900, 41.6675600, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127374, 'Kavaklıdere', 'Kavaklidere', 'Kavakdere,Kavaklidere,Kavaklıdere', 37.4446300, 28.3627600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127375, 'Kavakbaşı', 'Kavakbasi', 'Kavakbasi,Kavakbaşı', 38.4833700, 41.8196700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127376, 'Kavak', 'Kavak', 'Kavak', 39.2920500, 37.4812700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127377, 'Hazar', 'Hazar', 'Hazar,Kavak,Kavakkoy,Kavakköy', 38.3878000, 39.4236500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127378, 'Kavacık', 'Kavacik', 'Kavacik,Kavacık', 39.6755100, 28.4944600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127379, 'Kasımlar', 'Kasimlar', 'Kasimlar,Kasimlar Koyu,Kasımlar,Kasımlar Köyü', 37.5287500, 31.1927000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127380, 'Kaş', 'Kas', 'Andifli,Andiphilo,Antiphellus,Kas,Kash,Kaş,Kuash,ka shen,Каш,Къаш,卡什', 36.2017600, 29.6376600, 'TR', '2015-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127381, 'Karşıyaka', 'Karsiyaka', 'Cordaleo,Karshyjaka,Karsiyaka,Karşıyaka,Kordelio,Κορδελιό,Каршыяка', 38.4573300, 27.1106200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127382, 'Aladağ', 'Aladag', 'Aladag,Aladagu,Aladağ,Karsanti,Karsantı,Korsanti,Korsantı,Mansurlu,aladag  adna,aladagh,aladagh  adana,Аладаг,Аладагъ,ألاداغ,الاداغ، آدانا,الاداگ، ادنا,ضلع الاداگ', 37.5485000, 35.3960300, 'TR', '2014-09-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127383, 'Karpuzlu', 'Karpuzlu', 'Demircidere,Karpuzlu', 37.5586100, 27.8352800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127384, 'Kızılağaç', 'Kizilagac', 'Kizilagac,Kyzylagach,Kızılağaç,Кызылагач', 36.7305500, 31.5351700, 'TR', '2014-06-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127385, 'Karlıova', 'Karliova', 'Kanires,Karliova,Karlıova,Kânireş', 39.2904400, 41.0059400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127386, 'Karıncalı', 'Karincali', 'Karincali,Karıncalı', 39.9711800, 28.8589400, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127387, 'Kargı', 'Kargi', 'Kargifoca,Kargıfoca,Pirnaz,Pırnaz', 36.7013200, 29.0755700, 'TR', '2010-03-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127388, 'Karkamış', 'Karkamis', 'Barak,Carablus,Carabulus,Karakamis,Karakamış,Kargamis,Kargamış,Karkamis,Karkamysh,Karkamış', 36.8345200, 37.9983000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127389, 'Karayün', 'Karayun', 'Karayun,Karayün,Mamuga,Mamuğa', 39.6819400, 37.3052800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127390, 'Karayazı', 'Karayazi', 'Bayrakdar,Bayraktar,Karayazi,Karayazı', 39.6960400, 42.1427700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127391, 'Karatoprak', 'Karatoprak', 'Karatoprak,Turgutreis', 37.0138500, 27.2589300, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127392, 'Karataş', 'Karatas', 'Karatas,Karataş,Kucukkaratas,Kuecuekkaratas,Küçükkarataş', 36.5820400, 35.3701400, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127393, 'Karapınar', 'Karapinar', 'Karapinar,Karapınar,Sultaniye', 37.7159600, 33.5506400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127394, 'Karaoğlanlı', 'Karaoglanli', 'Karaoglanli,Karaoğlanlı', 38.5291700, 27.5666700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127395, 'Karaoğlan', 'Karaoglan', 'Kakbil,Karaoglan,Karaoğlan', 39.2264400, 39.2085300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127396, 'Karamanlı', 'Karamanli', 'Karamanli,Karamanlı', 37.3730100, 29.8230800, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127397, 'Karaman', 'Karaman', 'Ak Yokus,Ak Yokuş,Darende,Gorad Karaman,Karaman,Karamana,Karamanas,Kuaraman,Laranda,Qereman,ka la man,kalaman,karaman,karamana,karamani,qraman,Καραμάν,Горад Караман,Караман,Къараман,קאראמאן,قرامان,كارامان,کارامان,ਕਾਰਮਾਨ,ქარამანი,カラマン,卡拉曼,카라만', 37.1811100, 33.2150000, 'TR', '2012-08-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127398, 'Karalar', 'Karalar', 'Araban,Karalar', 37.3007300, 41.6758200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127399, 'Karakoyunlu', 'Karakoyunlu', 'Karakoyun,Karakoyunlu', 39.8703600, 43.6301400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127400, 'Karaköy', 'Karakoy', 'Karakoy,Karaköy', 39.0910100, 41.6830100, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127401, 'Ağrı', 'Agri', 'AJI,Aari,Aarı,Agiri,Agr",Agri,Agry,Agury,Agıri,Ahras,Ağrı,Karakilise,Karakose,Karaköse,Provinsi Agri,Provinsi Ağrı,Qerekose,a lei,aghri,aghry,ali,ari,aru,Агри,Агръ,Агры,Агъры,Աղրի,آغری,أغري,قەرەکۆسە,আরি,აღრი,アール,阿勒,아리', 39.7194400, 43.0513900, 'TR', '2017-01-25', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127402, 'Karaköprü', 'Karakopru', 'Karacoban,Karakopru,Karaköprü,Karaçoban', 39.3151200, 41.9645800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127403, 'Karaköprü', 'Karakopru', 'Karakepryukey,Karakopru,Karakopru Koyu,Karakëpryukëy,Karaköprü,Karaköprü Köyü', 37.2036100, 38.7994400, 'TR', '2016-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127404, 'Karakoçan', 'Karakocan', 'Karakocan,Karakodzhana,Karakoçan,Tepe,Tepekoy,Tepeköy,Каракоджана', 38.9517800, 40.0270600, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127405, 'Karakeçili', 'Karakecili', 'Karakecili,Karakeçili', 39.5941700, 33.3777800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127406, 'Karakeçi', 'Karakeci', 'Karakeci,Karakeçi,Mizar', 37.4523400, 39.4428500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127407, 'Karaisalı', 'Karaisali', 'Ceceli,Karaisali,Karaisalı,Çeceli,قره عیسالو', 37.2566700, 35.0588900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127408, 'Karahasanlı', 'Karahasanli', 'Karahasanli,Karahasanlı,Sadikali,Sadıkali', 39.2969300, 34.7215900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127409, 'Karahallı', 'Karahalli', 'Karaballi,Karaballı,Karahal,Karahalla,Karahalli,Karahallı', 38.3208300, 29.5302800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127410, 'Karadirek', 'Karadirek', 'Karadirek,Kilandiras,Kılandıras', 38.5683400, 30.1841700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127411, 'Karaçoban', 'Karacoban', 'Karacoban,Karaçoban', 39.3436400, 42.0991800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127412, 'Karaçay', 'Karacay', 'Karacay,Karaçay', 36.1355100, 36.0774300, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127413, 'Karacaören', 'Karacaoren', 'Karacaoren,Karacaviran,Karacaören', 39.7306200, 38.1152700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127414, 'Karacasu', 'Karacasu', 'Karacasu', 37.7281600, 28.6056900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127415, 'Karacadağ', 'Karacadag', 'Karacadag,Karacadağ,Kaynak', 37.7289400, 39.6354700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127416, 'Karaburun', 'Karaburun', 'Ahirli,Ahırlı,Karaburun', 38.6364000, 26.5109400, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127417, 'Karaağıl', 'Karaagil', 'Karaagil,Karaağıl', 39.1360900, 42.0845900, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127418, 'Kanlıavşar', 'Kanliavsar', 'Kanliavsar,Kanlıavşar', 37.2164600, 38.3093600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127419, 'Kangal', 'Kangal', 'Kangal', 39.2335400, 37.3911100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127420, 'Kandilli', 'Kandilli', 'Kandilli,Karabiyikhanlari,Karabıyıkhanları', 39.9058700, 40.8366200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127421, 'Kaman', 'Kaman', 'Kaman,Kaman i Kirsehir,Kaman i Kırşehir,Keman,ka man,kaman,Каман,کامان,کامان، قر شہر,卡曼', 39.3575000, 33.7238900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127422, 'Kalkım', 'Kalkim', 'Kalkim,Kalkım,Naipli', 39.8116700, 27.2150000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127423, 'Kalkan', 'Kalkan', 'Kalamaki,Kalkan,Калкан', 36.2651000, 29.4136900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127424, 'Kabahaydar', 'Kabahaydar', 'Kabahaydar,Kalacik,Kalacık,Kalecik,Shiran', 37.3133800, 39.0099500, 'TR', '2016-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127425, 'Kale', 'Kale', '', 39.0333300, 38.0000000, 'TR', '2006-01-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127426, 'Kale', 'Kale', 'Kale', 37.4391700, 28.8452800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127427, 'Kâhta', 'Kahta', 'Kahta,Kakhta,Kolik,Koluk,Kâhta,Kölük,Кахта', 37.7855200, 38.6237000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127428, 'Kahramanmaraş', 'Kahramanmaras', 'Caesarea Germanicia,Germanicea Marqasi,Gorad Kakhramanmarash,Gurgum,KCM,Kachramanmaras,Kachramanmarasas,Kachramanmarašas,Kahramanmaras,Kahramanmaraş,Kakhramanmarash,Karamanmarash,Kuag''ramanmarash,Maraache,Marache,Maraix,Maras,Marasch,Marash,Marasion,Maraş,Meres,Qəhrəmanmaraş,ka he la man ma la shen,kafuramanmarashu,kahramanmarashi,kalamanmalasyu,Καχραμανμαράς,Горад Кахраманмараш,Караманмараш,Кахраманмараш,Къагьраманмараш,Қаһраманмараш,Մարաշ,קהרמאנמרש,قهرمان مرعش,قهرمان‌مرعش,قہرمان مرعش,مرعش,مەرعەش,کہرامانمراش,ქაჰრამანმარაში,カフラマンマラシュ,卡赫拉曼馬拉什,카라만마라슈', 37.5847000, 36.9264100, 'TR', '2017-01-24', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127429, 'Kadışehri', 'Kadisehri', 'Kadisehir,Kadisehri,Kadışehir,Kadışehri', 39.9956800, 35.7919300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127430, 'Kadirli', 'Kadirli', 'Kadirli,Karszulkadriye,Karszülkadriye', 37.3738900, 36.0961100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127431, 'Kadınhanı', 'Kadinhani', 'Kadinhani,Kadınhanı,Saideli,Saiteli,syd ayly,سید ایلی', 38.2397200, 32.2113900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127432, 'Kabala', 'Kabala', 'Kabala', 37.3458500, 40.8005900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127433, 'Kabahaydar', 'Kabahaydar', 'Kabahaydar', 37.4000000, 39.0833300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127434, 'İzmir', 'Izmir', 'Azmir,Esmirna,IZM,Ismir,Izmir,Izmira,Izmiras,Izmiro,Smirne,Smyrna,Smyrne,Yazmir,azmyr,izmiri,izumiru,yi zi mi er,İzmir,Σμύρνη,Измир,איזמיר,إزمير,იზმირი,イズミル,伊兹密尔', 38.4127300, 27.1383800, 'TR', '2012-12-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127435, 'İvrindi', 'Ivrindi', 'Ivrindi,İvrindi', 39.5838900, 27.4863900, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127436, 'Isparta', 'Isparta', '"sparta,Baris,Gorad ysparta,Hamid,Hamid-Abad,Hamitabat,ISE,Isbarta,Isparta,Ispartah,Izbarta,Izparta,Sparta,Sparte,Spartē,Ysparta,asbrtt,asparta,iseupaleuta,usuparuta,yi si pa er ta,ysparta,İsparta,İzparta,Ισπάρτα,Горад Ыспарта,Испарта,Ъспарта,Ыспарта,אספרטה,إسبرطة,اسپارتا,ისპარტა,ウスパルタ,伊斯帕爾塔,이스파르타', 37.7644400, 30.5522200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127437, 'Yuntdağ', 'Yuntdag', 'Ismailli,Yuntdag,Yuntdağ,İsmailli', 38.9316700, 27.2136100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127438, 'İslahiye', 'Islahiye', 'Islahiye,İslahiye,İslâhiye', 37.0250000, 36.6305600, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127439, 'İskenderun', 'Iskenderun', 'Alejandreta,Aleksandretta,Alessandretta,Alexandretta,Alexandrette,Alexandria ad Issum,Gorad Iskendehrun,Iskandariyah,Iskanderun,Iskenderon,Iskenderun,Iskenderunas,Lissandretta,Myriandrus,askndrwn,askndrwnt,iseukendelun,yi si ken de lun,Îskenderûn,İskenderon,İskenderun,Αλεξανδρέττα,Іскендерун,Горад Іскендэрун,Искендерун,Ալեքսանդրեթ,إسكندرونة,اسكندرون,اسکندرون,伊斯肯德倫,이스켄데룬', 36.5871800, 36.1734700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127440, 'Işıklar', 'Isiklar', 'Isiklar,Işıklar', 38.6710100, 30.7409800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127441, 'İshaklı', 'Ishakli', 'Isakli,Ishakli,İsaklı,İshaklı', 38.1997200, 30.0133300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127442, 'Kavsan', 'Kavsan', 'Isgoren,Kavsan,İşgören', 37.6565300, 40.6580600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127443, 'İscehisar', 'Iscehisar', 'Iscehisar,İscehisar', 38.8619400, 30.7502800, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127444, 'İsabeyli', 'Isabeyli', 'Isabeyli,İsabeyli', 37.9014700, 28.2647500, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127445, 'İnönü', 'Inonu', 'Inonu,İnönü', 39.8153400, 30.1454900, 'TR', '2012-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127446, 'İnönü', 'Inonu', 'Inonu,Inonuciftligi,İnönü,İnönüçiftliği', 37.3166700, 33.7666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127447, 'İncirliova', 'Incirliova', 'Incirliova,Indzhirliova,Karahisar,Karapinar,Karapınar,anhyrlywa,anjyrlywa,aynjyrlywwa,yin ji er li ao wa,İncirliova,Инджирлиова,انجیرلیوا,انحیرلیوا,اینجیرلیووا,因吉爾利奧瓦', 37.8522200, 27.7236100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127448, 'İncesu', 'Incesu', 'Incesu,Injesu,İncesu', 38.6224000, 35.1826100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127449, 'İmranlı', 'Imranli', 'Hamidabad,Hamidabat,Hamilabat,Hamitabad,Hamitabat,Imraniye,Imranli,Umraniye,İmraniye,İmranlı', 39.8754400, 38.1135800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127450, 'İmamoğlu', 'Imamoglu', 'Imamoglu,İmamoğlu', 37.2650600, 35.6571700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127451, 'İlyaslı', 'Ilyasli', 'Ilyasli,İlyaslı', 38.6038900, 29.2005600, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127452, 'Ilıca', 'Ilica', 'Ilica,Ilici,Ilıca', 39.9465300, 41.0952000, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127453, 'Ilıca', 'Ilica', 'Ilica,Ilıca', 39.8758300, 27.7763900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127454, 'Ilıcalar', 'Ilicalar', 'Fahran,Icpinar,Ilica,Ilicalar,Ilıca,Ilıcalar,Kos,Kos Koyu,Koskoy,Kös,Kös Köyü,Kösköy,İçpınar', 38.9803400, 40.6739400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127455, 'İliç', 'Ilic', 'Ilic,Pusadi,Puşadı,İliç', 39.4510600, 38.5583600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127456, 'Ilgın', 'Ilgin', 'Ilgin,Ilgın,Tyriaeum', 38.2791700, 31.9138900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127457, 'İkizce', 'Ikizce', 'Ikizce,İkizce', 39.5951600, 32.6609700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127458, 'İkizce', 'Ikizce', 'Ekizce,Ikizce,Ikizdzhe,İkizce', 36.8626200, 37.7743200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127459, 'Aviski', 'Aviski', 'Asagi Aviski,Aviski,Aşağı Aviski,Ikikopru,İkiköprü', 37.9645900, 41.3311900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127460, 'İhsaniye', 'Ihsaniye', 'Ihsaniye,İhsaniye', 39.0291600, 30.4163900, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127461, 'Iğdır', 'Igdir', '"gdur,IGD,Idir,Igdir,Igdira,Igdyras,Iidir,Iğdır,Iıdır,aghdyr,ayghdr,ayghdyr,e de er,idileu,igdiri,udo~uru,ygdyr,Îdir,Īgdira,İğdır,Игдир,Ъгдър,Ыгдыр,Ցոլակերտ,اغدير,ایغدر,ایغدیر,ڕەشقەلاس,იგდირი,ウードゥル,厄德尔,이디르', 39.9237100, 44.0450000, 'TR', '2013-05-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127462, 'İdil', 'Idil', 'Distretto di Idil,Distretto di İdil,Hazak,Hezek,Hezex,Idil,Idil'',Khazak,adyl,aydl,aydyl,yi di er,İdil,Идиль,إيدل,ادیل,ایدیل,ضلع ادل,ܐܙܟ,伊迪爾', 37.3348100, 41.8894400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127463, 'Teffi', 'Teffi', 'Icoren,Teffi,İçören', 37.5578100, 41.0955100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127464, 'İçme', 'Icme', 'Icme,İçme', 38.6125700, 39.5513000, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127465, 'Hüyük', 'Huyuk', 'Hoyuk,Hoyuk Koyu,Huyuk,Höyük,Höyük Köyü,Hüyük', 37.9538800, 31.5963900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127466, 'Hozat', 'Hozat', 'Dersim,Hozat', 39.1002900, 39.2081600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127467, 'Hotamış', 'Hotamis', 'Hotamis,Hotamış', 37.6400400, 33.3186200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127468, 'Horsunlu', 'Horsunlu', 'Horsunlu', 37.9144100, 28.5915100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127469, 'Honaz', 'Honaz', 'Honaz', 37.7573000, 29.2699600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127470, 'Hocalar', 'Hocalar', 'Hocalar', 38.5782400, 29.9676800, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127471, 'Gyundyukoru', 'Gyundyukoru', 'Abdulimam,Abdülimam,Gundukoru,Gyundyukoru,Gündükoru', 37.1420700, 40.5014900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127472, 'Selçuklu', 'Selcuklu', 'Hocacihan,Selcuklu,Selçuklu', 37.8842000, 32.4922200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127473, 'Hizan', 'Hizan', 'Hizan', 38.2249800, 42.4183000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127474, 'Hisarcık', 'Hisarcik', 'Hisarcik,Hisarcık', 39.2505700, 29.2311600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127475, 'Hisar', 'Hisar', 'Hasar,Hisar,Hisarkoy,Hisarköy,Khisar', 37.6009400, 41.2279900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127476, 'Hınıs', 'Hinis', 'Hinis,Hınıs', 39.3576600, 41.6925300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127477, 'Himmetdede', 'Himmetdede', 'Himmetdede', 38.9102800, 35.0960700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127478, 'Hilvan', 'Hilvan', 'Hilvan,Karacorun,Karacurum,Karacurun,Karaçürun', 37.5868700, 38.9550500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127479, 'Hilal', 'Hilal', 'Helal,Hilal,Hilâl,Khelal', 37.4752800, 42.7858300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127480, 'Hıdırbey', 'Hidirbey', 'Cekmece,Hidirbey,Hıdırbey,Çekmece', 36.2080200, 36.1278700, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127481, 'Hıdırbaba', 'Hidirbaba', 'Balibey,Disidi,Dişidi,Hidirbaba,Hıdırbaba', 38.7670600, 38.9769800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127482, 'Hekimhan', 'Hekimhan', 'Hekimhan', 38.8162200, 37.9288200, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127483, 'Hekimdağ', 'Hekimdag', 'Hekimdag,Hekimdağ,Taskopru,Taşköprü', 39.9090400, 30.5646000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127484, 'Hazro', 'Hazro', 'Hazro', 38.2490300, 40.7712900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127485, 'Haymana', 'Haymana', 'Hamam,Haymana,Sivrihamam,Yaban', 39.4321200, 32.4973200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127486, 'Haydarlı', 'Haydarli', 'Haydarli,Haydarlı', 38.2597200, 30.3858300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127487, 'Havran', 'Havran', 'Havran', 39.5583300, 27.0983300, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127488, 'Hatunsaray', 'Hatunsaray', 'Hatunsaray', 37.5875300, 32.3480200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127489, 'Hatip', 'Hatip', 'Hatip,Hatir,Hatır', 37.7544700, 32.4222000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127490, 'Hassa', 'Hassa', 'Hassa', 36.7994400, 36.5177800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127491, 'Alacakaya', 'Alacakaya', 'Alacakaya,Hasarut,Hasrut', 38.4575100, 39.8595600, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127492, 'Hasköy', 'Haskoy', 'Haskoy,Hasköy', 38.6823100, 41.6785100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127493, 'Hasbek', 'Hasbek', 'Hasbek', 39.5494500, 35.5477200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127494, 'Hasankeyf', 'Hasankeyf', 'Hasankeyf,Hasankeyif,Heskif,Heskîf,Khasankejf,Khasankeye,hasankeipeu,hsn kyfa,Хасанкейф,حصن كيفا,حصن کیفا,حەسکیف,ضلع ہاسنکیف,하산케이프', 37.7061200, 41.4048000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127495, 'Hasançelebi', 'Hasancelebi', 'Hasancelebi,Hasançelebi', 38.9509300, 37.8806400, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127496, 'Hasanbeyli', 'Hasanbeyli', 'Hasanbeyli', 37.1283800, 36.5460800, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127497, 'Haruniye', 'Haruniye', 'Duzici,Düziçi,Haruniye', 37.2421600, 36.4548400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127498, 'Harran', 'Harran', 'Altinbasak,Altunbasak,Altunbaşak,Altynbashak,Altınbaşak,Charan,Haran,Harran,Kharran', 36.8600000, 39.0313900, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127499, 'Harput', 'Harput', 'Charput,Harpout,Harput,Kharput,Mamurat-el-Aziz', 38.7037300, 39.2415000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127500, 'Harmanlı', 'Harmanli', 'Harmanli,Harmanlı,Pervari,Perveri,Pevari', 37.8381200, 37.7442800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127501, 'Harmancık', 'Harmancik', 'Cardi,Harmancik,Harmancık,Çardı', 39.6761100, 29.1552800, 'TR', '2015-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127502, 'Harbiye', 'Harbiye', 'Harbiyah,Harbiyat,Harbiye,hrbyat,hrbyt,حربيات,حربية,Ḩarbīyah,Ḩarbīyāt', 36.1368500, 36.1329300, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127503, 'Han', 'Han', 'Han,Hankoy,Hanköy,Husrevpasa,Hüsrevpaşa', 39.1591700, 30.8613900, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127504, 'Hankendi', 'Hankendi', 'Hankendi,Hankoyu,Hanköyü', 38.5687900, 39.0573900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127505, 'Hani', 'Hani', 'Hani', 38.4074100, 40.3857800, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127506, 'Hanköy', 'Hankoy', 'Han,Hankoy,Hanköy', 36.9508100, 40.1985500, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127507, 'Hamzalı', 'Hamzali', 'Bahemdan,Hamzali,Hamzalı,Sehhamza,Seyhhamza,Şehhamza,Şeyhhamza', 38.3415900, 41.1625400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127508, 'Hamur', 'Hamur', 'Hamur', 39.6056100, 42.9850000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127509, 'Hamdibey', 'Hamdibey', 'Hamdibey,Koyuneli', 39.8494400, 27.2480600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127510, 'Halkapınar', 'Halkapinar', 'Halkapinar,Halkapınar,Zanapa,Zanape', 37.4339400, 34.1874300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127511, 'Halitpaşa', 'Halitpasa', 'Halitpasa,Halitpaşa,Hocali,Hocalı', 38.6854100, 27.6783600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127512, 'Halilçavuş', 'Halilcavus', 'Halilcavus,Halilcavus Koyu,Halilçavuş,Halilçavuş Köyü', 39.2472000, 41.7925700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127513, 'Halfeti', 'Halfeti', 'Halfeti', 37.2452900, 37.8687400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127514, 'Tuzla', 'Tuzla', 'Hakkibey,Hakkibeyli,Hakkıbey,Hakkıbeyli,Hayriye,Nasidiye-Hayriye,Naşidiye-Hayriye,Tuzla', 36.7007400, 35.0872600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127515, 'Hafik', 'Hafik', 'Hafik,Kochisar,Koçhisar', 39.8563900, 37.3863900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127516, 'Hadim', 'Hadim', 'Hadim,Khadim,Yukari Hadim,Yukarı Hadım,Хадим', 36.9877600, 32.4567400, 'TR', '2013-07-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127517, 'Hacılar', 'Hacilar', 'Hacilar,Hacılar', 38.6463100, 35.4493700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127518, 'Hacıbektaş', 'Hacibektas', 'Hacibektas,Hacıbektaş,Karabuyuk,Karabüyük,Karahuyuk,Karahüyük', 38.9407700, 34.5577000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127519, 'Aydınlar', 'Aydinlar', 'Aydinlar,Aydınlar,Haciarap,Haciharapkonagi,Hacıarap,Hacıharapkonağı,Musar,Muşar', 38.6219800, 38.5405200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127520, 'Haberli', 'Haberli', 'Basabirin,Basbirin,Basibirin,Baspirin,Basıbirin,Haberli', 37.3051000, 41.6175800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127521, 'Güzelyurt', 'Guzelyurt', 'Gelveri,Guzelyurt,Güzelyurt', 38.2772200, 34.3719400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127522, 'Güzelsu', 'Guzelsu', 'Guzelsu,Güzelsu,Hosap,Hoşap', 38.3103200, 43.7990600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127523, 'Güzelsu', 'Guzelsu', 'Guzelsu,Güzelsu', 36.8947200, 31.8563900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127524, 'Güzeloluk', 'Guzeloluk', 'Guzeloluk,Güzeloluk', 36.7944400, 34.0827400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127525, 'Güzelbağ', 'Guzelbag', 'Guzelbag,Güzelbağ,Kizilagac,Kızılağaç', 36.7336300, 31.8983700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127526, 'Gürün', 'Gurun', 'Gurun,Gürün,Inonu,İnönü', 38.7222500, 37.2709700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127527, 'Gürpınar', 'Gurpinar', 'Gurpinar,Gürpınar,Kigzi,Kığzı', 38.3237200, 43.4099100, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127528, 'Güroymak', 'Guroymak', 'Cukur,Goroymak,Guroymak,Göroymak,Güroymak,Norsin,Norşin,Çukur', 38.5758000, 42.0155800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127529, 'Güre', 'Gure', 'Gure,Güre', 38.6511100, 29.1669400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127530, 'Günyüzü', 'Gunyuzu', 'Gunyuzu,Günyüzü,Kozagaci,Kozağacı', 39.3834500, 31.8099500, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127531, 'Güney', 'Guney', 'Gunay,Guney,Günay,Güney', 38.1544400, 29.0677800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127532, 'Güneren', 'Guneren', 'Guneren,Güneren,Sarkimugayre,Sharkymugayre,Şarkımugayre', 36.7341700, 39.0886100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127533, 'Eksere', 'Eksere', 'Eksere,Gundogmus,Gündoğmuş', 36.8133900, 31.9997100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127534, 'Homa', 'Homa', 'Gumussu,Gümüşsu,Homa', 38.2392700, 29.9865100, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127535, 'Salanda', 'Salanda', 'Gumuskent,Gümüşkent,Salanda', 38.8255600, 34.5321200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127536, 'Gümüşakar', 'Gumusakar', 'Gumusakar,Gümüşakar,Kocgiri,Kockiri,Koçgiri,Koçkiri', 39.7938200, 38.6729700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127537, 'Becuh', 'Becuh', 'Becu,Becuh,Becü,Bedzhukh,Bicer,Biçer,Gulyazi,Gunyazi,Gülyazı,Günyazı', 37.3914100, 42.9901800, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127538, 'Gülveren', 'Gulveren', 'Bahvar,Bakhvar,Gulveren,Gülveren', 37.4871100, 41.4944600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127539, 'Gülşehir', 'Gulsehir', 'Arapsun,Arebsun,Gulsehir,Gülşehir', 38.7459400, 34.6252400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127540, 'Gülpınar', 'Gulpinar', 'Golpinar,Gulpinar,Gölpınar,Gülpınar,Kulahli,Külâhlı', 39.5327800, 26.1205600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127541, 'Gülnar', 'Gulnar', 'Gjul''nar,Gul''nar,Gulnar,Gülnar,Гюльнар,Гӱльнар,ضلع گلنار', 36.3414800, 33.3992100, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127542, 'Kiulukioi', 'Kiulukioi', 'Chulukioi,Gulluk,Güllük,Kiulukioi,Kulluk,Küllük', 37.2397200, 27.6002800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127543, 'Güllü', 'Guellue', 'Gullu,Güllü', 38.2711400, 29.1045100, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127544, 'Yenisu', 'Yenisu', 'Guleyan,Güleyan,Yenisu', 38.7520100, 40.8757100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127545, 'Güleçler', 'Gulecler', 'Gulecler,Güleçler,Hanuk,Hanük,Hunuk,Hünük,Khanyuk', 37.9533300, 42.5386100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127546, 'Başköy', 'Baskoy', 'Baskoy,Başköy,Gulebagdi,Gülebağdı', 39.8723100, 39.8418800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127547, 'Gücük', 'Gucuk', 'Gocuk,Gucuk,Göcük,Gücük,Kucuk,Küçük', 38.1936000, 37.4812000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127548, 'Baraniferho', 'Baraniferho', 'Baraniferho,Basan,Guclukonak,Güçlükonak', 37.4695700, 41.9059300, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127549, 'Gözpınar', 'Gozpinar', 'Gozpinar,Gözpınar,Hishis,Hıshıs,Khiskhis', 37.9771700, 41.4576100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127550, 'Gözne', 'Gozne', 'Giosna,Gozne,Goznekoy,Gözne,Gözneköy', 36.9952800, 34.5730600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127551, 'Gözler', 'Gozler', 'Gozler,Gözler', 38.1067900, 29.1537500, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127552, 'Gözeli', 'Gozeli', 'Gozeli,Gözeli,Iringil,Mercumut,Mercümüt,İringil', 38.4246000, 39.0572800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127553, 'Göynük', 'Goynuk', 'Gognuk,Gonuk,Goynuk,Gönük,Göynük,Göğnük,Ognut,Oğnut', 39.1394700, 40.8743800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127554, 'Göynük', 'Goeynuek', 'Gjojnjuk,Гёйнюк', 36.6600000, 30.5500000, 'TR', '2014-05-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127555, 'Payamlı', 'Payamli', 'Dolunay,Goveren,Göveren,Payamli,Payamlı', 37.0365100, 38.6133700, 'TR', '2016-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127556, 'Bisbin', 'Bisbin', 'Besbin,Bespin,Bisbin,Gorumlu,Görümlü', 37.3392900, 42.5694500, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127557, 'Göreme', 'Goereme', 'Churches of Goereme,Churches of Göreme,Corama,Gioremes slenis,Gioremės slėnis,Gjoreme,Goereme,Goereme Nemzeti Park es Kappadokia sziklatemplomai,Goereme Tarihi Milli Parki,Goreme,Gyoreme azgayin aygi,Göreme,Göreme Nemzeti Park és Kappadókia sziklatemplomai,Göreme Tarihi Milli Parkı,Görəmə Milli Parkı,Nacional''nij park G''oreme,Nacional''nyj park Gjoreme,Nacyjanal''ny park Gjorehmeh,Nkioreme,Parc national de Goereme et sites rupestres de Cappadoce,Parc national de Göreme et sites rupestres de Cappadoce,ge lei mei,ghwrym,goeleme,goreme rastriya nikunja,grmh,gwrmh,gyoreme guo li gong yuan,kexre me,Γκιόρεμε,Ѓореме,Гореме,Национальный парк Гёреме,Нацыянальны парк Гёрэмэ,Національний парк Гьореме,Գյորեմե ազգային այգի,גרמה,غوريم,گورمه,گوریمے,गोरेमे राष्ट्रिय निकुञ्ज,เกอเรเม,გორემეს ეროვნული პარკი,გორემეშ ერუანული პარკი,ギョレメ国立公園,格雷梅,괴레메', 38.6437000, 34.8352900, 'TR', '2011-04-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127558, 'Gördes', 'Gordes', 'Gordes,Gördes', 38.9327800, 28.2894200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127559, 'Gönen', 'Gonen', 'Gonen,Gönen,Гонен', 37.9563900, 30.5114000, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127560, 'Gömeç', 'Goemec', 'Altinova,Armudova,Armutova,Emrutabat,Goemec,Gume,Gömeç,Güme,Yayakoy,Yayaköy', 39.3901600, 26.8412700, 'TR', '2015-11-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127561, 'Gölova', 'Golova', 'Golova,Gölova', 36.7991700, 30.0388900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127562, 'Beyviran', 'Beyviran', 'Beyviran,Goloren,Golveren,Gölveren,Gölören', 37.8494900, 33.8597000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127563, 'Gölmarmara', 'Golmarmara', 'Golmarmara,Gölmarmara,Marmara', 38.7138900, 27.9141700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127564, 'Göllü', 'Gollu', 'Gollu,Gullu,Göllü,Güllü', 39.4499000, 34.3001100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127565, 'Gölhisar', 'Golhisar', 'Golhisar,Gölhisar,Horzom,Horzum', 37.1459000, 29.5087600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127566, 'Gölgelikonak', 'Golgelikonak', 'Golgelikonak,Gölgelikonak,Hileyluk,Hileylük,Hililuk,Hililük,Hululuk,Hülülük,Khyulyulyuk', 37.7692300, 42.1274400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127567, 'Göldüzü', 'Golduzu', 'Arin,Arın,Golduzu,Göldüzü', 38.8133500, 43.0190400, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127568, 'Gölcük', 'Golcuk', 'Golcuk,Gölcük', 39.3130900, 27.9831900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127569, 'Tilfetis', 'Tilfetis', 'Golcuk,Gölcük,Tilfetis', 37.4813500, 39.0473600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127570, 'Gölbaşı', 'Golbasi', 'Golbasi,Gölbaşı', 39.7904300, 32.8090300, 'TR', '2013-01-25', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127571, 'Gölbaşı', 'Golbasi', 'Gjol''bashi,Go''l''bashy,Goelbasi i Adiyaman,Gol''bashy,Golbasi,Gölbaşı,Gölbaşı i Adıyaman,Sere Golan,Sergol,Serê Golan,ge er ba she,gwlbashy  adyaman,Гоьльбашы,Гёльбаши,Гӧльбашы,سەرگۆل,گولباشی، آدیامان,گول‌باشی,格爾巴舍', 37.7836100, 37.6366700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127572, 'Göktepe', 'Goktepe', 'Belanya,Belanye,Belenye,Goktepe,Göktepe', 37.4190800, 28.5589400, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127573, 'Göktepe', 'Goktepe', 'Goktepe,Göktepe', 36.6268700, 32.6228000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127574, 'Göksun', 'Goksun', 'Goksun,Göksun', 38.0209600, 36.4973000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127575, 'Göksu', 'Goksu', 'Goksu,Göksu,Kocan,Koçan', 39.4890600, 42.1512700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127576, 'Gökoğlan', 'Gokoglan', 'Gokoglan,Gökoğlan', 39.5464800, 41.3040200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127577, 'Gökdere', 'Gokdere', 'Erduruk,Erdürük,Gokdere,Gökdere', 38.7428000, 40.2081500, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127578, 'Ergama', 'Ergama', 'Ergama,Gokceyazi,Gökçeyazı', 39.6271200, 27.6313900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127579, 'Menye', 'Menye', 'Gokceoren,Gökçeören,Menye', 38.5752800, 28.4888900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127580, 'Gökçen', 'Gokcen', 'Gokcen,Gökçen', 38.1136700, 27.8714400, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127581, 'Gökçekoru', 'Gokcekoru', 'Gokcekoru,Gökçekoru,Kerafon,Kerefan', 37.9562100, 42.4497100, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127582, 'Gökçedağ', 'Gokcedag', 'Gokcedag,Gökçedağ,Inekollar,İnekollar', 39.5583200, 28.9191100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127583, 'Civankan', 'Civankan', 'Civankan,Civinikan,Civinikân,Dzhivinikyan,Gokcebag,Gökçebağ', 37.9033900, 41.8775200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127584, 'Selah', 'Selah', 'Gokce,Gökçe,Selah,Selakh,Selâh', 37.2054100, 40.6974800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127585, 'Gökbudak', 'Gokbudak', 'Gokbudak,Gökbudak,Sanuh', 37.9036700, 42.6486600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127586, 'Göçbeyli', 'Gocbeyli', 'Gocbeyli,Göçbeyli', 39.2232800, 27.4038600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127587, 'Girmeli', 'Girmeli', 'Giremira,Girimira,Girmeli,Habap', 37.1110600, 41.4196000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127588, 'Geyikpınar', 'Geyikpinar', 'Geyikpinar,Geyikpinari,Geyikpınar,Geyikpınarı,Igik,Kolanis,Kolaniz,Kölânis,İğik', 38.3175900, 41.8206500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127589, 'Geyikli', 'Geyikli', 'Geyikli,Gheyikli', 39.8047200, 26.2075000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127590, 'Gevaş', 'Gevas', 'Gevas,Gevaş,Vastan,Vaston', 38.2921000, 43.1018900, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127591, 'Gesi', 'Gesi', 'Bagyurdu,Bağyurdu,Gesi,Gezi', 38.7918000, 35.6592300, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127592, 'Germencik', 'Germencik', 'Germecik,Germecık,Germencik,Igneabat,Igneada,Inabat,Ineabat,Mermencik,İnabat,İğneabat,İğneada', 37.8705600, 27.6028300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127593, 'Geriş', 'Geris', 'Geric,Geris,Geriç,Geriş', 36.9625000, 31.7330600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127594, 'Gerger', 'Gerger', '', 37.9500000, 39.0166700, 'TR', '2006-01-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127595, 'Gerdzhyush', 'Gerdzhyush', 'Gercus,Gercüş,Gerdzhyush', 37.5624900, 41.3775300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127596, 'Gencek', 'Gencek', 'Gencek,Gencek Kariyesi', 37.4498400, 31.5458800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127597, 'Genç', 'Genc', 'Darahini,Genc,Genk,Genç,Генк', 38.7477300, 40.5534300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127598, 'Gemerek', 'Gemerek', 'Gemerek', 39.1834200, 36.0718900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127599, 'Gelinkaya', 'Gelinkaya', 'Gelinkaya,Keferhavar,Keferhavvar,Keferhuvar,Keferhuvvar,Keferkhavvar', 37.4168300, 41.2699400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127600, 'Gelendost', 'Gelendost', 'Gelendos,Gelendost', 38.1208300, 31.0152800, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127601, 'Gelembe', 'Gelembe', 'Gelembe,Gelenbe', 39.1787200, 27.8484800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127602, 'Gediz', 'Gediz', 'Cadi,Gedis,Gediz,Гедиз', 38.9938900, 29.3913100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127603, 'Gedikler', 'Gedikler', 'Gedikler,Germili', 39.0822900, 38.8034600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127604, 'Timar', 'Timar', 'Canik,Gedikbulak,Timar', 38.8286500, 43.4333000, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127605, 'Gedikbaşı', 'Gedikbasi', 'Gedikbasi,Gedikbaşı', 39.4893900, 38.2474300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127606, 'Geçitli', 'Gecitli', 'Gecitli,Geçitli,Levin,Livin,Peyanis,Piyanis', 37.5866900, 43.5616300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127607, 'Gebiz', 'Gebiz', 'Gebiz,Macar', 37.1041700, 30.9377800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127608, 'Gazipaşa', 'Gazipasa', 'GZP,Gazipasa,Gazipaşa,Pazarci,Pazarcik,Pazarcı,Pazarcık,Pazarli,Pazarlı,Selinti,Silinti,Trajanopolis', 36.2694200, 32.3179200, 'TR', '2016-10-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127609, 'Gaziemir', 'Gaziemir', 'Gaziemir', 38.3239200, 27.1291800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127610, 'Gaziantep', 'Gaziantep', 'Aintab,Antep,Ayintap,Ayıntap,Dilok,Dîlok,GZT,Gazi-Ayintap,Gaziantep,Gaziantepa,Gaziantepas,Gazijantep,Gorad Gazijantehp,Guaziantep,Nkaziantep,Qazianteb,Qaziantep,gaji''antepa,gajiantepeu,gaziantepi,gazu~iantepu,jia ji an tai pu,ka si xan tep,Γκαζιαντέπ,Газиантеп,Газијантеп,Горад Газіянтэп,Гъазиантеп,Ґазіантеп,Գազիանթեպ,גזיאנטפ,عنتاب,غازی عینتاب,گازی ئانتەپ,ਗਜਿਆਂਤੇਪ,กาซีอันเตป,გაზიანთეფი,ガズィアンテプ,加濟安泰普,가지안테프', 37.0594400, 37.3825000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127611, 'Foça', 'Foca', 'Eski Foca,Eski Foja,Eski Foka,Eski Foça,Foca,Focha,Foilleri,Foja,Fokia,Fouges,Foujes,Foça,Karaca Foka,Karafoca,Karafoça,Palaies Phokes,Phocaea,Phogia', 38.6703000, 26.7565600, 'TR', '2016-12-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127612, 'Finike', 'Finike', 'Finike,Phoenicus,fei ni kai,fnkh,fynykh,fynyqyh,Финике,فنکه,فينيقيه,فینیکه,菲尼凱', 36.2950000, 30.1405600, 'TR', '2012-12-24', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127613, 'Fındık', 'Findik', 'Findik,Fyndyk,Fındık,Parona,Perona', 37.5131700, 41.9641800, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127614, 'Fevzipaşa', 'Fevzipasa', 'Fevzipasa,Fevzipaşa,Fevzitasa', 37.0941800, 36.6371900, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127615, 'Fethiye', 'Fethiye', 'Fethieh,Fethiye,Fethiye-Calis,Fethy,Fetiye,Fetkhie,Makri,Makry,Telmessus,fei te xi ye,fetohii~e,fthyh,fthyt,petiye,pthyyh,Μάκρη,Фетхие,Фетхіє,פטהייה,ضلع فتھیے,فتحية,فتحیه,フェトヒイェ,费特希耶,페티예', 36.6403800, 29.1275800, 'TR', '2017-05-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127616, 'Felahiye', 'Felahiye', 'Felahiye,Fellahiye,Rumdigin,Rumdiğin', 39.0905600, 35.5672200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127617, 'Feke', 'Feke', 'Asmaca,Feke,Феке,ضلع فیکے', 37.8144600, 35.9123300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127618, 'Ezine', 'Ezine', 'Ezine', 39.7856100, 26.3408300, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127619, 'Eymirli', 'Eymirli', 'Eymirli,Tib''yat,Tibyasa,Tibyat,Tib’yat,Tipyat', 37.1703000, 40.6868400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127620, 'Evciler', 'Evciler', 'Evciler', 39.7755600, 26.7716700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127621, 'Evciler', 'Evciler', 'Evciler', 38.0413900, 29.8866700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127622, 'Etimesgut', 'Etimesgut', 'Etimesgut,Etimesut', 39.9532800, 32.6328500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127623, 'Etili', 'Etili', 'Etili,Golcuk,Gölcük', 39.9855600, 26.8966700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127624, 'Eşme', 'Esme', 'Esme,Eşme,ashmh,اشمه', 38.3997600, 28.9690500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127625, 'Eşme', 'Esme', 'Esme,Eşme,Mezaakantar,Mezrakantar,Mezreaikantar,Mezreaikanter,Mezreakantar', 37.1556900, 40.6414200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127626, 'Eskişehir', 'Eskisehir', 'Dorylaeum,ESK,Ehskishekhir,Eski Shahr,Eski Shehir,Eski shehr,Eski-chehir,Eski-chéhir,Eskischehir,Eskisechir,Eskisechiras,Eskiseher,Eskisehir,Eskisehira,Eskishekhir,Eskişeher,Eskişehir,Eskišechiras,Eskišehira,Gorad Ehskishehkhir,ai si ji xie xi er,asky shhr,esakisehara,eseukisyehileu,eskishehiri,esukishehiru,Əskişəhər,Εσκισεχίρ,Горад Эскішэхір,Ескишехир,Ескішехір,Эскишехир,אסקישהיר,أسكي شهر,ئێسکی شەھر,اسکی شہر,اسکی‌شهر,ਏਸਕਿਸੇਹਰ,ესქიშეჰირი,エスキシェヒル,埃斯基谢希尔,에스키셰히르', 39.7766700, 30.5205600, 'TR', '2015-06-24', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127627, 'Eskil', 'Eskil', 'Eskiil,Eskil', 38.4016700, 33.4130600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127628, 'Esendere', 'Esendere', 'Bacirga,Bacirge,Bajirge,Esendere', 37.7114400, 44.6009900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127629, 'Eşen', 'Esen', 'Esen,Eşen,Kestep', 36.4548000, 29.2815400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127630, 'Erzurum', 'Erzurum', 'Ard-ar-Rum,Arzan-ar-Rum,Arzirum,Carana,ERZ,Ehrzurum,Erserum,Erzeroum,Erzerum,Erzirom,Erzirum,Erzurum,Erzuruma,Erzurumas,Erzéroum,Erzîrom,Gorad Ehrzurum,Kalikala,Karin,Theodosiopolis,ai er zu lu mu,ard rwm,ardrwm,arzrwm,eleujulum,eruzurumu,erzurumi,xer su rum,yەrzyڕۆm,Ərzurum,Ερζερούμ,Горад Эрзурум,Ерзурум,Эрзурум,Կարին,ארזורום,أرضروم,ئەرزیڕۆم,ارزروم,ارض روم,เอร์ซูรุม,ერზურუმი,エルズルム,埃尔祖鲁姆,에르주룸', 39.9086100, 41.2769400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127631, 'Erzincan', 'Erzincan', 'Arzanjan,Aziris,ERC,Ehrzindzhan,Ersindjan,Ersingan,Ersingjan,Erzincam,Erzincan,Erzindjan,Erzindzan,Erzindzanas,Erzindzhan,Erzindžanas,Erzingan,Erzinjan,Erznka,Erzıngan,Ezirgan,Yerznka,ai er jin zhan,arznjan,arzynjan,eleujinjan,erajikana,eruzu~injan,erzinjani,xer sin can,Ərzincan,Ерзинджан,Ерзинџан,Ерзінджан,Эрзинджан,Երզնկա,أرزينجان,ئەرزگان,ارزنجان,ਏਰਜਿੰਕਾਨ,เอร์ซินจาน,ერზინჯანი,エルズィンジャン,埃尔津詹,에르진잔', 39.7391900, 39.4901500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127632, 'Eruh', 'Eruh', 'Dih,Eruh,Erukh,Irs,Rekh,İrs', 37.7418300, 42.1742200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127633, 'Ertuğrul', 'Ertugrul', 'Ertogral,Ertoğral,Ertugrul,Ertuğrul', 39.5757800, 27.7067200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127634, 'Ermenek', 'Ermenek', 'Ermenak,Ermenek,Germanicopolis', 36.6404300, 32.8917900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127635, 'Erköklü', 'Erkoklu', 'Erkoklu,Erköklü,Irmi,İrmi', 37.8618200, 41.1441300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127636, 'Erkilet', 'Erkilet', 'Erkilet', 38.8204300, 35.4401100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127637, 'Ergani', 'Ergani', 'Arghana,Ehgrani,Ergani,Erganiosmaniye,Osmaniye,Эграни', 38.2689900, 39.7544600, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127638, 'Erentepe', 'Erentepe', 'Camili,Erentepe,Lis,Liz', 39.0089300, 42.0436400, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127639, 'Ereğli', 'Eregli', 'Cybistra,Ehregli,Erakleia,Eregli,Ereğli,Heraclea,Heraclea Minoa,Heraclee,Heracleia Minoa,Herakleia,Héraclée,Konyaereglisi,Konyaereğlisi,ai lei li,arghly,Ηράκλεια,Ерегли,Ереглі,Эрегли,ارغلی,ارغلی، قونیہ,埃雷利', 37.5133300, 34.0467200, 'TR', '2016-12-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127640, 'Erdemli', 'Erdemli', 'Ehrdemli,Erdemli,ai er dai mu li,ardmly,ayrdymly,Эрдемли,إيرديملي,اردملی,ضلع اردیملی,埃爾代姆利', 36.6049800, 34.3083600, 'TR', '2013-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127641, 'Erciş', 'Ercis', 'Arcis,Ercis,Erciş', 39.0258700, 43.3596400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127642, 'Erçek', 'Ercek', 'Akcha,Ercek,Erçek', 38.6510700, 43.6440100, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127643, 'Bulucan', 'Bulucan', 'Bolucan,Bulucan,Emirhan', 39.7025000, 37.7597200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127644, 'Emirgazi', 'Emirgazi', 'Emirgazi', 37.9022200, 33.8372200, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127645, 'Emirdağ', 'Emirdag', 'Aziziye,Distretto di Emirdag,Distretto di Emirdağ,Ehmirdag,Emirdag,Emirdağ,ai mi er da,amyrdagh,Эмирдаг,امیرداغ,ضلع امیرداگ,埃米爾達', 39.0197200, 31.1500000, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127646, 'Emiralem', 'Emiralem', 'Emiralem,Emiralem Koyu,Emiralem Köyü', 38.6097100, 27.1458800, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127647, 'Emet', 'Emet', 'Ehmet,Emet,Эмет', 39.3430000, 29.2584700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127648, 'Elvanlı', 'Elvanli', 'Elvanli,Elvanlı', 36.7040100, 34.3737400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127649, 'Güneysınır', 'Guneysinir', 'Elmali,Elmalı,Elmasun,Guneysinir,Güneysınır', 37.2694400, 32.7289800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127650, 'Elmalı', 'Elmali', 'Almali,Almalı,Ehlmaly,Elmali,Elmalı,ai er ma lei,almaly,Элмалы,المالی,埃爾馬勒', 36.7358300, 29.9177500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127651, 'Elmadağ', 'Elmadag', 'Asiyozgat,Asıyozgat,Elmadag,Elmadagi,Elmadağ,Elmadağı,Kucukyozgat,Küçükyozgat', 39.9208300, 33.2308300, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127652, 'Eleşkirt', 'Eleskirt', 'Eleskirt,Eleşkirt,Toprakkale,Zeydekan,Zeydikan,Zeydikân,Zidikan,Zidikân', 39.7980300, 42.6757400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127653, 'Elbistan', 'Elbistan', 'Ehl''bistan,Elbistan,albstan,Эльбистан,البستان', 38.2059100, 37.1983000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127654, 'Elbeyli', 'Elbeyli', 'Alimantar,Elbeyli', 36.6741700, 37.4666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127655, 'Elbaşı', 'Elbasi', 'Elbasi,Elbaşı,Zamanti', 38.6735100, 35.9675300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127656, 'Elazığ', 'Elazig', 'EZS,Ehljazyg,Elazig,Elazii,Elaziz,Elaziğ,Elazığ,Elazıı,Eleziz,Elezîz,Eliazihas,Eljaz"g,Eljazig,Elâzız,Elâzığ,Gorad Ehljazyg,Mezreh,Xarberd,ai la ze,alazygh,aylazgh,elajiga,elazighi,ellaji,erazu,mʿmwrt alʿzyz,Горад Элязыг,Елазиг,Елязиг,Елязъг,Элязыг,Խարբերդ,الازیغ,ایلازغ,خارپێت,معمورة العزيز,ਏਲਾਜਿਗ,ელაზიღი,エラズー,埃拉泽,엘라지', 38.6743100, 39.2232100, 'TR', '2013-05-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127657, 'Celeyke', 'Celeyke', 'Cela,Celaki,Celeyke,Ekinozu,Ekinözü', 38.0597400, 37.1878600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127658, 'Üçpınar', 'Ucpinar', 'Egri,Egrikoy,Eğri,Eğriköy,Ucpinar,Üçpınar', 38.7342300, 27.3616400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127659, 'Eğirdir', 'Egirdir', 'Egirdir,Egridir,Eğirdir,Prostanna', 37.8746200, 30.8504200, 'TR', '2011-01-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127660, 'Eğil', 'Egil', 'Egil,Eğil', 38.2574800, 40.0743500, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127661, 'Kocasinan', 'Kocasinan', 'Kocasinan', 38.7714700, 35.5725000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127662, 'Edremit', 'Edremit', 'Adramyti,Adramyttio,Adramyttium,Distretto di Edremit,EDO,Edremid,Edremit,Edremit i Balikesir,Edremit i Balıkesir,Ehdremit,adrmyt,ai de lei mi te,Αδραμύττιο,Эдремит,إدرميت,ادرمیت,埃德雷米特', 39.5961100, 27.0244400, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127663, 'Düzova', 'Duzova', 'Duzova,Düzova,Hoser,Huser,Höser,Khuser', 37.3541300, 42.0883700, 'TR', '2013-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127664, 'Dutluca', 'Dutluca', 'Asutka,Aşutka,Dutluca', 39.1358600, 38.6066200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127665, 'Duruca', 'Duruca', 'Duruca,Kertuvin,Kertyuvin,Kertüvin', 37.0930900, 41.3098600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127666, 'Dursunbey', 'Dursunbey', 'Balat,Dursunbey', 39.5859600, 28.6256800, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127667, 'Durak', 'Durak', 'Durak,Gedikleme', 39.7065800, 28.2717600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127668, 'Dumlupınar', 'Dumlupinar', 'Dumlupinar,Dumlupınar', 38.8540800, 29.9772000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127669, 'Sumbas', 'Sumbas', 'Arabli,Arapli,Araplı,Dugenli,Düğenli,Sumbas', 37.4513000, 36.0234900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127670, 'Döşemealtı', 'Dosemealti', 'Dosemealti,Döşemealtı,Yenikoy,Yeniköy', 37.0233300, 30.6024700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127671, 'Dorutay', 'Dorutay', 'Dorutay,Tasrumi,Taşrumi', 38.7993900, 44.0672600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127672, 'Dorumali', 'Dorumali', 'Dorumali', 36.8050000, 38.8530600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127673, 'Dörtyol', 'Dortyol', 'Dortyol,Dörtyol', 36.8391700, 36.2302500, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127674, 'Dombay', 'Dombay', 'Dombay,Dombayova', 38.1542100, 30.2087600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127675, 'Domaniç', 'Domanic', 'Domanic,Domanic Kozluca,Domaniç,Domaniç Kozluca,Hisar,Hisarkoy,Hisarköy', 39.8019400, 29.6091800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127676, 'Doğubayazıt', 'Dogubayazit', 'Baiazid,Bajaset,Bajasid,Bajesid,Bayazid,Bayazit,Bayezid,Bazid,Bazîd,Baīazid,Beyazit,Beyazıt,Beyzit,Beyzıt,Dogu Beyazidi,Dogubajazit,Dogubayazid,Dogubayazidi,Dogubayazit,Dogubeyazit,Doğu Beyazidi,Doğubayazidi,Doğubayazıd,Doğubayazıt,Doğubeyazıt,Karakose,Karaköse,dghw bayzyd,Догубаязит,دغو بایزید', 39.5469400, 44.0841700, 'TR', '2012-04-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127677, 'Doğanyol', 'Doganyol', 'Doganyol,Doğanyol,Keferdiz,Siro,Şiro', 38.3074600, 39.0343100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127678, 'Doğansu', 'Dogansu', 'Dogansu,Doğansu,Sultanmut', 39.1324800, 42.7324900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127679, 'Doğanşehir', 'Dogansehir', 'Dogansehir,Doğanşehir,Muhacir,Viransehir,Viranşehir', 38.0857400, 37.8711600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127680, 'Doğanpınar', 'Doganpinar', 'Doganpinar,Doğanpınar,Haral,Kharal', 36.8432100, 37.6175900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127681, 'Doğanköy', 'Dogankoy', 'Dogan,Dogankoy,Doğan,Doğanköy,Osyan', 37.7633400, 42.7892900, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127682, 'Doğankent', 'Dogankent', 'Dogankent,Doğankent,Mehmandar,Mihmandar,Minmandar', 36.8443200, 35.3439600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127683, 'Doğankavak', 'Dogankavak', 'Dogankavak,Doğankavak,Hadhatih,Hadhatıh,Hathatik,Khatkhatik', 37.9626500, 41.2267500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127684, 'Doğanhisar', 'Doganhisar', 'Doganhisar,Doğanhisar', 38.1463000, 31.6764800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127685, 'Doğanca', 'Doganca', 'Doganca,Dogandzha,Dogankoy,Doğanca,Doğanköy,Harhur,Kezi', 37.7995500, 42.3309900, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127686, 'Doğanbeyli', 'Doganbeyli', 'Doganbeyli,Doğanbeyli', 39.6951700, 39.0349900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127687, 'Doğanbey', 'Doganbey', 'Davgana,Doganbey,Doğanbey,Ipsile,Ipsıle', 37.8005000, 31.8911000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127688, 'Dodurga', 'Dodurga', 'Dodurga', 39.7997200, 29.9172200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127689, 'Diyarbakır', 'Diyarbakir', 'Amed,Amida,DIY,Diarbekir,Diarbekr,Diari-Bekir,Diari-Békir,Dijarbakir,Dijarbakira,Dijarbakiro,Dijarbakyr,Dijarbakyras,Dijarbakˌyr,Dijarbekir,Dikranakerd,Diyarbakir,Diyarbakır,Diyarbekir,Diyarbekır,Diyarbəkir,Diyaribakir,Diyaribekir,Diyarıbakır,Diyarıbekir,Gorad Dyjarbakyr,Ntigiarmpakir,di ya ba ke er,diarbakiri,diyaleubakileu,diyarubakuru,dyar bkr,dyarbkr,Ντιγιαρμπακίρ,Горад Дыярбакыр,Диарбекир,Диярбакыр,Диярбақыр,Дијарбакир,Дијарбекир,Діярбакир,Դիարբեքիր,דיארבקיר,ئامەد,ديار بكر,دیار بکر,دیاربکر,დიარბაქირი,ディヤルバクル,迪亚巴克尔,디야르바키르', 37.9136300, 40.2172100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127690, 'Diyadin', 'Diyadin', 'Didayin,Dijadin,Diyadin,Giyadin,Giyadîn,di ya ding,dyadyn,gyadyn,Диядин,دیادین,ضلع دیادن,گیادین,迪亞丁', 39.5405600, 43.6713500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127691, 'Divriği', 'Divrigi', 'Aphrike,Dewrige,Difrike,Divirgi,Divrigi,Divrik,Divriği,Divrık,Dêwrığe,Gorad Dyuryji,Tephrike,Tevrik,di fu li yi,dywryghy,dywryky,Горад Дыўрыйі,Дивриги,Տևրիկ,دیوریغی,دیوریکی,ضلع دیورگی,迪夫里伊', 39.3710000, 38.1137000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127692, 'Direkli', 'Direkli', 'Direkli', 39.7116700, 36.6516700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127693, 'Dinek', 'Dinek', 'Dinek', 37.3248100, 32.6160200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127694, 'Dinar', 'Dinar', 'Apamea Cibotus,Celaenae,Dinar,Dinar i Tyrkia,Dineir,Distretto di Dinar,Geyiklar,di na er,dynar,Динар,دینار,ضلع دینار,迪納爾', 38.0650000, 30.1655700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127695, 'Dilektepe', 'Dilektepe', 'Dilektepe,Minar,Zeligar', 38.0751700, 41.8271700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127696, 'Dikili', 'Dikili', 'Attalia,Dekeli,Dikeli,Dikili,di ji li,dykyly,Δεκελί,Дикили,Дікілі,دیکیلی,迪基利', 39.0710000, 26.8901700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127697, 'Dicle', 'Dicle', 'Dicle', 38.3657100, 40.0645000, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127698, 'Dicle', 'Dicle', 'Dicle,Kocapinar,Kocapınar,Omerin,Ömerin', 37.2886900, 42.0672100, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127699, 'Develi', 'Develi', 'Develi,Everek,Evrek', 38.3905600, 35.4922200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127700, 'Devecikonağı', 'Devecikonagi', 'Devecikonagi,Devecikonağı', 39.9148600, 28.5617600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127701, 'Derinkuyu', 'Derinkuyu', 'Derinkuyu,Melegobu,Melegubu,Melegöbü,Melegübü', 38.3751000, 34.7341900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127702, 'Derik', 'Derik', 'Derik', 37.3633600, 40.2647300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127703, 'Dereyanı', 'Dereyani', 'Dereyani,Dereyanı,Shuri,Suri,Şuri', 37.4274600, 40.8609600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127704, 'Turanlı', 'Turanli', 'Derekoy,Dereköy,Turanli,Turanlı', 39.2768200, 27.3246000, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127705, 'Derebucak', 'Derebucak', 'Derebucak', 37.3917900, 31.5091800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127706, 'Dere', 'Dere', 'Dere', 38.9829500, 39.3001700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127707, 'Derbent', 'Derbent', 'Derbent', 38.0142200, 32.0163900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127708, 'Denizli', 'Denizli', 'DNZ,Denisli,Denislu,Denislü,Denizli,Denizlis,Denizlu,Gorad Dehnizli,Ntenizli,dai ni zi li,deni s li,denijali,denijeulli,denizli,denizuri,dnyzly,Ντενιζλί,Горад Дэнізлі,Денизли,Денізлі,دنيزلي,دنیزلی,دەنیزلی,ڈینزلی,ਦੇਨਿਜਲੀ,เดนิซลี,დენიზლი,デニズリ,代尼茲利,데니즐리', 37.7741700, 29.0875000, 'TR', '2012-01-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127709, 'Demiryol', 'Demiryol', 'Demiryol,Til''merch,Tilmerc,Tilmere,Tilmerç,Til’merch', 37.9175100, 41.1498400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127710, 'Adala', 'Adala', 'Adala,Karatas,Karataş', 38.5775700, 28.2684700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127711, 'Demirci', 'Demirci', 'Demirci', 39.0460700, 28.6588900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127712, 'Deliktaş', 'Deliktas', 'Delihlitas,Delikta,Deliktas,Deliktaş', 39.3415700, 37.2037800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127713, 'Delice', 'Delice', 'Delice,Karabekir,Piran', 39.9537100, 34.0258700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127714, 'Deliçay', 'Delicay', 'Delicay,Deliçay,Kertis', 39.0816300, 43.4855200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127715, 'Değirmendere', 'Degirmendere', 'Degirmendere,Değirmendere', 38.1136100, 27.1413900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127716, 'Dedeli', 'Dedeli', 'Dedeli', 39.1743500, 43.0552400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127717, 'Dazkırı', 'Dazkiri', 'Daskiri,Daskırı,Dazkiri,Dazkırı,Polatli,Polatlı,Pulatli,Tazkiri,Tazkırı', 37.9186100, 29.8605600, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127718, 'Davutlar', 'Davutlar', 'Davutlar', 37.7339200, 27.2928300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127719, 'Davulga', 'Davulga', 'Davulga', 38.9791700, 31.3713900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127720, 'Datça', 'Datca', 'Datca,Datça,Resadiye,Reşadiye', 36.7377800, 27.6841700, 'TR', '2010-08-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127721, 'Darıkent', 'Darikent', 'Darikent,Darıkent', 38.9625200, 39.8079200, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127722, 'Dargeçit', 'Dargecit', 'Dargechit,Dargecit,Dargeçit,Deregecit,Deregeçit,Kerboran,Kerburan,Kerburun,Даргечит', 37.5461600, 41.7165200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127723, 'Darende', 'Darende', 'Darende,Yarpus,Даренде', 38.5458300, 37.5058300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127724, 'Danişment', 'Danisment', 'Danisment,Danişment', 39.8691700, 27.6330600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127725, 'Damlacık', 'Damlacik', 'Alut,Damlacik,Damlacık,Tavsi', 37.9142000, 38.6539200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127726, 'Dalyan', 'Dalyan', 'Dal''jan,Dalyan,Dalyankoy,Dalyanköy,Дальян', 36.8342900, 28.6446000, 'TR', '2015-04-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127727, 'Dallıbahçe', 'Dallibahce', 'Dallibahce,Dallıbahçe,Iresi,İresi', 39.1332100, 39.8792900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127728, 'Dalama', 'Dalama', 'Dalama', 37.7902800, 28.0663900, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127729, 'Dağyolu', 'Dagyolu', 'Dagyolu,Dağyolu,Seteri,Şeteri', 39.5384500, 39.9076500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127730, 'Dağlıca', 'Daglica', 'Daglica,Dağlıca', 37.3665800, 44.0852800, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127731, 'Dağkızılca', 'Dagkizilca', 'Dagkizilca,Dağkızılca', 38.3110000, 27.3908100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127732, 'Serhatta', 'Serhatta', 'Dagdosu,Dağdöşü,Serhata,Serhatta,Serkhatta', 37.6627800, 42.1406400, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127733, 'Dağ', 'Dag', 'Dag,Dagbeli,Dagkoy,Dağ,Dağbeli,Dağköy,Hafizbey,Hafızbey', 37.1930600, 30.5041700, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127734, 'Karahan', 'Karahan', 'Dagbasi,Dağbaşı,Karahan', 37.8982500, 39.3336600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127735, 'Dağardı', 'Dagardi', 'Dagardi,Dağardı,Gebeler', 39.4308000, 28.9955800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127736, 'Dadaşköy', 'Dadaskoy', 'Dadas,Dadaskent,Dadaskoy,Dadaş,Dadaşkent,Dadaşköy', 39.9448900, 41.2546500, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127737, 'Çüngüş', 'Cungus', 'Cunguc,Cungus,Cunkus,Cüngüç,Çüngüş,Çünküş', 38.2079800, 39.2855400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127738, 'Çumra', 'Cumra', 'Cumra,Çumra', 37.5732000, 32.7744600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127739, 'Menderes', 'Menderes', 'Cumaovasi,Cumaovası,Menderes,Мендерес', 38.2496300, 27.1342900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127740, 'Cumaçay', 'Cumacay', 'Cumacay,Cumaçay', 39.9152400, 43.1865300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127741, 'Akziyaret', 'Akziyaret', 'Akziyaret,Culmen,Cülmen,Gulmen,Gülmen', 37.3532800, 38.7960900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127742, 'Çukurca', 'Cukurca', 'Cal,Cokurca,Cukurca,Çal,Çokurca,Çukurca', 37.2480600, 43.6136100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127743, 'Özvatan', 'Ozvatan', 'Cukur,Ozvatan,Çukur,Özvatan', 39.1069000, 35.6999400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127744, 'Düvertepe', 'Duvertepe', 'Corum,Duvertepe,Düvertepe,Çorum', 39.2373400, 28.4400100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127745, 'Hakkari', 'Hakkari', 'Colemerik,Hakari,Hakkari,Hakâri,Julamerk,Khakkari,Çölemerik,Хаккари', 37.5744400, 43.7408300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127746, 'Çolaklı', 'Colakli', 'Colakli,Ispendere,Çolaklı,İspendere', 38.3335100, 38.5194600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127747, 'Çokak', 'Cokak', 'Cokak,Çokak', 37.7361300, 36.3286500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127748, 'Çobanlar', 'Cobanlar', 'Buyuk Cobanlar,Büyük Çobanlar,Cobanlar,Çobanlar', 38.7013900, 30.7827800, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127749, 'Cizre', 'Cizre', 'Beit Zabde,Bezabde,Cizre,Dzhizre,Jazirhe-a-ibn-a Omar,Jesiret ibn Omar,Jesıret ibn Omar,NKT,Джизре', 37.3302400, 42.1848400, 'TR', '2013-08-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127750, 'Çivril', 'Civril', 'Civril,Çivril', 38.3013900, 29.7386100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127751, 'Çırpı', 'Cirpi', 'Cirpi,Cirpikoy,Çırpı,Çırpıköy', 38.1644400, 27.4975000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127752, 'Çine', 'Cine', 'Cine,Hanakpinar,Hanakpınar,Çine', 37.6126600, 28.0591200, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127753, 'Çınaraltı', 'Cinaralti', 'Cinaralti,Rissin,Çınaraltı', 37.3849000, 40.8593800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127754, 'Çınar', 'Cinar', 'Cinar,Hanakpinar,Hanakpınar,Hankpinar,Hankpınar,Çınar', 37.7222600, 40.4069600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127755, 'Evren', 'Evren', 'Cikinagi,Evren,Çıkınağı', 39.0240200, 33.8062600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127756, 'Cihanbeyli', 'Cihanbeyli', 'Cihanbeyli,Inevi,İnevi', 38.6607200, 32.9243700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127757, 'Ashuta', 'Ashuta', 'Ashuta,Asuta,Asutka,Aşuta,Aşutka,Cigli,Çığlı', 37.3229000, 43.3748200, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127758, 'Serkan', 'Serkan', 'Cigir,Serkan,Çığır', 37.1587800, 41.7413200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127759, 'Çiğil', 'Cigil', 'Cigil,Çiğil', 37.4792300, 33.3180500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127760, 'Girikbedro', 'Girikbedro', 'Ciftlik,Ciftlikkoy,Ciftlikkoyu,Girikbedro,Çiftlik,Çiftlikköy,Çiftlikköyü', 37.1802800, 42.4211100, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127761, 'Çiftlik', 'Ciftlik', 'Ciftlik,Çiftlik', 39.7827600, 40.6348400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127762, 'Melikgazi', 'Melikgazi', '', 38.7500000, 35.4500000, 'TR', '2011-02-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127763, 'Çiftlik', 'Ciftlik', 'Ciftlik,Çiftlik', 38.1758000, 34.4853500, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127764, 'Çifteler', 'Cifteler', 'Cifteler,Cifteler Kasabasi,Çifteler,Çifteler Kasabası', 39.3830600, 31.0391700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127765, 'Çiftehan', 'Ciftehan', 'Ciftehan,Çiftehan', 37.5123300, 34.7695300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127766, 'Çiçekli', 'Cicekli', 'Cicekli,Çiçekli', 39.0546800, 39.4160400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127767, 'Çiçekdağı', 'Cicekdagi', 'Boyalik,Boyalık,Cicekdagi,Mecidiye,Çiçekdağı', 39.6069400, 34.4086100, 'TR', '2017-03-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127768, 'Ceylanpınar', 'Ceylanpinar', 'Ceylanpinar,Ceylanpınar,Cylanpinar,Dzheylanpynar,Raselain,Rass-el-Ain,Rass-el-Aïn,Resulayn,Resülayn', 36.8472200, 40.0500000, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127769, 'Ceyhan', 'Ceyhan', 'Ceyhan,Dzejkhan,Dzhejg''an,Dzhejkhan,Gorad Dzhehjkhan,Hamidiye,Jehan,Jeyhan,Zhejkhan,jeihan,jeihani,jie yi han,jyhan,Џејхан,Горад Джэйхан,Джейгьан,Джейхан,Жейхан,Ջեյհան,גייהאן,جيهان,جیحان,سیہان,ჯეიჰანი,ジェイハン,傑伊漢,제이한', 37.0247200, 35.8175000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127770, 'Çevrimova', 'Cevrimova', 'Barisil,Barsil,Barsyl,Barısıl,Cevrimova,Çevrimova', 37.8400300, 41.2728800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127771, 'Cevizlik', 'Cevizlik', 'Cevizlik', 38.1755400, 42.2260200, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127772, 'Cevizli', 'Cevizli', 'Cevizli,Gagras', 37.1969400, 31.7633300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127773, 'Çatalan', 'Catalan', 'Catalalan,Catalan,Catalani,Cevherli,Çatalalan,Çatalan,Çatalanı', 37.2485700, 35.2911000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127774, 'Çetinkaya', 'Cetinkaya', 'Cetinkaya,Kale,Çetinkaya', 39.2617800, 37.6260300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127775, 'Çeşme', 'Cesme', 'Cesme,Cheshme,Chesme,Chesnie,Cissus,Cıssus,Tsesme,cheshume,chshmh,qie shen mei,Çeşme,Τσεσμέ,Чешме,چشمه,チェシュメ,切什梅', 38.3261400, 26.3057400, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127776, 'Çermik', 'Cermik', 'Cemik,Cermik,Çemik,Çermik', 38.1353800, 39.4450000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127777, 'Cengerli', 'Cengerli', 'Cengerli,Emirgah,Emirgâh,Esirgah,Esirgâh,Esirkah,Çengerli', 39.7942600, 38.8481400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127778, 'Çemişgezek', 'Cemisgezek', 'Cemicgezek,Cemisgesek,Cemisgezek,Cemiskezek,Çemiçgezek,Çemişgesek,Çemişgezek,Çemişkezek', 39.0553900, 38.9075400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127779, 'Çeltikçi', 'Celtikci', 'Celtikci,Çeltikçi', 37.5294700, 30.4802800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127780, 'Çeltik', 'Celtik', 'Celtik,Çeltik', 39.0244400, 31.7905600, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127781, 'Çelikhan', 'Celikhan', 'Celikan,Celikhan,Çelikhan', 38.0256000, 38.2366500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127782, 'Çelebi', 'Celebi', 'Celebi,Çelebi', 39.4641800, 33.5241000, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127783, 'Celâlli', 'Celalli', 'Celali,Celalli,Celâlli', 39.6925000, 37.4238900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127784, 'Çaylı', 'Cayli', 'Cayli,Çaylı', 38.1533000, 28.1440600, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127785, 'Çaylarbaşı', 'Caylarbasi', 'Caylarbasi,Herheri,Çaylarbaşı', 37.7001000, 39.0096500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127786, 'Çaylar', 'Caylar', 'Caylar,Çaylar', 39.2673100, 41.2834400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127787, 'Mans', 'Mans', 'Cayirli,Mans,Çayırlı', 39.8077500, 40.0280000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127788, 'Çayıralan', 'Cayiralan', 'Akdag,Akdağ,Cayiralan,Cayirse,Cayirseyhi,Cayırşe,Çayıralan,Çayırşeyhi', 39.3027800, 35.6438900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127789, 'Çaybağı', 'Caybagi', 'Caybagi,Çaybağı', 38.6940100, 39.6202200, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127790, 'Çay', 'Cay', 'Cay,Kej,Çay,Кей', 38.5916700, 31.0286100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127791, 'Çavuşlu', 'Cavuslu', 'Cavuslu,Sarozbah,Saruzbah,Saruzbakh,Seruzbali,Soruzbah,Çavuşlu,Şeruzbalı', 37.5017900, 41.2487700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127792, 'Çavuş', 'Cavus', 'Cavus,Çavuş', 37.6096300, 31.9313500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127793, 'Çavdır', 'Cavdir', 'Cavdir,Çavdır', 37.1550000, 29.6938900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127794, 'Çavdarhisar', 'Cavdarhisar', 'Cavdarhisar,Çavdarhisar', 39.1934400, 29.6191500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127795, 'Çatalçam', 'Catalcam', 'Catalcam,Zevker,Çatalçam', 39.9743800, 38.8477700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127796, 'Çatalarmut', 'Catalarmut', 'Catalarmut,Catalcam,Çatalarmut,Çatalcam', 39.8028600, 39.3153900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127797, 'Malabadi', 'Malabadi', 'Catakkopru,Malabadi,Çatakköprü', 38.1516200, 41.2025600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127798, 'Çatak', 'Catak', 'Catak,Martanis,Satak,Sitak,Çatak,Şatak,Şitak', 38.0029300, 43.0524300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127799, 'Çat', 'Cat', 'Cat,Oyuklu,Uyuklu,Çat', 39.6064100, 40.9684400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127800, 'Çardak', 'Cardak', 'Cardak,Catak,Suleymanli,Süleymanlı,Çardak,Çatak', 38.0917100, 36.8235600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127801, 'Çardak', 'Cardak', 'Cardak,Cardakkoyu,DNZ,Çardak,Çardakköyü', 37.8269400, 29.6683300, 'TR', '2016-02-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127802, 'Çandır', 'Candir', 'Candir,Çandır', 39.2444600, 35.5139600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127803, 'Çandarlı', 'Candarli', 'Candarli,Chandarly,Sandarli,Çandarlı,Чандарлы', 38.9350300, 26.9340000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127804, 'Çan', 'Can', 'Can,Çan', 39.1483300, 40.2034800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127805, 'Çamlıyayla', 'Camliyayla', 'Camliyayla,Namrun,Yayla,Çamlıyayla', 37.1665200, 34.5929600, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127806, 'Çamlıdere', 'Camlidere', 'Camlidere,Chamlydere,Mecrihan,Medzhrikhan,Çamlıdere', 37.1544000, 39.0669700, 'TR', '2016-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127807, 'Anamas', 'Anamas', 'Yuruk,Yürük', 37.7666700, 30.8000000, 'TR', '2006-05-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127808, 'Çameli', 'Cameli', 'Cameli,Cumayani,Cumayanı,Karaman,Çameli', 37.0761100, 29.3447200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127809, 'Çamardı', 'Camardi', 'Camardi,Maden,Çamardı', 37.8322200, 34.9813900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127810, 'Çaltılıbük', 'Caltilibuk', 'Caltilibuk,Yenikoy,Yeniköy,Çaltılıbük', 39.9559000, 28.5991000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127811, 'Çalpınar', 'Calpinar', 'Calpinar,Siti,Çalpınar', 37.3654200, 41.1857600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127812, 'Çalışkan', 'Caliskan', 'Caliskan,Gitta,Gitte,Çalışkan', 37.2975100, 42.6422600, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127813, 'Çaldıran', 'Caldiran', 'Bayazitaga,Bayazıtağa,Caldiran,Çaldıran', 39.1431700, 43.9106800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127814, 'Çal', 'Cal', 'Cal,Demircikoy,Demirciköy,Çal', 38.0836100, 29.3988900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127815, 'Çakırlar', 'Cakirlar', 'Cakirlar,Çakırlar', 36.8714500, 30.5620800, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127816, 'Keysun', 'Keysun', 'Cakirhuyuk,Keysun,Çakırhüyük', 37.5607500, 37.8558300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127817, 'Çakırbeyli', 'Cakirbeyli', 'Cakirbeyli,Çakırbeyli', 37.7350100, 27.8238800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127818, 'Menteşe', 'Mentese', 'Cakallar,Mentese,Menteşe,Çakallar', 37.1166700, 28.2666700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127819, 'Çağlayancerit', 'Caglayancerit', 'Buyuk Cerbit,Buyuk Cerit,Büyük Cerbit,Büyük Cerit,Caglayancerit,Cagliyan Cerit,Çağlayancerit,Çağlıyan Çerit', 37.7452300, 37.2861800, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127820, 'Çağlayan', 'Caglayan', 'Caglayan,Çağlayan', 39.5850200, 39.6870200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127821, 'Çağlarca', 'Caglarca', 'Amutka,Caglarca,Peyik,Çağlarca', 39.0373200, 39.1386500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127822, 'Çağış', 'Cagis', 'Cagis,Çağış', 39.5188100, 28.0122400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127823, 'Dereova', 'Dereova', 'Buyukyurt,Büyükyurt,Dereova', 39.2504200, 39.8691600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127824, 'Nikfer', 'Nikfer', 'Buyukkonak,Büyükkonak,Konak,Nikfer', 37.4054200, 29.1372700, 'TR', '2012-04-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127825, 'Cinatamiho', 'Cinatamiho', 'Buyuk Kardes,Buyukkardes,Büyük Kardeş,Büyükkardeş,Cinatamaho,Cinatamiho,Dzhinatamakh', 37.2730400, 41.0336400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127826, 'Boğaziçi', 'Bogazici', 'Bogazici,Boğaziçi,Buyukkale,Büyükkale,Kadifeikebir,Kadıfeikebir', 38.0347200, 27.5594400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127827, 'Armutlu', 'Armutlu', 'Armutlu,Buyuk Armudan,Buyukarmutlu,Büyük Armudan,Büyükarmutlu', 39.5755000, 38.4272200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127828, 'Burhaniye', 'Burhaniye', 'Burhaniye,Kemer', 39.5004100, 26.9726900, 'TR', '2013-07-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127829, 'Buharkent', 'Buharkent', 'Buharkent,Burhaniye,Burhaniyekasabasi,Burhaniyekasabası,Cubukdag,Cubukdagi,Çubukdağ,Çubukdağı', 37.9639700, 28.7427000, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127830, 'Burdur', 'Burdur', 'Bourdour,Bourntour,Buldur,Burdur,Polydorion,ba er du er,brdwd,buleuduleu,burduri,burudo~uru,bwrdwr,Μπουρντούρ,Бурдур,بردود,بوردور,ბურდური,ブルドゥル,巴爾杜爾,부르두르', 37.7202800, 30.2908300, 'TR', '2012-01-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127831, 'Burç', 'Burc', 'Burc,Burç', 37.0136200, 37.1791300, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127832, 'Bünyan', 'Bunyan', 'Bunyan,Bunyan Hamit,Bünyan,Bünyan Hamit,Sarmisakli,Sarmısaklı', 38.8463000, 35.8603300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127833, 'Buldan', 'Buldan', 'Boldan,Buldan,bu er dan,bwldan,Булдан,بولدان,ضلع بلدن,布爾丹', 38.0450000, 28.8305600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127834, 'Bulanık', 'Bulanik', 'Bulanik,Bulanık', 39.0865600, 42.2715800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127835, 'Bucakkışla', 'Bucakkisla', 'Bucakkisla,Bucakkışla', 36.9544300, 33.0219600, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127836, 'Buca', 'Buca', 'Buca', 38.3983000, 27.1666200, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127837, 'Bucak', 'Bucak', 'Bucak,Budzhak,Буджак', 37.4591700, 30.5950000, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127838, 'Bozyazı', 'Bozyazi', 'Bozjazy,bo zi ya ze,bwzyazy,Бозязы,بوزیازی,ضلع بوزیازی,博茲亞澤', 36.1082000, 32.9611300, 'TR', '2008-04-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127839, 'Bozüyük', 'Bozuyuk', 'Bozoyuk,Bozujuk,Bozuyuk,Bozöyük,Bozüyük,bo ju yu ke,bwzwywk,Бозӱйӱк,بوزویوک,博聚于克', 39.9077800, 30.0366700, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127840, 'Boztepe', 'Boztepe', 'Boztepe,Boztepekoy,Boztepeköy', 39.2697200, 34.2611100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127841, 'Bozova', 'Bozova', 'Bozova,Hovenk,Huvek,Hövenk,Hüvek,Бозова', 37.3625000, 38.5266700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127842, 'Bozova', 'Bozova', 'Bozova,Zivint', 37.2161100, 30.2858300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127843, 'Bozoğlak', 'Bozoglak', 'Asagi Ihtik,Aşağı İhtik,Bozoglak,Bozoğlak,Ihtik,İhtik', 39.6229200, 38.8019400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127844, 'Bozkurt', 'Bozkurt', 'Bozkurt,Distretto di Bozkurt,Hamidiye,bwzkwrt  dnyzly,Бозкурт,بوزکورت، دنیزلی,ضلع بوزکرت', 37.8241700, 29.6097200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127845, 'Bozkır', 'Bozkir', 'Bozkir,Bozkır,Silistat,Sitistat', 37.1896300, 32.2473600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127846, 'Taliban', 'Taliban', 'Bozhuyuk,Bozhüyük,Taliban,Teliba Koyu,Teliba Köyü', 37.9810000, 41.4132800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127847, 'Bozdoğan', 'Bozdogan', 'Bozdogan,Bozdoğan', 37.6713400, 28.3139500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127848, 'Bozcaada', 'Bozcaada', 'Bogcaada,Bozca,Bozcaada,Bozdzhaada,Bozkada,Boğçaada,Castro,Distretto di Tenedo,Tenedo,Tenedos,Ténédos,bo zi gu dao,bwzgʼʼdh,tndws,Τένεδος,Бозджаада,Тенедос,בוזגאאדה,تندوس,ضلع بوزساڈا,博茲賈島', 39.8350000, 26.0697200, 'TR', '2016-12-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127849, 'Bozburun', 'Bozburun', 'Bozburun', 36.6949500, 28.0433600, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127850, 'Bozarmut', 'Bozarmut', 'Asagi Bozarmut,Aşağı Bozarmut,Bozarmut', 37.3091700, 28.1697200, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127851, 'Bozan', 'Bozan', 'Bozan', 39.7880600, 31.1016700, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127852, 'Bozalan', 'Bozalan', 'Bahmur,Bahnur,Behmur,Bekhmur,Bozalan', 37.3287400, 42.2636600, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127853, 'Bostancı', 'Bostanci', 'Bostanci,Bostancı,Rihani,Rihanı,Rikhani', 37.1777800, 42.3290600, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127854, 'Bornova', 'Bornova', 'Bornova,Bournovas,Burnova,Burnuva,Burunabat,Μπουρνόβας,Борнова', 38.4792100, 27.2399000, 'TR', '2015-01-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127855, 'Borlu', 'Borlu', 'Borlu', 38.7529100, 28.4674400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127856, 'Bor', 'Bor', 'Bor,Bor i Nigde,Bor i Niğde,Distretto di Bor,bo er,bwr,Бор,بور,بور، نیغدے,博爾', 37.8905600, 34.5588900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127857, 'Bolvadin', 'Bolvadin', 'Bolvadin', 38.7111100, 31.0486100, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127858, 'Simek', 'Simek', 'Bolukyazi,Bölükyazı,Hivris,Simek', 38.3274800, 42.1744800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127859, 'Bölme', 'Bolme', 'Bolme,Bölme', 38.6207600, 29.3737300, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127860, 'Böğürtlen', 'Bogurtlen', 'Bogurtlen,Böğürtlen', 37.1663200, 38.0811000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127861, 'Boğazören', 'Bogazoren', 'Bogazoren,Boğazören,Gelgetir,Kel''ketir,Kel’ketir,Kitir,Kıtır', 37.5277500, 43.0077800, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127862, 'Boğazlıyan', 'Bogazliyan', 'Bogazliyan,Boğazlıyan', 39.1887700, 35.2453700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127863, 'Boğazkent', 'Bogazkent', 'Bogazakent,Boğazakent,Bugazak,Buğazak', 36.8531900, 31.1638800, 'TR', '2013-11-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127864, 'Bodrum', 'Bodrum', 'Alikarnassos,BXN,Bodrum,Bodurum,Budrum,Halicarnassus,Halikarnassos,Petronium,bo de lu mu,bodeulum,bodorumu,bodrumi,bwdrwm,Αλικαρνασσός,Бодрум,בודרום,بودروم,ضلع بوڈرم,ბოდრუმი,ボドルム,博德鲁姆,보드룸', 37.0383300, 27.4291700, 'TR', '2016-12-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127865, 'Bitlis', 'Bitlis', 'Bages,Bidlis,Bidlîs,Bitlis,Bitliss,Bıdlis,bdlys,bi te li si,bi tlis,biteulliseu,bitlisi,bitorisu,blts,btlys,Битлис,Биҭлис,Бітліс,Բաղեշ,بتلیس,بدليس,بدلیس,بلتس,บิตลิส,ბითლისი,ビトリス,比特利斯,비틀리스', 38.4011500, 42.1078400, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127866, 'Bismil', 'Bismil', 'Bismil', 37.8451400, 40.6593100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127867, 'Birgi', 'Birgi', 'Balat,Birgi', 38.2502800, 28.0591700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127868, 'Birecik', 'Birecik', 'Apamea,Birecik,Biredzhik,Birejik,Birijik,Биреджик', 37.0257700, 37.9784100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127869, 'Bingöl', 'Bingol', 'BGG,Badlis,Bingol,Bingöl,Capakcur,Cevlik,Çapakçur,Çevlik,Бингол', 38.8847200, 40.4938900, 'TR', '2012-09-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127870, 'Binatlı', 'Binatli', 'Bileyder,Binatli,Binatlı', 37.8470800, 41.2160800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127871, 'Bigadiç', 'Bigadic', 'Bigadic,Bigadiç', 39.3925000, 28.1311100, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127872, 'Beytüşşebap', 'Beytussebap', 'Beyt-Esh-Shebab,Beytisebab,Beytisebap,Beytişebab,Beytusebap,Beytussebab,Beytussebap,Beytüşebap,Beytüşşebab,Beytüşşebap,El''ki,Elki,El’ki', 37.5631800, 43.1658300, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127873, 'Beyşehir', 'Beysehir', 'Bejshekhir,Beysehir,Beyşehir,bkshhry,Бейшехир,بکشهری', 37.6773500, 31.7245800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127874, 'Beypınarı', 'Beypinari', 'Beypinar,Beypinari,Beypınar,Beypınarı', 39.5064000, 37.7069000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127875, 'Beylikova', 'Beylikova', 'Beylikahir,Beylikahır,Beylikova', 39.6869400, 31.2055600, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127876, 'Beyçayırı', 'Beycayiri', 'Beycayiri,Beyçayırı', 38.0141200, 41.3237200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127877, 'Beyağaç', 'Beyagac', 'Beyagac,Beyağaç', 37.2352600, 28.8961200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127878, 'Kızılin', 'Kizilin', 'Besyol,Beşyol,Kizilin,Kızılin,Sahandil,Sahantil,Sihantil', 37.5469300, 38.0759500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127879, 'Beşpınar', 'Bespinar', 'Alenz,Arans,Aranz,Baspinar,Başpınar,Beshpynar,Bespinar,Beşpınar,Jukary-Lori,Ridvan,Rıdvan,Юкары-Лори', 37.8370900, 41.6021900, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127880, 'Besni', 'Besni', 'Bahisni,Behesni,Behisni,Besni,Bêsni,Bêsnî,bei si ni,bsny,Бесни,بسنی,بێسنی,ضلع بسنی,貝斯尼', 37.6927800, 37.8611100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127881, 'Beşkonak', 'Beskonak', 'Beskonak,Beşkonak,Yaris,Yaris Mahalle,Yarış,Yarış Mahalle', 37.1444400, 31.1991700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127882, 'Beşiri', 'Besiri', 'Beshirin,Besiri,Beşiri,Kabin,Kobin', 37.9157300, 41.2865000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127883, 'Bergama', 'Bergama', 'Bergama,Pergam,Pergame,Pergamo,Pergamon,Pergamos,Pergamum,Pérgamo,bie jia mo,brgama,pa jia ma,perugamon,prgamwn,prgmwn,Пергам,פרגמון,برگاما,پرگامون,ペルガモン,別迦摩,帕加马', 39.1207400, 27.1805200, 'TR', '2012-12-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127884, 'Belören', 'Beloren', 'Beloren,Belveren,Belören', 37.6372300, 37.5803000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127885, 'Belören', 'Beloren', 'Beloren,Belviran,Belören,Sarioglan,Sarioglanboyalisi,Sarıoğlan,Sarıoğlanboyalısı', 37.2148000, 32.5536300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127886, 'Belevi', 'Belevi', 'Belevi', 38.0150000, 27.4502800, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127887, 'Belen', 'Belen', 'Beilan,Belen,Beylan,Bilan,Белен', 36.4886600, 36.1948900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127888, 'Demirtaş', 'Demirtas', 'Belen,Belenkoy,Belenköy,Demirtas,Demirtaş', 36.4261100, 32.1925000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127889, 'Belek', 'Belek', 'Belek,Belekoy,Beleköy,Besyigit,Beşyiğit,Белек', 36.8627800, 31.0555600, 'TR', '2014-07-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127890, 'Bekirhan', 'Bekirhan', 'Bekirhan,Kanihani,Kânihani,Selmo,Şelmo', 38.1408600, 41.2935100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127891, 'Bekilli', 'Bekilli', 'Bekilli', 38.2310500, 29.4197000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127892, 'Behram', 'Behram', 'Assos,Bayram,Behram,Behramkale,Bekhramkale,Бехрамкале', 39.4934400, 26.3331600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127893, 'Beğendik', 'Begendik', 'Begendik,Beğendik,Bidar', 37.9755700, 42.6482300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127894, 'Bucak', 'Bucak', 'Begdes,Beğdeş,Bucak,Fak,Fek', 37.8693000, 39.0619900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127895, 'Bedirli', 'Bedirli', 'Bedirli', 39.5827600, 36.6204900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127896, 'Bayramiç', 'Bayramic', 'Bairamich,Bayramic,Bayramiç,Scepsis,Scepsıs', 39.8086200, 26.6098300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127897, 'Bayraklı', 'Bayrakli', 'Bayatika,Bayrakli,Bayraklı,Hadja Mucha', 38.4671700, 27.1638400, 'TR', '2015-11-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127898, 'Baykan', 'Baykan', 'Baykan,Havil,Havilhanlari,Havilhanları,Hovil,Huvil', 38.1575400, 41.7733000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127899, 'Bayır', 'Bayir', 'Bayir,Bayirkoy,Bayır,Bayırköy', 37.2677400, 28.2167700, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127900, 'Bayındır', 'Bayindir', 'Baindir,Bajindyr,Bayindir,Bayındır,Байиндыр', 38.2174100, 27.6474400, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127901, 'Bayat', 'Bayat', 'Bajat,Bayat,Hambarcin,Hambarçin,Баят,بایات، افیون قرہ حصار,ضلع بایات', 38.9830600, 30.9247200, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127902, 'Batman', 'Batman', 'BAL,Batman,Batman i Tyrkia,Batmanas,Elih,Gorad Batman,Iloh,Iluh,ba te man,bateuman,batman,batman  trky,batmani,batoman,btman,btmn,Êlih,Μπατμάν,Батман,Баҭман,Горад Батман,בטמן,ئێلح,باتمان,باتمان، ترکی,بطمان,ضلع باتمان,ბათმანი,バトマン,巴特曼,바트만', 37.8873800, 41.1322100, 'TR', '2014-02-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127903, 'Başyurt', 'Basyurt', 'Basyurt,Başyurt', 38.8350500, 39.9792900, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127904, 'Başpınar', 'Baspinar', 'Baspinar,Basvartanik,Basvartenik,Basvartinik,Başpınar,Başvartanik,Başvartenik,Başvartinik', 39.1901700, 38.6873700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127905, 'Başmakçı', 'Basmakci', 'Basmakci,Başmakçı', 37.8972200, 30.0116700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127906, 'Baskil', 'Baskil', 'Baskil', 38.5686600, 38.8163400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127907, 'Başkavak', 'Baskavak', 'Ahmedi,Akhmedi,Baskavak,Başkavak', 37.5646800, 40.8875700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127908, 'Başkale', 'Baskale', 'Bash Kaleh,Bashkala,Baskale,Başkale', 38.0452600, 44.0171800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127909, 'Yoğun', 'Yogun', 'Alos,Basari,Başarı,Yogun,Yoğun', 38.0990600, 39.5132100, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127910, 'Barla', 'Barla', 'Barla', 38.0177800, 30.7827800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127911, 'Barıştepe', 'Baristepe', 'Baristepe,Barıştepe,Salhi,Salkhi', 37.4832000, 41.4025100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127912, 'Banaz', 'Banaz', 'Banaz,Islamkoy,İslamköy', 38.7370700, 29.7519400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127913, 'Balya', 'Balya', 'Baliy,Balya', 39.7486100, 27.5788900, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127914, 'Balpınar', 'Balpinar', 'Balpinar,Balpınar,Giresiran,Girisiran,Gresiran,Kersivan', 37.8680400, 41.0553600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127915, 'Balpayam', 'Balpayam', 'Balbayam,Balpayam', 39.4200600, 40.0571300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127916, 'Balışeyh', 'Baliseyh', 'Balisey,Baliseyh,Balisih,Balisoh,Balli,Ballı,Balışey,Balışeyh,Balışoh,Balışıh', 39.9141100, 33.7233300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127917, 'Balıkesir', 'Balikesir', 'Achyraus,Adrianoutherai,Adrianouthērai,BZI,Bali-Kessir,Balikesir,Balikesira,Balikesr,Balikesri,Balikesyras,Balukesir,Balukisu,Balykesir,Balıkesir,Belikesir,Belikiser,Gorad Balykesir,Hadrianutherae,Karassi,ba lei ke ai xi er,balikesiri,baliq asyr,ballikesileu,balyksyr,barukesu~iru,Μπαλικεσίρ,Баликесир,Баликесір,Балъкесир,Балыкесир,Балықесир,Горад Балыкесір,بالِق أسير,بالیکسیر,ბალიქესირი,バルケスィル,巴勒克埃西爾,발리케시르', 39.6491700, 27.8861100, 'TR', '2017-01-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127918, 'Balcı', 'Balci', 'Balci,Balcı', 38.7253200, 34.1012300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127919, 'Balaban', 'Balaban', 'Balaban,Germiter', 38.4610600, 37.5788100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127920, 'Bala', 'Bala', 'Bala', 39.5542200, 33.1234400, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127921, 'Baklan', 'Baklan', 'Baklan,Dedekoy,Dedeköy', 37.9769400, 29.6086100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127922, 'Bahşılı', 'Bahsili', 'Bahsili,Bahşili,Bahşılı', 39.8001700, 33.4370100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127923, 'Bahçesaray', 'Bahcesaray', 'Bahcesara,Bahcesaray,Bahçesaray,Muks,Mukus,Müküs', 38.1246000, 42.7982500, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127924, 'Bahçe', 'Bahce', 'Bahce,Bahçe,Bulanik,Bulanikbahce,Bulanık,Bulanıkbahçe', 37.1972400, 36.5765800, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127925, 'Bağpınar', 'Bagpinar', 'Bagpinar,Bağpınar,Calgan,Çalgan', 37.5913900, 38.3191000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127926, 'Bağlıca', 'Baglica', 'Bagladzha,Baglica,Bağlıca,Huseyni,Hüseyni,Sihiyam,Sihiyan,Sihyan,Sikh''yan,Sikh’yan,Sıhıyan', 37.8697400, 41.7511000, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127927, 'Bağlıca', 'Baglica', 'Baglica,Bağlıca,Bennisht,Bennist,Bennişt,Bernist,Bernişt', 37.5270500, 40.6861800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127928, 'Bağlıca', 'Baglica', 'Baglica,Bağlıca,Inceler,Kadinuk,Kadinyuk,Kadinük,Kadun,Ziravik,İnceler', 37.4333300, 42.7741700, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127929, 'Bağkonak', 'Bagkonak', 'Bagkonak,Bağkonak,Orkenez,Örkenez', 38.2175000, 31.2722200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127930, 'Hazekyan', 'Hazekyan', 'Bagisli,Bağışlı,Hanekiyan,Hazekyan,Sivelan,Şivelân', 37.7176900, 44.0356000, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127931, 'Lodi', 'Lodi', 'Ayni,Aynı,Baggoze,Bağgöze,Lodi', 37.7126100, 41.9154000, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127932, 'Bağdere', 'Bagdere', 'Bagdere,Basnik,Bağdere,Başnik', 38.1144200, 40.7338200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127933, 'Bağarası', 'Bagarasi', 'Bagarasi,Bağarası', 37.7071000, 27.5487500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127934, 'Bademli', 'Bademli', 'Bademiye,Bademiyekasabasi,Bademiyekasabası,Bademli,Bademya', 38.0816700, 28.0577800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127935, 'Babatorun', 'Babatorun', 'Babatorun', 36.0774300, 36.2905100, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127936, 'Babadağ', 'Babadag', 'Babadag,Babadağ,Kadikoy,Kadıköy', 37.8076400, 28.8566500, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127937, 'Ayvalık', 'Ayvalik', 'Aivali,Ajvalyk,Ayvalik,Ayvalık,Cisthene,Kydoniai,aywalq,Айвалык,ایوالق', 39.3190500, 26.6954000, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127938, 'Ayvacık', 'Ayvacik', 'Ayvacik,Ayvacık', 39.6011100, 26.4047200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127939, 'Ayrancı', 'Ayranci', 'Ayranci,Ayranciderbent,Ayrancı,Ayrancıderbent,Osmaniye', 37.3612700, 33.6883000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127940, 'Tillo', 'Tillo', 'Aydinlar,Aydınlar,Tillo', 37.9491100, 42.0121000, 'TR', '2014-02-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127941, 'Aydınkonak', 'Aydinkonak', 'Aydinkonak,Aydınkonak,Keryuk,Korik,Koruk,Korukkoy,Këryuk,Körük,Körükköy', 37.8946100, 41.1640500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127942, 'İbradı', 'Ibradi', 'Aydinkent,Aydınkent,Ibradi,İbradı', 37.0969400, 31.5991700, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127943, 'Aydıncık', 'Aydincik', 'Ajdyndzhyk,Aydincik,Aydincik i Mersin,Aydinisik,Aydıncık,Aydıncık i Mersin,Aydınışık,Gilindire,a yi deng zhe ke,Айдынджык,آیدین‌جیک,ضلع ائیدنجک,阿伊登哲克', 36.1437000, 33.3201600, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127944, 'Aydın', 'Aydin', 'Aidin,Aidinas,Aidinio,Aidinion,Ajdin,Ajdun,Ajdyn,Ajdın,Aydin,Aydın,Aïdin,Aïdínion,CII,Gorad Ajdyn,Guesel Hissar,Guezel Hissar,Guezelhisar,Güsel Hissar,Güzel Hissar,Güzelhisar,Tralleis,Tralles,Tralli,ai deng,aidin,aidina,aidini,aido~un,aydyn,aywdn,Αϊδίνιο,Айдин,Айдън,Айдын,Ајдин,Горад Айдын,آیدین,أيدين,ایودن,ਐਦਿਨ,აიდინი,アイドゥン,艾登,아이딘', 37.8450100, 27.8396300, 'TR', '2012-09-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127945, 'Avsallar', 'Avsallar', 'Avsallar,Авсаллар', 36.6244800, 31.7694100, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127946, 'Avanos', 'Avanos', 'Avanos', 38.7150000, 34.8466700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127947, 'Atça', 'Atca', '', 37.8885900, 28.2152800, 'TR', '2015-04-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127948, 'Atburgazı', 'Atburgazi', 'Atburgaz,Atburgaz Koyu,Atburgaz Köyü,Atburgazi,Atburgazı', 37.6363900, 27.2461100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127949, 'Atabey', 'Atabey', 'Agros,Argos,Atabey,Ağros', 37.9508300, 30.6386100, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127950, 'Aslanapa', 'Aslanapa', 'Arslanapa,Aslanapa', 39.2158100, 29.8699000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127951, 'Aşkale', 'Askale', '', 39.9208300, 40.6950000, 'TR', '2006-01-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127952, 'Aşkale', 'Askale', 'Askale,Aşkale', 39.9171900, 40.6848200, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127953, 'Aşağıpınarbaşı', 'Asagipinarbasi', 'Asagi Pinarbas,Asagipinarbasi,Aşağı Pınarbaş,Aşağıpınarbaşı,Tomek,Tömek', 38.0383300, 32.6008300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127954, 'Kale', 'Kale', 'Asagi Mestikan,Aşağı Mestikân,Kale,Mestikan,Mestikân', 38.4153800, 38.7709200, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127955, 'Aşağıçiğil', 'Asagicigil', 'Asagicigil,Asagicigli,Aşağıçiğil,Aşağıçiğli', 38.0515000, 31.8637900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127956, 'Aşağı Beğdeş', 'Asagi Begdes', 'Asagi Begdes,Asagi Telfidan,Ashagy-Tel''fidan,Ashagy-Tel’fidan,Aşağı Beğdeş,Aşağı Telfidan', 36.8147200, 38.9191700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127957, 'Arslanköy', 'Arslankoy', 'Arslankoy,Arslanköy', 37.0188400, 34.2874100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127958, 'Danişment', 'Danisment', 'Arikbasi,Arıkbaşı,Birestik,Danisment,Danişment', 39.1715300, 38.1985100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127959, 'Arıcak', 'Aricak', 'Aricak,Arıcak,Karabegan,Karabeğan,Karabogan,Karaboğan,Mirivan,Mirvan', 38.5634000, 40.1248000, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127960, 'Arguvan', 'Arguvan', 'Argavan,Arguvan,Tahir', 38.7737500, 38.2632800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127961, 'Argıthanı', 'Argithani', 'Argithan,Argithani,Argıthan,Argıthanı', 38.2925900, 31.7145200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127962, 'Aras', 'Aras', 'Aras,Velibaba', 39.9882100, 42.3062800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127963, 'Yüreğir', 'Yuregir', 'Juregir,Jureguir,Yuregir,Yüreğir,Йӱрегир,Юрегир,Юрегъир,ضلع یوریگر', 36.9743900, 35.3591600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127964, 'Arapgir', 'Arapgir', 'Arabacis,Arabkir,Arapgir,Arapkir,عربکر,عربکیر', 39.0411700, 38.4951600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127965, 'Aran', 'Aran', 'Aran,Zoni', 37.4476800, 40.7475500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127966, 'Aralık', 'Aralik', 'Aralik,Aralık,Baskoy,Başköy', 39.8727800, 44.5191700, 'TR', '2016-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127967, 'Aralık', 'Aralik', 'Aralik,Aralyk,Aralık,Tezekli,Аралык', 37.8294500, 40.6802500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127968, 'Araban', 'Araban', 'Altintas,Altıntaş,Araban', 37.4266700, 37.6890000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127969, 'Yeşilyurt', 'Yesilyurt', 'Arabacimusa,Arabacımusa,Yesilyurt,Yeşilyurt', 40.0064000, 36.2206900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127970, 'Antalya', 'Antalya', 'AYT,Adalia,Antal''ja,Antalia,Antalija,Antaliya,Antaliyah,Antalja,Antalya,Antayla,Antália,Atali,Attalea,Attaleia,Attalia,Gorad Antal''ja,Olbia,Satalia,an ta li ya,antalia,antallia,antalya,antaruya,yantalya,Αττάλεια,Анталия,Анталија,Анталья,Анҭалиа,Горад Анталья,Անթալիա,אנטליה,آنتالیا,أنطاليا,ئانتالیا,انطالیہ,अंताल्या,ანთალია,アンタルヤ,安塔利亚,安塔利亞,안탈리아', 36.9081200, 30.6955600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127971, 'Antakya', 'Antakya', 'Antak''ja,Antakija,Antakiya,Antakiyah,Antakiyyah,Antakya,Antioch,Antioche,Antiocheia,Antiochia,Antiochia am Orontes,Antiochia di Siria,Antiochia vid Orontes,Antiochie,Antiochië,Antiohija,Antiokheia,Antiokhija,Antiokia,Antioquia,Antioquía,Antākiyyah,Antıoch,Anţākiyah,Hatay,an tiao ke,antakyt,antiokeia,ntakyt,Αντιόχεια,Антакия,Антакья,Антиохия,Антиохија,אנטיוכיה,أنطاكية,نتاكيّة,アンティオケイア,安条克', 36.2065500, 36.1572200, 'TR', '2014-08-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127972, 'Ankara', 'Ankara', 'ANK,Anakara,Ancara,Ancyra,Ang-ka-la,Angkara,Angora,Anguriyah,Ankar,Ankara,Ankara khot,Ankaro,Ankuara,Ankura,Ankyra,Ankyra (Ankyra),Anqara,Enguri,Engüri,Enqere,Gorad Ankara,akara,an ka la,angkala,ankara,anqrh,anqrt,xangkara,Ăng-kā-lá,Άγκυρα (Ankyra),Анкара,Анкара хот,Анкъара,Горад Анкара,Әнкара,Անկարա,אנקארא,אנקרה,آنکارا,أنقرة,ئەنقەرە,انقره,انقرہ,انکرہ,ܐܢܩܪܐ,अंकारा,আঙ্কারা,ਅੰਕਾਰਾ,ଆଙ୍କାରା,அங்காரா,అంకారా,ಅಂಕಾರಾ,അങ്കാറ,อังการา,ཨན་ཁ་ར།,ანკარა,አንካራ,アンカラ,安卡拉,앙카라', 39.9198700, 32.8542700, 'TR', '2013-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127973, 'Andırın', 'Andirin', 'Andiran,Andirin,Andıran,Andırın', 37.5775700, 36.3549200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127974, 'Andaç', 'Andac', 'Alaman,Alamon,Alamun,Andac,Andaç,Cigli,Zap,Çığlı', 37.3550000, 43.2639500, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127975, 'Anamur', 'Anamur', 'Anamur,Anemur,Anemurium,a na mu er,anamwr,Анамур,آنامور,أنامور,ضلع انامور,阿納穆爾', 36.0750800, 32.8369100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127976, 'Ambar', 'Ambar', 'Ambar,Anbar,Anbar Koyu,Anbar Köyü,Anbarci,Anbarcı', 37.8530500, 40.5279800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127977, 'Altınyayla', 'Altinyayla', 'Altinyayla,Altınyayla,Tonus', 39.2724900, 36.7509800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127978, 'Altınyayla', 'Altinyayla', 'Altinyayla,Altınyayla,Dinmil,Dirmil', 36.9972200, 29.5457900, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127979, 'Altınyaka', 'Altinyaka', 'Altinyaka,Altınyaka,Godene,Gödene', 36.5586100, 30.3483300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127980, 'Altıntaş', 'Altintas', 'Altintas,Altıntaş,Kurt Koyu,Kurtkoy,Kurtköy,Kürt Köyü', 39.0597200, 30.1091700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127981, 'Altınözü', 'Altinoezue', 'Altinoezue,Altınözü,Fatikli', 36.1124400, 36.2448800, 'TR', '2016-01-31', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127982, 'Altınova', 'Altinova', 'Altinova,Altunova,Altınova,Ayazina,Ayazma,Ayazmand,Ayazmant,Ayazmend,Ayazment,Ayazına,ayazmnd,ایازمند', 39.2173000, 26.7900800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127983, 'Altınoluk', 'Altinoluk', 'Altinoluk,Altunoluk,Altınoluk,Cambahce Papazlik,Papazli,Papazlik,Papazlı,Papazlık,Çambahçe Papazlik', 39.5794400, 26.7372200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127984, 'Altınkum', 'Altinkum', 'Altinkum,Altınkum', 38.2637400, 41.0625000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127985, 'Altunhisar', 'Altunhisar', 'Altinhisar,Altunhisar,Altınhisar,Andugu,Anduğu,Ortakoey,Ortaköy,andwghy,اندوغی', 37.9915900, 34.3733400, 'TR', '2013-07-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127986, 'Altınekin', 'Altinekin', 'Altinekin,Altınekin,Zivarik,Zıvarık', 38.3077800, 32.8686100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127987, 'Alpu', 'Alpu', 'Alpikoy,Alpu,Alpıköy', 39.7690300, 30.9606000, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127988, 'Alpköy', 'Alpkoy', 'Alpkoy,Alpköy', 39.6139300, 39.1863900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127989, 'Aliağa', 'Aliaga', 'Aliaga,Aliagaciftligi,Aliağa,Aliağaçiftliği,Алиага', 38.7997500, 26.9720300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127990, 'Gerger', 'Gerger', 'Aldus,Alduş,Gerger', 38.0280700, 39.0341800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127991, 'Albayrak', 'Albayrak', 'Albayrak,Der,Serelbak,Sikefti,Zapbasi,Zapbaşı,Şikefti', 38.1425200, 44.2012000, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127992, 'Alaşehir', 'Alasehir', 'Ala Shehr,Alachehir,Alachehr,Alaschehir,Alasechiras,Alasehir,Alashehir,Alashekhir,Alaşehir,Alašechiras,Alesehir,Aleşehir,Filadelfeia,Philadelphia,a la xie xi er,alashhr,arashehiru,Φιλαδέλφεια,Алашехир,Алашехір,آلاشهر,ضلع الاشہر,アラシェヒル,阿拉谢希尔', 38.3508300, 28.5171800, 'TR', '2014-01-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127993, 'Alanya', 'Alanya', 'Alaia,Alaiye,Alan''ja,Alana,Alanija,Alanja,Alanya,Alaya,Alâiye,Coracesium,a la ni ya,alania,alanya,allania,aran''ya,Алания,Аланья,Аланія,Алања,אלניה,آلانیا,ألانيا,الانیا,ალანია,アランヤ,阿拉尼亚,알라니아', 36.5437500, 31.9998200, 'TR', '2014-07-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127994, 'Alakamış', 'Alakamis', 'Alakamis,Alakamysh,Alakamış', 37.1589800, 41.7891500, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127995, 'Alaçatı', 'Alacati', 'Alacati,Alachati,Alaçatı,Latzata,Алачати', 38.2824600, 26.3745900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127996, 'Turluk', 'Turluk', 'Alacakaya,Turluk', 39.4403400, 39.8777300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127997, 'Alacahan', 'Alacahan', 'Alacahan', 39.1066700, 37.5755600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127998, 'Aktuzla', 'Aktuzla', 'Aktuzla,Aktuzlamemlahasi,Aktuzlamemlahası,Aktuzlamemlehasi,Aktuzlamemlehası,Bayaztuzla', 39.3301200, 42.2853300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(127999, 'Aktepe', 'Aktepe', 'Aktepe,Guvenc,Güvenç', 36.7016100, 36.4853500, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128000, 'Aksu', 'Aksu', 'Aksu,Аксу', 37.7988900, 31.0711100, 'TR', '2012-12-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128001, 'Aksu', 'Aksu', 'Aksu,Macun', 36.9538900, 30.8477800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128002, 'Akseki', 'Akseki', 'Akseki,Aksiki', 37.0486100, 31.7900000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128003, 'Akşehir', 'Aksehir', 'Ak Shehr,Aksehir,Akşehir,Philomelium', 38.3575000, 31.4163900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128004, 'Aksaray', 'Aksaray', 'Aksarai,Aksaraj,Aksarajus,Aksaray,Akusaraj,Aqserayiye,Gorad Aksaraj,a ke sa lai,agsalai,akasara''e,aksarai,akusarai,aq sray,Ακσαράι,Аксарай,Аксарај,Акъсарай,Ақсарай,Горад Аксарай,آق سراي,آق‌سرای,آکسرے,ਅਕਸਾਰਾਏ,აქსარაი,アクサライ,阿克萨赖,악사라이', 38.3725500, 34.0253700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128005, 'Akşar', 'Aksar', 'Aksar,Akşar,Hakif,Siris,Siriz,Şiris,Şiriz', 38.1000000, 42.5333300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128006, 'Akpınar', 'Akpinar', 'Akpinar,Akpınar,Turkakpinar,Türkakpınar', 39.4500500, 33.9648400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128007, 'Akpınar', 'Akpinar', 'Akpinar,Akpınar', 37.5738900, 38.2207700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128008, 'Akören', 'Akoren', 'Akoren,Akviran,Akören', 37.4534500, 32.3707000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128009, 'Akköy', 'Akkoy', 'Akkoy,Akköy', 37.9569400, 29.0781300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128010, 'Akköy', 'Akkoy', 'Akkoy,Akköy', 37.4913900, 27.2694400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128011, 'Akkışla', 'Akkisla', 'Akkisla,Akkışla', 39.0022200, 36.1738100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128012, 'Akkent', 'Akkent', 'Akkent', 38.1526800, 29.3789000, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128013, 'Akıncılar', 'Akincilar', 'Akincilar,Akıncılar,Tokaris,Tokariz', 37.7644400, 38.8230800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128014, 'Akıncı', 'Akinci', 'Akinci,Akyndzhi,Akıncı,Kasir,Kasır', 37.1664300, 40.8470600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128015, 'Akhisar', 'Akhisar', 'Ak Hisar,Akchisaras,Akhisar,Akhissar,Akkhisar,Aq Hisar,Axari,Azarion,Gorad Akkhisar,Thyatira,a ke xi sa er,akeuhisaleu,akysar,Акхисар,Горад Акхісар,آق‌حصار,آکیسار,阿克希薩爾,아크히사르', 38.9185200, 27.8400600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128016, 'Akdere', 'Akdere', 'Akdere,Akdereisikli,Akdereışıklı', 36.2408300, 33.7504100, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128017, 'Akdağmadeni', 'Akdagmadeni', 'Adagmadeni,Adağmadenı,Akdagmadeni,Akdağmadeni', 39.6602800, 35.8836100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128018, 'Akçay', 'Akcay', 'Akcay,Akçay,Kas Ciftligikoy,Kasciftligi,Kaş Çiftliğiköy,Kaşçiftliği', 36.6021700, 29.7462600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128019, 'Akçapınar', 'Akcapinar', 'Akcapinar,Akçapınar,Vaskovan', 38.9472800, 38.9423000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128020, 'Akçaova', 'Akcaova', 'Akcaova,Akçaova', 37.5027800, 28.0266700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128021, 'Akçakent', 'Akcakent', 'Akcakent,Akçakent', 39.6227800, 34.0958300, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128022, 'Akçakale', 'Akcakale', 'Akcakale,Akcekale,Akchakale,Akçakale,Heniye Gezalan,Hêniyê Ğezalan,Kaniya Xezalan,a ke qia ka lai,akuchakare,Акчакале,آقچه‌قلعه,أقجة قلعة,اکچاکالے,کانیی غەزاڵان,アクチャカレ,阿克恰卡萊', 36.7111100, 38.9475000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128023, 'Akçadağ', 'Akcadag', 'Akcadag,Akçadağ,Arga', 38.3389900, 37.9702100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128024, 'Akarsu', 'Akarsu', 'Akarsu,Alakilise', 39.9287800, 38.6138200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128025, 'Akarsu', 'Akarsu', 'Akarsu,Istilil,İstilil', 37.2261600, 41.0513800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128026, 'Ahmetli', 'Ahmetli', 'Ahmetli', 38.5196000, 27.9386500, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128027, 'Ahmetli', 'Ahmetli', 'Ahmetli', 38.1781700, 39.8562700, 'TR', '2015-07-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128028, 'Ahlat', 'Ahlat', 'Ahlat,Akhlat,Erkizan,Ахлат', 38.7489000, 42.4800700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128029, 'Ahırlı', 'Ahirli', 'Ahirli,Ahırlı', 37.2387400, 32.1188100, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128030, 'Ağlasun', 'Aglasun', 'Aglasun,Ağlasun,Belonu,Belönü', 37.6494400, 30.5341700, 'TR', '2012-02-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128031, 'Ağın', 'Agin', 'Agin,Ağın', 38.9379200, 38.7115500, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128032, 'Akcakışla', 'Akcakisla', 'Akcakisla,Akcakışla,Emlak,Emlâk', 39.5381800, 36.3362600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128033, 'Ağaçören', 'Agacoren', 'Agacoren,Ağaçören,Panli,Panlı', 38.8748400, 33.9167400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128034, 'Ağaçlı', 'Agacli', 'Agacli,Ağaçlı', 38.5172800, 40.9040100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128035, 'Gülağaç', 'Gulagac', 'Agacli,Ağaçlı,Gulagac,Gülağaç', 38.3957600, 34.3457600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128036, 'Ağabeyli', 'Agabeyli', 'Agabeyli,Akbeyli,Ağabeyli', 37.7336200, 37.1162500, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128037, 'Afyonkarahisar', 'Afyonkarahisar', 'AFY,Acroenus,Acroënus,Af''on-Karakhisar,Af''onkarakhisar,Afion,Afion Karachisar,Afion Karahissar,Afion-Karahisar,Afionkarakhisar,Afioun-Kara-Hissar,Afium Kara Hissar,Afium Karahisar,Afiun Karahissar,Afiun Qarahisar,Afiun-Carahissar,Afjonkarahisara,Afjonkarahisaras,Afyon,Afyonkara Hisar,Afyonkarahisar,Afıon Karahissar,Gorad Afjon,Kara Hissar Sahib,Karahisarisahip,Karahısarısahıp,a fei yong ka la xi sa er,afiyonkarahisaru,afywn qrh hsar,apionkalahisaleu,Αφιόν Καραχισάρ,Афионкарахисар,АфйонкъарахӀисар,Афьон-Карахисар,Афьон-Карахісар,Афьонкарахисар,Горад Афён,Աֆիոն-Կարահիսար,أفيون قره حصار,ئافيون قاراھىسار,افیون قره‌حصار,افیون قرہ حصار,افیون‌ قره حصاری,قره ‌حصار ساحب,აფიონ-ყარაჰისარი,アフィヨンカラヒサール,阿菲永卡拉希萨尔,아피온카라히사르', 38.7566700, 30.5433300, 'TR', '2012-04-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128038, 'Afşin', 'Afsin', 'Afsin,Afşin,Efsus,Yarpus,Yarpuz', 38.2476900, 36.9139900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128039, 'Adıyaman', 'Adiyaman', 'ADF,Adiaman,Adijaman,Adijamanas,Adityman,Adiyaman,Adiyamanska,Adujaman,Adyjaman,Adıyaman,Adıyamanská,Antigiaman,Carbanum,Gorad Adyjaman,Hisnumansur,Husnimansur,Husnumansur,Hüsnümansur,Perre,Pordonnium,Semsur,Semsûr,a de ya man,a de ya man sheng,adiamani,adiyaman,adiyamana,ado~uyaman,adyaman,adyyamyn,yadyyama,Αντιγιαμάν,Адияман,Адијаман,Адъяман,Адыяман,Горад Адыяман,Ադիյաման,אדיאמן,آدیامان,آدی‌یامان,أديامان,ئادىياما,ادییامین,سەمسوور,আদিয়ামান,ადიამანი,アドゥヤマン,阿德亚曼,阿德亚曼省,아디야만', 37.7644100, 38.2762900, 'TR', '2017-01-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128040, 'Adilcevaz', 'Adilcevaz', 'Adeljivaz,Adilcevaz,Adildzhevaz,Адилджеваз,عادالجواز,عادلجواز', 38.7991100, 42.7315900, 'TR', '2015-03-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128041, 'Adana', 'Adana', 'ADA,Adana,Adane,Adanë,Adhanah,Antiocheia,Edene,Gorad Adana,a da na,adana,adnt,xa da na,yadana,Άδανα,Αδανα,Αντιόχεια,Адана,Горад Адана,Ադանա,אדנה,آدانا,أضنة,ئادانا,अदना,আদানা,อาดานา,ადანა,アダナ,阿达纳,아다나', 37.0016700, 35.3288900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128042, 'Adaklı', 'Adakli', 'Adakli,Adaklı,Azakpert,Hosnek,Hösnek', 39.2262000, 40.4828300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128043, 'Acırlı', 'Acirli', 'Acirli,Acırlı,Derizbin,Dirizbin', 37.4554900, 41.2949900, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128044, 'Acıpınar', 'Acipinar', 'Acipinar,Acıpınar', 38.5267100, 33.8522500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128045, 'Acıpayam', 'Acipayam', 'Acipayam,Acıpayam,Batikaraagac,Batıkaraağaç,Garbi Karaagac,Garbî Karaağaç', 37.4238500, 29.3494100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128046, 'Dobada', 'Dobada', 'Acigol,Acıgöl,Dobada', 38.5502800, 34.5091700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128047, 'Acarlar', 'Acarlar', 'Abdallar,Acarlar', 37.8244400, 27.7466700, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128048, 'Çardaklı', 'Cardakli', 'Cardakli,Çardaklı', 37.2309800, 42.5840900, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128049, 'Ballı', 'Balli', 'Balli,Ballı', 37.4133300, 42.8394400, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128050, 'Yemişli', 'Yemisli', 'Yemisli,Yemişli', 37.3671000, 43.0771700, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128051, 'Karsani', 'Karsani', 'Gundes,Guzeldere,Gündeş,Güzeldere,Karsani,Minyanis,Minyanysh,Minyanış', 37.3071600, 43.4541000, 'TR', '2014-10-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128052, 'Nurdağı', 'Nurdagi', 'Nurdagi,Nurdağı', 37.1682100, 36.7362300, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128053, 'Yeşildere', 'Yesildere', 'Yesildere,Yeşildere', 36.9730000, 37.4948800, 'TR', '2015-10-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128054, 'Küçükkendirci', 'Kucukkendirci', '', 36.9058300, 38.3461100, 'TR', '2004-07-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128055, 'Mahmutlar', 'Mahmutlar', 'Makhmutlar,Махмутлар', 36.9490000, 36.1923100, 'TR', '2009-05-15', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128056, 'Gyuvench', 'Gyuvench', 'Guvenc,Gyuvench,Güvenç', 36.6853800, 36.4231200, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128057, 'Aşağı Karafakılı', 'Asagi Karafakili', 'Asagi Karafakili,Asagikarafakili,Aşağı Karafakılı,Aşağıkarafakılı', 36.7788500, 36.5577600, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128058, 'Çırtıman', 'Cirtiman', 'Cirtiman,Çırtıman', 36.5253100, 36.1812900, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128059, 'Kızkalesi', 'Kizkalesi', 'Kizkalesi,Kyzkalesi,Kızkalesi,Кызкалеси', 36.6583300, 36.2177800, 'TR', '2015-07-31', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128060, 'Kuzeytepe', 'Kuzeytepe', 'Guzeltepe,Güzeltepe,Kuzeytepe', 36.2650500, 36.1535000, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128061, 'Kastal', 'Kastal', 'Kastal', 36.2476000, 36.2409000, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128062, 'Açıkdere', 'Acikdere', 'Acikdere,Açıkdere,Habestuylu,Habestüylü,Khabeshtyuydyu', 36.2190900, 36.2599200, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128063, 'Toygarlı', 'Toygarli', 'Toygarli,Toygarlı', 36.2126100, 36.0726200, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128064, 'Gümüşgöze', 'Gumusgoze', 'Gumusgoze,Gümüşgöze', 36.1478500, 36.1328400, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128065, 'Dursunlu', 'Dursunlu', 'Dursunlu', 36.1673600, 36.1578800, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128066, 'Aşağıokçular', 'Asagiokcular', 'Asagiokcular,Aşağıokçular', 36.1780200, 36.1403300, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128067, 'Boynuyoğun', 'Boynuyogun', 'Boynuyogun,Boynuyoğun', 36.1693500, 36.3424900, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128068, 'Uzunbağ', 'Uzunbag', 'Uzunbag,Uzunbağ', 36.1402300, 36.0360300, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128069, 'Büyükçat', 'Buyukcat', 'Buyukcat,Büyükçat', 36.1150000, 36.0774000, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128070, 'Balıklıdere', 'Baliklidere', 'Baliklidere,Balıklıdere', 36.1209600, 36.1048100, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128071, 'Hacıpaşa', 'Hacipasa', 'Hacipasa,Hacıpaşa', 36.0690700, 36.3707600, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128072, 'Samankaya', 'Samankaya', 'Samankaya', 36.1502700, 36.1282900, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128073, 'Anayazı', 'Anayazi', 'Anayazi,Anayazı', 36.3210700, 36.1906100, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128074, 'Karasüleymanlı', 'Karasuleymanli', 'Karasuleymanli,Karasüleymanlı', 36.3419100, 36.4143100, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128075, 'Büyük Dalyan', 'Buyuk Dalyan', 'Buyuk Dalyan,Buyukdalyan,Büyük Dalyan,Büyükdalyan', 36.2882400, 36.2090300, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128076, 'Günyazı', 'Gunyazi', 'Gunyazi,Günyazı', 36.2330700, 36.1170200, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128077, 'Tepehan', 'Tepehan', 'Tepehan', 36.1585300, 36.2286000, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128078, 'Yiğityolu', 'Yigityolu', 'Karbeyaz,Yigityolu,Yiğityolu', 35.9969400, 36.2644400, 'TR', '2014-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128079, 'Uzunkavak', 'Uzunkavak', 'Uzunkavak', 36.3524000, 36.4195200, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128080, 'Denizciler', 'Denizciler', 'Denizciler', 36.6411000, 36.2141800, 'TR', '2016-09-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128081, 'Başaran', 'Basaran', 'Basaran,Başaran', 37.4765500, 43.1298400, 'TR', '2014-10-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128082, 'Doruklu', 'Doruklu', 'Doruklu', 37.2555000, 42.3351800, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128083, 'Akdiken', 'Akdiken', 'Akdiken', 36.7250000, 39.3086100, 'TR', '2016-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128084, 'Bulutlu', 'Bulutlu', 'Bulutlu,Yalintas,Yalıntaş', 36.7358300, 39.3938900, 'TR', '2015-12-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128085, 'Pekmezli', 'Pekmezli', 'Pekmezci,Pekmezli', 36.7536100, 39.4500000, 'TR', '2016-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128086, 'Koyunluca', 'Koyunluca', 'Koyunluca', 36.8227800, 39.3433300, 'TR', '2016-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128087, 'Yukarı Taşyalak', 'Yukari Tasyalak', 'Yukari Tasyalak,Yukarı Taşyalak', 36.9630600, 40.1319400, 'TR', '2012-01-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128088, 'Işıklar', 'Isiklar', 'Isiklar,Işıklar,Yusufharabasi,Yusufharabası', 36.9941700, 40.1263900, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128089, 'Çıplak', 'Ciplak', 'Ciplak,Çıplak', 36.9447200, 40.2375000, 'TR', '2012-01-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128090, 'Batikent', 'Batikent', 'Batikent,Batıkent', 39.9683300, 32.7308300, 'TR', '2009-10-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128091, 'Türkler', 'Tuerkler', '', 36.6019800, 31.8206700, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128092, 'Başyayla', 'Basyayla', 'Basyayla,Başyayla', 36.7533700, 32.6801800, 'TR', '2012-01-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128093, 'Dalaman', 'Dalaman', 'DLM,Dalaman', 36.7659100, 28.8028000, 'TR', '2014-07-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128094, 'Zonguldak', 'Zonguldak', 'Gorad Zanguldak,ONQ,Sandaraca,Songuldak,Sungul,Zon''nkoulntak,Zonguldak,Zonguldakas,Zonguldaq,Zonquldak,Zoungouldagh,Zunguldak,jong-guldakeu,zangwldak,zngwldagh,zong gu er da ke,zonguldaki,zongurudaku,zwnghwldaq,zwngwldagh,zwngwldak,Ζονγκουλντάκ,Горад Зангулдак,Зонгулдак,زانگولداک,زنگولداغ,زونغولداق,زونگولداغ,زونگولداک,ზონგულდაქი,ゾングルダク,宗古爾達克,종굴다크', 41.4513900, 31.7930500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128095, 'Zile', 'Zile', 'Zil,Zile,Зил', 40.3030600, 35.8863900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128096, 'Zeytinlik', 'Zeytinlik', 'Sirya,Zejtinlik,Zeytinlik,Зейтинлик', 41.1101300, 41.8581600, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128097, 'Zeytinburnu', 'Zeytinburnu', '', 40.9944100, 28.9041700, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128098, 'Zeytinbağı', 'Zeytinbagi', 'Tirilya,Trilia,Zeytinbagi,Zeytinbağı', 40.3908300, 28.7963900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128099, 'Yuvacık', 'Yuvacik', 'Yuvacik,Yuvacık', 40.6881500, 29.9673800, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128100, 'Yusufeli', 'Yusufeli', 'Ahalt,Jusufeli,Yusufeli,iusupeli,Юсуфели,იუსუფელი', 40.8204200, 41.5374300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128101, 'Yürük', 'Yuruk', 'Yoruk,Yuruk,Yörük,Yürük', 40.9355300, 27.0663100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128102, 'Yomra', 'Yomra', 'Dirona,Yomra', 40.9532600, 39.8554600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128103, 'Yoğuntaş', 'Yoguntas', 'Beder,Polos,Poloz,Yoguntas,Yoğuntaş', 41.8308100, 27.0697100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128104, 'Boztepe', 'Boztepe', 'Boztepe,Yenimusluman,Yenimüslüman,Yildiztepe,Yıldıztepe', 40.1877800, 35.8875000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128105, 'Yığılca', 'Yigilca', 'Ahmetciler,Ahmetçiler,Cayirliahmetciler,Yigilca,Yığılca,Çayırlıahmetçiler', 40.9598300, 31.4435500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128106, 'Yeşilyurt', 'Yesilyurt', 'Ciprek,Sargon,Sargun,Yesilyurt,Yeşilyurt,Çiprek', 40.3278600, 36.3514400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128107, 'Yeşilvadi', 'Yesilvadi', 'Alacali,Alacalı,Heciz,Hiciz,Saffetiye,Yesilvadi,Yeşilvadi', 41.1230000, 29.4769600, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128108, 'Yeşilce', 'Yesilce', 'Evady,Yavadi,Yavadı,Yesilce,Yevadi,Yevadı,Yeşilce,Евады', 40.5357700, 37.7956600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128109, 'Yenişehir', 'Yenisehir', 'YEI,Yenisehir,Yenişehir', 40.2644400, 29.6530600, 'TR', '2013-05-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128110, 'Yenipazar', 'Yenipazar', 'Kirka,Kırka,Yenipazar', 40.1783300, 30.5200000, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128111, 'Yeniköy', 'Yenikoy', 'Yenikoy,Yeniköy', 40.5356800, 29.3536400, 'TR', '2013-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128112, 'Yenice', 'Yenice', 'Yenice,Yenicekoy,Yeniceköy', 40.0877800, 29.4219400, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128113, 'Yenice', 'Yenice', 'Celtik,Yenice,Çeltik', 41.1996200, 32.3313300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128114, 'Yeniçağa', 'Yenicaga', 'Resadiye,Reşadiye,Yenicag,Yenicaga,Yeniçağ,Yeniçağa', 40.7711500, 32.0337500, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128115, 'Yavuzkemal', 'Yavuzkemal', 'Javuzkemal'',Koulakkagia,Kulakkaya,Sihlar,Sihlar Sipahi,Yavuzkemal,Şıhlar,Şıhlar Sipahi,Κουλάκκαγια,Явузкемаль', 40.6932900, 38.3372300, 'TR', '2016-11-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128116, 'Körfez', 'Korfez', 'Korfez,Körfez,Yaremdji,Yarimca,Yarımca', 40.7670400, 29.7827500, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128117, 'Yapraklı', 'Yaprakli', 'Tuht,Yaprakli,Yapraklı', 40.7578500, 33.7781900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128118, 'Yalova', 'Yalova', 'Gialova,Jalov,Jalova,Pythiae Thermae,Yalova,Yaluva,ialova,ya luo wa,yalloba,yalwa,yalwfa,yalwwa,yarovu~a,Γιάλοβα,Јалова,Ялова,يالوفا,یالوا,یالووا,იალოვა,ヤロヴァ,亞洛瓦,얄로바', 40.6550100, 29.2769300, 'TR', '2011-02-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128119, 'Yalnızçam', 'Yalnizcam', 'Sindiskom,Sindizkom,Yalnizcam,Yalnızçam', 41.0644400, 42.5008100, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128120, 'Yalakdere', 'Yalakdere', 'Merdigoz,Merdigöz,Yalakdera,Yalakdere,Yalakderekoy,Yalakdereköy', 40.6063600, 29.5622500, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128121, 'Yakuplu', 'Yakuplu', 'Tarakatya', 40.9889400, 28.6758200, 'TR', '2010-01-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128122, 'Yakakent', 'Yakakent', 'Gemenue,Gumenuz,Gümenüz,Yakakent', 41.6325000, 35.5288900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128123, 'Yağmurdere', 'Yagmurdere', 'Kesis,Kesiskoy,Keşis,Keşişköy,Yagmurdere,Yağmurdere', 40.5748700, 39.8624400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128124, 'Yağlıdere', 'Yaglidere', 'Camiyani,Camiyanı,Gemiyani,Gemiyanı,Jaglydere,Palakli Koyunun Camiyani Mevkii,Palaklı Köyünün Camiyanı Mevkii,Yaglidere,Yağlıdere,Яглыдере', 40.8567200, 38.6203500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128125, 'Yağlıdere', 'Yaglidere', 'Yaglidere,Yağlıdere', 40.5443200, 39.5276200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128126, 'Vize', 'Vize', 'Vize,wyzh,ویزه', 41.5725000, 27.7658300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128127, 'Vezirköprü', 'Vezirkopru', 'Koeprue,Köprü,Vezirkeprju,Vezirkopru,Vezirköprü,kpry,kwpry,wei ji er ke pu lu,wzyrkwprw,Везиркепрю,Везиркӧпрӱ,وزیرکوپرو,کوپری,کپری,韋濟爾克普呂', 41.1436100, 35.4547200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128128, 'Vezirhan', 'Vezirhan', 'Vezirhan', 40.2447200, 30.0200000, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128129, 'Velimeşe', 'Velimese', 'Velimese,Velimeşe', 41.2536100, 27.8783300, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128130, 'Veliköy', 'Velikoy', 'Mirya,Velikej,Velikoey,Velikoy,Veliköy,Великей', 41.3152800, 42.4325000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128131, 'Vakfıkebir', 'Vakfikebir', 'Vakfikebir,Vakfıkebir', 41.0458300, 39.2763900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128132, 'Uzunköprü', 'Uzunkoeprue', 'Ivanski,Ouzoun Kioprou,Uzunk''oprju,Uzunkeprju,Uzunkjoprju,Uzunkoeprue,Uzunkopru,Uzunköprü,awzwn kwprw,awzwnkwprw,uzunkyopuryu,wu zun ke pu lu,Ουζούν Κιοπρού,Узункепрю,Узункьопрю,Узункёпрю,Узункӧпрӱ,اوزون کوپرو,اوزونکوپرو,اوزون‌کوپرو,ウズンキョプリュ,烏尊克普呂', 41.2659700, 26.6885000, 'TR', '2015-05-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128133, 'Uzunisa', 'Uzunisa', 'Uzunhisar,Uzunisa', 40.9146500, 37.8481800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128134, 'Uzungöl', 'Uzungol', 'Serah,Uzungol,Uzungöl,Şerah', 40.6159400, 40.2885300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128135, 'Uzundere', 'Uzundere', 'Azort,Azortuzundere,Uzundere,Азорт', 40.5321800, 41.5383200, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128136, 'Üsküp', 'Uskup', 'Uskup,Üsküp', 41.7358300, 27.4052800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128137, 'Üsküdar', 'UEskuedar', 'Chrysopolis,Scutari,Skutari,Uskjudar,Uskudar,askdar,Üsküdar,Ускюдар,اسکدار', 41.0225200, 29.0236900, 'TR', '2013-11-13', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128138, 'Uruş', 'Urus', 'Urus,Uruş', 40.2490300, 32.1378500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128139, 'Ünye', 'UEnye', 'Oenoe,Onieh,UEnye,Un''e,Unia,Unie,Unieh,Ünia,Ünye,Унье', 41.1313900, 37.2825000, 'TR', '2015-04-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128140, 'Şenyurt', 'Senyurt', 'Kisha,Kiskha,Senyurt,Uncular,Şenyurt,Кисха', 40.4264500, 41.4282600, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128141, 'Umurbey', 'Umurbey', 'Umurbey', 40.4147200, 29.1830600, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128142, 'Umurbey', 'Umurbey', 'Bergas,Bergos,Bergoz,Umurbey', 40.2337300, 26.6063200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128143, 'Umraniye', 'Umraniye', '', 41.0164300, 29.1247600, 'TR', '2011-01-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128144, 'Ulus', 'Ulus', 'Distretto di Ulus,Ulus,awlws,awlws  bartyn,Улус,أولوس,اولوس، بارتین,ضلع اولس', 41.5841700, 32.6413900, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128145, 'Ulubey', 'Ulubey', 'Gunduzlu,Gündüzlü,Ulubei,Ulubey,Улубеи', 40.8686300, 37.7540500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128146, 'Ulaşlı', 'Ulasli', 'Asagiulasli,Aşağıulaşlı,Ulasli,Ulaşlı', 40.7058300, 29.6960800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128147, 'Uğurludağ', 'Ugurludag', 'Kizilveran,Kizilveren,Kizilviran,Kızılveran,Kızılveren,Kızılviran,Ugurludag,Uğurludağ', 40.4463100, 34.4525900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128148, 'Ovacık', 'Ovacik', 'Ovacik,Ovacık,UEckoese,Uchkose,Uckose,Üçköşe,Учкосе', 40.2004900, 40.9972700, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128149, 'Tuzluca', 'Tuzluca', 'Kulp,Tuzluca,Tuzludzha,Тузлуджа', 40.0387100, 43.6520800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128150, 'Tütüncü', 'Tutuncu', 'Ayvacik,Ayvacık,Tutuncu,Tütüncü', 40.0669400, 27.7197200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128151, 'Gülyalı', 'Gulyali', 'Gulyali,Gülyalı,Mustafaly,Turnasuyu,Мустафалы', 40.9615300, 38.0493700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128152, 'Türkeli', 'Turkeli', 'Gemiyani,Gemiyanı,Turkeli,Türkeli', 41.9476400, 34.3386100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128153, 'Turhal', 'Turhal', 'Turhal,Turkhal,Турхал', 40.3875000, 36.0811100, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128154, 'Trabzon', 'Trabzon', 'Atrabazandah,Gorad Trabzon,TZX,Tarabazandah,Tirabson,Tirabzon,Trabzon,Trabzona,Trabzonas,Trapesonda,Trapezonte,Trapezounta,Trapezund,Trapezunt,Trapezus,Trapisonda,Trapizon,Trebisonda,Trebizond,Trebizonda,Trebizonde,Trébizonde,tarabazona,te la bu zong,teulabeujon,torabuzon,trabzwn,trbzwn,tʼrapʼizoni,Τραπεζούντα,Горад Трабзон,Трабзон,Трапезунт,Տրապիզոն,טרבזון,ترابزون,ترابزۆن,طرابزون,ਤਰਾਬਜ਼ੋਨ,ტრაპიზონი,トラブゾン,特拉布宗,트라브존', 41.0050000, 39.7269400, 'TR', '2012-08-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128155, 'Tosya', 'Tosya', 'Docea,Tosja,Tosya,Тося', 41.0154500, 34.0401300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128156, 'Torul', 'Torul', 'Ardasa,Torul,Торул', 40.5507100, 39.2834400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128157, 'Tortum', 'Tortum', 'Nihah,Tortum,Тортум', 40.2889200, 41.5409600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128158, 'Topçam', 'Topcam', 'Gebeme,Inalan,Topcam,Topchan,Topçam,İnalan,Топчан', 40.6165800, 37.7705700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128159, 'Tonya', 'Tonya', 'Ortamahalle,Tonya', 40.8840200, 39.2848600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128160, 'Tokat', 'Tokat', 'Dazimon,Evdokia,Gorad Takat,Provincia de Tokat,TJK,Tocat,Tokat,Tokat Province,Tokatas,Tokatiaen,Tokatiän,Tokatska provincie,Tokatská provincie,Tokhuat,Toqat,Tukat,tokateu,tokati,tokatto,tuo ka te,twkat,twqat,twqt,Τοκάτ,Горад Такат,Токат,Тохъат,Եվդոկիա,טוקט,توقات,توکات,თოქათი,トカット,托卡特,토카트', 40.3138900, 36.5544400, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128161, 'Tirebolu', 'Tirebolu', 'Tarablus,Tereboli,Tireboli,Tirebolu,Trebolu,Tripolis,Тиреболу', 41.0069400, 38.8138900, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128162, 'Terme', 'Terme', 'Terme,Терме', 41.2091700, 36.9738900, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128163, 'Tepecik', 'Tepecik', 'Playa,Tepecik', 41.0293100, 28.5497800, 'TR', '2014-02-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128164, 'Tekkiraz', 'Tekkiraz', 'Tekkiraz,Теккираз', 40.9858800, 37.1602800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128165, 'Tekkeköy', 'Tekkekoy', 'Tekke,Tekkekej,Tekkekoey,Tekkekoy,Tekkeköy,Теккекей', 41.2116700, 36.4600000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128166, 'Tekke', 'Tekke', 'Tasabat,Taşabat,Tekke', 40.7155600, 36.1924700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128167, 'Tekirdağ', 'Tekirdag', 'Bisanthe,Gorad Tehkirdag,Raidestos,Rhaedestus,Rodoscuk,Rodosto,Rodostó,Rodosçuk,Tekfur Dagh,Tekfurdag,Tekfurdağ,Tekirdaa,Tekirdag,Tekirdahas,Tekirdağ,Tektur Dagh,Təkirdağ,tai ji er da,teki r dak,tekileuda,tekirdaghi,tekiruda,tkyrdagh,tykrdagh,Ραιδεστός,Горад Тэкірдаг,Родосто,Текирдаг,Текірдаг,טקירדא,تكيرداغ,تکیرداغ,تیکرداغ,เตกีร์ดาก,თექირდაღი,テキルダー,泰基爾達,테키르다', 40.9781000, 27.5110100, 'TR', '2017-05-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128168, 'Teke', 'Teke', 'Teke', 41.0605000, 29.6538100, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128169, 'Tavşanlı', 'Tavsanli', 'Tavsanli,Tavşanlı', 40.8187600, 29.5113600, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128170, 'Tavşancıl', 'Tavsancil', 'Tavsancil,Tavshanjik,Tavşancıl,Towshanjik', 40.7708300, 29.5719400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128171, 'Tatkavaklı', 'Tatkavakli', 'Kavakli,Kavaklı,Tatkavakli,Tatkavaklı', 40.0333300, 28.3666700, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128172, 'Taşova', 'Tasova', 'Tashova,Tasova,Taşova,Yemisenbuku,Yemişenbükü,Ташова', 40.7597200, 36.3225000, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128173, 'Taşköprü', 'Taskopru', 'Taskopru,Taşköprü', 41.5098000, 34.2141400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128174, 'Taşköprü', 'Taskopru', 'Taskopru,Taşköprü', 40.6736100, 29.3911100, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128175, 'Zigopor', 'Zigopor', 'Sarigoel,Sarigol,Sarıgöl,Taskiran,Taşkıran,Zapor,Zigapor,Zigopor,Запор', 40.9474500, 41.4947700, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128176, 'Taraklı', 'Tarakli', 'Tarakli,Taraklı,traqly,طراقلی', 40.3969400, 30.4927800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128177, 'Taflan', 'Taflan', 'Taflan,Тафлан', 41.4094400, 36.1288900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128178, 'Tacir', 'Tacir', 'Tacir,Tacir Koyu,Tacir Köyü', 40.5255600, 29.7397200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128179, 'Susuzmüsellim', 'Susuzmusellim', 'Susuzmusellim,Susuzmüsellim', 41.0988900, 27.0675000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128180, 'Susuz', 'Susuz', 'Nevodobovka,Susuz,Сусуз', 40.7791000, 43.1276900, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128181, 'Suşehri', 'Susehri', 'Endires,Endiryas,Susehiri,Susehri,Sushekhri,Suşehiri,Suşehri,Сушехри', 40.1600500, 38.0841300, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128182, 'Sürmene', 'Surmene', 'Hamurgan,Hamurgân,Homurgan,Humurgan,Humurgân,Kamurghia,Sjurmene,Suermene,Surmene,Syurmene,Sürmene,Сюрмене', 40.9058800, 40.1279200, 'TR', '2017-06-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128183, 'Sungurlu', 'Sungurlu', 'Sungurlu,Сунгурлу', 40.1675000, 34.3738900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128184, 'Suluova', 'Suluova', 'Suluca,Suluova', 40.8312900, 35.6478800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128185, 'Sultanköy', 'Sultankoy', 'Sultankoy,Sultanköy', 41.0213900, 27.9886100, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128186, 'Süloğlu', 'Sueloglu', 'Suleoglu,Suloglu,Süleoğlu,Süloğlu', 41.7690100, 26.9099900, 'TR', '2015-09-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128187, 'Sulakyurt', 'Sulakyurt', 'Konur,Sehsamikebir,Sulakujurt,Sulakyurt,Yukari Seyh Sami,Yukarı Şeyh Şamı,Şehşamıkebır,Сулакъюрт', 40.1573300, 33.7160000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128188, 'Sölöz', 'Soloz', 'Muslimsoloz,Muslimsoluz,Muslumsoloz,Müslimsölöz,Müslimsölüz,Müslümsölöz,Soloz,Sozlu,Sölöz,Sözlü', 40.3948000, 29.4155900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128189, 'Mahmudiye', 'Mahmudiye', 'Mahmudiye,Sogutpinar,Sogutpinari,Söğütpınar,Söğütpınarı', 40.3378700, 28.6494500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128190, 'Söğütlü', 'Sogutlu', 'Sogutlu,Söğütlü', 40.9059000, 30.4744800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128191, 'Soldere', 'Soldere', 'Sogutalan,Soldere,Söğütalan', 40.0608900, 28.5723100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128192, 'Şişli', 'Sisli', 'Sisli,Şişli', 41.0604600, 28.9871700, 'TR', '2010-12-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128193, 'Sırpsındığı', 'Sirpsindigi', 'Sarayakpinar,Sarayakpınar,Sirpsindigi,Sırpsındığı', 41.7812400, 26.4788800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128194, 'Şiran', 'Siran', 'Karaca,Shiran,Siran,Şiran,Ширан', 40.1906400, 39.1174700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128195, 'Sinop', 'Sinop', 'NOP,SIC,Sanub,Sinob,Sinop,Sinope,Sinopi,Sinub,Synopa,Sînop,Sınob,sinopeu,su~inopu,synwb,synwp,synwp  trky,xi nuo pu,Σινώπη,Синоп,סינופ,سينوب,سینوپ,سینوپ، ترکی,སི་ནོ་པེ།,სინოპი,スィノプ,锡诺普,시노프', 42.0268300, 35.1625300, 'TR', '2016-11-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128196, 'Sinekli', 'Sinekli', 'Sinekli', 41.2279800, 28.1904300, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128197, 'Sinekçi', 'Sinekci', 'Hifziye,Hifziyekoyu,Hıfziye,Hıfziyeköyü,Sinekci,Sinekçi', 40.2707300, 27.4066700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128198, 'Silivri', 'Silivri', 'Selibria,Selymbria,Siliviri,Silivri,slwry,slywry,سلوری,سلیوری', 41.0739300, 28.2464400, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128199, 'Şile', 'Sile', 'Artane,Chile,Kilia,Schile,Sile,Şile', 41.1754000, 29.6133300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128200, 'Seyitler', 'Seyitler', 'Seyitler', 41.1948400, 41.8369600, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128201, 'Şeyhli', 'Seyhli', 'Seyhli,Sihli,Şeyhli,Şıhlı', 40.9219400, 36.0633300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128202, 'Seydim', 'Seydim', 'Seydim', 40.5430200, 34.7381200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128203, 'Seydiler', 'Seydiler', 'Seydiler', 41.6200500, 33.7181500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128204, 'Şevketiye', 'Sevketiye', 'Hacibagam,Hacibagun,Hacipagun,Hacıbagam,Hacıbağun,Hacıpagun,Khadzhi Paun,Khadzhi Paunk''oj,Sevketiye,shwktyh,Şevketiye,Хаджи Паун,Хаджи Паункьой,شوکتیه', 40.0934700, 27.8466700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128205, 'Sergen', 'Sergen', 'Sergen', 41.7052800, 27.7083300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128206, 'Şerefiye', 'Serefiye', 'Serefiye,Sherefie,Şerefiye,Шерефие', 40.1119500, 37.7562400, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128207, 'Serdivan', 'Serdivan', 'Sardivan,Sardivar,Sardıvan,Serdivan', 40.7737600, 30.3800600, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128208, 'Şenpazar', 'Senpazar', 'Koztekke,Kuztekke,Sarbana,Senpazar,Senpazari,Şarbana,Şenpazar,Şenpazarı', 41.8089000, 33.2313500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128209, 'Şenkaya', 'Senkaya', 'Ortulu,Senkaya,Shenkaja,Örtülü,Şenkaya,Шенкая', 40.5565200, 42.3426600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128210, 'Selimpaşa', 'Selimpasa', 'Bigados,Bigadoş,Boados,Boghados,Epivates,Selimpasa,Selimpaşa', 41.0544800, 28.3667800, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128211, 'Selim', 'Selim', 'Selim,Селим', 40.4577200, 42.7828700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128212, 'Şebin Karahisar', 'Sebin Karahisar', 'Colonia,Karahisar-i Sarki,Karahisar-ı Şarki,Sarki Karahissar,Sebin Karahisar,Sebinkarahisar,Shebinkarakhisar,qrh hsar shrqy,Şarki Karahissar,Şebin Karahisar,Şebinkarahisar,Шебинкарахисар,قره حصار شرقی', 40.2883300, 38.4236100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128213, 'Seben', 'Seben', 'Carsamba,Carsanba,Seban,Seben,Çarsanba,Çarşamba', 40.4113400, 31.5735900, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128214, 'Şavşat', 'Savsat', 'Savsat,Shavshat,Yenikoy,Yeniköy,Şavşat,Шавшат', 41.2402700, 42.3610900, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128215, 'Şarköy', 'Sarkoey', 'Agora,Agorà,Peristasis,Sarikoy,Sariköy,Sarkioi,Sarkoey,Sarkoy,Tiristasis,Şarköy', 40.6139500, 27.1156300, 'TR', '2015-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128216, 'Sarıköy', 'Sarikoy', 'Sarikoy,Sarıköy', 40.2075000, 27.5961100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128217, 'Sarıkamış', 'Sarikamis', 'Sarikamis,Sarykamysh,Sarıkamış,Сарыкамыш', 40.3276900, 42.5870500, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128218, 'Sarıbuğday', 'Saribugday', 'Saribugday,Sarıbuğday,Turnuk,Türnük', 40.7480600, 35.4597200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128219, 'Saraydüzü', 'Sarayduzu', 'Kiziloglan,Kızıloğlan,Sarayduz,Sarayduzu,Saraydüz,Saraydüzü', 41.3286500, 34.8468600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128220, 'Saraycık', 'Saraycik', 'Saraycik,Saraycık', 40.9501700, 35.1116500, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128221, 'Saray', 'Saray', 'Saray', 41.4443100, 27.9219400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128222, 'Sapanca', 'Sapanca', 'Mudanya,Sabanca,Sapanca', 40.6914100, 30.2673800, 'TR', '2013-01-25', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128223, 'Samsun', 'Samsun', 'Amisos,Amisus,Djanik,Gorad Samsun,Janik,SSX,SZF,Sampsounta,Sams,Samsoun,Samsun,Samsuna,Samsunas,sa mu song,sam sun,samsun,samsuni,samswn,samusun,smswn,symsn,Αμισός,Σαμψούντα,Горад Самсун,Самсун,Սամսուն,סמסון,سامسون,سیمسن,ซัมซุน,სამსუნი,サムスン,薩姆松,삼순', 41.2797600, 36.3361000, 'TR', '2017-05-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128224, 'Samandıra', 'Samandira', 'Samandira,Samandra,Samandıra', 40.9990000, 29.2256500, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128225, 'Şalpazarı', 'Salpazari', 'Kirec,Kireç,Salpazari,Şalpazarı', 40.9382600, 39.1900600, 'TR', '2015-09-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128226, 'Şahin', 'Sahin', 'Sahin,Şahin', 41.0216700, 26.8425000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128227, 'Safranbolu', 'Safranbolu', 'Gorad Safranbalu,Saframpoli,Safranbolu,Zafranboli,fan hong hua cheng,safuranboru,sapeulanbollu,sapranbolu,sprnbwlw,Σαφράμπολη,Горад Сафранбалу,Сафранболу,ספרנבולו,سافران‌بولو,ضلع سافرانبولو,საფრანბოლუ,サフランボル,番紅花城,사프란볼루', 41.2508300, 32.6941700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128228, 'Şabanözü', 'Sabanozu', 'Sabanozu,Şabanözü', 40.4824900, 33.2835200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128229, 'Rize', 'Rize', 'Bechirias,Corum,Provinsi Rize,QRI,Rhizus,Rize,Rizeh,Rizenska provincie,Rizenská provincie,Rizounta,Rizė,Rizə,li ze,lije,rize,ryzh,Çorum,Ριζούντα,Ризе,Різе,Ռիզե,ريزه,ریزه,ریزہ,ریزے,რიზე,リゼ,里澤,리제', 41.0208300, 40.5219400, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128230, 'Reşadiye', 'Resadiye', 'Resadiye,Reshadie,Reşadiye,Решадие', 40.3919400, 37.3375000, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128231, 'Pursaklar', 'Pursaklar', 'Pursakkir,Pursakkır,Pursaklar', 40.0320300, 32.8952800, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128232, 'Posof', 'Posof', 'Digor,Dugur,Duğur,Posof,Пософ,ضلع پوسوف,პოსოფი', 41.5111100, 42.7291700, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128233, 'Piraziz', 'Piraziz', 'Abdal,Apdal,Eren,Erenkoy,Erenkoyu,Erenköy,Erenköyü,Piraziz,Pirazziz', 40.9529900, 38.1089000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128234, 'Piraziz', 'Piraziz', 'Nefsipiraziz,Piraziz,Пиразиз', 40.9224400, 38.1245800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128235, 'Pınarhisar', 'Pinarhisar', 'Pinarhisar,Pınarhisar', 41.6241700, 27.5200000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128236, 'Pınarbaşı', 'Pinarbasi', 'Pinarbasi,Pınarbaşı,Tekkesin,Tekkeşin', 41.6038800, 33.1109900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128237, 'Perşembe', 'Persembe', 'Persembe,Pershembe,Perşembe,Vona,Першембе', 41.0655600, 37.7713900, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128238, 'Pendik', 'Pendik', 'Pendik', 40.8775000, 29.2725000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128239, 'Pehlivanköy', 'Pehlivankoy', 'Pavli,Pehlivankoy,Pehlivanköy', 41.3481200, 26.9252200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128240, 'Peçenek', 'Pecenek', 'Pecenek,Peçenek', 40.4185700, 32.3083300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128241, 'Pazaryolu', 'Pazaryolu', 'Pazarjolu,Pazaryolu,Пазарйолу', 40.4114200, 40.7678000, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128242, 'Pazarköy', 'Pazarkoy', 'Pazar,Pazarkoy,Pazarköy', 40.9255500, 32.1807000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128243, 'Pazar', 'Pazar', 'Athenae,Atina,Buleb,Kizkalessi,Pazar,Пазар', 41.1791700, 40.8841700, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128244, 'Pazar', 'Pazar', 'Pazar,Sorba,Şorba', 40.3302700, 32.7482000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128245, 'Pazar', 'Pazar', 'Pazar,Пазар', 40.2765200, 36.2834700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128246, 'Pamukova', 'Pamukova', 'Akhisar,Pamukova,Sakaryaakhisar,Sakaryaakhisari,Sakaryaakhisarı,Sakaryahisar,aqhsar,اقحصار', 40.5081000, 30.1673200, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128247, 'Ovacuma', 'Ovacuma', 'Ovacuma', 41.4485000, 32.7536100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128248, 'Ovacık', 'Ovacik', 'Ovacik,Ovacık', 41.0766100, 32.9199400, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128249, 'Yenikonak', 'Yenikonak', 'Osmanli,Osmanlı,Otmanli,Otmanlı,Yenikonak', 41.8731900, 34.6030800, 'TR', '2015-10-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128250, 'Osmaneli', 'Osmaneli', 'Lefke,Osmaneli', 40.3572200, 30.0141700, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128251, 'Osmancık', 'Osmancik', 'Osmancik,Osmancık,Pimolisa', 40.9781800, 34.8047000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128252, 'Ortaköy', 'Ortakoy', 'Berta,Ortakej,Ortakoey,Ortakoy,Ortaköy,Ортакей', 41.2510400, 41.9836300, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128253, 'Ortaköy', 'Ortakoy', '', 41.1015400, 28.3758800, 'TR', '2010-01-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128254, 'Hemşin', 'Hemsin', 'Hemsin,Hemşin,Ortakoy,Ortaköy,Zugaortakoy,Zugaortaköy', 41.0477700, 40.8984000, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128255, 'Ortakent', 'Ortakent', 'Ortakent,Ortakoy,Ortaköy,Sisorta,Yilanlica,Yılanlıca', 40.3936700, 38.0102800, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128256, 'Ortaköy', 'Ortakoy', 'Ortakoy,Ortaköy', 40.2735200, 35.2517500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128257, 'Ortacalar', 'Ortacalar', 'Ortacalar,Ortakoy-Bucak,Ortaköy-Bucak', 41.2789600, 41.3788700, 'TR', '2013-12-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128258, 'Orta', 'Orta', 'Orta', 40.6242000, 33.1092800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128259, 'Ormanlı', 'Ormanli', 'Basveren,Başveren,Ormanli,Ormanlı', 41.1647200, 31.6141700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128260, 'Orhangazi', 'Orhangazi', 'Orhangazi,Pazarkoy,Pazarköy', 40.4891700, 29.3088900, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128261, 'Ordu', 'Ordu', 'Cotyora,OGU,Ordu,Орду', 40.9778200, 37.8904700, 'TR', '2015-09-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128262, 'Olur', 'Olur', 'Olor,Olur,Олур', 40.8216500, 42.1305500, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128263, 'Oltu', 'Oltu', 'Olti,Oltu,Olty,Олту', 40.5394500, 41.9872200, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128264, 'Öğdem', 'Ogdem', 'OEgdem,Ogdem,Okdem,Öğdem,Окдем', 40.9172800, 41.6361200, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128265, 'Of', 'Of', 'Of,Off,Ophius,Solakli,Solaklı,Sulakli,Sulaklı,Оф', 40.9405500, 40.2591800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128266, 'Niksar', 'Niksar', 'Cabeira,Diospolis,Neocaesarea,Niksar,Sebaste,Никсар', 40.5916700, 36.9516700, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128267, 'Narman', 'Narman', 'Id,Narman,İd', 40.3444900, 41.8608800, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128268, 'Narlıca', 'Narlica', 'Narlica,Narlıca', 40.3858300, 29.4811100, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128269, 'Nallıhan', 'Nallihan', 'Nallihan,Nallykhan,Nallıhan,na lei han,Наллыхан,ضلع نالیہان,ناللی‌حان,納勒漢', 40.1859300, 31.3517900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128270, 'Mustafakemalpaşa', 'Mustafakemalpasa', 'Kirmasti,Mustafakemalpasa,Mustafakemalpaşa,Mustafakemelpasa,Mustafakemelpaşa', 40.0381500, 28.4086600, 'TR', '2014-08-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128271, 'Muratlı', 'Muratli', 'Maradit,Muratli,Muratly Ke,Muratly-Ke,Muratlı,Муратлы-Ке', 41.4740500, 41.7064700, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128272, 'Muratlı', 'Muratli', 'Muratli,Muratlı', 41.1721600, 27.4992000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128273, 'Mudurnu', 'Mudurnu', 'Mudurnu', 40.4730000, 31.2075500, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128274, 'Mudanya', 'Mudanya', 'Montagnae,Mudan''i,Mudania,Mudanya,Myrlea Apamea,Муданьи', 40.3752800, 28.8822200, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128275, 'Mimarsinan', 'Mimarsinan', 'Kalikratya,Mimarsinan,Мимарсинан', 41.0179000, 28.5617600, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128276, 'Mihalgazi', 'Mihalgazi', 'Gomele,Gumele,Gömele,Gümele,Mihalgazi', 40.0262100, 30.5770700, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128277, 'Mezraa', 'Mezraa', 'Mezraa', 41.1976400, 35.1168400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128278, 'Meydancık', 'Meydancik', 'Imerhav,Meydancik,Meydancık,İmerhav', 41.4096400, 42.2364000, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128279, 'Mesudiye', 'Mesudiye', 'Hamidiye,Melet,Mesudie,Mesudiye,Месудие', 40.4544600, 37.7735300, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128280, 'Merzifon', 'Merzifon', 'Marsivan,Merzifon,Phazemon,mei er ji feng,mrzyfwn,Мерзифон,ضلع مرزیفون,مرزیفون,梅爾濟豐', 40.8733300, 35.4630600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128281, 'Meriç', 'Meric', 'Buyuk Doganca,Büyük Doğanca,Doganca,Doğanca,Meric,Meriç', 41.1918300, 26.4209700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128282, 'Mengen', 'Mengen', 'Besler,Beşler,Mengen,Turkbesli,Türkbeşli', 40.9387700, 32.0764200, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128283, 'Mecitözü', 'Mecitozu', 'Avukat Haci Koy,Avukat Hacı Köy,Hacikoey,Hacıköy,Mecidozu,Mecidözü,Mecitozu,Mecitözü', 40.5200000, 35.2952800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128284, 'Mecidiye', 'Mecidiye', 'Mecidiye', 40.6388900, 26.5391700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128285, 'Marmara Ereğlisi', 'Marmara Ereglisi', 'Eregli,Erekli,Ereğli,Heraclea,Marmara Ereglisi,Marmara Ereğlisi,Perinthus,arkly,ارکلی', 40.9700300, 27.9552800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128286, 'Marmaracık', 'Marmaracik', 'Marmaracik,Marmaracık', 41.2066700, 27.7544400, 'TR', '2013-05-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128287, 'Marmara', 'Marmara', 'Marmara', 40.5863300, 27.5554100, 'TR', '2014-09-22', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128288, 'Manyas', 'Manyas', 'Maltepe,Maltop,Manyas', 40.0463900, 27.9700000, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128289, 'Maltepe', 'Maltepe', '', 40.9356700, 29.1550700, 'TR', '2011-01-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128290, 'Malkara', 'Malkara', 'Malkara,Megalohora,Migalogora,Малкара', 40.8900000, 26.9011100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128291, 'Mahmut Şevket Paşa', 'Mahmut Sevket Pasa', 'Arnavutkoy,Arnavutköy,Mahmut Sevket Pasa,Mahmut Şevket Paşa,Mahmutsevketpasa Koy,Mahmutşevketpaşa Köy', 41.1528100, 29.1896800, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128292, 'Mahmutbey', 'Mahmutbey', 'Mahmutbey', 41.0536100, 28.8255600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128293, 'Maden', 'Maden', 'Maden,Madenhanlari,Madenhanları', 40.1813900, 40.4041700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128294, 'Maçka', 'Macka', 'Cevizlik,Machka,Macka,Matsouka,Maçka,Tzevislik,Ματσούκα,Τζεβισλίκ,Мачка', 40.8107200, 39.6046500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128295, 'Lüleburgaz', 'Luleburgaz', 'Arcadiopolis,Bergula,Ljuleburgas,Ljuleburgaz,Lueleburgaz,Lule Burgas,Luleburgaz,Lüleburgaz,Люлебургаз,Люлебургас', 41.4038500, 27.3591800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128296, 'Lapseki', 'Lapseki', 'Lampsacus,Lampsaki,Lapseki', 40.3441700, 26.6855600, 'TR', '2015-06-22', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128297, 'Lâlapaşa', 'Lalapasa', 'Lalapasa,Lâlapaşa', 41.8395100, 26.7356100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128298, 'Ladik', 'Ladik', 'Iladik,Ladik,Laodicea Pontica', 40.9105600, 35.8919400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128299, 'Kuzyaka', 'Kuzyaka', 'Kurdese,Kurdeşe,Kurtese,Kuzyaka,Kürteşe', 41.2320000, 33.7226700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128300, 'Kurucaşile', 'Kurucasile', 'Kurucasile,Kurucaşile', 41.8378100, 32.7162100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128301, 'Kurtkale', 'Kurtkale', 'Kurtkale', 41.2654600, 43.1258000, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128302, 'Kurşunlu', 'Kursunlu', 'Karacaviran,Kursunlu,Kurşunlu', 40.8410100, 33.2602800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128303, 'Kurşunlu', 'Kursunlu', 'Kursunlu,Kurşunlu', 40.0371200, 29.6597200, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128304, 'Küre', 'Kure', 'Kure,Küre', 41.8057800, 33.7116100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128305, 'Küplü', 'Kuplu', 'Kuplu,Küplü', 41.1069400, 26.3519400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128306, 'Küplü', 'Kuplu', 'Kuplu,Küplü', 40.0983700, 30.0001000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128307, 'Kumru', 'Kumru', 'Karacali,Karacalı,Kumru,Кумру', 40.8744400, 37.2638900, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128308, 'Kumluca', 'Kumluca', 'Kocanoz,Kumluca', 41.4472400, 32.4675900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128309, 'Kumburgaz', 'Kumburgaz', 'Kumburgaz', 41.0210800, 28.4803300, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128310, 'Kumbağ', 'Kumbag', 'Kum Baghu,Kumbag,Kumbağ', 40.8823600, 27.4591900, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128311, 'Kullar', 'Kullar', 'Kullar', 40.7241900, 29.9894300, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128312, 'Küçükkumla', 'Kucukkumla', 'Kucukkumla,Kucukkumlu,Küçükkumla,Küçükkumlu', 40.4704700, 29.1015200, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128313, 'Küçükdere', 'Kucukdere', 'Kucuk Gorgor,Kucukdere,Küçük Gorgor,Küçükdere', 40.8074800, 40.0551200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128314, 'Kozlu', 'Kozlu', 'Koslu,Kozlu', 41.4319400, 31.7458300, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128315, 'Kozlu', 'Kozlu', 'Kozlu,Козлу', 40.6087800, 36.4785800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128316, 'Kozcağız', 'Kozcagiz', 'Ahmetler,Kozcagiz,Kozcağız', 41.4833300, 32.3333300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128317, 'Koyulhisar', 'Koyulhisar', 'Kojul''khisar,Koyulhisar,Koyunhisar,Misaz,Mişaz,Коюльхисар', 40.3018400, 37.8233600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128318, 'Kovanlık', 'Kovanlik', 'Kovanlik,Kovanlikkoy,Kovanlyk,Kovanlık,Kovanlıkköy,Kuvanlik,Kuvanlikkoy,Kuvanlık,Kuvanlıkköy,Кованлык', 40.7548400, 38.1115500, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128319, 'Kötek', 'Kotek', 'Ketek,Koetek,Kotek,Kötek,Кетек', 40.2185000, 43.0022000, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128320, 'Köseköy', 'Kosekoy', 'Kocaeli,Kose,Kosekoy,Köse,Köseköy', 40.7401200, 30.0055600, 'TR', '2017-05-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128321, 'Köse', 'Kose', 'Kose,Köse', 40.2069200, 39.6462600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128322, 'Koruköy', 'Korukoy', 'Koru,Koru Koyu,Koru Köyü,Korukoy,Koruköy,Kuru Kioi,Kuru Koru,Kuru Koyu,Kuru Körü,Kuru Köyü', 40.6543500, 29.1628900, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128323, 'Korgun', 'Korgun', 'Korgan,Korgun', 40.7347900, 33.5184400, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128324, 'Korgan', 'Korgan', 'Korgan,Корган', 40.8247200, 37.3466700, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128325, 'Köprübaşı', 'Koprubasi', 'Koprubasi,Köprübaşı,Sarki Gonesera,Sarki Gonesra,Sarkigunesera,Sarkigunesere,Şarki Göneşra,Şarkigüneşera,Şarkigüneşere,Şarkî Goneşera', 40.8069200, 40.1143900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128326, 'Konuralp', 'Konuralp', 'Konuralp,Uskubu,Üskübü', 40.9053800, 31.1456800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128327, 'Kolay', 'Kolay', 'Kolay', 41.4182400, 35.8013600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128328, 'Saltukova', 'Saltukova', 'Kokaksu,Saltukova', 41.5202200, 32.0962100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128329, 'Kofçaz', 'Kofcaz', 'Kesirlik,Keşirlik,Kofcagiz,Kofcaz,Kofçaz,Kofçağız', 41.9448100, 27.1582900, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128330, 'Kocadere', 'Kocadere', 'Asagi Kocadere,Aşagı Kocadere,Kocadere', 40.6300000, 29.0300000, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128331, 'Kocaali', 'Kocaali', 'Kocaali,Kocali,Kocalı,Yukari Kocaali,Yukarı Kocaali', 41.0533600, 30.8527800, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128332, 'Kızılırmak', 'Kizilirmak', 'Huseyinli,Hüseyinli,Kizilirmak,Kızılırmak', 40.3455600, 33.9863900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128333, 'Kızılcahamam', 'Kizilcahamam', 'Kizicahamam,Kizilcahamam,Kyzyldzhakhamam,Kızıcahamam,Kızılcahamam,Yabanabat,ke zi lei gu ha ma mu,КъызылджахӀамам,Кызылджахамам,ضلع کزلجاہمام,قزلچه‌حمام,克孜勒賈哈馬姆', 40.4697200, 32.6505600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128334, 'Salmydessus', 'Salmydessus', 'Kiyikoy,Kıyıköy,Medea,Midia,Midiah,Midye,Salmydessus', 41.6347600, 28.0945900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128335, 'Kışlaköy', 'Kislakoy', 'Kislakoy,Kışlaköy', 40.3235300, 42.0223300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128336, 'Kırklareli', 'Kirklareli', 'Kirk Kilise,Kirk Kilisse,Kirk-Kilissa,Kirklareli,Kirklarelis,Kyrklareli,Kırklareli,Lozen,Lozengrad,Qirxlareli,Qırxlareli,Saranta Ekklesiai,Saranta Ekklēsiai,ke er ke la lei li,kileukeullalelli,kirakalaleri,kirklareli,krklaryly,kurukurareri,qrqlr ayly,qrqlrayly,Κιρκλαρελί,Киркларелі,Кыркларели,Лозенград,قرقلر ايلي,قرقلرایلی,کرکلاریلی,ਕਿਰਕਲਾਲੇਰੀ,ქირქლარელი,クルクラーレリ,克爾克拉雷利,키르클라렐리', 41.7350800, 27.2252100, 'TR', '2012-01-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128337, 'Kırcasalih', 'Kircasalih', 'Kircasalih,Kırcasalih,Zalif,Zalof', 41.3901900, 26.7949600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128338, 'Dikmen', 'Dikmen', 'Dikmen,Kircal,Kircali,Kırçal,Kırçalı', 41.6500000, 35.2666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128339, 'Gelegra', 'Gelegra', 'Gelegra,Kirbasi,Kırbaşı', 40.0137800, 31.8319700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128340, 'Kirazlı', 'Kirazli', 'Kirazli,Kirazlı', 40.0996400, 29.0416300, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128341, 'Kirazlı', 'Kirazli', 'Kirazli,Kirazli Koy,Kirazlı,Kirazlı Köy', 40.0417600, 26.7009000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128342, 'Kınalı', 'Kinali', 'Kinali,Kinaliada,Kınalı,Kınalıada,Proti,Кинали', 40.9071300, 29.0549900, 'TR', '2012-10-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128343, 'Kilimli', 'Kilimli', 'Kilimli', 41.4911100, 31.8386100, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128344, 'Kılıçkaya', 'Kilickaya', 'Ersis,Kilickaya,Kılıçkaya', 40.7047100, 41.4738500, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128345, 'Kılıç', 'Kilic', 'Kilic,Kilinc,Kılınç,Kılıç', 40.6330600, 29.3947200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128346, 'Kıbrıscık', 'Kibriscik', 'Karadogan,Karadoğan,Kibriscik,Kıbrıscık', 40.4077800, 31.8519400, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128347, 'Kestel', 'Kestel', 'Kestel', 40.1982800, 29.2123700, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128348, 'Keşap', 'Kesap', 'Kesap,Keshap,Keşap,Кешап', 40.9103200, 38.5013000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128349, 'Keşan', 'Kesan', 'Kesan,Keshan,Keşan,Кешан', 40.8558300, 26.6302800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128350, 'Kemerburgaz', 'Kemerburgaz', 'Kemerburgaz,Pirgos', 41.1590200, 28.9157200, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128351, 'Kemalpaşa', 'Kemalpasa', 'Kemalpasa,Kemalpaşa,Makriyal', 41.4783900, 41.5150400, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128352, 'Kelkit', 'Kelkit', 'Ciftlik,Kel''kit,Kelkit,klkyt,Çiftlik,Келькит,کلکیت', 40.1268200, 39.4342400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128353, 'Kazan', 'Kazan', 'Kazan,Kuazan,Казан,Къазан,ضلع کازان,کازان، انقرہ', 40.2316700, 32.6838900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128354, 'Kaytazdere', 'Kaytazdere', 'Kaytazdere', 40.6822500, 29.5323600, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128355, 'Kaynaşlı', 'Kaynasli', 'Kaynasli,Kaynaşlı', 40.7691700, 31.3221100, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128356, 'Kaynarca', 'Kaynarca', 'Kaynarca,Kucuk Kaynarca,Küçük Kaynarca,Seyhler,Seyhlue,Şeyhler,Şeyhlü', 41.0308300, 30.3075000, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128357, 'Kaymas', 'Kaymas', 'Araman,Arman,Kaymas,Kaymaz,Salmanli,Salmanlı', 40.9231000, 30.2659700, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128358, 'Kavaklı', 'Kavakli', 'Fetekoy,Feteköy,Kavakli,Kavakly,Kavaklı,Каваклы', 41.0925800, 28.3317200, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128359, 'Kavak', 'Kavak', 'Kavak,Кавак', 41.0783300, 36.0425000, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128360, 'Kastamonu', 'Kastamonu', 'Castamena,Castamon,Castamoni,Castamonu,Castamuni,KFS,Kastambul,Kastamoni,Kastamonu,Kastamouni,Kastamuni,Kastamuniyah,Qastamuni,Qestamonu,ka si ta mo nu,kaseutamonu,kastamanw,kastamwnw,kasutamonu,qstmwny,Κασταμονή,Кастамону,Касҭамону,قسطموني,قسطمونی,کاستامانو,کاستامونو,კასთამონუ,カスタモヌ,卡斯塔莫努,카스타모누', 41.3780500, 33.7752800, 'TR', '2013-05-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128361, 'Beycuma', 'Beycuma', 'Beycuma,Kasimlar,Kasımlar', 41.3281200, 31.9681100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128362, 'Kars', 'Kars', 'Cars,Gorad Kars,KSY,Kapc,Kars,Karsa,Karsas,Khuars,Kuars,Qars,Qers,Vanand,ka er si,kaleuseu,kar s,karasa,kars,karusu,qars,Καρς,Горад Карс,Карс,Къарс,Хъарс,Ҟарс,Կարս,קארס,قارص,قەرس,كارس,کارس,ਕਾਰਸ,การ์ส,ყარსი,カルス,卡爾斯,카르스', 40.5982500, 43.0854800, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128363, 'Kargı', 'Kargi', 'Kargi,Kargı', 41.1337300, 34.4874400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128364, 'Karayaka', 'Karayaka', 'Karajaka,Karakaya,Karayaka,Zidi,Zigdi,Zigri,Ziğdi,Ziğri,Караяка', 40.7440200, 36.5901800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128365, 'Karaurgan', 'Karaurgan', 'Karaurgan,Караурган', 40.2396400, 42.2728300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128366, 'Karasu', 'Karasu', 'Incili,Incirli,Karasu,İncili,İncirli', 41.1044200, 30.6966400, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128367, 'Karasu', 'Karasu', 'Aksu,Karasu,Карасу', 41.0709600, 30.7854300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128368, 'Karaşar', 'Karasar', 'Karasar,Karaşar', 40.3257300, 31.9868200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128369, 'Karapürçek', 'Karapurcek', 'Karapurcek,Karapürçek', 40.6419400, 30.5394400, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128370, 'Oğuzlar', 'Oguzlar', 'Karaoren,Karaveren,Karaviran,Karaören,Oguzlar,Oğuzlar', 40.7535300, 34.7027500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128371, 'Karamürsel', 'Karamursel', 'Karamursel,Karamusal,Karamürsel', 40.6914400, 29.6156800, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128372, 'Karakurt', 'Karakurt', 'Karakurt,Каракурт', 40.1659100, 42.6045300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128373, 'Karakasım', 'Karakasim', 'Karakasim,Karakasım', 41.5171800, 26.6438100, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128374, 'Karadere', 'Karadere', 'Karadere', 40.7317400, 30.8399200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128375, 'Karacaköy', 'Karacakoy', 'Karacakoy,Karacaköy', 41.4033800, 28.3805500, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128376, 'Karacaköy', 'Karacakoy', 'Karaca,Karacakoy,Karacaköy', 41.1512600, 29.7693500, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128377, 'Karacabey', 'Karacabey', 'Karacabey,Karadzhabej,Mihalic,Mihaliç,Miletopolis,Muhalich,Караджабей', 40.2132300, 28.3612000, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128378, 'Karabulduk', 'Karabulduk', 'Karabulduk', 40.8204300, 38.5494100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128379, 'Karabük', 'Karabuk', 'Karabiukas,Karabjuk,Karabuek,Karabuk,Karabük,Karampouk,Qerebuk,ka la bi ke,ka la bi ke sheng,kalabwikeu,karabuka,karabwk,karabyukku,Καραμπούκ,Карабук,Карабюк,Карабүк,Карабӱк,قره‌بوک,قرہ بوک,كارابوك,کارابوک,ਕਾਰਾਬੁਕ,ყარაბუქი,カラビュック,卡拉比克,卡拉比克省,카라뷔크', 41.2048800, 32.6276800, 'TR', '2015-08-01', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128380, 'Karabiga', 'Karabiga', 'Karabiga,Karabigha,Karabogha,Karabuga,Karabıgha,Priapus', 40.4036100, 27.3038900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128381, 'Kaptanpaşa', 'Kaptanpasa', 'Kaptanpasa,Kaptanpasha,Kaptanpaşa,Каптанпаша', 40.9606700, 40.7823800, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128382, 'Kapaklı', 'Kapakli', 'Kapakli,Kapaklı', 41.3291200, 27.9806400, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128383, 'Kandıra', 'Kandira', 'Kandira,Kandıra', 41.0700000, 30.1526200, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128384, 'Kâmil', 'Kamil', 'Kamil,Kâmil', 41.1036400, 34.7629800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128385, 'Kalkandere', 'Kalkandere', 'Kalkandere,Karadere,Medrese,Медресе', 40.9204600, 40.4369200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128386, 'Kalecik', 'Kalecik', 'Kalecik,Kaledzhik,Kualedzhik,Каледжик,Къаледжик,ضلع کالیجک,قلعہ جیک، انقرہ', 40.0972200, 33.4083300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128387, 'Kale', 'Kale', 'Kale,Кале', 40.3868800, 39.6833200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128388, 'Kağızman', 'Kagizman', 'Kagizman,Kagyzman,Kağızman,Кагызман', 40.1566900, 43.1342400, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128389, 'Evreşe', 'Evrese', 'Evrese,Evreşe,Kadikoy,Kadikoyu,Kadıköy', 40.6666700, 26.8833300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128390, 'Kadıköy', 'Kadikoy', 'Kadikoy,Kadıköy', 40.6201500, 29.2253600, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128391, 'Kabataş', 'Kabatas', 'Kabatas,Kabataş,Karay', 40.7500000, 37.4500000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128392, 'Kabalı', 'Kabali', 'Kabali,Kabalı', 41.8521100, 35.0624900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128393, 'Kabadüz', 'Kabaduz', 'Kabadjuz,Kabaduez,Kabaduz,Kabadüz,Кабадюз', 40.8609600, 37.8847000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128394, 'İznik', 'Iznik', 'Isnik,Iznik,Nicaea,Nicea,Nicee,Nicée,Nikaia,izuniku,nikaia,İznik,Изник,イズニク,ニカイア', 40.4286100, 29.7211100, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128395, 'İzmit', 'Izmit', 'Astacus,Cocaeli,Ismid,Ismit,Isnimid,Izmid,Izmit,Kodja-Eli,Koja-Ili,Nicomedia,Nicomedie,Nicomédie,Nikomedeia,Nikomedia,izumitto,yi zi mi te,İzmit,Измит,イズミット,伊兹密特', 40.7669400, 29.9169400, 'TR', '2014-03-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128396, 'İyidere', 'Iyidere', 'Ficibasi,Ficitasi,Fıçıbaşı,Fıçıtaşı,Iyidere,İyidere', 41.0119200, 40.3618500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128397, 'İstanbul', 'Istanbul', 'Bizanc,Bizánc,Byzance,Byzantion,Byzantium,Byzanz,Constantinoble,Constantinopla,Constantinople,Constantinopolen,Constantinopoli,Constantinopolis,Costantinopoli,Estambul,IST,Istamboul,Istambul,Istambuł,Istampoul,Istanbul,Istanbúl,Isztambul,Konstantinapoly,Konstantinopel,Konstantinopolo,Konstantinoupole,Konstantinoupoli,Konstantinoupolis,Konstantinápoly,Kustantiniyah,Micklagard,Micklagård,Mikligardur,Mikligarður,Stamboul,Stambul,Stambula,Stambuł,Tsarigrad,Vizantija (Vizantija),Vyzantio,astnbwl,bijantium,byuzantion,byzntywn,iseutanbul,istambula,isutanburu,stin Poli [stimˈboli],yi si tan bu er,İstanbul,Βυζάντιο,Βυζαντιο,Ισταμπουλ,Ισταμπούλ,Κωνσταντινουπολη,Κωνσταντινούπολη,Κωνσταντινούπολις,στην Πόλι [stimˈboli],Византија (Vizantija),Истанбул,Стамбул,ביזנטיון,اسطنبول,इस्तांबुल,イスタンブール,ビュザンティオン,伊斯坦布尔,비잔티움,이스탄불', 41.0138400, 28.9496600, 'TR', '2017-06-22', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128398, 'İspir', 'Ispir', 'Ispir,İspir,Испир', 40.4798100, 40.9937300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128399, 'İskilip', 'Iskilip', 'Andrapa,Iskelib,Iskilip,Neapolis,Neoclaudiopolis,İskilip', 40.7352800, 34.4738900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128400, 'İpsala', 'Ipsala', 'Ipsala,İpsala', 40.9211500, 26.3827300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128401, 'İntepe', 'Intepe', 'Arenkioi,Eren Keui,Erenkoy,Erenköy,Ghelmez,Intepe,İntepe', 40.0133300, 26.3328700, 'TR', '2016-12-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128402, 'Boyalı', 'Boyali', 'Boyali,Boyalı,Intas,İntas', 41.0271000, 33.3041000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128403, 'İnhisar', 'Inhisar', 'Inhisar,İnhisar', 40.0493200, 30.3852100, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128404, 'İnegol', 'Inegol', 'Inegeul,Inegoel,Inegol,İnegöl', 40.0780600, 29.5133300, 'TR', '2015-07-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128405, 'İnecik', 'Inecik', 'Inecek,Inecik,İnecek,İnecik', 40.9351800, 27.2811800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128406, 'İnece', 'Inece', 'Inece,Yenice,Yenioe,İnece', 41.6774700, 27.0678600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128407, 'İnebolu', 'Inebolu', 'Abonutichus,Ineboli,Inebolu,Inebolua,Ionopolis,Niopoli,Niopolis,İnebolu', 41.9747200, 33.7608300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128408, 'Gökçeada', 'Gokceada', 'GKD,Goekceada,Gokce,Gokceada,Gökçe,Gökçeada,Imroz,Panagia,İmroz', 40.2010700, 25.9090200, 'TR', '2013-03-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128409, 'Yarhisar', 'Yarhisar', 'Ilyasbey,Yarhisar,İlyasbey', 40.2167300, 29.8708800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128410, 'Ilgaz', 'Ilgaz', 'Ilgaz,Kochisarbala,Kochisaribala,Koçhisarbalâ,Koçhisarıbala', 40.9251100, 33.6258600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128411, 'İkizören', 'Ikizoren', 'Babsa,Bapsa,Ikizoren,İkizören', 40.6883300, 33.8833300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128412, 'İkizdere', 'Ikizdere', 'Cagiran Kaya,Cagrankaya,Cağrankaya,Cağıran Kaya,Ikizdere,Kurai Seba,Kurayisab"a,Kuraysaba,Kurayısab”a,Kureiseba,Kurreiseba,Küreiseba,Kürreiseba,İkizdere,Икиздере', 40.7748400, 40.5522700, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128413, 'İkizce', 'Ikizce', 'Ikizce,Lalelimaabeyceli,Lalelimabeyceli,Lâlelimaabeyceli,İkizce', 41.0583300, 37.0802800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128414, 'İhsaniye', 'Ihsaniye', 'Ihsaniye,İhsaniye', 40.6908700, 29.8347200, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128415, 'İhsangazi', 'Ihsangazi', 'Ihsangazi,Merguze,Mergüze,İhsangazi', 41.2043200, 33.5545500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128416, 'İğneada', 'Igneada', 'Igneada,Inada,Iniada,İğneada', 41.8744400, 27.9838900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128417, 'İğdir', 'Igdir', 'Igdir,Samatlar,İğdir', 41.2261700, 33.1369900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128418, 'İğdir', 'Igdir', 'Igdir,İğdir', 40.2663300, 35.6264500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128419, 'İbriktepe', 'Ibriktepe', 'Ibriktepe,İbriktepe', 41.0103700, 26.5034300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128420, 'Horasan', 'Horasan', 'Horasan,Khorasan,Хорасан', 40.0388500, 42.1636600, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128421, 'Hopa', 'Hopa', 'Apsarus,Hopa,Khopa,Khoppa,XHQ,hopa,huo pa,hwpa,khopa,Хопа,ضلع ہوپا,هوپا,ہوپا,ხოფა,ホパ,霍帕', 41.3904600, 41.4196600, 'TR', '2013-05-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128422, 'Filyos', 'Filyos', 'Filios,Filyos,Hisaronu,Hisaroso,Hisarönü,Hisarösö,Philios,Tieum', 41.5538300, 32.0238900, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128423, 'Hereke', 'Hereke', 'Asagi Hereke,Aşağı Hereke,Hereke,Herekefabrikasi,Herekefabrikası', 40.7861100, 29.6147200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128424, 'Hendek', 'Hendek', 'Hendek,Khandak', 40.7994400, 30.7480600, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128425, 'Nurluca', 'Nurluca', '', 41.0351900, 40.9058400, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128426, 'Güzelkent', 'Guzelkent', 'Guzelkent,Güzelkent,Halalli,Halallı,Halatli,Halatlı,Helaldi,Helaldı', 41.9484300, 34.3945000, 'TR', '2015-10-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128427, 'Hayrat', 'Hayrat', 'Gunesalan,Güneşalan,Hayrat,Nefsihundez,Nefsihündez', 40.8853000, 40.3649500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128428, 'Hayrabolu', 'Hayrabolu', 'Hayrabolu', 41.2131100, 27.1068800, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128429, 'Havza', 'Havza', 'Havza,Khavza,Thermae Phazemonitarum,Хавза', 40.9705600, 35.6622200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128430, 'Havsa', 'Havsa', 'Hafsa,Havsa', 41.5489800, 26.8220700, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128431, 'Hasköy', 'Haskoy', 'Haskoy,Hasköy', 41.6382200, 26.8574600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128432, 'Hasköy', 'Haskoy', 'Haskoey,Haskoy,Hasköy,Hocuvan,Hoçuvan,Khaskej,Хаскей', 40.9910600, 42.8839600, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128433, 'Hasayaz', 'Hasayaz', 'Hasayaz', 40.2406700, 33.3280000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128434, 'Hanönü', 'Hanonu', 'Gokceagac,Gökçeağaç,Hanonu,Hanönü', 41.6270500, 34.4666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128435, 'Hanak', 'Hanak', 'Hanak,Khanak,Ortahanak,Ханак', 41.2334400, 42.8403700, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128436, 'Hamzabey', 'Hamzabey', 'Hamzabey', 40.1358300, 29.5263900, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128437, 'Hamidiye', 'Hamidiye', 'Hamidiye', 41.1512800, 26.6641100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128438, 'Dedeköy', 'Dedekoy', '', 40.7475200, 35.0424900, 'TR', '2011-03-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128439, 'Hamamözü', 'Hamamozu', 'Hamamozu,Hamamözü', 40.7847600, 35.0258000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128440, 'Perşembe', 'Persembe', 'Hacikadi,Hacıkadı,Persembe,Perşembe', 41.4186700, 32.1598400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128441, 'Hacıhamza', 'Hacihamza', 'Hacihamza,Hacihamza Koy,Hacıhamza,Hacıhamza Köy', 41.0743000, 34.4490000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128442, 'Dokurcun', 'Dokurcun', 'Dokurcun', 40.5732000, 30.8678400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128443, 'Çayırova', 'Cayirova', 'Akkilise,Akkilişe,Aksekoy,Akseköy,Cayirova,Guzeltepe,Güzeltepe,Çayırova', 40.8344400, 29.4000000, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128444, 'Güvem', 'Guvem', 'Guvem,Güvem', 40.5906900, 32.6611100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128445, 'Gürsu', 'Gursu', 'Gursu,Gürsu', 40.2187600, 29.1948700, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128446, 'Gürpınar', 'Gurpinar', 'Anarsa,Anarşa,Gjurpynar,Gurpinar,Gürpınar,Гюрпынар', 40.9925600, 28.6142800, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128447, 'Gürgentepe', 'Gurgentepe', 'Akmescit,Gurgentepe,Gürgentepe', 40.7856700, 37.5896900, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128448, 'Güneysu', 'Guneysu', 'Guneysu,Güneysu,Ulucami', 40.9813000, 40.6046500, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128449, 'Kırık', 'Kirik', 'Gueneykoey,Guneykoy,Güneyköy,Hoka,Khoka,Kirik,Kırık,Хока', 40.3279400, 40.9186300, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128450, 'Güneyce', 'Guneyce', 'Guneyce,Guneyce Kasabasi,Güneyce,Güneyce Kasabası', 40.8209500, 40.4703500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128451, 'Gündoğdu', 'Gundogdu', 'Gjundogdu,Guendogdu,Gundogdu,Gündoğdu,Hamidiye,Гюндогду', 41.0531900, 40.6066400, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128452, 'Gündoğdu', 'Gundogdu', 'Gundogdu,Gündoğdu,Karanti', 40.2640800, 27.0928800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128453, 'Gümüşova', 'Gumusova', 'Gumusova,Gümüşova,Kisla,Kislakoy,Kışla,Kışlaköy', 40.8469400, 30.9411100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128454, 'Gumushkhane', 'Gumushkhane', 'Argyroupoli,Gjumjushane,Guemueshane,Gumusane,Gumushane,Gumushkhane,Gümüşane,Gümüşhane,Nkioumouschane,Αργυρούπολη,Γκιουμούσχανε,Гюмюшане', 40.4600100, 39.4717600, 'TR', '2016-05-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128455, 'Gümüşhacıköy', 'Gumushacikoy', 'Gumushacikoy,Gümüşhacıköy,Hacikoey,Hacıköy,hajy kwy,حاجی کوی', 40.8730600, 35.2147200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128456, 'Dimetoka', 'Dimetoka', 'Dimetoka,Gumuscay,Gümüşçay', 40.2822800, 27.2820500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128457, 'Gümüş', 'Gumus', 'Gumus,Gümüş', 40.8401800, 35.1719500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128458, 'Güdül', 'Gudul', 'Godul,Gudul,Gödul,Güdül', 40.2105100, 32.2455200, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128459, 'Akkaya', 'Akkaya', 'Akkaya,Gozkece,Gözkeçe', 41.2191300, 33.4848700, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128460, 'Göynük', 'Goynuk', 'Goynuk,Göynük,Torbali,Torbalı', 40.4002800, 30.7883300, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128461, 'Göynücek', 'Goynucek', 'Goynucek,Göynücek', 40.3991700, 35.5250000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128462, 'Görükle', 'Gorukle', 'Gorukle,Gurukle,Görükle,Gürükle,Korukle,Körükle', 40.2311400, 28.8401700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128463, 'Görele', 'Gorele', 'Elehu,Elevi,Gerele,Goerele,Gorele,Gurele,Görele,Gürele,Philocalia,Гереле', 41.0308300, 39.0030600, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128464, 'Gönen', 'Gonen', 'Gonan,Gonen,Gönan,Gönen,Гонен', 40.1049000, 27.6539900, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128465, 'Gölyaka', 'Golyaka', 'Golkaya,Golova,Golyaka,Gulkaya,Gölkaya,Gölova,Gölyaka,Gülkaya,Imamlar,İmamlar', 40.7769000, 30.9958700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128466, 'Gölpazarı', 'Golpazari', 'Golpazari,Gölpazarı', 40.2847200, 30.3172200, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128467, 'Gölova', 'Golova', 'Agvanis,Ağvanis,Goelova,Golova,Gölova,Агванис', 40.0619400, 38.6066700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128468, 'Balarim', 'Balarim', 'Balarim,Balarin,Baların,Golluce,Göllüce', 40.3738100, 29.5902500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128469, 'Kömürlü', 'Komurlu', 'Gollet,Göllet,Komurlu,Kömürlü', 40.7353900, 42.2881900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128470, 'Gölköy', 'Golkoy', 'Golkoy,Gölköy,Kusluvan,Kusluyan,Kuşluvan,Kuşluyan', 40.6868900, 37.6154400, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128471, 'Merdinik', 'Merdinik', 'Gole,Göle,Merdenek,Merdenik,Merdinik', 40.7874600, 42.6060300, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128472, 'Gölcük', 'Goelcuek', 'Geulzuk,Goelcuek,Gölcük', 40.7032300, 29.8721600, 'TR', '2015-08-13', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128473, 'Murgul', 'Murgul', 'Gektash,Goktas,Göktaş,Murgul,Гекташ,Мургул', 41.2793700, 41.5551400, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128474, 'Gökdere', 'Gokdere', 'Cilkoru,Gekdere,Goekdere,Gokdere,Gökdere,Çilkoru,Гекдере', 40.4729200, 36.7525000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128475, 'Gökçeli', 'Gokceli', 'Gekcheli,Goekceyazi,Gokceli,Gokceyazi,Gökçeli,Gökçeyazı,Ladik,Lâdik,Гекчели', 40.5833300, 36.7333300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128476, 'Gökçesu', 'Gokcesu', 'Cakirlar,Gokcesu,Gökçesu,Salipazari,Salıpazarı,Çakırlar', 40.8938900, 31.9595700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128477, 'Gökçekent', 'Gokcekent', 'Goekcekent,Gokcekent,Goredeibala,Gökçekent,Göredeibalâ,Jukary-Gerede,Naipli,Yukari Gerdek,Yukari Gerede,Yukari Gorede,Yukarı Gerdek,Yukarı Gerede,Yukarı Görede,Юкары-Гереде', 40.2864400, 38.1177100, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128478, 'Gökçebey', 'Gokcebey', 'Gokcebey,Gökçebey,Tefen', 41.3058300, 32.1423400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128479, 'Göbel', 'Gobel', 'Gobel,Göbel', 40.0197200, 28.1455600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128480, 'Giresun', 'Giresun', 'Cerasus,Choerades,Gireson,Giresun,Giresunas,Kerasounta,Kerassunde,Kerasun,Kerasunda,Kerasunt,Kiresun,OGU,Pharnacia,ghyrswn,gilesun,giresun,giresuni,grysn,gryswn,ji lei song,Κερασούντα,Гиресун,Ґіресун,Կերասուն,غيرسون,گره‌سون,گریسن,گریسون,გირესუნი,ギレスン,吉雷松,기레순', 40.9169800, 38.3874100, 'TR', '2015-09-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128481, 'Geyve', 'Geyve', 'Geiveh,Geyve,Tottaeum,kywh,کیوه', 40.5075000, 30.2925000, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128482, 'Gerze', 'Gerze', 'Carusa,Gerze,Gherseh,Gherzeh', 41.8036100, 35.2011100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128483, 'Gerede', 'Gerede', 'Crateia Flaviopolis,Gerede,Geredeh,gai lei dai,grdh,Гереде,ضلع گرید,گرده,蓋雷代', 40.8008300, 32.1969400, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128484, 'Çiftlik', 'Ciftlik', 'Ciftlik,Ciftlikkoy,Gencaga Ciftligi,Gençağa Çiftliği,Çiftlik,Çiftlikköy', 40.0723400, 42.2561700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128485, 'Gemlik', 'Gemlik', 'Cius,Gemlik,Kios,Kiye,Гемлик', 40.4309400, 29.1596900, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128486, 'Gelibolu', 'Gelibolu', 'Callipolis,Galipoli,Galipolo,Gallipoli,Gal·lípoli,Galípoli,Gelibolu,Guelibolou,Guélibolou,Kallipolis,Nkelimpolou,gai li bo lu,gellibollu,geriboru,gly bwlw,glybwlw,Γκελίμπολου,Галиполи,Гелиболу,Геліболу,گلی بولو,گلیبولو,ゲリボル,蓋利博盧,겔리볼루', 40.4102800, 26.6708300, 'TR', '2014-03-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128487, 'Gediksaray', 'Gediksaray', 'Gediksaray,Varay', 40.4452900, 35.6262700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128488, 'Gebze', 'Gebze', 'Gebze,Gebzė,Gorad Gebze,Guebze,Libyssa,gai bu ze,gbzh,gebuze,kkbwzh,Гебзе,Горад Гебзе,ضلع گیبزے,ککبوزه,گبزه,گەبزە,ゲブゼ,蓋布澤', 40.8027600, 29.4306800, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128489, 'Gaziler', 'Gaziler', 'Gaziler,Газилер', 40.4215300, 42.3479900, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128490, 'Gaziler', 'Gaziler', 'Gaziler,Pernavut,Газилер', 40.0812500, 43.4518700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128491, 'Fındıklı', 'Findikli', 'Findikli,Fındıklı,Gavra', 41.2690000, 41.1400200, 'TR', '2013-12-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128492, 'Ferizli', 'Ferizli', 'Ferizli', 40.9408200, 30.4858300, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128493, 'Fatsa', 'Fatsa', 'Fatisa,Fatsa,Fatseh,Fatza,Phadisana,Phadısana,Polemonium,Side,Фатса', 41.0277800, 37.5013900, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128494, 'Eynesil', 'Eynesil', 'Dereishakli,Dereishaklı,Deresakli,Deresaklı,Ehjnesil'',Eynesil,Эйнесиль', 41.0643600, 39.1427400, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128495, 'Eymir', 'Eymir', 'Eymir', 40.0192700, 35.2078800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128496, 'Eğerci', 'Egerci', 'Egerci,Egercili,Eyerci,Eğerci,Eğercili', 41.0992200, 31.8173900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128497, 'Evren', 'Evren', 'Evren,Sefker,Sevker,Sofker,Söfker', 40.2452700, 39.1753500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128498, 'Eskipazar', 'Eskipazar', 'Eskipazar,Mecidiye,Viransehir,Viranşehir,Wiranschehir', 40.9429800, 32.5309100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128499, 'Gözyeri', 'Gozyeri', 'Gozyeri,Gözyeri', 40.8659600, 32.5416700, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128500, 'Esiroğlu', 'Esiroglu', 'Ehsiroglu,Esiroglu,Esiroglu Mevkii,Esiroğlu,Esiroğlu Mevkii,Эсироглу', 40.8733100, 39.6882900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128501, 'Esenyurt', 'Esenyurt', 'Eksinoz,Ekşinoz,Esenyurt,Eskiyuz,Eskiyüz', 41.0269700, 28.6773200, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128502, 'Esenler', 'Esenler', 'Litros', 41.0435000, 28.8761900, 'TR', '2014-01-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128503, 'Esençay', 'Esencay', 'Bidevi,Esencay,Esençay', 40.6680600, 36.3802800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128504, 'Erfelek', 'Erfelek', 'Erfelek,Karasu,Salavat', 41.8792600, 34.9183800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128505, 'Erenler', 'Erenler', 'Erenler', 40.7550400, 30.3934400, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128506, 'Ereğli', 'Eregli', 'Bender Erekli,Bender-Eregli,Bender-Ereğli,Ehregli,Eregli,Erekli,Ereğli,Ergeli,Heraclea Pontica,Heraklea,Karadenizereglisi,Karadenizereğlisi,Эрегли', 41.2826100, 31.4180600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128507, 'Erdek', 'Erdek', 'Artace,Artaki,Erdek,Erdeku,ardk,اردک', 40.3996000, 27.7934800, 'TR', '2013-06-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128508, 'Erbaa', 'Erbaa', 'Ehrba,Erbaa,Herek,Эрба', 40.6688900, 36.5675000, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128509, 'Enez', 'Enez', 'Aenus,Aynos,Enez,Enos', 40.7247200, 26.0825000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128510, 'Eminönü', 'Eminoenue', 'Ehminjonju,Saray,Seraglio,Serai,Эминёню', 41.0176600, 28.9743800, 'TR', '2012-10-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128511, 'Eldivan', 'Eldivan', 'Dumeli,Dumeli Kasabasi,Dümeli,Dümeli Kasabası,Eldivan', 40.5297500, 33.4990300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128512, 'Elbeyli', 'Elbeyli', 'Elbeyli', 40.4861100, 29.7247200, 'TR', '2013-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128513, 'Eflani', 'Eflani', 'Celebiler,Eflani,Çelebiler', 41.4228900, 32.9576100, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128514, 'Edirne', 'Edirne', 'Adrianapolis,Adrianopel,Adrianople,Adrianopoja,Adrianopol,Adrianopoli,Adrianopolis,Adrianoupoli,Adrianoupolis,Adrianòpolis,Adrinople,Andrianoplin,Andrinople,Andrinòple,Drinapoly,Drinopolje,Drinápoly,Ederne,Ederné,Edirnae,Edirne,Edirnä,Edirnė,Edrene,Ehdirne,Gorad Ehdyrneh,Hadrianople,Hadrianopolis,Jedrene,Odrin,Odrín,adrnh,adrnt,ai di er nei,edileune,edirane,edirne,edirune,xe dirne,Édirne,Ədirnə,Αδριανούπολη,Једрене,Горад Эдырнэ,Едрене,Едірне,Одрин,Эдирне,Ադրիանապոլիս,אדירנה,أدرنة,ادرنه,ادرنہ,ਏਦਿਰਨੇ,เอดีร์เน,အီဒါးနီမြို့,ედირნე,エディルネ,埃迪爾內,에디르네', 41.6771900, 26.5559700, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128515, 'Edincik', 'Edincik', 'Aidinjik,Aidinjk,Aydincik,Aydıncık,Edincik,aydnjk,aydnjq,ایدنجق,ایدنجک', 40.3422900, 27.8612900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128516, 'Eceabat', 'Eceabat', 'Acaabat,Açaabat,Eceabat,Madytus,Maidos,Maitos,Maydos', 40.1841600, 26.3574000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128517, 'Düzköy', 'Duzkoy', 'Duzkoy,Düzköy', 40.8746100, 39.4153600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128518, 'Düzce', 'Duzce', 'Dusje,Duzce,Duzdje,Düzce', 40.8388900, 31.1638900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128519, 'Durusu', 'Durusu', 'Durusu,Terkos', 41.3033700, 28.6763500, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128520, 'Durağan', 'Duragan', 'Duragan,Durağan', 41.4158300, 35.0544400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128521, 'Dumlu', 'Dumlu', 'Dumlu,Hins,Khins,Хинс', 40.0586200, 41.3565400, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128522, 'Dörtdivan', 'Dortdivan', 'Cavuslar,Dortdivan,Dörtdivan,Çavuşlar', 40.7205200, 32.0631400, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128523, 'Karşıyaka', 'Karsiyaka', 'Dongel,Döngel,Karsiyaka,Karşıyaka', 40.6936000, 29.9415400, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128524, 'Dökmetepe', 'Dokmetepe', 'Ahir,Ahirkoyu,Ahur,Ahurkoyu,Ahurköyü,Ahır,Ahırköyü,Dekmetepe,Dikmetepe,Doekmetepe,Dokmetepe,Dökmetepe,Декметепе', 40.3122400, 36.2918000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128525, 'Doğruyol', 'Dogruyol', 'Cala,Chala,Dogrujol,Dogruyol,Doğruyol,Догруйол', 40.9798600, 43.4709800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128526, 'Doğanyurt', 'Doganyurt', 'Doganujurt,Doganyurt,Doğanyurt,Hosalay,Hoşalay,Meset,Доганъюрт', 42.0045700, 33.4602900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128527, 'Doğanyurt', 'Doganyurt', 'Dogan"jurt,Doganyurt,Doğanyurt,Hayati,Доганъюрт', 40.6880600, 36.7163900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128528, 'Doğantepe', 'Dogantepe', 'Dogantepe,Doğantepe,Zara', 40.5977800, 35.6041700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128529, 'Doğanşar', 'Dogansar', 'Dogansar,Doganshar,Doğanşar,Ipsala,Ipsile,Ipsili,Tozanli,Tozanlı,Tozonli,Tozonlı,İpsala,İpsile,İpsili,Доганшар,Ипсиле', 40.2084100, 37.5312300, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128530, 'Doğankent', 'Dogankent', 'Dogankent,Doğankent,Harsit,Harşit,Manastirbuku,Manastırbükü,Доганкент', 40.8075000, 38.9172200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128531, 'Doğançay', 'Dogancay', 'Dogancay,Doğançay', 40.6264700, 30.3355700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128532, 'Dodurga', 'Dodurga', 'Dodurga', 40.8548900, 34.8070300, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128533, 'Dikbıyık', 'Dikbiyik', 'Dikbijik,Dikbiyik,Dikbıyık,Дикбийик', 41.2207800, 36.6150000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128534, 'Digor', 'Digor', 'Digor,Дигор', 40.3689600, 43.4099700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128535, 'Devrekani', 'Devrekani', 'Devrekani', 41.6030300, 33.8392200, 'TR', '2012-02-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128536, 'Devrek', 'Devrek', 'Devrek,Hamidiye', 41.2191700, 31.9558300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128537, 'Destek', 'Destek', 'Destek,Дестек', 40.8466700, 36.1830600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128538, 'Dernekpazarı', 'Dernekpazari', 'Dernekpazari,Dernekpazarı', 40.7965800, 40.2446000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128539, 'Derince', 'Derince', 'Derince,Derinji', 40.7569400, 29.8147200, 'TR', '2014-10-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128540, 'Derepazarı', 'Derepazari', 'Derepazar,Derepazari,Derepazarı', 41.0239800, 40.4233200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128541, 'Dereli', 'Dereli', 'Dereli,Дерели', 40.7389000, 38.4433700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128542, 'Dereköy', 'Derekoy', 'Derekoy,Dereköy', 41.9300800, 27.3705200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128543, 'Derecik', 'Derecik', 'Bodamiya,Bodamya,Derecik,Deredzhik,Дереджик', 40.9459000, 39.5940100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128544, 'Büyükderbent', 'Buyukderbent', 'Buyukderbent,Büyükderbent,Derbent,Hikmetiye,Masukiye,Maşukiye', 40.7075300, 30.1143400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128545, 'Demirtaş', 'Demirtas', 'Demirtas,Demirtaş', 40.2719400, 29.0983300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128546, 'Pulur', 'Pulur', 'Demirezju,Demiroezue,Demirozu,Demirözü,Kisanta,Kısanta,Pulur,Демирезю', 40.1602300, 39.8923900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128547, 'Demirkent', 'Demirkent', 'Demirkent,Демиркент', 40.8790800, 41.7295300, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128548, 'Değirmendere', 'Degirmendere', 'Degirmendere,Degirmendere Kasabasi,Değirmendere,Değirmendere Kasabası,Yalidegirmendere,Yalıdeğirmendere', 40.7200000, 29.7808300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128549, 'Darıca', 'Darica', 'Darica,Darıca,Deridja,Derija', 40.7797300, 29.3945400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128550, 'Darıca', 'Darica', 'Darica,Darıca', 40.0206000, 27.8637400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128551, 'Dambaslar', 'Dambaslar', 'Dambaslar', 41.2241700, 27.2480600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128552, 'Damal', 'Damal', 'Damal,Ginya,Yukaridamal,Yukarıdamal,Дамал', 41.3414500, 42.8368000, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128553, 'Dağbaşı', 'Dagbasi', 'Dachbashi,Dagbasi,Dağbaşı,Дачбаши', 40.7276300, 39.9117700, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128554, 'Daday', 'Daday', 'Daday', 41.4786600, 33.4666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128555, 'Çubuk', 'Cubuk', 'Chubuk,Chubuku,Cubuk,Distretto di Cubuk,Distretto di Çubuk,Çubuk,Чубук,Чубукъ,ضلع چوبک,چوبوک، انقرہ', 40.2386100, 33.0322200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128556, 'Çorum', 'Corum', 'Chorum,Corum,Corumas,Euchaita,Gorad Charum,Tsoroum,cholum,chorumi,chorumu,chwrwm,jwrwm,koruma,qiao lu mu,Çorum,Čorumas,Τσορούμ,Горад Чарум,Чорум,جوروم,چوروم,چۆروم,ਕੋਰੁਮ,ჩორუმი,チョルム,喬魯姆,초룸', 40.5488900, 34.9533300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128557, 'Çorlu', 'Corlu', 'Chorlu,Corlu,Corum,Gorad Charlu,Tzirallum,Tzurullum,chwrlw,qiao er lu,tshwrlw,Çorlu,Çorum,Čorlu,Горад Чарлу,Чорлу,تشورلو,ضلع چورلو,چورلو,喬爾盧', 41.1591700, 27.8000000, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128558, 'Çöpköy', 'Copkoy', 'Copkoy,Çöpköy', 41.2197200, 26.8227800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128559, 'Çırçır', 'Circir', 'Circir,Çırçır', 40.0550000, 36.7750000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128560, 'Çınarcık', 'Cinarcik', 'Cinarcik,Çınarcık', 40.6453800, 29.1245000, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128561, 'Çilimli', 'Cilimli', 'Celimli,Cilimli,Cilmi,Çelimli,Çilimli,Çilmi', 40.8936100, 31.0491700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128562, 'Zurzuna', 'Zurzuna', 'Cildir,Zurzuna,Çıldır', 41.1214100, 43.1299000, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128563, 'Çiftlikköy', 'Ciftlikkoy', 'Ciftlik,Ciftlikkoy,Çiftlik,Çiftlikköy', 40.6602800, 29.3236100, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128564, 'Cide', 'Cide', 'Aegialis,Cide,Jidde,Jiddeh,Kara-Agach,Karaagac,Karaağaç', 41.8921100, 33.0043900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128565, 'Cerrah', 'Cerrah', 'Cerrah', 40.0712400, 29.4466100, 'TR', '2013-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128566, 'Çerkezköy', 'Cerkezkoey', 'Cerkezkoey,Çerkezköy', 41.2862900, 27.9993900, 'TR', '2013-03-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128567, 'Çerkeş', 'Cerkes', 'Cerkes,Cherkes,Cherkesh,Mecidiye,Çerkeş', 40.8116400, 32.8935800, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128568, 'Çerçiler', 'Cerciler', 'Cerciler,Çerçiler', 41.3945000, 35.2366500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128569, 'Cemilbey', 'Cemilbey', 'Cemilbey,Corak,Çorak', 40.3452900, 35.0513600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128570, 'Çeltikçi', 'Celtikci', 'Celtikci,Çeltikçi', 40.3219400, 32.4556900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128571, 'Çekmeköy', 'Cekmekoey', 'Cekme,Cekmekoy,Cemke,Çekme,Çekmeköy', 41.0411800, 29.1783800, 'TR', '2015-08-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128572, 'Çekerek', 'Cekerek', 'Cekerek,Hacikoy,Hacıköy,Turkmenhacikoyu,Türkmenhacıköyü,Çekerek', 40.0730600, 35.4947200, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128573, 'Kürtün', 'Kurtun', 'Cayra,Kjurtjun,Kuertuen,Kurtun,Kürtün,Ozkurtun,Çayra,Özkürtün,Кюртюн', 40.6951600, 39.0946800, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128574, 'Çaykara', 'Caykara', 'Caykara,Ciftesu,Kadahor,Çaykara,Çiftesu', 40.7426700, 40.2317500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128575, 'Çayırhan', 'Cayirhan', 'Cayirhan,Çayırhan', 40.0980600, 31.6731900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128576, 'Çayeli', 'Cayeli', 'Caybasi,Cayeli,Mapavri,Mapavrı,Çaybaşı,Çayeli', 41.0860900, 40.7221300, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128577, 'Çaycuma', 'Caycuma', 'Caycuma,Çaycuma', 41.4263900, 32.0755600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128578, 'Çaybaşı', 'Caybasi', 'Caybasi,Çaybaşı', 41.0171100, 37.0979600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128579, 'Çatalzeytin', 'Catalzeytin', 'Catalzeytin,Çatalzeytin', 41.9531400, 34.2162700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128580, 'Çatalca', 'Catalca', 'Catalca,Chataldja,Chatalja,Tchataldja,Tschataldja,Çatalca', 41.1432400, 28.4615400, 'TR', '2010-12-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128581, 'Çarşıbaşı', 'Carsibasi', 'Carsibasi,Charshibashi,Iskefiye,Skefe,Çarşıbaşı,İskefiye,Чаршибаши', 41.0827800, 39.3827800, 'TR', '2015-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128582, 'Çarşamba', 'Carsamba', 'Carsamba,Carsampa,Carsanba,Charshamba,Charshambah,Charshembe,Themiscyra,Çarşamba,Çarşanba,Чаршамба', 41.1988900, 36.7219400, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128583, 'Çanta', 'Canta', 'Canta,Cantakoy,Çanta,Çantaköy', 41.0789700, 28.0832300, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128584, 'Khanjarah', 'Khanjarah', 'Cankiri,Changra,Changri,Chankiri,Chankyry,Gangra Germanicopolis,Ghanjarah,Kangiri,Kangırı,Khanjarah,knghry,Çankırı,Чанкыры,کنغری', 40.5999500, 33.6153000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128585, 'Çandır', 'Candir', 'Candir,Çandır', 40.2571700, 33.4686800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128586, 'Çanakkale', 'Canakkale', 'Abydus,CKZ,Canakale,Canakkale,Canaqqala,Canaxqele,Chanak,Chanakale,Chanakkale,Chanaq,Chanoqqalʼa,Dardanelles,Kale-Sultanie,Tsanakkale,canakale,cha nak kale,chanakalle,chanakkare,chnaq‌qlʿh,chynk qlʿh,janakaly,qia na ka lai,qia na ka lai sheng,znqlh,Çanakkale,Çanaqqala,Çanaxqele,Čanakalė,Τσανάκκαλε,Чанакале,Чанаккале,Չանաքկալե,צנקלה,تاناککالے,جاناكالي,چاناق‌قلعه,چناق قلعے,چناق‌قلعه,چینک قلعه,ਚਾਨਕਲੇ,ชานักกาเล,ჩანაქკალე,チャナッカレ,恰納卡萊,恰纳卡莱省,차나칼레', 40.1555200, 26.4127100, 'TR', '2016-11-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128587, 'Çanakçı', 'Canakci', 'Canakci,Kuzcakoy,Kuzcaköy,Çanakçı', 40.9113900, 38.9881300, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128588, 'Çan', 'Can', 'Can,Pazarkoy,Çan', 40.0332800, 27.0523600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128589, 'Çamoluk', 'Camoluk', 'Camoluk,Chamoluk,Mindaval,Tesnik,Testik,Teşnik,Teştik,Çamoluk,Чамолук', 40.1273200, 38.7300600, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128590, 'Çamlıkaya', 'Camlikaya', 'Camlikaya,Çamlıkaya', 40.6391000, 41.1521800, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128591, 'Çamlıhemşin', 'Camlihemsin', 'Camlihemsin,Viceulya,Viçeülya,Yukarivice,Yukarıviçe,Çamlıhemşin', 41.0476500, 40.9999600, 'TR', '2013-12-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128592, 'Çamlıdere', 'Camlidere', 'Camlidere,Chamlydere,Sehler,Seyhler,Sorba,Çamlıdere,Şehler,Şeyhler,Чамлыдере,ضلع چاملدرے,چاملیدیرے، انقرہ', 40.4895800, 32.4749900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128593, 'Çamlıbel', 'Camlibel', 'Artova,Camlibel,Chamlybel'',Ciftlik,Ciftlik Koyu,Çamlıbel,Çiftlik,Çiftlik Köyü,Чамлыбель', 40.0863900, 36.4772200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128594, 'Camili', 'Camili', 'Camili,Macahel,Maçahel', 41.4783800, 41.8982500, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128595, 'Çağlayan', 'Caglayan', 'Caglayan,Cambur,Zambur,Çağlayan', 40.9001900, 39.7123100, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128596, 'Çamaş', 'Camas', 'Camas,Urmeli,Çamaş,Ürmeli', 40.9020000, 37.5278600, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128597, 'Çalı', 'Cali', 'Cali,Calikoy,Çalı,Çalıköy', 40.1686100, 28.9208300, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128797, 'Douliu', 'Douliu', 'Douliou,Douliu,Doulju,Dǒuliù,GJau Luc,Tau-lak-chhi,Teu-liuk-su,Tou-liou,Tou-liu,Tou-liu-chieh,Táu-la̍k-chhī,Téu-liuk-sṳ,Yun-lin,Yun-lin-hsien,Yün-lin,Yün-lin-hsien,deoulyu si,dou liu,dou liu shi,dwlyw,Đấu Lục,Доулю,دولیو,斗六,斗六市,더우류 시', 23.7094400, 120.5433300, 'TW', '2014-04-19', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128798, 'Yujing', 'Yujing', 'Chiao-pa-nien,Yu-ching,Yu-ching-chuang,Yu-ching-ts''un,Yujing,Yü-ching,Yü-ching-chuang,Yü-ching-ts’un,yu jing,玉井', 23.1249300, 120.4613800, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128799, 'Taoyuan', 'Taoyuan', 'Comte de Taoyuan,Comté de Taoyuan,Hsin-chu,Hsin-chu-hsien,Quan GJao Vien,Quận Đào Viên,T''ao-yuan,T''ao-yuan-chen,T''ao-yuan-chieh,T''ao-yuan-hsien,Taojuan'',Taojuanas,Taoyuan,Taoyuan District,Taoyuen,Tchao-juean,Tchao-jüan,Tho-hng-khu,Thô-hn̂g-khu,T’ao-yüan,T’ao-yüan-chen,T’ao-yüan-chieh,T’ao-yüan-hsien,tao yuan,tao yuan qu,taowian gu,tawywn,Таоюань,تاويون,تاویوان ضلع,桃園,桃園区,桃園區,타오위안 구', 24.9896000, 121.3187000, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128800, 'Taitung', 'Taitung', 'T''ai-tung,T''ai-tung Shih,T''ai-tung-chen,T''ai-tung-hsien,TTT,Taichung,Taidong,Taitung,T’ai-tung,T’ai-tung Shih,T’ai-tung-chen,T’ai-tung-hsien,tai dong,臺東', 22.7599100, 121.1445700, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128801, 'Taipei', 'Taipei', 'GJai Bac,Kota Taipei,Pan Kiao,Pan-ch''iao,Pan-ch''iao-chen,Pan-ch''iao-chieh,Pan-ch’iao,Pan-ch’iao-chen,Pan-ch’iao-chieh,T''ai-pei,T''ai-pei Shih,T''ai-pei-hsien,TPE,Taibei Shi,Taibei Shih,Taibejus,Taibėjus,Taipe,Taipeh,Taipei,Taipeium,Taipejus,Taipé,Taipéi,Taipėjus,Tajbehj,Tajpej,Tajpeo,Tayipeh,Tayipèh,Tchaj-pej,T’ai-pei,T’ai-pei Shih,T’ai-pei-hsien,ta''ipe,tai bei,tai bei shi,taibei,taibei si,taipei,thipe,Đài Bắc,Ταϊπέι,Тайбэй,Тайпей,Тајпеј,טאיפי,טאיפיי,تەيبېي,ताइपे,ไทเป,ཐའེ་པེ,ታይፔ,台北,台北市,臺北市,타이베이,타이베이 시,타이페이', 25.0477600, 121.5318500, 'TW', '2017-07-21', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128802, 'Taibao', 'Taibao', 'Kota Taibao,T''ai-pao,T''ai-pao-chuang,T''ai-pao-li,Ta-pao,Taibao,Tajbao,Tchaj-pao,Thai Bao,Thai-po-su,Thai-pó-sṳ,Thái Bảo,T’ai-pao,T’ai-pao-chuang,T’ai-pao-li,tai bao,tai bao shi,taibao si,taybayw,Тайбао,تایبائو,太保,太保市,타이바오 시', 23.4594400, 120.3322200, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128803, 'Xinying', 'Xinying', 'Hsin-ying,Hsing-ying,Sin-iâⁿ-khu,Sin-jing,Sin-yang-khi,Sinying,Sîn-yàng-khî,T''ai-nan,T''ai-nan-hsien,Tan Doanh,Tân Doanh,T’ai-nan,T’ai-nan-hsien,Xinying,Xinying District,sin-ing gu,xin ying,xin ying qu,新営区,新營,新營區,신잉 구', 23.3069400, 120.3105600, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128804, 'Tainan', 'Tainan', 'Dai-nang,Dài-nàng,GJai Nam,Gorad Tajnan'',Kota Tainan,T''ai-nan,T''ai-nan-shih,TNN,Tai-lam-chhi,Tainan,Tainan City,Tainanas,Tainanshi,Tainanshih,Tajnan,Tajnan'',Taynam,Tchaj-nan,Teynen shehiri,Thoi-nam-su,Thòi-nàm-sṳ,Tâi-lâm-chhī,T’ai-nan,T’ai-nan-shih,tai nan,tai nan shi,tainan si,taynan,thi hnan,Đài Nam,Горад Тайнань,Тайнань,טאינאן,تاينان,تاینان,ไถหนัน,台南,台南市,臺南,臺南市,타이난 시', 22.9908300, 120.2133300, 'TW', '2017-07-21', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128805, 'Fengyuan', 'Fengyuan', 'Feng Yung,Feng-yuan,Feng-yuan-chen,Feng-yuan-chieh,Feng-yüan,Feng-yüan-chen,Feng-yüan-chieh,Fengyuan,Fongyuan,Hu-lu-tun,T''ai-chung,T''ai-chung-hsien,T’ai-chung,T’ai-chung-hsien,feng yuan,豐原', 24.2500000, 120.7169400, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128806, 'Taichung', 'Taichung', 'GJai Trung,Kota Taichung,RMQ,Tai-tiong-chhi,Taichung,Taicungas,Taizhong,Taizhong Shi,Taičungas,Tajchzhun,Tajcung,Tajzhun,Tajĉung,Taychun,Tchaj-cung,Tchaj-čung,Teyjong shehiri,Thoi-chung-su,Thòi-chûng-sṳ,Tâi-tiong-chhī,tai zhong,tai zhong shi,taijung si,tay shangh,Đài Trung,Тайжун,Тайчжун,تاي شانغ,台中,台中市,臺中市,타이중 시', 24.1469000, 120.6839000, 'TW', '2017-07-21', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128807, 'Daxi', 'Daxi', 'Dasi,Daxi,Ta-Si-chen,Ta-ch''i,Ta-ch''i-chen,Ta-ch''i-chieh,Ta-ch’i,Ta-ch’i-chen,Ta-ch’i-chieh,Ta-hsi,Ta-hsi-chen,Ta-k''o-k''an,Ta-k’o-k’an,da xi,Та-Си-чен,大溪', 24.8837300, 121.2904300, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128808, 'Banqiao', 'Banqiao', 'Banchiao,Banciao,Banciao District,Banqiao,Banqiao District,Fang-ch''iao,Fang-ch’iao,Pan-ch''iao,Pan-ch’iao,San-kuang,San-kuang-li,ban qiao,ban qiao qu,fang qiao,板橋,板橋區,枋橋', 25.0142700, 121.4671900, 'TW', '2015-11-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128809, 'Puli', 'Puli', 'P''u-li,P''u-li-chieh,Puli,P’u-li,P’u-li-chieh,bu li,Пули,埔里', 23.9663900, 120.9695200, 'TW', '2014-07-08', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128810, 'Pizitou', 'Pizitou', 'Czjai,P''i-tzu-t''ou,Pizihtou,Pizitou,P’i-tzu-t’ou,pi zi tou,Цзяи,埤子頭', 23.4855600, 120.4447200, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128811, 'Pingtung', 'Pingtung', 'Binh GJong,Bình Đông,P''ing-tung,P''ing-tung-chieh,P''ing-tung-hsien,P''ing-tung-shih,PIF,Pching-tung,Phin-tung-su,Phìn-tûng-sṳ,Pin-tong-chhi,Pindun,Ping Tung,Pingdong,Pingdongas,Pingtung,Pingtung City,Pîn-tong-chhī,P’ing-tung,P’ing-tung-chieh,P’ing-tung-hsien,P’ing-tung-shih,ping dong,ping dong shi,pingdung si,pyngtwng,Пиндун,پینگتونگ,屏東,屏東市,핑둥 시', 22.6713500, 120.4881400, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128812, 'Nantou', 'Nantou', 'Lam-tau-chhi,Lâm-tâu-chhī,Nam GJau,Nam Đầu,Nam-theu-su,Nan''tou,Nan-t''ou,Nan-t''ou-chieh,Nan-t''ou-hsien,Nan-t''ou-shih,Nan-tchou,Nan-t’ou,Nan-t’ou-chieh,Nan-t’ou-hsien,Nan-t’ou-shih,Nantou,Nantou City,Nantou by,Nantow,Nàm-thèu-sṳ,nan tou,nan tou shi,nanteou si,nantw,Наньтоу,نانتو,南投,南投市,난터우 시', 23.9156600, 120.6638700, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128813, 'Miaoli', 'Miaoli', 'Miao-li,Miao-li-chieh,Miao-li-hsien,Miao-li-shih,Miaoli,miao li,苗栗', 24.5642700, 120.8236700, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128814, 'Magong', 'Magong', 'MZG,Magong,Magun,P''eng-hu,P''eng-hu-hsien,ma gong,Магун,馬公', 23.5654000, 119.5862700, 'TW', '2015-11-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128815, 'Lugu', 'Lugu', 'Ch''iang-tzu-liao,Ch’iang-tzu-liao,Lu-ku,Lugu,lu gu,Лугу,鹿谷', 23.7463900, 120.7525000, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128816, 'Fengshan', 'Fengshan', 'Feng-san,Feng-shan,Feng-shan-chieh,Feng-šan,Fengsanas,Fengshan,Fengšanas,Fongshan,Fongshan District,Fung-san-khi,Fung-sân-khî,Hōng-soaⁿ-khu,Kao-hsiung,Kao-hsiung-hsien,Phuong Son,Phượng Sơn,feng shan,feng shan qu,peongsan gu,鳳山,鳳山区,鳳山區,펑산 구', 22.6265900, 120.3612600, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128817, 'Kaohsiung', 'Kaohsiung', 'Gaosjun,Gaosyongshih,Gaoxiong,Gaoxiongshi,KHH,Kao-hsiung,Kao-hsiung-shih,Kaohsiung,Kaohsiung City,Takao,gao xiong,gao xiong fu,gao xiong shi,Гаосюн,高雄,高雄巿,高雄市', 22.6162600, 120.3133300, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128818, 'Yilan', 'Yilan', 'Ciudad de Yilan,Gi-lan-chhi,Gî-lân-chhī,I-lan,I-lan-hsien,I-lan-shih,Ilan,Ilan'',Jilanas,Ka-ma-lan,Kota Yilan,Nghi Lan,Ngi-lan-su,Ngì-làn-sṳ,Yilan,Yilan City,Yílán,ilan si,yi lan,yi lan shi,yylan,Илань,یلن سٹی,ییلان,宜蘭,宜蘭市,이란 시', 24.7570000, 121.7530000, 'TW', '2014-04-19', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128819, 'Hualien City', 'Hualien City', 'HUN,Hua Lien Kang,Hua-lien,Hua-lien-chiang,Hua-lien-hsien,Hua-lien-shih,Hualian,Hualian Shi,Hualien,Hualien City,Huālián Shì,Khualjan'',hua lian shi,hwalyen si,hwalyn,Хуалянь,هوالین,花蓮市,화롄 시', 23.9769400, 121.6044400, 'TW', '2015-12-13', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128820, 'Hsinchu', 'Hsinchu', 'HSZ,Hsin-chu,Hsin-chu-hsien,Hsin-chu-shih,Hsinchu,Kota Hsinchu,Sin''chzhu,Sin-chuk-su,Sin-cu,Sin-tek-chhi,Sin-tek-chhī,Sin-ču,Sinhcuz,Sinjhushih,Sîn-chuk-sṳ,Tan Truc,Tân Trúc,Xinzhu,Xinzhushi,nkhr sin cu,sinju si,syn shw,xin zhu,xin zhu shi,Синьчжу,Шиньжү,سين شو,นครซินจู๋,ཞིག་ཀྲུའུ།,新竹,新竹市,신주 시', 24.8036100, 120.9686100, 'TW', '2011-05-29', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128821, 'Hengchun', 'Hengchun', 'HCN,Hang Xuan,Hen-tshun-tsun,Heng-ch''un,Heng-chhun-tin,Heng-ch’un,Hengchun,Hèn-tshûn-tsṳ́n,Hêng-chhun-tìn,Hằng Xuân,heng chun,heng chun zhen,heongchun jin,恆春鎮,恒春,恒春鎮,헝춘 진', 22.0041700, 120.7438900, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128822, 'Zhubei', 'Zhubei', 'Chu-pei,Chupei,Chzhubehj,Cu-pej,Hung-mao,Jhubei,Truc Bac,Trúc Bắc,Tsuk-pet-su,Tsuk-pet-sṳ,Zhubei,jubei si,zhu bei,zhu bei shi,Ču-pej,Чжубэй,竹北,竹北市,주베이 시', 24.8383300, 121.0077800, 'TW', '2011-05-29', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128823, 'Jincheng', 'Jincheng', 'Chin-ch''eng,Chin-ch’eng,Chin-men,Chin-men-hsien,Chin-men-hsien-ch''eng,Chin-men-hsien-ch’eng,Hou-p''u,Hou-p’u,Jincheng,KNH,jin cheng,金城', 24.4366700, 118.3183300, 'TW', '2015-09-12', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128824, 'Keelung', 'Keelung', 'Chi-lung,Chi-lung-shih,Chilung,Co Long,Czilun,Cơ Long,Gie-leng,Giĕ-lè̤ng,Jilong,Jilongshi,Jilongshih,Ke-lang-chhi,Ke-lâng-chhī,Keelung,Ki-lung-su,Kota Keelung,Kî-lùng-sṳ,Shi-lun,Ti-lung,ji long,ji long shi,jilung si,ky lngh,Ťi-lung,Цзилун,Ши-лун,كي لنغ,基隆,基隆市,지룽 시', 25.1282500, 121.7419000, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128825, 'Jiayi Shi', 'Jiayi Shi', 'Chia-i,Chia-i-hsien,Chia-i-shih,Chiayi,Chiayi City,Jiayi Shi,Jiayi Shih,jia yi shi,嘉義市', 23.4791700, 120.4488900, 'TW', '2017-05-09', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128826, 'Chang-hua', 'Chang-hua', 'Chang Hwa,Chang-hua Nan-pu,Chang-hua North,Chang-hua Pei-pu,Chang-hua-hsien,Chang-hua-shih,Chang-hua-south,Jhanghua,Zhanghua,zhang hua,彰化', 24.0732700, 120.5627600, 'TW', '2010-12-17', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128827, 'Taoyuan City', 'Taoyuan City', 'Taojuan'',Таоюань', 24.9936800, 121.2969600, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128828, 'Taitung City', 'Taitung City', 'GJai GJong,Taidong,Taitung,Tchaj-tung,Táidong,tai dong,Đài Đông,台東', 22.7583000, 121.1444000, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128829, 'Nangan', 'Nangan', 'LZN,Nan-kan,Nangan,Nangan Xiang,nan gan,南竿', 26.1503900, 119.9328400, 'TW', '2010-12-05', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128830, 'Zhongxing New Village', 'Zhongxing New Village', 'Chung Hsing New Village,Chung-hsing-hsin-tsun,Jhongsing,Zhongxing', 23.9590800, 120.6851600, 'TW', '2016-06-22', 218);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128831, 'Zanzibar', 'Zanzibar', 'Gorad Zanzibar,Ilu Zanzibar,Poli tis Zanzivaris,Sansibar,Sansibar-Stadt,Unguja,ZNZ,Zanjibar,Zanzibar,Zanzibar City,Zanzibar by,Zanzibaras,Zanzibaro,Zanzibár,Zanzíbar,janjibaleusiti,mdynt znjbar,sang gei ba er shi,zanjibarushiti,zanzibari,zngbar,znzybr syty,Ìlú Zanzibar,Πόλη της Ζανζιβάρης,Горад Занзібар,Занзибар,Занзібар,זנזיבר סיטי,زنجبار شہر,زنگبار,مدينة زنجبار,ზანზიბარი,ザンジバルシティ,桑给巴尔市,잔지바르시티', -6.1639400, 39.1979300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128832, 'Wete', 'Wete', 'Veto,Wete,Weti,Вето', -5.0558900, 39.7293800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128833, 'Vwawa', 'Vwawa', 'Vawa,Vwawa', -9.1166700, 32.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128834, 'Vikindu', 'Vikindu', 'Vikindu', -7.0066700, 39.2984900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128835, 'Uyovu', 'Uyovu', '', -3.2833300, 31.5258300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128836, 'Uwelini', 'Uwelini', '', -5.4000000, 39.6833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128837, 'Uvinza', 'Uvinza', 'Kimalapamba,Rutschugiposten,Urvinsa,Uvinza,Uwinsa', -5.1036100, 30.3911100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128838, 'Utete', 'Utete', 'Utete', -7.9859800, 38.7579500, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128839, 'Usoke', 'Usoke', '', -5.1666700, 32.3500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128840, 'Ushirombo', 'Ushirombo', 'Ushirombo', -3.4919400, 31.9638900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128841, 'Usevia', 'Usevia', 'Usevia,Usevya', -7.1000000, 31.2333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128842, 'Usagara', 'Usagara', '', -2.6833300, 33.0000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128843, 'Usa River', 'Usa River', 'Usa,Usa River', -3.3666700, 36.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128844, 'Urambo', 'Urambo', '', -5.0666700, 32.0500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128845, 'Ulenje', 'Ulenje', 'Ulenje,Ulenji', -8.9333300, 33.6833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128846, 'Tunduma', 'Tunduma', 'Tunduma', -9.3000000, 32.7666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128847, 'Tumbi', 'Tumbi', '', -5.0666700, 32.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128848, 'Tukuyu', 'Tukuyu', 'Neu-Langenberg,Neu-Langenburg,New Langenberg,Ntukuju,Tukuyu', -9.2500000, 33.6500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128849, 'Tinde', 'Tinde', '', -3.8833300, 33.2000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128850, 'Tarime', 'Tarime', '', -1.3500000, 34.3666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128851, 'Tanga', 'Tanga', 'Gorad Tanga,Longa,TGT,Tan''nka,Tanga,tan ga,tang-ga,tanga,tanga  tanzanya,tnja,Τάνγκα,Горад Танга,Танга,טאנגה,تانگا، تانزانیا,تانگا، تنزانیہ,تنجا,タンガ,坦噶,탕가', -5.0689300, 39.0987500, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128852, 'Tabora', 'Tabora', 'TBO,Tabora,Tampora,ta bo la,tabola,tabora,tabwra,Ταμπόρα,Табора,تابورا,タボラ,塔波拉,타보라', -5.0162200, 32.8266300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128853, 'Sumbawanga', 'Sumbawanga', 'SUT,Sumbauanga,Sumbavanga,Sumbawanga,Zumbawanga,Zumbayanga,song ba wan jia,sumbawang-ga,sunbawanga,swmbawanga,Сумбаванга,Сумбауанга,سومباوانگا,スンバワンガ,松巴萬加,숨바왕가', -7.9666700, 31.6166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128854, 'Soni', 'Soni', '', -4.8500000, 38.3666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128855, 'Songwa', 'Songwa', '', -3.5166700, 33.5166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128856, 'Somanda', 'Somanda', '', -3.3666700, 33.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128857, 'Sokoni', 'Sokoni', '', -6.4333300, 39.5500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128858, 'Sirari', 'Sirari', 'Sirari', -1.2536700, 34.4759600, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128859, 'Singida', 'Singida', '', -4.8162900, 34.7435800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128860, 'Sikonge', 'Sikonge', 'Sikonge', -5.6333300, 32.7666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128861, 'Shinyanga', 'Shinyanga', 'SHY,Schinjanga,Shin''janga,Shinjanga,Shinyanga,Sinjanga,shinyanga,shynyanga,siniang-ga,xin yan jia,Šinjanga,Шиньянга,Шинянга,شینیانگا,シニャンガ,欣延加,시니앙가', -3.6639300, 33.4211800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128862, 'Shelui', 'Shelui', 'Shelui', -4.3666700, 34.2000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128863, 'Sepuka', 'Sepuka', 'Sepuka,Sipuka', -4.7500000, 34.5333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128864, 'Same', 'Same', 'Same,Ssame,Zame', -4.0666700, 37.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128865, 'Rulenge', 'Rulenge', '', -2.7175000, 30.6325000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128866, 'Rujewa', 'Rujewa', 'Rujewa,Rujewo', -8.7000000, 34.3833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128867, 'Puma', 'Puma', 'Puma', -5.0000000, 34.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128868, 'Poli', 'Poli', 'Poli', -3.3333300, 36.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128869, 'Pangani', 'Pangani', 'Pangani', -5.4252600, 38.9747300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128870, 'Old Shinyanga', 'Old Shinyanga', '', -3.5500000, 33.4000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128871, 'Nzega', 'Nzega', '', -4.2166700, 33.1833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128872, 'Nyanguge', 'Nyanguge', '', -2.5500000, 33.2000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128873, 'Nyamuswa', 'Nyamuswa', '', -1.9000000, 34.0166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128874, 'Nyalikungu', 'Nyalikungu', 'Nyalikungu,Nyarikungu', -3.1833300, 33.7833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128875, 'Nyakahanga', 'Nyakahanga', '', -1.6033300, 31.1413900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128876, 'Nyakabindi', 'Nyakabindi', '', -2.6333300, 33.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128877, 'Nsunga', 'Nsunga', '', -1.1438900, 31.3947200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128878, 'Nshamba', 'Nshamba', '', -1.7983300, 31.5511100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128879, 'Nkove', 'Nkove', '', -7.9500000, 30.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128880, 'Nkoaranga', 'Nkoaranga', 'Nkoaranga', -3.3333300, 36.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128881, 'Njombe', 'Njombe', 'JOM,Njobe,Njombe', -9.3333300, 34.7666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128882, 'Nguruka', 'Nguruka', '', -5.1091700, 31.0419400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128883, 'Ngudu', 'Ngudu', 'Ngudu', -2.9666700, 33.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128884, 'Ngorongoro', 'Ngorongoro', 'Ngorongoro', -3.2397300, 35.4874700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128885, 'Ngerengere', 'Ngerengere', 'Ngerengere', -6.7500000, 38.1166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128886, 'Ngara', 'Ngara', 'Ngara', -2.5122200, 30.6558300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128887, 'Nganane', 'Nganane', '', -6.4000000, 39.5500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128888, 'Ndungu', 'Ndungu', '', -4.3666700, 38.0500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128889, 'Ndago', 'Ndago', 'Ndago', -4.6000000, 34.3500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128890, 'Nansio', 'Nansio', 'Nansio', -2.1333300, 33.0500000, 'TZ', '2012-01-17', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128891, 'Nangwa', 'Nangwa', '', -4.4666700, 35.4500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128892, 'Namanyere', 'Namanyere', '', -7.5166700, 31.0500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128893, 'Namanga', 'Namanga', 'Namanga', -2.5511600, 36.7837700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128894, 'Nakatunguru', 'Nakatunguru', '', -2.1166700, 33.0666700, 'TZ', '2011-03-06', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128895, 'Naberera', 'Naberera', '', -4.2000000, 36.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128896, 'Mwembe', 'Mwembe', 'Mwemba,Mwembe', -4.1500000, 37.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128897, 'Mwaya', 'Mwaya', 'Muaja,Mvaya,Mwaya', -9.5500000, 33.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128898, 'Mwanza', 'Mwanza', 'Gorad Mvanza,MWZ,Muansa,Muanza,Muvanzo,Mvanza,Mwamza,Mwansa,Mwanza,meuwanja,mu wan zha,muwanza,mvanza,mwanza,Горад Мванза,Мванза,Муанза,موانزا,მვანზა,ムワンザ,姆万扎,므완자', -2.5166700, 32.9000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128899, 'Mwanga', 'Mwanga', '', -4.8000000, 38.2000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128900, 'Mwadui', 'Mwadui', 'MWN,Mwadui', -3.5500000, 33.6000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128901, 'Mvomero', 'Mvomero', '', -6.2500000, 38.6666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128902, 'Musoma', 'Musoma', 'MUZ,Mazama,Misoma,Musoma,Musome,Muzoma,maswma,mu suo ma,musoma,mwswma,Мусома,ماسوما,موسوما,ムソマ,穆索馬,무소마', -1.5000000, 33.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128903, 'Muriti', 'Muriti', '', -1.9833300, 32.9166700, 'TZ', '2011-03-06', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128904, 'Mungaa', 'Mungaa', 'Mungaa', -4.9666700, 34.8833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128905, 'Muleba', 'Muleba', '', -1.8397200, 31.6544400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128906, 'Muheza', 'Muheza', 'Mubeza,Muheza', -5.1666700, 38.7833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128907, 'Mugumu', 'Mugumu', '', -1.8500000, 34.7000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128908, 'Mugango', 'Mugango', 'Mgango,Mugango', -1.6833300, 33.7000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128909, 'Mtwango', 'Mtwango', 'Mtwango', -9.0166700, 34.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128910, 'Mto wa Mbu', 'Mto wa Mbu', 'Mto wa Mbu', -3.3500000, 35.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128911, 'Mtinko', 'Mtinko', 'Mtinko', -4.5500000, 34.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128912, 'Mtimbira', 'Mtimbira', '', -8.7833300, 36.3500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128913, 'Mtambile', 'Mtambile', 'Mtambile,Mtambili,Mwembeduka', -5.3833300, 39.7000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128914, 'Msowero', 'Msowero', '', -6.5333300, 37.2000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128915, 'Msanga', 'Msanga', '', -6.0500000, 36.0333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128916, 'Mpwapwa', 'Mpwapwa', 'Mpapua,Mpapwa,Mpwapwa', -6.3500000, 36.4833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128917, 'Mpanda', 'Mpanda', 'Mpanda', -6.3437900, 31.0695100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128918, 'Moshi', 'Moshi', 'Moschi,Moshi,Mosi,Mosis,Mošis,QSI,mo xi,moshi,mosi,mwshy,mwsy,Μόσι,Моши,מושי,موشی,موشی، تنزانیہ,モシ,莫希,모시', -3.3500000, 37.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128919, 'Morogoro', 'Morogoro', 'Gorad Maragora,Mkoa wa Morogoro,Morogoras,Morogoro,Moronkoro,Mrogoro,Murogoro,mo luo ge luo,mologolo,morogoro,mwrwghwrw,mwrwgwrw,Μορογκόρο,Горад Марагора,Морогоро,موروغورو,موروگورو,モロゴロ,莫罗戈罗,모로고로', -6.8210200, 37.6612200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128920, 'Monduli', 'Monduli', '', -3.3000000, 36.4500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128921, 'Mlowo', 'Mlowo', 'Mlowo', -9.0000000, 32.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128922, 'Mlimba', 'Mlimba', 'Mlimba', -8.8000000, 35.8166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128923, 'Mlangali', 'Mlangali', 'Mlangali', -9.7833300, 34.5166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128924, 'Mlandizi', 'Mlandizi', '', -6.7000000, 38.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128925, 'Mlalo', 'Mlalo', '', -4.9333300, 38.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128926, 'Mkuranga', 'Mkuranga', 'Mkuranga,Mkwanga', -7.1179900, 39.2078200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128927, 'Mkokotoni', 'Mkokotoni', 'Mkokotoni', -5.8750600, 39.2552300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128928, 'Mwandiga', 'Mwandiga', 'Mandyga,Miwandica,Mwandiga', -4.8300000, 29.6580600, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128929, 'Misungwi', 'Misungwi', 'Isungwi,Missungwi,Misungwi', -2.8500000, 33.0833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128930, 'Misasi', 'Misasi', '', -3.0000000, 33.0833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128931, 'Mikumi', 'Mikumi', 'Mikumi', -7.4040900, 36.9830900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128932, 'Micheweni', 'Micheweni', '', -4.9666700, 39.8333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128933, 'Mhango', 'Mhango', '', -3.2833300, 32.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128934, 'Mgandu', 'Mgandu', 'Mgandu', -5.9500000, 34.1333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128935, 'Mbumi', 'Mbumi', 'Mbumi,Mbuni', -7.9057700, 39.2104700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128936, 'Mbulu', 'Mbulu', 'Burru,Iraku,Mbulu,Mburu,Umbulu', -3.8500000, 35.5333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128937, 'Mbuguni', 'Mbuguni', 'Mbuguni', -3.5666700, 36.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128938, 'Mbeya', 'Mbeya', 'MBI,Mbee,Mbeja,Mbeya,ambya,mbya,meubeya,mu bei ya,mubeya,Мбее,Мбея,امبیا,مبيا,مبیا,ムベヤ,姆貝亞,므베야', -8.9000000, 33.4500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128939, 'Mazinde', 'Mazinde', 'Mazinde', -4.8000000, 38.2166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128940, 'Matui', 'Matui', '', -4.8000000, 38.2500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128941, 'Matonga', 'Matonga', 'Matonga,Matongo', -2.3833300, 34.0833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128942, 'Matamba', 'Matamba', '', -8.9833300, 33.9666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128943, 'Matai', 'Matai', '', -8.3000000, 31.5166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128944, 'Maswa', 'Maswa', '', -2.6833300, 33.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128945, 'Masumbwe', 'Masumbwe', '', -3.6333300, 32.1833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128946, 'Masoko', 'Masoko', 'Bujesi,Masoko', -9.3333300, 33.7500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128947, 'Maramba', 'Maramba', '', -5.0500000, 38.6166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128948, 'Maneromango', 'Maneromango', 'Maneromango', -7.1988000, 38.7847800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128949, 'Malya', 'Malya', 'Malaya,Malya', -2.9833300, 33.5166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128950, 'Malinyi', 'Malinyi', '', -8.9333300, 36.1333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128951, 'Malangali', 'Malangali', '', -8.5666700, 34.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128952, 'Malampaka', 'Malampaka', '', -3.1333300, 33.5333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128953, 'Makuyuni', 'Makuyuni', '', -4.7333300, 38.1000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128954, 'Makungu', 'Makungu', 'Makungu,Makuugu', -8.7333300, 35.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128955, 'Makumbako', 'Makumbako', 'Makambako,Makumbako', -8.8500000, 34.8333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128956, 'Makanya', 'Makanya', 'Makania,Makanya', -4.3666700, 37.8333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128957, 'Majengo', 'Majengo', '', -5.1500000, 38.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128958, 'Mahonda', 'Mahonda', '', -6.4500000, 39.4666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128959, 'Mahenge', 'Mahenge', 'Mahange,Mahenge', -8.6833300, 36.7166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128960, 'Mahanje', 'Mahanje', '', -9.9333300, 35.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128961, 'Kihangara', 'Kihangara', 'Kihangara,Magu Kahangara', -2.5833300, 33.3500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128962, 'Magugu', 'Magugu', 'Magagu,Magugu', -4.0166700, 35.7666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128963, 'Magomeni', 'Magomeni', '', -6.8000000, 39.2500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128964, 'Magomeni', 'Magomeni', '', -5.2333300, 38.1166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128965, 'Magole', 'Magole', '', -6.3769700, 37.3737300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128966, 'Mafinga', 'Mafinga', '', -7.2500000, 35.0666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128967, 'Mabamba', 'Mabamba', '', -3.5983300, 30.5019400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128968, 'Mabama', 'Mabama', '', -5.1333300, 32.5333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128969, 'Lushoto', 'Lushoto', 'Lushoto,Wilhelmstal', -4.7833300, 38.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128970, 'Lupiro', 'Lupiro', '', -8.3833300, 36.6666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128971, 'Lugoba', 'Lugoba', '', -6.4500000, 38.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128972, 'Longido', 'Longido', 'Longido', -2.7331900, 36.6977300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128973, 'Liwale', 'Liwale', 'Livale,Liwale', -9.7666700, 37.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128974, 'Lembeni', 'Lembeni', 'Lembeni', -3.7833300, 37.6166700, 'TZ', '2016-10-07', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128975, 'Lalago', 'Lalago', '', -3.4500000, 33.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128976, 'Laela', 'Laela', '', -8.5666700, 32.0500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128977, 'Kyela', 'Kyela', 'Kyela', -9.5833300, 33.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128978, 'Kyaka', 'Kyaka', 'Kyaka', -1.2522200, 31.4202800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128979, 'Kwakoa', 'Kwakoa', '', -3.7666700, 37.7166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128980, 'Kongwa', 'Kongwa', 'Kongwa', -6.2000000, 36.4166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128981, 'Kondoa', 'Kondoa', 'Kondoa,Kondoa Irangi', -4.9000000, 35.7833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128982, 'Konde', 'Konde', '', -4.9500000, 39.7500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128983, 'Koani Ndogo', 'Koani Ndogo', '', -6.1333300, 39.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128984, 'Koani', 'Koani', 'Koani', -6.1333300, 39.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128985, 'Kiwira', 'Kiwira', 'Kiwira', -9.1730700, 33.5415200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128986, 'Kiwengwa', 'Kiwengwa', 'Kivengva,Kiwembwa,Kiwengwo,Кивенгва', -5.9895700, 39.3768000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128987, 'Kisiwani', 'Kisiwani', 'Kisiwani,Kiswani', -4.1333300, 37.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128988, 'Kishapu', 'Kishapu', '', -3.6166700, 33.8666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128989, 'Kisesa', 'Kisesa', '', -3.0833300, 34.1500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128990, 'Kisarawe', 'Kisarawe', 'Kisarawe,Kiserawe', -6.9000000, 39.0666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128991, 'Kisanga', 'Kisanga', 'Kisanga', -7.4362200, 37.7033700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128992, 'Kirya', 'Kirya', '', -3.9166700, 37.4833300, 'TZ', '2011-03-06', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128993, 'Kirando', 'Kirando', '', -7.4166700, 30.6000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128994, 'Kiomboi', 'Kiomboi', 'Kiomboi', -4.2666700, 34.3666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128995, 'Kintinku', 'Kintinku', 'Kintinku', -5.8833300, 35.2333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128996, 'Kingori', 'Kingori', 'Kingori', -3.2833300, 36.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128997, 'Kimamba', 'Kimamba', '', -6.7833300, 37.1333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128998, 'Kilosa', 'Kilosa', 'Kilosa,Kilossa', -6.8333300, 36.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128999, 'Kilindoni', 'Kilindoni', 'Kilindoni', -7.9144600, 39.6620400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129000, 'Kilimatinde', 'Kilimatinde', 'Kilimatinde', -5.8500000, 34.9500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129001, 'Kijini', 'Kijini', '', -5.8500000, 39.3166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129002, 'Kihurio', 'Kihurio', '', -4.4666700, 38.0666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129003, 'Kigoma', 'Kigoma', 'Gorad Kigoma,Kigoma,Kigoma-Ujiji,Kigome,Kigomo,TKQ,ji ge ma,kigoma,kyghwma,kygwma,qygwmh,Горад Кігома,Кигома,Кигоме,קיגומה,كيغوما,کیگوما,キゴマ,基戈馬,키고마', -4.8769400, 29.6266700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129004, 'Kidodi', 'Kidodi', 'Kidodi', -7.6036100, 37.0043800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129005, 'Kidatu', 'Kidatu', 'Kidatu', -7.6991600, 36.9572200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129006, 'Kibondo', 'Kibondo', '', -3.5863900, 30.7202800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129007, 'Kibiti', 'Kibiti', 'Kibiti', -7.7217800, 38.9374900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129008, 'Kibaya', 'Kibaya', '', -5.3000000, 36.5666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129009, 'Kibara', 'Kibara', 'Kibara,Kibarra', -2.1500000, 33.4500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129010, 'Kibakwe', 'Kibakwe', 'Kibakwe', -6.7166700, 36.3666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129011, 'Kibaha', 'Kibaha', 'Kibaha', -6.7666700, 38.9166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129012, 'Katumba', 'Katumba', 'Kabumba,Katumba,Катумба', -9.2333300, 33.6166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129013, 'Katoro', 'Katoro', '', -3.0202800, 31.8958300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129014, 'Katoro', 'Katoro', '', -1.3997200, 31.5002800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129015, 'Katesh', 'Katesh', 'Ghatesh,Katesh', -4.5248300, 35.3849000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129016, 'Katerero', 'Katerero', '', -1.4000000, 31.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129017, 'Kasulu', 'Kasulu', 'Kassulo,Kasulo,Kasulu,Касулу', -4.5766700, 30.1025000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129018, 'Kasamwa', 'Kasamwa', '', -2.8500000, 32.4333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129019, 'Karema', 'Karema', 'Karema', -6.8205200, 30.4388700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129020, 'Kiratu', 'Kiratu', 'Karatu,Kiratu', -3.3333300, 35.6666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129021, 'Kandete', 'Kandete', 'Kandete', -9.1500000, 33.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129022, 'Kamachumu', 'Kamachumu', '', -1.6186100, 31.6200000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129023, 'Kaliua', 'Kaliua', 'Kaliua', -5.0605600, 31.7936100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129024, 'Kakonko', 'Kakonko', '', -3.2827800, 30.9641700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129025, 'Kahama', 'Kahama', 'KBH,Kahama', -3.8333300, 32.6000000, 'TZ', '2017-06-17', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129026, 'Kabanga', 'Kabanga', '', -2.6386100, 30.4677800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129027, 'Izazi', 'Izazi', 'Isasi,Izazi,Zasi', -7.2000000, 35.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129028, 'Itumba', 'Itumba', '', -9.4000000, 33.1833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129029, 'Itigi', 'Itigi', 'Itigi', -5.7000000, 34.4833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129030, 'Issenye', 'Issenye', 'Isenye,Issenye', -2.0000000, 34.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129031, 'Isaka', 'Isaka', 'Isaka,Исака', -3.9000000, 32.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129032, 'Iringa', 'Iringa', 'IRI,Irin''nka,Iringa,ayrynga,ayryngha,iling-ga,iringa,yi lin jia,Ιρίνγκα,Иринга,إيرينغا,ایرینگا,イリンガ,伊林加,이링가', -7.7666700, 35.7000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129033, 'Ipinda', 'Ipinda', 'Ipande,Ipinda', -9.4833300, 33.9000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129034, 'Inyonga', 'Inyonga', 'Inyonga,Nyonga', -6.7166700, 32.0666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129035, 'Ilula', 'Ilula', 'Ilula', -7.6766000, 36.0365800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129036, 'Ilongero', 'Ilongero', 'Ilongero,Irongero', -4.6666700, 34.8666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129037, 'Ilembula', 'Ilembula', 'Ilembula', -8.9000000, 34.5833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129038, 'Ilembo', 'Ilembo', '', -9.2500000, 33.3833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129039, 'Ikwiriri', 'Ikwiriri', 'Ikwiriri', -7.9561800, 38.9716400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129040, 'Ikungi', 'Ikungi', 'Ikungi', -5.1333300, 34.7666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129041, 'Igurusi', 'Igurusi', 'Igurunzi,Igurusi', -8.8500000, 33.8500000, 'TZ', '2012-01-17', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129042, 'Igurubi', 'Igurubi', '', -4.0000000, 33.7000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129043, 'Igunga', 'Igunga', '', -4.2833300, 33.8833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129044, 'Igugunu', 'Igugunu', 'Iguguno,Igugunu', -4.5666700, 34.6333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129045, 'Ifakara', 'Ifakara', 'Ifakara', -8.1333300, 36.6833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129046, 'Hedaru', 'Hedaru', '', -4.5000000, 37.9000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129047, 'Geita', 'Geita', 'GIT,Geita', -2.8666700, 32.1666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129048, 'Geiro', 'Geiro', 'Gairo,Geiro', -6.1500000, 36.8666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129049, 'Gamba', 'Gamba', '', -5.9000000, 39.3000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129050, 'Galappo', 'Galappo', 'Galapo,Galappo,Gwanzave', -4.2666700, 35.8500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129051, 'Endasak', 'Endasak', '', -4.4166700, 35.5166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129052, 'Dunda', 'Dunda', '', -8.1166700, 34.2500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129053, 'Dongobesh', 'Dongobesh', 'Dongabesh,Dongobesh', -4.0666700, 35.3833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129054, 'Dodoma', 'Dodoma', 'DOD,Dodom,Dodoma,Dodomao,Dódóma,Gorad Dadoma,Idodoma,Ntontoma,do do ma,dodoma,du du ma,duo duo ma,dwdwma,dwdwmh,totoma,Ντοντόμα,Горад Дадома,Додома,Դոդոմա,דאדאמא,דודומה,دودوما,دۆدۆما,ڈوڈوما,डोडोमा,दोदोमा,ਦੋਦੋਮਾ,டொடோமா,โดโดมา,დოდომა,ዶዶማ,ドドマ,多多马,杜篤瑪,도도마', -6.1722100, 35.7394700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129055, 'Dar es Salaam', 'Dar es Salaam', 'DAR,Dar Es Salaam,Dar Es Salam,Dar es Salaam,Dar es Salam,Dar es Salamas,Dar es Salams,Dar es Salám,Dar es-Salaam,Dar es-Salam,Dar əs Salam,Dar-ehs-Salam,Dar-ehs-Salam shaary,Dar-es-Salaam,Dar-es-Salam,Darasalam,Daresalama,Daresalamo,Daressalaam,Daressalam,Daruesselam,Darüsselam,Dárasalám,Dār es Salām,Dāresalāma,Gorad Dar-ehs-Salam,Ntar es Salam,Ntontoma,da lei si sa la mu,daleueseusallam,dar alslam,dar-es-salami,dar-xes-salam,dara asa salama,dara esa salama,daralslam,daruesusaramu,san lan gang,tarus''salam,Νταρ ες Σαλάμ,Ντοντόμα,Горад Дар-эс-Салам,Дар ес Салам,Дар ес-Салаам,Дар-ес-Салам,Дар-эс-Салам,Дар-эс-Салам шаары,דאר א-סלאם,דאר עס סאלאאם,دار السلام,دارالسلام,دارېسسالام,दार अस सलाम,दार एस सलाम,ਦਾਰ ਅਸ ਸਲਾਮ,தாருஸ்ஸலாம்,ดาร์-เอส-ซาลาม,ཏ་རེ་སི་ས་ལམ།,ဒါအက်စ် ဆယ်လန်းမြို့,დარ-ეს-სალამი,ダルエスサラーム,三蘭港,达累斯萨拉姆,다르에스살람', -6.8234900, 39.2695100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129056, 'Dareda', 'Dareda', 'Dareda,Ndareda', -4.2166700, 35.5500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129057, 'Chimala', 'Chimala', '', -8.8563700, 34.0239300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129058, 'Chato', 'Chato', 'Chato,Shato', -2.6377800, 31.7669400, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129059, 'Chanika', 'Chanika', '', -5.4166700, 38.0166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129060, 'Chalinze', 'Chalinze', '', -6.6378400, 38.3539600, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129061, 'Chala', 'Chala', '', -7.5833300, 31.2666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129062, 'Chake Chake', 'Chake Chake', 'Chake Chake,Chaki Chaki,PMA', -5.2458600, 39.7665900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129063, 'Butiama', 'Butiama', 'Buliama,Butiama', -1.7666700, 33.9666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129064, 'Buseresere', 'Buseresere', '', -3.0236100, 31.8747200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129065, 'Bungu', 'Bungu', 'Bungu', -7.6336900, 39.0581800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129066, 'Bunda', 'Bunda', '', -2.0500000, 33.8666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129067, 'Bukonyo', 'Bukonyo', '', -1.9500000, 32.9333300, 'TZ', '2011-03-06', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129068, 'Bukoba', 'Bukoba', 'BKZ,Bukoba,Bukobo,Gorad Bukoba,bu ke ba,bukoba,bwkwba,Букоба,Горад Букоба,بوكوبا,بوکوبا,ブコバ,布科巴,부코바', -1.3316700, 31.8122200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129069, 'Bukene', 'Bukene', '', -4.2333300, 32.8833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129070, 'Bugene', 'Bugene', '', -1.5911100, 31.1402800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129071, 'Bugarama', 'Bugarama', '', -2.8705600, 30.5280600, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129072, 'Biharamulo', 'Biharamulo', 'Biaramulo,Biharamulo,Usuwi', -2.6319400, 31.3088900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129073, 'Basotu', 'Basotu', '', -4.3666700, 35.0833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129074, 'Bashanet', 'Bashanet', 'Bashanet,Endalaghanet,Endalaghranid', -4.2333300, 35.4166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129075, 'Bariadi', 'Bariadi', 'Bariadi,Bariati', -2.8000000, 33.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129076, 'Bagamoyo', 'Bagamoyo', 'Bagamojo,Bagamoyo,ba jia mo yue,bagamoyo,bajamwyw,Багамойо,باجامويو,バガモヨ,巴加莫約,바가모요', -6.4422200, 38.9042200, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129077, 'Babati', 'Babati', 'Babati,Babati Mjini,Babatis,ba ba di,babati,babaty,bbty,Бабати,Бабаті,בבטי,باباتی,ババティ,巴巴蒂,바바티', -4.2166700, 35.7500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129078, 'Arusha', 'Arusha', 'ARK,Aruscha,Arusha,Aruso,Aruŝo,a lu sha,arusha,arwsha,Аруша,آروشا,アルーシャ,阿鲁沙', -3.3666700, 36.6833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129079, 'Tingi', 'Tingi', '', -11.3000000, 35.0333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129080, 'Tandahimba', 'Tandahimba', '', -10.7500000, 39.6333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129081, 'Songea', 'Songea', 'SGX,Songea,Songeja,Ssongea,sangy,song gai a,song-gea,songea,swngya,Сонгеа,Сонгея,سانگی,سونگیا,ソンゲア,松蓋阿,송게아', -10.6833300, 35.6500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129082, 'Ruangwa', 'Ruangwa', '', -10.0666700, 38.9333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129083, 'Nyangao', 'Nyangao', '', -10.3333300, 39.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129084, 'Newala Kisimani', 'Newala Kisimani', '', -10.9500000, 39.2833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129085, 'Nanyamba', 'Nanyamba', '', -10.6833300, 39.8333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129086, 'Nanhyanga', 'Nanhyanga', 'Nanhyanga,Nanyanga,Nyakahanga', -10.8000000, 39.5500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129087, 'Nangomba', 'Nangomba', '', -10.9000000, 38.5000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129088, 'Nanganga', 'Nanganga', '', -10.3833300, 39.1500000, 'TZ', '2011-03-06', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129089, 'Namikupa', 'Namikupa', '', -10.8333300, 39.6000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129090, 'Namalenga', 'Namalenga', '', -10.9500000, 39.1000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129091, 'Nachingwea', 'Nachingwea', 'NCH,Nachingwa,Nachingwea', -10.3725000, 38.7625100, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129092, 'Mtwara', 'Mtwara', 'MYW,Mikindani,Mtvara,Mtwara,amtwara,meuteuwala,mtwara,mutowara,Мтвара,امتوارا,متوارا,ムトワラ,므트와라', -10.2666700, 40.1833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129093, 'Mtama', 'Mtama', 'Mtama', -10.3000000, 39.3666700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129094, 'Mingoyo', 'Mingoyo', '', -10.1052600, 39.6185900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129095, 'Mbinga', 'Mbinga', 'Mbinga', -10.9333300, 35.0166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129096, 'Mbekenyera', 'Mbekenyera', '', -10.0000000, 38.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129097, 'Mbamba Bay', 'Mbamba Bay', 'Mbamba,Mbamba Bay,Mbampa', -11.2833300, 34.7666700, 'TZ', '2012-01-17', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129098, 'Matiri', 'Matiri', '', -10.7500000, 34.9000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129099, 'Masuguru', 'Masuguru', 'Masaguru,Masuguru', -11.3666700, 38.4166700, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129100, 'Masasi', 'Masasi', 'Masasi,Massassi,XMI,Масаси', -10.7166700, 38.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129101, 'Maposeni', 'Maposeni', '', -10.5833300, 35.4000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129102, 'Manda', 'Manda', 'Bongo,Ilela,Manda,Vamanda,Wiedhafen,Wiedhaven', -10.4666700, 34.5833300, 'TZ', '2013-04-03', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129103, 'Mahuta', 'Mahuta', '', -10.8666700, 39.4500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129104, 'Madimba', 'Madimba', '', -10.4000000, 40.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129105, 'Lulindi', 'Lulindi', '', -10.8166700, 39.1333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129106, 'Lukuledi', 'Lukuledi', '', -10.5666700, 38.8000000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129107, 'Luchingu', 'Luchingu', '', -10.9000000, 39.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129108, 'Liuli', 'Liuli', 'Liuli', -11.0833300, 34.6333300, 'TZ', '2013-04-03', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129109, 'Lindi', 'Lindi', 'LDI,Linda,Lindi,Lindis,Linti,lin di,lindi,lyndy,rindi,Λίντι,Линда,Линди,ليندي,لیندی,リンディ,林迪,린디', -9.9970900, 39.7164900, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129110, 'Kitangari', 'Kitangari', '', -10.6500000, 39.3333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129111, 'Kitama', 'Kitama', '', -10.7166700, 39.7333300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129112, 'Kigonsera', 'Kigonsera', 'Kigonsera', -10.8000000, 35.0500000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129113, 'Chiungutwa', 'Chiungutwa', '', -10.8833300, 38.9833300, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129114, 'Merelani', 'Merelani', 'Meralani,Merelani,Merelani Hills,Simanjiro district,Tanzanite Mine and Deposit', -3.5618200, 36.9789500, 'TZ', '2008-02-03', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129115, 'Nungwi', 'Nungwi', 'Nungvi,Нунгви', -5.7265100, 39.2987000, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129116, 'Kisasa', 'Kisasa', '', -6.1752600, 35.7926600, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129117, 'Mvomero', 'Mvomero', '', -6.3012200, 37.4439800, 'TZ', '2016-07-26', 220);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128767, 'Tunapuna', 'Tunapuna', 'Tunapuna,Tunapuna Village', 10.6333300, -61.3833300, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128768, 'Tabaquite', 'Tabaquite', 'Tabaquite,Tabaquite Village', 10.3882400, -61.2970400, 'TT', '2014-02-08', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128769, 'Siparia', 'Siparia', 'Siparia Village', 10.1333300, -61.5000000, 'TT', '2010-08-28', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128770, 'Scarborough', 'Scarborough', 'Port Louis,Scarborough', 11.1822900, -60.7352500, 'TT', '2017-05-24', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128771, 'Sangre Grande', 'Sangre Grande', 'Sangre Grand,Sangre Grande Station,Sangre Grande Town', 10.5833300, -61.1166700, 'TT', '2010-08-28', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128772, 'San Fernando', 'San Fernando', 'San Fernando', 10.2833300, -61.4666700, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128773, 'Rio Claro', 'Rio Claro', 'Rio Claro,Río Claro', 10.3000000, -61.1833300, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128774, 'Princes Town', 'Princes Town', 'Princess Town', 10.2666700, -61.3833300, 'TT', '2010-08-28', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128775, 'Port of Spain', 'Port of Spain', 'Acalquixohuayan Caxtillan,City of Port-of-Spain,Gorad Port-of-Spejn,POS,Po of Espay,Port of Spain,Port of Spein,Port of Speinas,Port of Spejn,Port of Speyn,Port oph Spein,Port ov Spejn,Port uf Spejn,Port-Of-Spejn,Port-au-Spain,Port-d''Espagne,Port-of-Spain,Port-of-Spein,Port-of-Spejn,Port-of-speyn,Porto Espana,Porto España,Portofspeina,Portospeno,Portu de Spania,Puerto Espana,Puerto España,Pò of Espay,bwrt awf sbyn,phxrt-xxf-spen,porata afa sapena,port ahp speyn,porta aba spena,porta opha spena,poteu obeu seupein,poteuobeuseupein,potoobusupein,prt aw aspayn,xi ban ya gang,Πορτ οφ Σπέιν,Πορτ-οφ-Σπέιν,Горад Порт-оф-Спейн,Порт ов Спејн,Порт оф Спейн,Порт оф Спејн,Порт ъф Спейн,Порт-Оф-Спейн,Порт-оф-Спейн,פורט אוף ספיין,بورت أوف سبين,پرت آو اسپاین,پورٹ آف اسپین,पोर्ट ऑफ स्पेन,পোর্ট অব স্পেন,ਪੋਰਟ ਆਫ਼ ਸਪੇਨ,போர்ட் ஆஃப் ஸ்பெய்ன்,പോർട്ട് ഓഫ് സ്പെയിൻ,พอร์ต-ออฟ-สเปน,པོ་རོ་ཊི་ཨོཕ་སི་པེ་ན།,პორტ-ოვ-სპეინი,ፖርት ኦፍ ስፔን,ポートオブスペイン,西班牙港,포트 오브 스페인,포트오브스페인', 10.6666800, -61.5188900, 'TT', '2016-02-07', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128776, 'Point Fortin', 'Point Fortin', 'Point  Fortin', 10.1833300, -61.6833300, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128777, 'Petit Valley', 'Petit Valley', '', 10.7000000, -61.5333300, 'TT', '2013-08-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128778, 'Peñal', 'Penal', 'Penal Village,Peñal Village', 10.1666700, -61.4666700, 'TT', '2010-09-01', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128779, 'Paradise', 'Paradise', '', 10.6529800, -61.3629800, 'TT', '2013-06-23', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128780, 'Mucurapo', 'Mucurapo', '', 10.6625300, -61.5369700, 'TT', '2014-02-08', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128781, 'Mon Repos', 'Mon Repos', '', 10.2797900, -61.4459000, 'TT', '2014-02-08', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128782, 'Marabella', 'Marabella', 'Marabella', 10.3061800, -61.4467100, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128783, 'Laventille', 'Laventille', 'Laventille', 10.6491700, -61.4988900, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128784, 'Debe', 'Debe', 'Debe,Debe Village,Débé,Débé Village', 10.2084600, -61.4527300, 'TT', '2014-02-08', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128785, 'Couva', 'Couva', 'Couva Savannah Village,kwwa,کؤوا,کووا', 10.4224800, -61.4674800, 'TT', '2010-08-28', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128786, 'Chaguanas', 'Chaguanas', 'Chaguanas', 10.5166700, -61.4166700, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128787, 'Arouca', 'Arouca', 'Arouca,Arouca Village', 10.6287700, -61.3348700, 'TT', '2012-08-04', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128788, 'Arima', 'Arima', 'Arima,Town of Arima', 10.6333300, -61.2833300, 'TT', '2016-05-11', 226);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128598, 'Çakırlı', 'Cakirli', 'Cakirli,Çakırlı', 40.5180600, 29.4522200, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128599, 'Çakırca', 'Cakirca', 'Cakirca,Çakırca', 40.4705600, 29.6633300, 'TR', '2013-05-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128600, 'Çakıralan', 'Cakiralan', 'Cakiralan,Çakıralan', 41.1682400, 35.7601700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128601, 'Laçin', 'Lacin', 'Buyuk Lacin,Büyük Lâçin,Lacin,Laçin', 40.7748600, 34.8806800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128602, 'Büyükköy', 'Buyukkoy', 'Buyukkoy,Büyükköy', 41.0148900, 40.6730200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128603, 'Büyükkarıştıran', 'Buyukkaristiran', 'Buyukkaristiran,Büyükkarıştıran', 41.3002800, 27.5452800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128604, 'Chekmejeh', 'Chekmejeh', 'Buyuk Chekmejeh,Buyukcekmece,Büyükçekmece,Chekmejeh', 41.0128400, 28.5382400, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128605, 'Büyükçavuşlu', 'Buyukcavuslu', 'Buyukcavuslu,Büyükçavuşlu', 41.2400200, 28.0633100, 'TR', '2013-10-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128606, 'Adalar', 'Adalar', 'Adalar,Bujukada,Buyukada,Büyükada,Prinkipo,Буюкада', 40.8677800, 29.1330600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128607, 'Bursa', 'Bursa', 'Boursa,Brossa,Broussa,Brousse,Brusa,Brussa,Burs,Bursa,Bursae,Burso,Gorad Bursa,Prousa,YEI,bu er sa,buleusa,bur sa,bursa,burusa,bwrsa,bwrsh,bwrst,Προύσα,Бурсæ,Бурса,Бурсо,Горад Бурса,בורסה,برصہ,بورسا,بورصة,بورصه,بورصہ,بۇرسا,बुर्सा,บูร์ซา,ბურსა,ブルサ,布尔萨,부르사', 40.1955900, 29.0601300, 'TR', '2015-07-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128608, 'Sarıcakaya', 'Saricakaya', 'Bunaklar,Saricakaya,Sarioglan,Sarıcakaya,Sarıoğlan', 40.0368600, 30.6267500, 'TR', '2012-04-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128609, 'Bulancak', 'Bulancak', 'Akkoy,Akköy,Bulancak,Bulancik,Bulandzhak,Pulandjak,Буланджак', 40.9380500, 38.2314800, 'TR', '2016-07-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128610, 'Buğdaylı', 'Bugdayli', 'Bugdayli,Buğdaylı,Kavak,Kavakkoy,Kavakköy', 40.2188900, 27.7705600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128611, 'Bozkurt', 'Bozkurt', 'Bozkurt,Pazaryeri,Persembe,Persenbe,Perşembe,Perşenbe', 41.9576900, 34.0108700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128612, 'Boyalık', 'Boyalik', 'Boyalik,Boyalık,Hadimkoy,Hadımköy', 41.2633700, 28.6314200, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128613, 'Boyalıca', 'Boyalica', 'Boyalica,Boyalıca', 40.4819400, 29.5608300, 'TR', '2013-04-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128614, 'Boyabat', 'Boyabat', 'Boyabat', 41.4688900, 34.7666700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128615, 'Borçka', 'Borcka', 'Borchka,Borcka,Borçka,Yeniyol,Борчка', 41.3579200, 41.6657900, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128616, 'Bolu', 'Bolu', 'Boli,Bolou,Bolu,Claudiopolis,Gorad Balu,bo lu,bollu,bolu,boru,bwlw,bwly,Μπολού,Болу,Горад Балу,بولو,بولی,ბოლუ,ボル,博盧,볼루', 40.7358300, 31.6061100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128617, 'Bolayır', 'Bolayir', 'Bolayir,Bolayır,Bulair,Bulayir,Bulayır', 40.5153000, 26.7566400, 'TR', '2016-12-14', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128618, 'Bolaman', 'Bolaman', 'Bolaman,Boloman,Laleli,Lâleli', 41.0343500, 37.5940900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128619, 'Boğazkale', 'Bogazkale', 'Bogazkale,Bogazkoy,Boghazkeui,Bonazkoy Hattusa,Boğazkale,Boğazköy,Boŋazköy Hattusa,Hatti,Hattousa,Hattusa,Hattusas,Hattusha,Hattuşaş,Hattuša,Khattusa,Khattusas,Pteria,hatto~usha,htwss,khatwsha,Хаттуса,חתושש,خاتوشا,Ḫattušaš,ハットゥシャ', 40.0219100, 34.6094700, 'TR', '2012-04-29', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128620, 'Boğazkaya', 'Bogazkaya', 'Bogazkaya,Boğazkaya,Toskoy,Tosköy', 41.4500000, 35.8666700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128621, 'Eminbey', 'Eminbey', 'Binbasieminbey,Binbaşıeminbey,Cilvana,Ehminbej,Eminbey,Emirbey,Эминбей', 41.5475500, 42.7819900, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128622, 'Bilecik', 'Bilecik', 'Agrilium,Belocome,Bilecik,Biledzhik,Bilejik,Biletsik,Biləcik,bi lai ji ke,bilejiki,billejikeu,birejiku,bylh jk,bylyjk,Μπιλετσίκ,Биледжик,Біледжик,بيله جك,بیله‌جک,بیلیجک,ბილეჯიქი,ビレジク,比萊吉克,빌레지크', 40.1419200, 29.9793200, 'TR', '2012-01-16', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128623, 'Biga', 'Biga', 'Big,Biga,Biga i Canakkale,Biga i Çanakkale,Bigeh,bi jia,byga,byga   chanaq qala,Биг,Бига,Бигэ,بیگا,بیگا ، چاناق قالا,بیگا، چناق قلعہ,ضلع بیگا,比加', 40.2280600, 27.2422200, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128624, 'Asarcık', 'Asarcik', 'Asarcik,Asarcık,Bicincik,Biçincik', 41.0355600, 36.2355600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128625, 'Beypazarı', 'Beypazari', 'Baibazar,Bejpazary,Beypazari,Beypazarı,Distretto di Beypazari,Distretto di Beypazarı,Petobriga,bei yi pa zha lei,beipajaleu,Бейпазары,بی‌پازاری,بےپازاری، انقرہ,ضلع بیپزاری,貝伊帕扎勒,베이파자르', 40.1675000, 31.9211100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128626, 'Beyçayırı', 'Beycayiri', 'Beycayiri,Beyçayırı', 40.2551500, 26.9244200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128627, 'Beyazköy', 'Beyazkoy', 'Anittepe,Anıttepe,Beyazkoy,Beyazköy', 41.3483300, 27.7038900, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128628, 'Beşpınar', 'Bespinar', 'Bespinar,Beşpınar,Cakal,Çakal', 41.1382200, 35.2172400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128629, 'Beşikdüzü', 'Besikduzu', 'Besikduzu,Beşikdüzü,Sarli,Şarlı', 41.0520200, 39.2329400, 'TR', '2016-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128630, 'Bereketli', 'Bereketli', 'Bereketli,Busurum,Büşürüm,Берекетли', 40.5127300, 37.2886200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128631, 'Belören', 'Beloren', 'Beloren,Belveren,Belören', 40.8615600, 33.4955700, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128632, 'Bayramören', 'Bayramoren', 'Bayramolen,Bayramoren,Bayramölen,Bayramören', 40.9432900, 33.2030000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128633, 'Bayburt', 'Bayburt', 'Baberd,Baiburt,Baimpourt,Bajburt,Bayburt,Bayburt Province,Bayburtiaen,Bayburtiän,Bayburtska provincie,Bayburtská provincie,Paipourt,Provincia de Bayburt,Provinsi Bayburt,ba yi bu er te,ba yi bu er te sheng,baibuleuteu,baiburti,baiburuto,baybwrd,baybwrt,beburata,bybwrt,Μπαϊμπούρτ,Παϊπούρτ,Байбурт,Բաբերդ,بايبورت,بایبورت,بایبورد,بیبورت,ਬੇਬੁਰਤ,ბაიბურთი,バイブルト,巴伊布尔特省,巴伊布爾特,바이부르트', 40.2563100, 40.2228900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128634, 'Bayat', 'Bayat', 'Alagoz,Alagöz,Bayat', 40.6458300, 34.2613900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128635, 'Başgedikler', 'Basgedikler', 'Basgedikler,Bashgedikler,Başgedikler,Башгедиклер', 40.6406900, 43.5217900, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128636, 'Başçiftlik', 'Basciftlik', 'Basciftlik,Basciftlik Koyu,Başçiftlik,Başçiftlik Köyü', 40.5469400, 37.1691700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128637, 'Bartın', 'Bartin', 'Bartan,Bartheni,Bartin,Bartin Merkez,Bartyn,Bartın,Bartın Merkez,Parthenium,ba er teng,baleutin,bartini,bartn,bartyn,baruto~un,Μπαρτίν,Бартин,Бартын,بارتن,بارتين,بارتین,ბართინი,バルトゥン,巴爾滕,바르틴', 41.6358300, 32.3375000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128638, 'Bandırma', 'Bandirma', 'BDM,Banderma,Bandirma,Bandyrma,Bandırma,Panderma,Panormos,Panormus,Бандырма', 40.3522200, 27.9766700, 'TR', '2016-12-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128639, 'Banarlı', 'Banarli', 'Banarli,Banarlı', 41.0670200, 27.3357500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128640, 'Ondokuzmayıs', 'Ondokuzmayis', '19 Mayis,19 Mayıs,Ballica,Ballıca,Ondokuzmayis,Ondokuzmayıs', 41.5011000, 36.0688700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128641, 'Ballı', 'Balli', 'Balli,Ballı', 40.8302800, 27.0554800, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128642, 'Balıklıçeşme', 'Baliklicesme', 'Baliklicesme,Balıklıçeşme', 40.3102900, 27.0817100, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128643, 'Balçık', 'Balcik', 'Balcik,Balçık,Hamidiye', 40.8725000, 29.4283300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128644, 'Bakacak', 'Bakacak', 'Bakacak,Cerkezbakacagi,Ipkaiye,Çerkezbakacağı,İpkaiye', 40.2049900, 27.0831700, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128645, 'Bahçecik', 'Bahcecik', 'Bagchejik,Bahcecik,Bahçecik', 40.6681000, 29.9147800, 'TR', '2015-06-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128646, 'Bağcılar', 'Bagcilar', 'Badzilaras rajons,Bagdzhylar,Bādžilaras rajons,Cifitburgaz,Ciftburgaz,Çiftburgaz,Çıfıtburgaz,Багджылар', 41.0390300, 28.8567100, 'TR', '2014-02-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128647, 'Bafra', 'Bafra', 'Bafra,Paura,Бафра', 41.5677800, 35.9069400, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128648, 'Babaeski', 'Babaeski', 'Babaatik,Babaeski,Babaiatik', 41.4325000, 27.0930600, 'TR', '2013-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128649, 'Azdavay', 'Azdavay', 'Azdavay,Carsamba,Carsanba,Çarsanba,Çarşamba', 41.6426700, 33.3000000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128650, 'Ayvacık', 'Ayvacik', 'Ayvacik,Ayvacık', 40.9911100, 36.6313900, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128651, 'Aydıntepe', 'Aydintepe', 'Ajdyntepe,Aydintepe,Aydıntepe,Hart,Айдынтепе', 40.3832500, 40.1427200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128652, 'Aydıncık', 'Aydincik', 'Aydincik,Aydıncık,Eskikoy,Eskiköy,Mamure', 40.1272700, 35.2876500, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128653, 'Ezinepazarı', 'Ezinepazari', 'Aydinca,Aydınca,Ehzjnepazary,Ezinepazari,Ezinepazarı,Zigala,Эзйнепазары', 40.5697200, 36.1391700, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128654, 'Aybastı', 'Aybasti', 'Ajbasty,Aybasti,Aybastı,Esenli,Айбасты', 40.6866700, 37.3991700, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128655, 'Ayaş', 'Ayas', '', 40.0193300, 32.3322100, 'TR', '2009-10-28', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128656, 'Ayancık', 'Ayancik', 'Ayancik,Ayancık,Istifan,İstifan', 41.9447200, 34.5861100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128657, 'Atkaracalar', 'Atkaracalar', 'Atkaracalar', 40.8159300, 33.0755600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128658, 'Aşağı Irmaklar', 'Asagi Irmaklar', 'Asagi Irmaklar,Ashagy-Irmaklar,Aşağı Irmaklar,Ашагы-Ирмаклар', 41.1829900, 42.1744300, 'TR', '2016-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128659, 'Artvin', 'Artvin', 'Ardvin,Artivin,Artvin,Artwin,XHQ,a er te wen,aleuteubin,artvini,artwyn,arutovu~in,Αρτβίν,Артвин,Артвін,Арҭвин,Արդվին,آرتوین,أرتوين,ارتوین,ართვინი,アルトヴィン,阿爾特溫,아르트빈', 41.1816100, 41.8217200, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128660, 'Artova', 'Artova', 'Artova,Kunduz,Артова', 40.1157800, 36.3001000, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128661, 'Arsin', 'Arsin', 'Arseni Zir,Arsin,Asagi Arsin,Aşağı Arsin', 40.9527100, 39.9267400, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128662, 'Arpaçay', 'Arpacay', 'Arpacay,Arpachaj,Arpaçay,Sarusat,Saruşat,Zarsat,Zarusat,Zaruşat,Zarşat,Арпачай', 40.8452200, 43.3274700, 'TR', '2015-04-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128663, 'Armutlu', 'Armutlu', 'Armadivos,Armadiyos,Armadıyos,Armidiyos,Armudli,Armutli,Armutlu', 40.5194400, 28.8280600, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128664, 'Arıt', 'Arit', 'Arit,Arıt,Mentespiri,Menteşpiri', 41.6870600, 32.6239600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128665, 'Arifiye', 'Arifiye', 'Arifiye', 40.7003600, 30.3507600, 'TR', '2015-11-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128666, 'Arhavi', 'Arhavi', 'Arhavi,Musazade,Мусазаде', 41.3512100, 41.3045600, 'TR', '2013-12-12', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128667, 'Çamiçi', 'Camici', 'Aguslu,Ardicli,Ardıçlı,Camici,Çamiçi', 40.6181000, 37.0016900, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128668, 'Ardeşen', 'Ardesen', 'Ardasen,Ardaşen,Ardesen,Ardeshen,Ardeşen,Ardisin,Ardişin,Ардешен', 41.1911100, 40.9875000, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128669, 'Ardanuç', 'Ardanuc', 'Adakale,Ardanuc,Ardanuch,Ardanuç,Tutunlu,Tütünlü,Ардануч', 41.1273800, 42.0629200, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128670, 'Ardahan', 'Ardahan', 'Ardaa,Ardagan,Ardahan,Ardakhan,Ardaã,Arntachan,Erdexan,Erdêxan,a er da han,aleudahan,ardahan,ardakhan,ardhan,arudahan,Ərdəhan,Αρνταχάν,Ардаган,Ардахан,Արդահան,ארדהאן,أرداهان,ارداخان,ارداہان,اردهان,არტაანი,アルダハン,阿爾達漢,아르다한', 41.1087100, 42.7022200, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128671, 'Araklı', 'Arakli', 'Arakli,Arakli Carsusu,Araklicarsisi,Arakly,Araklı,Araklı Çarşusu,Araklıçarşısı,Iraklia,Surmene,Sürmene,Араклы', 40.9385400, 40.0584200, 'TR', '2017-06-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128672, 'Araç', 'Arac', 'Arac,Araç', 41.2422200, 33.3276700, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128673, 'Amasya', 'Amasya', 'Amas''ja,Amasea,Amaseia,Amasia,Amasija,Amasiyah,Amasya,Amasya ringkond,Amàsia,Amásia,MZH,a ma xi ya,amasi''a,amasia,amasu~iya,amasya,amasyh,yamasya,Αμάσεια,Амасия,Амасья,Ամասիա,אמסיה,آماسیه,أماصيا,ئاماسیا,اماسیا,ਅਮਾਸਿਆ,ამასია,アマスィヤ,阿馬西亞,아마시아', 40.6533300, 35.8330600, 'TR', '2017-01-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128674, 'Amasra', 'Amasra', 'Amasra,Amasreh,Amassera,Amastra,Amastris,Sesamus', 41.7463300, 32.3863300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128675, 'Alucra', 'Alucra', 'Alucara,Alucra,Aludzhra,Mesudiye,Алуджра', 40.3165600, 38.7528500, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128676, 'Altınova', 'Altinova', 'Altinova,Altınova', 40.6949500, 29.5098600, 'TR', '2012-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128677, 'Almus', 'Almus', 'Almis,Almus,Almıs,Tozanli,Tozanlı,Алмус', 40.3758300, 36.9044400, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128678, 'Alıcık', 'Alicik', 'Alicak,Aliccik,Alicik,Alıcak,Alıccık,Alıcık', 40.8027500, 35.3225600, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128679, 'Alaplı', 'Alapli', 'Alapli,Alaplı,Yukaridogancilar,Yukaridogncilar,Yukarıdoğancılar,Yukarıdoğncılar', 41.1814000, 31.3851400, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128680, 'Alanyurt', 'Alanyurt', 'Adabinli,Alanyurt', 40.1088100, 29.5187100, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128681, 'Alaçam', 'Alacam', 'Alacam,Alacham,Alaçam,Zalecus,Zaliscus', 41.6055600, 35.5980600, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128682, 'Alaca', 'Alaca', 'Alaca,Huseyinabat,Huseyinbat,Huseynabat,Hüseyinabat,Hüseyinbat,Hüseynabat', 40.1683300, 34.8425000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128683, 'Akyurt', 'Akyurt', 'Akyurt,Ravli', 40.1351200, 33.0861400, 'TR', '2010-08-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128684, 'Akyazı', 'Akyazi', 'Akyaz,Akyazi,Akyazı', 40.6850000, 30.6222200, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128685, 'Akyaka', 'Akyaka', 'Ak"jaka,Akkaya,Akyaka,Kizil Cnakh,Kizilcakcak,Kızılçakçak,Suregel,Surgel,Süregel,Sürgel,Акъяка', 40.7409300, 43.6143200, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128686, 'Aksu', 'Aksu', 'Aksu,Aksu Koyu,Aksu Köyü,Аксу', 40.0896400, 38.0346700, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128687, 'Akşar', 'Aksar', 'Aksar,Akshar,Akşar,Акшар', 40.6465100, 42.3391000, 'TR', '2014-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128688, 'Aksakal', 'Aksakal', 'Ak Sakal Koy,Ak Sakal Köy,Aksakal', 40.1472500, 28.1068000, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128689, 'Mollafeneri', 'Mollafeneri', 'Akoren,Akviran,Akören,Aren,Mollafeneri', 40.8861100, 29.4944400, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128690, 'Akmeşe', 'Akmese', 'Akmese,Akmeşe,Ermese,Ermeşe', 40.8492900, 30.1982200, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128691, 'Akkuş', 'Akkus', 'Akkus,Akkush,Akkuş,Аккуш', 40.7930600, 37.0163900, 'TR', '2014-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128692, 'Akıncılar', 'Akincilar', 'Akincilar,Akyndzhilar,Akıncılar,Ezbider,Yukari Ezbider,Yukarı Ezbider,Акынджилар', 40.0717200, 38.3433000, 'TR', '2015-08-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128693, 'Akdağ', 'Akdag', 'Akdag,Akdağ,Cigdemlik,Zana,Çiğdemlik', 40.7123500, 35.9760500, 'TR', '2013-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128694, 'Akçakoca', 'Akcakoca', 'Akcakoca,Akcasehir,Akche Shehr,Akcheh,Akçakoca,Akçaşehir,Dia,Diospolis', 41.0866300, 31.1162300, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128695, 'Akçaabat', 'Akcaabat', 'Akcaabat,Akchaabad,Akçaabat,Hermonassus,Hermyse,Platana,Polatane,Polathane,Pulathane,Акчаабад', 41.0212100, 39.5714600, 'TR', '2014-06-27', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128696, 'Ağlı', 'Agli', 'Agil,Agilpazari,Agli,Aglikoy,Ağlı,Ağlıköy,Ağıl,Ağılpazarı,Kuruoglu,Kuruoğlu', 41.6860200, 33.5538300, 'TR', '2015-09-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128697, 'Adapazarı', 'Adapazari', 'Ada Bazar,Adapazar,Adapazari,Adapazaris,Adapazaru,Adapazary,Adapazarı,Antapazari,Gorad Adapazary,Sakar''ja,Sakarya,Tarsia,a da pa zha lei,adabazary,adapajali,adapazari,adapazaru,adapazary,yadapazary,Ανταπαζαρί,Адапазар,Адапазари,Адапазаръ,Адапазары,Адаҧазары,Горад Адапазары,Сакарья,Ադաբազարը,آدابازاري,آداپازاری,ئاداپازاری,ضلع اداپازاری,ადაფაზარი,アダパザル,阿达帕扎勒,아다파자리', 40.7805600, 30.4033300, 'TR', '2010-08-14', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128698, 'Abana', 'Abana', 'Abana,Apana', 41.9785800, 34.0110000, 'TR', '2012-01-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128699, 'Espiye', 'Espiye', 'Espiye', 40.9470500, 38.7029900, 'TR', '2015-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128700, 'Celâliye', 'Celaliye', '', 41.0518800, 28.4186700, 'TR', '2010-02-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128701, 'Muratbey', 'Muratbey', '', 41.0963000, 28.4922700, 'TR', '2010-02-17', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128702, 'Halıdere', 'Halidere', 'Halidere,Halıdere', 40.7160400, 29.7522300, 'TR', '2012-09-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128703, 'İçmeler', 'Icmeler', 'Ichlemer,Ichmeler,Icmeler,İçmeler,Ичмелер', 40.8463900, 29.3088900, 'TR', '2012-01-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128704, 'Merter Keresteciler', 'Merter Keresteciler', '', 41.0129500, 28.8859300, 'TR', '2017-05-23', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128705, 'güngören merter', 'guengoeren merter', 'Merter', 41.0071100, 28.8879500, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128706, 'Demre', 'Demre', 'Demre,Демре', 36.2537000, 29.9777000, 'TR', '2008-11-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128707, 'Turgutreis', 'Turgutreis', '', 37.0166700, 27.2666700, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128708, 'Karatay', 'Karatay', '', 37.8672600, 32.5286300, 'TR', '2015-06-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128709, 'Sarigerme', 'Sarigerme', 'Sarigerme,Саригерме', 36.7154900, 28.7043600, 'TR', '2009-01-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128710, 'Ölüdeniz', 'OEluedeniz', 'OEluedeniz,Oljudeniz,Oludeniz,Ölüdeniz,Олюдениз', 36.5667400, 29.1446700, 'TR', '2013-11-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128711, 'Arıköy', 'Arikoey', '', 41.2304400, 29.0042500, 'TR', '2009-04-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128712, 'Çatalhöyük', 'Catalhoeyuek', 'Catal Hejuk,Catal Hiujukas,Catal Hoeyuek,Catal Hueyuek,Catalhjujuka,Catalhoyuk,Catalhueyuek,Chatal Khejuk,Chatal-Gjujuk,Chatal-Khjujuk,Chatalkh''ojuk,Tsatalogiouk,chatalhoiuki,jia tai tu qiu,ztlhwywq,Çatal Höyük,Çatal Hüyük,Çatalhüyük,Čatal Hejuk,Čatal Hiujukas,Čatalhjujuka,Τσαταλογιούκ,Чатал Хејук,Чатал-Гююк,Чатал-Хююк,Чаталхьоюк,Чаталхѷюкъ,צטלהויוק,ჩათალჰოიუქი,チャタル・ヒュユク,加泰土丘', 37.6684700, 32.8268900, 'TR', '2009-04-18', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128713, 'Adalan', 'Adalan', 'Khejbeliada,Хейбелиада', 40.8759000, 29.0894000, 'TR', '2013-08-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128714, 'Ataşehir', 'Atasehir', '', 40.9833000, 29.1167000, 'TR', '2015-04-03', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128715, 'Başakşehir', 'Basaksehir', '', 41.0930700, 28.8020300, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128716, 'Beylikdüzü', 'Beylikduezue', '', 40.9820000, 28.6399000, 'TR', '2010-12-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128717, 'Büyükçekmece', 'Bueyuekcekmece', '', 41.0207200, 28.5850200, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128718, 'Çankaya', 'Cankaya', 'Cankaya,Çankaya', 39.9179000, 32.8626800, 'TR', '2015-05-14', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128719, 'Yaniklar', 'Yaniklar', 'Janyklar,Yaniklar,Yanıklar,Яныклар', 36.7082700, 29.0508100, 'TR', '2010-03-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128720, 'Battalgazi', 'Battalgazi', 'Battalgazi', 38.4228600, 38.3585000, 'TR', '2015-08-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128721, 'Güce', 'Guce', 'Guce,Güce', 40.8932000, 38.7982000, 'TR', '2015-02-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128722, 'Çatalpınar', 'Catalpinar', '', 40.8789900, 37.4535100, 'TR', '2010-11-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128723, 'Şehitkamil', 'Sehitkamil', 'Sehitkamil,Şehitkamil', 37.0796200, 37.3800300, 'TR', '2015-09-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128724, 'Şahinbey', 'Sahinbey', 'Sahinbey,Sakhinbej,Şahinbey,Сахинбей', 37.0483600, 37.3437100, 'TR', '2014-04-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128725, 'Bahçelievler', 'Bahcelievler', '', 41.0023100, 28.8598000, 'TR', '2010-12-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128726, 'Sultangazi', 'Sultangazi', '', 41.1065200, 28.8684700, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128727, 'Sultanbeyli', 'Sultanbeyli', '', 40.9607200, 29.2706700, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128728, 'Sancaktepe', 'Sancaktepe', '', 41.0024400, 29.2318700, 'TR', '2011-01-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128729, 'Kamışlı', 'Kamisli', 'Kamisli,Kamışlı', 37.5551900, 34.9472000, 'TR', '2013-09-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128730, 'Köprübaşı', 'Koprubasi', 'Koprubasi,Köprübaşı', 41.0475400, 35.5168700, 'TR', '2013-09-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128731, 'Çayırkent', 'Cayirkent', 'Cayirkent,Çayırkent', 41.1712800, 36.3288300, 'TR', '2013-09-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128732, 'Salıpazarı', 'Salipazari', '', 41.0839800, 36.8304000, 'TR', '2011-03-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128733, 'Karabağlar', 'Karabaglar', '', 38.3739600, 27.1352000, 'TR', '2011-03-09', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128734, 'Muratpaşa', 'Muratpasa', 'Muratpasa,Muratpaşa', 36.8915700, 30.7649800, 'TR', '2015-06-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128735, 'Okurcalar', 'Okurcalar', '', 36.6487600, 31.7038700, 'TR', '2013-11-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128736, 'Cumayeri', 'Cumayeri', 'Cumayeri', 40.8738900, 30.9509100, 'TR', '2012-05-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128737, 'Ortaköy', 'Ortakoy', 'Ortakoy,Ortaköy', 40.9730500, 30.6768600, 'TR', '2013-09-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128738, 'Polateli', 'Polateli', '', 36.8413700, 37.1440700, 'TR', '2012-06-07', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128739, 'Ovacık', 'Ovacik', 'Ovacik,Ovacık', 36.1713200, 33.5558100, 'TR', '2013-09-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128740, 'Kazımpaşa', 'Kazimpasa', 'Kazimpasa,Kazımpaşa', 40.7916000, 30.2950000, 'TR', '2013-09-11', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128741, 'Akçaova', 'Akcaova', 'Akcaova,Akçaova', 41.0366000, 29.9018000, 'TR', '2016-08-04', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128742, 'Termal', 'Termal', 'Termal', 40.6077900, 29.1736000, 'TR', '2012-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128743, 'Yıldırım', 'Yildirim', 'Yildirim,Yıldırım', 40.1885100, 29.1097400, 'TR', '2015-07-20', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128744, 'Osmangazi', 'Osmangazi', 'Osmangazi', 40.1967100, 29.0593500, 'TR', '2015-07-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128745, 'Büyükorhan', 'Buyukorhan', 'Buyukorhan,Büyükorhan', 39.7710200, 28.8861400, 'TR', '2013-06-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128746, 'Akçasır', 'Akcasir', 'Akcasir,Akçasır', 38.4472200, 41.2651300, 'TR', '2013-09-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128747, 'Taşburun', 'Tasburun', 'Tasburun,Taşburun', 39.9860700, 44.2235900, 'TR', '2013-09-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128748, 'Bağlar', 'Baglar', 'Baglar,Bağlar', 37.9137500, 40.2058400, 'TR', '2015-02-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128749, 'Sur', 'Sur', 'Sur', 37.9135100, 40.2285900, 'TR', '2015-02-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128750, 'Yenişehir', 'Yenisehir', 'Yenisehir,Yenişehir', 37.9414600, 40.1380100, 'TR', '2015-02-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128751, 'Palandöken', 'Palandoken', 'Palandoken,Palandöken', 39.8889800, 41.2805500, 'TR', '2015-06-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128752, 'Kazımkarabekir', 'Kazimkarabekir', 'Kazimkarabekir,Kazımkarabekir', 39.9159800, 41.2814500, 'TR', '2015-06-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128753, 'Yakutiye', 'Yakutiye', 'Yakutiye', 39.8982100, 41.2691600, 'TR', '2015-06-10', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128754, 'Tepebaşı', 'Tepebasi', 'Tepebasi,Tepebaşı', 39.8109100, 30.5255100, 'TR', '2015-07-26', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128755, 'Odunpazarı', 'Odunpazari', 'Odunpazari,Odunpazarı', 39.7682100, 30.5353800, 'TR', '2015-06-24', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128756, 'Pamukkale', 'Pamukkale', 'Pamukkale', 37.7912000, 29.1014100, 'TR', '2015-06-21', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128757, 'Nilüfer', 'Niluefer', 'Niluefer,Nilufer,Nilüfer', 40.2140100, 28.9156700, 'TR', '2015-07-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128758, 'Çaybağı', 'Caybagi', 'Caybagi,Çaybağı', 38.8285500, 39.6105700, 'TR', '2015-07-05', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128759, 'Merkez', 'Merkez', '', 40.1295400, 26.4207500, 'TR', '2015-07-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128760, 'İlkadım', 'Ilkadim', 'Ilkadim,İlkadım', 41.2873200, 36.2904600, 'TR', '2015-07-13', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128761, 'Kepez', 'Kepez', '', 36.9157900, 30.7078200, 'TR', '2015-07-19', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128762, 'Ümraniye', 'UEmraniye', 'UEmraniye,Ümraniye', 41.0329100, 29.1013700, 'TR', '2015-09-02', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128763, 'Altınordu', 'Altinordu', 'Altinordu,Altınordu', 40.9840400, 37.8734800, 'TR', '2015-08-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128764, 'Kürecik', 'Kurecik', 'Kurecik,Kürecik', 38.3367500, 37.7414200, 'TR', '2015-09-08', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128765, 'Doğruyol', 'Dogruyol', 'Dogruyol,Doğruyol', 41.0613200, 43.3220100, 'TR', '2016-07-06', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128766, 'Merkezefendi', 'Merkezefendi', '', 37.8054400, 29.0423600, 'TR', '2016-08-30', 228);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128789, 'Toga Village', 'Toga Village', 'Tonga', -6.2876400, 176.3147200, 'TV', '2013-07-08', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128790, 'Tanrake Village', 'Tanrake Village', 'Tanrake,Tapotali', -7.2456200, 177.1451100, 'TV', '2013-07-08', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128791, 'Kulia Village', 'Kulia Village', '', -6.1081900, 177.3339300, 'TV', '2013-07-08', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128792, 'Funafuti', 'Funafuti', 'FUN,Fongafale,Fongafale (atolon de Funafuti),Fongafale (atolón de Funafuti),Funafuti,Phounaphouti,Φουναφούτι', -8.5242500, 179.1941700, 'TV', '2014-08-19', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128793, 'Asau Village', 'Asau Village', '', -7.4902600, 178.6801600, 'TV', '2013-07-08', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128794, 'Savave Village', 'Savave Village', '', -8.0273100, 178.3135100, 'TV', '2013-07-08', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128795, 'Alapi Village', 'Alapi Village', '', -8.5207400, 179.1968000, 'TV', '2010-11-23', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(128796, 'Fakaifou Village', 'Fakaifou Village', '', -8.5175800, 179.2009400, 'TV', '2010-11-24', 231);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129118, 'Olenevka', 'Olenevka', 'Karadzhi,Olenevka,Qaragy,Qarağy,Караджи́,Оленевка', 45.3833300, 32.5333300, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129119, 'Urzuf', 'Urzuf', 'Primorskoye,Urzuf,Urzufskiye,Zelenoye,Урзуф', 46.9156200, 37.0996100, 'UA', '2014-09-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129120, 'Lebedyn', 'Lebedyn', 'Lebedin,Lebedina,Lebedine,Lebedyn,Lebedîn,Lebedın,lbdyn,lebedini,lie bie jin,Łebedyn,Лебедин,Լեբեդին,لبدین,ლებედინი,列別金', 50.5851800, 34.4849000, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129121, 'Staryy Dobrotvir', 'Staryy Dobrotvir', 'Starij Dobrotvir,Staryy Dobrotvir,Staryy Dobrotvor,Старий Добротвір', 50.2315400, 24.3770100, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129122, 'Druzhkivka', 'Druzhkivka', 'Druzhkivka,Druzhkovka,Дружковка,Дружківка', 48.6301300, 37.5525900, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129123, 'Zhydachiv', 'Zhydachiv', 'Jidaciv,Jydatchiv,Jîdaciv,Jıdaçiv,Schydatschiw,Zhidachev,Zhidachiv,Zhidachov,Zhidechuv,Zhidáchiv,Zhydachiv,Zhydachuv,Zidaciva,Zjydatsjiv,Zydaciv,Zydaczow,jydatshyf,ri da qiao fu,zhidachovi,zhydashyf,Żydaczów,Židačiva,Žydačiv,Жидачов,Жидачів,Ժիդաչև,זידאצוב,جيداتشيف,ژیداشیف,ჟიდაჩოვი,日達喬夫', 49.3846800, 24.1425400, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129124, 'Vasylivka', 'Vasylivka', 'Vasil''evka,Vasil''yevka,Vasilevka,Vasilievka,Vasilivka,Vasil’yevka,Vassolivka,Vassylivka,Vassõlivka,Vasylivka,Vasîlivka,Vasılivka,Wassyliwka,Wasyliwka,fasylyfka,wa xi li fu ka,wasylyfka,Василивка,Васильевка,Василівка,Վասիլիևկա,فاسيليفكا,واسیلیفکا,ვასილიევკა,瓦西利夫卡', 47.4369400, 35.2741700, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129125, 'Kovyl’noye', 'Kovyl''noye', 'Kovil''ne,Kovyl''noe,Kovyl''noye,Kovyl’noye,Manaj,Monaj Nemeckij,Ковильне,Ковыльное,Мона́й Неме́цкий', 45.6902800, 33.5277500, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129126, 'Ivano-Frankove', 'Ivano-Frankove', 'Imeni Ivana Franko,Ivana Franko,Ivano-Frankove,Ivano-Frankovo,Janow,Janów,Yanov,Yanuv,Івано-Франкове,Ивано-Франково', 49.9197800, 23.7291300, 'UA', '2013-02-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129127, 'Zybiny', 'Zybiny', 'Arginchik,ArƔyncyq,ArƔynčyq,Zibini,Zybiny,Аргинчи́к,Зибини,Зыбины', 45.2367400, 34.6498700, 'UA', '2017-02-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129128, 'Zvenyhorodka', 'Zvenyhorodka', 'Swenyhorodka,Zvenigorodka,Zvenihorodka,Zvenogorodka,Zvenyhorodka,Zvenîhorodka,Zvenõgorodka,Zvenıgorodka,Zwinogrodka,Zwinogródka,zbnygwrwdqh,zfynyhwrwdka,zi wei ni ge luo de ka,zwnyhwrwdka,Звенигородка,Զվենիգորոդկա,זבניגורודקה,زفينيهورودكا,زونیهورودکا,ზვეინიგოროდკა,茲韋尼戈羅德卡', 49.0786600, 30.9675500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129129, 'Zuya', 'Zuya', 'Zuja,Zuya,Зуя', 45.0541800, 34.3215200, 'UA', '2016-11-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129130, 'Zuhres', 'Zuhres', 'Zugrehs,Zugres,Zuhres,Зугрес,Зугрэс', 48.0114000, 38.2644400, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129131, 'Zorkino', 'Zorkino', 'Dulat,Zorkine,Zorkino,Дула́т,Зоркино,Зоркіне', 45.5476200, 34.7102800, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129132, 'Zoryns’k', 'Zoryns''k', 'Yelenovka,Yelënovka,Zorins''k,Zorinsk,Zoryns''k,Zoryns’k,Зоринск,Зоринськ', 48.4119400, 38.6236100, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129133, 'Zolotyy Potik', 'Zolotyy Potik', 'Potok,Potok Zloty,Potok Złoty,Zolotij Potik,Zolotoy Potok,Zolotyy Potik,Золотий Потік', 48.9095000, 25.3392600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129134, 'Zolotoye Pole', 'Zolotoye Pole', 'Cjurikhtal'',Dzhajlav-Saraj,Zolote Pole,Zolotoe Pole,Zolotoye Pole,Джайла́в-Сара́й,Золоте Поле,Золотое Поле,Цюрихта́ль', 45.1277400, 34.9914800, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129135, 'Zolotonosha', 'Zolotonosha', 'Zolotonosha,Золотоноша', 49.6683200, 32.0404700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129136, 'Zolochiv', 'Zolochiv', 'Zolochev,Zolochiv,Золочев,Золочів', 50.2798500, 35.9817900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129137, 'Zolochiv', 'Zolochiv', 'Solotschiw,Zlochev,Zlochuv,Zloczow,Zolochev,Zolochiv,Zolociv,Zolociva,Zolotchiv,Zolotjiv,Zolotsiv,Zolotsjiv,Zolotšiv,Zoloçiv,Zoločiv,Zoločiva,Złoczów,jollochiu,tslwktswf,zlwtswb,zolochevi,zorochiu,zuo luo qiao fu,zwlwtshyf,Золочев,Золочив,Золочів,Զոլոչև,זלוטשוב,تسلوکتسوف,زولوتشيف,ზოლოჩევი,ゾーロチウ,佐洛乔夫,졸로치우', 49.8059700, 24.8943600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129138, 'Znomenka', 'Znomenka', 'Snamenka,Znam"yanka,Znam''janka,Znamenka,Znamenka Pervaya,Znam”yanka,Znomenka,Знаменка,Знам’янка', 48.7127800, 32.6647200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129139, 'Zmiyiv', 'Zmiyiv', 'Gottvald,Gotval''d,Gotval’d,Zmiev,Zmiiv,Zmiyev,Zmiyiv,Змиев,Зміїв', 49.6745300, 36.3477500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129140, 'Zlynka', 'Zlynka', 'Novoukrainsk,Zlinka,Zlynka,Злинка,Злынка', 48.4852100, 31.5390600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129141, 'Zimino', 'Zimino', 'Perecfel''d,Zimine,Zimino,Зимине,Зимино,Перецфе́льд', 45.5079700, 33.5143100, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129142, 'Zhytomyr', 'Zhytomyr', 'Gorad Zhytomir,Jitomir,Jytomyr,Jytómyr,Jîtomîr,Jıtomır,Schytomyr,Shitomir,ZTR,Zhitomir,Zhitomiru,Zhytomir,Zhytomyr,Zitomir,Zitomiria,Zjytomyr,Zotomor,Zsitomir,Zytomierz,Zytomyr,Zytomyras,jitomileu,jitomu~iru,jytwmyr,ri tuo mi er,z''ytwmyr,zhytwmyr,Ĵitomir,Żytomierz,Žitomir,Žytomyr,Žytomyras,Žõtomõr,Горад Жытомір,Житомир,Житомиръ,Жытомир,Ժիտոմիր,ז''יטומיר,זשיטאמיר,جيتومير,ژیتومیر,ჟიტომირი,ジトームィル,日托米尔,지토미르', 50.2648700, 28.6766900, 'UA', '2013-05-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129143, 'Zhvanets', 'Zhvanets', 'Zhvanec,Zhvaned,Жванец', 48.5496800, 26.4874400, 'UA', '2010-07-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129144, 'Zhuravki', 'Zhuravki', 'Seit-Ehli,Zhuravki,Журавки,Сеи́т-Эли́', 45.1262900, 35.2151300, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129145, 'Zhuravka', 'Zhuravka', 'Zhuravka,Журавка', 50.4810800, 32.5949000, 'UA', '2013-07-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129146, 'Zhovtneve', 'Zhovtneve', 'Biliche,Bilicze,Vilichi,Zhovtneve,Zhovtnevoye,Жовтневе', 50.6636500, 24.2491800, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129147, 'Zhovkva', 'Zhovkva', 'Nesterov,Schowkwa,Zholkev,Zholkva,Zhovkva,Zhulkev,Zolkiew,Zovkva,joukeuba,joukuvu~a,z''wbqbh,Żółkiew,Žovkva,Жовква,Жолква,ז''ובקבה,ジョウクヴァ,조우크바', 50.0582500, 23.9726000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129148, 'Zhmerynka', 'Zhmerynka', 'Zhmerinka,Zhmerynka,Жмеринка', 49.0370500, 28.1120100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129149, 'Zhemchuzhina', 'Zhemchuzhina', 'Choty,Zhemchuzhina,Жемчужина,Чоты́', 45.2746600, 34.6577800, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129150, 'Zhelyabovka', 'Zhelyabovka', 'Andreevka,Chaja,Zheljabovka,Zhelyabovka,Андре́евка,Желябовка,Чая́', 45.3987700, 34.7577600, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129151, 'Zhovti Vody', 'Zhovti Vody', 'Geltonieji Vandenys,Jovti Vodi,Jovti Vody,Jovti Vodî,Jovti Vodı,Rudnik Shvarts,Scholti Woody,Schowti Wody,Zheleznyy Rudnik Shvarts,Zheltaya Reka,Zheltye Vody,Zheltyye Vody,Zhjoltye Vody,Zholtie vodi,Zhovti Vodi,Zhovti Vody,Zhyeltyy Vody,Zhëltaya Reka,Zhëltyye Vody,Zjovti Vody,Zolte Wody,Zovti Vodi,Zovti Vody,Zyoltie Vodi,jwfty fwdy,zhwfty wwdy,Żółte Wody,Žovti Vodi,Žovti Vody,Желтые Воды,Жовти Води,Жовті Води,Жолтие води,Жёлтые Воды,Ժյոլտիե Վոդի,جوفتي فودي,ژوفتی وودی,ჟოლტიე-ვოდი,ジョーウチ・ヴォーディ', 48.3449300, 33.5037400, 'UA', '2016-03-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129152, 'Zhashkiv', 'Zhashkiv', 'Zasashkhov,Zaskiv,Zhashkiv,Zhashkov,Жашков,Жашків', 49.2454500, 30.1102000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129153, 'Zgurovka', 'Zgurovka', 'Z.hurivka,Zgurivka,Zgurovka,Zhurivka,Z·hurivka,Згуровка,Згурівка', 50.5027600, 31.7849200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129154, 'Zernovoye', 'Zernovoye', 'Jakubovka,Zernove,Zernovoe,Zernovoye,Зернове,Зерновое,Яку́бовка', 45.3236400, 34.4809900, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129155, 'Zin’kiv', 'Zin''kiv', 'Zen''kov,Zen’kov,Zin''kiv,Zin’kiv,Зеньков,Зіньків', 50.2080600, 34.3637600, 'UA', '2014-03-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129156, 'Zemlyanichnoye', 'Zemlyanichnoye', 'Ortalan,Zemljanichne,Zemljanichnoe,Zemlyanichnoye,Земляничне,Земляничное,Ортала́н', 44.9744400, 34.8355300, 'UA', '2016-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129157, 'Zelyonoye', 'Zelyonoye', 'Tatar-Osman,Zelene,Zeljonoe,Zelyonoye,Зелене,Зелёное,Тата́р-Осма́н', 44.5958300, 34.0092100, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129158, 'Zelenogorskoye', 'Zelenogorskoye', 'Zelenogirs''ke,Zelenogorskoe,Zelenogorskoye,Зеленогорское,Зеленогірське', 45.0124900, 34.4684800, 'UA', '2016-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129159, 'Zdolbuniv', 'Zdolbuniv', 'Zdolbuniv,Zdolbunov,Zdolbunovo,Zdolbunow,Zdolbunuv,Zdołbunów,Здолбунов,Здолбунів', 50.5206000, 26.2425100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129160, 'Zdovbytsya', 'Zdovbytsya', 'Zdolbica,Zdolbitsa,Zdovbicja,Zdovbytsya,Zdołbica,Здовбиця', 50.4960700, 26.2411100, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129161, 'Zboriv', 'Zboriv', 'Zboriv,Zborov,Zborow,Zboruv,Zborów,Зборів', 49.6648400, 25.1409700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129162, 'Zbarazh', 'Zbarazh', 'Zbaraz,Zbarazh,Збараж', 49.6635700, 25.7761600, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129163, 'Zavetnoye', 'Zavetnoye', 'Saurchi,Zavetnoe,Zavetnoye,Zavitne,Заветное,Завітне,Саурчи́', 45.3269700, 34.8083700, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129164, 'Zavetnoye', 'Zavetnoye', 'Janysh-Takil,Koep Taqyl,Köp Taqyl,Zavetnoe,Zavetnoye,Zavitne,Заветное,Завітне,Яны́ш-Таки́л', 45.1230500, 36.3996500, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129165, 'Zavet-Leninskiy', 'Zavet-Leninskiy', 'Kuchuk-Alkaly,Zavet-Leninskij,Zavet-Leninskiy,Zavit-Lenins''kij,Завет-Ленинский,Завіт-Ленінський,Кучу́к-Алкалы́', 45.8625800, 34.3916000, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129166, 'Zavallya', 'Zavallya', 'Zaval''e,Zaval''ye,Zavallja,Zavallya,Zaval’ye,Завалля,Завалье', 48.2135400, 30.0155800, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129167, 'Karolino-Buhaz', 'Karolino-Buhaz', 'Bugaz,Kar''yer Devyatnadtsat'' Kilometrov,Karalino Bugaz,Karolino-Bugaz,Karolino-Buhaz,Kar’yer Devyatnadtsat’ Kilometrov,Zatoka,Каролино-Бугаз,Кароліно-Бугаз', 46.1449200, 30.5260900, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129168, 'Zatoka', 'Zatoka', 'Bugas,Bugaz,Zatoka,Затока', 46.0725100, 30.4653800, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129169, 'Zatyshshya', 'Zatyshshya', 'Zatish''ye,Zatishshja,Zatish’ye,Zatyshshya,Затишшя', 47.3335100, 29.8732700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129170, 'Zastavna', 'Zastavna', 'Zastavka,Zastavna,Zastazna,Заставна', 48.5230700, 25.8436900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129171, 'Zorya', 'Zorya', 'Camcic,Camcicu,Kamchik,Kamchiku,Zarya,Zorja,Zorya,Зоря', 45.9908000, 29.6967200, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129172, 'Zarichchya', 'Zarichchya', 'Zarech''ye,Zarech’ye,Zaricca,Zarichchya,Zazheche,Заріччя', 48.5214400, 24.6485700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129173, 'Zarichne', 'Zarichne', 'Pogost Zazhechny,Pogost-Zarechnyy,Pohost Zarzeczny,Zarechnoye,Zarichne,Zaricne,Зарічне', 51.8126000, 26.1290200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129174, 'Zarechnoye', 'Zarechnoye', 'Kamadzhi,Zarechnoe,Zarechnoye,Zarichne,Заречное,Зарічне,Камаджи́', 45.7363600, 34.4834500, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129175, 'Zarechnoye', 'Zarechnoye', 'Ajan,Shumkhaj,Zarechnoe,Zarechnoye,Zarichne,Заречное,Зарічне,Шумха́й', 44.8504800, 34.2642600, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129176, 'Zaporizhia', 'Zaporizhia', 'Aleksandrovsk,Alexandrovsk,OZH,Saporischschja,Saporoshje,Zaborozha,Zaporijia,Zaporizhia,Zaporizhzhya,Zaporizza,Zaporizzja,Zaporižžja,Zaporozh''e,Zaporozh''ye,Zaporozhye,Zaporozh’e,Zaporozh’ye,Алекса́ндровск,Запорожье,Запоріжжя', 47.8228900, 35.1903100, 'UA', '2016-11-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129177, 'Zaozyornoye', 'Zaozyornoye', 'Gaɣa Bojnaq,Jaly-Mojnak,Zaozerne,Zaozernoe,Zaozyornoye,Ğaɣa Bojnaq,Заозерне,Заозерное,Ялы́-Мойна́к', 45.1581600, 33.2786600, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129178, 'Zaliztsi', 'Zaliztsi', 'Zalizci,Zaliztsi,Zaliztsy,Zalos''tse Stare,Zalosce,Zalos’tse Stare,Zalozce,Zalozhtse,Zalozhtsy,Zalozhtsy-Stare,Załośce,Залізці', 49.7918800, 25.3729700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129179, 'Железный порт', 'Zheleznyj port', 'Zaliznij port,Zhelezny Port,Zheleznyj port,Zheleznyy Port,Zhelzeny Port,Железный порт,Залізний порт', 46.1166700, 32.2833300, 'UA', '2012-12-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129180, 'Zaliznychne', 'Zaliznychne', 'Dvadtsatiletiye Oktyabr'',Dvadtsatiletiye Oktyabr’,Zaliznichne,Zaliznichnoye,Zaliznychne,Залізничне', 47.6523800, 36.1652400, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129181, 'Zaliznychne', 'Zaliznychne', 'Bolgariyka,Bulgarica,Bulgariyka,Zaliznichne,Zaliznichnoye,Zaliznicne,Zaliznychne,Zheleznodorozhnoye,Залізничне', 45.7489000, 28.6146600, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129182, 'Zalesnoye', 'Zalesnoye', '', 48.0310400, 38.8093400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129183, 'Zalishchyky', 'Zalishchyky', 'Zaleshchik,Zaleshchiki,Zaleshchyki,Zaleshiki,Zaleszczyki,Zalishchiki,Zalishchyky,Zalishhiki,Zalisiki,Заліщики', 48.6433100, 25.7379400, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129184, 'Zakupne', 'Zakupne', 'Zakupna,Zakupne,Zakupnoye,Закупне', 49.1194400, 26.3375600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129185, 'Zahvizdya', 'Zahvizdya', 'Zagvizda,Zagvozd''ye,Zagvozd’ye,Zagvuz''dzh,Zagvuz’dzh,Zahvizdya,Загвіздя', 48.9183600, 24.6527500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129186, 'Zagnitkiv', 'Zagnitkiv', 'Zagnitkiv,Zagnitkov,Zahnitkiv,Загнитков,Загнітків', 48.0487800, 28.8923400, 'UA', '2010-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129187, 'Zachepylivka', 'Zachepylivka', 'Zacepilivka,Zachenilovka,Zachepilivka,Zachepilovka,Zachepylivka,Зачепиловка,Зачепилівка', 49.1938500, 35.2394300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129188, 'Zabolotiv', 'Zabolotiv', 'Zablotov,Zablotow,Zablotuv,Zabolotiv,Zabolotov,Zabłotów,Заболотів', 48.4705400, 25.2857100, 'UA', '2013-01-25', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129189, 'Yuzhne', 'Yuzhne', 'Juzhne,Juzhnyj,Южне,Южный', 46.6221100, 31.1013100, 'UA', '2012-12-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129190, 'Yur”yivka', 'Yur"yivka', 'Jur''evka,Jur''ivka,Yur"yivka,Yur''yevka,Yur''yivka,Yur’yevka,Yur”yivka,Юрьевка,Юр’ївка', 48.7374800, 36.0198700, 'UA', '2016-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129191, 'Yurkivka', 'Yurkivka', 'Jurkovka,Urkivka,Yurkivka,Yurkovka,Юрковка,Юрківка', 49.0125600, 31.1012500, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129192, 'Yevpatoriya', 'Yevpatoriya', 'Eupatoria,Eupatorio,Evpatorija,Evpatorya,Eŭpatorio,Jevpatorija,Jewpatorija,Kezlev,Yevpatoriya,ybptwryh,Євпаторія,Евпатория,יבפטוריה', 45.2009100, 33.3665500, 'UA', '2017-02-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129193, 'Yermakovo', 'Yermakovo', 'Ermakove,Ermakovo,Totaj,Yermakovo,Єрмакове,Ермаково,Тота́й', 45.8536400, 34.4864400, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129194, 'Yerky', 'Yerky', 'Ehrki,Erki,Yerki,Yerky,Ерки,Эрки', 48.9906200, 30.9881800, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129195, 'Yenakiyeve', 'Yenakiyeve', 'Enakieve,Enakievo,Ordshonikidse,Ordzhonikidze,Rykovo,Yenakiieve,Yenakiyeve,Yenakiyevo,Єнакієве,Енакиево', 48.2333100, 38.2113700, 'UA', '2016-05-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129196, 'Yemil’chyne', 'Yemil''chyne', 'Emil''chine,Emil''chino,Emil’chino,Yelmicheno,Yemil''chino,Yemil''chyne,Yemil’chino,Yemil’chyne,Ємільчине', 50.8734900, 27.8060400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129197, 'Yemelyanovka', 'Yemelyanovka', 'Dzhajtamgaly,Emel''janovka,Gaj Tamɣaly,Omeljanivka,Yemelyanovka,Ğaj Tamɣaly,Джайтамгалы́,Емельяновка,Омелянівка', 45.5328700, 34.8962400, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129198, 'Yelyzavethradka', 'Yelyzavethradka', 'Ehlizavetgradka,Elizavetgradka,Yelisavetgradka,Yelizavetgradka,Yelyzavethradka,Єлизаветградка,Елизаветградка,Элизаветградка', 48.8038100, 32.4046000, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129199, 'Yelanets’', 'Yelanets''', 'Elanec'',Yelanets'',Yelanets’,Єланець', 47.6968200, 31.8525300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129200, 'Yavoriv', 'Yavoriv', 'Iavoriv,Javoriv,Javoriva,Javorov,Jaworiw,Jaworow,Jaworów,Yavoriv,Yavorov,Yavoruv,iavorovi,ya wo li fu,yafwrwf,ybwryb,Јаворов,Яворов,Яворів,Յավորով,יבוריב,یافوروف,იავოროვი,亞沃里夫', 49.9386400, 23.3825400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129201, 'L’govskoye', 'L''govskoye', 'L''govs''ke,L''govskoe,L''govskoye,L’govskoye,Льговское,Льговське', 45.0980100, 34.9577000, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129202, 'Yasinya', 'Yasinya', 'Jasina,Jasinja,Jasińa,Kereshmeze,Yasina,Yasinya,Ясиня,Ясіня', 48.2793700, 24.3604200, 'UA', '2015-10-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129203, 'Yasynuvata', 'Yasynuvata', 'IAsinovataia,Iasinovataia,Iasinovàtaia,Iasinuvata,Iasînuvata,Jasinoevata,Jasinovataja,Jasinuvata,Jasnuvata,Jassonuvata,Jassynuwata,Jassõnuvata,Jasynuvata,Jasynuwata,Yasinovatara,Yasinovataya,Yasinuvata,Yassynouvata,Yasynuvata,Yasınuvata,ya xi nu wa ta,yasynwfata,ysynwata,Јасинувата,Ясиноватая,Ясинувата,Յասինովատայա,یاسینوفاتا,یسینواتا,იასინოვატაია,亞西努瓦塔', 48.1298000, 37.8594000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129204, 'Yarmolyntsi', 'Yarmolyntsi', 'Armolinci,Jarmolinci,Yarmolintsy,Yarmolyntsi,Ярмолинці', 49.1923600, 26.8372500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129205, 'Yarkoye Pole', 'Yarkoye Pole', 'Jarke Pole,Jarkoe Pole,Yarkoye Pole,Ярке Поле,Яркое Поле', 45.6129300, 34.3183400, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129206, 'Yarkoye', 'Yarkoye', 'Bij-Su-Kovche,Jarke,Jarkoe,Yarkoye,Бий-Су-Ковче́,Ярке,Яркое', 45.6912000, 34.2632300, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129207, 'Yaremche', 'Yaremche', 'Jaremche,Jaremcze,Yaremcha,Yaremche,Яремче', 48.4515700, 24.5543600, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129208, 'Yampil’', 'Yampil''', 'Jampol'',Yampil'',Yampil’,Yampol'',Yampol’,Ямполь', 51.9476500, 33.7875900, 'UA', '2011-02-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129209, 'Yampil’', 'Yampil''', 'Jampil'',Yampil'',Yampil’,Yampol'',Yampol’,Ямпіль', 48.2424000, 28.2819500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129210, 'Yamnytsya', 'Yamnytsya', 'Jamnicja,Yamnitsa,Yamnytsya,Ямниця', 48.9897200, 24.7075000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129211, 'Yalta', 'Yalta', 'Jalta,Yalta,Ялта', 46.9627900, 37.2736500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129212, 'Yalta', 'Yalta', 'Ialta,Jalta,Jalto,Jałta,Yalta,ya er ta,yalta,yaruta,Ялта,يالطا,იალტა,ヤルタ,雅尔塔,얄타', 44.5021800, 34.1662400, 'UA', '2016-05-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129213, 'Yahotyn', 'Yahotyn', 'Jagotin,Yagotin,Yahotyn,Яготин', 50.2797500, 31.7624600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129214, 'Yahil’nytsya', 'Yahil''nytsya', 'Jagel''nica,Jagielnica,Jagil''nicja,Yagel''nitsa,Yagel’nitsa,Yagielnitsa,Yahil''nytsya,Yahil’nytsya,Ягельница,Ягільниця', 48.9424800, 25.7437500, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129215, 'Yabluniv', 'Yabluniv', 'Abluniv,Jablonow,Jabluniv,Jabłonów,Yablonov,Yablonuv,Yabluniv,Яблунів', 48.4041800, 24.9387400, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129216, 'Yablunytsya', 'Yablunytsya', 'Jablonitza,Jablunica,Jablunicja,Yablonitsa,Yablunytsya,Яблуница,Яблуниця', 48.3174200, 24.4844800, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129217, 'Vyshchetarasivka', 'Vyshchetarasivka', 'Novoanastas''evka,Novoanastas''yevka,Novoanastas’yevka,Tarasovka,Velikaya Tarasovka,Verkhne-Tarasovka,Verkhnyaya Tarasovka,Visetarasivka,Vishhetarasivka,Vyshchetarasivka,Vyshchevtarasivka,Vyshetarasovka,Vysshetarasovka,Вищетарасівка,Высшетарасовка,Новоанастасьевка', 47.5685100, 34.8809600, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129218, 'Vysokopillya', 'Vysokopillya', 'Visokopillja,Vysokopillya,Vysokopol''e,Vysokopol''ye,Vysokopol’ye,Високопілля,Высокополье', 47.4918700, 33.5306100, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129219, 'Vysokyy', 'Vysokyy', 'Visokij,Vysokiy,Vysokyy,Високий', 49.8915600, 36.1217500, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129220, 'Vyshkovo', 'Vyshkovo', 'Vishkovo,Viskava,Vyshkove,Vyshkovo,Vyskovo,Vyskovo nad Tisou,Výškovo,Вишково', 48.0491100, 23.4211300, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129221, 'Vyshhorod', 'Vyshhorod', 'Vishgorod,Vyshgorod,Vyshhorod,Вишгород', 50.5847600, 30.4898000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129222, 'Dneprovka', 'Dneprovka', 'Chokrakly-Shejkh-Ehli,Dneprovka,Dniprovka,Shejkh-Ehli,Vyselki,Вы́селки,Днепровка,Дніпровка,Чокраклы́-Шейх-Эли́,Шейх-Эли́', 45.7137300, 34.3625600, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129223, 'Vynohradiv', 'Vynohradiv', 'Gorad Vynagradziu,Horvinogradovo,Nagyszollos,Nagyszolos,Nagyszöllös,Nagyszőllős,Nagyszőlős,Seleusu Mare,Seleușu Mare,Sevljus,Sevlus,Sevluš,Sevlyush,Vel''ky Sevl''yush,Vel’ky Sevl’yush,Vinogradiv,Vinogradov,Vinohradiv,Vinohradiva,Vynohradiv,Vynohradivas,Vınogradiv,Wynohradiw,fynwghradyf,vinogradovi,wei nuo ji la ji fu,wynwhradyf,wynwhrdyb,Виноградив,Виноградов,Виноградів,Горад Вынаградзіў,Վինոգրադով,וינוהרדיב,فينوغراديف,وینوهرادیف,ვინოგრადოვი,維諾吉拉季夫', 48.1413500, 23.0266600, 'UA', '2012-03-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129224, 'Vylok', 'Vylok', 'Tisza-Ujlak,Tiszaujlak,Tiszaújlak,Vilok,Vulok,Vylok,Vülok,Вилок', 48.1091500, 22.8386500, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129225, 'Vylkove', 'Vylkove', 'Valcov,Vilkov,Vilkove,Vilkovo,Vylkov,Vylkove,Vylkovo,Vylkovė,Vâlcov,Vılkove,Wilkowo,Wylkowe,fylkwfy,wei er ke wo,wylkwfh,Вилкове,Вилково,Վիլկովո,فيلكوفي,ویلکوفه,ვილკოვო,維爾科沃', 45.4021400, 29.5859500, 'UA', '2015-12-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129226, 'Vvedenka', 'Vvedenka', 'Vvedenka,Vvedenskoye,Введенка', 49.8237200, 36.5026400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129227, 'Vradiyivka', 'Vradiyivka', 'Bol''shaya Vradiyevka,Bol’shaya Vradiyevka,Bradiyevka,Velikaya Vradiyevka,Vradievka,Vradiivka,Vradiyevka,Vradiyivka,Врадіївка', 47.8619500, 30.5919500, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129228, 'Voznesensk', 'Voznesensk', 'Voznesen''s''k,Voznesens''k,Voznesensk,Voznesenska,Voznesenskas,Voznessensk,Wosnessensk,Woznesensk,Woznesenśk,fwznysynsk,wo zi nie xian si ke,wwznsnsq,wznsnsk,Вознесенск,Вознесенськ,Вознесеньськ,Վոզնեսենսկ,ווזנסנסק,فوزنيسينسك,وزنسنسک,ვოზნესენსკი,沃茲涅先斯克', 47.5649400, 31.3307800, 'UA', '2009-12-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129229, 'Voznesenka', 'Voznesenka', 'Voznesenka,Voznesensk,Вознесенка', 46.8716500, 35.4645800, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129230, 'Voyutychi', 'Voyutychi', 'Vojutichi,Voyutichi,Voyutyche,Voyutychi,Воютичи,Воютичі', 49.5513500, 23.1057900, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129231, 'Voykovo', 'Voykovo', 'Ajbar,Vojkove,Vojkovo,Voykovo,Айба́р,Войкове,Войково', 45.5122200, 33.8748200, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129232, 'Voykovo', 'Voykovo', 'Katerlez,Vojkove,Vojkovo,Voykovo,Войкове,Войково,Катерлез', 45.3832900, 36.4373900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129233, 'Vorzel’', 'Vorzel''', 'Dachi Vorzel'',Dachi Vorzel’,Vorzel'',Vorzel’,Ворзель', 50.5444000, 30.1530500, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129234, 'Vorozhba', 'Vorozhba', 'Vorozhba,Ворожба', 51.1733400, 34.2191700, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129235, 'Voronovytsya', 'Voronovytsya', 'Voronovicja,Voronovitsa,Voronovitsy,Voronovytsya,Вороновиця', 49.1095400, 28.6807800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129236, 'Voronkov', 'Voronkov', 'Voronkov,Воронков', 50.2223500, 30.8996700, 'UA', '2013-02-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129237, 'Vorokhta', 'Vorokhta', 'Vorokhta,Worochta,Ворохта', 48.2845900, 24.5653600, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129238, 'Vorobyovo', 'Vorobyovo', 'Kudajgul,Vorob''jovo,Vorobjove,Vorobyovo,Воробйове,Воробьёво,Кудайгу́л', 45.3289500, 33.2465400, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129239, 'Volovets', 'Volovets', 'Volovec,Воловец', 48.7109000, 23.1851000, 'UA', '2010-03-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129240, 'Voloka', 'Voloka', 'Voloka,Voloki,Волока', 48.1922500, 25.9307400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129241, 'Volodars’k-Volyns’kyy', 'Volodars''k-Volyns''kyy', 'Goroshki,Kutuzov-Volodarsk,Volodars''k-Volins''kij,Volodars''k-Volyns''kyy,Volodarsk,Volodarsk-Volynskiy,Volodars’k-Volyns’kyy,Володарськ-Волинський', 50.5976400, 28.4430000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129242, 'Volodars’ke', 'Volodars''ke', 'Kal''chik,Kal’chik,Voladarskoye,Volodars''ke,Volodarskoe,Volodarskoye,Volodars’ke,Володарское,Володарське', 47.2053300, 37.3213900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129243, 'Volodarka', 'Volodarka', 'Volodarka,Володарка', 49.5248400, 29.9122200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129244, 'Volochys’k', 'Volochys''k', 'Volochis''k,Volochisk,Volochys''k,Volochys’k,Woloczysk,Волочиськ', 49.5374800, 26.2156800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129245, 'Vil’ne', 'Vil''ne', 'Prosjana,Prosyana,Vil''ne,Vil''ny,Vil''nyy,Vil’ne,Vil’ny,Vil’nyy,Vol''noe,Vol''noye,Vol’noye,Вольное,Вільне,Просяна', 47.6364500, 34.8138700, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129246, 'Volnovakha', 'Volnovakha', 'Volnovacha,Volnovaha,Volnovahha,Volnovaja,Volnovakha,Volnovaxa,Volovakha,Wolnowacha,Wołnowacha,fwlnwfakha,volnovakha,vu~orunovu~aha,wo er nuo wa ha,wwlnwwakha,Волноваха,Վոլնովախա,فولنوفاخا,وولنوواخا,ვოლნოვახა,ヴォルノヴァーハ,沃爾諾瓦哈', 47.6010300, 37.4967400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129247, 'Vovchans’k', 'Vovchans''k', 'Volchansk,Vovchans''k,Vovchans’k,Woltschansk,Вовчанськ,Волчанск', 50.2907800, 36.9410800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129248, 'Voinka', 'Voinka', 'Voinka,Воинка,Воїнка', 45.8699000, 33.9913800, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129249, 'Vodyane', 'Vodyane', 'Vodjane,Vodjanoe,Vodyane,Vodyanoye,Водяне,Водяное', 47.4874600, 34.4923500, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129250, 'Vladislavovka', 'Vladislavovka', 'Oj-Kuju,Vladislavivka,Vladislavovka,Владиславовка,Владиславівка,Ой-Кую́', 45.1682800, 35.3765800, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129251, 'Volodymyr-Volyns’kyy', 'Volodymyr-Volyns''kyy', 'Vladimir,Vladimir-Volynsk,Vladimir-Volynskij,Vladimir-Volynskiy,Vlodzimezh,Volodimir-Volins''kij,Volodymir-Volyns''kyy,Volodymir-Volyns’kyy,Volodymyr-Volyns''kyy,Volodymyr-Volyns’kyy,Wladimir-Wolynsk,Wlodzimierz,Wlodzimierz Wolynski,Wlodzimierzec,Włodzimierz,Włodzimierz Wołyński,Włodzimierzec,Владимир-Волынский,Володимир-Волинський', 50.8525300, 24.3236400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129252, 'Volodymyrets’', 'Volodymyrets''', 'Vladimirei,Vladimirets,Vlodzimezhets,Volodimirec'',Volodymerets'',Volodymerets’,Volodymyrets'',Volodymyrets’,Wlodzimierzec,Włodzimierzec,Володимирець', 51.4213000, 26.1446900, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129253, 'Vyzhnytsya', 'Vyzhnytsya', 'Vijnita,Vijniţa,Visnita,Vizhnicja,Vizhnitsa,Viznits,Vișnița,Vyjnytsia,Vyzhnytsya,Wischnitza,Wiznitz,Wyznica,Wyżnica,wwyzsnyz‎,wyz''nyz,Вижниця,וויזשניץ‎,ויז''ניץ', 48.2480100, 25.1945200, 'UA', '2017-02-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129254, 'Vyshneve', 'Vyshneve', 'Vishneve,Vishnevoe,Vishnevoye,Vishnjovoe,Vishnëvoye,Visneve,Visnyovoe,Vychneve,Vyshneve,Vysjneve,Vysneve,Vyšneve,Vyšnevė,Vîșneve,Vışneve,Wyschnewe,Wysznewe,fyshnyfy,vishnevoe,wei shen nie wei,wyshnf,Вишневе,Вишневое,Вишнёвое,Վիշնյովոե,فيشنيفي,ویشنف,ვიშნევოე,維什涅韋', 50.3891300, 30.3705000, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129255, 'Vyshneve', 'Vyshneve', 'Erastovka,Vishneve,Vishnevoe,Vishnevoye,Vishnyevoye,Vishnyëvoye,Vishnëvoye,Vyshneve,Вишнëвое,Вишневе', 48.4361100, 33.9155600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129256, 'Vishennoye', 'Vishennoye', 'Mushash,Vishenne,Vishennoe,Vishennoye,Вишенне,Вишенное,Муша́ш', 45.1450900, 34.5969100, 'UA', '2016-05-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129257, 'Vishnyovka', 'Vishnyovka', 'Tarkhan,Vishnivka,Vishnjovka,Vishnyovka,Вишнёвка,Вишнівка,Тарха́н', 45.9596600, 33.9528900, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129258, 'Vynohradove', 'Vynohradove', 'Chalbasy,Vinogradnoye,Vinogradove,Vinogradovo,Vynohradove,Виноградове,Виноградово', 46.3695700, 32.9398000, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129259, 'Vinogradovo', 'Vinogradovo', 'Boz-Oglu-Montanaj,Vinogradove,Vinogradovo,Боз-Оглу́-Монтана́й,Виноградове,Виноградово', 45.3926400, 33.6466800, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129260, 'Vynohradivka', 'Vynohradivka', 'Curci,Curciul,Kurchny,Kurgchi,Vinogradivka,Vinogradovka,Vynohradivka,Виноградовка,Виноградівка', 45.6811900, 28.5713800, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129261, 'Vinogradnoye', 'Vinogradnoye', 'Chokul russkij,Vinogradne,Vinogradnoe,Vinogradnoye,Виноградне,Виноградное,Чоку́л ру́сский', 45.2933200, 35.8445100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129262, 'Vinogradnoye', 'Vinogradnoye', 'Vinogradne,Vinogradnoe,Vinogradnoye,Виноградне,Виноградное', 44.4814900, 34.1297300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129263, 'Vinnytsya', 'Vinnytsya', 'VIN,Vinnica,Vinnicja,Vinnitsa,Vinnytsia,Vinnytsya,Winniza,Винница,Вінниця', 49.2327800, 28.4809700, 'UA', '2016-09-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129264, 'Vin’kivtsi', 'Vin''kivtsi', 'Vin''kivci,Vin''kivtsi,Vin''kovtsy,Vin’kivtsi,Vin’kovtsy,Von''kovtsy,Von’kovtsy,Віньківці', 49.0346200, 27.2361700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129265, 'Vil’nyans’k', 'Vil''nyans''k', 'Chervonoarmeyskoye,Chervonoarmijs''ke,Krasnoarmeyskoye,Krasnoarmijs''ke,Sofiivka,Sofiyevka,Vil''njans''k,Vil''nyans''k,Vil’nyans’k,Vol''nyansk,Vol’nyansk,Вільнянськ,Красноармійське,Софіївка,Червоноармійське', 47.9438100, 35.4353900, 'UA', '2017-01-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129266, 'Vilino', 'Vilino', 'Burljuk,Viline,Vilino,Бурлю́к,Віліне', 44.8456000, 33.6716100, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129267, 'Veselynove', 'Veselynove', 'Veselinove,Veselinovo,Veselynove,Веселинове', 47.3566600, 31.2348800, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129268, 'Vesele', 'Vesele', 'Vesele,Veseloye,Vesëloye,Веселе', 47.0147900, 34.9150400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129269, 'Veseloye', 'Veseloye', 'Koutlak,Kutlak,Vesele,Veseloye,Vesjoloe,Веселе,Весёлое,Кутлак', 44.8580700, 34.8795200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129270, 'Veselovka', 'Veselovka', 'Otary,Veselivka,Veselovka,Vesjolovka,Веселiвка,Весёловка,Ота́ры', 45.3773300, 33.2138500, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129271, 'Verkhovyna', 'Verkhovyna', 'Verkhovina,Verkhovyna,Zabie,Zhab''ye,Zhabeye,Zhab’ye,Żabie,Верховина', 48.1557100, 24.7911200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129272, 'Verkhorechye', 'Verkhorechye', 'Bija-Sala,Verkhorech''e,Verkhorechye,Verkhorichchja,Бия́-Сала́,Верхоречье,Верхоріччя', 44.6973800, 33.9869600, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129273, 'Verkhnya Syrovatka', 'Verkhnya Syrovatka', 'Verkh.Syrovatka,Verkhnja Sirovatka,Verkhnya Syrovatka,Verkhnyaya Syrovatka,Верх.Сыроватка,Верхня Сироватка', 50.8290200, 34.9586100, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129274, 'Verkhnya Rozhanka', 'Verkhnya Rozhanka', 'Rozhanka Vizhna,Verkhnja Rozhanka,Verkhnjaja Rozhanka,Verkhnya Rozhanka,Verkhnyaya Rozhanka,Верхня Рожанка,Верхняя Рожанка', 48.7805000, 23.5154500, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129275, 'Verkhnyaya Belka', 'Verkhnyaya Belka', 'Verkhnja Bilka,Verkhnjaja Belka,Verkhnya Bilka,Verkhnyaya Belka,Verkhnyaya Bilka,Верхня Білка,Верхняя Белка', 49.8157500, 24.3032800, 'UA', '2013-02-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129276, 'Verkhnyachka', 'Verkhnyachka', 'Verkhnjachka,Verkhnyachka,Verkhnyochka,Верхнячка', 48.8284900, 30.0395700, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129277, 'Verkhniy Yasenov', 'Verkhniy Yasenov', 'Jasienow,Verkhnij Jasenov,Yasenuv Gurny,Верхний Ясенов', 48.1615600, 24.9453200, 'UA', '2010-07-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129278, 'Verkhniy Rohachyk', 'Verkhniy Rohachyk', 'Verhnij Rogacik,Verkhnij Rogachik,Verkhniy Rogachik,Verkhniy Rohachyk,Верхній Рогачик', 47.2505300, 34.3379700, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129279, 'Verkhnye Syn’ovydne', 'Verkhnye Syn''ovydne', 'Sinovudzko,Synovudzko,Synovudzko Vyzhne,Synowodzko Wyzne,Synowódzko Wyżne,Verkhne Sin''ovidne,Verkhnee Sinevidnoe,Verkhneye Sinevidnoye,Verkhneye Sinevodnoye,Verkhnye Syn''ovydne,Verkhnye Syn''ovyone,Verkhnye Syn’ovydne,Verkhnye Syn’ovyone,Верхнее Синевидное,Верхнє Синьовидне', 49.1030700, 23.5909900, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129280, 'Verkhnesadovoye', 'Verkhnesadovoye', 'Duvankoj,Verkhn''osadove,Verkhnesadovoe,Verkhnesadovoye,Верхнесадовое,Верхньосадове,Дуванко́й', 44.6893200, 33.7020700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129281, 'Verkhn’odniprovs’k', 'Verkhn''odniprovs''k', 'Verkhn''odniprovs''k,Verkhne-Dnyeprovsk,Verkhnedneprovsk,Verkhn’odniprovs’k,Верхнеднепровск', 48.6524200, 34.3345700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129282, 'Veresayevo', 'Veresayevo', 'Komzetovka,Kurulu-Kenege,Veresaeve,Veresaevo,Veresayevo,Вересаево,Вересаєве,Комзе́товка,Курулу́-Кенеге́', 45.3055100, 33.5000400, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129283, 'Verenchanka', 'Verenchanka', 'Varentsyantsa,Verenchanka,Vranceni,Vryncheny,Vrânceni,Веренчанка', 48.5465300, 25.7453300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129284, 'Verblyany', 'Verblyany', 'Verbljani,Verbljany,Verblyany,Verbyany,Vezhbyany,Wierzbiany,Вербляни,Вербляны', 50.0474700, 23.4218900, 'UA', '2013-02-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129285, 'Verbivka', 'Verbivka', 'Verbivka,Verbovka,Вербівка', 49.4166700, 35.5333300, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129286, 'Vendychany', 'Vendychany', 'Bendichany,Vendichani,Vendichany,Vendychany,Вендичани', 48.6117600, 27.7932400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129287, 'Velykoploske', 'Velykoploske', 'Bol''shoye Ploskoye,Bol’shoye Ploskoye,Ploskoye,Velikoploske,Velikoploskoye,Velykoploske,Великоплоске', 47.0125400, 29.6717100, 'UA', '2012-02-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129288, 'Velyka Mykhaylivka', 'Velyka Mykhaylivka', 'Grosulovo,Prosulovo,Velika Mihajlivka,Velika Mikhajlivka,Velikaya Mikhalovka,Velikaya Mikhaylovka,Velyka Mykhaylivka,Велика Михайлівка', 47.0797100, 29.8575300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129289, 'Velykyy Klyuchiv', 'Velykyy Klyuchiv', 'Klyuchev,Klyuchev Vel''kiy,Klyuchev Vel’kiy,Klyuchov,Klyuchuv Vel''ki,Klyuchuv Vel’ki,Klyuchëv,Velikij Kljuchiv,Velikij Kluciv,Velikiy Klyuchev,Velykyy Klyuchiv,Великий Ключів', 48.4709200, 24.9467700, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129290, 'Velyki Sorochyntsi', 'Velyki Sorochyntsi', 'Bol''shie Sorochincy,Bol''shiye Sorochintsy,Bol’shiye Sorochintsy,Veliki Sorochinci,Velikiye Sorochintsy,Velyki Sorochyntsi,Verkhniye Sorochintsy,Большие Сорочинцы,Великі Сорочинці', 50.0231400, 33.9414400, 'UA', '2014-03-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129291, 'Velyki Kopani', 'Velyki Kopani', 'Bol''shiye Kopani,Bol''shoye Kopani,Bol’shiye Kopani,Bol’shoye Kopani,Veliki Kopani,Velikie Kopani,Velikiye Kopani,Velyki Kopani,Velyki Kopany,Великие Копани,Великі Копані', 46.4868400, 32.9749800, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129292, 'Velikiye Borki', 'Velikiye Borki', 'Bol''shiye Borki,Bol’shiye Borki,Borki Vel''ke,Borki Velikiye,Borki Vel’ke,Borki Wielkie,Velikiye Borki', 49.5236300, 25.7575300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129293, 'Velykyy Burluk', 'Velykyy Burluk', 'Bol''shoy Burluk,Bolshoi Burlak,Bol’shoy Burluk,Velikij Burluk,Velikij Vurluk,Velikiy Burlok,Velikiy Burluk,Velykyy Burluk,Великий Бурлук,Великий Вурлук', 50.0617000, 37.3837300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129294, 'Velykyi Bereznyi', 'Velykyi Bereznyi', 'Nagyberezna,Velikij Bereznij,Velikij Bereznyj,Velikyj Bereznyj,Velke Berezne,Velky Berezny,Velký Berezný,Veľké Berezné,Veľký Berezný,Великий Березний,Великий Березный,Великый Березный', 48.8883100, 22.4605200, 'UA', '2012-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129295, 'Velyka Pysarivka', 'Velyka Pysarivka', 'Bol''shaya Pisarevka,Bol’shaya Pisarevka,Velika Pisarivka,Velikaya Pisarevka,Velyka Pysarivka,Велика Писарівка', 50.4243000, 35.4798900, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129296, 'Velyka Novosilka', 'Velyka Novosilka', 'Bol''shay Yanisal'',Bol''shaya Novoselka,Bol''shaya Yanisol'',Bol''shoy Yanisol'',Bol’shay Yanisal’,Bol’shaya Novosëlka,Bol’shaya Yanisol’,Bol’shoy Yanisol’,Janisal,Velika Novosilka,Velikaya Novoselka,Velikaya Novosëlka,Velyka Novosilka,Велика Новосілка', 47.8453100, 36.8353400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129297, 'Velyka Lepetykha', 'Velyka Lepetykha', 'Bol''shaya Lepatikha,Bol''shaya Lepetikha,Bolschaja Lepeticha,Bol’shaya Lepatikha,Bol’shaya Lepetikha,Velika Lepetikha,Velikaya Lepetikha,Velyka Lepetykha,Велика Лепетиха', 47.1757200, 33.9436200, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129298, 'Velyka Dymerka', 'Velyka Dymerka', 'Belaya Dymerka,Bol''shaya Dymerka,Bolschaja Bymerka,Bol’shaya Dymerka,Dimirka,Dymerka,Velika Dimerka,Velikaja Dymerka,Velikaya Dymerka,Velikaya Dymërka,Velyka Dymerka,Велика Димерка,Великая Дымерка', 50.5933300, 30.9031300, 'UA', '2017-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129299, 'Velyka Bilozerka', 'Velyka Bilozerka', 'Bol''shaya Belozerka,Bolschaja Beloserka,Bol’shaya Belozerka,Velika Bilozerka,Velikaya Belozerka,Velikaya Belozërka,Velyka Bilozerka,Велика Білозерка', 47.2775600, 34.7061600, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129300, 'Velyka Bahachka', 'Velyka Bahachka', 'Bogachka,Velika Bagachka,Velikaya Bagachka,Velikaya Bogachka,Velyka Bahachka,Велика Багачка', 49.7911600, 33.7225800, 'UA', '2014-03-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129301, 'Velyka Oleksandrivka', 'Velyka Oleksandrivka', 'Bol''shaya Aleksandrovka,Bolschaja Aleksandrowka,Bol’shaya Aleksandrovka,Velika Oleksandrivka,Velikaya Aleksandrovka,Velyka Oleksandrivka,Велика Олександрівка', 47.3196900, 33.3037300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129302, 'Vatutine', 'Vatutine', 'Vatutine,Vatutino,Ватутино,Ватутіне', 49.0150200, 31.0621100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129303, 'Vasyshcheve', 'Vasyshcheve', 'Vasishchevo,Vasishheve,Vasishhevo,Vasyshcheve,Васищеве,Васищево', 49.8285200, 36.3269100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129304, 'Vasilyevka', 'Vasilyevka', 'Vasil''evka,Vasilivka,Vasilyevka,Васильевка,Василівка', 45.1393800, 34.7229100, 'UA', '2016-05-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129305, 'Vasyl’kivka', 'Vasyl''kivka', 'Vasil''kivka,Vasil''kovka,Vasil’kovka,Vasyl''kivka,Vasyl’kivka,Wassilkowka,Васильковка,Васильківка', 48.2069800, 36.0236500, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129306, 'Vasylkiv', 'Vasylkiv', 'Vasil''kiv,Vasil''kov,Vasilkiv,Vasilkiva,Vasilkov,Vasiļkiva,Vassylkiv,Vasyl''kiv,Vasylkiv,Vasylkivas,Vasîlkiv,Vasılkiv,Wassylkiw,Wasylkow,Wasylków,fasylkyf,vu~asu~irikiu,wa xi li ji fu,wasylkyf,Васильков,Васильків,Васиљкив,Վասիլկով,فاسيلكيف,واسیلکیف,ვასილკოვი,ヴァスィリキーウ,瓦西里基夫', 50.1869300, 30.3134600, 'UA', '2014-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129307, 'Vashkivtsi', 'Vashkivtsi', 'Vascauti,Vashkivtsi,Vashkouts,Vashkoutsi,Vashkovtsy,Vaskivci,Văscăuţi,Вашківці', 48.3849100, 25.5102300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129308, 'Vary', 'Vary', 'Mezovari,Mezővári,Vari,Vary,Vári,Вари', 48.1220700, 22.7128100, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129309, 'Varva', 'Varva', 'Varva,Варва', 50.4950300, 32.7196800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129310, 'Vapnyarka', 'Vapnyarka', 'Vapnjarka,Vapnyarka,Wapnjarka,Вапнярка', 48.5347900, 28.7435800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129311, 'Valky', 'Valky', 'Valki,Valky,Валки', 49.8359700, 35.6122300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129312, 'Batiovo', 'Batiovo', 'Bat''jovo,Bat''ovo,Batiowo,Batjovo,Batjowo,Batoevo,Batovo,Batyu,Batövo,Baťovo,Bátyú,Батьово,Батьёво', 48.3616600, 22.3997000, 'UA', '2012-12-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129313, 'Uzyn', 'Uzyn', 'Uzin,Uzyn,Узин', 49.8261900, 30.4148700, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129314, 'Uzhhorod', 'Uzhhorod', 'Gorad Uzhgarad,Oezjhorod,Oujhorod,UDJ,Ujgorod,Ujhorod,Ujhorodo,Ujqorod,Ungvar,Ungvár,Uschhorod,Uzgorod,Uzhgorod,Uzhhorod,Uzhorod,Uzhorodas,Uzhorodum,Uzjhorod,Uĵhorodo,Użhorod,Užgorod,Užhorod,Užhorodas,awzhhwrwd,ujuholodeu,ujuhorodo,uzhgorodi,wu ri huo luo de,Úzhgorod,ʼwngwwʼr,Горад Ужгарад,Ужгород,אוז''הורוד,אונגוואר,اوژهورود,უჟგოროდი,ウージュホロド,乌日霍罗德,우주호로드', 48.6166700, 22.3000000, 'UA', '2013-01-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129315, 'Uyutnoye', 'Uyutnoye', 'Otar-Mojnak,Ujutne,Ujutnoe,Uyutnoye,Ота́р-Мойна́к,Уютне,Уютное', 45.1976900, 33.2979600, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129316, 'Uvarovo', 'Uvarovo', 'Brannoe Pole,Kijat,Uvarove,Uvarovo,Бра́нное По́ле,Кия́т,Уварове,Уварово', 45.2626000, 35.6650600, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129317, 'Utkivka', 'Utkivka', 'Utkivka,Utkovka,Утківка', 49.7858300, 36.0752800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129318, 'Ustynivka', 'Ustynivka', 'Ustinivka,Ustinovka,Ustipovka,Ustynivka,Устинівка', 47.9550700, 32.5367400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129319, 'Uspenka', 'Uspenka', 'Uspenka,Uspenskoye,Uzbenka,Успенка', 48.3907700, 39.1628400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129320, 'Usatove', 'Usatove', 'Usatove,Usatovo,Усатове', 46.5329600, 30.6596000, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129321, 'Urozhaynoye', 'Urozhaynoye', 'Ferngejm,Urozhajne,Urozhajnoe,Urozhaynoye,Урожайне,Урожайное,Фернгейм', 45.3362500, 35.0686500, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129322, 'Uralo-Kavkaz', 'Uralo-Kavkaz', 'Uralo-Kavkaz,Uralo-Kavkazskiy,Урало-Кавказ', 48.3211000, 39.8030200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129323, 'Nyzhni Petrivtsi', 'Nyzhni Petrivtsi', 'Nizhniye Petrovtsy,Nizni Petrivci,Nyzhni Petrivtsi,Unter-Petrouts,Нижні Петрівці', 48.0284700, 25.7232700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129324, 'Uman’', 'Uman''', 'Human,Humań,Uman,Uman'',Uman’,ʼwmn,ʼwmʼn,Умань,אומאן,אומן', 48.7483800, 30.2218400, 'UA', '2016-12-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129325, 'Ul’yanovka', 'Ul''yanovka', 'Ul''janovka,Ul''yanovka,Ul’yanovka,Ульяновка', 48.3310500, 30.2270200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129326, 'Ulychne', 'Ulychne', 'Gassendorf,Ulichne,Ulichno,Ulichnoye,Uliczno,Ulychne,Уличне,Улично', 49.2338500, 23.6511100, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129327, 'Ulanov', 'Ulanov', 'Ulaniv,Ulanov,Уланов,Уланів', 49.6951200, 28.1329800, 'UA', '2010-08-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129328, 'Ukromnoye', 'Ukromnoye', 'Novo-Sarabuz,Ukromne,Ukromnoe,Ukromnoye,Но́во-Сара́буз,Укромне,Укромное', 45.0427200, 34.0031200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129329, 'Ukrainka', 'Ukrainka', 'Ukrainka,Ukrayinka,Украинка,Українка', 50.1431700, 30.7461200, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129330, 'Ukrainka', 'Ukrainka', 'Kurcy,Ukrainka,Курцы́,Украинка,Українка', 44.8873000, 34.1397300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129331, 'Uhryniv', 'Uhryniv', 'Dolishniy Uhryniv,Gorishnyy Ugrinov,Ugriniv,Ugrinov,Ugryniv,Ugrynov-Gurny,Uhryniv,Угринів', 48.9552000, 24.6929200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129332, 'Uhniv', 'Uhniv', 'Ugnev,Ugniv,Ugnov,Ugnuv,Uhniv,Uhnow,Uhnów,Угнев,Угнів', 50.3681100, 23.7489500, 'UA', '2012-12-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129333, 'Uglovoye', 'Uglovoye', 'Adzhi-Bulat,Uglove,Uglovoe,Uglovoye,Аджи́-Була́т,Углове,Угловое', 44.8214600, 33.6045200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129334, 'Vuhlehirs’k', 'Vuhlehirs''k', 'Chazepetowka,Chazepetrovka,Khatsapetovka,Khatsepetovka,Uglegorsk,Vuglegirs''k,Vuhlehirs''k,Vuhlehirs’k,Вуглегірськ,Углегорск', 48.3147400, 38.2742300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129335, 'Tyvriv', 'Tyvriv', 'Tivriv,Tyvriv,Tyvrov,Тиврів', 49.0140400, 28.5084600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129336, 'Tysmenytsya', 'Tysmenytsya', 'Tismenicja,Tysmenitsa,Tysmenytsya,Tysmienica,Tyśmienica,Тисмениця', 48.9021900, 24.8448200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129337, 'Tysmenychany', 'Tysmenychany', 'Tismenichani,Tysmenichany,Tysmenychany,Тисменичани', 48.7716800, 24.6662600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129338, 'Tynne', 'Tynne', 'Tinne,Tynne,Tynnoye,Тинне', 50.6014500, 26.1848600, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129339, 'Tyachiv', 'Tyachiv', 'Tachevo,Taciv,Tacovo,Tačovo,Tjachiv,Tyachev,Tyachevo,Tyachiv,Тячів', 48.0117900, 23.5706100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129340, 'Turka', 'Turka', 'Tourka,Turka,Turko,tu er ka,twrka,twrqh,Турка,Տուրկա,טורקה,تورکا,ტურკა,圖爾卡', 49.1541100, 23.0296700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129341, 'Turiys’k', 'Turiys''k', 'Turijs''k,Turisk,Turiys''k,Turiysk,Turiys’k,Turzysk,Tuzhisk,Турійськ', 51.0864400, 24.5229400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129342, 'Turgenevka', 'Turgenevka', 'Teberti,Turgenevka,Теберти́,Тургеневка,Тургенєвка', 44.6974700, 33.8300700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129343, 'Turbiv', 'Turbiv', 'Turbiv,Turbov,Турбів', 49.3478800, 28.7211700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129344, 'Tul’chyn', 'Tul''chyn', 'Tu''chin,Tul''chin,Tul''chyn,Tultschin,Tul’chyn,Tu’chin,Тульчин', 48.6744800, 28.8464100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129345, 'Tukhlya', 'Tukhlya', 'Tuchla,Tukhlja,Tukhlya,Тухля', 48.9121800, 23.4730300, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129346, 'Tsyurupyns’k', 'Tsyurupyns''k', 'Aleshki,Cjurupins''k,Cjurupinsk,Tsyurupinsk,Tsyurupyns''k,Tsyurupyns’k,Цюрупинск,Цюрупинськ', 46.6184200, 32.7189000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129347, 'Tsybulevka', 'Tsybulevka', 'Cibulevka,Tsybulevka,Цибулевка', 48.3871900, 29.1028800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129348, 'Tsybli', 'Tsybli', 'Cibli,Tsybli,Циблі', 49.9948400, 31.5628100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129349, 'Tsvetochnoye', 'Tsvetochnoye', 'Cvetochnoe,Cvitochne,Novaja Burul''cha,Tsvetochnoye,Но́вая Бурульча́,Цветочное,Цвіточне', 45.0865500, 34.3852100, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129350, 'Tsvetkovo', 'Tsvetkovo', 'Cvetkovo,Cvitkove,Sloboda,Tsvetkovo,Tsvitkove,Zwitkowe,Цветково,Цвіткове', 49.1523100, 31.5373900, 'UA', '2017-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129351, 'Tsibulev', 'Tsibulev', 'Cibuliv,Tsibulev,Tsybulev,Tsybulevo,Tsybuliev,Tsybuliv,Цибулів', 49.0790700, 29.8472700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129352, 'Tselinnoye', 'Tselinnoye', 'Celinnoe,Cilinne,Kyrk-Chipche,Tselinnoye,Кырк-Чипче́,Целинное,Цілинне', 45.9063300, 34.1806300, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129353, 'Tsarychanka', 'Tsarychanka', 'Carichanka,Carychanka,Tsarichanka,Tsarychanka,Zaritschanka,Царичанка,Царычанка', 48.9369700, 34.4786000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129354, 'Truskavets’', 'Truskavets''', 'Gorad Truskavec,Trouskavets,Truskavec,Truskavec'',Truskaveca,Truskavet,Truskavets'',Truskavets’,Truskaveț,Truskawec,Truskawez,Truskawiec,Truszkavec,te lu si ka wei ci,teuluseukabecheu,trwskawyk,Горад Трускавец,Трускавец,Трускавець,Տրուսկավեց,טריסקעוויץ,تروسکاویک,ტრუსკავეცი,特魯斯卡韋茨,트루스카베츠', 49.2783700, 23.5061800, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129355, 'Trostyanets’', 'Trostyanets''', 'Trostjanec,Trostjanec'',Trostjanez,Trostyanets'',Trostyanets’,Тростянец,Тростянець', 50.4847800, 34.9656700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129356, 'Trostyanets’', 'Trostyanets''', 'Trostjanec'',Trostjanez,Trostyanets'',Trostyanets’,Тростянець', 48.5096100, 29.2348200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129357, 'Troyits’ke', 'Troyits''ke', 'Troic''ke,Troickoe,Troitsk,Troitskoye,Troyits''ke,Troyits’ke,Троицкое,Троїцьке', 49.9145000, 38.2927700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129358, 'Trypillia', 'Trypillia', 'Tripillja,Tripilya,Tripol''e,Tripolye,Trypillia,Триполье,Трипілля', 50.1180200, 30.7814100, 'UA', '2014-01-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129359, 'Tr’okhizbenka', 'Tr''okhizbenka', 'Tr''okhizbenka,Trekhizbenka,Trëkhizbenka,Tr’okhizbenka,Трехизбенка,Трьохізбенка', 48.7575100, 38.9633300, 'UA', '2015-04-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129360, 'Trebukhiv', 'Trebukhiv', 'Trebuhiv,Trebukhiv,Trebukhov,Trebukhovo,Требухов,Требухів', 50.4843200, 30.9030400, 'UA', '2013-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129361, 'Toshkivka', 'Toshkivka', 'Rudnik Toshkovka,Toshkivka,Toshkovka,Toshkovskiy,Toshkovskiy Rudnik,Toskivka,Ustinovka,Тошковка,Тошківка', 48.7791400, 38.5790300, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129362, 'Torkanivka', 'Torkanivka', 'Tarkanovka,Torkanovka,Торкановка', 48.3246200, 29.1474600, 'UA', '2013-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129363, 'Torez', 'Torez', 'Chistyakovo,Thorez,Topez,Tores,Torez,Toreza,Torezas,Tschistjakowa,Tschistjakowo,duo lie shi,twrz,Топез,Торез,Տորեզ,تورز,ტორეზი,多列士', 48.0387600, 38.5968500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129364, 'Topory', 'Topory', 'Topori,Topory,Топори,Топоры', 49.6518600, 29.3174100, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129365, 'Tomashpil’', 'Tomashpil''', 'Tomashpil'',Tomashpil’,Tomashpol'',Tomashpol’,Томашпіль', 48.5425600, 28.5168400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129366, 'Tomakivka', 'Tomakivka', 'Tomakivka,Tomakovka,Tomakowka,Томаковка,Томаківка', 47.8156900, 34.7413700, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129367, 'Tovste', 'Tovste', 'Tluste,Tluste Miasto,Tluste Myasto,Tolstoye,Tovste,Товсте', 48.8466300, 25.7262100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129368, 'Tokmak', 'Tokmak', 'Bol''shoy Tokmak,Bol’shoy Tokmak,Tokmak,Tokmak i Ukraina,Tokmaka,Tomak,tuo ke ma ke,twkmak  awkrayn,twqmq,Токмак,Տոկմակ,טוקמק,توکماک، اوکراین,ტოკმაკი,托克馬克', 47.2552200, 35.7123800, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129369, 'Tokarevo', 'Tokarevo', 'Dzhamchi,Tokareve,Tokarevo,Джамчи́,Токарево,Токарєве', 45.2836700, 35.1524400, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129370, 'Tlumach', 'Tlumach', 'Tlumach,Tlumacz,Tłumacz,Тлумач', 48.8640300, 25.0032500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129371, 'Tyshkivka', 'Tyshkivka', 'Tishkovka,Tiskivka,Tyshkivka,Тишковка,Тишківка', 48.4966500, 30.9422900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129372, 'Tymoshivka', 'Tymoshivka', 'Timoshevka,Timoshivka,Timoshovka,Timoshëvka,Timosivka,Tymoshivka,Тимошівка', 47.1841000, 35.1162500, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129373, 'Tetiyiv', 'Tetiyiv', 'Tetiev,Tetiiv,Tetiyev,Tetiyiv,Тетиев,Тетіїв', 49.3767000, 29.6647400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129374, 'Terpinnya', 'Terpinnya', 'Terpen''ye,Terpeniye,Terpen’ye,Terpinna,Terpinnja,Terpinnya,Терпіння', 46.9694200, 35.4210000, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129375, 'Terny', 'Terny', 'Terni,Terny,Tërny,Терни', 50.9891600, 33.9707000, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129376, 'Ternovka', 'Ternovka', 'Starye Shuli,Ternivka,Ternovka,Ста́рые Шули́,Терновка,Тернівка', 44.5792200, 33.7510500, 'UA', '2016-05-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129377, 'Ternuvate', 'Ternuvate', 'Ternovatoe,Ternovatoye,Ternuvate,Терноватое,Тернувате', 47.8304900, 36.1276100, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129378, 'Ternopil’', 'Ternopil''', 'TNL,Tarnopol,Tarnopol'',Tarnopol’,Ternopil,Ternopil'',Ternopilo,Ternopil’,Ternopol'',Ternopol’,trnwpwl,Тернополь,Тернопіль,טרנופול', 49.5558900, 25.6055600, 'UA', '2017-01-25', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129379, 'Terebovlya', 'Terebovlya', 'Terebovlja,Terebovlya,Trebozlya,Trembovlya,Trembowla,Теребовля', 49.3018700, 25.7099700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129380, 'Teplovka', 'Teplovka', 'Kontugan,Teplivka,Teplovka,Контуга́н,Тепловка,Теплівка', 45.0323900, 33.6958800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129381, 'Teplyk', 'Teplyk', 'Teplik,Teplyk,Теплик', 48.6656600, 29.7450400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129382, 'Teofipol’', 'Teofipol''', 'Teofipol'',Teofipol’,Teotipol'',Teotipol’,Теофіполь', 49.8381800, 26.4143300, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129383, 'Maslovo', 'Maslovo', 'Maslove,Maslovo,Tensu,Маслове,Маслово,Тенсу́', 45.7919700, 34.3629800, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129384, 'Tenistoye', 'Tenistoye', 'Kalymtaj,Tenistoe,Tenistoye,Tiniste,Калымта́й,Тенистое,Тінисте', 44.7430300, 33.6681200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129385, 'Tel’manove', 'Tel''manove', 'Ostgeym,Tel''manove,Tel''manovo,Tel’manove,Tel’manovo,Тельманове,Тельманово', 47.4099400, 38.0247600, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129386, 'Tatarbunary', 'Tatarbunary', 'Tatar Bunar,Tatarbounary,Tatarbunar,Tatarbunari,Tatarbunary,Tatarbunarı,Tatarpinari,Tatarpınarı,Tetereshti,da da bu na lei,tatarbwnary,Татарбунар,Татарбунари,Татарбунары,Տատարբունարի,تاتاربوناری,ტატარბუნარი,韃靼布納雷', 45.8373100, 29.6142400, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129387, 'Klepinino', 'Klepinino', 'Klepinine,Klepinino,Tashly-Kipchak,Клепинино,Клепиніне,Ташлы́-Кипча́к', 45.5280000, 34.1831500, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129388, 'Tarutyne', 'Tarutyne', 'Anchokrak,Tarutine,Tarutino,Tarutinskaya,Tarutyne,Тарутине', 46.1863600, 29.1520300, 'UA', '2016-03-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129389, 'Tarashcha', 'Tarashcha', 'Tarashcha,Tarashha,Тараща', 49.5583200, 30.4925900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129390, 'Tarakaniv', 'Tarakaniv', 'Tarakaniv,Tarakanov,Tarakanuv,Тараканов,Тараканів', 50.3796100, 25.7084300, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129391, 'Tankovoye', 'Tankovoye', 'Bijuk-Sjuren'',Tankove,Tankovoe,Tankovoye,Бию́к-Сюре́нь,Танкове,Танковое', 44.6582900, 33.8092900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129392, 'Sary-Bash', 'Sary-Bash', 'Sari-Bash,Sary Bas,Sary Baš,Sary-Bash,Tanino,Сари-Баш,Сары-Баш,Та́нино', 45.5714200, 33.7872800, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129393, 'Tal’ne', 'Tal''ne', 'Tal''ne,Tal''noe,Tal''noye,Tal’ne,Tal’noye,Тальне,Тальное', 48.8887700, 30.6948200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129394, 'Talalayivka', 'Talalayivka', 'Talalaevka,Talalaivka,Talalayevka,Talalayivka,Талалаевка,Талалаївка', 50.9578300, 31.9208500, 'UA', '2012-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129395, 'Talalayivka', 'Talalayivka', 'Talalaivka,Talalayevka,Talalayivka,Талалаївка', 50.8391300, 33.1437400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129396, 'Tabachnoye', 'Tabachnoye', 'Adzhi-Akhmat,Tabachne,Tabachnoe,Tabachnoye,Аджи́-Ахма́т,Табачне,Табачное', 45.6125700, 34.6149700, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129397, 'Tabachnoye', 'Tabachnoye', 'Tabachne,Tabachnoe,Tabachnoye,Табачне,Табачное', 44.9017500, 33.6763800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129398, 'Syevyerodonets’k', 'Syevyerodonets''k', 'Severodonec''k,Severodoneck,Severodonetsk,Sievierodonetsk,Syeverodonets''k,Syeverodonets’k,Syevyerodonets''k,Syevyerodonets’k,Северодонецк,Сєвєродонецьк', 48.9483200, 38.4916600, 'UA', '2016-05-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129399, 'Svyatogorsk', 'Svyatogorsk', 'Svjatogorsk,Svyatogorsk,Святогорск', 49.0333300, 37.5666700, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129400, 'Svityaz’', 'Svityaz''', 'Svitjaz'',Svityaz'',Svityaz’,Свитязь,Світязь', 51.4821100, 23.8590400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129401, 'Svetloye', 'Svetloye', 'Jancevo,Svetloe,Svetloye,Svitle,Tamak-Kirgiz,Светлое,Світле,Тама́к-Кирги́з,Я́нцево', 45.6332000, 34.6626400, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129402, 'Svitlovods’k', 'Svitlovods''k', 'Khrushchev,Khrushchëv,Kremges,Krylov,Novogeorgievsk,Novogeorgiyevsk,Svetlovodsk,Svitlovods''k,Svitlovods’k,Светловодск,Світловодськ', 49.0489400, 33.2410600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129403, 'Svetlodarsk', 'Svetlodarsk', 'Svetlodarsk,Светлодарск', 48.4337400, 38.2233100, 'UA', '2012-11-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129404, 'Sverdlovs’k', 'Sverdlovs''k', 'Imeni Sverdlova,Selo Imeni Sverdlova,Selo imeni Sverdlova,Sverdlovs''k,Sverdlovsk,Sverdlovs’k,Свердловск,Свердловськ,Село имени Свердлова', 48.0896400, 39.6524300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129405, 'Svatove', 'Svatove', 'Svatove,Svatovo,Swatowe,Swatowo,aswatwfh,sbtwbh,si wa tuo wei,Сватове,Сватово,Սվատովո,סבטובה,اسواتوفه,სვატოვო,斯瓦托韋', 49.4102900, 38.1503500, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129406, 'Svarychiv', 'Svarychiv', 'Svarichiv,Svarichov,Svariciv,Svarychev,Svarychiv,Svarychuv,Сваричів', 48.9622000, 24.1965800, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129407, 'Svalyava', 'Svalyava', 'Svalava,Svaljava,Svalva,Svalyava,Свалява', 48.5485300, 22.9957800, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129408, 'Suvorovskoye', 'Suvorovskoye', 'Bogaj,Suvorovs''ke,Suvorovskoe,Suvorovskoye,Бога́й,Суворовское,Суворовське', 45.2517100, 33.3719400, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129409, 'Sutysky', 'Sutysky', 'Sutiski,Sutysky,Сутиски', 49.0424500, 28.4173300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129410, 'Susanino', 'Susanino', 'Bijuk-Buzav,Susanine,Susanino,Бию́к-Буза́в,Сусанино,Сусаніне', 45.4989800, 33.6985400, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129411, 'Surs’ko-Mykhaylivka', 'Surs''ko-Mykhaylivka', 'Surs''ko-Mikhajlivka,Surs''ko-Mykhaylivka,Sursko-Mikhajlovka,Sursko-Mikhaylovka,Surs’ko-Mykhaylivka,Сурско-Михайловка,Сурсько-Михайлівка', 48.2720200, 34.7275900, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129412, 'Sumy', 'Sumy', 'Gorad Sumy,Soemi,Soemy,Soumy,Sumad,Sumae,Sumai,Sumi,Sumio,Sumo,Sumy,Sumî,Sumõ,Sumı,Szumi,UMY,su mei,sumi,sumu~i,swmy,Горад Сумы,Суми,Сумы,Սումի,סומי,سومي,سومی,სუმი,スームィ,蘇梅,수미', 50.9216000, 34.8002900, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129413, 'Sukhovolya', 'Sukhovolya', 'Sukhovolja,Sukhovolya,Суховоля', 49.8242600, 23.8377000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129414, 'Sudova Vyshnya', 'Sudova Vyshnya', 'Sadowa Wisznia,Sondova Vishnya,Sudova Vishnja,Sudova Vyshnya,Sudovaya Vishna,Sudovaya Vishnya,Sądowa Wisznia,Wisznia,Судова Вишня', 49.7889200, 23.3721800, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129415, 'Sudak', 'Sudak', 'Sudak,Sudako,Sudaq,Судак,სუდაკი', 44.8492400, 34.9747100, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129416, 'Subottsi', 'Subottsi', 'Subbotcy,Subbotets,Subbottsy,Subotci,Subottsi,Субботцы,Суботці', 48.6554500, 32.5209300, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129417, 'Studenok', 'Studenok', 'Studenok,Студенок', 49.0910700, 37.4869700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129418, 'Stryi', 'Stryi', 'Strij,Stry,Stryi,Stryj,Stryy,Стрий,Стрый', 49.2622300, 23.8560900, 'UA', '2014-03-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129419, 'Strogonovka', 'Strogonovka', 'Mamak,Strogonivka,Strogonovka,Мама́к,Строгоновка,Строгонівка', 44.9497000, 34.1792400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129420, 'Strabychovo', 'Strabychovo', 'Strabichevo,Strabichovo,Strabichëvo,Strabychove,Strabychovo,Страбичово', 48.3924700, 22.5430800, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129421, 'Stizhkivs’ke', 'Stizhkivs''ke', 'Stizhkivs''ke,Stizhkivs’ke,Stozhkovo,Stozhkovskoye,Стіжківське', 48.1133300, 38.4925000, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129422, 'Storozhnytsya', 'Storozhnytsya', 'Iovro-Darma,Storozhnica,Storozhnicja,Storozhnitsa,Storozhnytsya,Сторожница,Сторожниця', 48.6040300, 22.2326900, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129423, 'Storozhynets’', 'Storozhynets''', 'Storojinet,Storozhinec'',Storozhinets,Storozhynets'',Storozhynets’,Сторожинець', 48.1643000, 25.7202900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129424, 'Stolbovoye', 'Stolbovoye', 'Kurulu,Stolbovoe,Stolbovoye,Stovpove,Курулу́,Стовпове,Столбовое', 45.3627000, 33.4958400, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129425, 'Stetseva', 'Stetseva', 'Steceva,Stetseva,Stetsova,Стецева', 48.5276700, 25.5757200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129426, 'Botanicheskoye', 'Botanicheskoye', 'Aip,Botanicheskoe,Botanicheskoye,Botanichne,Аи́п,Ботаническое,Ботанічне', 45.7865600, 33.5485600, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129427, 'Stepnoye', 'Stepnoye', 'Munij,Stepne,Stepnoe,Stepnoye,Муни́й,Степне,Степное', 45.6521200, 33.7744100, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129428, 'Stepanivka', 'Stepanivka', 'Stepanovka,Степановка', 46.7948900, 29.9868400, 'UA', '2010-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129429, 'Stebnyk', 'Stebnyk', 'Stebnik,Stebniki,Stebnyk,Стебник', 49.2941600, 23.5635700, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129430, 'Steblëv', 'Steblev', 'Steblev,Steblev Pervyy,Steblëv,Steblëv Pervyy,Стеблев', 49.4018600, 31.0976400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129431, 'Stayki', 'Stayki', 'Stajki,Stayki,Стайки', 50.0781800, 30.9038000, 'UA', '2013-02-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129432, 'Stavyshche', 'Stavyshche', 'Stavishche,Stavishhe,Stavyshche,Ставище', 50.4005100, 29.5279600, 'UA', '2017-06-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129433, 'Stavyshche', 'Stavyshche', 'Stavishche,Stavishhe,Stavyshche,Ставище', 49.3912400, 30.1902200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129434, 'Staryy Sambir', 'Staryy Sambir', 'Starij Sambir,Stary Sambor,Staryj Sambor,Staryy Sambir,Staryy Sambor,Старий Самбір,Старый Самбор', 49.4385600, 23.0005600, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129435, 'Staryy Saltiv', 'Staryy Saltiv', 'Star.Saltov,Starij Saltiv,Stary Saltov,Staryj Saltov,Staryy Saltiv,Staryy Saltov,Стар.Салтов,Старий Салтів,Старый Салтов', 50.0761900, 36.7885200, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129436, 'Staryy Merchyk', 'Staryy Merchyk', 'Star.Merchik,Starij Merchik,Staryy Merchik,Staryy Merchyk,Стар.Мерчик,Старий Мерчик', 49.9814700, 35.7590400, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129437, 'Staryy Krym', 'Staryy Krym', 'Starij Krim,Stary Krym,Staryj Krym,Staryy Krym,Старий Крим,Старый Крым', 47.1614600, 37.4893400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129438, 'Stary Krym', 'Stary Krym', 'Eski Qirim,Eski Qyrym,Eski Qırım,Starij Krim,Stary Krym,Staryj Krym,Старий Крим,Старый Крым', 45.0288700, 35.0917400, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129439, 'Stari Kuty', 'Stari Kuty', 'Kuty Stare,Kuty Stary,Kuty Staryye,Stari Kuti,Stari Kuty,Staryye Kuty,Старі Кути', 48.2709300, 25.1729300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129440, 'Stari Bohorodchany', 'Stari Bohorodchany', 'Stare-Bogorodchany,Stari Bogorodcani,Stari Bohorodchany,Staryye Bogorodchany,Старі Богородчани', 48.8336100, 24.5243000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129441, 'Staroye Selo', 'Staroye Selo', 'Stare Selo,Staroe Selo,Staroye Selo,Старе Село,Старое Село', 49.7103700, 24.1895000, 'UA', '2013-02-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129442, 'Starokostyantyniv', 'Starokostyantyniv', 'Starokonstantinov,Starokonstantinow,Starokostantiniv,Starokostjantiniv,Starokostyantyniv,Староконстантинов,Старокостянтинів', 49.7576400, 27.2034200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129443, 'Starokozache', 'Starokozache', 'Cazaci,Cazacii-Vechi,Kazach'',Kazach’,Staro-Kozaki,Starokazach''ye,Starokazach’ye,Starokozach''ye,Starokozache,Starokozach’ye,Старокозаче', 46.3372200, 29.9852800, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129444, 'Starobesheve', 'Starobesheve', 'Starobesheve,Starobeshevo,Starobyeshevo,Staroye Beshevo,Старобешеве,Старобешево', 47.7503800, 38.0305100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129445, 'Starobil’s’k', 'Starobil''s''k', 'Bel''skiy Gorodok,Bel’skiy Gorodok,Staraya Belaya,Starobel''sk,Starobel’sk,Starobil''s''k,Starobil’s’k,Старобельск,Старобільськ', 49.2783200, 38.9106900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129446, 'Starychi', 'Starychi', 'Starichi,Starici,Stariska,Starychi,Stazhiska,Stirichi,Старичі', 49.9800100, 23.5584800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129447, 'Stara Vyzhivka', 'Stara Vyzhivka', 'Stara Vizhivka,Stara Vizivka,Stara Vyzhivka,Stara Vyzhva,Staraya Vizhivka,Staraya Vyzhevka,Стара Вижівка', 51.4376200, 24.4399700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129448, 'Stara Synyava', 'Stara Synyava', 'Stara Sinjava,Stara Synyava,Staraya Sinyava,Стара Синява', 49.6031800, 27.6190900, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129449, 'Stanislav', 'Stanislav', 'Stanislav,Станіслав', 46.5690900, 32.1477700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129450, 'Stanytsya Luhans’ka', 'Stanytsya Luhans''ka', 'Luganskaya,Stanichnno-Luganskoye,Stanichno Luganskaya,Stanichno-Lugans''ke,Stanichno-Luganskoe,Stanichno-Luganskoye,Stanicja Lugans''ka,Stanychno-Luhans''ke,Stanychno-Luhans’ke,Stanytsya Luhans''ka,Stanytsya Luhans’ka,Станиця Луганська,Станично-Луганское,Станично-Луганське', 48.6543300, 39.4794300, 'UA', '2015-04-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129451, 'Stal’noye', 'Stal''noye', 'Baryn,Stal''ne,Stal''noe,Stal''noye,Stal’noye,Бары́н,Стальне,Стальное', 45.7081400, 34.5623800, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129452, 'Stakhanovka', 'Stakhanovka', 'Beshuj-Iljak,Stakhanovka,Бешу́й-Иля́к,Стахановка', 45.3706200, 33.9488300, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129453, 'Stakhanov', 'Stakhanov', 'Gorad Stakhanau,Kadijewka,Kadiyevka,Ssergo,Stachanov,Stachanovas,Stachanow,Stahanov,Stahanova,Stahhanov,Stajanov,Stajánov,Stakhanov,Staxanov,astakhanwf  awkrayn,si da han nuo fu,Горад Стаханаў,Стаханов,Ստախանով,استاخانوف، اوکراین,სტახანოვი,斯達漢諾夫', 48.5681800, 38.6435200, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129454, 'Serednye Vodyane', 'Serednye Vodyane', 'Seredne Vodjane,Seredneh Vodjane,Serednye Vodyane,Sredneye Vodyanoye,Середнэ Водяне,Середнє Водяне', 47.9815900, 23.9104100, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129455, 'Serednye', 'Serednye', 'Seredne,Seredneye,Serednye,Srednee,Sredneye,Середнє,Среднее', 48.5404300, 22.5069600, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129456, 'Sribne', 'Sribne', 'Srebnoe,Srebnoye,Sribne,Sribnoye,Сребное,Срібне', 50.6638400, 32.9186700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129457, 'Spas’ke', 'Spas''ke', 'Spas''ke,Spasskoe,Spasskoye,Spas’ke,Спасское,Спаське', 48.6666700, 35.0538500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129458, 'Spas', 'Spas', 'Spas,Спас', 48.8899200, 24.0629300, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129459, 'Sovetskiy', 'Sovetskiy', 'Ichki,Sovets''kij,Sovetskij,Sovetskiy,Ички́,Советский,Совєтський', 45.3426700, 34.9246300, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129460, 'Sosnytsya', 'Sosnytsya', 'Sosnica,Sosnicja,Sosnitsa,Sosnytsya,Сосница,Сосниця', 51.5238700, 32.4998500, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129461, 'Solotvyno', 'Solotvyno', 'Aknaszlatina,Solotvina,Solotvino,Solotvyna,Solotvyno,Солотвино', 47.9460400, 23.8703500, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129462, 'Solotvyn', 'Solotvyn', 'Solotvin,Solotvina,Solotvyn,Solotwina,Sołotwina,Zolotvina,Солотвин', 48.7021200, 24.4221200, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129463, 'Solonka', 'Solonka', 'Solonka,Solonka Vel''ka,Solonka Velikaya,Солонка', 49.7562100, 24.0102800, 'UA', '2009-02-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129464, 'Solonytsivka', 'Solonytsivka', 'Sinelitsovka,Sinolitsevka,Solonicevka,Solonicivka,Solonitsevka,Solonytsivka,Солоницевка,Солоницівка', 49.9968200, 36.0346400, 'UA', '2015-10-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129465, 'Solnechnogorskoye', 'Solnechnogorskoye', 'Kuru-Uzen'',Quru OEzen,Quru Özen,Solnechnogorskoe,Solnechnogorskoye,Sonjachnogirs''ke,Куру́-Узе́нь,Солнечногорское,Сонячногірське', 44.7472200, 34.5399900, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129466, 'Solnechnaya Dolina', 'Solnechnaya Dolina', 'Koz,Kozy,Qoz,Solnechnaja Dolina,Solnechnaya Dolina,Sonjachna Dolina,Ко́зы,Коз,Солнечная Долина,Сонячна Долина', 44.8718500, 35.1062200, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129467, 'Solone', 'Solone', 'Solenoe,Solenoye,Solone,Solënoye,Соленое,Солоне', 48.2080500, 34.8720800, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129468, 'Sokolinoye', 'Sokolinoye', 'Kokkozy,Sokoline,Sokolinoe,Sokolinoye,Кокко́зы,Соколине,Соколиное', 44.5504100, 33.9589700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129469, 'Ilyinka', 'Ilyinka', 'Il''inka,Illinka,Ilyinka,Novyj Dzhelishaj,Vilor,Іллінка,Вило́р,Ильинка,Но́вый Джелиша́й', 45.8178400, 33.7948200, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129470, 'Sokyryany', 'Sokyryany', 'Secureni,Secureni Targ,Secureni Târg,Sekiryany,Sekuren'',Sekureni,Sekuren’,Sekuryany,Sokirjani,Sokiryany,Sokyryany,Сокиряни', 48.4474700, 27.4167800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129471, 'Sokal’', 'Sokal''', 'Sokal'',Sokal’,Сокаль', 50.4743800, 24.2828800, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129472, 'Sofiyivka', 'Sofiyivka', 'Sofievka,Sofiewka,Sofiivka,Sofijewka,Sofiyevka,Sofiyivka,Ssofijewka,Софиевка,Софіївка', 48.0486500, 33.8761800, 'UA', '2016-03-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129473, 'Sofyevka', 'Sofyevka', 'Sofievka,Sofiivka,Sofyevka,Софиевка,Софіївка', 45.0898500, 33.9988700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129474, 'Sobolivka', 'Sobolivka', 'Sobolivka,Соболівка', 49.3360400, 28.6509600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129475, 'Sniatyn', 'Sniatyn', 'Sniatyn,Snjatin,Snyatin,Snyatyn,Śniatyn,Снятин', 48.4469200, 25.5693700, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129476, 'Snihurivka', 'Snihurivka', 'Smigirevk,Snegirevka,Snegirëvka,Snigirevka,Snigirëvka,Snigurivka,Snihurivka,Снігурівка', 47.0757900, 32.8051600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129477, 'Snizhne', 'Snizhne', 'Shezhnoye,Snezhnoe,Snezhnoye,Snizhne,Снежное,Сніжне', 48.0261200, 38.7722500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129478, 'Smila', 'Smila', 'Smela,Smila,Smiła,asmyla  awkrayn,si mi la,smela,smylh,Смела,Смила,Сміла,Սմելա,סמילה,اسمیلا، اوکراین,სმელა,斯米拉', 49.2224200, 31.8871400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129479, 'Sloviansk', 'Sloviansk', 'Gorad Slavjansk,Slavjansk,Slavyansk,Slawjansk,Sloveansk,Sloviansk,Slovjan''sk,Slovjans''k,Slovjansk,Slovjanska,Slovjanskas,Slovjansko,Slovyansk,Slov”yans''k,Slowiansk,Slowjansk,Słowiańsk,Słowjansk,aslwfyansk,seullobiyansikeu,si la wei yang si ke,slwfyansk,suravu~yansuku,Σλοβιάνσκ,Горад Славянск,Славянск,Славјанск,Словянськ,Словяньск,Սլովյանսկ,اسلوفیانسک,سلوفيانسك,სლავიანსკი,スラヴャンスク,斯拉維揚斯克,슬로비얀시크', 48.8666700, 37.6166700, 'UA', '2010-07-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129480, 'Slov`yanoserbsk', 'Slov`yanoserbsk', 'Slov''janoserbs''k,Slov”yanoserbs''k,Слов''яносербськ', 48.6977900, 38.9813300, 'UA', '2013-01-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129481, 'Slobidka', 'Slobidka', 'Poselok Slobodka,Posëlok Slobodka,Slobidka,Slobodka,Слобідка', 47.8869400, 29.3461100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129482, 'Sloboda', 'Sloboda', 'Popova Sloboda,Sloboda,Слобода', 51.1980600, 33.6069500, 'UA', '2012-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129483, 'Slavyanskoye', 'Slavyanskoye', 'Sadyr,Slavjanskoe,Slavyanskoye,Slov''jans''ke,Сады́р,Славянское,Слов’янське', 45.7276800, 33.3216500, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129484, 'Slavuta', 'Slavuta', 'Slavouta,Slavuta,Slawuta,Sslawuta,Szlavuta,Sławuta,aslawwta,si la wu ta,Славута,Սլավուտա,סלאוויטא,اسلاووتا,სლავუტა,斯拉武塔', 50.3015500, 26.8650600, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129485, 'Slavs’ke', 'Slavs''ke', 'Slavs''ke,Slavsko,Slavskoe,Slavskoye,Slavs’ke,Slawsko,Sławsko,slawskoye,Славское,Славське', 48.8473400, 23.4458700, 'UA', '2017-01-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129486, 'Slavnoye', 'Slavnoye', 'Bakal Tatarskij,Slavne,Slavnoe,Slavnoye,Бака́л Тата́рский,Славне,Славное', 45.7217600, 33.2368900, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129487, 'Slatyne', 'Slatyne', 'Kuliki,Poselok Slatino,Posëlok Slatino,Slatine,Slatino,Slatyne,Слатине,Слатино', 50.2104100, 36.1537600, 'UA', '2013-11-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129488, 'Skvortsovo', 'Skvortsovo', 'Skvorcove,Skvorcovo,Skvortsovo,Starye Lezy,Staryj Lez,Скворцове,Скворцово,Ста́рые Ле́зы,Ста́рый Лез', 45.0754200, 33.8208400, 'UA', '2016-05-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129489, 'Skvyra', 'Skvyra', 'Skvira,Skvyra,Skvîra,Skvıra,Skwyra,askwyra,si ke wei la,sqwwyrh,Сквира,Սկվիրա,סקווירא,סקווירה,اسکویرا,სკვირა,斯克維拉', 49.7317700, 29.6656900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129490, 'Skole', 'Skole', 'Skol''ye,Skole,Skole i Ukraina,Skol’ye,askwlh,si ke lie,Сколе,Սկոլե,اسکوله,სკოლე,斯科列', 49.0371700, 23.5134600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129491, 'Skhidnytsya', 'Skhidnytsya', 'Schodnica,Skhidnicja,Skhidnytsya,Skhodnica,Skhodnitsa,Сходница,Східниця', 49.2282700, 23.3501600, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129492, 'Skelivka', 'Skelivka', 'Fel''shtin,Fel''shtyn,Felsteen,Felstin,Felsztyn,Fel’shtin,Fel’shtyn,Skelevka,Skelivka,Скелевка,Скелівка', 49.5372800, 22.9646700, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129493, 'Skalistoye', 'Skalistoye', 'Skaliste,Skalistoe,Skalistoye,Tav-Bodrak,Скалисте,Скалистое,Тав-Бодра́к', 44.8168600, 33.9779100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129494, 'Skalat', 'Skalat', 'Skalat,Скалат', 49.4273200, 25.9786900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129495, 'Skala-Podil’s’ka', 'Skala-Podil''s''ka', 'Skala,Skala Podolska,Skala-Podil''s''ka,Skala-Podil’s’ka,Skala-Podol''skaja,Skala-Podol''skaya,Skala-Podol’skaya,Skała,Skała Podolska,Скала-Подольская,Скала-Подільська', 48.8514900, 26.1990900, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129496, 'Skadovs’k', 'Skadovs''k', 'Skadovs''k,Skadovsk,Skadovs’k,Skadowsk,Скадовск,Скадовськ', 46.1161000, 32.9112400, 'UA', '2015-03-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129497, 'Sizovka', 'Sizovka', 'Saja,Sizivka,Sizovka,Сая,Сизiвка,Сизовка', 45.3489200, 33.8766900, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129498, 'Synevyrs''ka Polyana', 'Synevyrs''ka Polyana', 'Sinevir-Polyana,Sinevirskaja Poljana,Sinevirskaya Polyana,Siniyvir Polyana,Синевирская Поляна', 48.5848400, 23.6891000, 'UA', '2010-03-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129499, 'Synevyr', 'Synevyr', 'Alsoszinever,Alsószinevér,Sinevir,Siniyvir,Sinovir,Synevyr,Синевир', 48.4874500, 23.6257500, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129500, 'Synel’nykove', 'Synel''nykove', 'Sinel''nikove,Sinel''nikovo,Sinel’nikovo,Synel''nykove,Synel’nykove,Синельникове,Синельниково', 48.3204400, 35.5179200, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129501, 'Simferopol', 'Simferopol', 'Akmescit,Akməsҗit,Aq Mecit,Aq Mečit,Aqmescit,Gorad Simferopal'',SIP,Simferepol'',Simferopol,Simferopol'',Simferopole,Simferopoli,Simferopolis,Simferopolj,Simferopolo,Simferòpol,Simferópol,Sinferopol,Sinferopoli,Sinferòpol,Symferopol,Symferopoli,Sympheropolis,Szimferopol,cimhperoppol,shinferopori,simpelopol,simpheropola,smfrwpwl,symfrbwl,symfrwbwl,symfrwpwl,symprwpwl,xin fei luo bo er,Συμφερόπολη,Акмәсҗит,Горад Сімферопаль,Симфереполь,Симферопол,Симферополь,Симферопољ,Сімферополь,Սիմֆերոպոլ,סימפרופול,سمفروپول,سيمفربول,سيمفروبول,سیمفروپول,सिंफेरोपोल,சிம்ஃபெரோப்போல்,სიმფეროპოლი,シンフェロポリ,辛菲罗波尔,심페로폴', 44.9571900, 34.1107900, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129502, 'Simeiz', 'Simeiz', 'Pasjolak garadskoga typu Simjaiz,Simeiiz,Simeiz,Simeizo,Simejis,Simejiz,Simeïz,Szimejiz,Sîmeiiz,xi mei yi zi,Пасёлак гарадскога тыпу Сімяіз,Симеиз,Сімеїз,Սիմեիզ,西梅伊茲', 44.4064600, 34.0070400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129503, 'Shums’k', 'Shums''k', 'Shums''k,Shumskoye,Shums’k,Szumsk,Шумськ', 50.1215700, 26.1142400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129504, 'Shturmovoye', 'Shturmovoye', 'Novye Shuli,Shturmove,Shturmovoe,Shturmovoye,Новые Шули,Штурмове,Штурмовое', 44.5676700, 33.6224500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129505, 'Shpola', 'Shpola', 'Shpola,Шпола', 49.0068700, 31.3947100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129506, 'Shostka', 'Shostka', 'Schostka,Shostka,Шостка', 51.8629600, 33.4698000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129507, 'Sholokhove', 'Sholokhove', 'Sholokhove,Sholokhovo,Шолохове,Шолохово', 47.6945300, 34.0311900, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129508, 'Shklo', 'Shklo', 'Shklo,Szklo,Szkło,Шкло', 49.9567500, 23.5440800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129509, 'Shyshaky', 'Shyshaky', 'Shishaki,Shyshaky,Шишаки', 49.8817500, 34.0111800, 'UA', '2010-06-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129510, 'Shyryayeve', 'Shyryayeve', 'Sharayevo,Shirjaehve,Shirjaeve,Shiryayevo,Shyryayeve,Ширяэве,Ширяєве', 47.3805200, 30.1963800, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129511, 'Shyroke', 'Shyroke', 'Shiroke,Shirokoye,Shyroke,Широке', 47.9571100, 38.2316000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129512, 'Shyroke', 'Shyroke', 'Shiroke,Shirokoye,Shyroke,Широке', 47.6917300, 33.2571500, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129513, 'Pshenichnoye', 'Pshenichnoye', 'Karangit,Oktjabr''dorf,Pshenichne,Pshenichnoe,Pshenichnoye,Каранги́т,Октябрьдо́рф,Пшеничне,Пшеничное', 45.6462700, 34.8376700, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129514, 'Shypyntsi', 'Shypyntsi', 'Shipentsi,Shipintsy,Shypyntsi,Sipinci,Шипинці', 48.3767700, 25.7466400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129515, 'Partizany', 'Partizany', 'Partizani,Partizany,Shejkh-Ehli,Партизани,Партизаны,Шейх-Эли́', 45.1437300, 35.1550900, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129516, 'Shevchenkove', 'Shevchenkove', 'Bulatselivka,Bulazelewka,Shevchenkove,Shevchenkovo,Шевченкове,Шевченково', 49.6958500, 37.1734800, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129517, 'Shevchenkove', 'Shevchenkove', 'Shevchenko,Shevchenkove,Shevchenkovo,Шевченкове,Шевченково', 46.8628900, 32.2038700, 'UA', '2017-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129518, 'Shevchenkove', 'Shevchenkove', 'Caramahmet,Karamagmed,Karamakhmed,Shevchenkove,Shevchenkovo,Шевченкове,Шевченково', 45.5560400, 29.3335700, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129519, 'Sheshory', 'Sheshory', 'Sheshori,Sheshory,Шешори,Шешоры', 48.3319700, 24.9832900, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129520, 'Shepetivka', 'Shepetivka', 'Schepetowka,Sepetivka,Shepetivka,Shepetovka,Шепетовка,Шепетівка', 50.1854500, 27.0636500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129521, 'Shelkovichnoye', 'Shelkovichnoye', 'Shelkovichnoe,Shelkovichnoye,Shovkovichne,Temesh,Теме́ш,Шелковичное,Шовковичне', 45.1874800, 33.6880700, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129522, 'Shchors', 'Shchors', 'Shchors,Shchorsk,Shhors,Snovsk,Щорс', 51.8186500, 31.9450400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129523, 'Shchyrets’', 'Shchyrets''', 'Shcherzhets,Shchezhets,Shchirets,Shchyrets'',Shchyrets’,Shhirec,Shhiret'',Shirets,Szczerzec,Щиреть,Щирец', 49.6509600, 23.8742600, 'UA', '2013-03-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129524, 'Shcherbynivka', 'Shcherbynivka', 'Serbinivka,Shcherbinovka,Shcherbynivka,Shherbinivka,Щербинівка', 48.3948900, 37.7910200, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129525, 'Shchebetovka', 'Shchebetovka', 'Otus,Otuz,Otuzy,Shchebetovka,Shebetovka,Shhebetovka,Щебетовка', 44.9382100, 35.1580000, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129526, 'Shats’k', 'Shats''k', 'Shac''k,Shats''k,Shatsk,Shats’k,Szack,Шатск,Шатськ,Шацьк', 51.5020800, 23.9380600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129527, 'Sharhorod', 'Sharhorod', 'Shargorod,Sharhorod,Шаргород', 48.7383500, 28.0849700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129528, 'Shalyhyne', 'Shalyhyne', 'Shaligine,Shalygino,Shalyhyne,Shul''gino,Shul’gino,Шалигине,Шалыгино', 51.5716700, 34.1216700, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129529, 'Shakhtars’k', 'Shakhtars''k', 'Katyk,Shakhtars''k,Shakhtars’k,Shakhtersk,Shakhtërsk,Zapadno-Gruppskiy,Шахтарськ,Шахтерск', 48.0565700, 38.4382600, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129530, 'Shabo', 'Shabo', 'Sba,Shaba,Shabo,Şba,Шабо', 46.1326200, 30.3859500, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129531, 'Sivers’k', 'Sivers''k', 'Seversk,Sivers''k,Sivers’k,Yama,Северск,Сіверськ', 48.8669900, 38.1000700, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129532, 'Sevastopol', 'Sevastopol', 'Akujar,Akyar,Aqjar,Aqyar,Sebastopol,Sebastopoli,Sebastopolis,Sebastopolo,Sebastòpol,Sevastopal'',Sevastopol,Sevastopol'',Sevastopole,Sevastopolis,Sevastopolj,Sevastopolo,Sevastopoľ,Sevastoupoli,Sewastopol,Sivastopol,Szevasztopol,Sébastopol,UKS,sai wa si tuo bo er,sbstwpwl,sebaseutopol,sevhastopola,sevu~asutopori,swastwpwl,syfastwbwl,Σεβαστούπολη,Акъяр,Севастопаль,Севастопол,Севастополь,Севастопољ,סבסטופול,سواستوپول,سيفاستوبول,सेव्हास्तोपोल,ဆီပတ်စတိုပိုမြို့,სევასტოპოლი,セヴァストポリ,塞瓦斯托波爾,세바스토폴', 44.5888300, 33.5224000, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129533, 'Serpneve', 'Serpneve', 'Leiptig,Leipzig,Leyptsig,Leyptsigskaya,Serpneve,Serpnevoye,Skinos,Серпневе', 46.3009400, 29.0195800, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129534, 'Serhiyivka', 'Serhiyivka', 'Sergeevka,Sergeyevka,Sergeyevka-Bay,Serghieste-Noui,Serghieşte-Noui,Sergiivka,Sergiyivka,Serhiyivka,Сергеевка,Сергіївка', 46.0272000, 30.3768200, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129535, 'Seredyna-Buda', 'Seredyna-Buda', 'Iseredinabuda,Seredina Buda,Seredina-Buda,Seredyna-Buda,Середина Буда,Середина-Буда', 52.1890300, 34.0363900, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129536, 'Serebryanka', 'Serebryanka', 'Serebrjanka,Serebryanka,Серебрянка', 48.9191700, 38.1349400, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129537, 'Serebryanka', 'Serebryanka', 'Oktjabr''dorf,Serebrjanka,Serebryanka,Октябрьдо́рф,Серебрянка', 45.6393700, 33.4963200, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129538, 'Serebriya', 'Serebriya', 'Serebria,Serebriya,Серебрія', 48.4559300, 27.7192300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129539, 'Sencha', 'Sencha', 'Sencha,Сенча', 50.2548200, 33.3460200, 'UA', '2013-07-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129540, 'Semisotka', 'Semisotka', 'Semisotka,Семисотка', 45.2467600, 35.5650000, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129541, 'Semypolky', 'Semypolky', 'Semipolki,Semypolky,Семиполки', 50.7262700, 30.9344100, 'UA', '2013-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129542, 'Simeykyne', 'Simeykyne', 'Semejkino,Semeykino,Semeykinskiy,Simejkine,Simeykyne,Семейкино,Сімейкине', 48.3264300, 39.5336600, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129543, 'Semenivka', 'Semenivka', 'Semenivka,Semenivka i Tsjernihiv oblast,Semeniwka,Semenovka,Seminovka,Semionovka,Semjonovka,Semyonovka,Semënovka,Ssemenowka,smnybqh,smnyfka,xie miao nuo fu ka,Семеновка,Семенівка,Семёновка,Սեմյոնովկա,סמניבקה,سمنیفکا,სემიონოვკა,謝苗諾夫卡', 52.1782700, 32.5818300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129544, 'Semenivka', 'Semenivka', 'Semenivka,Semenovka,Semënovka,Семеновка,Семенівка', 49.5903100, 33.1804900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129545, 'Selydove', 'Selydove', 'Selidove,Selidovka,Selidovo,Selydove,Selydowe,Selîdove,Sełydowe,Sélydové,selidovo,slydwfh,xie li duo wei,Селидове,Селидово,Սելիդովո,سلیدوفه,სელიდოვო,謝利多韋', 48.1470800, 37.3003200, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129546, 'Silets’', 'Silets''', 'Selets,Selets Bel''ski,Selets Bel’ski,Sielec,Sielec Belski,Sielec Bełski,Silec'',Silets'',Silets’,Сілець', 50.2971200, 24.2046200, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129547, 'Syedove', 'Syedove', 'Imeni G. Ya. Sedova,Imeni Sedova,Imeni Sedova G. Ya.,Krivaya Kosa,Sedova,Sedove,Sedovo,Sehdove,Syedove,Седово,Сэдове,Сєдове', 47.0767800, 38.1560200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129548, 'Sedniv', 'Sedniv', 'Sednev,Sedniv,Sednëv,Седнев,Седнів', 51.6447300, 31.5649700, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129549, 'Shchastya', 'Shchastya', 'Schast''e,Schast''ye,Schast’ye,Shchastya,Shhastja,Счастье,Щастя', 48.7396300, 39.2323000, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129550, 'Savran’', 'Savran''', 'Savran'',Savran’,Саврань', 48.1321900, 30.0824700, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129551, 'Savyntsi', 'Savyntsi', 'Savinci,Savincy,Savintsi,Savintsy,Savyntsi,Sawinzy,Савинцы,Савинці', 49.4025700, 37.0626600, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129552, 'Sarny', 'Sarny', 'Sarni,Sarnv,Sarny,Sarnî,Sarnı,sa er nei,sarni,sarny,Сарни,Сарны,Սարնի,סארני,سارنی,სარნი,薩爾內', 51.3379500, 26.6019100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129553, 'Sarata', 'Sarata', 'Sarata,Serata,Сарата', 46.0196600, 29.6656700, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129554, 'Sambir', 'Sambir', 'Gorad Sambar,Sambir,Sambira,Sambiras,Sambor,Szambir,sambori,sambyr,sang bo er,smbyr,Горад Самбар,Самбир,Самбор,Самбір,Սամբոր,סמביר,سامبیر,სამბორი,桑博爾', 49.5183000, 23.1975200, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129555, 'Saki', 'Saki', 'Sakai,Saki,Sako,Sakî,Sakõ,Saq,Szaki,sa ji,Σάκι,Саки,Սակի,საკი,薩基', 45.1342400, 33.5999600, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129556, 'Sakhnovshchyna', 'Sakhnovshchyna', 'Sakhnovshchina,Sakhnovshchyna,Sakhnovshhina,Сахновщина', 49.1516600, 35.8719800, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129557, 'Sadzhavka', 'Sadzhavka', 'Sadzavka,Sadzhavka,Sazhovka,Саджавка', 48.5660300, 24.7882000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129558, 'Sadovoye', 'Sadovoye', 'Novo-Caricyno,Sadove,Sadovoe,Sadovoye,Но́во-Цари́цыно,Садове,Садовое', 45.3103700, 34.6526000, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129559, 'Rzhyshchiv', 'Rzhyshchiv', 'Rzhishchev,Rzhishchëv,Rzhishhev,Rzhyshchiv,Rzisiv,Ржищев,Ржищів', 49.9688600, 31.0462800, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129560, 'Rykhtychi', 'Rykhtychi', 'Rihtici,Rikhtichi,Rikhtsitse,Rychcice,Rykhtichi,Rykhtsitse,Rykhtychi,Рихтичи,Рихтичі', 49.3851100, 23.5566200, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129561, 'Rybakivka', 'Rybakivka', 'Adshijask,Adzhiaska,Adzhiyask,Rybakivka,Rybakovka,Рыбаковка', 46.6171200, 31.3499500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129562, 'Rybach''e', 'Rybach''e', 'Ribache,Rybach''e,Rybach’e,Tuak,Рибаче,Рыбачье,Туа́к', 44.7733100, 34.5960900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129563, 'Ruzhyn', 'Ruzhyn', 'Rushin,Ruzhin,Ruzhyn,Ружин', 49.7228000, 29.2045500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129564, 'Russkaya Polyana', 'Russkaya Polyana', 'Rus''ka Poljana,Russkaja Poljana,Russkaya Polyana,Русская Поляна,Руська Поляна', 49.4170000, 31.9200900, 'UA', '2010-12-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129565, 'Rusakovka', 'Rusakovka', 'Kokej Russkij,Rusakivka,Rusakovka,Коке́й Ру́сский,Русаковка,Русаківка', 45.1236900, 34.4745800, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129566, 'Rudne', 'Rudne', 'Rudno,Рудно', 49.8333300, 23.9000000, 'UA', '2008-01-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129567, 'Rudky', 'Rudky', 'Rudki,Rudky,Рудки', 49.6530600, 23.4870200, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129568, 'Ruch’i', 'Ruch''i', 'Kopkary Nemeckie,Ruch''i,Ruch’i,Копкары́ Неме́цкие,Ручьи,Руч’ї', 45.7856400, 33.6609300, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129569, 'Rubizhne', 'Rubizhne', 'Rubezhnaya,Rubezhnoe,Rubezhnoye,Rubizhne,Rubizne,Рубежное,Рубіжне', 49.0122900, 38.3796700, 'UA', '2013-11-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129570, 'Rozvadiv', 'Rozvadiv', 'Razvandov,Rozvadiv,Rozvadov,Rozvaduv,Розвадов,Розвадів', 49.5032300, 23.9620000, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129571, 'Rozivka', 'Rozivka', 'Lyuksemburg,Rosowka,Rozenberg,Rozivka,Rozovka,Розовка,Розівка', 47.3848400, 37.0679200, 'UA', '2015-04-25', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129572, 'Rozivka', 'Rozivka', 'Rozivka,Rozovka,Розівка', 46.9394000, 35.7720700, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129573, 'Rozhnyativ', 'Rozhnyativ', 'Rozhnitiv,Rozhnjativ,Rozhnyativ,Rozhnyatov,Rozhnyatuv,Roznativ,Roznatov,Rozniatow,Roznitev,Roznjativ,Roznyatuv,Rożniatów,Рожнятів', 48.9357600, 24.1637900, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129574, 'Rozhniv', 'Rozhniv', 'Rozhnev,Rozhniv,Rozhnov,Rozhnyuv,Rozniv,Roznov,Roznow,Rożnów,Рожнів', 48.3659700, 25.2258000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129575, 'Rozhyshche', 'Rozhyshche', 'Rozhishche,Rozhishhe,Rozhyshche,Rozyszcze,Рожище', 50.9154200, 25.2690600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129576, 'Rozdil', 'Rozdil', 'Razdol,Rozdil,Rozdo,Rozdol,Rozdul,Роздол,Розділ', 49.4614400, 24.0623000, 'UA', '2017-01-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129577, 'Rozdil’na', 'Rozdil''na', 'Posad Pazdelnaya,Razdel''naja,Razdel''naya,Razdel’naya,Раздельная', 46.8433400, 30.0791900, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129578, 'Rivne', 'Rivne', 'Rivne,Rovno,Rovnoye,Ровно', 48.2474200, 31.7543200, 'UA', '2012-04-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129579, 'Roven’ky', 'Roven''ky', 'Roven''ki,Roven''ky,Rovenki,Roven’ki,Roven’ky,Rowenki,Ровеньки', 48.0833100, 39.3776400, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129580, 'Roskoshnyy', 'Roskoshnyy', 'Raskoshnaya,Roskoshnaja,Roskoshnaya,Roskoshno,Roskoshnyy,Роскошная', 49.3708700, 30.1847100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129581, 'Rozkishne', 'Rozkishne', 'Imeni Tel''mana,Imeni Tel’mana,Kozlyach''ye,Kozlyach’ye,Roskoshnoe,Roskoshnoye,Rozkishne,Rozkisne,Tel''mana,Tel’mana,Vasil''yevka,Vasil’yevka,Розкішне,Роскошное', 48.4895900, 39.2788100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129582, 'Roskoshnoye', 'Roskoshnoye', 'Roskoshnoe,Roskoshnoye,Rozkishne,Seit-Bulat Novyj,Розкішне,Роскошное,Сеи́т-Була́т Но́вый', 45.6518700, 34.1155200, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129583, 'Ropcha', 'Ropcha', 'Ropcha,Ropche,Ропча', 48.1198800, 25.7742100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129584, 'Romodan', 'Romodan', 'Romodan,Ромодан', 49.9905500, 33.3250600, 'UA', '2014-03-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129585, 'Romny', 'Romny', 'Rommy,Romnai,Romni,Romny,Romnî,Romnı,lomni,luo mu nei,romni,romunu~i,rwmny,Ромни,Ромны,Ռոմնի,רומני,رومنی,რომნი,ロムヌィ,羅姆內,롬니', 50.7510400, 33.4747100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129586, 'Romashkino', 'Romashkino', 'Ikor,Romashkine,Romashkino,Sokur-Koj,Ико́р,Ромашкине,Ромашкино,Соку́р-Кой', 45.2564700, 33.2551700, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129587, 'Rokosovo', 'Rokosovo', 'Rokosiv,Rokosov,Rokosovo,Рокосово', 48.2101800, 23.1762400, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129588, 'Rokytne', 'Rokytne', 'Rakitno,Rakitnoye,Rokitino,Rokitne,Rokitno,Rokitnoye,Rokytne,Рокитне', 51.2796000, 27.2140000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129589, 'Rohatyn', 'Rohatyn', 'Gorad Ragatyn,Rogatin,Rogatın,Rohatin,Rohatina,Rohatino,Rohatyn,Rohatîn,luo jia jing,rwhatyn,Горад Рагатын,Рогатин,Ռոհատին,רוהאטין,روهاتین,روہاتین,ڕۆھاتین,როგატინი,羅加京', 49.4090000, 24.6092700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129590, 'Rodnikovo', 'Rodnikovo', 'Rodnikove,Rodnikovo,Staryj Kulchuk,Родникове,Родниково,Старый Кулчу́к', 45.0429600, 33.9540700, 'UA', '2016-05-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129591, 'Rodyns’ke', 'Rodyns''ke', 'Khutor Liman,Krasnyy Liman,Liman,Rodins''ke,Rodinskoe,Rodinskoye,Rodyns''ke,Rodyns’ke,Родинское,Родинське', 48.3519900, 37.2060200, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129592, 'Rodatychi', 'Rodatychi', 'Rodatichi,Rodatyche,Rodatychi,Rodatycze,Родатичи,Родатичі', 49.7986200, 23.5333600, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129593, 'Rivne', 'Rivne', 'Eractum,Gorad Rouna,RWN,Rivne,Rivno,Rivnė,Riwne,Rovno,Rowne,Ruvne,Równe,liune,luo fu nuo,riune,rovno,rwbnw,rwfnw,rywn,rywnh,Горад Роўна,Ровно,Рівне,Ռովնո,ראוונע,רובנו,روفنو,ریون,ریونه,როვნო,リウネ,羅夫諾,리우네', 50.6230800, 26.2274300, 'UA', '2013-05-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129594, 'Reshetylivka', 'Reshetylivka', 'Resetilivka,Reshetilivka,Reshetilovka,Reshetylivka,Решетиловка,Решетилівка', 49.5650100, 34.0781500, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129595, 'Ripky', 'Ripky', 'Reoki,Repki,Ripki,Ripky,Репки,Ріпки', 51.8010500, 31.0838300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129596, 'Reni', 'Reni', 'Reni,lie ni,reni,rny  awkrayn,Рени,Рені,Ռենի,رنی، اوکراین,რენი,列尼', 45.4572700, 28.2931700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129597, 'Richky', 'Richky', 'Rechki,Richki,Richky,Rzyczki,Zhichki,Zhychki,Речки,Річки', 50.2770600, 23.6461700, 'UA', '2013-02-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129598, 'Rechka', 'Rechka', 'Rechka,Rechki,Richka,Речка,Річка', 48.2803400, 24.9333000, 'UA', '2010-08-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129599, 'Razdol’noye', 'Razdol''noye', 'Ak-Shejkh,Aq Sejich,Aq Šejiχ,Razdol''noe,Razdol''noye,Razdol’noye,Rozdol''ne,Ак-Ше́йх,Раздольное,Роздольне', 45.7708300, 33.4877700, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129600, 'Rava-Rus’ka', 'Rava-Rus''ka', 'Rava-Rus''ka,Rava-Ruska,Rava-Russkaja,Rava-Russkaya,Rava-Rus’ka,Rawa Ruska,Рава-Русская,Рава-Руська', 50.2307900, 23.6282500, 'UA', '2013-02-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129601, 'Ratne', 'Ratne', 'Rafno,Ratne,Ratno,Ратне', 51.6683000, 24.5303000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129602, 'Rozsypne', 'Rozsypne', 'Rassypnoy,Rassypnoye,Rozsipne,Rozsypne,Розсипне', 48.1496600, 38.5761900, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129603, 'Ralivka', 'Ralivka', 'Radlovichi,Ralevka,Ralivka,Ралевка,Ралівка', 49.4998200, 23.2373900, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129604, 'Rakiv Lis', 'Rakiv Lis', 'Rakiv Lis,Rakov Les,Rakovy Lyas,Раків Ліс', 51.6217400, 24.9242700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129605, 'Rakoshyno', 'Rakoshyno', 'Beregrakos,Beregrákos,Rakoshin,Rakoshino,Rakoshyn,Rakoshyno,Ракошин,Ракошино', 48.4671300, 22.5968700, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129606, 'Rokytne', 'Rokytne', 'Rakitno,Rakitnoe,Rakitnoye,Rokitne,Rokytne,Ракитное,Рокитне', 49.6866500, 30.4738400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129607, 'Rakhiv', 'Rakhiv', 'Rachov,Rakhiv,Rakhov,Rakhovo,Рахов,Рахів', 48.0526000, 24.2008900, 'UA', '2015-10-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129608, 'Radomyshl', 'Radomyshl', 'Radomishl,Radomishl'',Radomyshl'',Radomyshl’,Радомишль,Радомышль', 50.4961300, 29.2291100, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129609, 'Radens’k', 'Radens''k', 'Radens''k,Radensk,Radenskoye,Redanskoje,Раденск,Раденськ', 46.5486000, 32.9278700, 'UA', '2017-07-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129610, 'Radekhiv', 'Radekhiv', 'Radekhiv,Radekhov,Radzekhov,Radzekhuv,Radziechow,Radziechów,Радехів', 50.2824900, 24.6427900, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129611, 'Radcha', 'Radcha', 'Radcha,Radcza,Радча', 48.8502300, 24.6550200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129612, 'Piatykhatky', 'Piatykhatky', 'P''yatykhatky,Peatihatki,Peatîhatkî,Piatyjatky,Pitikhatki,Pjatichatka,Pjatichatki,Pjatikhatki,Pjatychatky,Pjatykhatky i Dnipropetrovsk oblast,Pyatihatki,Pyatikhatka,Pyatikhatki,Pyatixatki,Pyatıhatkı,pi ya ji ha te ji,puyatihatoki,pyatykhatky,Пятихатки,Пјатихатки,Պյատիխատկի,پیاتیخاتکی,პიატიხატკი,プヤティハートキ,皮亞季哈特基', 48.4133300, 33.7105600, 'UA', '2009-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129613, 'Pyatikhatka', 'Pyatikhatka', 'Beshuj-Ehli,P''jatikhatka,Pjatikhatka,Pyatikhatka,Бешу́й-Эли́,Пятихатка,П’ятихатка', 45.3234700, 34.2551600, 'UA', '2016-07-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129614, 'Putyvl’', 'Putyvl''', 'Putivl'',Putivl’,Putyvl'',Putyvl’,Путивль', 51.3374500, 33.8706600, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129615, 'Putyla', 'Putyla', 'Putila,Putyla,Storonets Putilla,Путила', 47.9886900, 25.0945500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129616, 'Pustomyty', 'Pustomyty', 'Pustomiti,Pustomyty,Пустомити,Пустомыты', 49.7153200, 23.9129500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129617, 'Pushkino', 'Pushkino', 'Ehsen-Ehki,Pushkine,Pushkino,Пушкино,Пушкіне,Эсен-Эки́', 45.2037300, 34.9764200, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129618, 'Pukhivka', 'Pukhivka', 'Pukhivka,Pukhovka,Пуховка,Пухівка', 50.6097000, 30.7177000, 'UA', '2016-06-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129619, 'Pryluky', 'Pryluky', 'Priluki,Pryluki,Pryluky,Pryłuki,Прилуки', 50.5932300, 32.3876100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129620, 'Prudyanka', 'Prudyanka', 'Prudjanka,Prudyanka,Прудянка', 50.2360600, 36.1683500, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129621, 'Prudy', 'Prudy', 'Ablesh,Prudi,Prudy,Абле́ш,Пруди,Пруды', 45.2392200, 34.7021700, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129622, 'Prostornoye', 'Prostornoye', 'Prostorne,Prostornoe,Prostornoye,Shirin Novyj,Просторне,Просторное,Шири́н Но́вый', 45.6559700, 34.6983700, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129623, 'Pryyutivka', 'Pryyutivka', 'Prijutivka,Prijutovka,Priyutovka,Pryyutivka,Приютовка,Приютівка', 48.7209400, 33.0707800, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129624, 'Pryvillya', 'Pryvillya', 'Privilla,Privol''e,Privol''noye,Privol''ye,Privol’noye,Privol’ye,Pryvillya,Приволье,Привілля', 49.0150100, 38.3045700, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129625, 'Privetnoye', 'Privetnoye', 'Dzhuma-Ehli,Privetnoe,Privetnoye,Privitne,Джума́-Эли́,Приветное,Привітне', 45.1196900, 35.0596000, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129626, 'Privetnoye', 'Privetnoye', 'Privetnoe,Privetnoye,Privitne,Uskut,Приветное,Привітне,Уску́т', 44.8214500, 34.6793500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129627, 'Pryshyb', 'Pryshyb', 'Prishib,Pryshyb,Пришиб', 47.2592700, 35.3195300, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129628, 'Priozyornoye', 'Priozyornoye', 'Churubash,Priozerne,Priozernoe,Priozyornoye,Приозерне,Приозерное,Чуруба́ш', 45.2699000, 36.3340500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129629, 'Sartana', 'Sartana', 'Primorskoe,Primorskoye,Sartana,Приморское,Сартана', 47.1743600, 37.6926600, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129630, 'Primorskiy', 'Primorskiy', 'Primors''kij,Primorskij,Primorskiy,Приморский,Приморський', 45.1190400, 35.4802500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129631, 'Prymors’k', 'Prymors''k', 'Nogaisk,Nogaysk,Primors''k,Primorsk,Primorskoye,Prymors''k,Prymors’k,Приморск,Приморськ', 46.7347900, 36.3442500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129632, 'Prykolotne', 'Prykolotne', 'Prikolotne,Prikolotnoe,Prikolotnoye,Prykolotne,Приколотне,Приколотное', 50.1627300, 37.3452400, 'UA', '2013-11-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129633, 'Pryazovs’ke', 'Pryazovs''ke', 'Pokrovka,Priazovs''ke,Priazovskoye,Pryazovs''ke,Pryazovs’ke,Vtoraya Pokrovka,Приазовське', 46.7342600, 35.6425100, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129634, 'Preobrazhenka', 'Preobrazhenka', 'Preobrazhenka,Преображенка', 47.5719400, 35.8166700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129635, 'Pravda', 'Pravda', 'Der-Ehmes,Duermen,Dürmen,Pravda,Дер-Э́мес,Правда', 45.7790300, 33.8464900, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129636, 'Potelych', 'Potelych', 'Potelich,Potelych,Potylich,Potylicz,Потелич', 50.2080400, 23.5467400, 'UA', '2013-02-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129637, 'Poroshkovo', 'Poroshkovo', 'Poroshkov,Poroshkove,Poroshkovo,Poroshkovoye,Porosko,Poroskov,Poroskő,Poroškov,Порошкове,Порошково', 48.6683200, 22.7532800, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129638, 'Porohy', 'Porohy', 'Porogi,Porohy,Porokhi,Porokhy,Пороги', 48.6875500, 24.2632200, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129639, 'Popil''nya', 'Popil''nya', 'Poelnja,Popel''naya,Popel''nja,Popel''nya,Popil''nja,Popilnia,Попельня,Попільня', 49.9665200, 29.4435300, 'UA', '2014-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129640, 'Popasna', 'Popasna', 'Imeni Kaganovicha,Imeni L.M. Kaganovicha,Kaganovich,Kaganowitsch,Popasna,Popasnaja,Popasnaya,Popasnyj,bo pa si na,pwpasna,Попасна,Попасная,Попасный,Պոպասնայա,پوپاسنا,პოპასნაია,波帕斯納', 48.6332800, 38.3780400, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129641, 'Poninka', 'Poninka', 'Paninka,Poninka,Понінка', 50.1849200, 27.5362900, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129642, 'Pomichna', 'Pomichna', 'Pomichna,Pomicna,Pomoshnaja,Pomoshnaya,Помошная,Помічна', 48.2422200, 31.4158300, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129643, 'Pomoryany', 'Pomoryany', 'Pomorjani,Pomoryany,Pomorzany,Pomorzhany,Поморяни', 49.6409200, 24.9307000, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129644, 'Polyanka', 'Polyanka', 'Poljanka,Polyanka,Polyanki,Полянка', 50.2583600, 27.6880900, 'UA', '2013-02-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129645, 'Poltava', 'Poltava', 'Gorad Paltava,PLV,Poltav,Poltava,Poltavae,Poltave,Poltavo,Poltawa,Połtawa,Pultava,bo er ta wa,bwltafa,poltaba,porutavu~a,pwltawa,pwltbh,Горад Палтава,Полтав,Полтавæ,Полтава,Полтаве,Պոլտավա,פאלטאווע,פולטבה,بولتافا,پولتاوا,პოლტავა,ポルタヴァ,波尔塔瓦,폴타바', 49.5937300, 34.5407300, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129646, 'Polonne', 'Polonne', 'Pollonoye,Polonne,Polonnoje,Polonnoye,Полонне', 50.1242400, 27.5108700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129647, 'Polohy', 'Polohy', 'Chubarovka,Pologi,Pologı,Polohi,Polohy,Polohî,Połohy,bo luo ji,pwlwhy,Пологи,Պոլոգի,פולוהי,پولوهی,პოლოგი,波洛吉', 47.4844400, 36.2536100, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129648, 'Pokrovs’ke', 'Pokrovs''ke', 'Pokrovka,Pokrovs''ke,Pokrovskoe,Pokrovskoye,Pokrovs’ke,Покровское,Покровське', 47.9785200, 36.2256000, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129649, 'Pokotylivka', 'Pokotylivka', 'Pokatilovka,Pokotilivka,Pokotilovka,Pokotylivka,Покотилівка', 49.9134300, 36.1751100, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129650, 'Pohrebyshche', 'Pohrebyshche', 'Pogrebischtsche,Pogrebishche,Pogrebishchenskiy,Pogrebishhe,Pohrebyshche,Погребище', 49.4863900, 29.2636100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129651, 'Pidvolochys’k', 'Pidvolochys''k', 'Pidvolochis''k,Pidvolochys''k,Pidvolochys’k,Podvolochisk,Podvolochiska,Podvolochissk,Podwoloczyska,Podwołoczyska,Підволочиськ', 49.5347200, 26.1458500, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129652, 'Pidvynohradiv', 'Pidvynohradiv', 'Pidvinogradiv,Pidvynohradiv,Podvinogradov,Підвиноградів', 48.1394700, 22.9719400, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129653, 'Pidkamin’', 'Pidkamin''', 'Pidkamien,Pidkamin'',Podkamen'',Podkamen’,Podkamien,Podkamień,Подкамень,Підкамінь', 49.9459900, 25.3167200, 'UA', '2013-02-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129654, 'Pidhirtsi', 'Pidhirtsi', 'Pidgirci,Pidhirtsi,Pidhorodtsi,Podgorcy,Podgortse,Podgortsy,Podhorce,Подгорцы,Підгірці', 49.9461100, 24.9795000, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129655, 'Pidhorodne', 'Pidhorodne', 'Pidgorodne,Pidhorodne,Podgorodnoe,Podgorodnoye,Подгородное,Підгородне', 48.5752800, 35.1068000, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129656, 'Pidhorodna', 'Pidhorodna', 'Pidgorodna,Pidhorodna,Podgorodnaja,Podgorodnaya,Подгородная,Підгородна', 48.1070400, 30.8895300, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129657, 'Pidhaytsi', 'Pidhaytsi', 'Pdace,Pidgajci,Pidhajci,Pidhaytsi,Podgaytse,Podgaytsy,Podhace,Podhaicy,Podhajce,Podhajci,Підгайці', 49.2685300, 25.1334100, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129658, 'Pidbuzh', 'Pidbuzh', 'Pidbuzh,Podbuz,Podbuzh,Podbuż,Подбуж,Підбуж', 49.3348300, 23.2488700, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129659, 'Pochtovoye', 'Pochtovoye', 'Bazarchik,Pochtovoe,Pochtovoye,Poshtove,Базарчи́к,Почтовое,Поштове', 44.8354000, 33.9615900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129660, 'Pochayiv', 'Pochayiv', 'Pochaev,Pochaiv,Pochayev,Pochayiv,Pochayuv Stary,Почаев', 50.0050900, 25.5118300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129661, 'Pobugskoye', 'Pobugskoye', 'Pobugskoe,Pobugskoye,Побугское', 48.1657900, 30.5927400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129662, 'Pobednoye', 'Pobednoye', 'Pobedne,Pobednoe,Pobednoye,Tarkhanlar,Победное,Побєдне,Тарханла́р', 45.7010900, 34.4480500, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129663, 'Pnikut', 'Pnikut', 'Pnikut,Пникут,Пнікут', 49.7110400, 23.1382600, 'UA', '2013-03-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129664, 'Pniv', 'Pniv', 'Pnev,Pniow,Pniv,Pniów,Pnyuv,Пнів', 48.6178300, 24.5287200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129665, 'Plodovoye', 'Plodovoye', 'Azek,Plodove,Plodovoe,Plodovoye,Азе́к,Плодове,Плодовое', 44.8715600, 33.8561500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129666, 'Koktebel', 'Koktebel', 'Koktebel,Koktebel'',Коктебель', 44.9615500, 35.2466000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129667, 'Plakhtiyivka', 'Plakhtiyivka', 'Kletereshti,Plahteevca,Plahtiivka,Plakhteyevka,Plakhtiivka,Plakhtiyevka,Plakhtiyivka,Плахтіївка', 46.1006000, 29.7216900, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129668, 'Pivdenne', 'Pivdenne', 'Pivdenne,Pivdennoe,Pivdennoye,Pivdennyy,Yuzhniy,Yuzhnyy,Пивденное,Південне', 49.8831500, 36.0678500, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129669, 'Pishcha', 'Pishcha', 'Pishcha,Pishha,Piszcza,Пища,Піща', 51.6092800, 23.8207900, 'UA', '2013-02-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129670, 'Pyryatyn', 'Pyryatyn', 'Pirjatin,Piryatin,Pyryatin,Pyryatyn,Пирятин', 50.2424200, 32.5062100, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129671, 'Pionerskoye', 'Pionerskoye', 'Dzholman,Pioners''ke,Pionerskoe,Pionerskoye,Джолма́н,Пионерское,Піонерське', 44.8808300, 34.2019400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129672, 'Pylypets’', 'Pylypets''', 'Pilipec,Pilipec'',Pilipets,Pylypets'',Pylypets’,pylypz,Пилипец,Пилипець,פיליפץ', 48.6676800, 23.3519100, 'UA', '2017-01-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129673, 'Petrivs’ke', 'Petrivs''ke', 'Petrivs''ke,Petrivs’ke,Petrovskaya,Petrovskoe,Petrovskoye,Петровское,Петрівське', 49.1769500, 36.8999900, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129674, 'Petrove', 'Petrove', 'Petrova,Petrove,Petrovo,Петрове,Петрово', 48.3246700, 33.2561700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129675, 'Petrovka', 'Petrovka', 'Petrivka,Petrovka,Петровка,Петрівка', 45.4977600, 34.2881600, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129676, 'Petropavlivka', 'Petropavlivka', 'Petropavlikva,Petropavlivka,Petropavlovka,Петропавловка,Петропавлівка,Петропавліква', 48.4564300, 36.4367000, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129677, 'Petrivka', 'Petrivka', 'Kurisovo,Petrivka,Petrovka,Petrovskoye,Петрівка', 46.9695100, 30.9591400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129678, 'Petrykivka', 'Petrykivka', 'Petrikivka,Petrikovka,Petrykivka,Петриковка,Петриківка', 48.7293300, 34.6335800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129679, 'Petrikov', 'Petrikov', 'Petrikiv,Petrikov,Petrykiv,Петриків', 49.5312200, 25.5790100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129680, 'Petranka', 'Petranka', 'Petranka,Петранка', 48.9024600, 24.3034700, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129681, 'Piskivka', 'Piskivka', 'Peskovka,Peskovskiv Zavod,Piskivka,Пісківка', 50.6937800, 29.6193400, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129682, 'Peschanoye', 'Peschanoye', 'Alma-Tamak,Peschanoe,Peschanoye,Pishhane,Алма́-Тама́к,Песчаное,Піщане', 44.8434200, 33.6092100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129683, 'Pishchanka', 'Pishchanka', 'Peschanka,Peschanki,Pischanka,Pishchanka,Pishhanka,Піщанка', 48.2072700, 28.8860700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129684, 'Peschana', 'Peschana', '', 48.1291800, 29.7308600, 'UA', '2011-08-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129685, 'Pervomayskoye', 'Pervomayskoye', 'Dzhurchi,Gurtcu,Pervomajs''ke,Pervomajskoe,Pervomayskoye,Ğurtču,Джурчи́,Первомайское,Первомайське', 45.7174400, 33.8559600, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129686, 'Pervomays’kyy', 'Pervomays''kyy', 'Pervomajs''kij,Pervomajskij,Pervomays''kyy,Pervomaysk,Pervomayskiy,Pervomays’kyy,Первомайский,Первомайський', 49.3874200, 36.2147100, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129687, 'Pervomayskoye', 'Pervomayskoye', 'Bejtanysh,Pervomajs''ke,Pervomajskoe,Pervomayskoye,Бейтаны́ш,Первомайское,Первомайське', 45.1120700, 34.0647800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129688, 'Pervomays’k', 'Pervomays''k', 'Pervomaika,Pervomaisk,Pervomajs''k,Pervomajsk,Pervomays''k,Pervomaysk,Pervomays’k,Первомайск,Первомайськ', 48.6298800, 38.5480600, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129689, 'Pervomays’k', 'Pervomays''k', 'Pervomaisk,Pervomajs''k,Pervomajsk,Pervomays''k,Pervomays’k,Perwomaisk,Первомайск,Первомайськ', 48.0443300, 30.8507300, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129690, 'Pershotravneve', 'Pershotravneve', 'Pershotravneve,Pershotravnevoye,Першотравневе', 51.3928700, 28.8683700, 'UA', '2012-09-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129691, 'Manhush', 'Manhush', 'Mangush,Manhush,Pershotravneve,Pershotravnevoe,Pershotravnevoye,Pershotravnevyy,Pervomayskoye,Мангуш,Першотравневе,Першотравневое', 47.0558200, 37.3106800, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129692, 'Perovo', 'Perovo', 'Badana,Perove,Perovo,Бадана́,Перове,Перово', 44.9251300, 34.0575300, 'UA', '2016-05-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129693, 'Pereyaslav-Khmel’nyts’kyy', 'Pereyaslav-Khmel''nyts''kyy', 'Perejaslav-Khmel''nic''kij,Perejaslav-Khmel''nickij,Perejaslawl,Pereyaslav,Pereyaslav-Khmel''nitskiy,Pereyaslav-Khmel''nyts''kyy,Pereyaslav-Khmel’nitskiy,Pereyaslav-Khmel’nyts’kyy,Переяслав-Хмельницкий,Переяслав-Хмельницький', 50.0673900, 31.4496900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129694, 'Pereval’s’k', 'Pereval''s''k', 'Pereval''s''k,Pereval''sk,Pereval’sk,Pereval’s’k,Перевальск,Перевальськ', 48.4377900, 38.8438400, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129695, 'Pereval''noye', 'Pereval''noye', 'Angara,Pereval''ne,Pereval''noe,Pereval''noye,Ангара́,Перевальне,Перевальное', 44.8483800, 34.3127100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129696, 'Peresichna', 'Peresichna', 'Peresechnaja,Peresechnaya,Peresechnoye,Peresichna,Пересечная,Пересічна', 50.0245200, 35.9787100, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129697, 'Peremyshlyany', 'Peremyshlyany', 'Peremishljani,Peremyshlyany,Przemysiany,Przemyslany,Przemysliane,Przemyśiany,Przemyślany,Pzhemyslyany,Перемишляни', 49.6652300, 24.5584600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129698, 'Perehonivka', 'Perehonivka', 'Peregonivka,Peregonovka,Perehonivka,Перегоновка,Перегонівка', 48.5355200, 30.5192300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129699, 'Perechyn', 'Perechyn', 'Perechin,Perechyn,Perecin,Perecseny,Perečin,Перечин', 48.7361600, 22.4820000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129700, 'Pechenizhyn', 'Pechenizhyn', 'Pecenizin,Pechenezhin,Pechenizhin,Pechenizhyn,Peczenizyn,Печеніжин', 48.5155100, 24.8942300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129701, 'Pechenihy', 'Pechenihy', 'Pechenegi,Pechenigi,Pechenihy,Печенеги,Печеніги', 49.8716700, 36.9347200, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129702, 'Pavlysh', 'Pavlysh', 'Pavlichi,Pavlish,Pavlysh,Павлиш,Павлыш', 48.9176200, 33.3569100, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129703, 'Pavlivka', 'Pavlivka', 'Pavlivka,Pavlovka,Павловка,Павлівка', 49.6086400, 38.7091700, 'UA', '2013-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129704, 'Pavlovka', 'Pavlovka', 'Pavlivka,Pavlovka,Павловка', 49.4414300, 28.4595600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129705, 'Pavlohrad', 'Pavlohrad', 'Gorad Paulagrad,Pavlogi,Pavlograd,Pavlohrad,Pavlohrada,Pavlohradas,Pawlograd,Pawlohrad,Pawłohrad,ba fu luo ge lei,pabeulloheuladeu,paurofurado,pawlwhrad,Горад Паўлаград,Павлоград,Պավլոգրադ,פאבלוהראד,پاولوهراد,პავლოგრადი,パウロフラード,巴甫洛格勒,파블로흐라드', 48.5342600, 35.8709800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129706, 'Pasichna', 'Pasichna', 'Pasechna,Pasechnaya,Pasichna,Pasicna,Pasieczna,Пасічна', 48.5715200, 24.4300300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129707, 'Parutyne', 'Parutyne', 'Il''inskoye,Parutina,Parutino,Парутино', 46.7053800, 31.8970900, 'UA', '2010-07-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129708, 'Partyzany', 'Partyzany', 'Budennovka,Budenovka,Budënnovka,Partizani,Partizany,Partyzany,Партизани,Партизаны', 46.3338300, 34.7531400, 'UA', '2015-04-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129709, 'Partizanskoye', 'Partizanskoye', 'Orta Sobla,Partizans''ke,Partizanskoe,Partizanskoye,Sabla,Sably,Партизанское,Партизанське,Сабла́,Саблы́', 44.8337900, 34.0846500, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129710, 'Panyutyne', 'Panyutyne', 'Panjutine,Panjutino,Panyutina,Panyutino,Panyutyne,Панютине,Панютино', 48.9369200, 36.2756300, 'UA', '2016-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129711, 'Pantayivka', 'Pantayivka', 'Pantaevka,Pantaivka,Pantayevka,Pantayivka,Пантаевка,Пантаївка', 48.6740000, 32.8841000, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129712, 'Ozerne', 'Ozerne', 'Ozerne,Ozernoye,Ozërnoye,Озерне', 50.1781600, 28.7338400, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129713, 'Ozerne', 'Ozerne', 'Babel'',Babele,Babel’,General Al Averescu,General-Averesku,Ozerne,Ozernoye,Ozërnoye,Озерне', 45.4030000, 28.6754600, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129714, 'Ozerna', 'Ozerna', 'Jezierna,Ozerna,Ozernaja,Ozernaya,Ozernyani,Ozernyany,Ozërnaya,Yezerna,Озерна,Озерная', 49.6289100, 25.3289500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129715, 'Ovruch', 'Ovruch', 'Gorad Ouruch,Ovroutch,Ovruc,Ovruch,Ovruci,Ovrucs,Ovruts,Ovrutsj,Ovrutš,Ovruç,Ovruč,Owrucz,Owrutsch,ao fu lu qi,awwrwch,ovuruchi,Горад Оўруч,Овруч,Օվրուչ,אוורוטש,اووروچ,オーヴルチ,奧夫魯奇', 51.3246000, 28.8035100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129716, 'Ovidiopol’', 'Ovidiopol''', 'Ovidiopol,Ovidiopol'',Ovidiopol’,Owidiopol,Овидио́поль,Ові́діополь', 46.2499800, 30.4412700, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129717, 'Otyniya', 'Otyniya', 'Otinia,Otinija,Ottunia,Ottynia,Ottynya,Otyniya,Otynya,Отинія', 48.7376700, 24.8611100, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129718, 'Ostrovskoye', 'Ostrovskoye', 'Kijat,Ostrovs''ke,Ostrovskoe,Ostrovskoye,Кия́т,Островское,Островське', 45.7423200, 34.0660700, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129719, 'Ostroh', 'Ostroh', 'Gorad Astrog,Ostrog,Ostroh,Ostroha,Ostrohas,Ostrug,Ostróg,Osztroh,ao si te luo he,awstrwh,osutorofu,Горад Астрог,Острог,Օստրոգ,אוסטרוה,اوستروه,ოსტროგი,オストロフ,奧斯特羅赫', 50.3294200, 26.5142500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129720, 'Oster', 'Oster', 'Oster,Ostjor,Ostër,Остер', 50.9506000, 30.8822900, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129721, 'Osypenko', 'Osypenko', 'Novospasovka,Novospasovskaya,Novospasskoye,Osipenko,Osypenko,Осипенко', 46.9136000, 36.8253000, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129722, 'Orzhytsya', 'Orzhytsya', 'Orzhica,Orzhicja,Orzhitsa,Orzhytsya,Оржица,Оржиця', 49.7901000, 32.6994100, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129723, 'Orlovskoye', 'Orlovskoye', 'Baj-Bolush,Orlivs''ke,Orlovskoe,Orlovskoye,Syrt-Bij-Bolush,Бай-Болу́ш,Орловское,Орлівське,Сырт-Бий-Болу́ш', 45.8107000, 33.9730800, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129724, 'Orlinoye', 'Orlinoye', 'Bajdar,Bajdary,Orline,Orlinoe,Orlinoye,Байда́ры,Орлине,Орлиное', 44.4468500, 33.7758800, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129725, 'Orikhiv', 'Orikhiv', 'Orechoff,Orechowka,Orekhov,Orihiv,Orikhiv,Оріхів', 47.5673100, 35.7857500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129726, 'Ordzhonikidze', 'Ordzhonikidze', 'Aleksandrovka,Aleksandrovka Number 2,Imeni Ordzhonikidze,Krepatskoye,Ordzhonikidze,Орджоникидзе,Орджонікідзе', 47.6676300, 34.0595700, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129727, 'Ordzhonikidze', 'Ordzhonikidze', 'Ordzhonikidze,Орджоникидзе,Орджонікідзе', 44.9640100, 35.3557600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129728, 'Orativ', 'Orativ', 'Orativ,Oratov,Oratovo,Оратів', 49.1888900, 29.5269700, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129729, 'Oposhnya', 'Oposhnya', 'Oposhnja,Oposhnya,Опошня', 49.9565200, 34.6122600, 'UA', '2011-02-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129730, 'Onufriyivka', 'Onufriyivka', 'Onufrievka,Onufriivka,Onufriyevka,Onufriyivka,Онуфриевка,Онуфріївка', 48.9071600, 33.4486900, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129731, 'Onokivtsi', 'Onokivtsi', 'Onokivci,Onokivtsi,Onokovcy,Onokovtse,Onokovtsy,Оноковцы,Оноківці', 48.6576300, 22.3418300, 'UA', '2012-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129732, 'Olyka', 'Olyka', 'Olika,Olyka,Ołyka,Олика', 50.7185500, 25.8125100, 'UA', '2013-12-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129733, 'Ol''shanskoye', 'Ol''shanskoye', 'Ol''shans''ke,Olshanske,Olshanskiy,Ольшанське', 47.1841100, 31.7937500, 'UA', '2007-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129734, 'Vil’shanka', 'Vil''shanka', 'Ol''shanka,Olschanka,Ol’shanka,Vil''shanka,Vil’shanka,Вільшанка,Ольшанка', 48.2360400, 30.8760800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129735, 'Olyshivka', 'Olyshivka', 'Olischewka,Olishevka,Olishivka,Olishëvka,Olyshivka,Олишевка,Олишівка', 51.2226600, 31.3331400, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129736, 'Olevs’k', 'Olevs''k', 'Olevs''k,Olevsk,Olevs’k,Олевськ', 51.2248200, 27.6522800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129737, 'Olesko', 'Olesko', 'Oles''ko,Olesko,ao lie xi ke,Олеско,Олесько,אולסקו,奧列西科', 49.9623300, 24.8933600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129738, 'Oleshnyk', 'Oleshnyk', 'Egres,Egresh,Oleshnik,Oleshnyk,Олешник', 48.1640600, 22.9616700, 'UA', '2014-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129739, 'Oleksandriya', 'Oleksandriya', 'Aleksandria,Aleksandrija,Aleksandriya,Alexandrija Pervaya,Oleksandrija,Oleksandriya,Александрия,Олександрия,Олександрія', 48.6696100, 33.1159300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129740, 'Oleksandrivka', 'Oleksandrivka', 'Aleksandrovka,Oleksandrivka,Александровка,Олександрівка', 48.9633600, 32.2349200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129741, 'Okunevka', 'Okunevka', 'Beshi,Okunevka,Okunivka,Okunjovka,Tarpanchi,Беши́,Окунёвка,Окунівка,Тарпанчи́', 45.3685500, 32.7635700, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129742, 'Oktyabr’skoye', 'Oktyabr''skoye', 'Judendorf,Oktjabr''skoe,Oktjabrs''ke,Oktyabr''skoye,Oktyabr’skoye,Октябрське,Октябрьское,Юдендо́рф', 45.6553100, 33.9491800, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129743, 'Oktyabr''skoye', 'Oktyabr''skoye', 'Oktjabr''skoe,Oktjabrs''ke,Oktyabr''skoye,Октябрське,Октябрьское', 45.3621500, 36.3680300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129744, 'Oktyabr’skoye', 'Oktyabr''skoye', 'Bijuk-Onlar,Buejuek Oniar,Büjük Oniar,Oktjabr''skoe,Oktjabrs''ke,Oktyabr''skoye,Oktyabr’skoye,Бию́к-Онла́р,Октябрське,Октябрьское', 45.2886600, 34.1352100, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129745, 'Okhotskoye', 'Okhotskoye', 'Alikech,Okhots''ke,Okhotskoe,Okhotskoye,Алике́ч,Охотское,Охотське', 45.4861200, 34.8640100, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129746, 'Okhotnikovo', 'Okhotnikovo', 'Dzhaga-Kushhu,Okhotnikove,Okhotnikovo,Джага́-Кущу́,Охотникове,Охотниково', 45.2398500, 33.5940500, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129747, 'Odessa', 'Odessa', 'Ades,Gorad Adehsa,ODS,Odesa,Odess,Odessa,Odessa osh,Odessae,Odesse,Odessos,Odessus,Odessza,Odissos,Oděsa,Udessa,ao de sa,awdsa,awdysa,odesa,odessa,Ódessa,Οδησσός,Горад Адэса,Одеса,Одесс,Одессæ,Одесса,Одесса ош,Одессе,Օդեսա,אדעס,אודסה,أوديسا,اودسا,اوديسا,اودیسا,ओदेसा,အိုဒက်ဆာမြို့,ოდესა,オデッサ,敖德薩,오데사', 46.4774700, 30.7326200, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129748, 'Ochakiv', 'Ochakiv', 'Gorad Achakau,OEzi,Ocakiv,Ocakiva,Ocakivas,Ocakiw,Ocakov,Oceac,Ochakiv,Ochakov,Oczakow,Oczaków,Otchakiv,Otschakiw,Otschakow,Otsjakiv,Otxakiv,Otxàkiv,Oçakiv,Oĉakiv,Očakiv,Očakiva,Očakivas,Očakiw,Očakov,ao qia ji fu,awchakyf,Özi,Горад Ачакаў,Очаков,Очаків,Օչակով,אוצקיב,اوچاکیف,ოჩაკოვი,奧恰基夫', 46.6128300, 31.5498200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129749, 'Obukhiv', 'Obukhiv', 'Oboukhiv,Obuchiv,Obuchiw,Obuchow,Obuchów,Obuh''iv,Obuhiv,Obuhiva,Obuhov,Obuh’iv,Obukhiv,Obukhov,Obuxov,ao bu xi fu,awbwkyf,obukhovi,Обухив,Обухов,Обухів,Օբուխով,اوبوکیف,ობუხოვი,奧布希夫', 50.1068900, 30.6184800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129750, 'Obroshyne', 'Obroshyne', 'Obroshin,Obroshine,Obroshino,Obroshyne,Оброшин,Оброшине', 49.7833300, 23.8666700, 'UA', '2009-02-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129751, 'Obodivka', 'Obodivka', 'Obodivka,Obodovka,Obodovka Novaya,Ободівка', 48.4051400, 29.2477500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129752, 'Obertyn', 'Obertyn', 'Obertin,Obertyn,Обертин', 48.7003200, 25.1701200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129753, 'Nyrkiv', 'Nyrkiv', 'Nirkiv,Nyrkov,Nyrkow,Nyrkuv,Nyrków,Нирків,Нырков', 48.8149200, 25.5998900, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129754, 'Nuyno', 'Nuyno', 'Nujno,Nuyno,Нуйно', 51.5462800, 24.9101800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129755, 'Novyy Yarychiv', 'Novyy Yarychiv', 'Jarychow,Jaryczow,Jaryczow Nowy,Jaryczów,Jaryczów Nowy,Novij Ariciv,Novyy Yarychev,Novyy Yarychiv,Yarychev Novy,Yarychev Novyy,Yarychuv,Новий Яричів', 49.9044400, 24.3052300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129756, 'Novyy Svit', 'Novyy Svit', 'Nov.Svet,Novij Svit,Novy Svet,Novyy Svet,Novyy Svit,Нов.Свет,Новий Світ', 47.8059100, 38.0211200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129757, 'Novy Svet', 'Novy Svet', 'Novij Svit,Novy Svet,Novyj Svet,Новий Світ,Новый Свет', 44.8308700, 34.9137000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129758, 'Novyy Starodub', 'Novyy Starodub', 'Nov.Starodub,Novij Starodub,Novo-Starodub,Novy Starodub,Novyy Starodub,Нов.Стародуб,Новий Стародуб', 48.5158000, 33.1732900, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129759, 'Novi Troyany', 'Novi Troyany', 'Novi Troani,Novi Trojani,Novi Troyany,Novo Traian,Novo Trajan,Novotroyan,Novyye Troyany,Traian,Traianul-Nou,Trayan,Trayanu,Нові Трояни', 45.9427500, 28.8562800, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129760, 'Novi Sanzhary', 'Novi Sanzhary', 'Nov.Sanzhary,Novi Sanzari,Novi Sanzhari,Novi Sanzhary,Novi Senzhari,Novo-Senzhary,Novyye Sanzhary,Novyye Senzhary,Нов.Санжары,Нові Санжари', 49.3439500, 34.3108400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129761, 'Novi Petrivtsi', 'Novi Petrivtsi', 'Novi Petrivci,Novi Petrivtsi,Novopetrovtsy,Novye Petrovcy,Novye Petrovtsy,Novyye Petrovtsy,Новые Петровцы,Нові Петрівці', 50.6275400, 30.4431000, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129762, 'Novi Bilokorovychi', 'Novi Bilokorovychi', 'Novi Bilokorovichi,Novi Bilokorovici,Novi Bilokorovychi,Novyye Belokorovichi,Novyye Belorovichi,Нові Білокоровичі', 51.1154800, 28.0546300, 'UA', '2012-08-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129763, 'Novyy Buh', 'Novyy Buh', 'Novi Bug,Novij Bug,Novo Bug,Novy Bug,Novyy Bug,Novyy Buh,Nowyi Bug,Новий Буг', 47.6930800, 32.5216000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129764, 'Novozhilovka', 'Novozhilovka', 'Besharan-Otar,Novozhilivka,Novozhilovka,Бешара́н-Ота́р,Новожиловка,Новожилівка', 45.1596000, 34.2327000, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129765, 'Nove Davydkovo', 'Nove Davydkovo', 'Nove Davidkovo,Nove Davydkove,Nove Davydkovo,Novoye Davidkovo,Novoye Davydkovo,Нове Давидково', 48.4413300, 22.6216400, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129766, 'Dubki', 'Dubki', 'Dubki,Novoe Budke,Дубки,Но́вое Будке́', 44.9358100, 34.0235500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129767, 'Novovorontsovka', 'Novovorontsovka', 'Novaya Vorontsovka,Novovoroncovka,Novovorontsovka,Нововоронцовка', 47.5003500, 33.9174800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129768, 'Novovolyns’k', 'Novovolyns''k', 'Novovolins''k,Novovolyns''k,Novovolynsk,Novovolynskiy,Novovolyns’k,Нововолинськ,Нововолынск', 50.7257600, 24.1626500, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129769, 'Novovasylivka', 'Novovasylivka', 'Novovasil''yevka,Novovasilevka,Novovasilivka,Novovasil’yevka,Novovasylivka,Нововасилевка,Нововасилівка', 46.8302100, 35.7513600, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129770, 'Novoukrayinka', 'Novoukrayinka', 'Novo-Urainka,Novoukrainka,Novoukrainsk,Novoukrayinka,Новоукраинка,Новоукраїнка', 48.3263500, 31.5285200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129771, 'Novotroyits’ke', 'Novotroyits''ke', 'Novotroic''ke,Novotroickoe,Novotroitskoye,Novotroyits''ke,Novotroyits’ke,Новотроицкое,Новотроїцьке', 46.3556000, 34.3327200, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129772, 'Novostepnoye', 'Novostepnoye', 'Novo-Dzhankoj,Novostepnoe,Novostepnoye,Novostepove,Но́во-Джанко́й,Новостепное,Новостепове', 45.6620600, 34.3870000, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129773, 'Novoselovskoye', 'Novoselovskoye', 'Frajdorf,Novoselivs''ke,Novoselovskoye,Novosjolovskoe,Новоселівське,Новосёловское,Фрайдорф', 45.4427600, 33.5979500, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129774, 'Novosyolovka', 'Novosyolovka', 'Novoselivka,Novosjolovka,Novosyolovka,Новоселівка,Новосёловка', 44.9937700, 33.8352500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129775, 'Novoselytsya', 'Novoselytsya', 'Bol''shaya Novoselitsa,Bol''shiye Novoselitsy,Bol’shaya Novoselitsa,Bol’shiye Novoselitsy,Novoselica,Novoselicja,Novoselitsa,Novoselytsya,Velikaya Novoselitsa,Новоселица,Новоселиця', 50.0703000, 27.5195500, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129776, 'Novoselytsya', 'Novoselytsya', 'Noua Sulitsa,Novoselicja,Novoselitsa,Novoselytsya,Sulita,Sulitsa-Noua,Sulitsa-Nova,Suliţa,Новоселиця', 48.2193100, 26.2653100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129777, 'Novopskov', 'Novopskov', 'Novopskov,Новопсков', 49.5464000, 39.0898700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129778, 'Novopokrovka', 'Novopokrovka', 'Novo Pokrovzkoye,Novo-Pokrovskoye,Novopokrovka,Новопокровка', 49.8334900, 36.5477100, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129779, 'Novopokrovka', 'Novopokrovka', 'Novopokrovka,Pokrovskaya,Новопокровка', 48.0591800, 34.6061900, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129780, 'Novopokrovka', 'Novopokrovka', 'Buzavchi,Novopokrovka,Бузавчи́,Новопокровка', 45.4219800, 34.4505200, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129781, 'Poltavka', 'Poltavka', 'Novopokrovka,Poltavka,Новопокро́вка,Полтавка', 45.3513300, 34.1837100, 'UA', '2016-07-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129782, 'Novopavlovka', 'Novopavlovka', 'Novopavlivka,Novopavlovka,Новопавловка,Новопавлівка', 45.8663400, 33.8901800, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129783, 'Novomykolayivka', 'Novomykolayivka', 'Novomikolaivka,Novomykolayivka,Novonikolaevka,Novonikolayevka,Новомиколаївка,Новониколаевка', 48.5562500, 34.3739900, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129784, 'Novomykolayivka', 'Novomykolayivka', 'Novomikolaivka,Novomykolayivka,Novonikolayevka,Новомиколаївка', 47.9781000, 35.9102000, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129785, 'Novonikolayevka', 'Novonikolayevka', 'Kachan,Kachan-Besh-Kuju,Novomikolaivka,Novonikolaevka,Novonikolayevka,Кача́н,Кача́н-Беш-Кую́,Новомиколаївка,Новониколаевка', 45.3085500, 36.0574900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129786, 'Novomoskovs’k', 'Novomoskovs''k', 'Novomoskovs''k,Novomoskovsk,Novomoskovs’k,Новомосковск,Новомосковськ', 48.6379900, 35.2454800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129787, 'Novomyrhorod', 'Novomyrhorod', 'Novomirgorod,Novomirhorod,Novomyrhorod,Novomîrhorod,Novomırgorod,Novomırhorod,Nowomyrhorod,novomirgorodi,nwbwmyrhwrwd,nwwwmyrhwrwd,xin mi er huo luo de,Новомиргород,Նովոմիրգորոդ,נובומירהורוד,نووومیرهورود,ნოვომირგოროდი,新米爾霍羅德', 48.7810500, 31.6420400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129788, 'Novokrymskoye', 'Novokrymskoye', 'Borlak-Tama,Burlaq,Novokrims''ke,Novokrymskoe,Novokrymskoye,Борла́к-Тама́,Новокримське,Новокрымское', 45.7800700, 34.1554300, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129789, 'Novoivanovka', 'Novoivanovka', 'Novoivanivka,Novoivanovka,Новоiванiвка,Новоивановка', 45.4491400, 33.0983300, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129790, 'Novohrad-Volyns’kyy', 'Novohrad-Volyns''kyy', 'Novograd Volynski,Novograd-Volins''kij,Novograd-Volynsk,Novograd-Volynskij,Novograd-Volynskiy,Novohrad-Volyns''kyy,Novohrad-Volyns’kyy,Nowograd Wolynsk,Nowogrod Wolynski,Nowogród Wołyński,Zvyagel'',Zvyagel’,Zvydgel,Zwiahl,nwbwhrd-wwlynsqy,Новоград-Волинський,Новоград-Волынский,נובוהרד-וולינסקי', 50.5941200, 27.6165000, 'UA', '2016-12-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129791, 'Novogrigoryevka', 'Novogrigoryevka', 'Novogrigor''evka,Novogrigorivka,Novogrigoryevka,Новогригорьевка,Новогригорівка', 45.4520000, 34.6037800, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129792, 'Novofedorivka', 'Novofedorivka', 'Novaya Fedorovka,Novofedorivka,Novofedorovka,Новофедоровка,Новофедорівка', 46.1712800, 32.3178100, 'UA', '2017-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129793, 'Novodonets’ke', 'Novodonets''ke', 'Novodonec''ke,Novodoneckoe,Novodonets''ke,Novodonetskoye,Novodonets’ke,Новодонецкое,Новодонецьке', 48.6352600, 36.9847700, 'UA', '2016-03-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129794, 'Voskhod', 'Voskhod', 'Najleben,Voskhod,Восход,Найле́бен', 45.5099900, 34.3935500, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129795, 'Novodnistrovs’k', 'Novodnistrovs''k', 'Novodnestrovsk,Novodnistrovs''k,Novodnistrovs’k,Новоднестровск', 48.5864100, 27.3815200, 'UA', '2014-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129796, 'Novobohdanivka', 'Novobohdanivka', 'Novaya Bogdanovka,Novobogdanivka,Novobogdanovka,Novobohdanivka,Новобогданівка', 47.0852400, 35.3294500, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129797, 'Novoazovs''k', 'Novoazovs''k', 'Budennovka,Budennowka,Budenovka,Budyanovka,Budyenovka,Budënnovka,Novoazovs''k,Novoazovsk,Novoazovskoye,Novonikolayevskaya,Nowo-Nikolajewskaja,Новоазовск', 47.1138900, 38.0859900, 'UA', '2010-06-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129798, 'Novoaydar', 'Novoaydar', 'Novoajdar,Novoaydar,Новоайдар', 48.9639100, 39.0058300, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129799, 'Novoarkhanhel’s’k', 'Novoarkhanhel''s''k', 'Archangorod,Arkhangorod,Novoarkhangel''s''k,Novoarkhangel''sk,Novoarkhangel’sk,Novoarkhanhel''s''k,Novoarkhanhel’s’k,Архангород,Новоархангельск,Новоархангельськ', 48.6580300, 30.8182100, 'UA', '2017-05-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129800, 'Novoandreyevka', 'Novoandreyevka', 'Kashik-Degirmen,Novoandreevka,Novoandreyevka,Novoandriivka,Каши́к-Дегирме́н,Новоандреевка,Новоандріївка', 45.1990400, 34.0938400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129801, 'Novooleksiyivka', 'Novooleksiyivka', 'Novo-Ukrainka,Novoalekseevka,Novoalekseyevka,Novooleksiivka,Novooleksiyivka,Novyy Gorodok,Новоалексеевка,Новоолексіївка', 46.2247200, 34.6403100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129802, 'Novytsya', 'Novytsya', 'Novicja,Novitsa,Novytsya,Новиця', 48.9634500, 24.3354200, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129803, 'Novhorod-Sivers’kyy', 'Novhorod-Sivers''kyy', 'Novgorod-Seversk,Novgorod-Severskij,Novgorod-Severskiy,Novgorod-Sivers''kij,Novhorod-Sivers''kyy,Novhorod-Sivers’kyy,Novogorod-Severskiy,Nowgorod Sewerski,Новгород-Северский,Новгород-Сіверський', 52.0057700, 33.2615000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129804, 'Novhorodka', 'Novhorodka', 'Novgorodka,Novhorodka,Новгородка', 48.3650600, 32.6578500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129805, 'Nove-Misto', 'Nove-Misto', 'Nove Misto,Nove-Misto,Нове Місто', 48.9811300, 29.8281300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129806, 'Nova Vodolaha', 'Nova Vodolaha', 'Nov.Vodolaga,Nova Vodolaga,Nova Vodolaha,Novaya Vodolaga,Нов.Водолага,Нова Водолага', 49.7190100, 35.8657800, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129807, 'Nova Praha', 'Nova Praha', 'Nov.Praga,Nova Praga,Nova Praha,Novaya Praga,Нов.Прага,Нова Прага', 48.5682100, 32.9027300, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129808, 'Novopokrovka', 'Novopokrovka', 'Novaya Pokrovka,Novopokrovka,Новопокровка', 45.1651700, 35.2530400, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129809, 'Nova Odesa', 'Nova Odesa', 'Fedorovka,Nova Odesa,Novaja Odessa,Novaya Odessa,Нова Одеса,Новая Одесса', 47.3077800, 31.7850600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129810, 'Nova Mayachka', 'Nova Mayachka', 'Bol''shaya Mayachka,Bol’shaya Mayachka,Nova Majachka,Nova Mayachka,Novaja Majachka,Novaya Mayachka,Нова Маячка,Новая Маячка', 46.5999600, 33.2270700, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129811, 'Nova Kakhovka', 'Nova Kakhovka', 'Naujoji Kachovka,Nova Kachovka,Nova Kahovka,Nova Kajovka,Nova Kakhovka,Novaja Kakhovka,Novaya Kakhova,Novaya Kakhovka,Novaya Kaxovka,Novo Kakhovka,Nowa Kachowka,nobakahouka,nwbh qhwbqh,nwwa kakhwfka,xin ka huo fu ka,Нова Каховка,Новая Каховка,Նովայա Կախովկա,נובה קחובקה,نووا کاخوفکا,ნოვაია-კახოვკა,新卡霍夫卡,노바카호우카', 46.7545100, 33.3486400, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129812, 'Novoestoniya', 'Novoestoniya', 'Novaja Ehstonija,Novaya Estoniya,Novoestonija,Novoestoniya,Но́вая Эсто́ния,Новоестонія', 45.4996000, 34.2429800, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129813, 'Nova Borova', 'Nova Borova', 'Nova Borova,Novaya Borovaya,Novaya Borovaya Rudnya,Нова Борова', 50.6929600, 28.6344600, 'UA', '2013-03-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129814, 'Nova Ushytsya', 'Nova Ushytsya', 'Nova Ushicja,Nova Ushytsya,Novaya Ushitsa,Нова Ушиця', 48.8371600, 27.2743400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129815, 'Nosivka', 'Nosivka', 'Nosivka,Nosovka,Nosowka,Носовка,Носівка', 50.9315200, 31.5828200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129816, 'Nyzy', 'Nyzy', 'Nizi,Nizy,Nyzy,Низи,Низы', 50.7828100, 34.7844100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129817, 'Nizhyn', 'Nizhyn', 'Gorad Nezhyn,Neshin,Nezhin,Nezin,Niezyn,Nieżyn,Nijin,Nijino,Nijyn,Nijîn,Nijın,Nischyn,Nizhin,Nizhyn,Nizin,Nizjyn,Nizon,Nizyn,Nizynas,Niĵino,Nižyn,Nižynas,Nižõn,nie ren,nyzhyn,Горад Нежын,Нежин,Нижин,Ніжин,Нїжин,Նեժին,نیژین,涅任', 51.0480100, 31.8868800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129818, 'Nyzhnya Krynka', 'Nyzhnya Krynka', 'Nizhnja Krinka,Nizhnyaya Krinka,Nizhnyaya Krynka,Nyzhnya Krynka,Нижня Кринка', 48.1135000, 38.1606400, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129819, 'Nyzhnya Duvanka', 'Nyzhnya Duvanka', 'Nishnjaja Duwanka,Nizhnja Duvanka,Nizhnjaja Duvanka,Nizhnyaya Duvanka,Nyzhnya Duvanka,Нижня Дуванка,Нижняя Дуванка', 49.5846400, 38.1742900, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129820, 'Nyzhni Sirohozy', 'Nyzhni Sirohozy', 'Nizhni Sirogozi,Nizhnie Serogozy,Nizhniye Serogozy,Nizni Sirogozi,Nyzhni Sirohozy,Нижние Серогозы,Нижні Сірогози', 46.8484200, 34.3804400, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129821, 'Nyzhnye Selyshche', 'Nyzhnye Selyshche', 'Nizhne Selishhe,Nizhne Selisht''ye,Nizhne Selisht’ye,Nizhnee Selishhe,Nizhneye Selishche,Nyzhnye Selyshche,Нижнее Селище,Нижнє Селище', 48.1991100, 23.4475700, 'UA', '2012-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129822, 'Nizhnegorskiy', 'Nizhnegorskiy', 'Nizhn''ogirs''kij,Nizhnegorskij,Nizhnegorskiy,Seitler,Нижнегорский,Нижньогірський,Сеитле́р', 45.4478900, 34.7383900, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129823, 'Nikopol’', 'Nikopol''', 'Nikopol,Nikopol'',Nikopol’,Никополь,Нікополь', 47.5711900, 34.3963700, 'UA', '2016-05-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129824, 'Mykolayivka', 'Mykolayivka', 'Mikolaivka,Mykolayivka,Nikolayevka,Nikolayevka Vtoraya,Миколаївка', 47.5413500, 30.7561500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129825, 'Nikolayevka', 'Nikolayevka', 'Mikolaivka,Nikolaevka,Nikolayevka,Миколаївка,Николаевка', 44.9621300, 33.6106100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129826, 'Nevyts’ke', 'Nevyts''ke', 'Nevic''ke,Nevickoe,Nevitske,Nevitskoye,Nevyts''ke,Nevyts’ke,Невицкое,Невицьке', 48.6747200, 22.3881300, 'UA', '2012-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129827, 'Netishyn', 'Netishyn', 'Neteshin,Netishin,Netishyn,Netisin,Solov''ye Goryn'',Solov’ye Goryn’,Нетешин,Нетішин', 50.3400400, 26.6417100, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129828, 'Neresnytsya', 'Neresnytsya', 'Neresnicja,Neresnitsa,Neresnytsya,Nizhnya Novoselitsa,Novoselice,Novoselitsa,Нересниця', 48.1181400, 23.7658800, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129829, 'Nemyriv', 'Nemyriv', 'Nemiriv,Nemirov,Nemyriv,Немирів', 48.9707600, 28.8377900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129830, 'Nelipyno', 'Nelipyno', 'Nelepino,Nelipino,Nelipyne,Nelipyno,Неліпино', 48.5610100, 23.0314600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129831, 'Nekrasovka', 'Nekrasovka', 'Kulchora[,Nekrasovka,Кулчора́[,Некрасовка', 45.4408500, 34.9858400, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129832, 'Nedryhayliv', 'Nedryhayliv', 'Nedrigajliv,Nedrigajlov,Nedrigaylov,Nedryhayliv,Недригайлов,Недригайлів', 50.8339800, 33.8762600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129833, 'Nebyliv', 'Nebyliv', 'Nebiliv,Nebyliv,Nebylov,Nebyluv,Небилів', 48.8152600, 24.2165700, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129834, 'Naydenovka', 'Naydenovka', 'Najd''onivka,Najdjonovka,Naydenovka,Tabuldy,Найдьонівка,Найдёновка,Табулды́', 45.2708800, 34.4489800, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129835, 'Navariya', 'Navariya', 'Navaria,Navarija,Navariya,Навария,Наварія', 49.7495200, 23.9274600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129836, 'Nasypnoe', 'Nasypnoe', 'Nasipne,Nasypkoj,Nasypnoe,Nasypnoye,Насипне,Насыпко́й,Насыпное', 45.0528500, 35.2941500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129837, 'Narodychi', 'Narodychi', 'Bolshie Narodichi,Narodichi,Narodici,Naroditschi,Narodychi,Народичі', 51.2028600, 29.0822800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129838, 'Nadvirna', 'Nadvirna', 'Naduvrna,Nadvirna,Nadvorna,Nadvornaja,Nadvornaya,Nadwirna,Nadworna,Nadwórna,na de wo er na ya,nadvornaia,nadwyrna,ndbwrnh,Надвирна,Надворная,Надвірна,Նադվորնայա,נאדווערנע,נדבורנה,نادویرنا,ნადვორნაია,納德沃爾納亞', 48.6348000, 24.5693600, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129839, 'Mysovoe', 'Mysovoe', 'Kazantip,Misove,Mysovoe,Казанти́п,Мисове,Мысовое', 45.4478800, 35.8352800, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129840, 'Shchyolkino', 'Shchyolkino', 'Shchyolkino,Shhjolkino,Shholkine,Щолкіне,Щёлкино', 45.4298500, 35.8225000, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129841, 'Mykolayiv', 'Mykolayiv', 'Mikolaiv,Mikolajow,Mikolayuv,Mikotajow,Mikotajów,Mikołajów,Mykolayiv,Nikolaev,Nikolayev,Миколаїв,Николаев', 49.5237200, 23.9852200, 'UA', '2017-01-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129842, 'Mykolayiv', 'Mykolayiv', 'Mikolaiv,Mykolaiv,Mykolayiv,NLV,Nikolaev,Nikolajew,Nikolayev,Vernoleninsk,Верноленинск,Миколаїв,Николаев', 46.9659100, 31.9974000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129843, 'Muzhiyevo', 'Muzhiyevo', 'Muzhievo,Muzhiyeve,Muzhiyevo,Muzhiyovo,Nagy-Muzsaly,Nagymuzsaly,Velikoye Muzhiyovo,Мужиево,Мужієво', 48.1795900, 22.6994300, 'UA', '2017-04-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129844, 'Muskatnoye', 'Muskatnoye', 'Adargin Nemeckij,Muskatne,Muskatnoe,Muskatnoye,Адарги́н Неме́цкий,Мускатне,Мускатное', 45.4658600, 34.5431600, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129845, 'Murovani Kurylivtsi', 'Murovani Kurylivtsi', 'Murovani Kurilivci,Murovani Kurylivtsi,Murovano-Kurilovtsy,Murovany-Kurilovtsy,Murovanye Kurilovtsy,Murovanyye Kurilovtsy,Муровані Курилівці', 48.7234800, 27.5189200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129846, 'Murovane', 'Murovane', 'Laszki Murowane,Lyashki Muravane,Lyashki Murovany,Murovane,Murovanoe,Murovanoye,Murovany,Муроване,Мурованое', 49.5214300, 22.9367000, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129847, 'Mukacheve', 'Mukacheve', 'Mikachevo,Mukaceve,Mukacevo,Mukacheve,Mukachevo,Mukaczewo,Mukatschewe,Mukačeve,Mukačevo,Munkacevo,Munkachevo,Munkacs,Munkačevo,Munkács,Мукачеве,Мукачево,מונקאטש,מונקאץ''', 48.4391900, 22.7177900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129848, 'Mostys''ka', 'Mostys''ka', 'Mos''tsiska,Mosciska,Mostis''ka,Mostiska,Mostys''ka,Mostys’ka,Mos’tsiska,Mościska,Мостиска,Мостиська', 49.7946700, 23.1507700, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129849, 'Mospyne', 'Mospyne', 'Mospine,Mospino,Mospyne,Моспине,Моспино', 47.8908100, 38.0639500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129850, 'Moshny', 'Moshny', 'Dudnitskoye,Moshni,Moshny,Мошни,Мошны', 49.5147300, 31.7475700, 'UA', '2010-12-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129851, 'Morskoye', 'Morskoye', 'Kapsikhor,Mors''ke,Morskoe,Morskoye,Капсихо́р,Морское,Морське', 44.8259300, 34.8031400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129852, 'Morshyn', 'Morshyn', 'Morshin,Morshyn,Morsztyn,Morszyn,Моршин', 49.1565200, 23.8723200, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129853, 'Monastyrys’ka', 'Monastyrys''ka', 'Monasterzhyska,Monasterzyska,Monastezhiska,Monastiris''ka,Monastyriska,Monastyrys''ka,Monastyrys’ka,Монастириська', 49.0890900, 25.1732700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129854, 'Monastyryshche', 'Monastyryshche', 'Monastirishhe,Monastyrishche,Monastyryshche,Монастирище', 48.9909000, 29.8047000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129855, 'Molodohvardiys’k', 'Molodohvardiys''k', 'Molodogvardejsk,Molodogvardejskoe,Molodogvardeysk,Molodogvardeyskoye,Molodogvardijs''k,Molodohvardiys''k,Molodohvardiys’k,Молодогвардейск,Молодогвардейское,Молодогвардійськ', 48.3451100, 39.6524400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129856, 'Molodiya', 'Molodiya', 'Cosmin,Kosmin,Molodia,Molodiya,Plaiul Cosmin,Молодія', 48.2232600, 26.0213900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129857, 'Molodizhne', 'Molodizhne', 'Molodezhnoe,Molodezhnoye,Molodizhne,Molodizne,Molodëzhnoye,Молодежное,Молодіжне', 48.1773200, 32.6601500, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129858, 'Molodyozhnoye', 'Molodyozhnoye', 'Molodizhne,Molodjozhnoe,Molodyozhnoye,Молодёжное,Молодіжне', 45.0035400, 34.0563400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129859, 'Molochnoye', 'Molochnoye', 'Molochne,Molochnoe,Molochnoye,Terekly-Konrat,Молочне,Молочное,Тереклы-Конра́т', 45.1996000, 33.2223300, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129860, 'Mohyliv-Podil’s’kyy', 'Mohyliv-Podil''s''kyy', 'Mogilev-Podol''skij,Mogilev-Podol''skiy,Mogiliv-Podil''s''kij,Mogilov Podolski,Mogilëv-Podol’skiy,Mohyliv-Podil''s''kyy,Mohyliv-Podil’s’kyy,Могилев-Подольский,Могилів-Подільський', 48.4459800, 27.7982000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129861, 'Mlyniv', 'Mlyniv', 'Mliniv,Mlinov,Mlyniv,Mlynuv,Млинів', 50.5090000, 25.6167500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129862, 'Mleyev', 'Mleyev', 'Mleyev,Mleyevo,Mliev,Млиев', 49.3443400, 31.5339000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129863, 'Mizoch', 'Mizoch', 'Mizoc,Mizoch,Mizocz,Мізоч', 50.4000000, 26.1500000, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129864, 'Miusyns’k', 'Miusyns''k', 'Miusins''k,Miusinsk,Miusyns''k,Miusyns’k,Миусинск,Міусинськ', 48.0775000, 38.9036400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129865, 'Mityayevo', 'Mityayevo', 'Mitjaeve,Mitjaevo,Mityayevo,Novyj Karagurt,Митяево,Митяєве,Но́вый Карагу́рт', 45.2342300, 33.7015000, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129866, 'Mitrofanovka', 'Mitrofanovka', 'Mitrofanivka,Mitrofanovka,Sollar,Митрофановка,Митрофанівка,Солла́р', 45.4511400, 34.6788300, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129867, 'Mirovka', 'Mirovka', 'Mirovka,Мировка', 49.9312600, 30.6230900, 'UA', '2013-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129868, 'Myronivka', 'Myronivka', 'Mironivka,Mironovka,Mironowka,Mironówka,Myronivka,Myroniwka,Mîronivka,Mıronivka,mi luo nuo fu ka,myrwnyfka,Мироновка,Миронівка,Միրոնովկա,میرونیفکا,მირონოვკა,米羅諾夫卡', 49.6600700, 30.9822500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129869, 'Mirny', 'Mirny', 'Mirnij,Mirny,Mirnyj,Мирний,Мирный', 45.3078800, 33.0350100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129870, 'Myrhorod', 'Myrhorod', 'MXR,Mirgorod,Mirhorod,Mirhoroda,Mirhorodo,Morgorod,Myrhorod,Myrhorodas,Mõrgorod,Mırgorod,mi er ge luo de,mirgorodi,myrhwrwd,Миргород,Միրգորոդ,מירהורוד,میرهورود,میرہوروڈ,მირგოროდი,米爾哥羅德', 49.9685400, 33.6088600, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129871, 'Mynay', 'Mynay', 'Minaj,Minay,Mynay,Минай', 48.5888000, 22.2750200, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129872, 'Milove', 'Milove', 'Melovoe,Melovoy,Melovoye,Milove,Меловое,Мілове', 49.3752800, 40.1322200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129873, 'Mikulintsy', 'Mikulintsy', 'Mikuliczyn,Mikulince,Mikulinci,Mikulincy,Mikulintse,Mikulintsy,Mikulińce,Микулинцы,Микулинці', 49.3960000, 25.6051800, 'UA', '2010-04-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129874, 'Mykhaylivka', 'Mykhaylivka', 'Mihajlivka,Mikhajlivka,Mikhaylovka,Mykhaylivka,Михайлівка', 47.2723500, 35.2223500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129875, 'Mikhaylovka', 'Mikhaylovka', 'Karamin,Mikhajlivka,Mikhajlovka,Mikhaylovka,Карами́н,Михайловка,Михайлівка', 45.5283800, 34.6405800, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129876, 'Mikhaylovka', 'Mikhaylovka', 'Mikhajlivka,Mikhajlovka,Mikhaylovka,Михайловка,Михайлівка', 45.1132500, 33.6107100, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129877, 'Myhove', 'Myhove', 'Migove,Migovo,Migovoye,Mikhova,Myhove,Мигове', 48.1574900, 25.3790400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129878, 'Myhiya', 'Myhiya', 'Migei,Migeja,Migeya,Migija,Migiya,Myhiya,Мигеи,Мигея,Мигия', 48.0371900, 30.9515300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129879, 'Michurinskoye', 'Michurinskoye', 'Kaburchak,Michurins''ke,Michurinskoe,Michurinskoye,Кабурча́к,Мичуринское,Мічурінське', 45.0743000, 34.7067200, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129880, 'Mezhvodnoye', 'Mezhvodnoye', 'Jarylgach,Mezhvodnoe,Mezhvodnoye,Mizhvodne,Межводное,Міжводне,Ярылга́ч', 45.5875100, 32.8450100, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129881, 'Velyki Mezhyrichi', 'Velyki Mezhyrichi', 'Mendzyzhech,Menzhirichi,Mezherichi,Mezhirichi,Mezhirichi-Koretskiye,Miedzyrzecz,Międzyrzecz,Veliki Mezhirichi,Velikie Mezhirichi,Velikiye Mezhirichi,Velyki Mezhyrichi,Великие Межиричи,Великі Межирічі', 50.6543100, 26.8662600, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129882, 'Chudey', 'Chudey', 'Chiudey,Chudei,Chudej,Chudey,Chudeyu,Chudyn,Ciudeiu,Czudyn,Mezhirech''ye,Mezhirech’ye,Mezhyrichchya,Чудей', 48.0524700, 25.6220800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129883, 'Volovo', 'Volovo', 'Mezhgor''e,Mezhgor''ye,Mezhgor’ye,Mizhgir''ja,Mizhhir"ya,Mizhhir''ya,Mizhhir”ya,Volove,Volovets,Volovo,Volové,Межгорье,Міжгір’я', 48.5245800, 23.5056300, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129884, 'Mezhova', 'Mezhova', 'Grigor''yevka,Grigor’yevka,Mezhevaja,Mezhevaya,Mezhova,Межевая,Межова', 48.2531800, 36.7346800, 'UA', '2016-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129885, 'Mezenivka', 'Mezenivka', 'Mezenevka,Mezenivka,Mezenovka,Мезеновка,Мезенівка', 50.6348600, 35.3134000, 'UA', '2013-11-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129886, 'Merefa', 'Merefa', 'Meref,Merefa,mei lie fa,merepa,mrfa,Мерефа,Մերեֆա,مرفا,მერეფა,梅列法', 49.8230200, 36.0506900, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129887, 'Zhuravlyovka', 'Zhuravlyovka', 'Minlerchik,Zhuravlivka,Zhuravljovka,Zhuravlyovka,Журавлёвка,Журавлівка,Минлерчи́к', 45.1768000, 33.9968000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129888, 'Mena', 'Mena', 'Mena,Мена', 51.5217000, 32.2156800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129889, 'Melitopol’', 'Melitopol''', 'Melitopol,Melitopol'',Melitopol’,mellitopol,Мелитополь,Мелітополь,멜리토폴', 46.8489100, 35.3653300, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129890, 'Melioratyvne', 'Melioratyvne', 'Meliorativne,Meliorativnoe,Meliorativnoye,Melioratyvne,Мелиоративное,Меліоративне', 48.6300900, 35.4155800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129891, 'Melekyne', 'Melekyne', 'Byelosarai,Melekine,Melekino,Melekyne,Milyenko,Мелекине,Мелекино', 46.9595700, 37.3998100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129892, 'Medzhibozh', 'Medzhibozh', 'Medshibosh,Medzhibozh,Miedzyboz,Меджибож', 49.4374800, 27.4048700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129893, 'Medvedevo', 'Medvedevo', 'Medvedeve,Medvedevo,Tabuldy-Ass,Медведеве,Медведево,Табулды́-Асс', 45.3859700, 33.0040000, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129894, 'Medvedevka', 'Medvedevka', 'Auz-Kirk,Medvedevka,Medvedivka,Ау́з-Кирк,Медведевка,Медведівка', 45.8838900, 34.5556200, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129895, 'Medenychi', 'Medenychi', 'Medenica,Medenice,Medenichi,Medenici,Medenitsa,Medenitse,Medenitsy,Medenychi,Меденица,Меденичі', 49.4305500, 23.7507300, 'UA', '2017-01-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129896, 'Mazanka', 'Mazanka', 'Mazanka,Мазанка', 45.0055000, 34.2558100, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129897, 'Mayskoye', 'Mayskoye', 'Khaklaj,Majfel''d,Majs''ke,Majskoe,Mayskoye,Ма́йфельд,Майское,Майське,Хакла́й', 45.5955500, 34.5521300, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129898, 'Mayaky', 'Mayaky', 'Kommuna Mayak,Majaki,Mayaki,Mayaky,Маяки', 47.4408300, 29.5598500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129899, 'Matviyivka', 'Matviyivka', 'Matrviivka,Matveyevka,Matviivka,Matviyivka,Novo-Popovka,Матвіївка,Матрвіївка', 47.0747300, 35.1444400, 'UA', '2015-12-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129900, 'Massandra', 'Massandra', 'Masandra,Massandra,Масандра,Массандра', 44.5095800, 34.1881700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129901, 'Mashivka', 'Mashivka', 'Mashevka,Mashivka,Masivka,Машевка,Машівка', 49.4430800, 34.8668800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129902, 'Maryevka', 'Maryevka', 'Mar''evka,Mar''ivka,Maryevka,Марьевка,Мар’ївка', 45.1133000, 36.2399200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129903, 'Marshintsy', 'Marshintsy', 'Marshenits'',Marshenits’,Marshintsy', 48.2175100, 26.2913300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129904, 'Markivka', 'Markivka', 'Markivka,Markovka,Markowka,Novo-Markovka,Марковка,Марківка', 49.5229000, 39.5705500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129905, 'Markova', 'Markova', 'Markova,Маркова', 48.6757600, 24.4138200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129906, 'Mariupol', 'Mariupol', 'Gorad Maryupal'',Hayeren,MPW,Marijupol,Marioupol,Marioupol'',Marioupoli,Mariupol,Mariupol'',Mariupolj,Zhdanov,hindi,kartuli,ma li wu bo er,ma ri xupal,maliupol,mari''upol,mari''upola,marywbwl,marywpwl,mrwpl,mryʼwpwl,mʼrywpʼl,ri ben yu,Μαριούπολη,Горад Марыупаль,Жданов,Мариупол,Мариуполь,Маријупољ,Маріуполь,Марїоуполь,Հայերեն,מאריופאל,מריאופול,ماريوبول,ماریوپول,مروپل,मरिउपोल,हिन्दी,మరిఉపొల్,ಮರಿಉಪೊಲ್,มารีอูปัล,ქართული,ማሪኡፖል,日本語,马里乌波尔,마리우폴', 47.0951400, 37.5413100, 'UA', '2014-08-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129907, 'Mareyka', 'Mareyka', 'Mar"yinka,Mar''inka,Mareyka,Mar’inka,Mar”yinka,Марьинка,Мар’їнка', 47.9452700, 37.5054400, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129908, 'Krinichnoye', 'Krinichnoye', 'Krinichne,Krinichnoe,Krinichnoye,Криничне,Криничное', 45.0242800, 34.6120200, 'UA', '2016-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129909, 'Marhanets’', 'Marhanets''', 'Komintern,Marganec,Marganec'',Marganets,Marhanets'',Marhanets’,Марганец,Марганець', 47.6354300, 34.6276900, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129910, 'Marfovka', 'Marfovka', 'Daut-Ehli,Marfivka,Marfovka,Дау́т-Эли́,Марфовка,Марфівка', 45.1985300, 36.0914400, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129911, 'Mar’yanovka', 'Mar''yanovka', 'Mar''janivka,Mar''janovka,Mar''yanovka,Mare,Маре́,Марьяновка,Мар’янівка', 45.4462700, 34.2947400, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129912, 'Manyava', 'Manyava', 'Manjava,Manyava,Манява', 48.6554100, 24.3753700, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129913, 'Mankivka', 'Mankivka', 'Man''kivka,Man''kovka,Man’kivka,Man’kovka,Маньковка,Маньківка', 48.9634900, 30.3336600, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129914, 'Manevychi', 'Manevychi', 'Maneviche,Manevichi,Manevychi,Маневичі', 51.2940500, 25.5343600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129915, 'Manchenky', 'Manchenky', 'Khutor Manchenkov,Manchenki,Manchenkov,Manchenky,Манченки', 49.9798200, 35.8583500, 'UA', '2011-01-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129916, 'Maly Mayak', 'Maly Mayak', 'Bijuk-Lambat,Buejuek Lambat,Büjük Lambat,Malij Majak,Maly Mayak,Malyj Majak,Бию́к-Ламба́т,Малий Маяк,Малый Маяк', 44.6135600, 34.3646900, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129917, 'Muromskoye', 'Muromskoye', 'Malyj Burunduk,Muroms''ke,Muromskoe,Muromskoye,Ма́лый Бурунду́к,Муромское,Муромське', 45.0905100, 34.8490000, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129918, 'Malorechenskoye', 'Malorechenskoye', 'Kuchuk-Uzen'',Malorechenskoe,Malorechenskoye,Malorichens''ke,Кучу́к-Узе́нь,Малореченское,Малоріченське', 44.7588800, 34.5578900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129919, 'Malokaterynivka', 'Malokaterynivka', 'Malokaterinivka,Malokaterinovka,Malokaterynivka,Maloyekaterinovka,Малокатеринівка', 47.6555000, 35.2564900, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129920, 'Malokakhovka', 'Malokakhovka', 'Malaya Kakhovka,Malokakhovka,Малокаховка', 46.7814200, 33.4479000, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129921, 'Malyn', 'Malyn', 'Malin,Malina,Malyn,Malynas,Malîn,Malın,ma lin,malini,malyn,Малин,Մալին,מאלין,مالین,მალინი,馬林', 50.7723300, 29.2383300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129922, 'Mala Vyska', 'Mala Vyska', 'Mal.Viska,Mala Viska,Mala Vyska,Malaya Viska,Malaya Viski,Malaya Vys''ka,Malaya Vys’ka,Мал.Виска,Мала Виска', 48.6430800, 31.6365700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129923, 'Mala Tokmachka', 'Mala Tokmachka', 'Mala Tokmachka,Malaya Tokmachka,Мала Токмачка', 47.5356300, 35.8929300, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129924, 'Mala Danylivka', 'Mala Danylivka', 'Mal.Danilovka,Mala Danilivka,Mala Danylivka,Malaya Danilovka,Мал.Даниловка,Мала Данилівка', 50.0635400, 36.1656400, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129925, 'Mala Bilozerka', 'Mala Bilozerka', 'Mala Bilozerka,Malaya Belozerka,Malaya Belozërka,Мала Білозерка', 47.2473700, 34.9345700, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129926, 'Yantarnoye', 'Yantarnoye', 'Jantarne,Jantarnoe,Tashly-Dair,Tasly Dajyr,Tašly Dajyr,Yantarnoye,Ташлы́-Даи́р,Янтарне,Янтарное', 45.4347300, 34.2213400, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129927, 'Makiv', 'Makiv', '', 48.7948700, 26.6918800, 'UA', '2012-12-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129928, 'Makiyivka', 'Makiyivka', 'Dmitriyevsk,Makayevka,Makeevka,Makejewka,Makeyevka,Makiivka,Makiyivka,Makyeevka,Makyevka,Макеевка,Макіївка', 48.0478200, 37.9257600, 'UA', '2017-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129929, 'Makariv', 'Makariv', 'Makariv,Makarov,Макарів', 50.4640800, 29.8112800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129930, 'Mahdalynivka', 'Mahdalynivka', 'Magdalinivka,Magdalinovka,Magdalinowka,Magdalinowka Pervaya,Magdalinowka Vtoraya,Mahdalynivka,Магдалиновка,Магдалинівка', 48.9211100, 34.9149100, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129931, 'Magazinka', 'Magazinka', 'Magazinka,Магазинка', 45.8631200, 34.0496900, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129932, 'Liutizh', 'Liutizh', 'Liutizh,Ljutezh,Ljutizh,Lutesh,Lutezh,Lyutezh,Лютеж,Лютіж', 50.6835000, 30.3932400, 'UA', '2016-06-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129933, 'Lyubotyn', 'Lyubotyn', 'Ljubotin,Lyobotin,Lyubotin,Lyubotyn,Люботин', 49.9469100, 35.9290700, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129934, 'Lyuboml’', 'Lyuboml''', 'Ljuboml'',Luboml,Lyubomi,Lyuboml'',Lyuboml’,Любомль', 51.2260100, 24.0372700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129935, 'Lyubymivka', 'Lyubymivka', 'Ljubimivka,Ljubimovka,Lubimivka,Lyubimovka,Lyubymivka,Любимовка,Любимівка', 46.8106300, 33.5686200, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129936, 'Lyubeshiv', 'Lyubeshiv', 'Ljubeshiv,Lubieszow,Lubieszów,Lyubashevo,Lyubeshev,Lyubeshiv,Lyubeshov,Lyubeshuv,Любешів', 51.7653500, 25.5142000, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129937, 'Lyubech', 'Lyubech', 'Ljubech,Lyubech,Lyubich'',Lyubich’,Lyubyach,Любеч', 51.7026000, 30.6569200, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129938, 'Lyubar', 'Lyubar', 'Ljubar,Lyubar,Любар', 49.9204500, 27.7591800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129939, 'Lysyanka', 'Lysyanka', 'Lisjanka,Lisyanka,Lisyanko,Lysjanka,Lysyanka,Лисянка,Лысянка', 49.2522900, 30.8294600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129940, 'Lysa Hora', 'Lysa Hora', 'Lisa Gora,Lysa Hora,Lysaja Gora,Lysaya Gora,Лиса Гора,Лысая Гора', 48.1705900, 31.1099400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129941, 'Lviv', 'Lviv', 'Gorad L''vou,Ilbav,L''viv,L''vov,L''vov osh,LWO,Lavov,Lembaersch,Lemberg,Lemburg,Lembärsch,Leopoli,Leopolis,Leopołi,Leopul,Leópolis,Liopuli,Liov,Liòpuli,Ljviv,Lviv,Lvivo,Lvov,Lvova,Lvovas,Lwif,Lwiw,Lwow,Lwuw,Lwów,Lwůw,l wif,l''vov,lbwb,lfyf,li wo fu,libibeu,libiu,livhiva,liviv,lvov,lvovi,lvyv,lwwf,lwyw,lywyw,lʻmbryq,rivu~iu,İlbav,Ļvova,Ľvov,Λβιβ,Горад Львоў,Лавов,Лвов,Львив,Львов,Львов ош,Львів,Լվով,לבוב,לעמבערג,לעמבריק,لفيف,لووف,لویو,لڤیڤ,لیویو,लिव्हिव,லிவீவ்,ลวีฟ,ლვოვი,リヴィウ,利沃夫,리비브,리비우', 49.8382600, 24.0232400, 'UA', '2017-06-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129942, 'Luzhany', 'Luzhany', 'Lujeni,Luzhani,Luzhany,Luzheny,Лужани', 48.3649200, 25.7717300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129943, 'Lutuhyne', 'Lutuhyne', 'Loutougino,Loutouhyne,Lutugine,Lutugino,Lutugone,Lutugõne,Lutugıne,Lutuhine,Lutuhyne,Lutuhîne,Lutúgine,lu tu ji nuo,lwtwhynh,Łutuhyne,Лутугине,Лутугино,Լուտուգինո,لوتوهینه,ლუტუგინო,盧圖吉諾', 48.4050700, 39.2267500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129944, 'Luts’k', 'Luts''k', 'Loetsk,Loutsk,Luc''k,Luck,Luckas,Lucko,Luts''k,Lutsk,Luts’k,Luzk,UCK,lwzq,Łuck,Луцк,Луцьк,לוצק', 50.7593200, 25.3424400, 'UA', '2017-01-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129945, 'Lutovynivka', 'Lutovynivka', 'Lutovinivka,Lutovinovka,Lutovynivka,Лутовиновка,Лутовинівка', 49.2372600, 33.9051000, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129946, 'Lukiv', 'Lukiv', 'Lukiv,Lukov,Lukuv,Луків', 51.0521000, 25.4005900, 'UA', '2012-07-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129947, 'Luhansk', 'Luhansk', 'Gorad Lugansk,Loehansk,Louchansk,Louhansk,Lugan''sk,Lugans''k,Lugansk,Luganskaj,Lugánsk,Luhans''k,Luhansk,Luhanska,Luhanskas,Luhansko,Luhanszk,Luhans’k,Lukhansk,Luqansk,VSG,Voroshilovgrad,Woroschilowgrad,lu gan si ke,luhansikeu,lwhansk,lwhnsq,ruhanshiku,Ługańsk,Łuhańsk,Λουχάνσκ,Ворошиловград,Горад Луганск,Луганск,Луганскай,Луганськ,Луганьск,Луханск,Луһанск,Լուգանսկ,לוהנסק,لوهانسك,لوهانسک,لوہانسک,ლუგანსკი,ルハーンシク,卢甘斯克,루한시크', 48.5670500, 39.3170600, 'UA', '2015-06-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129948, 'Lugovoye', 'Lugovoye', 'Agibel'',Lugove,Lugovoe,Lugovoye,Агибель,Лугове,Луговое', 45.2346900, 35.7220200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129949, 'Luhyny', 'Luhyny', 'Lugini,Luginy,Luhyny,Лугини', 51.0820300, 28.4005700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129950, 'Luhans’ke', 'Luhans''ke', 'Lugans''ke,Luganskaya,Luganskoe,Luganskoje,Luganskoye,Luhans''ke,Luhans’ke,Луганское,Луганське', 48.4457400, 38.2615300, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129951, 'Luchistoye', 'Luchistoye', 'Demerdzhi,Luchiste,Luchistoe,Luchistoye,Демерджи́,Лучисте,Лучистое', 44.7364600, 34.4006300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129952, 'Lubny', 'Lubny', 'Loubny,Lubin,Lubnai,Lubni,Lubnie,Lubny,Lubnî,Lubnı,lu bu ni,lubni,lwbny,Łubnie,Лубни,Лубны,Լուբնի,לובני,لوبنی,ლუბნი,盧布尼', 50.0162500, 32.9969400, 'UA', '2016-09-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129953, 'Lozovoye', 'Lozovoye', 'Ehski-Orda,Eski Orda,Lozove,Lozovoe,Lozovoye,Лозове,Лозовое,Эски́-Орда́', 44.9060000, 34.1641400, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129954, 'Lozova', 'Lozova', 'Losowa,Losowaja,Lozova,Lozovaja,Lozovaya,Lozowa,lozovaia,luo zuo wa,lwzwbh,Łozowa,Лозова,Лозовая,Լոզովայա,לוזובה,ლოზოვაია,洛佐瓦', 48.8893700, 36.3175500, 'UA', '2016-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129955, 'Lozuvatka', 'Lozuvatka', 'KWG,Lozovatka,Lozuvatka,Лозоватка,Лозуватка', 48.0571000, 33.2858100, 'UA', '2013-11-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129956, 'Lozno-Oleksandrivka', 'Lozno-Oleksandrivka', 'Aleksandrovka,Aleksandrowka,Lozno-Aleksandrovka,Lozno-Aleksandrovskiy,Lozno-Oleksandrivka,Лозно-Александровка,Лозно-Олександрівка', 49.8391000, 38.7409800, 'UA', '2013-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129957, 'Lopukhiv', 'Lopukhiv', 'Brustura,Lopuhiv,Lopukhiv,Lopukhov,Лопухів', 48.3652700, 23.9638200, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129958, 'Lopatyn', 'Lopatyn', 'Lopatin,Lopatyn,Лопатин', 50.2202200, 24.8483100, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129959, 'Lokhvytsya', 'Lokhvytsya', 'Lochwiza,Lokhvica,Lokhvicja,Lokhvitsa,Lokhvytsa,Lokhvytsya,Лохвица,Лохвиця', 50.3677600, 33.2602400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129960, 'Lokachi', 'Lokachi', 'Lokache,Lokachi,Lokaci,Lokacze,Łokacze,Локачі', 50.7370000, 24.6494400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129961, 'Lobanovo', 'Lobanovo', 'Bogemka,Dzhadra,Lobanove,Lobanovo,Боге́мка,Джадра́,Лобанове,Лобаново', 45.7755200, 34.2423600, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129962, 'Lyubashivka', 'Lyubashivka', 'Ljubashivka,Lubasivka,Lyubashevka,Lyubashivka,Lyubashëvka,Любашівка', 47.8371600, 30.2597600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129963, 'Livadia', 'Livadia', 'Livadia,Livadija,Ливадия,Лівадія', 44.4702100, 34.1427200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129964, 'Litvinenkovo', 'Litvinenkovo', 'Kentugaj,Litvinenkove,Litvinenkovo,Qaja Asty,Кентуга́й,Литвиненкове,Литвиненково', 45.0864800, 34.3110700, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129965, 'Lityn', 'Lityn', 'Litin,Lityn,Літин', 49.3250900, 28.0809400, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129966, 'Lysychovo', 'Lysychovo', 'Lisichevo,Lisichovo,Lysycheve,Lysychovo,Лисичово', 48.4967700, 23.2899200, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129967, 'Lysychans’k', 'Lysychans''k', 'Lisichans''k,Lisichansk,Lysychans''k,Lysychans’k,Лисичанск,Лисичанськ', 48.9048500, 38.4420700, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129968, 'Lypovets’', 'Lypovets''', 'Lipovec'',Lipovets,Lypovets'',Lypovets’,Липовець', 49.2296400, 29.0555500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129969, 'Lypova Dolyna', 'Lypova Dolyna', 'Lipova Dolina,Lipovaja Dolina,Lipovaya Dolina,Lypova Dolyna,Липова Долина,Липовая Долина', 50.5642800, 33.7979300, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129970, 'Lypnyazhka', 'Lypnyazhka', 'Lipnjazhka,Lipnyazhka,Lypnyazhka,Липняжка', 48.4469400, 31.0761100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129971, 'Lypcha', 'Lypcha', 'Lipca,Lipcha,Lipcse,Lipsa,Lipse,Lipsha,Lipča,Lipša,Lypcha,Липча', 48.2610700, 23.3833600, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129972, 'Lymanske', 'Lymanske', 'Limanskoe,Lymanske,Sel''ts,Sel’ts,Zel''ts,Zel''tsy,Zel’ts,Zel’tsy,Лиманское', 46.6557000, 29.9672200, 'UA', '2014-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129973, 'Lyman', 'Lyman', 'Liman,Lyman,Лиман', 49.5976900, 36.4703000, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129974, 'Lykhivka', 'Lykhivka', 'Likhivka,Likhovka,Lykhivka,Лиховка,Лихівка', 48.6873500, 33.9227900, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129975, 'Letychiv', 'Letychiv', 'Letichev,Letichiv,Leticiv,Letychiv,Летичів', 49.3826300, 27.6305100, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129976, 'Lisovi Sorochyntsi', 'Lisovi Sorochyntsi', 'Lesovy,Lesovy Sorochintsy,Lesovye Sorochincy,Lesovyye Sorochintsy,Lisovi Sorochinci,Lisovi Sorochyntsi,Pesovy,Sorochincy,Velikie Sorochincy,Великие Сорочинцы,Лесовые Сорочинцы,Лісові Сорочинці,Сорочинцы', 50.6892000, 32.3291900, 'UA', '2013-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129977, 'Leninskoye', 'Leninskoye', 'Kir-Bajljar,Lenindorf,Lenins''ke,Leninskoe,Leninskoye,Кир-Байляр,Лениндо́рф,Ленинское,Ленінське', 45.2684400, 34.0502300, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129978, 'Leninskoye', 'Leninskoye', 'Lenins''ke,Leninskoe,Leninskoye,Petrovskoe,Ленинское,Ленінське,Петро́вское', 45.2537300, 35.9196900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129979, 'Lenino', 'Lenino', 'Lenine,Lenino,Yedi Kuyu,Yedi Quyu,lie ni nie,Ленино,Леніне,Լենինո,列尼涅', 45.2985700, 35.7770800, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129980, 'Lenina', 'Lenina', 'Imeni Lenina,Lenina,Poselok Imeni Lenina,Posëlok Imeni Lenina,Леніна', 48.4294400, 39.1455600, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129981, 'Lebedyn', 'Lebedyn', 'Lebedin,Lebedyn,Лебедин', 48.9624200, 31.5269600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129982, 'Lazurne', 'Lazurne', 'Lazurne,Lazurnoye,Novoalekseyevka,Лазурне', 46.0840000, 32.5295500, 'UA', '2017-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129983, 'Lazi', 'Lazi', 'Lazi,Lazy,Лази', 48.0666700, 24.2333300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129984, 'Lazeshchyna', 'Lazeshchyna', 'Laveshchina,Lazeshchina,Lazeshchyna,Lazeshhina,Loveshchina,Лазещина', 48.2685200, 24.4201000, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129985, 'Lanivtsi', 'Lanivtsi', 'Lanavtse,Lanivci,Lanivtsi,Lanovtse,Lanovtsy,Lanowce,Łanowce,Ланівці', 49.8632800, 26.0908200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129986, 'Lanchyn', 'Lanchyn', 'Lanchin,Lanchyn,Lanczyn,Łanczyn,Ланчин', 48.5578100, 24.7562200, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129987, 'Ladyzhyn', 'Ladyzhyn', 'Ladizhin,Ladyzhin,Ladyzhyn,Lodyzhin,Ладижин', 48.6849600, 29.2367900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129988, 'Ladan', 'Ladan', 'Ladan,Ladin,Ладан', 50.5195900, 32.5817800, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129989, 'Kyiv', 'Kyiv', 'Chijv,Civ,Cív,Gorad Kieu,IEV,Kaenugardur,Keju,Kiebo,Kief,Kieu,Kiev,Kiev osh,Kievi,Kievo,Kiew,Kiiev,Kiiv,Kijev,Kijeva,Kijevas,Kijew,Kijow,Kijuw,Kijv,Kijów,Kijůw,Kiova,Kiovia,Kiyev,Kiyiw,Kiëf,Kjiv,Kueyiv,Kyev,Kyiiv,Kyiv,Kyiw,Kyjev,Kyjiv,Kyjiw,Kyèv,Kænugarður,Kíev,Kîev,Küyiv,ji fu,kheiyf,kiefu,kiv,kiva,kiyebha,kiyepeu,kyf,kyiva,kyyf,qyyb,Κίεβο,Горад Кіеў,Кейӳ,Киев,Киев ош,Київ,Кијев,Кыив,Кыйив,Кꙑѥвъ,Կիև,קייב,קיעוו,كىيېۋ,كييف,کیف,کیێڤ,کی‌یف,कीव,क्यीव,কিয়েভ,கீவ்,കീവ്,เคียฟ,ཀིབ།,ကီးယက်မြို့,კიევი,ኪየቭ,キエフ,基輔,키예프', 50.4546600, 30.5238000, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129990, 'Kvasy', 'Kvasy', 'Kvasi,Kvasy,Tiszaborkut,Tiszaborkút,Кваси,Квасы', 48.1497300, 24.2799500, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129991, 'Kuznetsovs’k', 'Kuznetsovs''k', 'Kuznecovsk,Kuznetsovs''k,Kuznetsovsk,Kuznetsovs’k,Кузнецовск', 51.6833300, 25.8666700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129992, 'Kuybysheve', 'Kuybysheve', 'Kujbisheve,Kujbyshevo,Kuybysheve,Kuybyshevo,Куйбишеве,Куйбышево', 47.3580000, 36.6490800, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129993, 'Kuibyshevo', 'Kuibyshevo', 'Albat,Kujbisheve,Kujbyshevo,Kuybyshevo,Алба́т,Куйбишеве,Куйбышево', 44.6290000, 33.8689500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129994, 'Kuty', 'Kuty', 'Kuti,Kutty,Kuty,Кути', 48.2586800, 25.1794600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129995, 'Kuteynykove', 'Kuteynykove', 'Kuteinikowo,Kutejnikove,Kuteynikovo,Kuteynykove,Кутейникове', 47.8122700, 38.2882200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129996, 'Kushuhum', 'Kushuhum', 'Kushugum,Kushugumovka,Kushuhum,Кушугум', 47.7127800, 35.2091700, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129997, 'Kushnytsya', 'Kushnytsya', 'Kushnicja,Kushnitsa,Kushnitse,Kushnytsya,Kusnice,Kušnice,Кушниця', 48.4398800, 23.2581600, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129998, 'Kurakhovo', 'Kurakhovo', 'Kurakhovo,Kurakhovstroy,Novo-Ulakly,Petrovka,Курахово', 47.9852200, 37.2821000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(129999, 'Kupjansk', 'Kupjansk', 'Koupiansk,Kup"yans''k,Kup''jans''k,Kup''jansk,Kupeansk,Kupiansk,Kupiańsk,Kupjans''k,Kupjansk,Kupjanska,Kupjanskas,Kupyansk,Kup”yans’k,ku pi yang si ke,kwpyansk,Купьянск,Купянск,Купянськ,Купјанск,Куп’янськ,Կուպյանսկ,קופיאנסק,کوپیانسک,კუპიანსკი,庫皮揚斯克', 49.7105500, 37.6151700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130000, 'Kulynychi', 'Kulynychi', 'Kulinichi,Kulinici,Kulynychi,Кулиничи,Кулиничі', 49.9817800, 36.3828300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130001, 'Kulykivka', 'Kulykivka', 'Kulikivka,Kulikovka,Kulikowka,Kulykivka,Куликовка,Куликівка', 51.3734500, 31.6466100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130002, 'Kulykiv', 'Kulykiv', 'Kulikiv,Kulikov,Kulikuv,Kulykiv,Куликів', 50.3142400, 24.8175700, 'UA', '2012-11-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130003, 'Kryzhopil’', 'Kryzhopil''', 'Krizhopil'',Krizhopol'',Krizhopol’,Kryzhopil'',Kryzhopil’,Kryzhopol'',Kryzhopol’,Крижопіль', 48.3828900, 28.8662200, 'UA', '2015-04-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130004, 'Kryzhanivka', 'Kryzhanivka', 'Krizanivka,Krizhanivka,Kryzhanivka,Kryzhanovka,Крижанівка', 46.5616700, 30.7948700, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130005, 'Kryvyi Rih', 'Kryvyi Rih', 'Gorad Kryvy Rog,KWG,Krivi Rih,Krivi Rog,Krivii Rih,Krivij Rig,Krivij Rih,Kriviy Rig,Krivoi Rog,Krivoj Rog,Krivoj rog,Krivojroga,Krivoy Rog,Krivoy Roq,Krivyj Rig,Kriví Rih,Krivói Rog,Kriwoi Rog,Krovoi Rig,Kruevuey Rih,Kryvy Rih,Kryvyi Rih,Kryvyj Rih,Kryvyj Rihas,Kryvyy Rih,Kryvyï Rih,Krywyj Rih,Krzywy Rog,Krzywy Róg,Krîvîi Rih,Krõvõi Rig,Krüvüy Rih,Krıvıy Rig,ke li wo luo ge,keulibiliheu,kh ri wi rikh,kryfy ryh,kryfyy ryh,qryby ryh,Горад Крывы Рог,Криви Рог,Кривий Риҕ,Кривий Ріг,Кривой Рог,Кривой рог,Кривый Ріг,Կրիվոյ Ռոգ,קריבי ריה,كريفي ريه,کریفیی ریه,ครีวีริค,კრივოი-როგი,クルィヴィーイ・リーフ,克里沃罗格,크리비리흐', 47.9096600, 33.3804400, 'UA', '2014-12-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130006, 'Krymskoye', 'Krymskoye', 'Avel'',Krims''ke,Krymskoe,Krymskoye,Аве́ль,Кримське,Крымское', 45.1883600, 33.8010600, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130007, 'Krymka', 'Krymka', 'Krimka,Krymka,Sultan-Bochala,Кримка,Крымка,Султа́н-Бочала́', 45.7045300, 34.1878200, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130008, 'Kruty', 'Kruty', 'Kruty,Круты', 51.0597400, 32.1063400, 'UA', '2010-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130009, 'Krolevets’', 'Krolevets''', 'Korolevets,Krolevec,Krolevec'',Krolevets,Krolevets'',Krolevets’,Krolovets,Кролевец,Кролевець', 51.5477500, 33.3847500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130010, 'Kryve Ozero', 'Kryve Ozero', 'Krive Ozero,Krivoye Ozero,Kryve Ozero,Криве Озеро', 47.9524200, 30.3492800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130011, 'Kryva Hora', 'Kryva Hora', 'Kriva Gora,Krivaja Gora,Krivaya Gora,Kryva Hora,Крива Гора,Кривая Гора', 51.3849500, 30.1997800, 'UA', '2012-09-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130012, 'Kryva', 'Kryva', 'Kriva,Krivaya,Krivoye,Kryva,Nagykirva,Tiszakirva,Крива', 48.1723400, 23.2364700, 'UA', '2012-11-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130013, 'Krinichnaya', 'Krinichnaya', 'Krinichnaya,Krinitschnaja', 48.1289900, 38.0259700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130014, 'Krynychky', 'Krynychky', 'Krinichki,Krinichky,Krynychky,Кринички', 48.3755100, 34.4670100, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130015, 'Krest’yanovka', 'Krest''yanovka', 'Krest''janovka,Krest''yanovka,Krestjanivka,Krest’yanovka,Larindorf,Крестьяновка,Крестянівка,Лариндо́рф', 45.7226800, 33.9393800, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130016, 'Kripens’kyy', 'Kripens''kyy', 'Krepenskij,Krepenskiy,Kripens''kij,Kripens''kyy,Kripens’kyy,Крепенский,Кріпенський', 48.0770900, 39.0580000, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130017, 'Tatariv', 'Tatariv', 'Krementsy,Kremintsi,Kremintsy,Tartarov,Tatariv,Tatarov,Татаров,Татарів', 48.3455800, 24.5783600, 'UA', '2012-12-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130018, 'Kreminna', 'Kreminna', 'Kremenaya,Kremennaja,Kremennaya,Kremennoj,Kremina,Kreminna,ke lie mian na ya,krmyna,Кременная,Кременной,Кремина,Кремінна,Կրեմենայա,کرمینا,კრემენაია,克列緬納亞', 49.0495000, 38.2179200, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130019, 'Kremenets’', 'Kremenets''', 'Kremenec,Kremenec'',Kremenets,Kremenets'',Kremenets’,Krzemieniec,Kshemenets,Кременец,Кременець', 50.0969300, 25.7245900, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130020, 'Kremenchuk', 'Kremenchuk', 'Gorad Kramjanchug,KHU,Kermenchuk,Kremenchug,Kremenchuk,Kremenciuk,Kremencsuk,Kremencug,Kremencuk,Kremencuka,Kremencukas,Krementchouk,Krementjuk,Krementschug,Krementschuk,Krementsjoek,Krementsjuk,Krementsuk,Krementxuk,Krementšuk,Kremençug,Kremençuk,Kremenĉuk,Kremenčuk,Kremenčuka,Kremenčukas,Krzemienczuk,Krzemieńczuk,ke lie mian qiu ge,keulemenchukeu,krmnchwk,kuremenchuku,kʼremenchugi,qrmnzwg,Горад Крамянчуг,Керменчӳк,Кирмәнчек,Кременчуг,Кременчук,Կրեմենչուգ,קרמנצוג,کرمنچوک,კრემენჩუგი,クレメンチューク,克列緬丘格,크레멘추크', 49.0680200, 33.4204100, 'UA', '2013-04-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130021, 'Krayneye', 'Krayneye', 'Krajne,Krajnee,Krayneye,Teshij,Крайнее,Крайнє,Теши́й', 45.2299300, 33.8323900, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130022, 'Krasyatychi', 'Krasyatychi', 'Krasjatichi,Krasyatichi,Krasyatychi,Krusyatichi,Красятичі', 51.0763600, 29.6489900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130023, 'Krasnyi Mak', 'Krasnyi Mak', 'Bijuk-Karalez,Krasnij Mak,Krasnyi Mak,Krasnyj Mak,Бию́к-Карале́з,Красний Мак,Красный Мак', 44.6421800, 33.7813000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130024, 'Krasnyy Luch', 'Krasnyy Luch', 'Krasnij Luch,Krasniluch,Krasny Luch,Krasnyi Luch,Krasnyj luch,Krasnyy Luch,Krassntjlutsch,Красний Луч,Красный луч', 48.1395400, 38.9371500, 'UA', '2016-05-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130025, 'Krasnyy Lyman', 'Krasnyy Lyman', 'Krasnij Liman,Krasniy Liman,Krasny Liman,Krasnyj Liman,Krasnyy Liman,Krasnyy Lyman,Liman,Красний Лиман,Красный Лиман', 48.9883700, 37.8022500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130026, 'Krasnyy Kut', 'Krasnyy Kut', 'Krasnij Kut,Krasnyy Kut,Красний Кут', 48.2013800, 38.7976500, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130027, 'Krasnoznamenka', 'Krasnoznamenka', 'Krasnoznam''janka,Krasnoznamenka,Краснознаменка,Краснознам’янка', 45.2867600, 34.0003600, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130028, 'Krasne', 'Krasne', 'Krasne,Krasnoe,Krasnoye,Красне,Красное', 49.9144700, 24.6134000, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130029, 'Krasne', 'Krasne', 'Krasne,Krasnoye,Красне', 46.1308800, 32.7691000, 'UA', '2015-03-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130030, 'Krasnoyarskoye', 'Krasnoyarskoye', 'Donuzlav 1,Krasnojars''ke,Krasnojarskoe,Krasnoyarskoye,Mechit-Donuzlav,Донузла́в 1,Красноярское,Красноярське,Мечи́т-Донузла́в', 45.5066100, 33.2664100, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130031, 'Krasnotorka', 'Krasnotorka', 'Krasnogorka,Krasnotorka,Красноторка', 48.6820400, 37.5326600, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130032, 'Krasnosilka', 'Krasnosilka', 'Gil''dendorf,Gil’dendorf,Kolendorovo,Krasnoselka,Krasnosilka,Krasnosëlka,Красносілка', 46.6225800, 30.7742100, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130033, 'Krasnopillya', 'Krasnopillya', 'Krasnopilla,Krasnopillja,Krasnopillya,Krasnopol''e,Krasnopol''ye,Krasnopole,Krasnopol’ye,Краснополье,Краснопілля', 50.7745800, 35.2596500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130034, 'Krasnoperekops’k', 'Krasnoperekops''k', 'Krasnoperekops''k,Krasnoperekopsk,Krasnoperekops’k,Or qapu,Красноперекопск,Красноперекопськ', 45.9571600, 33.7965000, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130035, 'Krasnopavlivka', 'Krasnopavlivka', 'Krasnopavlivka,Krasnopavlovka,Краснопавловка,Краснопавлівка', 49.1364300, 36.3191100, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130036, 'Krasnolesye', 'Krasnolesye', 'Krasnoles''e,Krasnolesye,Krasnolissja,Tavel'',Краснолесье,Краснолісся,Таве́ль', 44.8325900, 34.2308600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130037, 'Krasnokuts’k', 'Krasnokuts''k', 'Krasnokuts''k,Krasnokutsk,Krasnokuts’k,Краснокутск,Краснокутськ', 50.0660200, 35.1627500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130038, 'Krasnokamenka', 'Krasnokamenka', 'Kiziltash,Krasnokam''janka,Krasnokamenka,Кизилта́ш,Краснокаменка,Краснокам’янка', 44.5638300, 34.2887700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130039, 'Krasnogvardeyskoye', 'Krasnogvardeyskoye', 'Krasnogvardejskoe,Krasnogvardeyskoye,Krasnogvardijs''ke,Kurman-Kemel''chi,Красногвардейское,Красногвардійське,Курма́н-Кемельчи́', 45.5027100, 34.3013400, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130040, 'Krasnogvardeyskoye', 'Krasnogvardeyskoye', 'Krasnogvardejskoe,Krasnogvardeyskoye,Krasnogvardijs''ke,Novyj Cjurikhtal'',Красногвардейское,Красногвардійське,Но́вый Цюрихта́ль', 45.1834800, 34.9506600, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130041, 'Krasnohrad', 'Krasnohrad', 'Konstantinograd,Krasnograd,Krasnohrad,Krasnohradas,ke la si nuo he la de,khrasnwhrad,Красноград,Կրասնոգրադ,خراسنوهراد,კრასნოგრადი,克拉斯諾赫拉德', 49.3800900, 35.4418600, 'UA', '2015-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130042, 'Krasnogorka', 'Krasnogorka', 'Kenegez,Kop-Kenegez,Krasnogirka,Krasnogorka,Кенеге́з,Коп-Кенеге́з,Красногорка,Красногірка', 45.2451300, 35.8073900, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130043, 'Krasnoflotskoye', 'Krasnoflotskoye', 'Kajnash,Krasnoflots''ke,Krasnoflotskoe,Krasnoflotskoye,Кайна́ш,Краснофлотское,Краснофлотське', 45.3157200, 34.9475600, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130044, 'Krasnodon', 'Krasnodon', 'Krasnodon,Krasnodonskiy,Краснодон', 48.3124500, 39.5628400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130045, 'Krasnodon', 'Krasnodon', 'Krasnodon,Krasnodona,Krassnodon,Sorokin,Sorokino,ke la si nuo dun,krasnwdwm,qrsnwdwn,Краснодон,Կրասնոդոն,קרסנודון,کراسنودوم,კრასნოდონი,克拉斯諾頓', 48.2923500, 39.7392100, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130046, 'Krasnoarmeyskoye', 'Krasnoarmeyskoye', 'Ashkhadan,Krasnoarmejskoe,Krasnoarmeyskoye,Krasnoarmijs''ke,Murza-Kojash,Ашхада́н,Красноармейское,Красноармійське,Мурза́-Коя́ш', 45.9910300, 34.0303700, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130047, 'Krasnoarmiys’k', 'Krasnoarmiys''k', 'Grishino,Krasnoarmejsk,Krasnoarmeysk,Krasnoarmeyskoye,Krasnoarmijs''k,Krasnoarmiys''k,Krasnoarmiys’k,Krassnoarmeiskoje,Красноармейск,Красноармійськ', 48.2819800, 37.1758500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130048, 'Krasnaya Zor’ka', 'Krasnaya Zor''ka', 'Karacha-Kangil,Krasna Zor''ka,Krasnaja Zor''ka,Krasnaya Zor''ka,Krasnaya Zor’ka,Карача́-Канги́л,Красна Зорька,Красная Зорька', 45.1343200, 34.0401500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130049, 'Krymskaya Roza', 'Krymskaya Roza', 'Krasnaja Roza,Krims''ka Roza,Krymskaja Roza,Krymskaya Roza,Кра́сная Ро́за,Кримська Роза,Крымская Роза', 45.0577600, 34.3563100, 'UA', '2016-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130050, 'Krasnaya Polyana', 'Krasnaya Polyana', 'Kizil-Chonrav,Krasna Poljana,Krasnaja Poljana,Krasnaya Polyana,Кизи́л-Чонра́в,Красна Поляна,Красная Поляна', 45.4824100, 32.9379000, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130051, 'Krasna', 'Krasna', 'Krasna,Krasnaya,Krasnoye,Красна', 48.5757100, 24.7002700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130052, 'Krasyliv', 'Krasyliv', 'Krasiliv,Krasilov,Krasilow,Krasyliv,Красилов,Красилів', 49.6518600, 26.9725300, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130053, 'Kramators’k', 'Kramators''k', 'Kramators''k,Kramatorsk,Kramatorskaja,Kramatorskaya,Kramators’k,Краматорск,Краматорськ', 48.7230500, 37.5562900, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130054, 'Kozova', 'Kozova', 'Kozova,Kozovo,Kozowa,Козова', 49.4354400, 25.1508600, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130055, 'Kozhanka', 'Kozhanka', 'Kozhanka,Кожанка', 49.9793300, 29.7380600, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130056, 'Kozel’shchyna', 'Kozel''shchyna', 'Kozel''shchina,Kozel''shchyna,Kozel''shhina,Kozel’shchina,Kozel’shchyna,Козельщина', 49.2168200, 33.8481000, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130057, 'Kozelets’', 'Kozelets''', 'Koselez,Kozelec,Kozelec'',Kozelets,Kozelets'',Kozelets’,Козелец,Козелець', 50.9133400, 31.1214000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130058, 'Kivsharivka', 'Kivsharivka', 'Kivsarivka,Kivsharivka,Kovsharov,Kovsharovka,Ківшарівка', 49.6309600, 37.6882100, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130059, 'Kovel', 'Kovel', 'Kovel,Kovel'',Kovel’,Kowel,Ковель', 51.2152600, 24.7086700, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130060, 'Kotsyubyns’ke', 'Kotsyubyns''ke', 'Berkovets,Imeni Kotsyubinskogo,Kocjubins''ke,Kocjubinskoe,Kotsiubynske,Kotsyubinskogo,Kotsyubinskoye,Kotsyubyns''ke,Kotsyubyns’ke,Коцюбинское,Коцюбинське', 50.4883600, 30.3295700, 'UA', '2014-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130061, 'Kotovs’k', 'Kotovs''k', 'Birzula,Kotovs''k,Kotovsk,Kotovs’k,Kotowsk,Котовск,Котовськ', 47.7530500, 29.5320500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130062, 'Kotel’va', 'Kotel''va', 'Kotel''va,Kotel’va,Котельва', 50.0686400, 34.7586200, 'UA', '2014-02-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130063, 'Kotel’nikovo', 'Kotel''nikovo', 'Agujar-Dzhiren'',Kotel''nikove,Kotel''nikovo,Kotel’nikovo,Агъя́р-Джире́нь,Котельникове,Котельниково', 45.3658400, 34.0257500, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130064, 'Kostyantynivka', 'Kostyantynivka', 'Konstantinovka,Kostyantynivka,Константиновка', 47.8266000, 31.1355100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130065, 'Kostryzhivka', 'Kostryzhivka', 'Costrijeni,Kostrizhevka,Kostrizhovka,Kostrizivka,Kostryzhivka,Kostryzhuvka,Kostryzowka,Kostryzówka,Кострижівка', 48.6545500, 25.7131600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130066, 'Kostopil’', 'Kostopil''', 'Kostopel,Kostopil'',Kostopil’,Kostopol,Kostopol'',Kostopol’,Костополь,Костопіль', 50.8784100, 26.4519200, 'UA', '2014-10-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130067, 'Kosiv', 'Kosiv', 'Cosau,Cosău,Kosiv,Kosiva,Kosov,Kosow,Kossiv,Kossiw,Kossow,Kossuv,Kosuv,Kosów,ke suo fu,kwsyf,qwswb,Косов,Косів,Կոսով,קאסאוו,קוסוב,کوسیف,კოსოვი,科索夫', 48.3107100, 25.0957500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130068, 'Kosmach', 'Kosmach', 'Kosmach,Космач', 48.7508900, 24.3673100, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130069, 'Kosmach', 'Kosmach', 'Kosmach,Kosmacz,Kozmacz,Космач', 48.3299100, 24.8205200, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130070, 'Koson’', 'Koson''', 'Kosini,Kosino,Kosiny,Koson'',Koson’,Kosyny,Mezokaszony,Mezőkaszony,Косонь', 48.2550500, 22.4559700, 'UA', '2017-04-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130071, 'Koryukivka', 'Koryukivka', 'Karyukovka,Korjukivka,Korjukovka,Korukivka,Koryukivka,Koryukovka,Корюковка,Корюківка', 51.7687700, 32.2481300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130072, 'Korsun’-Shevchenkivs’kyy', 'Korsun''-Shevchenkivs''kyy', 'Karun'' Sheychenkovskaya,Karun’ Sheychenkovskaya,Korssun-Schewtschem Kowskij,Korsun'',Korsun''-Shevchenkivs''kij,Korsun''-Shevchenkivs''kyy,Korsun''-Shevchenkovskij,Korsun''-Shevchenkovskiy,Korsun’,Korsun’-Shevchenkivs’kyy,Korsun’-Shevchenkovskiy,Корсунь-Шевченковский,Корсунь-Шевченківський', 49.4189400, 31.2586500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130073, 'Korotych', 'Korotych', 'Korotich,Korotych,Коротич,Коротыч', 49.9473700, 36.0373600, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130074, 'Korostyshiv', 'Korostyshiv', 'Korostishiv,Korostyshev,Korostyshiv,Korostyszow,Korostyszów,Коростишів,Коростышев', 50.3172300, 29.0563000, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130075, 'Korosten’', 'Korosten''', 'Korosten,Korosten'',Korostenj,Korosten’,Korosteń,Koroszteny,Коростень', 50.9593700, 28.6385500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130076, 'Korop', 'Korop', 'Korop,Короп', 51.5663800, 32.9586100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130077, 'Korolevo', 'Korolevo', 'Kirakhaza,Kiralkhaza,Kiralyhaza,Királyháza,Koroleve,Korolevo,Kralovo na Tison,Kralovo nad Tisou,Королеве,Королево', 48.1524700, 23.1365900, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130078, 'Kornyn', 'Kornyn', 'Kornin,Kornyn,Корнин', 50.0953000, 29.5358100, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130079, 'Korniyivka', 'Korniyivka', 'Karneyevka,Korneevka,Korneyevka,Korniivka,Korniyivka,Корнеевка,Корніївка', 50.4166100, 31.4626100, 'UA', '2013-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130080, 'Kormovoye', 'Kormovoye', 'Kormove,Kormovoe,Kormovoye,Togajly,Кормове,Кормовое,Тогайлы́', 45.5000100, 33.6119200, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130081, 'Korets’', 'Korets''', 'Korec,Korec'',Korets,Korets'',Korets’,Korzec,Korzhets,Kozhets,Корец,Корець', 50.6165500, 27.1605500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130082, 'Koreiz', 'Koreiz', 'Koreiz,Кореиз,Кореїз', 44.4337400, 34.0851600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130083, 'Kopychyntsi', 'Kopychyntsi', 'Kopachintsy,Kopichintsy,Kopicinci,Kopychin''tse,Kopychintsa,Kopychintsy,Kopychin’tse,Kopychyn''tse,Kopychyntsi,Kopychyn’tse,Kopyczynce,Kopyczyńce,Копичинці', 49.1044100, 25.9102600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130084, 'Kopayhorod', 'Kopayhorod', 'Kopajgorod,Kopaygorod,Kopayhorod,Копайгород', 48.8591700, 27.7969000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130085, 'Kostyantynivka', 'Kostyantynivka', 'Konstantinovka,Konstantinowka,Kostjantinivka,Kostjantyniwka,Kostyantynivka,Константиновка,Костянтинівка', 48.5277000, 37.7069000, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130086, 'Kostyantynivka', 'Kostyantynivka', 'Konstantinovka,Konstantinovka Yedionkhta,Kostjantinivka,Kostyantynivka,Yedinokhta,Константиновка,Костянтинівка', 46.8167300, 35.4228700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130087, 'Konotop', 'Konotop', 'Gorad Kanatop,Kanatyp,Konotop,Konotopa,Konotopas,ke nuo tuo pu,kho nx thxp,kwnwtwp,qwnwtwp,Горад Канатоп,Канатып,Конотоп,Կոնոտոպ,קונוטופ,کونوتوپ,โคนอทอป,კონოტოპი,科諾托普', 51.2403200, 33.2026300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130088, 'Kondratyevo', 'Kondratyevo', 'Aksjuru-Konrat,Kindratove,Kondrat''evo,Kondratyevo,Аксюру́-Конра́т,Кондратьево,Кіндратове', 45.6312500, 34.4738700, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130089, 'Komsomol’s’ke', 'Komsomol''s''ke', 'Komsomol''s''ke,Komsomol''skoe,Komsomol''skoye,Komsomol’skoye,Komsomol’s’ke,Комсомольское,Комсомольське', 49.5970100, 36.5261800, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130090, 'Kompaniyivka', 'Kompaniyivka', 'Kompaneevka,Kompaneyevka,Kompaniivka,Kompaniyivka,Компанеевка,Компаніївка', 48.2511500, 32.2079500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130091, 'Kominternivs’ke', 'Kominternivs''ke', 'Antono-Kodintsevo,Antono-Kodintsovo,Kominternivs''ke,Kominternivs’ke,Kominternovskoye,Комінтернівське', 46.8128000, 30.9393400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130092, 'Komarno', 'Komarno', 'Komarno,Комарно', 49.6273900, 23.6995200, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130093, 'Kol’tsovo', 'Kol''tsovo', 'Kol''cove,Kol''covo,Kol''tsovo,Kol’tsovo,Tegesh,Кольцове,Кольцово,Теге́ш', 45.3280700, 33.4499200, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130094, 'Koloski', 'Koloski', 'Koloski,Oraz,Колоски,Ора́з', 45.2693600, 33.2938600, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130095, 'Koloniya Zastav’ye', 'Koloniya Zastav''ye', 'Koloniya Zastav''ye,Koloniya Zastav’ye,Zastav''ye,Zastav’ye', 50.8166700, 27.0333300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130096, 'Kolomyya', 'Kolomyya', 'Colomeea,Kholomya,Kolomea,Kolomea-Ost,Kolomeo,Kolomija,Kolomyia,Kolomyja,Kolomyya,Kołomyja,Коломия,Коломыя', 48.5311500, 25.0364900, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130097, 'Kolomak', 'Kolomak', 'Kolomak,Коломак', 49.8398700, 35.3044100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130098, 'Kolodeznoye', 'Kolodeznoye', 'Chongrav,Kolodeznoe,Kolodeznoye,Kolodjazne,Колодезное,Колодязне,Чонгра́в', 45.2268200, 34.3369800, 'UA', '2016-07-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130099, 'Kolodenka', 'Kolodenka', 'Kolodenka,Колоденка', 50.5856100, 26.3160100, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130100, 'Kolochava', 'Kolochava', 'Alsokalocsa,Alsókalocsa,Kolocava,Kolochava,Koločava,Nizhni Kolochava,Колочава', 48.4285100, 23.6959000, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130101, 'Kulevcha', 'Kulevcha', 'Culevcea,Kolesnoye,Kolisne,Kolësnoye,Kulevcha,Kulevchya,Кулевча', 46.0303400, 29.9361400, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130102, 'Kol’chugino', 'Kol''chugino', 'Bulganak,Kol''chugine,Kol''chugino,Kol’chugino,Kronental'',Булгана́к,Кольчугине,Кольчугино,Кронента́ль', 44.9436700, 33.7886500, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130103, 'Kodyma', 'Kodyma', 'Kodima,Kodyma,Кодима,Кодыма', 48.0987500, 29.1246300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130104, 'Kodra', 'Kodra', 'Kodra,Кодра', 50.5948800, 29.5587300, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130105, 'Kochetok', 'Kochetok', 'Kochegok,Kochetok,Кочеток', 49.8800500, 36.7372300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130106, 'Kobyzhcha', 'Kobyzhcha', 'Kobizhcha,Kobyzhcha,Kobyzhchi,Кобижча,Кобыжча', 50.8285400, 31.5043900, 'UA', '2012-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130107, 'Kobleve', 'Kobleve', 'Kobleve,Koblevo,Koblewo,Коблеве,Коблево', 46.6649900, 31.2080400, 'UA', '2012-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130108, 'Kobelyaky', 'Kobelyaky', 'Kobeljaki,Kobelyaki,Kobelyaky,Кобеляки', 49.1489200, 34.1965300, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130109, 'Knyazhichi', 'Knyazhichi', 'Knjazhichi,Knyazhichi,Княжичи', 50.4627500, 30.7836900, 'UA', '2010-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130110, 'Klishkivtsi', 'Klishkivtsi', 'Cliscauti,Clişcăuţi,Klishkauts'',Klishkauts’,Klishkivtsi,Klishkovtsy,Kliskivci,Клішківці', 48.4316100, 26.2623100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130111, 'Klevan’', 'Klevan''', 'Klevan'',Klevan’,Klewan,Klewań,Клевань', 50.7430500, 25.9762800, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130112, 'Klenovyy', 'Klenovyy', 'Klenovij,Klenovyy,Кленовий', 48.1193400, 39.4588000, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130113, 'Klembivka', 'Klembivka', 'Klembivka,Klembovka,Клембівка', 48.3903700, 28.4109200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130114, 'Klavdiyevo-Tarasove', 'Klavdiyevo-Tarasove', 'Dachi Klavdiyevo,Klavdievo-Tarasove,Klavdievo-Tarasovo,Klavdiyevo-Tarasove,Klavdiyevo-Tarasovo,Клавдиево-Тарасово,Клавдіэво-Тарасове,Клавдієво-Тарасове', 50.5841600, 30.0113400, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130115, 'Kivertsi', 'Kivertsi', 'Kiverci,Kivertse,Kivertsi,Kivertsy,Kiwerce,Ківерці', 50.8342500, 25.4582100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130116, 'Kitsman’', 'Kitsman''', 'Cotman,Cozmeni,Kicman'',Kitsman'',Kitsman’,Kotsman,Kotsmen,Kotzman,Kozmeny,Кіцмань', 48.4435700, 25.7668000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130117, 'Shirokoye', 'Shirokoye', 'Kitaj,Shiroke,Shirokoe,Shirokoye,Кита́й,Широке,Широкое', 45.2002900, 34.0506900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130118, 'Kirovskoye', 'Kirovskoye', 'Kirovs''ke,Kirovskoe,Kirovskoye,Кировское,Кіровське', 45.5450300, 33.0776900, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130119, 'Kirovskoye', 'Kirovskoye', 'Islam-Terek,Kirovs''ke,Kirovskoe,Kirovskoye,Исла́м-Тере́к,Кировское,Кіровське', 45.2296700, 35.1998700, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130120, 'Kirovs’k', 'Kirovs''k', 'Golubovka,Kirovs''k,Kirovsk,Kirovs’k,Кировск,Кіровськ', 48.6375100, 38.6428000, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130121, 'Kropyvnytskyi', 'Kropyvnytskyi', 'Elizavetgrad,Gorad Kiravagrad,KGO,Kirovo,Kirovograd,Kirovogrado,Kirovohrad,Kirovohrada,Kirovohradas,Kirovohrado,Kirovoqrad,Kirowo,Kirowograd,Kirowohrad,Kropivnic''kij,Kropyvnytskyi,Sinowjewsk,Yelisavetgrad,Yelizavetgrad,Yelizavety,Zinov''evsk,Zinov''yevsk,Zinovievsk,Zinov’evsk,Zinov’yevsk,ji luo wo ge lei,kiloboheuladeu,kirovu~ofurado,kyrwwhrad,qyrwbwgrd,Горад Кіраваград,Кировоград,Кропивницький,Кіровоград,Կիրովոգրադ,קירובוגרד,کیرووهراد,کیرووہراد,კიროვოგრადი,キロヴォフラード,基洛沃格勒,키로보흐라드', 48.5132000, 32.2597000, 'UA', '2016-10-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130122, 'Kirovo', 'Kirovo', 'Kirove,Kirovo,Vojkovshtadt,Войковшта́дт,Кирово,Кірове', 45.2210600, 35.8422700, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130123, 'Kyrylivka', 'Kyrylivka', 'Kirilivka,Kirillovka,Kyrylivka,Кирилівка', 46.3759200, 35.3675300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130124, 'Kyrykivka', 'Kyrykivka', 'Kirikivka,Kirikovka,Kyrykivka,Кириковка,Кириківка', 50.3640800, 35.1149000, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130125, 'Kiliya', 'Kiliya', 'Chilia,Chilia Noua,Chilia-Noua,Chilia-Nouă,Kilaya,Kilia Noue,Kilija,Kiliya,Kiliya Noua,Килия,Кілія', 45.4551800, 29.2636700, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130126, 'Khyriv', 'Khyriv', 'Chyriw,Chyrow,Chyrów,Hiriv,Hiriva,Hîriv,Hıriv,Khiriv,Khyriv,Khyrov,Khyruv,Kolo Chyrowa,Xirov,hei luo fu,hyrwb,khirovi,khyryf,Хирів,Хыров,Խիրով,חירוב,خیریف,ხიროვი,黑羅夫', 49.5341700, 22.8553800, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130127, 'Khust', 'Khust', 'Chust,Guste,Huszt,Khust,Хуст', 48.1793000, 23.2990900, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130128, 'Khrystynivka', 'Khrystynivka', 'Christinowka,Hristinivka,Khristinivka,Khristinovka,Khrystynivka,Kristinovka,Христинівка', 48.8248800, 29.9680500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130129, 'Khotiv', 'Khotiv', 'Khotiv,Khotov,Хотов,Хотів', 50.3306900, 30.4683600, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130130, 'Khotyn', 'Khotyn', 'Chocim,Chocimi csata,Chotyn,Hotin,Khotin,Khotyn,Ĥotin,Хотин,Хотын', 48.5069300, 26.4912100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130131, 'Khorostkiv', 'Khorostkiv', 'Chorostkow,Chorostków,Horostkiv,Khorostkiv,Khorostkov,Khorostkuv,Хоростків', 49.2111400, 25.9216500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130132, 'Khorosheve', 'Khorosheve', 'Khorosheve,Khoroshevo,Хорошеве,Хорошево', 49.8541300, 36.2170400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130133, 'Khorol', 'Khorol', 'Khorol,Хорол', 49.7836700, 33.2783300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130134, 'Kholmy', 'Kholmy', 'Kholmi,Kholmy,Холми,Холмы', 51.8709600, 32.6006300, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130135, 'Khodoriv', 'Khodoriv', 'Chodoriv,Chodoriw,Chodorov,Chodorow,Chodorów,Hodoriv,Hodoriva,Jodoriv,Jódoriv,Khodoriv,Khodorov,Xodorov,huo duo luo fu,hwdwrwb,khodorovi,khwdwryf,Ходоров,Ходорів,Խոդորով,חודורוב,خودوریف,ხოდოროვი,霍多羅夫', 49.4099300, 24.3047000, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130136, 'Khmelnytskyi', 'Khmelnytskyi', 'Chmelnyzkyj,HMJ,Kamelnitskiy,Khmel''nic''kij,Khmel''nickij,Khmel''nitskiy,Khmel''nyts''kyy,Khmelinitski,Khmel’nitskiy,Khmel’nyts’kyy,Proskurov,Proskurovak,Proskurow,Проскуров,Хмельницкий,Хмельницький', 49.4216100, 26.9965300, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130137, 'Khmil’nyk', 'Khmil''nyk', 'Khmel''nik,Khmel''niki,Khmel’nik,Khmel’niki,Khmil''nik,Khmil''nyk,Khmil’nyk,Хмельник,Хмільник', 49.5597900, 27.9575400, 'UA', '2010-08-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130138, 'Khymchyn', 'Khymchyn', 'Khimchin,Khomchin,Khymchyn,Химчин', 48.3863900, 25.1480300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130139, 'Kherson', 'Kherson', 'Cherson,Chersona,Chersonas,Chersoń,Gorad Kherson,H''erson,Herson,Hersona,Hersono,Herszon,H’erson,Jerson,Jersón,KHE,Kherson,Xerson,he er song,heleuson,heruson,hrswn,khersana,khersoni,khrswn,khyrswn,Ĥersono,Χερσώνα,Горад Херсон,Херсон,Խերսոն,חרסון,خرسون,خيرسون,خیرسون,खेर्सन,ხერსონი,ヘルソン,赫尔松,헤르손', 46.6558100, 32.6178000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130140, 'Khartsyz’k', 'Khartsyz''k', 'Kharciz''k,Kharcyzsk,Khartsysk,Khartsyz''k,Khartsyzsk,Khartsyz’k,Харцизьк,Харцызск', 48.0424300, 38.1472800, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130141, 'Kharkiv', 'Kharkiv', 'Carcovia,Carcóvia,Charcovia,Charkiv,Charkiw,Charkov,Charkovas,Charkow,Charków,HRK,Harkiv,Harkiva,Harkivo,Harkov,Harkova,Jarkov,Khar''kov,Kharkiv,Kharkov,Khar’kov,ha er ke fu,haleukiu,harikofu,hrqwb,kaleukipeu,kalipeu,kharkwf,Ĥarkivo,Ĥarkov,Харков,Харків,Харьков,חרקוב,خاركوف,ხარკოვი,ハリコフ,哈爾科夫,카르키프,카리프,하르키우', 49.9808100, 36.2527200, 'UA', '2017-06-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130142, 'Kerch', 'Kerch', 'Bospor,KHC,Kerc,Kerc'',Kerca,Kerce,Kerch,Kerch'',Kerci,Kerco,Kercs,Kercz,Keric,Keritch,Keriç,Kertch,Kertj,Kerts,Kertsch,Kertschia,Kertsj,Kertx,Kertš,Kerç,Kerĉo,Kerč,Kerč'',Kerča,Kerčė,Panticapaeum,ke chi,keleuchi,kerchi,keruchi,krch,kyrtsh,qrz,Κερτς,Керч,Керчь,Կերչ,קרץ,كيرتش,کرچ,ქერჩი,ケルチ,刻赤,케르치', 45.3531000, 36.4742900, 'UA', '2016-05-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130143, 'Kel’mentsi', 'Kel''mentsi', 'Chelmenti,Chelmenţi,Kel''menci,Kel''mentsi,Kel''mentsy,Kel’mentsi,Kel’mentsy,Кельменці', 48.4650300, 26.8345700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130144, 'Kehychivka', 'Kehychivka', 'Kegichevka,Kegichëvka,Kegicivka,Kehychivka,Кегичевка,Кегичівка', 49.2865600, 35.7615300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130145, 'Kozyatyn', 'Kozyatyn', 'Kasatin,Kazatin,Kozjatin,Kozyatyn,qwzyʼtyn,Козятин,קוזיאטין', 49.7143100, 28.8338500, 'UA', '2016-12-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130146, 'Kazanka', 'Kazanka', 'Kanzanka,Kazanka,Kazanko,Kazavka,Kazenka,Казанка', 47.8462500, 32.8217700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130147, 'Kozachi Laheri', 'Kozachi Laheri', 'Kazach''i,Kazach''i Lageri,Kazach’i,Kazach’i Lageri,Kozachi Lageri,Kozachi Laheri,Kozaci Lageri,Казачьи Лагери,Козачі Лагері', 46.7037200, 32.9776000, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130148, 'Kaydaki', 'Kaydaki', 'Koydaki,Starye Kodaki,Старые Кодаки', 48.3767800, 35.1239800, 'UA', '2010-06-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130149, 'Katyuzhanka', 'Katyuzhanka', 'Katiuzhanka,Katjuzhanka,Katyuzhanka,Катюжанка', 50.8059500, 30.1376300, 'UA', '2014-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130150, 'Katerynopil’', 'Katerynopil''', 'Ekaterinople,Kal''niboloto,Kal’niboloto,Katerinopil'',Katerinopol'',Katerinopol’,Katerynopil'',Katerynopil’,Malyj Jekaterinopol,Yekaterinopol'',Yekaterinopol’,Катеринополь,Катеринопіль', 48.9553000, 30.9682300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130151, 'Karlivka', 'Karlivka', 'Karlivka,Karliwka,Karlovka,Karlowka,ka er li fu ka,karlyfka,Карловка,Карлівка,Կարլովկա,کارلیفکا,კარლოვკა,卡爾利夫卡', 49.4572300, 35.1297500, 'UA', '2015-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130152, 'Soledar', 'Soledar', 'Imeni Karla Libknekhta,Karla Libknekhta,Karlo-Libknekhtovo,Karlo-Libknekhtovsk,Poselok,Soledar,Соледар', 48.6793500, 38.0890200, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130153, 'Karapyshi', 'Karapyshi', 'Karapishi,Karapisi,Karapyshi,Карапиші,Карапыши', 49.6423700, 30.7900200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130154, 'Kapitanivka', 'Kapitanivka', 'Kapitanivka,Kapitanovka,Капитановка,Капітанівка', 48.9171900, 31.7167100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130155, 'Kaniv', 'Kaniv', 'Gorad Kaneu,Kanev,Kanew,Kaniow,Kaniv,Kaniva,Kanivas,Kaniw,Kaniów,Kanëv,Kaņiva,Kániv,ka ni fu,kaniu,kanyf,qnyb,Горад Канеў,Канев,Канив,Канів,Կանև,קניב,کانیف,კანევი,カニウ,卡尼夫,카니우', 49.7518200, 31.4600400, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130156, 'Komysh-Zorya', 'Komysh-Zorya', 'Kamysh-Zarja,Kamysh-Zarya,Komish-Zorja,Komysh-Zorya,Камыш-Заря,Комиш-Зоря', 47.3275500, 36.6929800, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130157, 'Komyshnya', 'Komyshnya', 'Kamyshnja,Kamyshnya,Komishnja,Komyshno,Komyshnya,Камышня,Комишня', 50.1835900, 33.6826900, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130158, 'Kamyshevka Vtoraya', 'Kamyshevka Vtoraya', 'Chemchelul Mare,Kamyshevka Vtoraya', 46.2333300, 29.8333300, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130159, 'Komyshuvakha', 'Komyshuvakha', 'Kamyshevakha,Komishuvakha,Komyshuvakha,Комишуваха', 47.7159800, 35.5298100, 'UA', '2016-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130160, 'Komyshany', 'Komyshany', 'Arnautka,Kamyshany,Komishani,Komyshany,Комишани', 46.6371600, 32.5071900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130161, 'Kamianets-Podilskyi', 'Kamianets-Podilskyi', 'KCP,Kam"yanets''-Podil''s''kyy,Kam''janec''-Podil''s''kij,Kamenec-Podol''skij,Kamenec-Podolski,Kamenets Podol''ski,Kamenets Podol’ski,Kamenets-Podilski,Kamenets-Podol''sk,Kamenets-Podol''skiy,Kamenets-Podol’sk,Kamenets-Podol’skiy,Kamenez-Podolsk,Kamianets-Podilskyi,Kamieniec Podolski,Kamjanec''-Podil''s''kij,Kamjanets-Podilskoi,Kamjanets-Podilskyi,Kamjanets-Podilskyj,Kamjanets-Podilskõi,Kamjanez-Podilskyj,Kamyanets-Podilsky,Kam”yanets’-Podil’s’kyy,qmnyz-pwdwlsqy,qʼamʻnyz,qʼamʻnʻz־pʼdʼlsq,Каменец-Подолски,Каменец-Подольский,Камянець-Подільський,Кам’янець-Подільський,קאַמעניץ,קאַמענעץ־פאדאלסק,קמניץ-פודולסקי', 48.6845000, 26.5855900, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130162, 'Kamennyye Potoki', 'Kamennyye Potoki', 'Kam"yani Potoky,Kam''jani Potoki,Kamenno-Pototskoye,Kamennye_potoki,Kamennyye Potok,Kamennyye Potoki,Kam”yani Potoky,Каменные_потоки,Кам’яні Потоки', 48.9797400, 33.5263800, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130163, 'Millerovo', 'Millerovo', 'Kam"yane,Kam''jane,Kamennoe,Kamennoye,Kam”yane,Millerovo,Каменное,Кам’яне', 48.1682900, 39.1653700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130164, 'Kamin’-Kashyrs’kyy', 'Kamin''-Kashyrs''kyy', 'Kamen'' Koshirski,Kamen''-Kashirsk,Kamen''-Kashirskiy,Kamen''-Koshirskiy,Kamen-Koschyrski,Kamen’ Koshirski,Kamen’-Kashirsk,Kamen’-Kashirskiy,Kamen’-Koshirskiy,Kamien Koszyrski,Kamień Koszyrski,Kamin''-Kashirs''kij,Kamin''-Kashyrs''kyy,Kamin’-Kashyrs’kyy,Камінь-Каширський', 51.6241200, 24.9586400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130165, 'Kamenka-Na-Dnepre', 'Kamenka-Na-Dnepre', 'Kam"yanka-Dniprovs''ka,Kam''janka-Dniprovs''ka,Kamenka,Kamenka-Dneprovskaja,Kamenka-Dneprovskaya,Kamenka-Na-Dnepre,Kam”yanka-Dniprovs’ka,Каменка-Днепровская,Кам’янка-Дніпровська', 47.4848100, 34.4114600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130166, 'Kamionka Strumitowa', 'Kamionka Strumitowa', 'Kam"yanka-Buz''ka,Kam''janka-Buz''ka,Kamenka,Kamenka Strumilova,Kamenka-Bugskaya,Kamenka-Strumilovskaya,Kamionka,Kamionka Strumitowa,Kam”yanka-Buz’ka,Кам’янка-Бузька', 50.1065500, 24.3445100, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130167, 'Kamianka', 'Kamianka', 'Kam"yanka,Kam''janka,Kamenka,Kamenka-Shevchenkovskaya,Kamianka,Kam”yanka,Каменка,Кам’янка', 49.0318000, 32.1039600, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130168, 'Kamianytsia', 'Kamianytsia', 'Kam"yanytsya,Kam''janicja,Kamenica,Kamenica Nad Uh,Kamenitsa,Kamennitsa,Kam”yanytsya,Okementse,Каменица,Кам’яниця', 48.6934300, 22.3957000, 'UA', '2012-12-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130169, 'Kalush', 'Kalush', 'Kalouch,Kalush,Kalusz,Katusz,Kałusz,karushu,Калуш,קאַלוש,カルシュ', 49.0118700, 24.3730800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130170, 'Kalyny', 'Kalyny', 'Alsokalinfalva,Alsókálinfalva,Kalini,Kaliny,Kalyny,Калини', 48.1407800, 23.8738000, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130171, 'Kalynivka', 'Kalynivka', 'Kalinivka,Kalinovka,Kalinovskiy,Kalinowka,Kalinówka,Kalynivka,Kalyniwka,Kalînivka,Kalınivka,ka li ni fu ka,kalynywka,karu~iniuka,Калинивка,Калиновка,Калинівка,Կալինովկա,קאליניבקה,کالینیوکا,კალინოვკა,カルィーニウカ,卡利尼夫卡', 49.4538900, 28.5260800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130172, 'Kalinovka', 'Kalinovka', 'Kalinivka,Kalinovka,Korpe,Калиновка,Калинівка,Корпе́', 45.3165800, 35.7464300, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130173, 'Kalinino', 'Kalinino', 'Kalinindorf,Kalinine,Kalinino,Najleten,Orman-Adzhi,Калининдо́рф,Калинино,Калініне,Найле́тен,Орма́н-Аджи́', 45.7426200, 33.7767600, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130174, 'Kalinino', 'Kalinino', 'Kalinindorf,Kalinine,Kalinino,Калининдо́рф,Калинино,Калініне', 45.5952100, 34.2203000, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130175, 'Kalcheva', 'Kalcheva', 'Calceva,Kal''chevo,Kalcheva,Kalchevaya,Kal’chevo,Калчева', 45.7374600, 28.8144100, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130176, 'Kalanchak', 'Kalanchak', 'Kalanchak,Каланчак', 46.2562300, 33.2907000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130177, 'Mirnoye', 'Mirnoye', 'Mirne,Mirnoe,Mirnoye,Sarajly-Kijat,Мирне,Мирное,Сарайлы́-Кия́т', 44.9833000, 34.0616000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130178, 'Kakhovka', 'Kakhovka', 'Kachovka,Kachowka,Kahovka,Kajovka,Kakhovka,Kaxovka,ka huo fu ka,kakhwfka,Каховка,Կախովկա,کاخوفکا,კახოვკა,卡霍夫卡', 46.8137100, 33.4869800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130179, 'Kayiry', 'Kayiry', 'Kairi,Kairy,Kayiry,Zapadnyye Kairy,Каїри', 46.9453700, 33.7059100, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130180, 'Kaharlyk', 'Kaharlyk', 'Kagarlik,Kagarlyk,Kagorlyk,Kaharlyk,Кагарлик,Кагарлык', 49.8623300, 30.8281500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130181, 'Kadubivtsi', 'Kadubivtsi', 'Kadobeste,Kadobovtsy,Kadubivci,Kadubivtsi,Кадубівці', 48.5833700, 25.7687100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130182, 'Kacha', 'Kacha', 'Kacha,Kaco,Kacza,Kascsa,Katcha,Katsja,Kaĉo,Qaci,Qaçı,ka qia,Кача,Կաչա,卡恰', 44.7763500, 33.5438700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130183, 'Izyumovka', 'Izyumovka', 'Izjumivka,Izjumovka,Izyumovka,Tamgadzhi,Ізюмівка,Изюмовка,Тамгаджи́', 45.0443700, 35.1371700, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130184, 'Izyum', 'Izyum', 'Izjum,Izyum,Изюм', 49.2087500, 37.2484900, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130185, 'Izyaslav', 'Izyaslav', 'Izjaslav,Izyaslav,Izyaslavl'',Izyaslavl’,Ізяслав,Изяслав', 50.1194700, 26.8212500, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130186, 'Izobil’noye', 'Izobil''noye', 'Izobil''ne,Izobil''noe,Izobil''noye,Izobil’noye,Tamak,Ізобільне,Изобильное,Тама́к', 45.5701900, 34.9446900, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130187, 'Izobil’noye', 'Izobil''noye', 'Izobil''ne,Izobil''noe,Izobil''noye,Izobil’noye,Korbek,Ізобільне,Изобильное,Корбе́к', 44.7027600, 34.3535700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130188, 'Izmayil', 'Izmayil', 'Ismail,Ismajil,Izmail,Izmaił,Izmayil,Tuchkov,İsmail,Ізмаїл,Измаил,Измаїл', 45.3492900, 28.8407900, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130189, 'Yizhivtsi', 'Yizhivtsi', 'Idzesti,Izhevtsy,Izivci,Yizhivtsi,Їжівці', 48.0396200, 25.6623200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130190, 'Iza', 'Iza', 'Iza,Іза,Иза', 48.2152500, 23.3286700, 'UA', '2012-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130191, 'Ivanivka', 'Ivanivka', 'Ivanivka,Ivanovka,Yanovka,Іванівка', 46.9756900, 30.4699800, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130192, 'Ivanivka', 'Ivanivka', 'Ivanivka,Ivanovka,Iwanowka,Іванівка,Ивановка,Иванівка', 46.7208200, 34.5529800, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130193, 'Ivanovka', 'Ivanovka', 'Ivanivka,Ivanovka,Kamyshly,Іванівка,Ивановка,Камышлы́', 45.0720000, 33.6613000, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130194, 'Ivano-Frankivs’k', 'Ivano-Frankivs''k', 'IFO,Ivano-Frankivs''k,Ivano-Frankivs’k,Ivano-Frankovsk,Stanislau,Stanislav,Stanislavov,Stanislavyv,Stanislaw,Stanislawow,Stanisław,Stanisławów,stnyslb,stʼnyslʼww,ʼywwnw-prnqybsq,Івано-Франківськ,Ивано-Франковск,איוונו-פרנקיבסק,סטאניסלאוו,סטניסלב', 48.9215000, 24.7097200, 'UA', '2017-07-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130195, 'Ivankiv', 'Ivankiv', 'Ivankiv,Ivankov,Iwankow,Іванків,Иванків', 50.9386500, 29.8942600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130196, 'Ivanychi', 'Ivanychi', 'Ivaniche,Ivanichi,Ivanychi,Iwanicze,Іваничі', 50.6387900, 24.3600300, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130197, 'Ispas', 'Ispas', 'Ispas,Испас', 48.2973400, 25.2740600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130198, 'Ishun’', 'Ishun''', 'Ishun'',Ishun’,UEjsuen,Üjšün,Ішунь,Ишунь', 45.9240300, 33.8236400, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130199, 'Irshava', 'Irshava', 'Gorad Irshava,Ilosva,Iloșva,Irchava,Irsava,Irschawa,Irshava,Irsjava,Irszawa,Irŝava,Iršava,ayrshawa,irshava,yi er sha wa,İrşava,Іршава,Горад Іршава,Иршава,Իրշավա,אירשבה,ארשעווע,ایرشاوا,ირშავა,伊爾沙瓦', 48.3166700, 23.0384600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130200, 'Irpin', 'Irpin', 'Dachi Irpen'',Dachi Irpen’,Irpen,Irpen'',Irpen’,Irpien,Irpień,Irpin,Irpin'',Irpina,Irpin’,Irpiń,Irpiņa,Irpiň,ayrpyn,yi er ping,İrpin,Ірпінь,Ирпень,Ирпињ,Իրպեն,ایرپین,ირპენი,伊爾平', 50.5217500, 30.2505500, 'UA', '2017-05-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130201, 'Ilovays’k', 'Ilovays''k', 'Ilovaiskaia,Ilovajsk,Ilovays''k,Ilovayskaya,Ilovays’k,Иловайск', 47.9249800, 38.2023500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130202, 'Illichivs’k', 'Illichivs''k', 'Il''ichevka,Il''ichevsk,Illichivs''k,Illichivs’k,Ilyitschovsk,Il’ichevka,Il’ichevsk,Il’ichëvsk,Іллічівськ,Ильичевск', 46.3049500, 30.6547800, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130203, 'Illintsi', 'Illintsi', 'Il''intsy,Illinci,Illintsi,Il’intsy,Іллінці,Иллінці', 49.1047900, 29.2177300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130204, 'Ilychyovo', 'Ilychyovo', 'Il''ichjovo,Illicheve,Ilychyovo,Karakuj,Іллічеве,Ильичёво,Караку́й', 45.2834800, 35.7386400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130205, 'Ilyichevo', 'Ilyichevo', 'Il''ichjovo,Illicheve,Ilyichovo,Kijanly,Іллічеве,Ильичёво,Киянлы́', 45.2452400, 35.0712700, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130206, 'Ichnya', 'Ichnya', 'Ichnja,Ichnya,Itschnja,Malaya Ichnya,Ічня,Ичня', 50.8625800, 32.3942500, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130207, 'Horodok', 'Horodok', 'Gorodok,Gorodok-Proskurovskiy,Horodok,Городок', 49.1637400, 26.5839400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130208, 'Horlivka', 'Horlivka', 'Gorlauka,Gorlivka,Gorlovk,Gorlovka,Gorlovko,Gorlowka,Gorłówka,Górlovka,Horlivka,Horliwka,Horļivka,Hòrlivka,Qorlivka,ge er luo fu ka,gorlovkʼa,holeulliuka,hwrlybqh,hwrlyfka,Горлаўка,Горловк,Горловка,Горловко,Горлівка,Һорливка,Գորլովկա,הורליבקה,هورليفكا,هورلیفکا,გორლოვკა,戈爾洛夫卡,호를리우카', 48.3357600, 38.0532500, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130209, 'Hlyboka', 'Hlyboka', 'Adancata,Adynkata,Gliboka,Glibookaya,Glyboka,Glybokaya,Hlyboka,Khliboka,Глибока', 48.0897100, 25.9293300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130210, 'Hlukhiv', 'Hlukhiv', 'Gluchoff,Gluchow,Gluhiv,Glukhiv,Glukhov,Gluxov,Gorad Glukhiu,Głuchów,Hloechiv,Hloukhiv,Hluchiv,Hluchivas,Hluchiw,Hluhiv,Hluhiva,Hlujiv,Hlukhiv,Hlújiv,furuhiu,ge lu huo fu,glukhovi,heulluhiu,hlwhyb,hlwkhyf,Глухив,Глухов,Глухів,Горад Глухіў,Գլուխով,הלוחיב,هلوخيف,هلوخیف,გლუხოვი,フルーヒウ,格盧霍夫,흘루히우', 51.6782200, 33.9162000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130211, 'Hvizd', 'Hvizd', 'Gvizd,Gvozd,Hvizd,Гвізд', 48.6851700, 24.5505500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130212, 'Gvardeyskoye', 'Gvardeyskoye', 'Akchora,Gvardejskoe,Gvardeyskoye,Gvardijs''ke,Акчора́,Гвардейское,Гвардійське', 45.5868800, 33.9768100, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130213, 'Gvardeyskoye', 'Gvardeyskoye', 'Gvardejskoe,Gvardeyskoye,Gvardijs''ke,Sarabuz,Spat,Гвардейское,Гвардійське,Сарабуз,Спат', 45.1169200, 34.0218800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130214, 'Huty', 'Huty', 'Guti,Guty,Huty,Гути,Гуты', 50.1332200, 35.3439400, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130215, 'Husiatyn', 'Husiatyn', 'Gusjatin,Gusyatin,Husiatyn,Husyatyn,Гусятин', 49.0726300, 26.2141000, 'UA', '2017-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130216, 'Gurzuf', 'Gurzuf', 'Gurzuf,Гурзуф', 44.5462400, 34.2784100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130217, 'Hupalivka', 'Hupalivka', 'Gupalivka,Gupalovka,Hupalivka,Гупаловка,Гупалівка', 49.1113900, 34.7355600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130218, 'Hulyaypole', 'Hulyaypole', 'Guljai-Pole,Guljajpole,Gulyai Pole,Gulyaypole,Hulyaypole,Гуляйполе', 47.6638900, 36.2563300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130219, 'Hubynykha', 'Hubynykha', 'Gubinikha,Hubynykha,Губиниха', 48.8098000, 35.2560200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130220, 'Grushevka', 'Grushevka', 'Grushevka,Grushivka,Saly,Грушевка,Грушівка,Салы́', 45.0228100, 34.9730100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130221, 'Hryshkivtsi', 'Hryshkivtsi', 'Grishkivci,Grishkovtsy,Griskivci,Hryshkivtsi,Гришківці', 49.9352900, 28.6038300, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130222, 'Grishino', 'Grishino', 'Grishine,Grishino,Tokulchak,Toqulcaq,Toqulčaq,Гришине,Гришино,Токулча́к', 45.6421900, 33.8309800, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130223, 'Hrymayliv', 'Hrymayliv', 'Grimajliv,Grimalov,Grimaylov,Grzhimalov,Grzhymalov,Grzymalow,Grzymałów,Gzhimaluv,Hrymayliv,Гримайлів', 49.3320800, 26.0111200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130224, 'Gresovskiy', 'Gresovskiy', 'Grehsovskij,Gresivs''kij,Gresovskiy,Гресівський,Грэсовский', 45.0080400, 34.0265700, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130225, 'Hrebinka', 'Hrebinka', 'Grebenka,Grebenkovskiy,Grebinka,Grebënka,Hrebinka,Гребенка,Гребінка', 50.1171200, 32.4361000, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130226, 'Hradyz’k', 'Hradyz''k', 'Gradiz''k,Gradizhsk,Hradyz''k,Hradyz’k,Градижск,Градизьк', 49.2345800, 33.1361300, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130227, 'Hostomel’', 'Hostomel''', 'Gostomel'',Gostomel’,Gostoml'',Gostoml’,Hostomel,Hostomel'',Гостомель', 50.5684100, 30.2651000, 'UA', '2017-05-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130228, 'Hoshcha', 'Hoshcha', 'Goshcha,Goshha,Hoshcha,Hoszcza,Гоща', 50.6003000, 26.6743500, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130229, 'Hirs’ke', 'Hirs''ke', 'Girs''ke,Gorskoe,Gorskoye,Hirs''ke,Hirs’ke,Горское,Гірське', 48.7346800, 38.4954100, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130230, 'Lesnovka', 'Lesnovka', 'Goropashnik,Lesnovka,Lisnivka,Novosjolovka,Горопа́шник,Лесновка,Ліснівка,Новосёловка', 45.1535000, 33.6188900, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130231, 'Horokhiv', 'Horokhiv', 'Gorokhiv,Gorokhov,Gorokhuv,Horochow,Horochów,Horokhiv,Горохів', 50.5018600, 24.7614900, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130232, 'Horodok', 'Horodok', 'Gorodok,Gorodok-Yagellonskiy,Grodek,Grodek Jagiellonski,Grodok Jagiellonski,Grudek Yagellon''ski,Grudek Yagellon’ski,Grudek-Yagel''on''ski,Grudek-Yagel’on’ski,Gródek Jagielloński,Gródok Jagielloński,Horodok,Городок', 49.7846500, 23.6480600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130233, 'Horodnya', 'Horodnya', 'Gorodnja,Gorodnya,Horodnya,Городня', 51.8908500, 31.5974100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130234, 'Horodnytsya', 'Horodnytsya', 'Gorodnicja,Gorodnitsa,Horodnytsya,Городниця', 50.8069700, 27.3167600, 'UA', '2013-02-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130235, 'Horodnye', 'Horodnye', 'Chiishia,Chiishiya,Chiyshiya,Ciisia,Ciişia,Gorodne,Gorodneh,Gorodneye,Gorodnoye,Gradina,Horodne,Horodnye,Ogorodnoye,Городнэ,Городнє', 45.8908300, 28.8483300, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130236, 'Horodyshche', 'Horodyshche', 'Gorodishche,Gorodishhe,Gorodyshche,Horodyshche,Horodyszcze,Городище', 50.6396500, 26.3657300, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130237, 'Horodyshche', 'Horodyshche', 'Gorodishche,Gorodishhe,Horodyshche,Imeni G.I. Petrovskogo,Poselok Imeni G.I. Petrovskogo,Posëlok Imeni G.I. Petrovskogo,Городище', 49.2848900, 31.4451300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130238, 'Horodenka', 'Horodenka', 'Gorodenka,Gorodënka,Horodenka,Городенка', 48.6727400, 25.5016300, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130239, 'Hornostayivka', 'Hornostayivka', 'Gornostaivka,Gornostayevka,Gorostayevka,Hornostayivka,Горностаївка', 47.0077700, 33.7289900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130240, 'Gornostayevka', 'Gornostayevka', 'Akkoz,Aq Koez,Aq Köz,Gornostaevka,Gornostaivka,Gornostayevka,Mariental'',Акко́з,Горностаевка,Горностаївка,Мариента́ль', 45.2781900, 36.1860100, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130241, 'Horinchovo', 'Horinchovo', 'Gorinchovo,Gorincovo,Horinchove,Horinchovo,Horincovo,Horinčovo,Горінчово', 48.2707600, 23.4347500, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130242, 'Golubinka', 'Golubinka', 'Foti-Sala,Golubinka,Голубинка,Фоти́-Сала́', 44.5938200, 33.9152100, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130243, 'Holovyne', 'Holovyne', 'Golovin,Golovine,Golovino,Holovyne,Головине', 50.4711800, 28.8253000, 'UA', '2013-03-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130244, 'Holovanivs’k', 'Holovanivs''k', 'Golovanevsk,Golovanivs''k,Golvanevsk,Holovanivs''k,Holovanivs’k,Голованевск,Голованівськ', 48.3840000, 30.4613100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130245, 'Hołoby', 'Holoby', 'Golobi,Goloby,Holoby,Hołoby,Kholoby,Голоби', 51.0865100, 25.0076700, 'UA', '2012-07-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130246, 'Hola Prystan’', 'Hola Prystan''', 'Gola Pristan'',Golaja Pristan'',Golaya Pristan'',Golaya Pristan’,Hola Prystan'',Hola Prystan’,Гола Пристань,Голая Пристань', 46.5271900, 32.5241700, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130247, 'Hnidyn', 'Hnidyn', 'Gnedin,Gnedyn'',Gnedyn’,Gnidin,Gnidyn,Hnidyn,Гнедин,Гнідин', 50.3289900, 30.7105900, 'UA', '2013-05-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130248, 'Hlobyne', 'Hlobyne', 'Globine,Globino,Hlobyne,Глобине,Глобино', 49.3878400, 33.2595900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130249, 'Hlevakha', 'Hlevakha', 'Glevakha,Hlevakha,Глеваха', 50.2742300, 30.3270600, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130250, 'Glazovka', 'Glazovka', 'Baksy,Glazivka,Glazovka,Баксы́,Глазовка,Глазівка', 45.3879200, 36.5796500, 'UA', '2016-05-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130251, 'Heniches’k', 'Heniches''k', 'Geniches''k,Genichesk,Genitschesk,Heniches''k,Heniches’k,Геническ,Генічеськ', 46.1759200, 34.8034000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130252, 'Hayvoron', 'Hayvoron', 'Gaivoron,Gajvoron,Gayvoron,Hayvoron,Гайворон', 48.3395800, 29.8679100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130253, 'Haisyn', 'Haisyn', 'Gaisin,Gaissin,Gajsin,Gaysin,Haysyn,Гайсин', 48.8114300, 29.3897700, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130254, 'Gaspra', 'Gaspra', 'Gaspra,Haspra,Гаспра', 44.4336400, 34.1029700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130255, 'Halych', 'Halych', 'Aliche,Galic,Galich,Galič,Galıç,Gorad Galich,Halica,Halicas,Halici,Halicz,Halicʻ,Halitsch,Haliča,Haličas,Halyc,Halych,Halytch,Halytsch,Halytsj,Halytx,Halyč,Halîci,galichi,hallichi,halych,halytsh,haru~ichi,jia li qi,Галич,Горад Галіч,Հալիչ,האליץ,هاليتش,هالیچ,გალიჩი,ハールィチ,加利奇,할리치', 49.1217900, 24.7257800, 'UA', '2016-03-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130256, 'Hadyach', 'Hadyach', 'Gadjach,Gadyach,Hadyach,Гадяч', 50.3711200, 33.9909900, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130257, 'Frunzivka', 'Frunzivka', 'Frunzivka,Frunzovka,Zakhar''yevka,Zakharovka,Zakhar’yevka,Фрунзівка', 47.3323200, 29.7590300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130258, 'Shtormovoye', 'Shtormovoye', 'Frunzevka,Shtormove,Shtormovoe,Shtormovoye,Voznesenovka,Вознесе́новка,Фру́нзевка,Штормове,Штормовое', 45.2671700, 33.0869300, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130259, 'Partenit', 'Partenit', 'Partenit,Partenito,pa er jie ni te,Партенит,Партеніт,Պարտենիտ,帕爾捷尼特', 44.5780000, 34.3446400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130260, 'Frunze', 'Frunze', 'Frunze,Фрунзе', 48.6686300, 38.7544400, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130261, 'Frunze', 'Frunze', 'Frunze,Фрунзе', 45.0268800, 33.6295600, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130262, 'Frontovoye', 'Frontovoye', 'Frontove,Frontovoe,Frontovoye,Otarkoj,Отарко́й,Фронтове,Фронтовое', 44.6673700, 33.7384100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130263, 'Foros', 'Foros', 'Foros,Foroso,Phoros,fu luo si,Форос,Ֆորոս,福羅斯', 44.3921400, 33.7879800, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130264, 'Fontanka', 'Fontanka', 'Fontanka,Makagonka,Фонтанка', 46.5664600, 30.8596500, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130265, 'Filatovka', 'Filatovka', 'Filativka,Filatovka,Фiлатiвка,Филатовка', 46.0819200, 33.7851000, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130266, 'Feodosiya', 'Feodosiya', 'Caffa,Feodosia,Feodosija,Feodosiya,Feodossia,Feodossija,Feodosya,Feodòssia,Fyeodosiya,Kaffa,Kefe,Teodosia,Teodozio,Teodozja,Teodósia,Theodosia,Theodosie,Théodosie,feodoshiya,pe-odosiya,Феодосия,Феодосія,フェオドシヤ,페오도시야', 45.0367700, 35.3778900, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130267, 'Fastiv', 'Fastiv', 'Fastiv,Fastiva,Fastiw,Fastov,Fastow,Fastów,fa si di fu,fastyw,pstwb,Фастив,Фастов,Фастів,Ֆաստով,כוואסטוב,פסטוב,فاستیو,ფასტოვი,法斯蒂夫', 50.0767000, 29.9177000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130268, 'Eskhar', 'Eskhar', 'Ehskhar,Eskhar,Есхар,Эсхар', 49.7961400, 36.5904700, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130269, 'Energodar', 'Energodar', 'Ehnergodar,Energodar,Енергодар,Энергодар', 47.4986500, 34.6574000, 'UA', '2010-08-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130270, 'Dzvinogrud', 'Dzvinogrud', 'Dzvinogrud,Zvenigorod,Zvenyhorod,Звенигород', 49.7333300, 24.2500000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130271, 'Mirnovka', 'Mirnovka', 'Dzhurgun,Mirnivka,Mirnovka,Джургу́н,Мирновка,Мирнівка', 45.6908300, 34.3096600, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130272, 'Dzhankoy', 'Dzhankoy', 'Dshankoi,Dzhanhoi,Dzhankoi,Dzhankoj,Dzhankoy,Джанкой', 45.7116800, 34.3927400, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130273, 'Romaniv', 'Romaniv', 'Dsershinsk,Dzerzhinsk,Dzerzhyns''k,Dzerzhyns’k,Romaniv,Romanov,Романів', 50.1480200, 27.9312400, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130274, 'Dzerzhyns’k', 'Dzerzhyns''k', 'Dzerzhins''k,Dzerzhinsk,Dzerzhyns''k,Dzerzhyns’k,Imeni Dzerzhinskogo,Дзержинск,Дзержинськ', 48.3986900, 37.8478700, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130275, 'Demnya', 'Demnya', 'Demnia,Demnja,Demnya,Dymovka,Демня,Дымовка', 49.5673800, 23.9460700, 'UA', '2017-01-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130276, 'Dymer', 'Dymer', 'Dimer,Dymer,Димер,Дымер', 50.7864700, 30.3026000, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130277, 'Dvorichna', 'Dvorichna', 'Dvorichna,Dvoricna,Dvurechnaja,Dvurechnaya,Dvuretshnaya,Дворічна,Двуречная', 49.8501900, 37.6826200, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130278, 'Dunayivtsi', 'Dunayivtsi', 'Dunaivci,Dunayevtsy,Dunayivtsi,Poselok Dunayevtsy,Posëlok Dunayevtsy,Дунаївці', 49.0207800, 26.8412200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130279, 'Dunaivtsi', 'Dunaivtsi', 'Dounaivtsi,Dounaïvtsi,Dunaevcy,Dunaiivti,Dunaiivți,Dunaivci,Dunaivtsi,Dunajewzy,Dunajivciai,Dunajivtsi,Dunajiwzi,Dunajowce,Dunayevtsy,Dunayivtsi,du na yi fu qi,dunaevtsi,dunaivtsi,dwnayftsy,dwnayyftsy,dwnyybzy,Дунаевцы,Дунаївці,Դունաևցի,דונייבצי,دونائیفتسی,دونايفتسي,दुनैव्त्सि,დუნაევცი,杜納伊夫齊', 48.8890900, 26.8563600, 'UA', '2015-07-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130280, 'Duliby', 'Duliby', 'Dulibi,Duliby,Дуліби', 49.2313400, 23.8153200, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130281, 'Dudchany', 'Dudchany', 'Dudchani,Dudchany,Dudchino,Дудчани,Дудчаны', 47.1855700, 33.7639000, 'UA', '2010-08-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130282, 'Dubrovytsya', 'Dubrovytsya', 'Dabrowica,Dombrovitsa,Dubrovicja,Dubrovitsa,Dubrovytsya,Dąbrowica,Дубровиця', 51.5743800, 26.5650300, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130283, 'Dubove', 'Dubove', 'Dombo,Dombó,Dubove,Dubovoye,Дубове', 48.1720500, 23.8895400, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130284, 'Dubno', 'Dubno', 'Doubno,Dubnas,Dubno,do~ubuno,du bu nuo,dubno,dwbnw,Дубно,Դուբնո,דובנו,دوبنو,დუბნო,ドゥブノ,杜布諾', 50.4169400, 25.7343200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130285, 'Dublyany', 'Dublyany', 'Dublany,Dubljani,Dublyany,Дубляни', 49.9041100, 24.0863700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130286, 'Dublyany', 'Dublyany', 'Dobrowlany,Dublany,Dubljani,Dublyany,Дубляни', 49.4983200, 23.3871800, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130287, 'Druzhba', 'Druzhba', 'Druzhba,Khutor Mikhailovsky,Khutor Mikhaylovskiy,Mikhailovskaya Khutor,Mikhaylovskiy Khutor,Дружба', 52.0454500, 33.9451700, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130288, 'Druzhba', 'Druzhba', 'Druzhba,Tribukhovtsy,Trybukhivtsi,Дружба', 49.0425100, 25.4505500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130289, 'Drohobych', 'Drohobych', 'Drogobich,Drogobych,Drogobycz,Drohobic,Drohobico,Drohobiĉ,Drohobiĉo,Drohobych,Drohobycz,Drohobytsch,Drohobytsj,dorohobu~ichi,drwhwbyz,Дрогобич,Дрогобыч,דרוהוביץ,ドロホブィチ', 49.3499100, 23.5056100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130290, 'Drahovo', 'Drahovo', 'Dragovo,Drahove,Drahovo,Драгово', 48.2357300, 23.5491400, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130291, 'Drabiv', 'Drabiv', 'Drabiv,Drabov,Драбов,Драбів', 49.9602900, 32.1407000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130292, 'Dovbysh', 'Dovbysh', 'Dovbish,Dovbysh,Markhlevsk,Довбиш', 50.3733200, 27.9874200, 'UA', '2013-02-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130293, 'Donetsk', 'Donetsk', 'DOK,Donec''k,Doneck,Doneck osh,Donecka,Doneckas,Donecko,Donesk,Donetk,Donetsk,Donetsk i Ukraina,Donezk,Donețk,Donieck,Donietsk,Donjeck,Doněck,Dońeck,Doņecka,Gorad Daneck,Hughesovka,Jusowka,Juzivka,Juzovka,Ntonetsk,Stalin,Staline,Stalino,Yuzovka,Yuzovo,deanerrsk,do net skh,donecheukeu,donetska,donetsu~iku,dun nie ci ke,dwntsk,dwnytsk,dwnzq,tonetsk,Ντονέτσκ,Горад Данецк,Донецк,Донецк ош,Донецьк,Доњецк,Сталино,Сталіне,Сталіно,Юзовка,Юзівка,Դոնեցկ,דונצק,دونتسک,دونيتسك,دونیتسک,دۆنێتسک,दोनेत्स्क,தோனெத்ஸ்க்,ഡൊണെറ്റ്സ്ക്,โดเนตสค์,დონეცკი,ドネツィク,頓涅茨克,도네츠크', 48.0230000, 37.8022400, 'UA', '2017-05-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130294, 'Domanivka', 'Domanivka', 'Domanevka,Domanivka,Доманівка', 47.6319200, 30.9885100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130295, 'Dolyna', 'Dolyna', 'Dolina,Dolyna,Dolîna,Dolına,Gorad Dalyna,dolina,duo li na,dwlyna,dwlynh,Горад Далына,Долина,Դոլինա,דאלינע,דולינה,دولينا,دولینا,დოლინა,多利納', 48.9733000, 24.0094400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130296, 'Dolyns''ka', 'Dolyns''ka', 'Dolinskaja,Dolinskaya,Dolinskoye,Dolyns''ka,Schewtschenkowo,Shevchenkovo,Долинская', 48.1104100, 32.7644900, 'UA', '2010-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130297, 'Dolinnoye', 'Dolinnoye', 'Dolinne,Dolinnoe,Dolinnoye,Topchikoj,Долинне,Долинное,Топчико́й', 44.7532000, 33.7776600, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130298, 'Dovhe', 'Dovhe', 'Dolga,Dolgoye,Dolha,Dovge,Dovhe,Довге', 48.3652700, 23.2790400, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130299, 'Dokuchayevs’k', 'Dokuchayevs''k', 'Dokuchaevs''k,Dokuchaevsk,Dokuchayevs''k,Dokuchayevsk,Dokuchayevs’k,Yelenovskiy Kar''yer,Yelenovskiy Kar’yer,Yelenovskiye Kar''yery,Yelenovskiye Kar’yery,Докучаевск,Докучаєвськ', 47.7504600, 37.6793600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130300, 'Dobryanka', 'Dobryanka', 'Dobrjanka,Dobrovelichkivka,Dobryanka,Добровеличківка,Добрянка', 52.0631400, 31.1856700, 'UA', '2012-11-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130301, 'Dobrushino', 'Dobrushino', 'Dobrushine,Dobrushino,Добрушине,Добрушино', 45.3744100, 33.3654700, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130302, 'Dobroye', 'Dobroye', 'Dobre,Dobroe,Dobroye,Mamut Sultan,Mamut-Sultan,Добрoе,Добре,Маму́т-Султа́н', 44.8663200, 34.2266100, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130303, 'Dobrovelychkivka', 'Dobrovelychkivka', 'Dobrovelichkivka,Dobrovelichkovka,Dobrovelychkivka,Revuc''ke,Revuckoe,Revutskoye,Добровеличковка,Добровеличківка,Ревуцкое,Ревуцьке', 48.3877800, 31.1802800, 'UA', '2017-07-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130304, 'Dobropillya', 'Dobropillya', 'Dobropillja,Dobropillya,Dobropol''e,Dobropol''ye,Dobropol’ye,Krasnoarmeyskiy Rudnik,Доброполье,Добропілля', 48.4614700, 37.0852400, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130305, 'Dobromyl’', 'Dobromyl''', 'Dobromil'',Dobromil’,Dobromyl'',Dobromyl’,Добромиль', 49.5719300, 22.7862900, 'UA', '2016-07-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130306, 'Dnipro', 'Dnipro', 'DNK,Dnepr,Dnepropetrovsk,Dnepropetrovska,Dnepropetrowsk,Dnetropetrovsk,Dniepropetrovsk,Dniepropetrovskas,Dniepropetrowsk,Dnipro,Dnipropetrovs''k,Dnipropetrovsk,Dnipropetrovsko,Dnipropetrovs’k,Dnipropetrowsk,Dnjepropetrovsk,Dnjepropetrowsk,Dnjipropetrovsk,Dnyipropetrovszk,Dněpropetrovsk,Dņepropetrovska,Ekaterinoslav,Ekaṭerinoslav,Gorad Dneprapjatrousk,Iekaterinoslav,Katerynoslav,Ntnipropetrofsk,Yekaterinoslav,Yekaterinovslav,d ni por pet rxfskh,deunipeulopeteulousikeu,di nie bo luo bi de luo fu si ke,dnepropetrovska,dnybrwbtrwfsk,dnyprwptrwbsq,dnyprwptrwfsk,dnyprwptrwwsk,donipuropetoroushiku,Ντνιπροπετρόφσκ,Горад Днепрапятроўск,Днепр,Днепропетровск,Дніпро,Дніпропетровськ,Днїпропетровск,Дњепропетровск,Екатеринослав,Դնեպրոպետրովսկ,דניפרופטרובסק,دنيبروبتروفسك,دنیپروپتروفسک,دنیپروپترووسک,द्नेप्रोपेत्रोव्स्क,ดนีโปรเปตรอฟสค์,დნეპროპეტროვსკი,ドニプロペトロウシク,第聂伯罗彼得罗夫斯克,드니프로페트로우시크', 48.4593000, 35.0386500, 'UA', '2016-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130307, 'Dniprodzerzhyns’k', 'Dniprodzerzhyns''k', 'Dneprodsershinsk,Dneprodzerzhinsk,Dneprodzherzhinsk,Dnieprodzerzhynsk,Dniprodzerzhyns''k,Dniprodzerzhynsk,Dniprodzerzhyns’k,Kamenskoye,Днепродзержинск', 48.5113400, 34.6021000, 'UA', '2016-05-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130308, 'Dnipryany', 'Dnipryany', 'Britany,Dneprjany,Dnepryany,Dniprani,Dniprjani,Dnipryany,Днепряны,Дніпряни', 46.7463100, 33.2728800, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130309, 'Dniprovka', 'Dniprovka', 'Dneprovka,Dniprovka,Днепровка,Дніпровка', 47.4294500, 34.6180500, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130310, 'Dniprorudne', 'Dniprorudne', 'Dneprograd,Dneprorudnoe,Dneprorudnoye,Dniprorudne,Днепрорудное,Дніпрорудне', 47.3816900, 34.9765200, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130311, 'Dmytrivka', 'Dmytrivka', 'Dmitrivka,Dmitrovka,Dmytrivka,Дмитровка,Дмитрівка', 48.7969000, 32.7164500, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130312, 'Dmitrovka', 'Dmitrovka', 'Chjorno-Kosh,Dmitrivka,Dmitrovka,Дмитровка,Дмитрівка,Чёрно-Кош', 45.4841100, 35.0588000, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130313, 'Dmytrivka', 'Dmytrivka', 'Dmitrievka,Dmitrivka,Dmitriyevka,Dmitrovka,Dmytrivka,Дмитровка,Дмитрівка', 47.9361100, 38.9366100, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130314, 'Dymytrove', 'Dymytrove', 'Dimitrove,Dimitrovo,Dymytrove,Димитрове,Димитрово', 48.6076700, 32.9834700, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130315, 'Dmytrivka', 'Dmytrivka', 'Deleni,Dimitresti,Dimitreşti,Dimitrovka,Dmitrivka,Dmitriyevka,Dmitrovka,Dmytrivka,Dumitresht'',Dumitreshti,Dumitresht’,Dumitresti,Dumitreşti,Дмитровка,Дмитрівка', 45.9716700, 28.9863900, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130316, 'Dymytrov', 'Dymytrov', 'Dimitrov,Dimitrova,Dimitrovo,Dymytrov,Dymytrow,Dîmîtrov,Dımıtrov,Imeni Dimitrova,dymytrwf,dymytrwf  awkrayn,ji mi te luo fu,Димитров,Դիմիտրով,ديميتروف,دیمیتروف، اوکراین,დიმიტროვი,季米特洛夫', 48.3052300, 37.2609100, 'UA', '2014-12-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130317, 'Dykan’ka', 'Dykan''ka', 'Dikan''ka,Dikan’ka,Dykan''ka,Dykan’ka,Диканька', 49.8250100, 34.5278700, 'UA', '2014-02-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130318, 'Desna', 'Desna', 'Desna,Десна', 50.9273100, 30.7604800, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130319, 'Derhachi', 'Derhachi', 'Dergachi,Dergaci,Dergacze,Dergatschi,Dergaçi,Derhachi,Derhachy,Derhaci,Derhaciai,Derhatchi,Derhatschi,Derhatsji,Derhači,Derhačiai,dergachi,drhachy,dyrhatshy,jie er jia qi,Дергачи,Дергачі,Դերգաչի,درهاچی,ديرهاتشي,დერგაჩი,傑爾加奇', 50.1065900, 36.1211200, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130320, 'Derazhnya', 'Derazhnya', 'Derazhnja,Derazhnva,Derazhnya,Деражня', 49.2692000, 27.4338200, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130321, 'Demydivka', 'Demydivka', 'Demidivka,Demidovka,Demiduvka,Demydivka,Демидівка', 50.4281400, 25.3361900, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130322, 'Delyatyn', 'Delyatyn', 'Delatyn,Deliatin,Deljatin,Delyatin,Delyatino,Delyatyn,Diljatyn,Dilyatyn,Делятин', 48.5235400, 24.6246600, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130323, 'Dihtyari', 'Dihtyari', 'Degtjari,Degtyari,Degtyary,Digtjari,Dihtyari,Дегтяри,Дігтярі', 50.5826400, 32.7701200, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130324, 'Debal’tseve', 'Debal''tseve', 'Debal''ceve,Debal''cevo,Debal''tseve,Debal''tsevo,Debalzewo,Debal’tseve,Debal’tsevo,Дебальцеве,Дебальцево', 48.3407200, 38.4049000, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130325, 'Davydivka', 'Davydivka', 'Davideni,Davidino,Davidivka,Davidovka,Davydivka,Davydovka,Давидівка', 48.1209900, 25.5646100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130326, 'Dashev', 'Dashev', 'Dashev,Dashiv,Дашев,Дашів', 49.0044900, 29.4255900, 'UA', '2010-04-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130327, 'Dalekoye', 'Dalekoye', 'Chegoltaj Tatarskij,Daleke,Dalekoye,Daljokoe,Далеке,Далёкое,Чеголта́й Тата́рский', 45.6600600, 33.0805900, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130328, 'Dachnoye', 'Dachnoye', 'Dachne,Dachnoe,Dachnoye,Malyj Taraktash,Taraktash,Дачне,Дачное,Малый Таракта́ш,Таракта́ш', 44.8844800, 34.9833300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130329, 'Chutove', 'Chutove', 'Chutove,Chutovo,Чутове,Чутово', 49.7104300, 35.1657100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130330, 'Chulakivka', 'Chulakivka', 'Chulakivka,Chulakovka,Chulokovka,Culakivka,Чулаківка', 46.3576300, 32.3514000, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130331, 'Chuhuyiv', 'Chuhuyiv', 'Chuguev,Chuguiv,Chuguyev,Chuhuyiv,Tschugujew,Чугуев,Чугуїв', 49.8358800, 36.6880300, 'UA', '2016-09-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130332, 'Chudniv', 'Chudniv', 'Chudniv,Chudnov,Cudniv,Tschudnow,Чуднів', 50.0520400, 28.1174500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130333, 'Chortkiv', 'Chortkiv', 'Chertkov,Chortkiv,Chortkov,Chortkuv,Ciortkiv,Cortkiv,Cortkiva,Csortkiv,Czortkow,Czortków,Tchortkiv,Tschortkiw,Tschortkow,Tsjortkiv,chwrtkyf,qiao er te ji fu,zwrtqwb,Çortkiv,Čortkiv,Čortkiva,Чорткив,Чортков,Чортків,Չորտկով,טשארטקאוו,צורטקוב,چورتکیف,ჩორტკოვი,喬爾特基夫', 49.0170900, 25.7980400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130334, 'Chopovychi', 'Chopovychi', 'Chapovichi,Chepovichi,Chopovichi,Chopovychi,Copovici,Чоповичі', 50.8332500, 28.9533400, 'UA', '2017-04-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130335, 'Chop', 'Chop', 'Chap,Chop,Cop,Csap,Csapi,Csop,Czop,Tschop,Čop,Чоп', 48.4319800, 22.2055500, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130336, 'Krasnoye', 'Krasnoye', 'Chalgary,Krasne,Krasnoe,Krasnoye,Красне,Красное,Чалгары́', 45.1399900, 34.0945200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130337, 'Chkalovo', 'Chkalovo', 'Chkalove,Chkalovo,Чкалове,Чкалово', 45.6047400, 34.8339500, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130338, 'Chistopolye', 'Chistopolye', 'Chistopillja,Chistopol''e,Chistopolye,Dere-Salyn,Дере́-Салы́н,Чистополье,Чистопілля', 45.3654100, 36.1831200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130339, 'Chisten’koye', 'Chisten''koye', 'Adzhi-Kal,Chisten''ke,Chisten''koe,Chisten''koye,Chisten’koye,Аджи́-Кал,Чистеньке,Чистенькое', 44.8815200, 34.0471600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130340, 'Chynadiyovo', 'Chynadiyovo', 'Chinadievo,Chinadijovo,Chinadiyevo,Chynadiiovo,Chynadiyeve,Chynadiyovo,Чинадиево,Чинадійово', 48.4817900, 22.8217000, 'UA', '2012-04-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130341, 'Chyhyryn', 'Chyhyryn', 'Cehrin,Chigirin,Chyhyryn,Tchighin,Çehrin,Чигирин', 49.0837600, 32.6554900, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130342, 'Chervonyy Oskil', 'Chervonyy Oskil', 'Chervonyj Oskol,Chervonyy Oskil,Chervonyy Oskol,Krasny Oskol,Krasnyy Oskol,Червоный Оскол', 49.1790600, 37.4259300, 'UA', '2015-08-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130343, 'Chervone', 'Chervone', 'Chervone,Chervonoye,Esman'',Esman’,Luzhki,Червоне', 51.7700600, 34.0672900, 'UA', '2012-02-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130344, 'Chervone', 'Chervone', 'Chervone,Chervonnoye,Chervonoye,Червоне', 49.9497500, 28.8687400, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130345, 'Chervonopartyzans’k', 'Chervonopartyzans''k', 'Chervonopartizans''k,Chervonopartizansk,Chervonopartyzans''k,Chervonopartyzans’k,Chervonopartzansk,Krasnopartizansk,Krasnopartizanskiy,Червонопартизанск,Червонопартизанськ', 48.0761300, 39.7961800, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130346, 'Chervonohryhorivka', 'Chervonohryhorivka', 'Cervonogrigorivka,Chervonogrigorivka,Chervonogrigorovka,Chervonohryhorivka,Krasnogrigor''yevka,Krasnogrigor’yevka,Червоногригоровка,Червоногригорівка', 47.6229800, 34.5388700, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130347, 'Chervonohrad', 'Chervonohrad', 'Cervonohrad,Chervonograd,Chervonohrad,Czerwonohrad,Krasnipali,Krisnipolye,Kristinopol'',Kristinopol’,Krvstonopol,Krystynopol,Червоноград', 50.3910500, 24.2351400, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130348, 'Chervonoarmiys’k', 'Chervonoarmiys''k', 'Chervonnoarmeysk,Chervonoarmeysk,Chervonoarmijs''k,Chervonoarmiys''k,Chervonoarmiys’k,Pulin,Червоноармійськ', 50.4678400, 28.2713000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130349, 'Radyvyliv', 'Radyvyliv', 'Chervonoarmeysk,Chervonoarmiys''k,Chervonoarmiys’k,Radiviliv,Radyvyliv,Radzivilluv,Radzivilov,Радивилів', 50.1299400, 25.2557600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130350, 'Chervona Sloboda', 'Chervona Sloboda', 'Chervona Sloboda,Chervonaja Sloboda,Chervonaya Sloboda,Chervonaya Slobodka,Krasnaya Sloboda,Червона Слобода,Червоная Слобода', 49.3789000, 32.1464300, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130351, 'Chortomlyk', 'Chortomlyk', 'Aleksandrovka,Alekseyevka,Chertomlyk,Chortomlik,Chortomlyk,Чертомлык,Чортомлик', 47.6231500, 34.1419800, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130352, 'Chernyatyn', 'Chernyatyn', 'Chernjatin,Chernyatin,Chernyatyn,Czerniatyn,Чернятин', 48.6603400, 25.4483200, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130353, 'Chornyanka', 'Chornyanka', 'Chernen''ka,Chernen’ka,Chernjanka,Chernyanka,Chornjanka,Chornyanka,Чернянка,Чорнянка', 46.6522200, 33.3590400, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130354, 'Chernyakhivka', 'Chernyakhivka', 'Chernjakhovka,Chernyakhivka,Черняховка', 50.2188200, 31.9308200, 'UA', '2013-03-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130355, 'Chernyakhiv', 'Chernyakhiv', 'Cernahiv,Chernjakhiv,Chernyakhiv,Chernyakhov,Черняхів', 50.4565200, 28.6701800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130356, 'Chornukhyne', 'Chornukhyne', 'Chernukhino,Chornukhine,Chornukhyne,Чернухино,Чорнухине', 48.3233900, 38.5227200, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130357, 'Chornukhy', 'Chornukhy', 'Chernukhi,Chornukhi,Chornukhy,Чернухи,Чорнухи', 50.2673200, 32.9419600, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130358, 'Chernozemnoye', 'Chernozemnoye', 'Chernozemnoye,Chernozjomnoe,Chornozemne,Novyj Kerleut,Но́вый Керлеу́т,Чернозёмное,Чорноземне', 45.4080800, 34.8199000, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130359, 'Chornorudka', 'Chornorudka', 'Chernorudka,Chornorudka,Чернорудка,Чорнорудка', 49.8464000, 29.0606200, 'UA', '2016-08-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130360, 'Chernopolye', 'Chernopolye', 'Chernopol''e,Chernopolye,Chornopillja,Karachjol'',Карачё́ль,Чернополье,Чорнопілля', 45.0439900, 34.6391600, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130361, 'Chernomorskoye', 'Chernomorskoye', 'Ak-Mechet'',Chernomorskoe,Chernomorskoye,Chornomors''ke,Ак-Мече́ть,Черноморское,Чорноморське', 45.5065700, 32.6977600, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130362, 'Chornoliztsi', 'Chornoliztsi', 'Charnolozhtse,Charnolozhtsy,Chernolozhtsy,Chernoloztsy,Chornoliztsi,Cornolizci,Чорнолізці', 48.8303400, 24.8957600, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130363, 'Chornobayivka', 'Chornobayivka', 'Chernoayevka,Chernobayevka,Chernovayevka,Chornobaivka,Chornobayivka,Cornobaivka,Чорнобаївка', 46.6941100, 32.5537100, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130364, 'Chornobay', 'Chornobay', 'Chernobaj,Chernobay,Chornobaj,Chornobay,Чернобай,Чорнобай', 49.6664400, 32.3293200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130365, 'Cherniyiv', 'Cherniyiv', 'Cerniiv,Cherneyev,Cherneyuv,Cherniyev,Cherniyiv,Czerniejow,Czerniejów,Черніїв', 48.8565800, 24.7138800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130366, 'Chernivtsi', 'Chernivtsi', 'CWC,Cernauti,Cernivci,Cernivciai,Cernivco,Cernivtsi,Cernovci,Cernovice,Cernăuţi,Cernăuți,Charnaucy,Chernivci,Chernivtsi,Chernovci,Chernovcy,Chernovits,Chernovitsy,Chernovsi,Chernovtsy,Csernyivci,Czerniowce,Czernovicum,Czernowitz,Tchernivtsi,Tjernivtsi,Tschernowitz,Tsernivtsi,Tsjernivtsi,Txernivtsi,Txernivtsí,Tšernivtsi,cheleuniuchi,chernovtsi,cheruniutsu~i,chrnywtsy,chyrnywtsy,qie er nuo fu ce,zrnwbyz,Çernivtsi,Çernivtsı,Ĉernivco,Černivci,Černivciai,Černovci,Černovice,Čerņivci,Чарнаўцы,Чернивци,Черновци,Черновцы,Чернівці,Чернівцї,Չեռնովցի,טשערנאוויץ,צרנוביץ,چرنیوتسی,چیرنیوتسی,ჩერნოვცი,チェルニウツィー,切爾諾夫策,체르니우치', 48.2914900, 25.9403400, 'UA', '2013-12-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130367, 'Chernihiv', 'Chernihiv', 'Cernigau,Cernigiv,Cernigivo,Cernigovas,Cernigău,Cernihiv,Cernihivo,Cernihiw,Cernihov,Cerniqov,Chernigiv,Chernigov,Chernihiv,Chernígov,Csernyihiv,Czernihovia,Czernihow,Czernihów,Gorad Charnigau,Tchernihiv,Tjernihiv,Tschernigow,Tschernihiw,Tsernigiv,Tsernihiv,Tsjernihiv,Txernihiv,Txerníhiv,Tšernigiv,Tšernihiv,cheleunihiu,chernigovi,cherunihiu,chrnyhyf,qie er ni ge fu,tshrnyhyf,z''rnyhyb,Çernigiv,Çerniqov,Ĉernigivo,Ĉernihivo,Černigiv,Černigovas,Černihiv,Černihiw,Černihov,Горад Чарнігаў,Чернигов,Чернігів,Чернїгів,Չեռնիգով,צ''רניהיב,تشرنيهيف,چرنیهیف,چرنیہیف,ჩერნიგოვი,チェルニーヒウ,切尔尼戈夫,체르니히우', 51.5055100, 31.2848700, 'UA', '2013-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130368, 'Chernihivka', 'Chernihivka', 'Chernigivka,Chernigovka,Chernihivka,Tschernigowka,Черниговка,Чернігівка', 47.1999200, 36.1614800, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130369, 'Chernivtsi', 'Chernivtsi', 'Chernevtsy,Chernivci,Chernivtsi,Chernovcy,Черновцы,Чернівці', 48.5422500, 28.1147300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130370, 'Chernelytsya', 'Chernelytsya', 'Chernelicja,Chernelitsa,Chernelitse,Chernelytsya,Czernelica,Чернелиця', 48.8120700, 25.4247700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130371, 'Cherkasy', 'Cherkasy', 'CKC,Cerkasad,Cerkasai,Cerkasi,Cerkaso,Cerkassi,Cerkasy,Cerkasî,Cherkas khot,Cherkasi,Cherkassi,Cherkassy,Cherkasy,Circassium,Cserkaszi,Czerkasy,Gorad Charkasy,Tcherkassi,Tcherkassy,Tcherkássi,Tjerkasy,Tscherkassy,Tserkasso,Tserkasy,Tsjerkasi,Tsjerkasy,Txerkassi,Txerkasy,Tšerkassõ,Tšerkasy,cheleukasi,cherukasu~i,chrkasy,chrkysy,chyrkasy,qie er ka se,zrqʼsy,Çerkassi,Çerkası,Ĉerkaso,Čerkasad,Čerkasai,Čerkasi,Čerkasy,Горад Чаркасы,Черкас хот,Черкаси,Черкасси,Черкассы,Черкасы,Չերկասի,צרקאסי,چرکاسی,چرکیسی,چیرکاسی,ჩერკასი,チェルカースィ,切爾卡瑟,체르카시', 49.4285400, 32.0620700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130372, 'Chemerivtsi', 'Chemerivtsi', 'Cemerivci,Chemerivci,Chemerivtsi,Chemerovtsy,Chemirovtsy,Чемерівці', 49.0117900, 26.3420300, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130373, 'Chelyadinovo', 'Chelyadinovo', 'Cheljabincevo,Cheljadinove,Cheljadinovo,Chelyadinovo,Tobechik,Тобечи́к,Челя́бинцево,Челядиново,Челядінове', 45.2072900, 36.3762000, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130374, 'Chechel’nyk', 'Chechel''nyk', 'Chechel''nik,Chechel''nyk,Chechel’nik,Chechel’nyk,Chel''nik,Chel’nik,Чечельник', 48.2150900, 29.3672800, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130375, 'Chaykino', 'Chaykino', 'Chajkine,Chajkino,Chaykino,Malyj Tarkhan,Tarqanlar,Ма́лый Тарха́н,Чайкине,Чайкино', 45.8111100, 34.5953800, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130376, 'Chaykino', 'Chaykino', 'Chajkine,Chajkino,Chaykino,Chujke,Чайкине,Чайкино,Чуйке́', 45.0822300, 34.0867300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130377, 'Chasiv Yar', 'Chasiv Yar', 'Chasiv Jar,Chasiv Yar,Chasov Yar,Chasov-Jar,Часов-Яр,Часів Яр', 48.5934800, 37.8572400, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130378, 'Chaplynka', 'Chaplynka', 'Chaplinka,Chaplynka,Tschaplinka,Чаплинка', 46.3650700, 33.5402700, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130379, 'Chapayeve', 'Chapayeve', 'Chapaehve,Chapaeve,Chapaevo,Chapayeve,Chapayevo,Чапаево,Чапаэве,Чапаєве', 49.3662500, 35.8748600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130380, 'Chapayevka', 'Chapayevka', 'Chapaevka,Chapayevka,Чапаевка', 49.3817900, 30.4513700, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130381, 'Viytivka', 'Viytivka', 'Chapayevka,Viitivka,Vijtivka,Viytivka,Voytovka,Війтівка', 48.4260300, 29.5429100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130382, 'Chapayevka', 'Chapayevka', 'Chapaehvka,Chapaevka,Chapayevka,Imeni Chapayeva,Imeni Tovarishcha Chapayeva,Чапаевка,Чапаэвка,Чапаєвка', 47.4711400, 36.3450700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130383, 'Chapayevka', 'Chapayevka', 'Chapaevka,Chapayevka,Cherkez-Tobaj,Чапаевка,Чапаєвка,Черке́з-Тоба́й', 45.2811900, 34.8942800, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130384, 'Bytkiv', 'Bytkiv', 'Bitkiv,Bitkov,Bitkuv,Bytkiv,Bytkov,Битків', 48.6296800, 24.4739800, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130385, 'Bystrytsya', 'Bystrytsya', 'Bistricja,Bystrica,Bystritsa,Bystrytsya,Бистриця,Быстрица', 48.4593100, 24.2454500, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130386, 'Chernyshevo', 'Chernyshevo', 'Chernishove,Chernyshevo,Oguz-Oglu,Огу́з-Оглу́,Чернишове,Чернышево', 45.7820200, 33.4282500, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130387, 'Bykivka', 'Bykivka', 'Bikivka,Bykivka,Bykovka,Биківка', 50.2928500, 27.9831400, 'UA', '2013-02-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130388, 'Bus’k', 'Bus''k', 'Bus''k,Busk,Bus’k,Буск,Буськ', 49.9654800, 24.6122700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130389, 'Bushtyno', 'Bushtyno', 'Bushtina,Bushtino,Bushtyna,Bushtyno,Bustino,Bustyahaza,Bustyaháza,Buštino,Буштино', 48.0512100, 23.4857900, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130390, 'Buryn’', 'Buryn''', 'Burin'',Buryn'',Buryn’,Буринь,Бурынь', 51.1991200, 33.8352300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130391, 'Burshtyn', 'Burshtyn', 'Ambar,Ambr,Ambre,Boersjtyn,Bourchtyn,Burschtyn,Burshtin,Burshtyn,Bursjtyn,Burstin,Burstina,Burstron,Burstyn,Bursztyn,Burştın,Burština,Burštyn,Burștîn,Gintaras,Ho phach,Hổ phách,Jantar,Jantar'',Merevaik,Meripihka,Raf,Rav,Sucino,Sukceno,ampar,burushutin,bwrshtyn,bwrstyn,hobag,hu po,kohaku,Âmbar,Бурштин,Бурштын,Янтарь,Բուրշտին,בורשטין,بورشتين,بورشتین,அம்பர்,ბურშტინი,コハク,ブルシュティン,琥珀,호박', 49.2586700, 24.6277700, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130392, 'Pozharskoye', 'Pozharskoye', 'Bulganak-Bodrak,Pozhars''ke,Pozharskoe,Pozharskoye,Булгана́к-Бодра́к,Пожарское,Пожарське', 44.9355400, 33.8710900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130393, 'Buki', 'Buki', 'Buki,Буки', 49.0958300, 30.3964100, 'UA', '2015-05-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130394, 'Budy', 'Budy', 'Budi,Budy,Буди,Буды', 49.8913300, 36.0209600, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130395, 'Buchach', 'Buchach', 'Bitshutsh,Boetsjatsj,Boutchatch,Bucac,Bucaca,Bucacas,Buceaci,Buchach,Buczacz,Bugach,Butjatj,Butsats,Butschatsch,Butsjatsj,Butšatš,Buçaç,Buĉaĉ,Bučač,Bučača,Bučačas,Gorad Buchach,bu qia qi,buchachi,bwchach,bwtshatsh,bwzʼz,Бучач,Горад Бучач,Բուչաչ,בוצאץ,بوتشاتش,بوچاچ,ბუჩაჩი,布恰奇', 49.0625400, 25.3879800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130396, 'Bucha', 'Bucha', 'Bucha,Bychansk,Dachi Bucha,Буча', 50.5434500, 30.2120100, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130397, 'Bryukhovychi', 'Bryukhovychi', 'Brjukhovichi,Bruhovici,Bryukhovichi,Bryukhovychi,Brzuchowice,Bzhukhovitse,Брюховичи,Брюховичі', 49.9046700, 23.9596900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130398, 'Bryanka', 'Bryanka', 'Brjanka,Bryanka,Bryanskiy,Bryanskiy Rudnik,Брянка', 48.5110000, 38.6722200, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130399, 'Brusyliv', 'Brusyliv', 'Brusiliv,Brusilov,Brussilow,Brusyliv,Брусилів', 50.2844900, 29.5262600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130400, 'Brovary', 'Brovary', 'Brovarai,Brovari,Brovary,Brovarî,Brovarı,Browary,Gorad Bravary,beulobali,brovari,brwfary,brwwary,bu luo wa li,burovu~aru~i,Бровари,Бровары,Броварі,Горад Бравары,Բրովարի,ברובארי,بروفاري,بروواری,ბროვარი,ブロヴァルィー,布羅瓦里,브로바리', 50.5180900, 30.8067100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130401, 'Broska', 'Broska', 'Broasca,Broaska,Broska,Броска', 45.3732700, 28.7830000, 'UA', '2015-01-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130402, 'Broshniv-Osada', 'Broshniv-Osada', 'Broshnev,Broshnev-Osada,Broshniv-Osada,Broshnyuv,Brosniv-Osada,Broszniow,Broszniów,Brozniow,Brożniów,Oshnev-Osada,Proszniow,Proszniów,Брошнів-Осада', 48.9962100, 24.1974800, 'UA', '2012-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130403, 'Brody', 'Brody', 'Brodai,Brodi,Brody,Brodî,Brodı,beulodi,brodi,brody,brwdy,bu luo de,burodi,Броди,Броды,Բրոդի,ברודי,برودي,برودی,ბროდი,ブロディ,布羅德,브로디', 50.0879100, 25.1502700, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130404, 'Brylivka', 'Brylivka', 'Brilevka,Brilivka,Brilëvka,Brylivka,Брилівка', 46.4247600, 33.1472100, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130405, 'Bratslav', 'Bratslav', 'Braclav,Braclavas,Braclaw,Bracław,Bratlav,Bratslav,Brazlaw,Brațlav,Pasjolak garadskoga typu Braclau,bratslaf,brslb,bu la ci la fu,buratsurau,Брацлав,Пасёлак гарадскога тыпу Брацлаў,Բրացլավ,בראסלעוו,ברסלב,براتسلاف,ブラーツラウ,布拉茨拉夫', 48.8225700, 28.9407000, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130406, 'Brats’ke', 'Brats''ke', 'Brats''ke,Bratskoye,Brats’ke,Братське', 47.8636000, 31.5839300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130407, 'Brailiv', 'Brailiv', 'Brailiv,Brailov', 49.1098600, 28.1745900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130408, 'Boyarka', 'Boyarka', 'Bojarka,Boyarka,Boyarka-Budayevka,Budayevka,Боярка', 50.3191100, 30.2972800, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130409, 'Boyany', 'Boyany', 'Bayan,Bayany,Boian,Bojani,Boyan,Boyany,Бояни', 48.2707700, 26.1262400, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130410, 'Nikita', 'Nikita', 'Botanicheskoye,Nikita,Никита,Нікіта', 44.5156400, 34.2384000, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130411, 'Borzna', 'Borzna', 'Borsna,Borzna,bo er zi na,boruzuna,borzna,bwrzna,Борзна,Բորզնա,بورزنا,ბორზნა,ボルズナー,博爾茲納', 51.2546400, 32.4269000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130412, 'Borshchiv', 'Borshchiv', 'Berchev,Bershchev,Borshchev,Borshchiv,Borshchov,Borshchuv,Borshhiv,Borshtshev,Borsiv,Borszczow,Borszczów,Борщів', 48.8033200, 26.0434700, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130413, 'Borova', 'Borova', 'Borova,Borovaja,Borovaya,Борова,Боровая', 50.1762500, 30.1042900, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130414, 'Borova', 'Borova', 'Borova,Borovaja,Borovaya,Borowaja,Боровая', 49.3777000, 37.6213600, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130415, 'Boromlya', 'Boromlya', 'Boromlja,Boromlya,Боромля', 50.6183900, 34.9704200, 'UA', '2013-10-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130416, 'Borodyanka', 'Borodyanka', 'Borodjanka,Borodyanka,Бородянка', 50.6448400, 29.9201000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130417, 'Borodino', 'Borodino', 'Borodino,Saka,Бородіно', 46.3025000, 29.2416700, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130418, 'Boryspil’', 'Boryspil''', 'Borispil'',Borispilo,Borispol'',Borispol’,Boryspil,Boryspil'',Boryspil’,Boryspol,boru~isupiri,Борисполь,Бориспіль,ボルィースピリ', 50.3526900, 30.9550100, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130419, 'Boryslav', 'Boryslav', 'Borislau,Borislav,Borislava,Boriszlav,Boroslav,Boryslav,Boryslavas,Boryslaw,Borysxaw,Borysław,Borîslav,Borõslav,Borıslav,bao li si la fu,borislavi,bwryslaf,bwryslb,Борислав,Բորիսլավ,באריסלאוו,בוריסלב,بوريسلاف,بوریسلاف,ბორისლავი,鲍里斯拉夫', 49.2867200, 23.4323800, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130420, 'Bilshivtsi', 'Bilshivtsi', 'Bil''shivtsi,Bilisauti,Bilişăuţi,Bol''shovtsy,Bolshevitz,Bolszowce,Boshovtse,Bołszowce', 49.1833300, 24.7500000, 'UA', '2012-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130421, 'Bolhrad', 'Bolhrad', 'Belgrad,Bolgrad,Bolhrad,Bolhradas,Bołgrad,bo er he la de,bolgradi,bolheuladeu,bwlhrad,Болград,Բոլգրադ,بولهراد,ბოლგრადი,博爾赫拉德,볼흐라드', 45.6826200, 28.6148700, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130422, 'Bolekhiv', 'Bolekhiv', 'Bolechiv,Bolechivas,Bolechiw,Bolechow,Bolechów,Bolehiv,Bolehiva,Bolekhiv,Bolekhov,Bolekhuv,Bolexov,bo lie huo fu,bolekhovi,bwlhwb,bwlkhyf,bwlyhwb,bwlykhyf,Болехов,Болехів,Բոլեխով,בולחוב,בוליחוב,بولخیف,بوليخيف,ბოლეხოვი,博列霍夫', 49.0660700, 23.8643500, 'UA', '2013-01-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130423, 'Bohuslav', 'Bohuslav', 'Boguslav,Boguslaw,Bohuslav,Богуслав', 49.5493900, 30.8744000, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130424, 'Bohorodchany', 'Bohorodchany', 'Bogorodchani,Bogorodchany,Bohorodchany,Bohorodczany,Bradshin,Brodshin,Богородчани,בוהורודצ''אני', 48.8070000, 24.5383400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130425, 'Bohodukhiv', 'Bohodukhiv', 'Bododukhov,Bogoduchow,Bogoduhiv,Bogodukhiv,Bogodukhov,Bogoduxov,Bohodochiv,Bohodoukhiv,Bohoduchiv,Bohoduchivas,Bohoduchiw,Bohoduhiv,Bohodukhiv,bo huo du xi fu,bogodukhovi,bohodukhiva,bwhwdwkhyf,Богодухов,Богодухів,Բոգոդուխով,بوهودوخيف,بوهودوخیف,बोहोदूख़िव,ბოგოდუხოვი,博霍杜希夫', 50.1646600, 35.5276500, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130426, 'Bohdan', 'Bohdan', 'Belaya Tissa,Bila Tisa,Bilá Tisa,Bogdan,Bohdan,Byala Tissa,Tiszabogboy,Tiszabogdany,Tiszabogdány,Богдан', 48.0412200, 24.3522200, 'UA', '2012-06-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130427, 'Bogatoye', 'Bogatoye', 'Bagate,Bakhchi-Ehli,Bogatoe,Bogatoye,Багате,Бахчи́-Эли́,Богатое', 45.0293300, 34.7673200, 'UA', '2016-05-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130428, 'Bobrynets’', 'Bobrynets''', 'Bobrinec,Bobrinec'',Bobrinets,Bobrinez,Bobrynets'',Bobrynets’,Бобринец,Бобринець', 48.0589600, 32.1664100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130429, 'Bobrovytsya', 'Bobrovytsya', 'Bobrovica,Bobrovicja,Bobrovisty,Bobrovitsa,Bobrovitsy,Bobrovytsya,Бобровица,Бобровиця', 50.7469300, 31.3948000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130430, 'Bibrka', 'Bibrka', 'Bibrka,Boberka,Bobrka,Boiberik,Boiberke,Boyberik,Boyberke,Bóbrka,Prachnik,Бобрка,Бібрка', 49.6409300, 24.2887400, 'UA', '2017-01-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130431, 'Bobovo', 'Bobovo', 'Bobove,Bobovo,Bobovoje,Bobovoye,Tisobiken'',Tiszaboekeny,Tiszabökény,Бобове,Тисобикень', 48.0716600, 22.8958500, 'UA', '2011-01-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130432, 'Blyznyuky', 'Blyznyuky', 'Blisnezy,Bliznetsy,Bliznjuki,Bliznyuki,Blyznyuky,Staryye Bliznetsy,Близнюки', 48.8577500, 36.5550500, 'UA', '2016-03-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130433, 'Blizhneye', 'Blizhneye', 'Blizhne,Blizhnee,Blizhneye,Blizhnjaja Bajbuga,Бли́жняя Байбуга́,Ближнее,Ближнє', 45.0569400, 35.3305600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130434, 'Blahodatne', 'Blahodatne', 'Amurosievka,Amvrosiyevka,Blagodatne,Blagodatnoe,Blagodatnoye,Blahodatne,Donetsko-Amvrosiyevka,Благодатне,Благодатное', 47.8792800, 38.4849200, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130435, 'Blahodatne', 'Blahodatne', 'Blagodatne,Blagodatnoe,Blagodatnoye,Blahodatne,Благодатне,Благодатное', 47.7001300, 37.4189800, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130436, 'Biryukove', 'Biryukove', 'Birjukove,Birjukovo,Birjukowo,Birukove,Biryukove,Biryukovka,Biryukovo,Krinichnaya,Бирюково,Бірюкове', 47.9563100, 39.7384300, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130437, 'Bilhorod-Dnistrovs’kyy', 'Bilhorod-Dnistrovs''kyy', 'Akkerman,Belgorod-Dnestrovskij,Belgorod-Dnestrovskiy,Bilgorod-Dnistrovs''kij,Bilhorod-Dnistrovs''kyy,Bilhorod-Dnistrovs’kyy,Byelogorod,Cetatea Alba,Cetatea Albă,Белгород-Днестровский,Білгород-Дністровський', 46.1952000, 30.3493800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130438, 'Bila Tserkva', 'Bila Tserkva', 'Belaja Cerkov'',Belaja Zerkow,Belaya Tserkov'',Belaya Tserkov’,Belaya serkov,Biala Cerkiew,Biała Cerkiew,Bila Cerkva,Bila Cerkwa,Bila Terkva,Bila Tserkva,Bila Zerkwa,Bila Țerkva,Gorad Belaja Carkva,Shura Chirku,bai cai er ke wei,belaia-tserkʼovi,billacheleukeuba,byla tsrkfa,byla tsyrkfa,bylh zrqwwh,Белая Церковь,Била Церква,Біла Церква,Горад Белая Царква,Шурă Чиркӳ,Բելայա Ցերկով,בילה צרקווה,שווארצע טומאה,بيلا تسيركفا,بیلا تسرکفا,ბელაია-ცერკოვი,ビーラ・ツェールクヴァ,白采尔科维,빌라체르크바', 49.8093900, 30.1120900, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130439, 'Bezimenne', 'Bezimenne', 'Bezimenne,Bezimennoye,Bezymennoe,Bezymennoye,Bezymenovka,Безыменное,Безіменне', 47.1071600, 37.9381500, 'UA', '2015-06-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130440, 'Bezlyudivka', 'Bezlyudivka', 'Besliwdifca,Besljudiwka,Bezlioudivka,Bezliountivka,Bezliudivka,Bezliúdivka,Bezljudivka,Bezljudovka,Bezludiwka,Bezluedivka,Bezlyudivka,Bezlyudovka,Bezlüdivka,Pasjolak Behzljudziuka,bie zi liu ji fu ka,byzlywdyfka,Μπεζλιουντίβκα,Безлиудивка,Безлюдовка,Безлюдівка,Бєꙁлюдовъка,Пасёлак Бэзлюдзіўка,Բեզլյուդովկա,بيزليوديفكا,別茲柳季夫卡', 49.8754700, 36.2653900, 'UA', '2014-01-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130441, 'Donskoye', 'Donskoye', 'Dons''ke,Donskoe,Donskoye,Kerneuch,Донское,Донське,Кернеу́ч', 45.0450900, 34.2141300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130442, 'Bershad’', 'Bershad''', 'Berschad,Bershad'',Bershad’,Бершадь', 48.3678200, 29.5172600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130443, 'Beryslav', 'Beryslav', 'Berislav,Berisslaw,Beryslav,Beryslavas,Beryslaw,Berysław,Berîslav,Berıslav,bei li si la fu,berislavi,bryslaf,byryslaf,Берислав,Բերիսլավ,بریسلاف,بيريسلاف,ბერისლავი,貝里斯拉夫', 46.8415200, 33.4283800, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130444, 'Berezovo', 'Berezovo', 'Berezna,Berezove,Berezovo,Березове,Березово', 48.3094300, 23.4740000, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130445, 'Berezivka', 'Berezivka', 'Berezivka,Berezovka,Berëzovka,Березовка,Березівка', 49.4393500, 35.7073600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130446, 'Berezivka', 'Berezivka', 'Beresovka,Beresowka,Berezivka,Berezovka,Berëzovka,Березовка,Березівка', 47.2042900, 30.9078000, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130447, 'Berezovka', 'Berezovka', 'Berezivka,Berezovka,Sejich Eli,Smidovich,Šejiχ Eli,Березовка,Березівка,Смидо́вич', 45.5747100, 33.3439700, 'UA', '2017-03-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130448, 'Berezne', 'Berezne', 'Berezne,Berezno,Berëzno,Березне', 51.0009400, 26.7510600, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130449, 'Bereznyky', 'Bereznyky', 'Bereznik,Berezniki,Bereznyky,Березники', 48.5140700, 23.2198200, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130450, 'Bereznehuvate', 'Bereznehuvate', 'Bereznegovata,Bereznegovataya,Bereznegovatoe,Bereznegovatoye,Berezneguvate,Bereznehuvate,Березнеговатое,Березнегувате', 47.3078300, 32.8499300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130451, 'Berezna', 'Berezna', 'Beresna,Berezna,Березна', 51.5716000, 31.7845600, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130452, 'Berezyne', 'Berezyne', 'Berezina,Berezine,Berezino,Berezyne,Ratunda,Березине', 46.2296800, 29.2043600, 'UA', '2016-04-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130453, 'Бережани', 'Berezhani', 'Berejani,Bereschany,Berezany,Berezhani,Berezhany,Berezjany,Berežany,Brzezany,Brzezhany,Brzeżany,Бережани,Бережаны', 49.4500000, 24.9333300, 'UA', '2010-01-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130454, 'Berezanka', 'Berezanka', 'Berezanka,Suvorovo,Tiligulo-Berezanka,Tiligulo-Berezannya,Березанка', 46.8526200, 31.3880200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130455, 'Berestechko', 'Berestechko', 'Berestechko,Beresteczko,Beresteczo,Берестечко', 50.3604700, 25.1107100, 'UA', '2010-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130456, 'Berehove', 'Berehove', 'Bereg,Beregove,Beregovo,Beregszasz,Beregszász,Berehove,Berehovo,Berehovė,Berehowe,Berehowo,Berekhovo,Gorad Behrehgaveh,Peregium,belehobe,beregovo,bie lie ge wo,brhwbh,brhwfh,byryhwfy,Берегове,Берегово,Горад Бэрэгавэ,Բերեգովո,בערעגסאז,ברהובה,برهوفه,بيريهوفي,ბერეგოვო,别列戈沃,베레호베', 48.2055500, 22.6441800, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130457, 'Beregovoye', 'Beregovoye', 'Beregove,Beregovoe,Beregovoye,Koronel'',Берегове,Береговое,Коронель', 45.0947000, 35.4338500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130458, 'Berehomet', 'Berehomet', 'Barhumet,Beregomet,Berehomet,Bergomet,Berhomet,Berhomete pe Siret,Berkhomet,Berkhomet-pe-Siret,Берегомет', 48.1788200, 25.3485500, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130459, 'Velyki Berehy', 'Velyki Berehy', 'Beregi,Veliki Beregi,Velikie Beregi,Velyki Beregy,Velyki Berehy,Великие Береги,Великі Береги', 48.2318700, 22.7459100, 'UA', '2017-04-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130460, 'Berdychiv', 'Berdychiv', 'Berdicev,Berdichen,Berdichev,Berdichiv,Berdiciv,Berdiciva,Berditschew,Berdiçev,Berdičiva,Berdychiv,Berdyciv,Berdycivas,Berdyciw,Berdyczow,Berdyczów,Berdytchiv,Berdytjiv,Berdytschiw,Berdytsiv,Berdytsjiv,Berdytšiv,Berdyčiv,Berdyčivas,Berdyčiw,Berdîciv,Berdıçiv,Gorad Behrdychyu,beleudichiu,berdichevi,berudichifu,bie er ji qie fu,brdychyf,brdyzb,byrdytshyf,Бердичев,Бердичив,Бердичів,Горад Бэрдычыў,Բերդիչև,בערדיטשעוו,ברדיצב,بردیچیف,بيرديتشيف,ბერდიჩევი,ベルディチフ,別爾基切夫,베르디치우', 49.8992800, 28.6023500, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130461, 'Berdyans’k', 'Berdyans''k', 'Berdjans''k,Berdjansk,Berdyans''k,Berdyansk,Berdyans’k,Osipenko,Бердянск,Бердянськ', 46.7664400, 36.7987200, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130462, 'Belz', 'Belz', 'Bele,Bels,Belsk,Belz,Belza,Belzas,Belzec,Bełsk,Bełz,bei er zi,belzi,beruzu,blz,bylz,Белз,Բելզ,בלז,بلز,بيلز,ბელზი,ベルズ,貝爾茲', 50.3822600, 24.0064200, 'UA', '2017-05-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130463, 'Bili Oslavy', 'Bili Oslavy', 'Belyye Oslavy,Bili Oslavi,Bili Oslavy,Oslav Byaly,Oslaw Bialy,Oslawy Biale,Osław Biały,Osławy Białe,Білі Ослави', 48.4872200, 24.7007800, 'UA', '2012-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130464, 'Bilyayivka', 'Bilyayivka', 'Belyayevka,Bilaivka,Biljaivka,Bilyayivka,Біляївка', 46.4831900, 30.2167800, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130465, 'Bilozerka', 'Bilozerka', 'Belozerka,Belozërka,Bilozerka,Білозерка', 46.6248000, 32.4425100, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130466, 'Bile', 'Bile', 'Beloe,Beloye,Bile,Белое,Біле', 48.4952300, 39.0505100, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130467, 'Bilovods''k', 'Bilovods''k', 'Belovodsk,Belowodskoje,Bilovods''k,Беловодск', 49.2084600, 39.5897500, 'UA', '2010-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130468, 'Bilopillya', 'Bilopillya', 'Belopol''e,Belopol''ye,Belopolje,Belopol’ye,Bilopilla,Bilopillja,Bilopillya,Белополье,Білопілля', 51.1501600, 34.3128700, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130469, 'Bilokurakyne', 'Bilokurakyne', 'Belokurakino,Bilokurakine,Bilokurakyne,Белокуракино,Білокуракине', 49.5341000, 38.7306700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130470, 'Inkerman', 'Inkerman', 'Belokamensk,Inceromania,Inkerman,Inkermanas,Inkermano,aynkrman,yin ke er man,İnkerman,Інкерман,Белока́менск,Инкерман,Ինկերման,اینکرمان,因克爾曼', 44.6139100, 33.6098000, 'UA', '2016-05-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130471, 'Lyakhovtsy', 'Lyakhovtsy', 'Belogor''ye,Belogor’ye,Bilogir''ja,Bilohir"ya,Bilohir”ya,Lyakhovtsy,Білогір’я', 50.0026300, 26.4282400, 'UA', '2014-09-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130472, 'Belogorsk', 'Belogorsk', 'Belogorsk,Bilogirs''k,Karasubazar,Белогорск,Білогірськ,Карасубаза́р', 45.0546200, 34.6018500, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130473, 'Bilohorivka', 'Bilohorivka', 'Belogorovka,Bilogorivka,Bilohorivka,Белогоровка,Білогорівка', 48.9250300, 38.2482200, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130474, 'Bilky', 'Bilky', 'Belka,Belki,Bil''ki,Bilki,Bilky,Bil’ki,Белка,Білки', 48.3150300, 23.1324800, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130475, 'Bilyts’ke', 'Bilyts''ke', 'Belickoe,Belitskoye,Bilic''ke,Bilyts''ke,Bilyts’ke,Khutor Belitskiy,Белицкое,Білицьке', 48.4064200, 37.1811100, 'UA', '2014-06-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130476, 'Belinskoye', 'Belinskoye', 'Belins''ke,Belinskoe,Belinskoye,Белинское,Бєлінське', 45.3746500, 36.0821200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130477, 'Bila Krynytsya', 'Bila Krynytsya', 'Belaya Krinitsa,Bila Krinica,Bila Krinicja,Bila Krynytsya,Біла Криниця', 50.6398200, 29.4704100, 'UA', '2013-04-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130478, 'Belaya', 'Belaya', 'Belaya,Bila,Біла', 49.0290000, 25.7705900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130479, 'Bekhtery', 'Bekhtery', 'Bekhteri,Bekhtery,Бехтери', 46.2479000, 32.2912300, 'UA', '2014-12-03', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130480, 'Bazaliya', 'Bazaliya', 'Bazalia,Bazaliya,Базалія', 49.7126700, 26.4733100, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130481, 'Bayrachky', 'Bayrachky', 'Bajrachki,Bayrachki,Bayrachky,Байрачки', 48.3920000, 38.6017400, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130482, 'Trudovoye', 'Trudovoye', 'Bajgel''dy,Trudove,Trudovoe,Trudovoye,Байгельды́,Трудове,Трудовое', 45.2379700, 33.7583600, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130483, 'Baturyn', 'Baturyn', 'Barturin,Batouryn,Baturin,Baturina,Baturinum,Baturyn,Baturynas,Baturîn,Baturın,ba tu lin,bato~uru~in,batulin,batwryn,Бартурин,Батурин,Բատուրին,باتورين,باتورین,ბატურინი,バトゥールィン,巴圖林,바투린', 51.3456700, 32.8779400, 'UA', '2012-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130484, 'Batal’noye', 'Batal''noye', 'Aɣyrmag Eli,Batal''ne,Batal''noe,Batal''noye,Batal’noye,Батальне,Батальное', 45.1940200, 35.6158300, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130485, 'Bashtanka', 'Bashtanka', 'Bachtanka,Baschtanka,Bashhanka,Bashtanka,Basjtanka,Bastanka,Basztanka,Baştanka,Baštanka,Baștanka,ba shen tan ka,bashtanka,Баштанка,Бащанка,Բաշտանկա,باشتانكا,باشتانکا,ბაშტანკა,巴什坦卡', 47.4071900, 32.4386800, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130486, 'Baryshivka', 'Baryshivka', 'Barishivka,Baryshevka,Baryshivka,Lipnyaki,Баришівка,Барышевка', 50.3609800, 31.3217300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130487, 'Barvinkove', 'Barvinkove', 'Barvenkova,Barvenkovo,Barvinkove,Barvinkovė,Barwenkowa,Barwinkowe,ba wen ke fu,barfynkwfy,barwynkwfh,Барвенково,Барвинкове,Барвінкове,Բարվենկովո,بارفينكوفي,باروینکوفه,ბარვენკოვო,巴文科伏', 48.9097000, 37.0205100, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130488, 'Baranivka', 'Baranivka', 'Baranivka,Baranovka,Baranowka,Баранівка', 50.3000000, 27.6666700, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130489, 'Baranovka', 'Baranovka', 'Baranovka,Барановка', 50.2969100, 27.6622000, 'UA', '2010-07-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130490, 'Sinitsyno', 'Sinitsyno', 'Barak,Sinicine,Sinicyno,Sinitsyno,Бара́к,Синицине,Синицыно', 45.2386200, 35.2465900, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130491, 'Bar', 'Bar', 'Bar,Bar i Ukraina,Baras,ba er,baleu,bar,bar  awkrayn,bari,baru,Бар,Բար,באר,بار,بار، اوکراین,ბარი,バール,巴爾,바르', 49.0771700, 27.6825600, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130492, 'Banyliv', 'Banyliv', 'Baniliv,Banilov,Banyliv,Russish Banilya,Russkiy Banilov,Банилів', 48.3661200, 25.3454900, 'UA', '2012-01-18', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130493, 'Balta', 'Balta', 'Balta,Balta i Ukraina,Bałta,ba er ta,balta,balta  awkrayn,Балта,Բալտա,באלטה,بالتا,بالتا، اوکراین,ბალტა,巴爾塔', 47.9354800, 29.6198200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130494, 'Balky', 'Balky', 'Balki,Balky,Балки', 47.3833600, 34.9439600, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130495, 'Zaritcha', 'Zaritcha', 'Zarech''e,Заречье', 49.7166700, 29.2333300, 'UA', '2013-02-16', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130496, 'Balakliya', 'Balakliya', 'Balakleja,Balakleya,Balaklija,Balakliya,Балаклея,Балаклія', 49.4627000, 36.8595100, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130497, 'Balaklava', 'Balaklava', 'Balaclava,Balaklava,Balaklavo,Balaklawa,Baliklava,Baliqlava,Balyglava,Balıklava,Balıqlava,Bałakława,balaklafa,ballakeullaba,barakuravu~a,Балаклава,بالاكلافا,バラクラヴァ,발라클라바', 44.5111800, 33.5994200, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130498, 'Bakhmach', 'Bakhmach', 'Bakhmach,Бахмач', 51.2009300, 32.7745100, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130499, 'Bakhmach', 'Bakhmach', 'Bachmatsch,Bakhmach,Bakhmach Romenskiy,Бахмач', 51.1814400, 32.8346300, 'UA', '2012-10-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130500, 'Bakhchisaray', 'Bakhchisaray', 'Bachtjisaraj,Bachtschyssaraj,Bachtsjisaraj,Bahcesaray,Bahcisarajo,Bahçesaray,Bakczysaraj,Bakhchisaraj,Bakhchisaray,Baĥĉisarajo,Baɣca Saraj,Baɣča Saraj,bafuchisarai,baheuchisalai,Бахчисарай,バフチサライ,바흐치사라이', 44.7552500, 33.8578200, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130501, 'Bagerovo', 'Bagerovo', 'Bagerove,Bagerovo,Багерове,Багерово', 45.3741700, 36.2970500, 'UA', '2016-05-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130502, 'Babanka', 'Babanka', 'Babanka,Babynka,Бабанка', 48.7097100, 30.4482700, 'UA', '2017-03-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130503, 'Azovskoye', 'Azovskoye', 'Azovs''ke,Azovskoe,Azovskoye,Kalaj,Азовское,Азовське,Кала́й', 45.5860400, 34.5668000, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130504, 'Abrikosovo', 'Abrikosovo', 'Abrikosove,Abrikosovo,Ajgashen,Ordzhak-Dzhabu,Абрикосове,Абрикосово,Айгаше́н,Орджа́к-Джабу́', 45.6923600, 34.1015600, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130505, 'Avdiyivka', 'Avdiyivka', 'Avdeevka,Avdeyevka,Avdiivka,Avdiyivka,Awdejewka,Авдеевка,Авдіївка', 48.1398900, 37.7425500, 'UA', '2014-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130506, 'Auly', 'Auly', 'Auli,Auly,Romankovo,Аули,Аулы', 48.5666000, 34.4611100, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130507, 'Ostanino', 'Ostanino', 'Ojsul,Ostanine,Ostanino,Ойсу́л,Останино,Останіне', 45.3273100, 35.9129500, 'UA', '2016-05-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130508, 'Askaniya-Nova', 'Askaniya-Nova', 'Askania-Nova,Askanija-Nova,Askanija-Nowo,Askaniya-Nova,Chapli,Асканія-Нова', 46.4513500, 33.8688900, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130509, 'Artsyz', 'Artsyz', 'Archiz,Arcis,Arciz,Arcyz,Arcyzas,Arsis,Arsiz,Artsis,Artsiz,Artsyz,Artsız,Arzys,a er qi zi,artsizi,artsyz,Арциз,Արցիզ,آرتسیز,أرتسيز,არციზი,阿爾齊茲', 45.9919400, 29.4182400, 'UA', '2017-03-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130510, 'Artemivs’k', 'Artemivs''k', 'Artemivs''k,Artemivs’k,Artemovsk,Artemovskiy,Artemowsk,Artëmovsk,Bakhmut,Артемовск,Артемівськ', 48.5955900, 37.9998700, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130511, 'Artemivs’k', 'Artemivs''k', 'Artemivs''k,Artemivs’k,Artemovsk,Artëmovsk,Артемовск,Артемівськ', 48.4406100, 38.7320000, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130512, 'Aromatnoye', 'Aromatnoye', 'Aromatne,Aromatnoe,Aromatnoye,Rozental'',Ароматне,Ароматное,Розента́ль', 45.0367800, 34.3992100, 'UA', '2016-05-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130513, 'Armyansk', 'Armyansk', 'Armjans''k,Armjansk,Armyansk,Ermeni Bazar,Армянск,Армянськ', 46.1091900, 33.6920600, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130514, 'Arbuzynka', 'Arbuzynka', 'Arbusinka,Arbuzinka,Arbuzynka,Арбузинка', 47.9097200, 31.3196300, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130515, 'Apostolove', 'Apostolove', 'Apostolove,Apostolovo,Apostolovė,Apostolowe,Apostolowo,Apostołowo,a bo si tuo luo wei,abwstwlwfy,aposutorovu~e,apwstwlwfh,Апостолове,Апостолово,Ապոստոլովո,آپوستولوفه,أبوستولوفي,აპოსტოლოვო,アポーストロヴェ,阿波斯托洛韋', 47.6600300, 33.7136900, 'UA', '2016-05-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130516, 'Antratsyt', 'Antratsyt', 'Antracit,Antracita,Antracyt,Antracytas,Antratit,Antratsit,Antratsot,Antratsyt,Antratsõt,Antratsıt,Antrazyt,Antrațît,Bokovo-Antratsit,an te la qi te,antratsyt,Антрацит,Անտրացիտ,آنتراتسیت,أنتراتسيت,ანტრაციტი,安特拉齊特', 48.1150300, 39.0912800, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130517, 'Antoniny', 'Antoniny', 'Antonini,Antoniny,Антоніни', 49.8097400, 26.8771400, 'UA', '2016-11-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130518, 'Andrushivka', 'Andrushivka', 'Andruschowka,Andrushevka,Andrushivka,Andrushjovka,Andrushovka,Андрушёвка,Андрушівка', 50.0228800, 29.0202300, 'UA', '2014-10-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130519, 'Anan’yiv', 'Anan''yiv', 'Anan''iv,Anan''yer,Anan''yev,Anan''yiv,Anan’yer,Anan’yev,Anan’yiv,Ананьїв', 47.7210600, 29.9450200, 'UA', '2014-11-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130628, 'Zombo', 'Zombo', '', 2.5135500, 30.9090900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130629, 'Yumbe', 'Yumbe', 'Yumbe', 3.4650600, 31.2468900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130630, 'Wobulenzi', 'Wobulenzi', 'Wobolenzi,Wobulenzi,Wobulenzil', 0.7283300, 32.5122200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130631, 'Wakiso', 'Wakiso', 'Wakiso', 0.4044400, 32.4594400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130632, 'Tororo', 'Tororo', 'TRY,Tororas,Tororo,tololo,tororo,tuo luo luo,Тороро,トロロ,托罗罗,토로로', 0.6929900, 34.1808500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130633, 'Soroti', 'Soroti', 'SRT,Soroti,suo luo ti,swrwty,סורוטי,سوروتی,索羅提', 1.7146400, 33.6111300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130634, 'Sironko', 'Sironko', 'Siroko,Sironko,Solokho,Soloko,xi long ke,錫龍科', 1.2313200, 34.2477300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130635, 'Serere', 'Serere', '', 1.4941700, 33.4552800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130636, 'Sembabule', 'Sembabule', 'Sembabule', -0.0772200, 31.4566700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130637, 'Rukungiri', 'Rukungiri', 'Kinyasano,Rukungire,Rukungiri', -0.8411100, 29.9419400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130638, 'Rubirizi', 'Rubirizi', 'Rubirizi', -0.2988900, 30.1336100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130639, 'Rakai', 'Rakai', 'Rakai', -0.7200000, 31.4838900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130640, 'Pallisa', 'Pallisa', 'Palissa,Pallisa,Паллиса', 1.1450000, 33.7094400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130641, 'Paidha', 'Paidha', 'Pai-ida,Paidha,Payida', 2.4166900, 30.9855100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130642, 'Pader Palwo', 'Pader Palwo', '', 2.8005600, 33.1350000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130643, 'Nyachera', 'Nyachera', 'Nyachera,Nyakyera', -0.9000000, 30.4166700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130644, 'Ntungamo', 'Ntungamo', '', -0.8833300, 29.6500000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130645, 'Ntungamo', 'Ntungamo', 'Ntungamo', -0.8794400, 30.2641700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130646, 'Ntoroko', 'Ntoroko', '', 1.0411100, 30.4811100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130647, 'Nsika', 'Nsika', 'Nsiika,Nsika,Nsiki', -0.3580000, 30.4313600, 'UG', '2016-12-01', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130648, 'Njeru', 'Njeru', 'Daru,Njeru', 0.4416600, 33.1791700, 'UG', '2016-12-03', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130649, 'Ngora', 'Ngora', 'Ngora', 1.4313900, 33.7772200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130650, 'Nebbi', 'Nebbi', 'Nebbi,Nebi', 2.4782600, 31.0889300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130651, 'Namutumba', 'Namutumba', '', 0.8361100, 33.6861100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130652, 'Namasuba', 'Namasuba', '', 0.6894400, 32.4213900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130653, 'Nakasongola', 'Nakasongola', 'Nakasongola', 1.3088900, 32.4563900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130654, 'Nakaseke', 'Nakaseke', 'Nakaseke', 0.7516700, 32.3850000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130655, 'Mukono', 'Mukono', 'Mukono', 0.3533300, 32.7552800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130656, 'Muhororo', 'Muhororo', '', 0.9380600, 30.7594400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130657, 'Mubende', 'Mubende', 'Mubende,Mubendi,موبیندے', 0.5584900, 31.3948900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130658, 'Mpigi', 'Mpigi', '', 0.2250000, 32.3136100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130659, 'Moyo', 'Moyo', 'Moyo,OYG', 3.6608800, 31.7247400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130660, 'Moroto', 'Moroto', 'Maroto,Moroto', 2.5345300, 34.6665900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130661, 'Mityana', 'Mityana', 'Mit''jana,Mitiyana,Mityana,Митьяна', 0.4175000, 32.0227800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130662, 'Mitoma', 'Mitoma', '', -0.6841700, 30.0700000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130663, 'Mbarara', 'Mbarara', 'Barara,MBQ,Mbarara,eumbalala,mbarara,Μπαράρα,Мбарара,مبارارا,მბარარა,음바라라', -0.6046700, 30.6485100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130664, 'Mbale', 'Mbale', 'Mbale,Mbalė,mu ba lai,Мбале,מבאלה,مبالے,姆巴萊', 1.0820900, 34.1750300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130665, 'Mayuge', 'Mayuge', '', 0.4597200, 33.4802800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130666, 'Masindi Port', 'Masindi Port', 'Masindi Port', 1.6960600, 32.0860800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130667, 'Masindi', 'Masindi', 'KCU,Masinai,Masindi,Masindis,masyndy,Масинди,ماسیندی', 1.6744400, 31.7150000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130668, 'Masaka', 'Masaka', 'Masaka,Masaki,Масака,Масаки', -0.3337900, 31.7340900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130669, 'Maracha', 'Maracha', 'Maraca,Maracha', 3.2704200, 30.9553200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130670, 'Lyantonde', 'Lyantonde', 'Lyantonde', -0.4030600, 31.1572200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130671, 'Lwengo', 'Lwengo', 'Lwengo', -0.4161100, 31.4080600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130672, 'Luwero', 'Luwero', '', 0.8491700, 32.4730600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130673, 'Lugazi', 'Lugazi', 'Lugazi,Lugazis,lwgazy,لوگازی', 0.3678800, 32.9376000, 'UG', '2016-12-03', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130674, 'Lira', 'Lira', 'Lira,lyrh,Лира,לירה,لیرا، یوگنڈا', 2.2499000, 32.8998500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130675, 'Kyotera', 'Kyotera', 'Kyotera', -0.6155600, 31.5175000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130676, 'Kyenjojo', 'Kyenjojo', 'Kyanjojo,Kyenjojo,Kyonjojo', 0.6327800, 30.6213900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130677, 'Kyegegwa', 'Kyegegwa', 'Kyegegwa', 0.5022200, 31.0413900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130678, 'Kumi', 'Kumi', '', 1.4608300, 33.9361100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130679, 'Kotido', 'Kotido', '', 2.9805600, 34.1330600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130680, 'Koboko', 'Koboko', 'Kaboko,Koboko', 3.4136400, 30.9599400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130681, 'Kitgum', 'Kitgum', 'Kitgum,Kitgumo,Китгум', 3.2783300, 32.8866700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130682, 'Kisoro', 'Kisoro', 'Kisolo,Kisoro,kyswrw,کیسورو', -1.2853800, 29.6849700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130683, 'Kiryandongo', 'Kiryandongo', '', 1.8763300, 32.0622500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130684, 'Kiruhura', 'Kiruhura', '', -0.1966400, 30.8444600, 'UG', '2016-12-01', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130685, 'Kireka', 'Kireka', 'Kireka', 0.3475000, 32.6491700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130686, 'Kilembe', 'Kilembe', '', 0.1983500, 30.0130200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130687, 'Kigorobya', 'Kigorobya', '', 1.6162000, 31.3089000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130688, 'Kibuku', 'Kibuku', 'Kibuku', 1.0433300, 33.7975000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130689, 'Kiboga', 'Kiboga', 'Kiboga', 0.9161100, 31.7741700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130690, 'Kibingo', 'Kibingo', '', -0.6260200, 30.4359400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130691, 'Kibale', 'Kibale', '', 0.8000000, 31.0666700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130692, 'Kayunga', 'Kayunga', 'Kayunga', 0.7025000, 32.8886100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130693, 'Katakwi', 'Katakwi', 'Katakwi', 1.8911100, 33.9661100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130694, 'Kasese', 'Kasese', 'KSE,Kasese,Kasesė,ka sai sai,qssh,Касесе,קססה,کاسیسے,卡塞塞', 0.1833300, 30.0833300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130695, 'Kapchorwa', 'Kapchorwa', 'Kapchorwa,Sabei,Sebei', 1.4009600, 34.4503800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130696, 'Kanungu', 'Kanungu', 'Kanungu,Kinkizi,Makiro', -0.9575000, 29.7897200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130697, 'Kanoni', 'Kanoni', 'Kanone,Kanoni', 0.1772200, 31.8811100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130698, 'Kamwenge', 'Kamwenge', '', 0.1866000, 30.4539300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130699, 'Kamuli', 'Kamuli', 'Kamuli', 0.9472200, 33.1197200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130700, 'Kampala', 'Kampala', 'Campala,Gorad Kampala,IKampala,KLA,Kaempaala,Kambaala,Kampal,Kampala,Kampalo,Kanpala,kam pa la,kambala,kampala,kampalla,kan pa la,kanpara,kapala,kmpala,qmplh,Καμπάλα,Горад Кампала,Кампала,Կամպալա,קאמפאלא,קמפלה,كامبالا,كامپالا,کامپالا,کمپالا,کمپالہ,कंपाला,कम्पाला,ਕੰਪਾਲਾ,କାମ୍ପାଲା,கம்பாலா,กัมปาลา,ཀམ་པ་ལ།,კამპალა,ካምፓላ,カンパラ,坎帕拉,캄팔라', 0.3162800, 32.5821900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130701, 'Kalungu', 'Kalungu', '', -0.1696900, 31.7584700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130702, 'Kaliro', 'Kaliro', 'Kaliro', 0.8944400, 33.4994400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130703, 'Kalangala', 'Kalangala', 'Kalangala', -0.3088900, 32.2250000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130704, 'Kajansi', 'Kajansi', '', 0.2154800, 32.5345300, 'UG', '2016-12-03', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130705, 'Kagadi', 'Kagadi', 'Kagadi', 0.9605600, 30.7966700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130706, 'Kaberamaido', 'Kaberamaido', 'Kaberamaido,Kabiramaido', 1.7388900, 33.1594400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130707, 'Kabale', 'Kabale', 'Kabale,Kabalė,Кабале,קבאלה', -1.2485700, 29.9899300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130708, 'Kaabong', 'Kaabong', 'Kaabong', 3.4836100, 34.1491700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130709, 'Jinja', 'Jinja', 'Dzhindzha,Dzindza,Džindža,JIN,Jinga,Jinja,Tzintza,gyngh,jin gu,jinja,Τζίντζα,Джинджа,גינגה,ジンジャ,金賈,진자', 0.4390200, 33.2031700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130710, 'Iganga', 'Iganga', 'Igang,Iganga,aganga,Иганга,اگانگا', 0.6091700, 33.4686100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130711, 'Ibanda', 'Ibanda', '', -0.1339800, 30.4961600, 'UG', '2016-12-01', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130712, 'Hoima', 'Hoima', 'Hoima,Khoima,Хоима,ہویما', 1.4331400, 31.3524100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130713, 'Gulu', 'Gulu', 'Gul,Gulu,Nkoulou,ULU,gu lu,gullu,gulu,gwlw,Γκουλού,Гул,Гулу,גולו,گولو,გულუ,古盧,굴루', 2.7745700, 32.2989900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130714, 'Gombe', 'Gombe', 'Gombe', 0.2033300, 32.0880600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130715, 'Fort Portal', 'Fort Portal', 'Fort Portal,Fort Portalas,Fort-Portal,Kabarole,poteupoteol,Форт-Портал,فورٹ پورٹل,フォート・ポータル,포트포털', 0.6617400, 30.2748000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130716, 'Entebbe', 'Entebbe', 'EBB,Ehntebbe,Entebbe,Entebe,Entebė,antbh,antyby,en de pei,entebe,Ентеббе,Ентебе,Энтеббе,אנטבה,ענטעבע,إنتيبي,انتبه,انتیبے,အင်တက်ဘီမြို့,ენტებე,エンテベ,恩德培,엔테베', 0.0562100, 32.4794900, 'UG', '2017-06-06', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130717, 'Dokolo', 'Dokolo', 'Dokolo', 1.8983300, 33.1775000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130718, 'Byakabanda', 'Byakabanda', 'Byakabanda,Kyakabanda', -0.7425000, 31.4063900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130719, 'Bwizibwera', 'Bwizibwera', 'Bwizibwera', -0.5916700, 30.6286100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130720, 'Bweyogerere', 'Bweyogerere', 'Bweyogerere', 0.3577300, 32.6633200, 'UG', '2016-12-03', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130721, 'Buyende', 'Buyende', 'Buyende', 1.1516700, 33.1550000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130722, 'Buwenge', 'Buwenge', 'Buwenge', 0.6499600, 33.1712800, 'UG', '2017-06-06', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130723, 'Butaleja', 'Butaleja', 'Butaleja', 0.9119400, 33.9511100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130724, 'Busia', 'Busia', 'Busia,Busla,bu xi ya,بوسیا، یوگنڈا,布西亞', 0.4658800, 34.0922100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130725, 'Bushenyi', 'Bushenyi', 'Bushenyi', -0.5369500, 30.1857900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130726, 'Busembatia', 'Busembatia', '', 0.7772500, 33.6236400, 'UG', '2017-02-04', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130727, 'Bundibugyo', 'Bundibugyo', 'Bundibugyo', 0.7111700, 30.0646900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130728, 'Bulisa', 'Bulisa', '', 2.1178100, 31.4116300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130729, 'Bulambuli', 'Bulambuli', '', 1.1666700, 34.3833300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130730, 'Bukwa', 'Bukwa', 'Bukwa,Bukwo', 1.2591700, 34.7538900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130731, 'Bukomansimbi', 'Bukomansimbi', 'Bukamba,Bukomansimbe,Bukomansimbi', -0.1577800, 31.6041700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130732, 'Bukedea', 'Bukedea', 'Bukedea,Bukidea', 1.3169400, 34.0505600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130733, 'Buikwe', 'Buikwe', 'Buikwe', 0.3375000, 33.0105600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130734, 'Bugiri', 'Bugiri', 'Bugiri', 0.5713900, 33.7416700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130735, 'Bugembe', 'Bugembe', 'Bugembe', 0.4821300, 33.2406500, 'UG', '2016-12-03', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130736, 'Bududa', 'Bududa', 'Baduda,Bududa', 1.0111800, 34.3311200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130737, 'Budaka', 'Budaka', '', 1.0038900, 33.9255600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130738, 'Binyin', 'Binyin', 'Binyin,Binyiny', 1.4166700, 34.5333300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130739, 'Arua', 'Arua', 'Arua,RUA,a lu a,alua,arwa,Аруа,اروا,阿鲁阿,아루아', 3.0201300, 30.9110500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130740, 'Apac', 'Apac', 'Apac,Apach', 1.9755600, 32.5386100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130741, 'Amuria', 'Amuria', 'Amuria', 2.0036100, 33.6511100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130742, 'Amudat', 'Amudat', 'Amdat,Amudat', 1.9500000, 34.9500000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130743, 'Amolatar', 'Amolatar', 'Amolatar,Amolitar,Amolota,Amolotar,Molitar', 1.6155600, 32.8397200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130744, 'Alebtong', 'Alebtong', 'Alebtong,Alebtongo', 2.2447200, 33.2547200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130745, 'Adjumani', 'Adjumani', 'Adjumani,Ajumani', 3.3778600, 31.7909000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130746, 'Abim', 'Abim', '', 2.7016700, 33.6761100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130747, 'Nakapiripirit', 'Nakapiripirit', '', 1.9166700, 34.7833300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130748, 'Pader', 'Pader', '', 3.0500000, 33.2166700, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130749, 'Margherita', 'Margherita', '', 0.4186100, 29.8911100, 'UG', '2012-04-28', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130750, 'Nwoya', 'Nwoya', 'Nwoya', 2.6342200, 32.0010600, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130751, 'Isingiro', 'Isingiro', 'Isingiro', -0.8686400, 30.8301900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130752, 'Manafwa', 'Manafwa', 'Manafwa', 0.9784200, 34.3743000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130753, 'Oyam', 'Oyam', '', 2.2350000, 32.3849500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130754, 'Amuru', 'Amuru', 'Amuru', 2.8138800, 31.9386800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130755, 'Namayingo', 'Namayingo', '', 0.2398300, 33.8849100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130756, 'Kitamilo', 'Kitamilo', 'Kitamilo', 0.2221500, 33.2060800, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130757, 'Kyankwanzi', 'Kyankwanzi', 'Kyankwanzi', 1.2006100, 31.8006300, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130758, 'Kole', 'Kole', '', 2.4001500, 32.8003400, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130759, 'Otuke', 'Otuke', 'Otuke', 2.5003800, 33.5006500, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130760, 'Napak', 'Napak', '', 2.2513900, 34.2501200, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130761, 'Luuka Town', 'Luuka Town', 'Luuka Town', 0.7007600, 33.3002000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130762, 'Buhweju', 'Buhweju', '', -0.3502700, 30.3002900, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130763, 'Agago', 'Agago', '', 2.8338300, 33.3336100, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130764, 'Lamwo', 'Lamwo', '', 3.5297200, 32.8016000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130765, 'Kampala Central Division', 'Kampala Central Division', '', 0.3246700, 32.5747000, 'UG', '2016-06-22', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130766, 'Gombe', 'Gombe', '', 0.4869500, 32.4793800, 'UG', '2015-11-20', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130767, 'Kihihi', 'Kihihi', '', -0.5692500, 29.6951600, 'UG', '2016-07-05', 232);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130520, 'Amvrosiyivka', 'Amvrosiyivka', 'Amvrosievka,Amvrosiivka,Amvrosiyevka,Amvrosiyivka,Donetsko Amerskevka,Donetsko-Amvrosiyevka,Donezko-Amwrossijewka,Амвросиевка,Амвросіївка', 47.7934800, 38.4776800, 'UA', '2014-08-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130521, 'Amurskoye', 'Amurskoye', 'Alabash-Konrat,Amurs''ke,Amurskoe,Amurskoye,Алаба́ш-Конра́т,Амурское,Амурське', 45.2782200, 34.1282300, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130522, 'Alushta', 'Alushta', 'Aloushta,Alshta,Aluschta,Alushta,Alusta,Aluszta,Aluşta,Alušta,Ałuszta,allusyuta,Алушта,알루슈타', 44.6772800, 34.4097000, 'UA', '2016-05-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130523, 'Alupka', 'Alupka', 'Aloupka,Alupk,Alupka,Alupko,Ałupka,a lu pu ka,alwbka,alwpka,Αλούπκα,Алупка,Алупко,Ալուպկա,آلوپکا,ألوبكا,ალუპკა,阿盧普卡', 44.4180800, 34.0453100, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130524, 'Alekseyevka', 'Alekseyevka', 'Alekseevka,Alekseyevka,Ehski-Alikech,Oleksiivka,Алексеевка,Олексіївка,Эски́-Алике́ч', 45.5819400, 33.6298000, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130525, 'Oleksandrivka', 'Oleksandrivka', 'Aleksandrovka,Alexandrowka,Oleksandrivka,Олександрівка', 48.7083700, 36.9156100, 'UA', '2016-03-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130526, 'Oleksandrivka', 'Oleksandrivka', 'Aleksandrovka,Oleksandrivka,Roksandrovka,Александровка,Олександрівка', 46.8382600, 32.7611600, 'UA', '2017-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130527, 'Oleksandrivka', 'Oleksandrivka', 'Aleksandrovka,Oleksandrivka,Александровка,Олександрівка', 46.3289300, 30.6348100, 'UA', '2015-02-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130528, 'Aleksandrovka', 'Aleksandrovka', 'Aleksandrovka,Bij-Akaj-Kemel''chi,Oleksandrivka,Александровка,Бий-Ака́й-Кемельчи́,Олександрівка', 45.5765400, 34.0994700, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130529, 'Alchevs’k', 'Alchevs''k', 'Alchevs''k,Alchevsk,Alchevskoe,Alchevs’k,Kommunarsk,Voroshilovsk,Woroschilowsk,Алчевск,Алчевськ', 48.4689300, 38.8166900, 'UA', '2014-06-05', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130530, 'Andreyevka', 'Andreyevka', 'Akleiz,Andreevka,Andreyevka,Andriivka,Аклеи́з,Андреевка,Андріївка', 44.8166300, 33.5631300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130531, 'Yakymivka', 'Yakymivka', 'Akimivka,Akimovka,Akimowka,Jakimivka,Yakymivka,Акимовка,Якимівка', 46.6997200, 35.1591600, 'UA', '2015-04-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130532, 'Akimovka', 'Akimovka', 'Akimovka,Jakimivka,Акимовка,Якимівка', 45.5198100, 34.8243800, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130533, 'Okhtyrka', 'Okhtyrka', 'Achtyrka,Akhtirka,Akhtyrka,Okhtirka,Okhtyrka,Ахтырка,Охтирка', 50.3103600, 34.8987900, 'UA', '2014-07-08', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130534, 'Agrarnoye', 'Agrarnoye', 'Agrarne,Agrarnoe,Agrarnoye,Аграрне,Аграрное', 45.0159600, 34.0572500, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130535, 'Lekarstvennoye', 'Lekarstvennoye', 'Agach-Ehli,Lekarstvennoe,Lekarstvennoye,Likarstvenne,Ага́ч-Эли́,Лекарственное,Лікарственне', 44.9419400, 33.8222900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130536, 'Aeroflotskiy', 'Aeroflotskiy', 'Aehroflotskij,Aeroflots''kij,Aeroflotskiy,Аерофлотський,Аэрофлотский', 45.0181600, 33.9996100, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130537, 'Adzhamka', 'Adzhamka', 'Adzhamka,Аджамка', 48.5424500, 32.5354200, 'UA', '2016-06-04', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130538, 'Abrikosovka', 'Abrikosovka', 'Abrikosivka,Abrikosovka,Najman,Абрикосовка,Абрикосівка,Найма́н', 45.1075900, 35.1013900, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130539, 'Malynivka', 'Malynivka', 'Malinivka,Malinovka,Malynivka,Малиновка,Малинівка', 49.8166700, 36.7333300, 'UA', '2014-06-26', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130540, 'Kopashnovo', 'Kopashnovo', 'Gernyes,Gernyés,Kopashneve,Kopashnevo,Kopashnovo,Копашневе,Копашново', 48.2197000, 23.4845700, 'UA', '2012-05-06', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130541, 'Narkevychi', 'Narkevychi', 'Narkevici,Narkevychi,Yasne,Наркевичі', 49.5171700, 26.6417800, 'UA', '2012-01-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130542, 'Kirove', 'Kirove', 'Kirove,Kirovo,Кирово,Кірове', 47.6531100, 35.6951200, 'UA', '2012-01-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130543, 'Novosel’skoye', 'Novosel''skoye', 'Novosel''skoe,Novosel''skoye,Novosel’skoye,Novosil''s''ke,Новосельское,Новосільське', 45.5035700, 32.7225000, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130544, 'Orekhovo', 'Orekhovo', 'Orekhovo,Orikhove,Орехово,Оріхове', 45.1294400, 33.6318000, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130545, 'Krasni Okny', 'Krasni Okny', 'Krasni Okni,Krasni Okny,Krasnyye Okny,Okna,Okny,Красні Окни', 47.5404400, 29.4600100, 'UA', '2017-03-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130546, 'Kuchurhan', 'Kuchurhan', 'Kuchurgan,Kuchurhan,Кучурган', 47.1630200, 29.7893700, 'UA', '2012-01-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130547, 'Smyga', 'Smyga', 'Smiga,Smyga,Смига,Смыга', 50.2391000, 25.7657500, 'UA', '2012-02-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130548, 'Tayirove', 'Tayirove', 'Tairove,Tairovo,Tayirove,Таїрове', 46.3631300, 30.6489100, 'UA', '2015-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130549, 'Teplodar', 'Teplodar', 'Teplodar,Теплодар', 46.5058500, 30.3252100, 'UA', '2015-02-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130550, 'Komsomolsk', 'Komsomolsk', 'Komsomol''s''k,Komsomol''sk,Komsomolsk,Komsomolsk i Ukraina,Komsomolsk na Dnepru,Komsomolska,Komsomoļska,gong qing cheng,komsomolsikeu,kwmswmwlsk  awkrayn,qwmswmwlsq,Комсомолск,Комсомольск,Комсомольськ,Комсомољск на Дњепру,Կոմսոմոլսկ,קומסומולסק,کومسومولسک، اوکراین,კომსომოლსკი,共青城,콤소몰시크', 49.0101800, 33.6356700, 'UA', '2013-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130551, 'Slavutych', 'Slavutych', 'Gorad Slavucich,Slavoetytsj,Slavoutytch,Slavutic,Slavutica,Slavutich,Slavutici,Slavutiča,Slavutots,Slavutyc,Slavutych,Slavutycius,Slavutytj,Slavutyts,Slavutytsj,Slavutytš,Slavutyč,Slavutyčius,Slavutîci,Slavutõtš,Slavutıç,Slawutycz,Slawutytsch,Szlavutics,Sławutycz,aslawwtych,si la fu di qi,surabuchitchi,Горад Славуціч,Славутич,Սլավուտիչ,اسلاووتیچ,სლავუტიჩი,スラブチッチ,斯拉夫蒂奇', 51.5196400, 30.7343400, 'UA', '2016-03-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130552, 'Orzhiv', 'Orzhiv', 'Orzhiv,Оржів', 50.8000000, 26.1200000, 'UA', '2012-12-01', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130553, 'Kurskoye', 'Kurskoye', 'Kishlav,Kurs''ke,Kurskoe,Kurskoye,Кишла́в,Курское,Курське', 45.0290800, 34.9362300, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130554, 'Rovnoye', 'Rovnoye', 'Karasan,Rivne,Rovnoe,Rovnoye,Караса́н,Ровное,Рівне', 45.3513400, 34.3523000, 'UA', '2016-07-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130555, 'Kashtanovoye', 'Kashtanovoye', 'Kashtanove,Kashtanovoe,Kashtanovoye,Каштанове,Каштановое', 44.8321000, 34.0591200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130556, 'Levadki', 'Levadki', 'Levadki,Левадки', 44.8708300, 34.0427800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130557, 'Beloglinka', 'Beloglinka', 'Aktachi-Kijat,Beloglinka,Biloglinka,Актачи́-Кия́т,Белоглинка,Білоглинка', 44.9949000, 34.0416700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130558, 'Komsomol’skoye', 'Komsomol''skoye', 'Komsomol''s''ke,Komsomol''skoe,Komsomol''skoye,Комсомольское,Комсомольське', 45.0190000, 34.0304900, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130559, 'Malen’koye', 'Malen''koye', 'Kichkine,Malen''ke,Malen''koe,Malen''koye,Malen’koye,Кичкине́,Маленьке,Маленькое', 45.0758500, 33.9994200, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130560, 'Solnechnoye', 'Solnechnoye', 'Solnechnoe,Solnechnoye,Sonjachne,Солнечное,Сонячне', 45.0476700, 34.0838000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130561, 'Fontany', 'Fontany', 'Fontani,Fontany,Jagmurcha,Фонтани,Фонтаны,Ягмурча́', 44.8971700, 34.0729700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130562, 'Zalesye', 'Zalesye', 'Zales''e,Zalesye,Zalissja,Залесье,Залісся', 44.8868700, 34.1016800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130563, 'Konstantinovka', 'Konstantinovka', 'Konstantinovka,Kostjantinivka,Константиновка,Костянтинівка', 44.8551100, 34.1206900, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130564, 'Urozhaynoye', 'Urozhaynoye', 'Brusilovo,Chojunchi,Chujuncha,Cujuncu,Urozhajne,Urozhajnoe,Urozhaynoye,Čujunču,Бруси́лово,Урожайне,Урожайное,Чоюнчи́,Чуюнча́', 45.0452200, 34.1351100, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130565, 'Trudovoye', 'Trudovoye', 'Trudove,Trudovoe,Trudovoye,Трудове,Трудовое', 44.9913300, 34.2031100, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130566, 'Mel’nichnoye', 'Mel''nichnoye', 'Mel''nichne,Mel''nichnoe,Mel''nichnoye,Mel’nichnoye,Terekli-Shejkh-Ehli,Мельничне,Мельничное,Терекли́-Шейх-Эли́', 45.1988500, 34.4201200, 'UA', '2016-05-31', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130567, 'Drofino', 'Drofino', 'Bol''shoj Matis,Drofine,Drofino,Malyj Matis,Большой Матис,Дрофине,Дрофино,Малый Матис', 45.2862900, 34.6158900, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130568, 'Kostochkovka', 'Kostochkovka', 'Ehshkene,Kistochkivka,Kostochkovka,Косточковка,Кісточківка,Эшкене́', 45.3174700, 34.6741800, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130569, 'Razdol’noye', 'Razdol''noye', 'Razdol''noe,Razdol''noye,Razdol’noye,Rozdol''ne,Раздольное,Роздольне', 45.3616100, 34.8548200, 'UA', '2016-08-15', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130570, 'Nekrasovo', 'Nekrasovo', 'Bol''shevik,Nekrasove,Nekrasovo,Большевик,Некрасове,Некрасово', 45.4245300, 34.2854500, 'UA', '2016-07-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130571, 'Uvarovka', 'Uvarovka', 'Burnas,Burnash,Burnaš,Uvarivka,Uvarovka,Бурна́ш,Уваровка,Уварівка', 45.4510800, 34.7881200, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130572, 'Listvennoye', 'Listvennoye', 'Listvennoe,Listvennoye,Listvinne,Лиственное,Листвинне', 45.4808600, 34.8108700, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130573, 'Vol’noye', 'Vol''noye', 'Frajleben,Vil''ne,Vol''noe,Vol''noye,Vol’noye,Вольное,Вільне,Фрайле́бен', 45.5657000, 34.3036000, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130574, 'Roshchino', 'Roshchino', 'Roshchino,Roshhine,Roshhino,Рощине,Рощино', 45.6091600, 34.3799200, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130575, 'Suvorovo', 'Suvorovo', 'Suvorove,Suvorovo,Суворове,Суворово', 46.0886500, 33.6880000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130576, 'Izumrudnoye', 'Izumrudnoye', 'Izumrudne,Izumrudnoe,Izumrudnoye,Ізумрудне,Изумрудное', 45.7370400, 34.4129900, 'UA', '2016-06-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130577, 'Kholmovka', 'Kholmovka', 'Kholmivka,Kholmovka,Zalankoj,Заланко́й,Холмовка,Холмівка', 44.6583000, 33.7545600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130578, 'Pakharevka', 'Pakharevka', 'Pakharevka,Pakharivka,Пахаревка,Пахарівка', 45.8347200, 34.1612900, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130579, 'Luganskoye', 'Luganskoye', '28-j uchastok,28-й участок,Lugans''ke,Luganskoe,Luganskoye,Луганское,Луганське', 45.8019000, 34.2378600, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130580, 'Yasnopolyanskoye', 'Yasnopolyanskoye', 'Jasnopoljans''ke,Jasnopoljanskoe,Yasnopolyanskoye,Яснополянское,Яснополянське', 45.9409700, 34.3526200, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130581, 'Novoozyornoye', 'Novoozyornoye', 'Novoozerne,Novoozerno,Novoozjornoe,Novoozoernoye,Novoozyornoe,Novoozyornoye,Novoozörnoye,Nowooserne,nuo wo ao ze er nie,Новоозерне,Новоозёрное,Նովոոզյորնոե,諾沃奧澤爾涅', 45.3831400, 33.1171500, 'UA', '2016-06-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130582, 'Chernovo', 'Chernovo', 'Chernove,Chernovo,Frajdorf,Фрайдорф,Чернове,Черново', 45.5083300, 33.9339700, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130583, 'Kukushkino', 'Kukushkino', 'Karaba-Kukush,Kukushkine,Kukushkino,Караба́-Куку́ш,Кукушкино,Кукушкіне', 45.7192400, 33.3903000, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130584, 'Senokosnoye', 'Senokosnoye', 'Bozuk-Kuju,Buzukkoj,Senokosnoe,Senokosnoye,Sinokisne,Бозу́к-Кую́,Бузукко́й,Сенокосное,Сінокісне', 45.7327700, 33.5155200, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130585, 'Bratskoye', 'Bratskoye', 'Brats''ke,Bratskoe,Bratskoye,Jalantush,Staryj Jalantash,Братское,Братське,Ста́рый Яла́нташ,Яланту́ш', 45.8317000, 33.9215100, 'UA', '2016-07-27', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130586, 'Sovkhoznoye', 'Sovkhoznoye', 'Sovkhozne,Sovkhoznoe,Sovkhoznoye,Совхозне,Совхозное', 45.9600500, 33.7715500, 'UA', '2016-08-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130587, 'Pochetnoye', 'Pochetnoye', 'Pochetne,Pochetnoye,Pochjotnoe,Tuzla,Почетне,Почётное,Тузла́', 45.9949500, 33.7658800, 'UA', '2017-03-28', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130588, 'Kamenolomnya', 'Kamenolomnya', 'Kamenolomnja,Kamenolomnya,Каменоломня', 45.2480400, 33.4177300, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130589, 'Vladimirovka', 'Vladimirovka', 'Vladimirovka,Volodimirivka,Владимировка,Володимирівка', 45.1476000, 33.5758300, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130590, 'Geroyskoye', 'Geroyskoye', 'Ashaga-Dzhamin,Gerojs''ke,Gerojskoe,Geroyskoye,Gor''kovskoe,Ашага́-Джами́н,Геройское,Геройське,Го́рьковское', 45.1385700, 33.7467500, 'UA', '2016-08-11', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130591, 'Zhuravli', 'Zhuravli', 'Zhuravli,Zhuravly,Журавли,Журавлі', 45.2524600, 33.6410400, 'UA', '2016-09-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130592, 'Zernovoye', 'Zernovoye', 'Zernove,Zernovoe,Zernovoye,Зернове,Зерновое', 45.2883800, 33.8641400, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130593, 'Chervonoye', 'Chervonoye', 'Chervone,Chervonnoe,Chervonoye,Червоне,Червонное', 45.1229400, 33.6866200, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130594, 'Novofedorovka', 'Novofedorovka', 'Novofedorivka,Novofedorovka,Novofjodorovka,Новофедорівка,Новофёдоровка', 45.0947300, 33.5721100, 'UA', '2016-08-12', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130595, 'Shkol’noye', 'Shkol''noye', 'Shkil''ne,Shkol''noe,Shkol''noye,Shkol’noye,Школьное,Шкільне', 45.0575800, 33.8973700, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130596, 'Vinnitskoye', 'Vinnitskoye', 'Vinnic''ke,Vinnickoe,Vinnitskoye,Винницкое,Вінницьке', 44.9812900, 33.7392000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130597, 'Prudovoye', 'Prudovoye', 'Prudove,Prudovoe,Prudovoye,Прудове,Прудовое', 44.9042400, 33.7811400, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130598, 'Kashtany', 'Kashtany', 'Kashtani,Kashtany,Novyj Burljuk,Каштани,Каштаны,Но́вый Бурлю́к', 44.8676000, 33.7899500, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130599, 'Aromatnoye', 'Aromatnoye', 'Aromatne,Aromatnoe,Ароматне,Ароматное', 44.8037300, 33.8700500, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130600, 'Solnechniy', 'Solnechniy', 'Solnechniy,Solnechnyj,Sonjachnij,Солнечный,Сонячний', 44.7867700, 33.6178600, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130601, 'Polyushko', 'Polyushko', 'Poljushko,Polyushko,Полюшко', 44.7421900, 33.5891300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130602, 'Zheleznodorozhnoye', 'Zheleznodorozhnoye', 'Zaliznichne,Zheleznodorozhnoe,Zheleznodorozhnoye,Железнодорожное,Залізничне', 44.7171000, 33.8041700, 'UA', '2016-05-20', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130603, 'Denyshi', 'Denyshi', 'Denishi,Denyshi,Дениші,Деныши', 50.2141500, 28.4039500, 'UA', '2010-03-07', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130604, 'Stepove', 'Stepove', 'Stepovoe,Степовое', 46.7038500, 30.0791900, 'UA', '2010-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130605, 'Pervomayskoye', 'Pervomayskoye', 'Karagoz,Pervomajs''ke,Pervomajskoe,Pervomayskoye,Караго́з,Первомайское,Первомайське', 45.0619100, 35.1639500, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130606, 'Yuzhnoukrains''k', 'Yuzhnoukrains''k', 'Juzhnoukrains''k,Juzhnoukrainsk,Южноукраинск,Южноукраїнськ', 47.8177700, 31.1826300, 'UA', '2010-10-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130607, 'Mizhhir’ya', 'Mizhhir''ya', 'Boureni,Mezhgor''e,Mischhirja,Mizhgir''ja,Mizhhiria,OEkoermezo,Volove,Volove Pole,Volovvyj,Volové,Wolowe,Wolowe Pole,Wołowe,Wołowe Pole,wwʼlʼwwʻ‎,Ökörmező,Воловвый,Волове,Волове Поле,Межгорье,Міжгір''я,וואלאווע‎', 48.5187600, 23.5023300, 'UA', '2017-01-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130608, 'Kremidivka', 'Kremidivka', 'Kremidivka,Kremidovka,Кремидовка,Кремидівка', 46.7335100, 30.7847200, 'UA', '2013-02-13', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130609, 'Kulykiv', 'Kulykiv', 'Kulikiv,Kulikov,Kulikow,Kulików,Куликов,Куликів', 49.9795400, 24.0781700, 'UA', '2013-02-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130610, 'Hlyns''k', 'Hlyns''k', 'Glins''k,Glins''ko,Glinsk,Glinsko,Glińsko,Глинск,Глинськ,Глинсько', 50.0603300, 23.8995600, 'UA', '2013-02-14', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130611, 'Novoyavorivs''k', 'Novoyavorivs''k', 'Novojavorivs''k,Novojavorovsk,Новояворовск,Новояворівськ', 49.9302300, 23.5735700, 'UA', '2013-02-19', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130612, 'Sofiyivska Borschagivka', 'Sofiyivska Borschagivka', 'Sofievskaja Borshhagovka,Софиевская Борщаговка', 50.4100500, 30.3672400, 'UA', '2013-03-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130613, 'Chervona Motovylivka', 'Chervona Motovylivka', 'Chervonaja Motovilovka,Червоная Мотовиловка', 50.1582100, 30.0742100, 'UA', '2013-03-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130614, 'Kriukivschina', 'Kriukivschina', 'Krjukovshhina,Крюковщина', 50.3715300, 30.3686100, 'UA', '2013-03-22', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130615, 'Horenka', 'Horenka', 'Gorenka,Horenka,Горенка', 50.5573100, 30.3321700, 'UA', '2015-04-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130616, 'Chabany', 'Chabany', 'Chabani,Chabany,Чабани,Чабаны', 50.3407100, 30.4235600, 'UA', '2014-01-09', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130617, 'Kirove', 'Kirove', 'Kirovo,Кирово', 50.3689000, 31.1206600, 'UA', '2013-04-24', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130618, 'Prolisky', 'Prolisky', 'Proleski,Proliski,Prolisky,Проліски', 50.3911800, 30.7800000, 'UA', '2015-04-29', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130619, 'Sovkhoznoye', 'Sovkhoznoye', 'Sovkhozne,Sovkhoznoe,Sovkhoznoye,Temir-Aga,Совхозне,Совхозное,Теми́р-Ага́', 45.0306100, 34.0106800, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130620, 'Ivanovka', 'Ivanovka', 'Beshkurtka,Ivanivka,Ivanovka,Іванівка,Бешкуртка́,Ивановка', 45.3743000, 34.7201300, 'UA', '2016-08-10', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130621, 'Krasnokamenka', 'Krasnokamenka', 'Krasnokam''janka,Krasnokamenka,Краснокаменка,Краснокам’янка', 44.9244600, 35.0754000, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130622, 'Aviatorskoe', 'Aviatorskoe', 'Aviators''ke,Aviatorskoe,Avіators''ke,Авиаторское,Авіаторське', 48.3671400, 35.0813200, 'UA', '2015-03-17', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130623, 'Sakharnaya Golovka', 'Sakharnaya Golovka', 'Sakharna Golovka,Sakharnaja Golovka,Sakharnaya Golovka,Сахарна Головка,Сахарная Головка', 44.5836200, 33.6438300, 'UA', '2016-05-23', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130624, 'Yarkoye Pole', 'Yarkoye Pole', 'Jarke Pole,Jarkoe Pole,Krasnyj Terchek,Yarkoye Pole,Кра́сный Терче́к,Ярке Поле,Яркое Поле', 45.2058100, 35.1984800, 'UA', '2016-07-21', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130625, 'Smotrych', 'Smotrych', 'Smotrich,Tatariski,Смотрич,Татариски', 48.6614900, 26.5603100, 'UA', '2017-04-02', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130626, 'Glybochek', 'Glybochek', 'Glibochek,Glubochek,Глибочек,Глубочек', 48.8668600, 30.7989700, 'UA', '2017-04-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130627, 'Nova Pryluka', 'Nova Pryluka', 'Nova Priluka,Novaja Priluka,Nowe Przyluki,Nowe Przyłuki,nwbh prylwqh,Нова Прилука,Новая Прилука,נובה פרילוקה', 49.3748800, 28.6995500, 'UA', '2017-05-30', 233);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130768, 'Bay Minette', 'Bay Minette', 'Bay Minette,Bay Minette Station,Bej Minet,Bej-Minett,bay mynyty,be minetta,bei mi nei te,by mynt,Бей-Мінетт,Беј Минет,باي مينيتي,بی مینت,बे मिनेत्त,贝米内特', 30.8829600, -87.7730500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130769, 'Edna', 'Edna', 'Edna,Ednaville,Macaroni Station,adna,adna  tgzas,Една,إدنا,ادنا، تگزاس', 28.9785900, -96.6460900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130770, 'Bayou La Batre', 'Bayou La Batre', 'Baju la Batr,Baju-La-Batr,Bayou La Batre,Bayou Labatra,Bayou Labatre,Bayou Le Batre,Bayou le Batre,bai you la ba te li,bayw la batr,beyau la batre,Баю-Ла-Батр,Бају ла Батр,بايو لا باتر,بایو لا باتر,बेयौ ला बात्रे,拜尤拉巴特里', 30.4035200, -88.2485200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130771, 'Henderson', 'Henderson', 'Khenderson,hndrswn,hndrswn  tgzas,Хендерсон,هندرسون,هندرسون، تگزاس', 32.1532200, -94.7993800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130772, 'Natalia', 'Natalia', '', 29.1896800, -98.8625300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130773, 'Bear Creek', 'Bear Creek', 'Bear Creek,Bearcreek', 34.2748200, -87.7005800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130774, 'Fort Hunt', 'Fort Hunt', '', 38.7328900, -77.0580300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130775, 'Yorktown', 'Yorktown', 'Jorktaun,Yorktown i Virginia,iorktʼauni,yokeutaun,yokutaun,yue ke zhen,ywrktwwn  wrjynya,Јорктаун,Йорктаун,یورکتوؤن، ورجینیا,იორქტაუნი,ヨークタウン,約克鎮,요크타운', 37.2387600, -76.5096700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130776, 'Brighton', 'Brighton', 'Brajton,Brighton,Woodward Crossing,Брайтон', 33.4342800, -86.9472100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130777, 'Ocean View', 'Ocean View', 'Hall''s Store,Halls Store,Ocean View,Oushan Vju,awshn fyw,osana bhyu,ou shen wei you,Оушан Вју,أوشن فيو,اوشن ویو، ڈیلاویئر,اوشن‌ویو، دلاور,ओसन भ्यू,欧申维尤', 38.5451100, -75.0890700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130778, 'Berry', 'Berry', 'Berry,Berry Station', 33.6598300, -87.6000100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130779, 'Trinity', 'Trinity', '', 28.1808500, -82.6817700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130780, 'Villas', 'Villas', '', 26.5503500, -81.8687000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130781, 'Bessemer', 'Bessemer', 'Besemer,Bessemer,bei se mo,bes''semara,beseomeo,bsmr,bysmyr,Бесемер,Бессемер,بسمر,بيسمير,बेस्सेमर,贝瑟默,베서머', 33.4017800, -86.9544400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130782, 'Aurora', 'Aurora', 'Aurora,Avrora,City of Aurora,Orora,arwra  ayndyana,Аврора,Орора,آرورا، ایندیانا', 39.0570000, -84.9013400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130783, 'New Pekin', 'New Pekin', 'New Pekin,Old Pekin,Pekin,Pekin Station', 38.5050600, -86.0169200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130784, 'Stockton', 'Stockton', 'Stock Town,Stockton,Stoktun,Стоктън', 39.4380700, -99.2651000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130785, 'Paducah', 'Paducah', 'PAH,Padjuka,Paducah,Paduka,Pekin,badwka,pa di you ka,pade~yuka,pdwka  kntaky,peodyuka,Падука,Падјука,بادوكا,پاڈوکاہ، کینٹکی,پدوکا، کنتاکی,パデューカ,帕迪尤卡,퍼듀카', 37.0833900, -88.6000500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130786, 'Monticello', 'Monticello', '', 32.5965300, -91.3940000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130787, 'Red Chute', 'Red Chute', '', 32.5559800, -93.6132300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130788, 'Jessup', 'Jessup', 'Andersonville,Dzesap,Hooversville,Jessup,Jessups,Jessups Cut,Jessups Cut Station,Pierceland,jswp  mrylnd,Џесап,جسوپ، مریلند', 39.1492700, -76.7752500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130789, 'Birmingham', 'Birmingham', 'BHM,Bermincham,Bermingkham,Birmingam,Birmingamas,Birmingem,Birmingema,Birmingham,Birmingham i Alabama,Birminhem,Gorad Birmingem,baminguhamu,baminhamu,barmingahema,barmingahyama,beominghaem,birmingemi,bo ming han,brmnghham,brmyngm  alabama,parminkam,Μπέρμιγχαμ,Бермингхам,Бирмингам,Бирмингем,Бірмінгем,Горад Бірмінгем,ברמינגהאם,برمنغهام,برمنگھم، الاباما,برمینگم، آلاباما,बर्मिंगहॅम,बर्मिङ्गह्याम,பர்மிங்காம்,རྦིར་མིང་ཧམ།,ბირმინგემი,バーミングハム,バーミンハム,伯明翰,버밍햄', 33.5206600, -86.8024900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130790, 'Delhi Hills', 'Delhi Hills', '', 39.0928400, -84.6127200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130791, 'Turpin Hills', 'Turpin Hills', '', 39.1100600, -84.3799400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130792, 'Lugoff', 'Lugoff', '', 34.2273700, -80.6892500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130793, 'Blountsville', 'Blountsville', 'Blauntsvil,Blauntsvill,balontasbhila,blantswyl,blwntsfyl,bu lang te si wei er,Блаунтсвил,Блаунтсвілл,بلانتسویل,بلونتسفيل,बलोन्टस्भिल,布朗特斯维尔', 34.0814900, -86.5911000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130794, 'Blue Ridge', 'Blue Ridge', '', 32.4926400, -86.1905200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130795, 'Buda', 'Buda', 'Bjuda,Buda,Do Pray,Du Pree,bwda,bwda  tgzas,Бјуда,بودا,بودا، تگزاس', 30.0852100, -97.8402800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130796, 'Boaz', 'Boaz', 'Boaz,bo a si,bo''aja,boazu,bwaz,Боаз,بواز,बोआज,ボアズ,波阿斯', 34.2006500, -86.1663700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130797, 'Brent', 'Brent', 'Brent,Cooper Addition', 32.9373500, -87.1647200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130798, 'Brewton', 'Brewton', 'Brewton,Brjuton,Bruton,Crossroads,Newport,bri''utana,brwtwn,brywtwn,bu lu dun,Брутон,Брютон,بروتون,بريوتون,ब्रीउटन,布鲁顿', 31.1051800, -87.0721900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130799, 'Bridgeport', 'Bridgeport', 'Bridgeport,Bridzhport,Bridzport,Jonesville,brijaporta,brydjbwrt,bryjpwrt,bu li qi bo te,Бриџпорт,Бріджпорт,برج پورٹ، الاباما,بريدجبورت,بریجپورت,ब्रिजपोर्ट,布里奇波特', 34.9475800, -85.7144200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130800, 'Brook Highland', 'Brook Highland', 'Lake Purdy', 33.4356600, -86.6738800, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130801, 'Brookside', 'Brookside', 'Bruksajd,brukasa''ida,brwksayd,brwksayd  alabama,bu lu ke sai de,Бруксайд,Бруксајд,بروكسايد,بروکساید، آلاباما,ब्रूकसाइड,布鲁克塞德', 33.6378800, -86.9166600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130802, 'Brookwood', 'Brookwood', 'Brookwood,Horsehead', 33.2556700, -87.3208300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130803, 'Brundidge', 'Brundidge', 'Brundidge,Colliers Store', 31.7201600, -85.8160600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130804, 'Butler', 'Butler', 'Batler,Butler,Hendrick''s Crossroads,Hendricks Crossroads,Hendrix Crossroads,ba te lei,batlara,batlr  alabama,btlr,Батлер,باتلر، آلاباما,بتلر,بٹلر، الاباما,बट्लर,巴特勒', 32.0895900, -88.2219700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130805, 'Bynum', 'Bynum', 'Bynum,Pig Tract', 33.6131600, -85.9610800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130806, 'Cahaba Heights', 'Cahaba Heights', 'Cahaba Heights,Merkel,New Market,New Merkle', 33.4640000, -86.7319300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130807, 'Calera', 'Calera', 'Buxahatchie,Calera,Kalera,Lime Kiln,Lime Plant,Lime Station,ka lai la,kalra,kalyra,kyalera,Калера,كاليرا,کالرا,क्यालेरा,卡莱拉', 33.1029000, -86.7536000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130808, 'Camden', 'Camden', 'Barboursville,Camden,Kamden,ka mu deng,kaemdeon,kamdn,kamdyn,kyamdena,Камден,كامدين,کامدن,کیمڈن، الاباما,क्याम्डेन,卡姆登,캠던', 31.9909800, -87.2905500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130809, 'Carbon Hill', 'Carbon Hill', 'Carbon Hill,Carbonhill', 33.8917700, -87.5261200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130810, 'Carrollton', 'Carrollton', 'Karolton,Karrollton,ka luo er dun,kaeleolteon,karwlltwn,karwltwn  alabama,kyarolatana,Каролтон,Карроллтон,كاروللتون,کارولتون، آلاباما,کیرولٹن، الاباما,क्यारोलटन,卡罗尔顿,캐럴턴', 33.2616900, -88.0950300, 'US', '2017-04-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130811, 'Cedar Bluff', 'Cedar Bluff', 'Cedar Bluff,Cedarbluff,Jefferson', 34.2200900, -85.6077400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130812, 'Center Point', 'Center Point', 'Senter Pojnt,Sentr-Pojnt,sentara po''inta,sntr bwynt,sntr pwynt  alabama,zhong xin dian,Сентер Појнт,Сентр-Пойнт,سنتر بوينت,سنتر پوینت، آلاباما,سەنتەر پۆینت، ئەلاباما,सेन्टर पोइन्ट,中心点', 33.6456600, -86.6836000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130813, 'Centre', 'Centre', 'Center,Centre,Senter,Sentr,sentara,sntr,sntr  alabama,zhong xin,Сентер,Сентр,سنتر,سنتر، آلاباما,سەنتەر، ئەلاباما,सेन्टर,中心', 34.1520400, -85.6788500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130814, 'Centreville', 'Centreville', 'Centerville,Centreville,Falls of Cahaba,Falls of the Cahawba,Sentervil,Sentrvill,The Falls,sen te wei er,sentarabhila,sntrfyl,sntrwyl  alabama,Сентервил,Сентрвілл,سنترفيل,سنترویل، آلاباما,سەنتەرڤیل، ئەلاباما,सेन्टरभिल,森特维尔', 32.9462000, -87.1166900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130815, 'Chalkville', 'Chalkville', '', 33.6531600, -86.6477700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130816, 'Chatom', 'Chatom', 'Chatom,catoma,cha te mu,chtwm  alabama,tshatwm,Чатом,تشاتوم,چتوم، آلاباما,چەتۆم، ئەلاباما,चाटोम,查特姆', 31.4651700, -88.2544600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130817, 'Chelsea', 'Chelsea', 'Chelsi,celsi,chelsi,chlsy  alabama,qie er xi,tshylsya,Челси,Челсі,تشيلسيا,چلسی، آلاباما,چێلسی، ئەلاباما,चेल्सी,切尔西,첼시', 33.3401100, -86.6302600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130818, 'Cherokee', 'Cherokee', 'Cheroki,ceroki,chrwky  alabama,qie nuo ji,shyrwky,Чероки,Черокі,شيروكي,چروکی، آلاباما,چێرۆکی، ئەلاباما,चेरोकी,切诺基', 34.7570300, -87.9728100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130819, 'Chickasaw', 'Chickasaw', 'Chikaso,chykasa  alabama,cikasah,qi ka suo,tshykasw,Чикасо,تشيكاسو,چیکاسا، آلاباما,چیکاسۆ، ئەلاباما,चिकासः,契卡索', 30.7638000, -88.0747200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130820, 'Childersburg', 'Childersburg', 'Childersberg,Childersburg,Childersburgh,ca''ildarsabarga,chai er de si bao,childeoseubeogeu,chyldrzbrg  alabama,tshyldrsbwrgh,Чилдерсберг,تشيلدرسبورغ,چیلدرزبرگ، آلاباما,چیلدەرزبورگ، ئەلاباما,चाइल्डर्सबर्ग,柴尔德斯堡,칠더스버그', 33.2781700, -86.3549800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130821, 'Choccolocco', 'Choccolocco', 'Choccolocco,Frog Level', 33.6592700, -85.7035700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130822, 'Citronelle', 'Citronelle', 'Sitronel,Sitronell,sa''itronela,sytrwnl  alabama,sytrwnyl,xi te luo nei er,Ситронел,Сітронелл,سيترونيل,سیترونل، آلاباما,سیترونێل، ئەلاباما,साइट्रोनेल,锡特罗内尔', 31.0907300, -88.2280600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130823, 'Clanton', 'Clanton', 'Clanton,Goose Pond,Klanton,Klenton,Pond,ke lan dun,keullaenteon,klantana,klantwn,klntn  alabama,Клантон,Клентон,كلانتون,کلنتن، آلاباما,کلەنتۆن، ئەلاباما,क्लान्टन,克兰顿,클랜턴', 32.8387400, -86.6294300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130824, 'Clay', 'Clay', 'Klej,ke lai,klay,kle,kly  alabama,Клей,Клеј,كلاي,کلی، آلاباما,کلەی، ئەلاباما,क्ले,克莱', 33.7026000, -86.5997100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130825, 'Clayton', 'Clayton', 'Klejton,ke lai dun,klaytwn,kletana,klytwn  alabama,Клейтон,Клејтон,كلايتون,کلیتون، آلاباما,کلیٹن، الاباما,کلەیتۆن، ئەلاباما,क्लेटन,克莱顿', 31.8782200, -85.4496600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130826, 'Cleveland', 'Cleveland', 'Anderton,Blackwoods Cross Roads,Blackwoods Crossroads,Cleveland,Dry Creek Cross Roads,Dry Creek Crossroads,Klivlend,ke li fu lan,klibhalyanda,klyfland,klywlnd  alabama,Кливленд,Клівленд,كليفلاند,کلیولند، آلاباما,کلیولینڈ، الاباما,کلیڤلەند، ئەلاباما,क्लिभल्यान्ड,克利夫兰', 33.9909300, -86.5774900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130827, 'Clio', 'Clio', 'Adkinson Head,Clio,Klajo Alabama),Klio,New Clio,ke li ou,kliyo,klyw,klyw  alabama,Клајо Алабама),Кліо,كليو,کلیو، آلاباما,کلیۆ، ئەلاباما,क्लियो,克里欧', 31.7087800, -85.6105000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130828, 'Coaling', 'Coaling', 'Clements Depot,Coaling', 33.1590100, -87.3408300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130829, 'Collinsville', 'Collinsville', 'Kolinsvil,Kollinsvil'',Kollinsvill,kalynzwyl  alabama,ke lin si wei er,kolinsabhila,kwlynsfyl,Колинсвил,Коллинсвиль,Коллінсвілл,كولينسفيل,کالینزویل، آلاباما,کۆلینزڤیل، ئەلاباما,कोलिन्सभिल,科林斯维尔', 34.2639800, -85.8605300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130830, 'Columbiana', 'Columbiana', 'Columbia,Columbiana,Coonsboro,German Hill,Kolambiana,Kolumbijana,ge lun bi ya na,klmbyana  alabama,kolambiyana,kwlwmbyana,Коламбіана,Колумбијана,كولومبيانا,کلمبیانا، آلاباما,کۆلومبیانا، ئەلاباما,कोलम्बियाना,哥伦比亚纳', 33.1781700, -86.6072100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130831, 'Concord', 'Concord', 'Konkord,Конкорд', 33.4676100, -87.0311100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130832, 'Coosada', 'Coosada', 'Coosaada,Coosada,Coosada Station,Coosauda', 32.4979100, -86.3313600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130833, 'Cordova', 'Cordova', 'Cordova,Dent', 33.7598300, -87.1833300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130834, 'Cottonwood', 'Cottonwood', 'Cotton Wood,Cottonwood,Kotonvud,Kottonvud,ka dun,katanavuda,katnwwd  alabama,qtnwwd,Котонвуд,Коттонвуд,قطنوود,کاتنوود، آلاباما,کۆتنوود، ئەلاباما,कटनवूड,卡顿', 31.0487900, -85.3049300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130835, 'Cowarts', 'Cowarts', 'Cowart,Cowarts', 31.2001800, -85.3046500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130836, 'Creola', 'Creola', '', 30.8918500, -88.0397200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130837, 'Crossville', 'Crossville', 'Copelands Bridge,Crossville,Krossvill,Krosvil,ke luo si wei er,krasabhila,kraswyl  alabama,krwwsfyl,Кросвил,Кроссвілл,كرووسفيل,کراسویل، آلاباما,کراسویل، الاباما,کرۆسڤیل، ئەلاباما,क्रसभिल,克罗斯维尔', 34.2875900, -85.9941400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130838, 'Cullman', 'Cullman', 'Kallmen,Kalman,Kulman,ka er man,kalamyana,karuman,keolmeon,klmn  alabama,kwlman,Каллмен,Калман,Кулман,Кълман,كولمان,کلمن، آلاباما,کەلمەن، ئەلاباما,कलम्यान,カルマン,卡尔曼,컬먼', 34.1748200, -86.8436100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130839, 'Dadeville', 'Dadeville', 'Dejdvil,Dejdvill,dai de wei er,ddwyl  alabama,dyadebhila,dydfyl,Дейдвілл,Дејдвил,ددویل، آلاباما,ديدفيل,دەیدڤیل، ئەلاباما,ड्याडेभिल,戴德维尔', 32.8312400, -85.7635700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130840, 'Daleville', 'Daleville', 'Dale Court House,Daleville,Dejlvil,Dejlvill,dai er wei er,dalyfyl,delabhila,dylwyl  alabama,Дейлвілл,Дејлвил,داليفيل,دیلویل، آلاباما,دەیلڤیل، ئەلاباما,डेलभिल,戴尔维尔', 31.3101700, -85.7129900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130841, 'Danville', 'Danville', 'Danville,Houstons Store', 34.4145400, -87.0875100, 'US', '2011-02-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130842, 'Daphne', 'Daphne', 'Dafni,Daphne,Daphney,Hollywood,da fu ni,dfny  alabama,dyaphne,dyfny,Дафни,Дафні,دفنی، آلاباما,ديفني,دەفنی، ئەلاباما,ड्याफ्ने,达芙妮', 30.6035300, -87.9036000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130843, 'Dauphin Island', 'Dauphin Island', 'Dafin-Ajlend,Dauphin-eiland,Dofin Ajland,Dofin-Ajlend,dafyn aylnd  alabama,dauphina a''ilyanda,dawfyn ayslnd,dopin-aillaendeu,duo fen dao,Дафін-Айленд,Дофин Ајланд,Дофин-Айленд,دافین آیلند، آلاباما,داوفين إيسلند,دۆفین ئایلەند، ئەلاباما,डौफिन आइल्यान्ड,多芬岛,도핀아일랜드', 30.2554800, -88.1097200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130844, 'Deatsville', 'Deatsville', 'Deatsville,Deetsville', 32.6081900, -86.3958100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130845, 'Decatur', 'Decatur', 'Decatur,Dekejter,Dekejtur,decatur,dekatara,di kai te,dikeiteo,diketa,diketara,dykatwr,dykytr  alabama,Декейтер,Декејтур,ديكاتور,دیکیتر، آلاباما,دیکەیتەر، ئەلاباما,ڈیکیٹر، الاباما,डिकेटर,डेकाटर,ディケーター,迪凯特,디케이터', 34.6059300, -86.9833400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130846, 'Demopolis', 'Demopolis', 'Demopolis,White Bluff,dai mo bo li si,demopolisa,dmwpwlys  alabama,dymwbwlys,Демополис,Демополіс,دموپولیس، آلاباما,ديموبوليس,دێمۆپۆلیس، ئەلاباما,डेमोपोलिस,戴摩波里斯', 32.5176400, -87.8364000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130847, 'Dora', 'Dora', 'Dora,Horse Creek,Horsecreek,Sharon', 33.7287200, -87.0902800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130848, 'Dothan', 'Dothan', 'Cawthons Cowpen,DHN,Dotan,Dothan,Dothen,Poplar Head,dosan,doseon,dothana,dothyana,duo sen,dwthan,dwthn  alabama,Дотан,دوثان,دوثن، آلاباما,دۆتەن، ئەلاباما,ڈوتھن، الاباما,डोथान,डोथ्यान,ドーサン,多森,도선', 31.2232300, -85.3904900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130849, 'Double Springs', 'Double Springs', '', 34.1463700, -87.4024700, 'US', '2017-05-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130850, 'East Brewton', 'East Brewton', '', 31.0932300, -87.0627500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130851, 'East Florence', 'East Florence', 'East Florence,Sweetwater', 34.8095300, -87.6494700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130852, 'Eclectic', 'Eclectic', '', 32.6354100, -86.0344100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130853, 'Elberta', 'Elberta', 'Elberta,ai er bo ta,albrta  alabama,aylbyrta,elbarta,Елберта,إيلبيرتا,ئێلبێرتا، ئەلاباما,البرتا، آلاباما,एल्बर्टा,埃尔伯塔', 30.4143600, -87.5977600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130854, 'Enterprise', 'Enterprise', 'Drake Eye,ETS,Enterprajs,Enterprajz,Enterprise,antrbrayz,antrprayz  alabama,en te pu lai si,intarapra''ija,Ентерпрайс,Ентерпрајз,إنتربرايز,ئینتەر پرایز، ئەلاباما,انترپرایز، آلاباما,इन्टरप्राइज,恩特普赖斯', 31.3151700, -85.8552200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130855, 'Eufaula', 'Eufaula', 'EUF,Eufala,Eufaula,Irwinton,Jufola,you fu la,yuphaula,ywfla  alabama,ywfwla,Јуфола,Юфола,يوفولا,یوفلا، آلاباما,یووفۆلا، ئەلاباما,युफौला,尤福拉', 31.8912700, -85.1454900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130856, 'Eutaw', 'Eutaw', 'Juto,you tuo,yutah,ywtaw,ywtyw  alabama,Јуто,Юто,يوتاو,یوتئو، آلاباما,یووتۆ، ئەلاباما,युटः,尤托', 32.8405900, -87.8876200, 'US', '2017-03-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130857, 'Evergreen', 'Evergreen', 'Coseys Old Field,Evergreen,Evergrin,ai fu ge lin,awrgryn  alabama,ayfrghryn,ebharagrina,Евергрин,Еверґрін,إيفرغرين,ئێڤەرگرین، ئەلاباما,اورگرین، آلاباما,एभरग्रीन,埃弗格林', 31.4335000, -86.9569200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130858, 'Fairfield', 'Fairfield', 'Corey,Fairfield,Feerfild,Ferfild,Feurfild,fei er fei er de,fyrfyld,fyrfyld  alabama,peeopildeu,pheyaraphilda,Ферфилд,Феърфилд,Феєрфілд,فيرفيلد,فیئرفیلڈ، الاباما,فیرفیلد، آلاباما,فێرفیلد، ئەلاباما,फेयरफिल्ड,费尔菲尔德,페어필드', 33.4859400, -86.9119400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130859, 'Fairhope', 'Fairhope', 'Alabama City,Fairhope,Feergoup,Ferkhoup,fei er huo pu,fyrhwb,fyrhwp  alabama,pheyarahopa,Ферхоуп,Феєргоуп,فيرهوب,فیئرہوپ، الاباما,فیرهوپ، آلاباما,فێرھۆپ، ئەلاباما,फेयरहोप,费尔霍普', 30.5229700, -87.9033300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130860, 'Falkville', 'Falkville', '', 34.3684300, -86.9086200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130861, 'Fayette', 'Fayette', 'Faett,Fayette,Fayette Courthouse,Fayette Depot,Fayette Depot Town,Fayetteville,Fejet,Frog Level,Lafayette,Latona,Latone,Layfayette,fayt  alabama,fayyt,fei ye te,peies,Фаєтт,Фејет,فاييت,فایت، آلاباما,فایێت، ئەلاباما,费耶特,페이엣', 33.6845500, -87.8308500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130862, 'Fayetteville', 'Fayetteville', 'Fayetteville,New Fayetteville', 33.1456700, -86.4058100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130863, 'Flint City', 'Flint City', 'Flint,Flint City,Morganburgh,Morgansburg', 34.5231500, -86.9702900, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130864, 'Florala', 'Florala', 'Florala,Lake City,Lake View,Lakeview,flwrala,flwrala  alabama,fu luo la la,phlorala,Флорала,فلورالا,فلورالا، آلاباما,فلورالا، ئەلاباما,फ्लोराला,弗洛腊拉', 31.0051800, -86.3280000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130865, 'Florence', 'Florence', 'Florencija,Florens,flarns  alabama,flwrns,flwrns  alabama,fu luo lun si,furorensu,peullolenseu,phlorensa,Флоренс,Флоренция,فلارنس، آلاباما,فلورنس,فلورنس، الاباما,فلۆرەنس، ئەلاباما,फ्लोरेन्स,フローレンス,弗洛伦斯,플로렌스', 34.7998100, -87.6772500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130866, 'Flomaton', 'Flomaton', 'Flomaton,Pensacola Junction,Reutersville,Whiting', 31.0001800, -87.2608100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130867, 'Foley', 'Foley', 'Foley,Foli,NHX,fu li,fwly,fwly  alabama,pholi,Фоли,Фолі,فولي,فولی، آلاباما,فۆلی، ئەلاباما,फोली,弗利', 30.4065900, -87.6836000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130868, 'Forestdale', 'Forestdale', '', 33.5701100, -86.8963800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130869, 'Fort Deposit', 'Fort Deposit', 'Fort Deposit,Fort Deposite,Fort Depozit,Fort-Dipozit,di bo xi te bao,fwrt dpazyt  alabama,fwrt dybwzyt,pharta dipojita,Форт Депозит,Форт-Діпозіт,فورت ديبوزيت,فورت دپازیت، آلاباما,فۆرت دیپۆزیت، ئەلاباما,फर्ट डिपोजिट,迪波西特堡', 31.9845900, -86.5785900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130870, 'Fort Payne', 'Fort Payne', 'Fort Pejn,Fort-Pejn,fwrt bayn,fwrt pyn  alabama,pei en bao,pharta peyana,Форт Пејн,Форт-Пейн,فورت باين,فورت پین، آلاباما,فۆرت پەین، ئەلاباما,फर्ट पेयन,佩恩堡', 34.4442500, -85.7196900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130871, 'Frisco City', 'Frisco City', 'Frisco City,Jones Mill,Jones Mills,Roy', 31.4335000, -87.4013800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130872, 'Fultondale', 'Fultondale', 'Fultondejl,fwltndyl  alabama,fwltwndal,phulatanadela,Фултондейл,Фултондејл,فولتندیل، آلاباما,فولتندەیل، ئەلاباما,فولتوندال,फुलटनडेल', 33.6048300, -86.7938800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130873, 'Fyffe', 'Fyffe', '', 34.4467600, -85.9041400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130874, 'Gadsden', 'Gadsden', 'Double Springs,GAD,Gadsden,Queen City of the Coosa,gaejeudeon,gazuden,gdsdn  alabama,ghadsdn,gyadsdena,jia ci deng,Гадсден,Ґадсден,غادسدن,گدسدن، آلاباما,گەدسدن، ئەلاباما,ग्याड्स्डेन,ガズデン,加兹登,개즈던', 34.0143400, -86.0063900, 'US', '2017-03-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130875, 'Gardendale', 'Gardendale', 'Gardendejl,gardenadela,gardndyl  alabama,ghardndyl,jia deng,Гардендејл,Ґардендейл,غاردنديل,گاردندیل، آلاباما,گاردندەیل، ئەلاباما,गार्डेनडेल,加登', 33.6601000, -86.8127700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130876, 'Geneva', 'Geneva', 'Dzeniva,Zheneva,Zheniva,jenebha,jie ni wa,jnyfa,jnywa  alabama,Џенива,Женева,Женіва,جنيفا,جنیوا، آلاباما,جنیڤا، ئەلاباما,जेनेभा,杰尼瓦', 31.0329600, -85.8638200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130877, 'Georgiana', 'Georgiana', 'Georgiana,Pittsville', 31.6371000, -86.7419200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130878, 'Glencoe', 'Glencoe', 'Glenko,Glinko,ge lan ke,ghlnkw,glenako,glnkw  alabama,Гленко,Ґлінко,غلنكو,گلنکو، آلاباما,گلێنکۆ، ئەلاباما,ग्लेनको,格兰克', 33.9570400, -85.9324700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130879, 'Good Hope', 'Good Hope', 'Gud Khoup,Gud-Goup,ghwd hwb,gu de huo pu,guda hopa,gwd hwp  alabama,Гуд Хоуп,Ґуд-Гоуп,غود هوب,گود هوپ، آلاباما,گود ھۆپ، ئەلاباما,गूड होप,古德霍普', 34.1159300, -86.8636100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130880, 'Goodwater', 'Goodwater', 'Adkins Gap,Good Water,Goodwater,Gudvoter,ghwdwwtr,gu de wo te,gudavatara,gwd watr  alabama,Гудвотер,Ґудвотер,غودووتر,گود واتر، آلاباما,گودوۆتەر، ئەلاباما,गूडवाटर,古德沃特', 33.0656700, -86.0533000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130881, 'Gordo', 'Gordo', '', 33.3201200, -87.9028000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130882, 'Grand Bay', 'Grand Bay', 'Grand Bay,Grand Bej,Grandbay,Grend-Bej,ghrand byh,grnd by  alabama,gryanda be,Гранд Беј,Ґренд-Бей,غراند بيه,گرند بی، آلاباما,ग्र्यान्ड बे', 30.4763100, -88.3422300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130883, 'Grayson Valley', 'Grayson Valley', '', 33.6481600, -86.6394300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130884, 'Graysville', 'Graysville', 'Gintown,Graysville,Grejsvil,Grejsvill,ge lei si wei er,ghrysfyl,grejabhila,gryswyl  alabama,Грејсвил,Ґрейсвілл,غريسفيل,گریسویل، آلاباما,گرەیسڤیل، ئەلاباما,ग्रेजभिल,格雷斯维尔', 33.6206600, -86.9713800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130885, 'Greensboro', 'Greensboro', 'Greensboro,Greensborough,Grinsboro,New Troy,Russell Settlement,Troy,ge lin si bo luo,ghrynsbwrw,grinasbaro,grynzbwrw  alabama,Гринсборо,Ґрінсборо,غرينسبورو,گرینزبورو، آلاباما,گرینزبۆرۆ، ئەلاباما,ग्रीनस्बरो,格林斯博罗', 32.7041500, -87.5955000, 'US', '2017-03-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130886, 'Greenville', 'Greenville', 'Buttsville,Greenville,Grinvil,Grinvill,ge lin wei er,ghrynfyl,grinabhila,grynwyl  alabama,Гринвил,Гринвилл,Ґрінвілл,غرينفيل,گرینویل، آلاباما,گرینویل، الاباما,گرینڤیل، ئەلاباما,ग्रीनभिल,格林维尔', 31.8296000, -86.6177500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130887, 'Grove Hill', 'Grove Hill', 'Grave Hill,Grove Hill,Grovehill,Macon,Magoffins Store,Smithville', 31.7087700, -87.7772200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130888, 'Guin', 'Guin', 'Caudle,Guin,Gvin,ghwyn,gn  alabama,gu yin,gu''ina,Гвин,Гуїн,غوين,گن، آلاباما,گوین، ئەلاباما,गुइन,古因', 33.9656600, -87.9147500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130889, 'Gulf Shores', 'Gulf Shores', 'GUF,Galf Shors,Galf-Shors,galf shwrz  alabama,galpha sorsa,ge er fu hai an,ghlf shwrz,Галф Шорс,Ґалф-Шорс,غلف شورز,گالف شورز، آلاباما,گەلف شۆرز، ئەلاباما,गल्फ शोर्स,格尔夫海岸', 30.2460400, -87.7008200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130890, 'Guntersville', 'Guntersville', 'Creek Path,Gantersvil,Gantersvill,Gunters Ferry,Gunters Landing,Gunters Village,Guntersville,Helican,Helicon,Kusa-Nunahi,Kusanunnahi,Marshall,White House,Wyeth City,gan te si wei er,gantrzwyl  alabama,ghntrsfyl,guntarsabhila,Гантерсвил,Гантерсвілл,غنترسفيل,گانترزویل، آلاباما,گەنتەرسڤیل، ئەلاباما,गुन्टर्सभिल,甘特斯维尔', 34.3582300, -86.2944600, 'US', '2017-04-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130891, 'Hackleburg', 'Hackleburg', '', 34.2773200, -87.8286400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130892, 'Haleyville', 'Haleyville', 'Gejlivill,Haleysville,Haleyville,Khejlivil,halyfyl,halywyl,hei li wei er,hyalebhila,Гейлівілл,Хејливил,هاليفيل,هالیویل,ھالیڤیل، ئەلاباما,ह्यालेभिल,黑利维尔', 34.2264900, -87.6214100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130893, 'Hamilton', 'Hamilton', 'Gamil''ton,Gemilton,HAB,Hamilton,Khamilton,Toll Gate,hamyltwn,han mi er dun,hmyltwn  alabama,hyamilatana,Гамильтон,Гемілтон,Хамилтон,هاميلتون,همیلتون، آلاباما,ھەمیلتۆن، ئەلاباما,ہیملٹن، الاباما,ह्यामिलटन,汉密尔顿', 34.1423200, -87.9886400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130894, 'Hanceville', 'Hanceville', 'Gensvill,Gilmer,Hanceville,Khensvil,han si wei er,hnswyl  alabama,hyansabhila,hynsfyl,Генсвілл,Хенсвил,هنسویل، آلاباما,هينسفيل,ھێنسڤیل، ئەلاباما,ह्यान्सभिल,汉斯维尔', 34.0606500, -86.7675000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130895, 'Harpersville', 'Harpersville', '', 33.3440000, -86.4380400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130896, 'Hartford', 'Hartford', 'Clemmons City,Dundee,Gartford,Hartford,Khartford,ha te fu de,hartapharda,hartfwrd,Гартфорд,Хартфорд,هارتفورد,ھارتفۆرد، ئەلاباما,ہارٹفورڈ، الاباما,हार्टफर्ड,哈特福德', 31.1024000, -85.6968800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130897, 'Hartselle', 'Hartselle', 'Gartsell,Hartsel,Hartsell,Hartsell''s Station,Hartselle,Hartsells,Khartsel,ha te sai er,hartasela,hartsl  alabama,hartsyl,Гартселл,Хартсел,هارتسل، آلاباما,هارتسيل,ھارتسێل، ئەلاباما,हार्टसेल,哈特塞尔', 34.4434300, -86.9352800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130898, 'Harvest', 'Harvest', 'Garvest,Harvest,Kelly,Kharvest,harbhesta,harfst,harwst,Гарвест,Харвест,هارفست,هاروست,हार्भेस्ट', 34.8556400, -86.7508300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130899, 'Hayden', 'Hayden', 'Hayden,Rockland', 33.8926000, -86.7577700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130900, 'Hayneville', 'Hayneville', 'Big Swamp,Gejnvill,Hayneville,Khejnvil,hai en wei er,hayanabhila,hynfyl,hynwyl  alabama,Гейнвілл,Хејнвил,هينفيل,هینویل، آلاباما,ھەینڤیل، ئەلاباما,हायनभिल,海恩维尔', 32.1840300, -86.5802500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130901, 'Hazel Green', 'Hazel Green', 'Hazel Green,Hazlegreen', 34.9323100, -86.5719400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130902, 'Headland', 'Headland', 'Gedlend,Khedland,hdlnd  alabama,he lan,hedalyanda,hydland,Гедленд,Хедланд,هدلند، آلاباما,هيدلاند,ھێدلەند، ئەلاباما,हेडल्यान्ड,赫兰', 31.3512800, -85.3421600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130903, 'Heflin', 'Heflin', 'Geflin,Kheflin,he fu lin,hephina,hflyn  alabama,hyfln,Гефлін,Хефлин,هفلین، آلاباما,هيفلن,ھێفلین، ئەلاباما,हेफिन,赫夫林', 33.6489900, -85.5874600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130904, 'Helena', 'Helena', 'Cove,Gelena,Helena,Hillsboro,Hillsborough,Khelena,Khelina,Lees Cove,hai lun na,helena,hlna  alabama,hylyna,Гелена,Хелена,Хелина,هلنا، آلاباما,هيلينا,ھێلێنا، ئەلاباما,हेलेना,海伦娜', 33.2962200, -86.8436000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130905, 'Henagar', 'Henagar', '', 34.6350800, -85.7671900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130906, 'Hokes Bluff', 'Hokes Bluff', 'Hokes Bluff,Hokesbluff,Hooks Bluff,The Bluff', 33.9981500, -85.8663600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130907, 'Holt', 'Holt', '', 33.2340100, -87.4844500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130908, 'Holtville', 'Holtville', 'Holtville,Slapout', 32.6362400, -86.3266400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130909, 'Homewood', 'Homewood', 'Goumvud,Khomvud,homavuda,huo mu wu de,hwmwwd,hwmwwd  alabama,Гоумвуд,Хомвуд,هوموود,هوموود، آلاباما,ھۆموود، ئەلاباما,होमवूड,霍姆伍德', 33.4717700, -86.8008200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130910, 'Hoover', 'Hoover', 'Guver,Hoover,Khuver,fuba,hu fu,hubhara,hwfr,hwwr  alabama,Гувер,Хувер,هوفر,هوور، آلاباما,ھووڤەر، ئەلاباما,ہوور، الاباما,हूभर,フーバー,胡佛', 33.4053900, -86.8113800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130911, 'Hueytown', 'Hueytown', 'Earnest,G''juitaun,Huey,Hueytown,Khjuitaun,hu ai zhen,hwytawn,hyuyata''una,hywyytawn  alabama,Гьюітаун,Хјуитаун,هويتاون,هیوئیتاون، آلاباما,ھیویتاون، ئەلاباما,ह्युयटाउन,胡艾镇', 33.4512200, -86.9966600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130912, 'Huguley', 'Huguley', '', 32.8345700, -85.2296600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130913, 'Huntsville', 'Huntsville', 'Gantsvill,HSV,Hantsvila,Hantsvilis,Hantsvill,Hunts Spring,Huntsville,Khantsvil,Khantsvill,Khuntsvil,Twickenham,hantsabhila,hantsubiru,hantswyl  alabama,heng ci wei er,heoncheubil,hntsfyl,Гантсвілл,Хантсвил,Хантсвилл,Хънтсвил,האנטסוויל,هانتسویل، آلاباما,هنتسفيل,ھەنتسڤیل، ئەلاباما,ہنٹسویل، الاباما,हन्त्सभिल,ハンツビル,亨茨维尔,헌츠빌', 34.7304000, -86.5859400, 'US', '2017-04-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130914, 'Indian Springs Village', 'Indian Springs Village', '', 33.3553900, -86.7544300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130915, 'Inverness', 'Inverness', 'Inverness,Thomas Station,Thomasville', 32.0148800, -85.7460600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130916, 'Irondale', 'Irondale', 'Ajrondejl,a''iranadela,ai ang dai er,ayrndyl  alabama,ayrwndyl,Айрондейл,Ајрондејл,آيرونديل,آیرندیل، آلاباما,ئایرۆندەیل، ئەلاباما,आइरनडेल,艾昂戴尔', 33.5381600, -86.7072100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130917, 'Jackson', 'Jackson', 'Dzekson,Dzhekson,Jackson,Pine Level,Republicville,jaksn  yەlabama,jakswn,jakuson,jie ke xun,jksn  alabama,jyakasana,jyksn  alabama,Џексон,Джексон,جاكسون,جاکسن، ئەلاباما,جکسن، آلاباما,جیکسن، الاباما,ज्याकसन,ジャクソン,杰克逊', 31.5090500, -87.8944400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130918, 'Jacksonville', 'Jacksonville', 'Drayton,Dzeksonvil,Dzheksonvill,Greens Trading Post,Jackson,Jackson Ville,Jacksonville,Jacksoonville,Jaksonville,Madison,jaksnvyl  yەlabama,jakswnfyl,jakusonbiru,jie ke xun wei er,jkkswnwyl  alabama,jksnwyl  alabama,jyakasanabhila,Џексонвил,Джексонвилл,Джексонвілл,جاكسونفيل,جاکسنڤیل، ئەلاباما,جکسنویل، آلاباما,جککسونویل، الاباما,ज्याकसनभिल,ジャクソンビル,杰克逊维尔', 33.8138200, -85.7613000, 'US', '2017-03-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130919, 'Jasper', 'Jasper', 'Dzasper,Dzhasper,bi yu,gspr,jaeseupeo,jasbr,jaspr  alabama,jspr  albama,jyaspara,Џаспер,Джаспер,גספר,جاسبر,جاسپر، آلاباما,جاسپەر، ئەلاباما,جسپر، الباما,ज्यास्पर,碧玉,재스퍼', 33.8312200, -87.2775100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130920, 'Jemison', 'Jemison', 'Bristol,Jamison,Jemison,Langston Station,Langstonsville', 32.9598500, -86.7466500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130921, 'Kimberly', 'Kimberly', 'Jefferson,Kimberli,Kimberly,jin bai li,kimbarle,kmbrly,kymbrly  alabama,Кимберли,Кімберлі,كمبرلي,کیمبرلی، آلاباما,کیمبەرلی، ئەلاباما,किम्बर्ले,金佰利', 33.7734400, -86.8138800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130922, 'Kinsey', 'Kinsey', 'Kinsi,jin sai,kinse,knsy,kynzy  alabama,Кинси,Кінсі,كنسي,کینزی، آلاباما,کینزی، ئەلاباما,किन्से,金赛', 31.2990600, -85.3443800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130923, 'Ladonia', 'Ladonia', '', 32.4682000, -85.0791000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130924, 'Lafayette', 'Lafayette', 'Chambersville,La Fayette,LaFayette,Lafajet,Lafayette,LayFayette,Лафайет', 32.8998500, -85.4010600, 'US', '2012-05-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130925, 'Lake Purdy', 'Lake Purdy', '', 33.4301100, -86.6805400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130926, 'Lake View', 'Lake View', '', 33.2806700, -87.1375000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130927, 'Lanett', 'Lanett', 'Bluffton,Lanet,Lanett,la nei te,lanyt,leneta,lnt  alabama,Ланет,Ланетт,لانيت,لانیٹٹ، الابامہ,لنت، آلاباما,لەنێت، ئەلاباما,लेनेट,拉内特', 32.8687400, -85.1905000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130928, 'Leeds', 'Leeds', 'Cedar Grove,Leeds,Lids,Oak Ridge,li ci,lidsa,lydz,lydz  alabama,Лидс,Лідс,ليدز,لیدز، آلاباما,لیدز، ئەلاباما,لیڈز، الاباما,लीड्स,利兹', 33.5481600, -86.5444300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130929, 'Leesburg', 'Leesburg', 'Hamptonville,Leesburg,Leesburgh,Lisberg,Lizburg,li si bao,lijbarga,lysbrgh,lyzbrg  alabama,Лизбург,Лісберг,ليسبرغ,لیزبرگ، آلاباما,لیزبرگ، الاباما,لیزبێرگ، ئەلاباما,लीज्बर्ग,利斯堡', 34.1798200, -85.7613600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130930, 'Level Plains', 'Level Plains', 'Level Plain,Level Plains,Level Plains Crossroads', 31.2996200, -85.7779900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130931, 'Linden', 'Linden', 'Hohenlinden,Linden,Lindon,Marengo,Screamsville,lin deng,lindena,lyndn,lyndn  alabama,Линден,Лінден,ليندن,لیندن، آلاباما,لیندن، ئەلاباما,लिन्डेन,林登', 32.3062500, -87.7980700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130932, 'Lincoln', 'Lincoln', 'Kingsville,Lincoln,Linkol''n,Linkoln,lin ken,lingkeon,linkana,lnkn,lnkn  alabama,lynkwln  alabama,Линколн,Линкольн,Лінкольн,لنكن,لنکن، الاباما,لینکن، ئەلاباما,لینکولن، آلاباما,लिङ्कन,林肯,링컨', 33.6131600, -86.1183100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130933, 'Lineville', 'Lineville', 'County Line,Lajnvil,Lajnvill,Lineville,Lundies Crossroads,la''inabhila,lai en si wei er,laynfyl,laynwyl  alabama,Лайнвілл,Лајнвил,لاينفيل,لاینویل، آلاباما,لاینڤیل، ئەلاباما,लाइनभिल,莱恩斯维尔', 33.3106700, -85.7544100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130934, 'Lipscomb', 'Lipscomb', 'Lipscomb,Lipskom,Wheeling,li pu si ke mu,lipskomba,lybskwmb,lypskm  alabama,ripusukomu,Липском,Ліпском,ليبسكومب,لیپسکم، آلاباما,لیپسکۆم، ئەلاباما,लिप्स्कोम्ब,リプスコーム,利普斯科姆', 33.4256600, -86.9266600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130935, 'Livingston', 'Livingston', 'Livingston,Livingstone,li wen si dun,libhingastana,lyfynghstn,lywyngstwn  alabama,Ливингстон,Лівінгстон,ليفينغستن,لیونگسٹن، الاباما,لیوینگستون، آلاباما,لیڤینگستن، ئەلاباما,लिभिंगस्टन,利文斯顿', 32.5843000, -88.1872500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130936, 'Locust Fork', 'Locust Fork', '', 33.9076000, -86.6152700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130937, 'Loxley', 'Loxley', 'Bennett,Loksli,Loxley,laksly  alabama,lokse,luo shi li,lwksly,Локсли,Локслі,لاکسلی، آلاباما,لوكسلي,لۆکسلی، ئەلاباما,लोक्से,洛士利', 30.6182500, -87.7530500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130938, 'Luverne', 'Luverne', 'Lavern,Luvern,lawrn  alabama,lu wen,lubharne,lwfrn,Лаверн,Луверн,لاورن، آلاباما,لوفرن,लुभर्ने,卢文', 31.7165500, -86.2638500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130939, 'Madison', 'Madison', 'Madison,Medison,Mehdison,madison,madysn,mai di xun,mdyswn  alabama,myadisana,Мадисон,Медисон,Медісон,Мэдисон,ماديسن,مدیسون، آلاباما,میڈیسون، الاباما,مەدیسن، ئەلاباما,म्याडिसन,マディソン,麦迪逊', 34.6992600, -86.7483300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130940, 'Malvern', 'Malvern', 'Eagan,Malvern', 31.1393400, -85.5191000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130941, 'Marbury', 'Marbury', 'Bozeman,Marbury', 32.7012400, -86.4710900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130942, 'Margaret', 'Margaret', '', 33.6862100, -86.4749800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130943, 'Marion', 'Marion', 'Marion,Mehrion,Muckles Ridge,ma li ang,marywn,marywn  alabama,meriyana,Марион,Маріон,Мэрион,ماريون,ماریون، آلاباما,ماریون، الاباما,ماریۆن، ئەلاباما,मेरियन,马里昂', 32.6323500, -87.3191700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130944, 'Meadowbrook', 'Meadowbrook', '', 33.4020500, -86.6966500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130945, 'Meridianville', 'Meridianville', '', 34.8514800, -86.5722200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130946, 'Midfield', 'Midfield', 'Midfild,mdfyld,midaphilda,mydfyld  alabama,zhong chang,Мидфилд,Мідфілд,مدفيلد,میدفیلد، آلاباما,میدفیلد، ئەلاباما,मिडफिल्ड,中场', 33.4615000, -86.9088800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130947, 'Midland City', 'Midland City', 'Kennedys Crossroads,Midland City', 31.3190600, -85.4938200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130948, 'Mignon', 'Mignon', '', 33.1834500, -86.2610900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130949, 'Millbrook', 'Millbrook', 'Milbruk,Millbruk,mi er bu lu ke,milabruka,milbeulug,mylbrwk,mylbrwk  alabama,Милбрук,Міллбрук,ميلبروك,میلبروک، آلاباما,میلبروک، ئەلاباما,मिलब्रूक,米尔布鲁克,밀브룩', 32.4798600, -86.3619200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130950, 'Minor', 'Minor', '', 33.5373300, -86.9405500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130951, 'Mobile', 'Mobile', 'La Mobila,La Mobile,MOB,Mo-il-la,Mobajl,Mobil,Mobila,Mobilas,Mobile,Mobille,Moville,mo bi er,moba''ila,mobil,mobila,mobili,mobiru,mwbayl  alabama,mwbyl,mwbyl  alabama,Мобајл,Мобил,Мобіл,מוביל,موبائل، الاباما,موبيل,موبیل، آلاباما,मोबाइल,मोबिल,მობილი,ម៉ូបាល,モービル,莫比尔,모빌', 30.6943600, -88.0430500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130952, 'Monroeville', 'Monroeville', 'Centerville,MVC,Monroeville,Monrovil,Monrovill,Walkers Mill,Walkers Store,men luo wei er,munrobhila,mwnrwfyl,mwnrwwyl  alabama,Монровил,Монровілл,مونروفيل,مونروویل، آلاباما,مۆنرۆڤیل، ئەلاباما,मुन्रोभिल,门罗维尔', 31.5279400, -87.3247100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130953, 'Montevallo', 'Montevallo', 'Kings,Montavalo,Montevallo,Montevalo,Montivello,Smiths Store,Wilsons Hill,meng te wa luo,montebhyalo,mwntyfalw,mwntywlw  alabama,Монтевало,Монтівелло,مونتيفالو,مونتیولو، آلاباما,مۆنتێڤەلۆ، ئەلاباما,मोन्तेभ्यालो,蒙特瓦洛', 33.1006700, -86.8641600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130954, 'Montgomery', 'Montgomery', 'Gorad Mantgomery,MGM,Mons Gomerici,Montgomeri,Montgomeris,Montgomery,Montgomuri,Montnkomeri,mamtagomeri,mantagomeri,mantgameri,mantkamari,meng ge ma li,mong-gomeli,mongomeri,montagomari,mwntghwmry,mwntgmry,mwntgwmry,mxn t kx me xri,Μοντγκόμερι,Горад Мантгомеры,Монтгомери,Монтгомері,Монтгомъри,Մոնտգոմերի,מאנטגאמערי,מונטגומרי,مونتغومري,مونتگمری,مونٹگمری,مونٹگمری، الاباما,माँटगोमेरी,मान्टगोमेरी,मोन्टगोमरी,मोन्तगोमरी,மான்ட்கமரி,ಮಾಂಟ್ಗಾಮೆರಿ,มอนต์กอเมอรี,მონტგომერი,モンゴメリー,蒙哥馬利,蒙哥马利,몽고메리', 32.3668100, -86.2999700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130955, 'Moody', 'Moody', 'Moody,Moodys,Moodys Crossroads', 33.5909400, -86.4908200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130956, 'Moores Mill', 'Moores Mill', 'Moore Mill,Moores Mill,Moores Mills', 34.8439800, -86.5183200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130957, 'Morris', 'Morris', 'Moris,Morris,mo li si,morisa,mwrys,mwrys  alabama,Морис,Морріс,موريس,موریس، آلاباما,مۆریس، ئەلاباما,मोरिस,莫里斯', 33.7481600, -86.8086000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130958, 'Moulton', 'Moulton', 'Molton,ma''ulatana,mo er dun,mwltn,mwltn  alabama,Молтон,مولتن,مولتن، آلاباما,مۆلتن، ئەلاباما,माउलटन,莫尔顿', 34.4812100, -87.2933500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130959, 'Moundville', 'Moundville', 'Carthage,Maundvil,Maundvill,Moundville,ma''undabhila,mang de wei er,mawndfyl,mawndwyl  alabama,Маундвил,Маундвілл,ماوندفيل,ماوندویل، آلاباما,ماوندڤیل، ئەلاباما,माउन्डभिल,芒德维尔', 32.9976200, -87.6300100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130960, 'Mount Olive', 'Mount Olive', '', 33.6709400, -86.8561000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130961, 'Mount Vernon', 'Mount Vernon', 'Mount Vernon,United States Arsenal', 31.0851800, -88.0133300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130962, 'Mountain Brook', 'Mountain Brook', '', 33.5009400, -86.7522100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130963, 'Munford', 'Munford', 'Munford,Munford Station', 33.5298300, -85.9508000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130964, 'Muscle Shoals', 'Muscle Shoals', 'Chustanaluyi,Dagunahi,MSL,Masl Shouls,Masl-Shols,Muscle Shoals,Quad Cities,The Shoals,Tri-Cities,ma si er xiao er si,masala solsa,masl shaywlz  alabama,msl shwls,Масл Шоулс,Масл-Шолс,ماسل شائولز، آلاباما,مسل شولس,مەسل شۆلس، ئەلاباما,मशल शोल्स,马斯尔肖尔斯', 34.7448100, -87.6675300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130965, 'New Brockton', 'New Brockton', 'Brock,Brockton,New Brockton,New Brocton', 31.3857200, -85.9293900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130966, 'New Hope', 'New Hope', 'Clouds Town,N''ju-Goup,New Hope,Newhope,Nju Khoup,Vienna,n''yu hopa,nw hwb,nyw hwp  alabama,xin xi wang,Њу Хоуп,Нью-Гоуп,نو هوب,نیو هوپ، آلاباما,न्यु होप,新希望', 34.5371200, -86.3942600, 'US', '2017-04-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130967, 'New Market', 'New Market', 'N''ju-Market,New Market,Newmarket,Nju Market,n''yu marketa,nw markt,nyw markt  alabama,Њу Маркет,Нью-Маркет,نو ماركت,نیو مارکت، آلاباما,न्यु मार्केट', 34.9100300, -86.4277900, 'US', '2017-04-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130968, 'Newton', 'Newton', 'N''juton,Njuton,n''yutana,niu dun,nwtn,nywtn  alabama,Њутон,Ньютон,نوتن,نیوتن، آلاباما,نیووتن، ئەلاباما,न्युटन,牛顿', 31.3351700, -85.6052100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130969, 'North Bibb', 'North Bibb', '', 33.2040100, -87.1530500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130970, 'Northport', 'Northport', 'Canetuck,Kentuck,North Port,North Tuskaloosa,Northport,Nortport,narthaporta,noseupoteu,nosupoto,nuo si bo te,nwrth bwrt,nwrthpwrt  alabama,Нортпорт,نورتپۆرت، ئەلاباما,نورث بورت,نورثپورت، آلاباما,नर्थपोर्ट,ノースポート,诺斯波特,노스포트', 33.2290100, -87.5772300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130971, 'Odenville', 'Odenville', 'Hardins Shop,Liberty,Odenville', 33.6773200, -86.3966500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130972, 'Ohatchee', 'Ohatchee', 'Ohatchee,Ohatchie', 33.7834300, -86.0024700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130973, 'Opelika', 'Opelika', 'Big Swamp,Opelajka,Opelika,Opelikan,Opillaka,Owls Roost,awbylyka,awplyka  alabama,opela''ika,opelika,ou pei lai ka,Опелајка,Опеліка,أوبيليكا,ئۆپێلیکا، ئەلاباما,اوپلیکا، آلاباما,ओपेलाइका,ओपेलिका,欧佩莱卡', 32.6454100, -85.3782800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130974, 'Oneonta', 'Oneonta', 'Oneonta,Oneonto,Onionta,ao ni ang ta,awnywnta,awnyywnta  alabama,oniyonta,Онеонта,Онионта,أونيونتا,ئۆنیۆنتا، ئەلاباما,اونیئونتا، آلاباما,ओनियोन्टा,奥尼昂塔', 33.9481500, -86.4727600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130975, 'Opp', 'Opp', 'Hallton,Op,Opp,Oupp,ao pu,ap  alabama,awb,oppa,Оп,Оупп,آپ، آلاباما,أوب,ئۆپ، ئەلاباما,ओप्प,奥普', 31.2826700, -86.2555100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130976, 'Orange Beach', 'Orange Beach', '', 30.2943700, -87.5735900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130977, 'Owens Cross Roads', 'Owens Cross Roads', 'Owens Cross Roads,Owens Crossroad,Owens Crossroads', 34.5881500, -86.4588800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130978, 'Oxford', 'Oxford', 'Lick Skillet,Lickskillet,Oksford,Oxford,Snow Creek,Snows Creek,aksapharda,aksfwrd  alabama,awksfwrd,niu jin,ogseupeodeu,Оксфорд,آکسفرڈ، الاباما,آکسفورد، آلاباما,أوكسفورد,ئۆکسفۆرد، ئەلاباما,अक्सफर्ड,牛津,옥스퍼드', 33.6142700, -85.8349600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130979, 'Ozark', 'Ozark', 'Bullards,Merrick,Merricks,OZR,Ozark,Woodshop,ao suo ka,awzark,awzark  alabama,ojarka,Озарк,أوزارك,ئۆزارک، ئەلاباما,اوزارک، آلاباما,ओजार्क,奥索卡', 31.4590600, -85.6404900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130980, 'Pelham', 'Pelham', 'Pelam,Pelham,Shelby Courthouse,Shelbyville,blham,pei lei mu,pelahyama,plham  alabama,Пелам,بلهام,پلهام، آلاباما,پێلھەم، ئەلاباما,पेलह्याम,佩勒姆', 33.2856700, -86.8099900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130981, 'Pell City', 'Pell City', 'PLR,Pel Siti,Pell-Siti,byl syty,pei er cheng,pella siti,pl syty  alabama,Пел Сити,Пелл-Сіті,بيل سيتي,پل سیتی، آلاباما,پێل سیتی، ئەلاباما,पेल्ल सिटी,佩尔城', 33.5862100, -86.2860900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130982, 'Phenix City', 'Phenix City', 'Browneville,Brownville,Feniks-Siti,Finiks Siti,Knights Station,Lively,Phenix City,Phoenix,feng huang cheng,fnyks syty  alabama,fynyks syty,phiniksa siti,Фенікс-Сіті,Финикс Сити,فنیکس سیتی، آلاباما,فينيكس سيتي,فینیکس سیتی، ئەلاباما,फिनिक्स सिटी,凤凰城,鳳凰城', 32.4709800, -85.0007700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130983, 'Phil Campbell', 'Phil Campbell', 'Fil Kembel,Fil-Kempbell,fyl kambl,fyl kmpbl  alabama,phila kyampabela,Фил Кембел,Філ-Кемпбелл,فيل كامبل,فیل کمپبل، آلاباما,فیل کەمبل، ئەلاباما,फिल क्याम्पबेल,菲尔·坎贝尔', 34.3509300, -87.7064200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130984, 'Piedmont', 'Piedmont', 'Cross Plains,Cross Point,Gross Plains,Gross Point,Hollow Stump,Pedmont,Pidmont,Piedmont,Piedmont Station,bydmwnt,pa''idamanta,pi ai meng te,pymwnt  alabama,Пидмонт,Пєдмонт,بيدمونت,پیدمۆنت، ئەلاباما,پیمونت، آلاباما,पाइडमन्ट,皮埃蒙特', 33.9245500, -85.6113500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130985, 'Pike Road', 'Pike Road', 'Pike Road,Pikeroad', 32.2843100, -86.1030200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130986, 'Pine Level', 'Pine Level', '', 32.5837400, -86.4655300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130987, 'Pinson', 'Pinson', 'Hagoods Crossroads,Mount Pinson,Mount Pinson Station,Pinson,Wymond,bynswn,pan song,pinasana,pynsan  alabama,Пинсон,Пінсон,بينسون,پینسان، آلاباما,पिनसन,潘松', 33.6889900, -86.6833200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130988, 'Pleasant Grove', 'Pleasant Grove', 'Earle,Frog Pond,Pleasant Grove,Plezant Grouv,Plezent-Grov,blyznt ghrwf,plijenta grobha,plyznt grww  alabama,pu lai sen te ge luo fu,Плезант Гроув,Плезент-Ґров,بليزنت غروف,پلیزنت گروو، آلاباما,پلێزنت گرۆڤ، ئەلاباما,प्लिजेन्ट ग्रोभ,普莱森特格罗夫', 33.4909400, -86.9702700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130989, 'Point Clear', 'Point Clear', 'Big Point Clear,Point Clear,Pointclear', 30.4740800, -87.9191600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130990, 'Prattville', 'Prattville', 'Prattvill,Pratvil,bratfyl,prtwyl  alabama,pryatabhila,pu la te wei er,Пратвил,Праттвілл,براتفيل,پرتویل، آلاباما,پرەتڤیل، ئەلاباما,प्र्याटभिल,普拉特维尔', 32.4640200, -86.4597000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130991, 'Priceville', 'Priceville', '', 34.5250900, -86.8947300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130992, 'Prichard', 'Prichard', 'Prichard,Prichard Station,brytshard,pricarda,prychard  alabama,pu li cha de,Причард,Прічард,بريتشارد,پریچارد، آلاباما,پریچارد، ئەلاباما,प्रिचार्ड,普里查德', 30.7388000, -88.0788900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130993, 'Ragland', 'Ragland', 'Ragland,Trout Creek', 33.7445400, -86.1558100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130994, 'Rainbow City', 'Rainbow City', 'Coosa Bend,Kota Rainbow,Morgans Crossroads,Rainbow City,Rejnbou Siti,Rejnbov-Siti,cai hong shi,renbo siti,rynbw syty,rynbw syty  alabama,Рейнбов-Сіті,Рејнбоу Сити,رينبو سيتي,رینبو سیتی، آلاباما,ڕەینبۆ سیتی، ئەلاباما,रेन्बो सिटी,彩虹市', 33.9548200, -86.0419200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130995, 'Rainsville', 'Rainsville', 'Rejnsvil,Rejnsvill,rensabhila,rui si wei er,rynsfyl,rynzwyl  alabama,Рейнсвілл,Рејнсвил,رينسفيل,رینزویل، آلاباما,ڕەینسڤیل، ئەلاباما,रेन्सभिल,瑞斯维尔', 34.4942500, -85.8477500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130996, 'Red Bay', 'Red Bay', 'Red Bay,Red Bej,Red-Bej,Redbay,Vincents Cross Roads,Vincents Crossroads,hong wan,ray bay,reda be,Ред Беј,Ред-Бей,راي باي,रेड बे,红湾', 34.4398200, -88.1408700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130997, 'Reform', 'Reform', 'Reform,ripharma,rui fu er mu,ryfwrm,ryfwrm  alabama,Реформ,ريفورم,ریفورم، آلاباما,ڕیفۆرم، ئەلاباما,रिफर्म,瑞富尔姆', 33.3784500, -88.0153000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130998, 'Rehobeth', 'Rehobeth', '', 31.1229600, -85.4527100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(130999, 'Riverside', 'Riverside', 'Readman,Riversajd,Riverside,Риверсайд', 33.6062100, -86.2044200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131000, 'Roanoke', 'Roanoke', 'Chulafinnee,High Pine,Roanok,Roanoke,Roanouk,lo-eonokeu,luo a nuo ke,royanoka,rwanwk  alabama,rwnwk,Роанок,Роаноук,روآنوک، آلاباما,رونوك,ڕوانۆک، ئەلاباما,रोयानोक,罗阿诺克,로어노크', 33.1512300, -85.3721700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131001, 'Robertsdale', 'Robertsdale', 'Robertsdale,Robertsdejl,Silver Hill,luo bo ci dai er,robartsadela,rwbrtsdyl,Робертсдейл,Робертсдејл,روبرتسديل,रोबर्ट्सडेल,罗伯茨代尔', 30.5538000, -87.7119300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131002, 'Rock Creek', 'Rock Creek', '', 33.4770500, -87.0802700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131003, 'Rockford', 'Rockford', 'Pondalassa,Pondelassa,Rockford', 32.8895700, -86.2196900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131004, 'Rogersville', 'Rogersville', 'Rodgersville,Rogers Ville,Rogersville', 34.8257800, -87.2967600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131005, 'Russellville', 'Russellville', 'Raselvil,Rassellvill,Ruselvil,la sai er wei er,leoselbil,raselabhila,raslfyl,raslwyl  alabama,Раселвил,Расселлвілл,Ръселвил,راسلفيل,راسلویل، آلاباما,ڕەسلڤیل، ئەلاباما,रसेलभिल,拉塞尔维尔,러셀빌', 34.5078700, -87.7286400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131006, 'Saks', 'Saks', '', 33.6987100, -85.8396900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131007, 'Samson', 'Samson', 'Sampson,Samson,sa mu sen,samswn,samswn  alabama,syamasana,Самсон,سامسون,سامسون، آلاباما,سامسۆن، ئەلاباما,स्यामसन,萨姆森', 31.1129500, -86.0460500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131008, 'Saraland', 'Saraland', 'Alvarez Station,Cleveland,Cleveland Station,Saraland,Saralend,sa la lan,saraland,saralyanda,Сараланд,Сараленд,سارالاند,साराल्यान्ड,萨拉兰', 30.8207400, -88.0705600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131009, 'Sardis City', 'Sardis City', 'Sardis City,Sardis Crossroads', 34.1742600, -86.1227500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131010, 'Satsuma', 'Satsuma', 'Sacuma,Satsuma,sa mo,satsuma,satswma,Сатсума,Сацума,ساتسوما,सात्सुमा,萨摩', 30.8532400, -88.0561100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131011, 'Scottsboro', 'Scottsboro', 'Sage Town,Scotts Mill,Scottsboro,Scottsborough,Scottsville,Skotsboro,Skottsboro,askatsbra  alabama,si ke ci bo luo,skatasbaro,skwtsbwrw,Скотсборо,Скоттсборо,اسکاتسبرا، آلاباما,سكوتسبورو,سکۆتسبۆرۆ، ئەلاباما,स्कटस्बरो,斯科茨博罗', 34.6723100, -86.0341500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131012, 'Selma', 'Selma', 'Ecor de Bienville,High Soapstone Bluff,Moores Bluff,Piachee,Piachi,SEM,SES,Sel''ma,Selma,sai er ma,selma,seruma,slma,slma  alabama,Селма,Сельма,سلما,سلما، آلاباما,سێلما، ئەلاباما,सेल्मा,セルマ,塞尔玛,셀마', 32.4073600, -87.0211000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131013, 'Semmes', 'Semmes', '', 30.7782400, -88.2591700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131014, 'Sheffield', 'Sheffield', 'Sheffield,Sheffild,Shefild,York Bluff,sephaphilda,shfyld,shfyld  alabama,xie fei er de,Шефилд,Шеффилд,Шеффілд,شفيلد,شفیلد، آلاباما,شێفیلد، ئەلاباما,शेफफिल्ड,谢菲尔德', 34.7650900, -87.6986400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131015, 'Shelby', 'Shelby', '', 33.1104000, -86.5841500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131016, 'Slocomb', 'Slocomb', '', 31.1082300, -85.5943800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131017, 'Smiths Station', 'Smiths Station', 'Smiths', 32.5401400, -85.0985500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131018, 'Smoke Rise', 'Smoke Rise', '', 33.8917700, -86.8202700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131019, 'Southside', 'Southside', 'Smoke Neck,Southside', 33.9245400, -86.0224700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131020, 'Spanish Fort', 'Spanish Fort', 'Spanish Fort,Spejnish-Fort,aspnysh fwrt  alabama,sbanysh fwrt,spyanisa pharta,xi ban ya bao,Спаниш Форт,Спейніш-Форт,اسپنیش فورت، آلاباما,سبانيش فورت,سپەنیش فۆرت، ئەلاباما,स्प्यानिश फर्ट,西班牙堡', 30.6749100, -87.9152700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131021, 'Springville', 'Springville', 'Big Springs,Springville', 33.7750500, -86.4719100, 'US', '2017-05-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131022, 'Steele', 'Steele', 'Steele,Steeles Depot,Steels Depot,Steels Station', 33.9398200, -86.2016400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131023, 'Stevenson', 'Stevenson', 'Stivenson,astywnsn  alabama,shi di wen sen,stebhenasana,styfnswn,Стивенсон,Стівенсон,استیونسن، آلاباما,ستيفنسون,ستیڤنسن، ئەلاباما,स्टेभेनसन,史蒂文森', 34.8686900, -85.8394200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131024, 'Stewartville', 'Stewartville', 'Stewartsville,Stewartville', 33.0792900, -86.2444200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131025, 'Sulligent', 'Sulligent', 'Cansler,Moscow,Sulligent', 33.9017700, -88.1344800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131026, 'Sumiton', 'Sumiton', 'Democrat,Samiton,Sumiton,sa mi dun,samytwn,sumitana,Самитон,Самітон,ساميتون,सुमिटन,萨米顿', 33.7556600, -87.0500000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131027, 'Summerdale', 'Summerdale', 'Samerdejl,Sammerdejl,Sonora,Summerdale,sai men dai er,samaradela,samrdyl,samrdyl  alabama,Самердејл,Саммердейл,سامرديل,سامردیل، آلاباما,سامەردەیل، ئەلاباما,समरडेल,赛门戴尔', 30.4877000, -87.6997100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131028, 'Sylacauga', 'Sylacauga', 'Chalakagay,Clevelands Store,Cuillicoga,Cyllacogga,Marble City,Scille Coggy,Silakoga,Sillacogga,Suellocauga,Suillacouge,Suyllecogga,Sylacauga,Sylacogga,Syllacauga,Syllacogy,shirakoga,silakauga,silleokoga,sylakawgha,sylakwga  alabama,xi la ke jia,Силакога,Силакоґа,سيلاكاوغا,سیلاکوگا، آلاباما,سیلاکۆگا، ئەلاباما,सीलाकौगा,シラコーガ,锡拉科加,실러코가', 33.1731700, -86.2516400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131029, 'Sylvan Springs', 'Sylvan Springs', '', 33.5156600, -87.0149900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131030, 'Sylvania', 'Sylvania', 'Silvejnija,Silvenija,silbhyaniya,sylfanya,sylwynya  alabama,xi er wei ni ya,Силвејнија,Сілвенія,سيلفانيا,سیلوینیا، آلاباما,سیلڤەینیا، ئەلاباما,सील्भ्यानिया,西尔韦尼亚', 34.5623100, -85.8124700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131031, 'Talladega', 'Talladega', 'ASN,Bride of the Mountain,Highland City,Taladega,Taladiga,Talatekah,Talladega,Talladegee,Talladiga,Talladigger,Teledega,Telladega,Tulladega,ta la di jia,taelleodiga,taladega,taladiga,taladygha,Таладига,Талладіґа,تالاديغا,टालाडेगा,ടാലദീഗ,塔拉迪加,탤러디가', 33.4359400, -86.1058000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131032, 'Tallassee', 'Tallassee', 'Talasi,Talasse,Tallasee,Tallassee,Tallassi,Tallesee,ta la xi,talasi,talasy,Таласи,Таллассі,تالاسي,टालासी,塔拉西', 32.5359700, -85.8932900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131033, 'Tarrant', 'Tarrant', 'Tarant,Tarrant,Tarrant City,Tarrent,ta lan te,tarant  alabama,tarnt,tarryanta,Тарант,Таррент,تارانت، آلاباما,تارنت,टर्र्यान्ट,塔兰特', 33.5834400, -86.7727700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131034, 'Taylor', 'Taylor', 'Tejlor,Тейлор', 31.1649000, -85.4682700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131035, 'Taylor', 'Taylor', '', 31.9754300, -86.2333000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131036, 'Theodore', 'Theodore', 'Fowl River Station,Theodore', 30.5476900, -88.1752800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131037, 'Thomasville', 'Thomasville', 'Choctaw,Thomasville,Tomasvil,Tomasvill,thomasabhila,tomasubiru,tomeoseubil,tuo ma si wei er,twmasfyl,twmaswyl  alabama,Томасвил,Томасвілл,توماسفيل,توماسویل، آلاباما,थोमसभिल,トーマスビル,托马斯维尔,토머스빌', 31.9134900, -87.7358400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131038, 'Thorsby', 'Thorsby', 'Strasburg,Strasburgh,Thorsby', 32.9156800, -86.7158200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131039, 'Tillmans Corner', 'Tillmans Corner', 'Three Notches,Tillmans Corner', 30.5901900, -88.1708400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131040, 'Town Creek', 'Town Creek', 'Jonesboro,Jonesborough,Town Creek,Towncreek', 34.6812000, -87.4061300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131041, 'Trinity', 'Trinity', 'Fennels Turnout,Triniti,Trinity,Trinity Station,te rui ne te,triniti,trynyty,trynyty  alabama,Тринити,Триніті,ترينيتي,ترینیتی، آلاباما,ट्रिनिटी,特瑞呢特', 34.6067600, -87.0883500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131042, 'Troy', 'Troy', 'Centerville,Centreville,Deer Stand Hill,TOI,Troj,Troja,Troy,Zebulon,te luo yi,teuloi,tro''i,trwy,trwy  alabama,Трой,Троя,Трој,تروي,تروی، آلاباما,ٹرائے، الاباما,ट्रोइ,特洛伊,트로이', 31.8087700, -85.9699500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131043, 'Trussville', 'Trussville', 'Trassvill,Trasvil,Truss,Trussville,te lu si wei er,trasabhila,traswyl  alabama,trwsfyl,Трасвил,Трассвілл,تراسویل، آلاباما,تروسفيل,ट्रसभिल,特鲁斯维尔', 33.6198300, -86.6088800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131044, 'Tuscaloosa', 'Tuscaloosa', 'Black Warrior Town,Druid City,Louiseville,Matildaville,Shelbyville,Shelleyville,Shelltown,Shellytown,TCL,Taskalusa,Tuscaloosa,Tuskalloosa,Tuskaloosa,ta si ka lu sa,taskalusa,taskalwsa  alabama,tasukarusa,teoseukeollusa,tsqlwsh,twskalwsa,Таскалуса,טסקלוסה,تاسکالوسا، آلاباما,توسكالوسا,टस्कालूसा,ടസ്കലൂസ,タスカルーサ,塔斯卡卢萨,터스컬루사', 33.2098400, -87.5691700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131045, 'Tuscumbia', 'Tuscumbia', 'Big Spring,Cold Water,Deshlar Cross Roads,Ococoposa,Ococoposo,Ocoposa,Oka Kapassa,Taskambi,Taskambija,Tuscumbia,Tuskumbija,ta si kan bi ya,taskambiya,taskambya  alabama,tasukanbia,twskwmbya,Таскамби,Таскамбия,Таскамбија,Таскамбія,Тъскъмбия,تاسکامبیا، آلاباما,توسكومبيا,तस्कम्बिया,タスカンビア,塔斯坎比亚', 34.7312000, -87.7025300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131046, 'Tuskegee', 'Tuskegee', 'TGE,Taskigi,Tuskegee,Tuskidzhi,ta si ji ji,taskeji,taskygy,tasukigi,teoseukigi,tsqygy,twskyjy,Таскиги,Таскігі,Тъскиджи,טסקיגי,تاسکیگی,توسكيجي,टस्केजी,タスキーギ,塔斯基吉,터스키기', 32.4241500, -85.6909600, 'US', '2017-04-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131047, 'Union Springs', 'Union Springs', 'Junion Springs,Junion-Springs,lian meng quan,yuniyana springas,ywnyn sprngz  alabama,ywnywn aspryngz  alabama,ywnywn sbrynghz,Јунион Спрингс,Юніон-Спрингс,يونيون سبرينغز,یونین سپرنگز، الاباما,یونیون اسپرینگز، آلاباما,युनियन स्प्रिङ्गस्,联盟泉', 32.1443200, -85.7149500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131048, 'Uniontown', 'Uniontown', 'Juniontaun,Uniontown,Woodville,you ning dui,yuniyanata''una,ywnywntawn,ywnywntawn  alabama,Јунионтаун,Юніонтаун,يونيونتاون,یونین ٹاؤن، الاباما,یونیونتاون، آلاباما,युनियनटाउन,尤宁敦', 32.4495800, -87.5141700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131049, 'Valley', 'Valley', 'Fairfax,Langdale,River View,Shawmut,Vali,Valley,Velli,bhyali,faly,shan gu,wly  alabama,wyly  alabama,Вали,Веллі,فالي,ولی، آلاباما,ویلی، الاباما,भ्याली,山谷', 32.8187400, -85.1793900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131050, 'Valley Grande', 'Valley Grande', 'Valegrande,Valley Grande', 32.5090200, -86.9874900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131051, 'Vandiver', 'Vandiver', '', 33.4706600, -86.5133200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131052, 'Vance', 'Vance', 'Smallwood,Smallwood Station,Trion,Tryon,Vance,Vance Station,Vances Station', 33.1742800, -87.2336100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131053, 'Vernon', 'Vernon', 'Swayne Courthouse,Vernon,bharnona,fu nong,fyrnwn,wrnwn  alabama,Вернон,فيرنون,ورنون، آلاباما,भर्नोन,弗农', 33.7570500, -88.1089200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131054, 'Vestavia Hills', 'Vestavia Hills', 'Vestavia,Vestavia Hills', 33.4487200, -86.7877700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131055, 'Vincent', 'Vincent', 'Propel,Propell,Vincent', 33.3845500, -86.4119200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131056, 'Warrior', 'Warrior', 'Varrier,Vorior,Warrior,Warrior Station,variyara,waryr  alabama,wo li er,wwrywr,Варріер,Вориор,واریر، آلاباما,ووريور,वारियर,沃里尔', 33.8142700, -86.8094400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131057, 'Weaver', 'Weaver', 'Viver,Weaver,Weavers,Weavers Station,vibhara,wei fu wei er,wyfr,wywr  alabama,Вивер,Вівер,ويفر,ویور، آلاباما,वीभर,威弗维尔', 33.7520500, -85.8113500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131058, 'Webb', 'Webb', 'Veb,Vebb,veba,wb  alabama,wei bo,wyb,Веб,Вебб,وب، آلاباما,ويب,वेब,韦伯', 31.2604500, -85.2732700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131059, 'Wedowee', 'Wedowee', 'McDonald,Vedaui,Vedovi,Wedowee,vedovi,wdwwy  alabama,wei dao yi,wydwwy,Ведауи,Ведові,ودووی، آلاباما,ويدووي,वेडोवी,韦道伊', 33.3090000, -85.4846700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131060, 'West Blocton', 'West Blocton', 'Blockton,Blocton,Suttleton,Suttletown,West Blocton', 33.1181700, -87.1250000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131061, 'Westover', 'Westover', '', 33.3495500, -86.5358200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131062, 'Wetumpka', 'Wetumpka', 'Ouitumkis,Vetampka,Wetumka,Wetumkee,Wetumpka,Whittumke,Witumpka,vetumka,wei tun ka,wtampka  alabama,wytwmbka,Ветампка,وتامپکا، آلاباما,ويتومبكا,वेटुम्का,威屯卡', 32.5437400, -86.2119100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131063, 'Whitesboro', 'Whitesboro', '', 34.1634300, -86.0694200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131064, 'Wilsonville', 'Wilsonville', '', 33.2342800, -86.4835900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131065, 'Winfield', 'Winfield', 'Luxapallila,Needmore,Vinfild,Winfield,vinaphilda,wen fei er de,wynfyld,wynfyld  alabama,Винфилд,Вінфілд,وينفيلد,وینفیلد، آلاباما,विनफिल्ड,温菲尔德', 33.9289900, -87.8172500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131066, 'Woodstock', 'Woodstock', '', 33.2067800, -87.1500000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131067, 'York', 'York', 'Jork,York,York Station,Йорк', 32.4862500, -88.2964200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131068, 'Alexander', 'Alexander', '', 34.6295400, -92.4412700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131069, 'Alma', 'Alma', 'Al''ma,Alma,Gum Town,alma,alma  arknsas,Алма,Альма,آلما,ألما,الما، آرکنساس,अल्मा', 35.4778700, -94.2218800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131070, 'Arkadelphia', 'Arkadelphia', 'Arcadelphia,Archadelphia,Arkadelfija,Arkadelphia,a ka de er fei ya,arkadelphiya,arkadlpya,arkdlfya,Аркаделфија,آرکادلپیا,أركدلفيا,आर्कादेल्फिया,阿卡德尔菲亚', 34.1209300, -93.0537800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131071, 'Arkansas City', 'Arkansas City', 'Arkansas City,Arkanzas Siti,Arkanzas-Siti,Campbells Landing,arkansah siti,Арканзас Сити,Арканзас-Сити,Арканзас-Сіті,आर्कान्सः सिटी', 33.6087200, -91.2067800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131072, 'Ash Flat', 'Ash Flat', 'Ash Flat,Ashflat', 36.2239600, -91.6084800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131073, 'Ashdown', 'Ashdown', 'Ashdown,Eshdaun,Keller,ashdawn,ashdwn,esda''una,Ешдаун,أشدون,اشداون,एश्डाउन', 33.6742900, -94.1313100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131074, 'Atkins', 'Atkins', '', 35.2464700, -92.9365600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131075, 'Augusta', 'Augusta', 'Augusta,Chickasaw Crossing,Chickasaw Landing,Ogasta,agasta,agwsta,awghwsta,Огаста,آگسٹا، آرکنساس,آگوستا,أوغوستا,अगस्ता', 35.2823100, -91.3654100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131076, 'Austin', 'Austin', 'Ostin,Остин', 34.9984200, -91.9837600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131077, 'Bald Knob', 'Bald Knob', 'Bald Knob,Baldknob,Bold Nob,Bold-Nob,bald nwb,balda noba,bldnwb,borudonobu,Болд Ноб,Болд-Ноб,بالد نوب,بلدنوب,बाल्ड नोब,ボールドノブ', 35.3098100, -91.5679100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131078, 'Barling', 'Barling', 'Barling,baralinga,barlyng,barlyngh,Барлинг,Барлінг,بارلينغ,بارلینگ,बारलिङ्ग', 35.3256500, -94.3016000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131079, 'Batesville', 'Batesville', 'BVX,Batesville,Batsvil'',Bejtsvil,Bejtsvill,Big Bottom,Greenbriar,Napoleon,Oil Trough Bottom,Poke Bayou,betsabhila,btswyl,bytsfyl,Батсвіль,Бейтсвилл,Бејтсвил,بتسویل,بيتسفيل,बेट्सभिल', 35.7698000, -91.6409700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131080, 'Bay', 'Bay', 'Bay,Big Bay,Big Bay Siding Station', 35.7423000, -90.5623300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131081, 'Beebe', 'Beebe', 'Beebe,Beebe Station,Bibi,bibe,byby,bybyh,Биби,بيبي,بیبیه,बीबे', 35.0706400, -91.8795900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131082, 'Bella Vista', 'Bella Vista', 'Bela Vista,Bella Vista,Bella Vista Village,Bella-Vista,bella bhista,bellabiseuta,blawysta,byla fysta,Бела Виста,Белла-Виста,Белла-Віста,بلاویستا,بيلا فيستا,بیلا وسٹا، آرکنساس,बेल्ला भिस्ता,벨라비스타', 36.4807000, -94.2713400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131083, 'Benton', 'Benton', 'Benton,benatana,benteon,bntwn,Бентон,بنتون,بینٹن، آرکنساس,बेनटन,벤턴', 34.5645400, -92.5868300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131084, 'Bentonville', 'Bentonville', 'Bentonvil,Bentonvil'',Bentonvill,Bentonville,Osage,ben dun wei,benatanabhila,bentanavhila,benteonbil,bentonbiru,bntwn wyl,bntwnfyl,Бентонвил,Бентонвилл,Бентонвилле,Бентонвіль,بنتون ویل,بنتونفيل,بینٹنویل، آرکنساس,बेनटनभिल,बेन्टनव्हिल,ベントンビル,本頓維,벤턴빌', 36.3728500, -94.2088200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131085, 'Berryville', 'Berryville', 'Berivil,Berrivil'',Berrivill,beribhila,bryfyl,brywyly,Беривил,Берривилл,Беррівіль,بريفيل,بریویلی,बेरीभिल', 36.3647900, -93.5679700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131086, 'Bethel Heights', 'Bethel Heights', '', 36.2142400, -94.1293700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131087, 'Blytheville', 'Blytheville', 'BYH,Blajtvil,Blajtvil'',Blajtvill,Blytheville,blayt wyl,bleithabhila,blythfyl,Блайтвилл,Блайтвіль,Блајтвил,بلایت ویل,بليثفيل,ब्लेीथभिल', 35.9273000, -89.9189800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131088, 'Bono', 'Bono', 'Bonnerville,Bono', 35.9086800, -90.8026200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131089, 'Booneville', 'Booneville', 'Bunvil,Bunvil'',Bunvill,bunabhila,bwnfyl,bwnwyl,Бунвил,Бунвилл,Бунвіль,بونفيل,بونویل,बूनभिल', 35.1400900, -93.9215900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131090, 'Brinkley', 'Brinkley', 'Brinkley,Brinkli,Lick Skillet,brinkle,brnkly,brynkly,Бринкли,برنکلی,برينكلي,ब्रिंक्ले', 34.8878700, -91.1945700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131091, 'Brookland', 'Brookland', 'Brookland,Brookvale', 35.9000700, -90.5820500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131092, 'Bryant', 'Bryant', '', 34.5959300, -92.4890500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131093, 'Bull Shoals', 'Bull Shoals', 'Bull Shoals,Newton Flat', 36.3839600, -92.5815500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131094, 'Cabot', 'Cabot', 'Kabot,kabwt,kyabota,Кабот,كابوت,کابوت,کابوٹ، آرکنساس,क्याबोत', 34.9745300, -92.0165300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131095, 'Calico Rock', 'Calico Rock', 'Calico Rock,Calicorock,Kaliko Rok,Kaliko-Rok,kalykw rak,kalykw rwk,kyaliko raka,Калико Рок,Калико-Рок,Каліко-Рок,كاليكو روك,کالیکو راک,क्यालिको रक', 36.1195100, -92.1359900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131096, 'Camden', 'Camden', 'CDH,Camden,Choteau de Fabri,Corea Fabre,Ecor a Fabri,Ecore Fabre,Ecore a Fabre,Fabres Bluff,Fabres Landing,Fabris Bluff,Fabrys Bluff,Kamden,L''Ecore a Fabri,LaCore Fabre,kaemdeon,kamdn,kyamdena,Камден,كامدن,کامدن,کیمڈن، آرکنساس,क्याम्डेन,캠던', 33.5845600, -92.8343300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131097, 'Caraway', 'Caraway', '', 35.7581300, -90.3223200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131098, 'Carlisle', 'Carlisle', 'Karlajl,karlayl  arknsas,karlaysl,karlijle,karlystlh,Карлайл,Карлајл,كارلايسل,کارلائل، آرکنساس,کارلیستله,कार्लिज्ले', 34.7831500, -91.7465200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131099, 'Cave City', 'Cave City', 'Cave City,Loyal', 35.9417400, -91.5484700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131100, 'Cave Springs', 'Cave Springs', 'Allen Mill,Cave Spring,Cave Spring Mill,Cave Springs', 36.2634100, -94.2318700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131101, 'Cedarville', 'Cedarville', 'Cedarville,Spencers Shop', 35.5698100, -94.3668800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131102, 'Centerton', 'Centerton', 'Centerpoint,Centerton', 36.3598000, -94.2852100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131103, 'Charleston', 'Charleston', 'Charl''ston,Charles Towne,Charleston,Charlestown,Charlston,carlsatana,charlztwn,tsharlstwn,Чарлстон,Чарльстон,تشارلستون,چارلزتون,چارلسٹن، آرکنساس,चार्ल्सटन', 35.2970400, -94.0363200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131104, 'Cherokee Village', 'Cherokee Village', 'Cherokee Village,Cherokee Village West', 36.2978400, -91.5159700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131105, 'Clarendon', 'Clarendon', 'Clarendon,Klarendon,Mouth of Cache,Mouth of the Cache,Rockroe,Roe Rock,klarndwn,klyarendana,Кларендон,كلارندون,کلارندون,क्ल्यारेन्डन', 34.6931500, -91.3137400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131106, 'Clarksville', 'Clarksville', 'Clarksville,Johnson Courthouse,Klarksvil,Klarksvil'',Klarksvill,klarkasbhila,klarksfyl,klarkswyl,klarkswyl  arknsas,Кларксвил,Кларксвилл,Кларксвіль,كلاركسفيل,کلارکسویل,کلارکسویل، آرکنساس,क्लार्कस्भिल', 35.4714700, -93.4665700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131107, 'Clinton', 'Clinton', 'Klinton,klintana,klyntwn,Клинтон,Клінтон,كلينتون,کلنٹن، آرکنساس,کلینتون,क्लिन्टन', 35.5914700, -92.4604400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131108, 'Coal Hill', 'Coal Hill', 'Coal Hill,Coalhill', 35.4373100, -93.6729700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131109, 'Conway', 'Conway', 'Conway,Conway Station,Konuehj,Konvej,kanve,kanwy,kon-wei,kwnwy,Конвей,Конвеј,Конуэй,كونوي,کانوی,کونوے، آرکنساس,कन्वे,콘웨이', 35.0887000, -92.4421000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131110, 'Corning', 'Corning', 'Carpenters Station,Corning,Hecht City,Korning,karninga,ke ning,kwrnyng,kwrnyngh,Корнинг,كورنينغ,کورنینگ,कर्निंग,科宁', 36.4078400, -90.5798300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131111, 'Crossett', 'Crossett', 'CRT,Krosent,Krossett,kraseta,krast,krwsyt,Кросент,Кроссетт,كروسيت,کراست,क्रसेट', 33.1281800, -91.9612400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131112, 'Danville', 'Danville', 'Danvil,Danvil'',Danvill,Danville,Monrovia,danfyl,dnwyl,dyanabhila,Данвил,Данвилл,Данвіль,دانفيل,دنویل,ड्यानभिल', 35.0539800, -93.3935200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131113, 'Dardanelle', 'Dardanelle', 'Council Oaks,Dandenai,Darbinel,Dardanel'',Dardanell,Dardanelle,Dardi,Dardonnie,Derdonnai,Dosduail,da da ni er,dardyanela,drdanl,drdnyl,Дарбинел,Дарданелл,Дарданель,دردانل,دردنيل,दार्द्यानेल,达达尼尔', 35.2231400, -93.1579500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131114, 'De Queen', 'De Queen', 'Calamity,De Kvin,De Queen,De-Kuin,de kvina,dy kwyn,dy kwyyn,Де Квин,Де-Куин,Де-Куін,دي كوين,دی کویین,डे क्वीन', 34.0378900, -94.3413200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131115, 'De Witt', 'De Witt', 'De-Uitt,De-Vitt,DeWitt,Devit,de vita,dwyt,dy wyt,Де-Вітт,Де-Уитт,Девит,دویت,دي ويت,डे विट', 34.2928800, -91.3379000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131116, 'Decatur', 'Decatur', 'Corner Springs,Decatur,Dekejter,Dekejtur,dekatara,di kai te,dkatr,dykatwr,Декейтер,Декејтур,ديكاتور,دکاتر,देकातर,迪凯特', 36.3359100, -94.4607700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131117, 'Dermott', 'Dermott', 'Dermot,Dermott,darmota,drmwt,dyrmwt,Дермот,Дермотт,درموت,ديرموت,डर्मोट', 33.5253900, -91.4359500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131118, 'Des Arc', 'Des Arc', 'Bayou d''Arc,De Ark,De-Ark,Des Arc,Des Argues,Desarc,Desarcs,des arka,ds ark,dys ark,Де Арк,Де-Арк,دس آرک,ديس أرك,देस् आर्क', 34.9770400, -91.4951300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131119, 'Diaz', 'Diaz', 'Diaz,Diez', 35.6384100, -91.2651300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131120, 'Dierks', 'Dierks', 'Dierks,Hardscrabble', 34.1192800, -94.0165800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131121, 'Dover', 'Dover', 'Dover,Logans Store,Довер', 35.4014700, -93.1143400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131122, 'Dumas', 'Dumas', 'Djuma,Dumas,dwmas,dyumasa,Думас,Дюма,دوماس,ड्युमास', 33.8870500, -91.4917900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131123, 'Earle', 'Earle', 'Earl,Earle,Ehrl,Erl,Erli,ayarl,ayrl,eyarle,Ерл,Ерли,Эрл,إيرل,ایارل,एयर्ले', 35.2750900, -90.4667700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131124, 'East End', 'East End', '', 34.5506500, -92.3409900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131125, 'El Dorado', 'El Dorado', 'ELD,Ehl''-Dorado,El Dorado,El Dorejdo,El''-Dorado,Eldorado,al dwradw,aldwradw,el doryado,Ел Дорејдо,Ель-Дорадо,Эль-Дорадо,إل دورادو,الدورادو,एल् डोर्याडो', 33.2076300, -92.6662700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131126, 'Elkins', 'Elkins', 'Elkins,Hood,Marshalls Prairie', 36.0014700, -94.0082500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131127, 'Elm Springs', 'Elm Springs', 'Elm Springs,Elmsprings', 36.2061900, -94.2343700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131128, 'England', 'England', 'England,Hurgens', 34.5442600, -91.9690300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131129, 'Eudora', 'Eudora', 'Eudora,Judora,adwra,yudora,ywdwra,Јудора,Еудора,Юдора,ادورا,يودورا,युडोरा', 33.1095700, -91.2620600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131130, 'Eureka Springs', 'Eureka Springs', 'Jurika Springs,arka aspryngz,yureka springsa,yurekasupuringusu,ywryka sbrynghz,Јурика Спрингс,ارکا اسپرینگز,يوريكا سبرينغز,युरेका स्प्रिंग्स,ユーレカスプリングス', 36.4011800, -93.7379700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131131, 'Fairfield Bay', 'Fairfield Bay', '', 35.5942400, -92.2779300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131132, 'Farmington', 'Farmington', 'Engels Mills,Farmington,farmnghtwn,farmyngtwn,pharmingatana,Фармингтон,Фармінгтон,فارمنغتون,فارمنگٹن، آرکنساس,فارمینگتون,फार्मिंगटन', 36.0420200, -94.2471500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131133, 'Fayetteville', 'Fayetteville', 'FYV,Faetvil'',Fayetteville,Fejetvil,Fejetvilis,Fejetvill,Washington Courthouse,faytfyl,fayt‌wyl,fei ye te wei er,feiettobiru,peiesbil,phayetabhila,phetavhila,Фаєтвіль,Фейетвилл,Фејетвил,פאייטוויל,فائیٹویل، آرکنساس,فايتفيل,فایت‌ویل,फायेटभिल,फेटव्हिल,フェイエットビル,费耶特维尔,페이엣빌', 36.0625800, -94.1574300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131134, 'Flippin', 'Flippin', 'FLP,Flippin,Flippin Barrens,Goatville', 36.2789600, -92.5971100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131135, 'Fordyce', 'Fordyce', 'Fordajs,fwrdays,fwrdys,phardisa,Фордайс,Фордајс,فوردایس,فورديس,फर्डिस', 33.8137200, -92.4129300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131136, 'Forrest City', 'Forrest City', 'FCY,Forest City,Forist Siti,Forrest,Forrest City,Forrest-Siti,farst syty,fwrst syty,pharesta siti,Форист Сити,Форрест-Сити,Форрест-Сіті,فارست سیتی,فورست سيتي,फरेस्ट सिटी', 35.0081500, -90.7898300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131137, 'Fort Smith', 'Fort Smith', 'Belle Point,FSM,Fort Smit,Fort Smith,Fort-Smit,fotosumisu,fwrt asmyt,fwrt smyth,pharta smitha,pwrt smyt,shi mi si bao,Форт Смит,Форт-Смит,פורט סמית,فورت اسمیت,فورت سميث,فورٹ سمتھ، آرکنساس,फर्ट स्मिथ,フォートスミス,史密斯堡', 35.3859200, -94.3985500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131138, 'Gassville', 'Gassville', 'Gassville,Mount Pleasant,Turkeys Neck', 36.2831200, -92.4940500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131139, 'Gentry', 'Gentry', 'Dzentri,Dzhentri,Gentry,Gentry City,Gentryville,Orchard,jentri,jntray,jyntry,Џентри,Джентри,Джентрі,جنترای,جينتري,जेन्ट्री', 36.2675800, -94.4846600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131140, 'Gibson', 'Gibson', 'Gibson,Runyan Acres', 34.8842600, -92.2357000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131141, 'Glenwood', 'Glenwood', 'Glenvud,Glenwood,Glinvud,Holly,ghlynwwd,glenavuda,glnwwd,Гленвуд,Глінвуд,غلينوود,گلنوود,ग्लेनवूड', 34.3267700, -93.5507400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131142, 'Gosnell', 'Gosnell', 'Gosnel,Gosnell,gasnela,ghwsnyl,gsnl,Госнел,Госнелл,غوسنيل,گسنل,गस्नेल', 35.9597900, -89.9720300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131143, 'Goshen', 'Goshen', 'Goshen,Гошен', 36.1011900, -93.9913100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131144, 'Gravel Ridge', 'Gravel Ridge', 'Gravel Hill,Gravel Ridge', 34.8684200, -92.1907000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131145, 'Gravette', 'Gravette', 'Gravet,Gravett,Gravette,Grejvet,Grejvett,La Gravette,ghrafyt,grabheta,grawt,Гравет,Грейвет,Грейветт,غرافيت,گراوت,ग्राभेट', 36.4220200, -94.4535500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131146, 'Green Forest', 'Green Forest', '', 36.3353500, -93.4360200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131147, 'Greenbrier', 'Greenbrier', 'Greenbrier,Grinbrajer,Grinbrir,Mooresville,Mooreville,ghrynbryr,grinabrayara,gryn braybr,Гринбрајер,Гринбрир,Грінбрір,غرينبرير,گرین برایبر,ग्रीनब्रायर', 35.2339700, -92.3876500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131148, 'Greenland', 'Greenland', 'Greenland,Greenland Station,Rugby,Staunton', 35.9942500, -94.1752000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131149, 'Greenwood', 'Greenwood', 'Grinvud,ghrynwwd,grinavuda,grynwwd,Гринвуд,Грінвуд,غرينوود,گرینوود,ग्रीनवूड', 35.2156500, -94.2557700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131150, 'Gurdon', 'Gurdon', 'Gardon,gardana,ge deng,ghwrdwn,gwrdwn,Гардон,غوردون,گوردون,गर्डन,格登', 33.9209400, -93.1540600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131151, 'Hamburg', 'Hamburg', 'Gamburg,Hamburg,Hamburgh,Khamberg,Khamburg,hambwrg,hambwrgh,hyamabarga,Гамбург,Хамберг,Хамбург,هامبورغ,هامبورگ,ह्यामबर्ग', 33.2281800, -91.7976300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131152, 'Hampton', 'Hampton', 'Gempton,Khehmpton,Khempton,hambtwn,han pu dun,hmptwn,hyamptana,Гемптон,Хемптон,Хэмптон,هامبتون,همپتون,ह्याम्प्टन,汉普顿', 33.5378900, -92.4698800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131153, 'Harrisburg', 'Harrisburg', 'Garrisberg,Harrisborough,Harrisburg,Harrisburgh,Kharisburg,harysbwrgh,hrysbwrg,hyarisabarga,Гаррисберг,Харисбург,هاريسبورغ,هریسبورگ,ہیرسبرک، آرکنساس,ह्यारिसबर्ग', 35.5642500, -90.7167800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131154, 'Harrison', 'Harrison', 'Crooked Creek,Garrison,HRO,Harrison,Kharison,Kharrison,haryswn,hryswn,hyarisana,Гаррисон,Гаррісон,Харисон,Харрисон,هاريسون,هریسون,ह्यारिसन', 36.2297900, -93.1076800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131155, 'Haskell', 'Haskell', '', 34.5014800, -92.6365500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131156, 'Hazen', 'Hazen', '', 34.7809300, -91.5809700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131157, 'Heber Springs', 'Heber Springs', 'Heber Springs,Khiber Springs,Khiber-Springs,Sugar Loaf,hbraspryngz,hibara springsa,hybyr sbrynghz,Хибер Спрингс,Хибер-Спрингс,Хібер-Спрінгс,هبراسپرینگز,هيبير سبرينغز,हिबर स्प्रिंग्स', 35.4914700, -92.0312600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131158, 'Helena', 'Helena', 'Helena,Khelena,Khelina,Monticello,Saint Francis,helena,Хелена,Хелина,हेलेना', 34.5295500, -90.5917700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131159, 'Highland', 'Highland', '', 36.2759000, -91.5240300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131160, 'Holiday Island', 'Holiday Island', '', 36.4853500, -93.7321400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131161, 'Hope', 'Hope', 'Khoup,hopa,hopeu,huo pu,hwb,hwp,Хоуп,هوب,هوپ,होप,霍普,호프', 33.6670600, -93.5915700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131162, 'Horatio', 'Horatio', 'Horatio,Rock Hill', 33.9384500, -94.3571500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131163, 'Horseshoe Bend', 'Horseshoe Bend', '', 36.2292300, -91.7643100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131164, 'Hot Springs', 'Hot Springs', 'HOT,Hot Springs,Hot Springs National Park,Khot-Springs,Man-a-tak-a,Valley of Vapors,Warm Springs,Хот-Спрингс', 34.5037000, -93.0551800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131165, 'Hot Springs Village', 'Hot Springs Village', '', 34.6720400, -92.9987900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131166, 'Hoxie', 'Hoxie', 'Khoksi,hoksi,hwksy,Хокси,هوكسي,هوکسی,होक्सि', 36.0503500, -90.9751200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131167, 'Hughes', 'Hughes', '', 34.9492600, -90.4714900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131168, 'Huntsville', 'Huntsville', 'Gantsvill,Huntsville,Khantsvil,Khantsvill,Sevierville,hantsbhila,hantsfyl,hantswyl,Гантсвілл,Хантсвил,Хантсвилл,هانتسفيل,هانتسویل,हन्ट्स्भिल', 36.0861900, -93.7413000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131169, 'Jacksonville', 'Jacksonville', 'Dzeksonvil,Dzhehksonvill,Dzheksonvil'',Dzheksonvill,jaegseunbil,jakswnfyl,jkkswnwyl  arknsas,jksnwyl,jyakasanabhila,Џексонвил,Джексонвилл,Джексонвіль,Джэксонвилл,جاكسونفيل,جکسنویل,جککسونویل، ارکنساس,ज्याकसनभिल,잭슨빌', 34.8662000, -92.1101500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131170, 'Jasper', 'Jasper', 'Dzasper,jasbr,jaspr,jspr  arknsas,jyaspara,Џаспер,جاسبر,جاسپر,جسپر، ارکنساس,ज्यास्पर', 36.0081300, -93.1865700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131171, 'Johnson', 'Johnson', 'Dzhonson,Dzonson,janasana,janswn  arkanzas,jwnswn,Џонсон,Джонсон,جانسون، آرکانزاس,جونسون,जनसन', 36.1328600, -94.1654800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131172, 'Jonesboro', 'Jonesboro', 'Dzhonsboro,Dzhounsburou,Dzounsboro,JBR,Jonesboro,Jonesborough,jonasbro,jonjeubeoleo,jonzuboro,jwnsbwrw  arknsas,jwnzbrw,jwnzbwrw,qiong si bo lei,Џоунсборо,Джонсборо,Джоунсбъроу,جونزبرو,جونزبورو,جونسبورو، آرکنساس,जोनस्ब्रो,ジョーンズボロ,琼斯伯勒,존즈버러', 35.8423000, -90.7042800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131173, 'Judsonia', 'Judsonia', 'Judsonia,Prospect Bluff', 35.2700900, -91.6398600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131174, 'Kensett', 'Kensett', 'Kennsett,Kensett', 35.2317500, -91.6676400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131175, 'Lake City', 'Lake City', 'Lake City,Old Town,Oldtown,Sunk Lands', 35.8161900, -90.4342700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131176, 'Lake Hamilton', 'Lake Hamilton', '', 34.4245300, -93.0951800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131177, 'Lake Village', 'Lake Village', 'Lejk Vilidz,Lejk-Villidzh,leka bhileja,lyk fylyj,lyk wlyj  arknsas,lyk wylyj,Лейк-Виллидж,Лейк-Віллідж,Лејк Вилиџ,ليك فيليج,لیک ولیج، ارکنساس,لیک ویلیج,लेक भिलेज', 33.3287300, -91.2817800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131178, 'Lamar', 'Lamar', 'Cabin Creek,Cabin Creek Station,Lamar', 35.4406400, -93.3879600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131179, 'Landmark', 'Landmark', 'Parkers-Iron Springs', 34.6112000, -92.3196000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131180, 'Lavaca', 'Lavaca', 'Lavaca,Military Grove,Oak Bower', 35.3362000, -94.1732600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131181, 'Leachville', 'Leachville', '', 35.9359100, -90.2578800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131182, 'Lepanto', 'Lepanto', 'Lepanto,Lepanto Station', 35.6111900, -90.3298200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131183, 'Lewisville', 'Lewisville', 'L''juisvil'',L''juisvill,Lafayette Court House,Lewisville,Luisvil,New Lewisville,livisabhila,lwysfyl,Луисвил,Льюисвилл,Льюїсвіль,لوئیس‌ویل,لويسفيل,लिविसभिल', 33.3584600, -93.5776800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131184, 'Lincoln', 'Lincoln', 'Black Jack,Georgetown,Lincoln,Linkol''n,Linkoln,linkana,lnkn  arknsas,lynkln  arkanzas,lynkwln,Линколн,Линкольн,Лінкольн,لنکن، آرکنساس,لينكولن,لینکلن، آرکانزاس,लिङ्कन', 35.9495300, -94.4235500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131185, 'Little Flock', 'Little Flock', '', 36.3859100, -94.1352000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131186, 'Little Rock', 'Little Rock', 'Acropolis,Anilco,Arkopolis,Gorad Litl-Rok,LIT,La Petit Roche,Litl Rok,Litl Rokas,Litl Roks,Litl-Rok,Litlroka,Little Rock,Littlerock,Litul Rok,Old Channel,Old Channel Little River,Petit Roche,Petit Rochelle,Petit Rocher,lie du luo bu,litala raka,litala roka,liteullog,litil rak,litila raka,littil rak,lytl rak  arkanzas,lytl rwk,lytl rwq,ritorurokku,xiao shi cheng,xiao yan cheng,Λιτλ Ροκ,Горад Літл-Рок,Литл Рок,Литл-Рок,Литъл Рок,Літл-Рок,Լիթլ Ռոք,ליטל ראק,ליטל רוק,ليتل روك,لٹل راک,لٹل راک، آرکنساس,لیتل راک، آرکانزاس,लिटल रॉक,लिटिल रक,लिटिल् राक्,लितल रक,லிட்டில் ராக்,ලිට්ල් රොක්,ლიტლ-როკი,リトルロック,列度洛埠,小岩城,小石城,리틀록', 34.7464800, -92.2895900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131187, 'London', 'London', 'Haddoxburg,London', 35.3289700, -93.2529600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131188, 'Lonoke', 'Lonoke', 'Hicks Station,Lone Oak,Lonok,Lonoke,lonoke,lwnkh,lwnwky,Лонок,لونوكي,لونکه,लोनोके', 34.7839800, -91.8998600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131189, 'Lowell', 'Lowell', 'Bloomington,Louehll,Louel,Lovel,Lowell,Mud Town,Mudtown,lovela,lwwl,lwyl,Ловел,Лоуел,Лоуэлл,لوول,لويل,लोवेल', 36.2553500, -94.1307600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131190, 'Luxora', 'Luxora', '', 35.7561900, -89.9281400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131191, 'Magnolia', 'Magnolia', 'AGO,Frog Level,Magnolia,Magnolija,maghnwlya,mgnwlya,myagnoliya,mygnwlya  arknsas,Магнолија,ماغنوليا,مگنولیا,میگنولیا، آرکنساس,म्याग्नोलिया', 33.2670700, -93.2393300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131192, 'Malvern', 'Malvern', 'Malvern,Malvern Junction,malfyrn,malwrn,myalbharna,Малверн,مالفيرن,مالورن,म्याल्भर्न', 34.3623100, -92.8129500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131193, 'Manila', 'Manila', 'Big Lake Island,Cinda,MXA,Manila,manila,manyla,Манила,Маніла,مانيلا,مانیلا,मनिला', 35.8800700, -90.1670400, 'US', '2017-06-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131194, 'Mansfield', 'Mansfield', 'Chocoville,Mansfield,Mansfield Station,Mehnsfild,Мэнсфилд', 35.0595400, -94.2527100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131195, 'Marianna', 'Marianna', 'Marianna,Marijana,maryana,meriyana,Марианна,Маријана,Маріанна,ماريانا,ماریانا,मेरियाना', 34.7737100, -90.7576100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131196, 'Marion', 'Marion', 'Marion,Marion City,Mehrion,marywn,marywn  arknsas,meriyana,Марион,Маріон,Мэрион,ماريون,ماریون,ماریون، آرکنساس,मेरियन', 35.2145300, -90.1964800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131197, 'Marked Tree', 'Marked Tree', 'Marked Tri,markd try,markda tri,Маркед Три,ماركد تري,مارکد تری,मार्क्ड ट्री', 35.5328600, -90.4206600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131198, 'Marmaduke', 'Marmaduke', '', 36.1870100, -90.3831600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131199, 'Marshall', 'Marshall', 'Burroughville,Burrowsville,Marshal,Marshall,Raccoon Springs,marsala,Маршал,Маршалл,मार्शल', 35.9089600, -92.6312700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131200, 'Marvell', 'Marvell', '', 34.5556600, -90.9128900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131201, 'Maumelle', 'Maumelle', 'maumela,mawmwly,mawmyl,ماومولی,ماوميل,मौमेल', 34.8667600, -92.4043200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131202, 'Mayflower', 'Mayflower', 'Mayflower,Twentymile Camp', 34.9570300, -92.4273800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131203, 'McAlmont', 'McAlmont', '', 34.8084200, -92.1818100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131204, 'McCrory', 'McCrory', '', 35.2562000, -91.2001200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131205, 'McGehee', 'McGehee', 'Makgi,Makgikhi,makghyhy,mikagehi,mk gy,Макги,Макгихи,Макгі,ماكغيهي,مک گی,मिकगेही', 33.6290000, -91.3995600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131206, 'Melbourne', 'Melbourne', 'Mel''burn,Melborn,Melbourne,Melburn,Mill Creek,melbarna,mlbwrn,mlbwrn  arknsas,Мелборн,Мелбурн,Мельбурн,ملبورن,ملبورن، آرکنساس,मेल्बर्न', 36.0595100, -91.9084800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131207, 'Mena', 'Mena', 'Mena,mena,mna,myna,Мена,منا,مينا,मेना', 34.5862200, -94.2396600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131208, 'Midway', 'Midway', '', 36.3853400, -92.4618300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131209, 'Mineral Springs', 'Mineral Springs', 'Greenville,Mineral Springs,Saline', 33.8751200, -93.9138000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131210, 'Monette', 'Monette', 'Monette,Stottsville', 35.8906300, -90.3442700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131211, 'Monticello', 'Monticello', 'Montisello,Montiselo,mantyslw,montiselo,mwntayslw,Монтиселло,Монтисело,Монтіселло,مانتیسلو,مونتايسلو,मोन्टिसेलो', 33.6290000, -91.7909600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131212, 'Morrilton', 'Morrilton', 'Lewisburg,MPJ,Morilton,Morrillton,Morrilton,morilatana,mwryltwn,Морилтон,Моррилтон,Моррілтон,موريلتون,موریلتون,मोरिलटन', 35.1509200, -92.7440500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131213, 'Mount Ida', 'Mount Ida', 'Maunt Ajda,Montgomery,Mount Ida,Salem,ma''unta ida,mant ayda,mawnt ayda,Маунт Ајда,مانت آیدا,ماونت إيدا,माउन्ट इडा', 34.5567600, -93.6340800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131214, 'Mountain View', 'Mountain View', 'Mauntin Vju,Mauntin-V''ju,Mauntin-Vju,Mountain View,Mountainview,ma''untena bhyu,mantyn wyw,mawntn fyw,Маунтин Вју,Маунтин-Вью,Маунтін-Вю,ماؤنٹین ویو، آرکنساس,مانتین ویو,ماونتن فيو,माउन्टेन भ्यू', 35.8684100, -92.1176500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131215, 'Mountain Home', 'Mountain Home', 'Mountain Home,Rapps Barren,Rapps Barrens,WMH', 36.3353400, -92.3851600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131216, 'Mulberry', 'Mulberry', 'Crittenden,Malberi,Malberri,Mulberry,malaberi,malbry,mwlbyry,Малбери,Малберри,Малберрі,مالبری,مولبيري,मलबेरी', 35.5006400, -94.0515900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131217, 'Murfreesboro', 'Murfreesboro', 'Merfrisboro,Murfreesboro,Murfreesborough,Murfrizboro,Zebulon,maraphrisbaro,mwrfrysbwrw,mwrfryzbwrw,Мерфрисборо,Мурфризборо,مورفريسبورو,مورفریزبورو,मरफ्रीस्बरो', 34.0623300, -93.6899000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131218, 'Nashville', 'Nashville', 'Hells Valley,Mine Creek,Nashvill,Nashville,Neshvil,n''yasabhila,nashfyl,nshwyl,nyshwyl  arknsas,Нашвилл,Нешвил,ناشفيل,نشویل,نیشویل، آرکنساس,न्याशभिल', 33.9456700, -93.8471300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131219, 'Newark', 'Newark', 'N''juark,New Ark,Newark,Njuark,n''yu''arka,niu hua ke,nwark,nywark,nywark  arknsas,Њуарк,Ньюарк,نوارک,نيوارك,نیوآرک، آرکنساس,न्युआर्क,紐華克', 35.7017400, -91.4415200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131220, 'Newport', 'Newport', 'N''juport,New Port,Newport,Njuport,n''yuporta,nywbwrt,nywpwrt,Њупорт,Ньюпорт,نيوبورت,نیوپورت,نیوپورٹ، آرکنساس,न्युपोर्ट', 35.6048000, -91.2818000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131221, 'North Crossett', 'North Crossett', '', 33.1656800, -91.9415200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131222, 'North Little Rock', 'North Little Rock', 'Argenta,Barling Cross,De Cantillion,De Cantillon,Huntersville,Hunterville,Nort Litl Rok,Nort-Litl-Rok,North Little Rock,nartha litala raka,noseuliteullog,nwrt lytl rak,nwrth lytl rwk,Норт Литл Рок,Норт-Литл-Рок,Норт-Літл-Рок,نارتھ لٹل راک، آرکنساس,نورت لیتل راک,نورث ليتل روك,नर्थ लिटल रक,노스리틀록', 34.7695400, -92.2670900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131223, 'Ola', 'Ola', 'Hightsville,Ola,Petit Jean,Petite Jean,Petitejean,awla,ola,Ола,أولا,اولا,ओला', 35.0323100, -93.2232300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131224, 'Osceola', 'Osceola', 'Osceola,Oseola,Osiola,Plant Point,awskywla,awsywla,os''siyola,Осеола,Осиола,Осцеола,أوسيولا,اوسکئولا,ओस्सियोला', 35.7050800, -89.9695300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131225, 'Ozark', 'Ozark', 'Ozark,awzark,azrk,ojarka,Озарк,آزرک,أوزارك,ओजार्क', 35.4870300, -93.8277000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131226, 'Paragould', 'Paragould', 'Center Hill,PGR,Paragould,Paraguld,Parmley,The Crossing,baraghwld,paragwld,pyaragolda,Парагулд,باراغولد,پاراگولد,پیراگولڈ، آرکنساس,प्यारागोल्ड', 36.0584000, -90.4973300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131227, 'Paris', 'Paris', 'Paris,Parizh,barys,parys,perisa,pyrs  arknsas,Париж,Парис,باريس,پاریس,پیرس، آرکنساس,पेरिस', 35.2920300, -93.7299200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131228, 'Parkin', 'Parkin', '', 35.2634200, -90.5712200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131229, 'Pea Ridge', 'Pea Ridge', '', 33.9206600, -91.3367900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131230, 'Pea Ridge', 'Pea Ridge', 'Pea Ridge,Pearidge,Strouds Store', 36.4539600, -94.1152000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131231, 'Perryville', 'Perryville', 'Perivil,byryfyl,peribhila,prywyl,Перивил,بيريفيل,پریویل,पेरीभिल', 35.0048100, -92.8026700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131232, 'Piggott', 'Piggott', 'Piggott,Pigot,Pigott,byghwt,piggata,pygat,Пигот,بيغوت,پیگات,पिग्गट', 36.3828400, -90.1906500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131233, 'Pine Bluff', 'Pine Bluff', 'Mount Maria,PBF,Pajn Blaf,Pine Bluff,bayn blaf,pa''ina blapha,painbeulleopeu,payn blaf  arkanzas,payn blf  arknsas,Пајн Блаф,باين بلاف,پائن بلف، آرکنساس,پاین بلاف، آرکانزاس,पाइन ब्लफ,파인블러프', 34.2284300, -92.0032000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131234, 'Piney', 'Piney', '', 34.5031400, -93.1260200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131235, 'Pocahontas', 'Pocahontas', 'Bettis Bluff,Betts Bluff,Pocahontas,Pokakhontas,bwkahwntas,pokyahontaja,pwkwhants,Покахонтас,بوكاهونتاس,پوکوهانتس,पोक्याहोन्ताज', 36.2614600, -90.9712300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131236, 'Pottsville', 'Pottsville', 'Galla Station,Potts Station,Pottsville', 35.2481400, -93.0490600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131237, 'Prairie Creek', 'Prairie Creek', '', 36.3420200, -94.0618700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131238, 'Prairie Grove', 'Prairie Grove', 'Prairie Grove,Prairiegrove,Prehjri-Grov,Prejri-Grov,Preri Grouv,bryry ghrwf,prayry grw,pre''irigrobha,Прейрі-Гров,Прери Гроув,Прэйри-Гров,بريري غروف,پرایری گرو,प्रेइरीग्रोभ', 35.9759100, -94.3177100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131239, 'Prescott', 'Prescott', 'Preskot,Preskott,bryskwt,preskata,prskat,Прескот,Прескотт,بريسكوت,پرسکات,प्रेस्कट', 33.8026100, -93.3810100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131240, 'Rector', 'Rector', '', 36.2631200, -90.2926000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131241, 'Redfield', 'Redfield', '', 34.4451000, -92.1832000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131242, 'Rison', 'Rison', '', 33.9584300, -92.1901500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131243, 'Rockwell', 'Rockwell', '', 34.4642600, -93.1337900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131244, 'Rogers', 'Rogers', 'ROG,Rodzers,Rodzhers,Rogers,lojeoseu,luo jie si,rajrz  arknsas,rojarsa,rwgrz,rwjrz,Роджерс,Роџерс,راجرز، آرکنساس,روجرز,روگرز,रोजर्स,罗杰斯,로저스', 36.3320200, -94.1185400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131245, 'Russellville', 'Russellville', 'Raselvil,leoselbil,raselabhila,raslfyl,raslwyl,rslwyl  arknsas,Раселвил,راسلفيل,راسلویل,رسلویل، آرکنساس,रसेलभिल,러셀빌', 35.2784200, -93.1337900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131246, 'Salem', 'Salem', 'Pilot Hill,Salem,Salem in Fulton County,Sejlem,salm,Сейлем,Сејлем,سالم,سیلم، فلٹن کاؤنٹی، آرکنساس', 36.3711800, -91.8226500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131247, 'Salem', 'Salem', '', 34.6289800, -92.5582200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131248, 'Searcy', 'Searcy', 'Frankford,SRC,Searcy,Sersi,seosi,sirsi,syrsy,Серси,Серсі,سيرسي,سیرسی,सीर्सी,서시', 35.2506400, -91.7362500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131249, 'Shannon Hills', 'Shannon Hills', '', 34.6200900, -92.3954300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131250, 'Sheridan', 'Sheridan', 'Sheridan,seridyana,shrydan,shyrydan,Шеридан,Шерідан,شریدان,شيريدان,शेरिड्यान', 34.3070400, -92.4012700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131251, 'Siloam Springs', 'Siloam Springs', 'Hico,SLG,Sajlom Springs,Sajlom-Springs,Siloam City,Siloam Springs,sayaloma springja,saylwm sbrynghz,silo''ama springas,sylwam aspryngz,Сайлом-Спрингс,Сайлом-Спрінгс,Сајлом Спрингс,سايلوم سبرينغز,سیلوام اسپرینگز,सायलोम स्प्रिंग्ज,सिलोआम स्प्रिङ्गस्', 36.1881400, -94.5405000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131252, 'Smackover', 'Smackover', '', 33.3648500, -92.7248800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131253, 'Southside', 'Southside', 'South Side,Southside', 35.6984100, -91.6234700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131254, 'Springdale', 'Springdale', 'SPZ,Shiloh,Springdale,Springdejl,Springdejl'',aspryngdyl  arkanzas,sbrynghdl,seupeulingdeil,springadela,supuringuderu,Спрингдейл,Спрингдејл,Спрінгдейль,اسپرینگدیل، آرکانزاس,سبرينغدل,سپرنگڈیل، آرکنساس,स्प्रिङ्गडेल,スプリングデール,스프링데일', 36.1867400, -94.1288100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131255, 'Stamps', 'Stamps', '', 33.3654000, -93.4951800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131256, 'Star City', 'Star City', 'Star City,Star Siti,Star Town,Star-Siti,Twinkle Town,astar syty,star syty,stara siti,Стар Сити,Стар-Сити,Стар-Сіті,استار سیتی,ستار سيتي,स्टार सिटी', 33.9428800, -91.8434700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131257, 'Stuttgart', 'Stuttgart', 'SGT,Statgart,Stuttgart,Stuttgart (Arkansas  USA),ashtwtgart,shtwtghart,stutagarta,Статгарт,اشتوتگارت,شتوتغارت,स्तुतगार्त', 34.5003700, -91.5526300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131258, 'Sulphur Springs', 'Sulphur Springs', 'Sulphur Springs,White Sulphur Springs', 34.1806500, -92.1234800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131259, 'Texarkana', 'Texarkana', 'Miller Court House,Teksarkana,Texarcana,Texarkana,tegsakaena,teksarkana,tekusakana,tksarkana,tyksarkana,Тексаркана,تيكساركانا,تکسارکانا,ٹیکسرکینا، آرکنساس,टेक्सार्काना,テクサーカナ,텍사캐나', 33.4417900, -94.0376900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131260, 'Tontitown', 'Tontitown', 'Tonitown,Tontitown', 36.1778600, -94.2335400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131261, 'Trumann', 'Trumann', 'Truman,Trumann,trumyana,trwman,trwmn,Труман,ترومان,ترومن,ट्रुम्यान', 35.6736900, -90.5073300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131262, 'Tuckerman', 'Tuckerman', '', 35.7306300, -91.1984600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131263, 'Van Buren', 'Van Buren', 'Phillips Landing,Van Bjuren,Van Buren,Van-B''juren,Van-Buren,Vanburen,bhyana burena,fan bywryn,vu~anbyuren,wn bwrn,Ван Бјурен,Ван-Бурен,Ван-Бьюрен,فان بيورين,ون بورن,भ्यान बुरेन,ヴァンビューレン', 35.4367600, -94.3482700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131264, 'Vilonia', 'Vilonia', 'Vilonia,Vilsonia', 35.0839800, -92.2079300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131265, 'Waldo', 'Waldo', '', 33.3515100, -93.2957300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131266, 'Waldron', 'Waldron', 'Ponton Valley,Potou Valley,Uoldron,Voldron,Waldron,Winfield,valadrona,waldrwn,Волдрон,Уолдрон,والدرون,वालड्रोन', 34.8984300, -94.0907600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131267, 'Walnut Ridge', 'Walnut Ridge', 'ARG,Volnat Ridz,Walnut Ridge,Walnutridge,valanata rija,Волнат Риџ,वालनट रीज', 36.0684000, -90.9559500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131268, 'Ward', 'Ward', '', 35.0303600, -91.9504200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131269, 'Warren', 'Warren', 'Pennington,Uorren,Varren,Voren,Warren,varena,warn,waryn,Варрен,Ворен,Уоррен,وارن,وارين,वारेन', 33.6126100, -92.0645800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131270, 'West Crossett', 'West Crossett', '', 33.1409600, -91.9940200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131271, 'West Fork', 'West Fork', 'Uehst-Fork,Vest Fork,Vest-Fork,West Fork,Westfork,Woolseys Store,vesta pharka,wst fwrk  arkanzas,wyst fwrk,Вест Форк,Вест-Форк,Уэст-Форк,وست فورک، آرکانزاس,ويست فورك,वेस्ट फर्क', 35.9242500, -94.1885400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131272, 'West Helena', 'West Helena', 'Vest Khelena,vesta helena,Вест Хелена,वेस्ट हेलेना', 34.5506600, -90.6417700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131273, 'West Memphis', 'West Memphis', 'AWM,Campo de Esperanza,Hopeville,Uehst-Memfis,Vest Memfis,Vest-Memfis,West Memphis,vesta memphisa,Вест Мемфис,Вест-Мемфіс,Уэст-Мемфис,ویسٹ میمفس، آرکنساس,वेस्ट मेम्फिस', 35.1464800, -90.1845400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131274, 'White Hall', 'White Hall', 'Uajt-Kholl,Vajt Khol,Vajt-Kholl,White Hall,Whitehall,vha''ita hala,wayt hal,Вайт-Холл,Вајт Хол,Уайт-Холл,وايت هال,وایت هال,व्हाइट हल', 34.2739900, -92.0909800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131275, 'Wrightsville', 'Wrightsville', '', 34.6023200, -92.2168100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131276, 'Wynne', 'Wynne', 'Vajn,Wynne,Wynne Junction,Wynne Station,vinne,Вајн,विन्ने', 35.2245300, -90.7867800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131277, 'Yellville', 'Yellville', 'Jelvil,Shawneetown,Yellville,yelbhila,ylfyl,ylwyl,Јелвил,يلفيل,یلولے ، ارکنساس,یلویل,येल्भिल', 36.2261800, -92.6848900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131278, 'Chevy Chase', 'Chevy Chase', 'Cheivy Chase,Chevy Chase', 38.9640000, -77.0677600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131279, 'Washington, D.C.', 'Washington, D.C.', 'Federal Capital,Federal City,Federal Town,Nations Capital,Ouasinkton,Ranatakariahshne,Ranatakariáhshne,Rome,Territory of Columbia,Vashington,Vasingtonas,Vasingtonia,Vašingtonas,WAS,Washington,Washington City,Washington D. C.,Washington D.C.,Washington DC,Waszyngton,hua sheng dun te qu,wosingteon D.C.,wosingteon DC,Ουάσιγκτον,Вашингтон,华盛顿特区,워싱턴 D.C.,워싱턴 DC', 38.8951100, -77.0363700, 'US', '2017-07-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131280, 'Bear', 'Bear', 'Bear,Bear Station', 39.6292800, -75.6582600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131281, 'Bellefonte', 'Bellefonte', '', 39.7662200, -75.5093600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131282, 'Bethany Beach', 'Bethany Beach', 'Betani Bich,bei se ni tan,bethyani bica,bytany bytsh,sahl btany  dlawr,Бетани Бич,بيتاني بيتش,بیتھانی بیچ، ڈیلاویئر,ساحل بتانی، دلاور,बेथ्यानी बीच,貝瑟尼灘', 38.5395600, -75.0551800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131283, 'Blades', 'Blades', '', 38.6356700, -75.6099300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131284, 'Bridgeville', 'Bridgeville', 'Bridge Branch,Bridge Town,Bridgebranch,Bridgeville,Bridzvil,brijabhila,brydjfyl,bu li qi wei er,Бриџвил,برج ویل، ڈیلاویئر,بريدجفيل,بریج‌ویل، دلاور,ब्रिजभिल,布里奇维尔', 38.7426100, -75.6043700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131285, 'Brookside', 'Brookside', 'Brookside,Brookside Park', 39.6670600, -75.7268800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131286, 'Camden', 'Camden', 'Camden,Kamden,Mifflins Cross Roads,Piccadily,ka mu deng,kamdn,kmdn  dlawr,kyamdena,Камден,كامدن,کمدن، دلاور,کیمڈن، ڈیلاویئر,क्याम्डेन,卡姆登', 39.1134500, -75.5418700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131287, 'Cheswold', 'Cheswold', 'Cheswold,DOV,Leipsic Station,Moorton', 39.2192800, -75.5857600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131288, 'Claymont', 'Claymont', 'Claymont,Gwinhurst,Klejmont,Naaman''s,Naaman''s Creek,Naamans Corner,klemonta,Клејмонт,क्लेमोन्ट', 39.8006700, -75.4596400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131289, 'Clayton', 'Clayton', 'Clayton,Jimtown,Klejton,Salisbury,Smyrna Station,klaytwn,kletana,klytwn  dlawr,Клейтон,Клејтон,كلايتون,کلیتون، دلاور,کلیٹون، ڈیلاویئر,क्लेटन', 39.2906700, -75.6343700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131290, 'Delaware City', 'Delaware City', 'Delavehr-Siti,Delaver Siti,Delaver-Siti,Delaware City,Newbold''s Landing,delavera siti,dellaweeositi,derau~eashiti,dlawr syty  dlawr,dylawyr syty,te la hua cheng,Делавер Сити,Делавер-Сіті,Делавэр-Сити,دلاور سیتی، دلاور,ديلاوير سيتي,ڈیلاویئر سٹی، ڈیلاویئر,डेलावेर सिटी,デラウェアシティ,特拉华城,델라웨어시티', 39.5778900, -75.5888100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131291, 'Delmar', 'Delmar', 'Delmar,de er ma,delmara,dlmar,dlmar  dlawr,Делмар,دلمار,دلمار، دلاور,ڈلمار، ڈیلاویئر,डेल्मार,德尔玛', 38.4565100, -75.5771500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131292, 'Dover', 'Dover', 'DOV,Douvur,Dover,Dover i Delaware,Dovera,Doveres,Doveris,Doverės,Gorad Dover,Ntover,doba,dobeo,dobhara,dovar,dovhara,duo fu,dwbr,dwfr,dwwr  dlawr,tovar,Ντόβερ,Горад Довер,Довер,Доувър,Դովեր,דאווער,דובר,دوفر,دوور، دلاور,ڈwwr,ڈوور,ڈوور، ڈیلاویئر,डोभर,डोवर्,डोव्हर,दोभर,டோவர்,ドーバー,多佛,도버', 39.1581700, -75.5243700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131293, 'Edgemoor', 'Edgemoor', 'Edge Moor,Edgemoor', 39.7501100, -75.4996400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131294, 'Elsmere', 'Elsmere', 'Elsmir,ai er si mi er,alsmr,alsmr  dlawr,elsmera,Елсмир,إلسمر,السمر، دلاور,ایلسمیر، ڈیلاویئر,एल्स्मेर,埃尔斯米尔', 39.7392800, -75.5979800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131295, 'Felton', 'Felton', 'Felton,fei er dun,fltwn  dlawr,fyltwn,pheltana,Фелтон,فلتون، دلاور,فيلتون,فیلٹن، ڈیلاویئر,फेल्टन,费尔顿', 39.0084500, -75.5779800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131296, 'Georgetown', 'Georgetown', 'Dzordztaun,GED,George Town,Georgetown,jorjata''una,jwrjtawn,qiao zhi dui,Џорџтаун,جرج‌تاون، دلاور,جورج ٹاؤن، ڈیلاویئر,جورجتاون,जोर्जटाउन,乔治敦', 38.6901100, -75.3854700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131297, 'Glasgow', 'Glasgow', 'Aikens Tavern,Aikentown,Glasgow', 39.6048300, -75.7452100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131298, 'Greenville', 'Greenville', 'Grinvil,Grinvill,grinabhila,Гринвил,Гринвилл,گرینویل، ڈیلاویئر,ग्रीनभिल', 39.7790000, -75.5982600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131299, 'Greenwood', 'Greenwood', 'Greenwood,Grinvud,Saint Johnstown,ge lin wu de,ghrynwwd,grinavuda,Гринвуд,غرينوود,گرین ووڈ، ڈیلاویئر,گرین‌وود، دلاور,ग्रीनवूड,格林伍德', 38.8070600, -75.5913200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131300, 'Harrington', 'Harrington', 'Clark''s Corner,Clarks Corner,Garrington,Harrington,Kharington,Kharrington,ha ling dun,harinton,harynghtwn,hryngtwn  dlawr,hyaringatana,Гаррінґтон,Харингтон,Харрингтон,هارينغتون,هرینگتون، دلاور,ہیرنگٹن، ڈیلاویئر,ह्यारिंगटन,ハリントン,哈灵顿', 38.9237200, -75.5777000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131301, 'Highland Acres', 'Highland Acres', '', 39.1209500, -75.5218700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131302, 'Hockessin', 'Hockessin', 'Hocesion,Hockessin,Hockessing,Khokesin,Occasian,Occasion,Ockession,Okesan,Okeshion,Okesian,Okession,hokesina,Хокесин,होकेसिन', 39.7876100, -75.6966000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131303, 'Kent Acres', 'Kent Acres', '', 39.1317800, -75.5249200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131304, 'Laurel', 'Laurel', 'Laurel,Laurel Town,Lorel,lao lei er,laurela,lawrl  dlawr,lwryl,Лорел,لارل، ڈیلاویئر,لاورل، دلاور,لوريل,लौरेल,劳雷尔', 38.5565000, -75.5713100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131305, 'Lewes', 'Lewes', 'Fort Oplandt,Hoornkill,L''juis,Lewes,Lewes Creek,Lewes Town,Lewestown,Lewis,Lewis Town,Lewistown,Luis,Swanendael,Swanendale,Swansdak,Swansdale,Whoore Kill,Zwaanendael,liu yi si,livija,lwys,lwz  dlawr,ruisu,Луис,Льюис,Льюїс,لوز، دلاور,لويس,لیوئس، ڈیلاویئر,लीवीज,ルイス,刘易斯', 38.7745600, -75.1393500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131306, 'Long Neck', 'Long Neck', '', 38.6201100, -75.1507400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131307, 'Middletown', 'Middletown', 'Middle Town,Middleton,Middletown,Midltaun,mi de er dui,midalata''una,midorutaun,mydltawn  dlawr,myldtawn,Мидлтаун,ميلدتاون,مڈل ٹاؤن، ڈیلاویئر,میدلتاون، دلاور,मिडलटाउन,ミドルタウン,米德尔敦', 39.4495600, -75.7163200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131308, 'Milford', 'Milford', 'Milford,North Milford,South Milford,mi er fu de,milapharda,milpeodeu,mirufodo,mylfwrd,mylfwrd  dlawr,Милфорд,Мілфорд,ميلفورد,میلفورد، دلاور,میلفورڈ، ڈیلاویئر,मिलफर्ड,ミルフォード,米尔福德,밀퍼드', 38.9126100, -75.4279700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131309, 'Millsboro', 'Millsboro', 'Millsboro,Millsborough,Milsboro,Rock Haul,Rock Hole,Washington,Washington Village,mi er si bo lei,milasbaro,mylsbrw  dlawr,mylsbwrw,Милсборо,ملزبورو، ڈیلاویئر,ميلسبورو,میلسبرو، دلاور,मिलस्बरो,米尔斯伯勒', 38.5915000, -75.2913000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131310, 'Milton', 'Milton', 'Broadkill,Clowes,Clows,Conwell''s Landing,Conwells Landing,Head of Broadkill,Head of Broadkiln,Mil''ton,Milton,Osborne''s Landing,Osbornes Landing,Sockumtown,Upper Landing,mi er dun,milatana,myltwn,myltwn  dlawr,Милтон,Мильтон,ملٹن، ڈیلاویئر,ميلتون,میلتون، دلاور,मिलटन,米尔顿', 38.7776100, -75.3099100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131311, 'New Castle', 'New Castle', 'Aresapa,Cannekonkan,Delaware Town,Fort Casimir,Fort Casimires,Fort Kasimier,Fort Trefalldigheet,Fort Trinity,Macherish Kitton,N''ju-Kasl,Neu Castle,Neucastle,New Amstel,New Castel,New Castl,New Castle,New Castle Town,New Castle Towne,Newcastle,Newcastle Town,Nieu Causeland,Nieuwer-Amstel,Niew Amstel,Nju Kasl,Sandhocken,Santhoeck,Tamakonck,Tamecongh,Trefaldighet,Trefalldigheet,n''yu kyasala,niu ka si er,nyukaeseul,nyukyassuru,nyw kasl,nywkasl  dlawr,Њу Касл,Нью-Касл,نيو كاسل,نیو کیسل، ڈیلاویئر,نیوکاسل، دلاور,न्यु क्यासल,ニューキャッスル,纽卡斯尔,뉴캐슬', 39.6620600, -75.5663100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131312, 'Newark', 'Newark', 'N''juark,New Worke,Newark,Njuark,n''yu''arka,niu wa ke,nyuaku,nywark,nywark  dlawr,Њуарк,Ньюарк,Нюарк,نيوارك,نیوآرک، دلاور,نیوآرک، ڈیلاویئر,न्युआर्क,ニューアーク,纽瓦克', 39.6837200, -75.7496600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131313, 'Newport', 'Newport', 'N''juport,New Port,New Port Ayre,Newport,Njuport,n''yuporta,niu bo te,nywbwrt,nywpwrt  dlawr,Њупорт,Ньюпорт,نيوبورت,نیو پورٹ، ڈیلاویئر,نیوپورت، دلاور,न्युपोर्ट,纽波特', 39.7137200, -75.6093700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131314, 'North Star', 'North Star', '', 39.7612200, -75.7191000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131315, 'Pike Creek', 'Pike Creek', '', 39.7309500, -75.7041000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131316, 'Pike Creek Valley', 'Pike Creek Valley', '', 39.7362200, -75.6982700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131317, 'Rehoboth Beach', 'Rehoboth Beach', 'REH,Rehobeth,Rehobeth Beach,Rehoboth,Rehoboth Beach,Rekhobot Bich,Rekhobot-Bich,li huo bo si tan,rehobosubichi,rehobotha bica,ryhwbath bych  dlawr,ryhwbwth bytsh,Рехобот Бич,Рехобот-Бич,Рехобот-Біч,ريهوبوث بيتش,ریهوباث بیچ، دلاور,ریہوبوتھ بیچ، ڈیلاویئر,रेहोबोथ बीच,レホボスビーチ,里霍伯斯灘', 38.7209500, -75.0760100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131318, 'Riverview', 'Riverview', '', 39.0265000, -75.5107600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131319, 'Rodney Village', 'Rodney Village', '', 39.1320600, -75.5324200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131320, 'Seaford', 'Seaford', 'Hooper''s Landing,Hoopers Landing,Seaford,Seaford City,Seford,Siford,shifodo,sipharda,syfwrd,syfwrd  dlawr,xi fu de,Сифорд,سيفورد,سیفورد، دلاور,سیفورڈ، ڈیلاویئر,सीफर्ड,シーフォード,锡福德', 38.6412300, -75.6110400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131321, 'Selbyville', 'Selbyville', 'Sandy Branch,Selbyville', 38.4603900, -75.2207400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131322, 'Smyrna', 'Smyrna', 'Cross Roads,Duck Creek,Duck Creek Cross Roads,Duck Creek Town,Smirna,Smyrna,smirna,smyrna,smyrna  dlawr,Смирна,سمرنا، ڈیلاویئر,سميرنا,سمیرنا، دلاور,स्मीर्ना', 39.2998300, -75.6046500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131323, 'Townsend', 'Townsend', 'Charleston,Charley Town,Charleytown,Taunsend,Townsend,ta''unasenda,tang sen de,tawnsnd,tawnsnd  dlawr,Таунсенд,تاونسند,تاونسند، دلاور,ٹاؤن سینڈ، ڈیلاویئر,टाउनसेन्ड,汤森德', 39.3951100, -75.6916000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131324, 'Wilmington', 'Wilmington', 'Christinahamn,Fort Altena,Fort Christina,Gorad Uilmingtan,ILG,Uilmington,Uilmingtun,Vilmington,Vilmingtona,Vilmingtonas,Vilmingtonia,Walmington,Willington,Willingtown,Wilmington,Wilmington City,Wilmington i Delaware,u~iruminton,vilmingatana,wei er ming dun,wilmingteon,wylmnghtwn,wylmyngtwn,wylmyngtwn  dlawr,Вилмингтон,Вілмінгтон,Горад Уілмінгтан,Уилмингтон,Уилмингтън,וילמינגטון,ويلمنغتون,ویلمینگتون، دلاور,ویلمینگٹن، ڈیلاویئر,विल्मिंगटन,უილმინგტონი,ウィルミントン,威尔明顿,윌밍턴', 39.7459500, -75.5465900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131325, 'Wilmington Manor', 'Wilmington Manor', '', 39.6867800, -75.5843700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131326, 'Wyoming', 'Wyoming', 'Camden Station,Vajoming,West Camden,Wyoming,huai e ming,vayominga,waywmngh,waywmyng  dlawr,Вайоминг,Вайомінг,Вајоминг,وايومنغ,وایومنگ، ڈیلاویئر,وایومینگ، دلاور,वायोमिंग,怀俄明', 39.1181700, -75.5588100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131327, 'Alachua', 'Alachua', '', 29.7516300, -82.4248300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131328, 'Allapattah', 'Allapattah', 'Allapatah,Allapattah', 25.8145400, -80.2239400, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131329, 'Altamonte Springs', 'Altamonte Springs', 'Altamont Springs,Altamonte Spgs,Altamonte Springs,Altamonte-Springs,a er ta meng te si pu lin si,altamonte springas,altamwnt aspryngz  flwryda,altamwnt sbrnghz,Алтамонт Спрингс,Алтамонте-Спрінгс,آلتامونت اسپرینگز، فلوریدا,ألتامونت سبرنغز,अल्तामोन्ते स्प्रिङ्गस्,阿尔塔蒙特斯普林斯', 28.6611100, -81.3656200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131330, 'Alturas', 'Alturas', '', 27.8716900, -81.7150800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131331, 'Alva', 'Alva', '', 26.7156200, -81.6100800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131332, 'Andover', 'Andover', 'Andover,Miami Gardens,endobhara,Андовер,एन्डोभर', 25.9684300, -80.2128300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131333, 'Anna Maria', 'Anna Maria', '', 27.5311500, -82.7334300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131334, 'Apalachicola', 'Apalachicola', 'AAF,Apalachicola,Apalachikola,Appalachicola,a ba la qi ke la,abalatshykwla,apalachykwla  flwryda,epalacikola,Апалачикола,آپالاچیکولا، فلوریدا,أبالاتشيكولا,एपालाचिकोला,阿巴拉契科拉', 29.7260000, -84.9856000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131335, 'Apollo Beach', 'Apollo Beach', '', 27.7730800, -82.4075900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131336, 'Apopka', 'Apopka', 'Ahahpopka,Apopka,a bo ka,abwbka,apwpka  flwryda,epopka,Апопка,آپوپکا، فلوریدا,أبوبكا,एपोप्का,阿勃卡', 28.6761700, -81.5118600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131337, 'Arcadia', 'Arcadia', 'Arcadia,Arkadija,Tater Hill Bluff,Tater Hill Landing,Waldrons Homestead,Аркадия', 27.2158800, -81.8584200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131338, 'Archer', 'Archer', '', 29.5299700, -82.5190000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131339, 'Asbury Lake', 'Asbury Lake', '', 30.0491300, -81.8214900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131340, 'Astatula', 'Astatula', '', 28.7097200, -81.7328500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131341, 'Astor', 'Astor', 'Astor,Ehstor,estara,Астор,Эстор,एस्टर', 29.1624800, -81.5253500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131342, 'Atlantic Beach', 'Atlantic Beach', 'Atlantik Bich,aeteullaentigbichi,atlantyk bych  flwryda,atlantyk bytsh,da xi yang hai tan,etlantika bica,Атлантик Бич,آتلانتیک بیچ، فلوریدا,أتلانتيك بيتش,एट्लान्टिक बीच,大西洋海滩,애틀랜틱비치', 30.3344100, -81.3987000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131343, 'Atlantis', 'Atlantis', 'Atlantis,atlantys,atlantys  flwryda,etlantisa,ya te lan di si,Атлантис,آتلانتیس، فلوریدا,أتلانتيس,एट्लान्टिस,亚特兰蒂斯', 26.5909000, -80.1008800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131344, 'Auburndale', 'Auburndale', 'Oberndejl,abarnadela,ao ben dai er,awbwrndal,Оберндејл,أوبورندال,اوبورن‌دیل، فلوریدا,अबर्नडेल,奥本代尔', 28.0653000, -81.7886900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131345, 'Aventura', 'Aventura', 'Adventura,Aventura,a wen tu la,aebeontula,afyntjwra,awntwra  flwryda,ebhencura,Авентура,أفينتجورا,اونتورا، فلوریدا,एभेन्चुरा,阿文图拉,애번투라', 25.9564800, -80.1392100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131346, 'Avon Park', 'Avon Park', 'AVO,Ejvon Park,afwn bark,awwn park  flwryda,bi hu hua yuan,ebhona parka,Ејвон Парк,آوون پارک، فلوریدا,أفون بارك,एभोन पार्क,碧湖花园', 27.5958700, -81.5061900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131347, 'Azalea Park', 'Azalea Park', '', 28.5411100, -81.3006200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131348, 'Babson Park', 'Babson Park', '', 27.8319700, -81.5223000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131349, 'Bagdad', 'Bagdad', '', 30.5988000, -87.0322300, 'US', '2016-02-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131350, 'Bal Harbour', 'Bal Harbour', 'Bal Harbor,Bal Harbour,bal harbr  flwryda,bal harbwr,bao luo ha bo,byal harbara,بال هاربر، فلوریدا,بال هاربور,ब्याल् हार्बर,保罗哈博', 25.8917600, -80.1269900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131351, 'Baldwin', 'Baldwin', 'Bolduin,Boldvin,baldavina,baldwyn,baldwyn  flwryda,bao de wen,Болдвин,Болдуин,بالدوين,بالدوین، فلوریدا,بالڈون، فلوریڈا,बाल्डविन,鲍德温', 30.3027400, -81.9753900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131352, 'Balm', 'Balm', '', 27.7594700, -82.2612000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131353, 'Bartow', 'Bartow', 'BOW,Bartou,ba tuo,barato,bartaw  flwryda,bartw,Бартоу,بارتاو، فلوریدا,بارتو,बारटो,巴托', 27.8964100, -81.8431400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131354, 'Bay Harbor Islands', 'Bay Harbor Islands', 'Bej Kharbor Ajlands,Bej-Kharbor-Ajlends,bay harbwr ayland,be harbara a''ilyandas,by harbr aylndz  flwryda,gang kou wan qun dao,Бей-Харбор-Айлендс,Беј Харбор Ајландс,باي هاربور آيلاند,بی هاربر آیلندز، فلوریدا,بے ہاربر آیلینڈز، فلوریڈا,बे हार्बर आइल्यान्डस्,港口湾群岛', 25.8875900, -80.1311600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131355, 'Bay Hill', 'Bay Hill', '', 28.4680600, -81.5161800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131356, 'Bay Pines', 'Bay Pines', '', 27.8141900, -82.7781600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131357, 'Bayonet Point', 'Bayonet Point', '', 28.3266700, -82.6834300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131358, 'Bayshore Gardens', 'Bayshore Gardens', '', 27.4253200, -82.5903800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131359, 'Beacon Square', 'Beacon Square', 'Beacon Square,Beacon Squier', 28.2086200, -82.7553800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131360, 'Bee Ridge', 'Bee Ridge', '', 27.2839400, -82.4806500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131361, 'Belle Glade', 'Belle Glade', 'Bel Glejd,bei er ge lai de,bele glyada,bl ghlyd,bl glyd  flwryda,Бел Глејд,بل غليد,بل گلید، فلوریدا,बेले ग्ल्याड,贝尔格莱德', 26.6845100, -80.6675600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131362, 'Belle Glade Camp', 'Belle Glade Camp', '', 26.6575700, -80.6828400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131363, 'Belle Isle', 'Belle Isle', 'Belle Isle,Nela Isle (in part),Nela Isle Annex (in part)', 28.4583400, -81.3592400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131364, 'Belleair', 'Belleair', '', 27.9358500, -82.8062100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131365, 'Belleair Beach', 'Belleair Beach', '', 27.9230800, -82.8431600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131366, 'Belleair Bluffs', 'Belleair Bluffs', '', 27.9214100, -82.8170500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131367, 'Belleview', 'Belleview', 'Belvju,bei er wei you,belebhyu,bylyfyw,Белвју,بل‌ویو، فلوریدا,بيليفيو,बेलेभ्यू,贝尔维尤', 29.0552600, -82.0623100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131368, 'Bellview', 'Bellview', 'Belleview,Bellview', 30.4615900, -87.3149700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131369, 'Beverly Hills', 'Beverly Hills', 'Bevurli Khils,Бевърли Хилс', 28.9169200, -82.4581500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131370, 'Big Coppitt Key', 'Big Coppitt Key', '', 24.5965300, -81.6600900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131371, 'Big Pine Key', 'Big Pine Key', 'Big Pine,Big Pine Key,Big-Pajn-Ki,Bog Pajn Ki,biga pa''ina ki,bigpainki,Биг-Пайн-Ки,Бог Пајн Ки,बिग पाइन की,빅파인키', 24.6698700, -81.3539700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131372, 'Biscayne Park', 'Biscayne Park', '', 25.8826000, -80.1806000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131373, 'Bithlo', 'Bithlo', '', 28.5547200, -81.1064500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131374, 'Black Diamond', 'Black Diamond', '', 28.9124800, -82.4859300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131375, 'Bloomingdale', 'Bloomingdale', '', 27.8936400, -82.2403700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131376, 'Blountstown', 'Blountstown', 'Blauntstaun,Blountstown,Lafarka,beulleoncheutaun,bla''untsata''una,blwntstawn,bu lang si dun,Блаунтстаун,بلاونتس‌تاون، فلوریدا,بلونتستاون,ब्लाउन्ट्सटाउन,布朗斯顿,블런츠타운', 30.4437900, -85.0474400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131377, 'Boca Del Mar', 'Boca Del Mar', 'Boca Raton,Boka-Del-Mar,Loka Del Mar,boka dela mara,Бока-Дел-Мар,Лока Дел Мар,बोका डेल मार', 26.3450800, -80.1467100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131378, 'Boca Pointe', 'Boca Pointe', '', 26.3331300, -80.1594900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131379, 'Boca Raton', 'Boca Raton', 'BCT,Boca Raton,Boca Ratone,Boca Ratón,Boca de Ratones,Bocaraton,Boka Raton,Boka-Raton,WTA Boca Raton,bo ka la dun,boka retana,bokaleoton,bokaraton,bwka ratwn,bwka ratwn  flwryda,Бока Ратон,Бока-Ратон,באקא ראטאן,بوكا راتون,بوکا راتون، فلوریدا,बोका रेटन,ボカラトン,博卡拉頓,보카러톤', 26.3586900, -80.0831000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131380, 'Bokeelia', 'Bokeelia', 'Bokilija,bokiliya,Бокилия,Бокилија,बोकीलिया', 26.7056300, -82.1589800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131381, 'Bonifay', 'Bonifay', '', 30.7918600, -85.6796500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131382, 'Bonita Springs', 'Bonita Springs', 'Bonita Springs,Bonita-Springs,bo ni ta wen quan,bonita springas,bwnyta aspryngz  flwryda,bwnyta sbrnghz,Бонита Спрингс,Боніта-Спрінгс,بونيتا سبرنغز,بونیتا اسپرینگز، فلوریدا,बोनिता स्प्रिङ्गस्,博尼塔温泉', 26.3398100, -81.7787000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131383, 'Bowling Green', 'Bowling Green', 'Bouling-Grin,Боулинг-Грин', 27.6383700, -81.8239700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131384, 'Boyette', 'Boyette', '', 27.8175300, -82.2225900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131385, 'Boynton Beach', 'Boynton Beach', 'Bojnton Bich,Bojnton-Bich,Boynton,Boynton Beach,bo yin dun hai tan,bo''inatana bica,bointeonbichi,bwyntwn,bwyntwn bych  flwryda,Бойнтон-Біч,Бојнтон Бич,بوينتون,بوینتون بیچ، فلوریدا,बोइनटन बीच,博因顿海滩,보인턴비치', 26.5253500, -80.0664300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131386, 'Bradenton', 'Bradenton', 'Braden Town,Bradenton,Bradentown,Braiden Town,Braidentown,Brejdenton,beuleideunteon,bradenatana,bradntwn,bradntwn  flwryda,bu lei deng dun,bureidenton,Брейдентон,Брејдентон,برادنتون,برادنتون، فلوریدا,ब्राडेनटन,ბრადენტონი,ブレイデントン,布雷登顿,브레이든턴', 27.4989300, -82.5748200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131387, 'Bradenton Beach', 'Bradenton Beach', 'Bradenton Beach,Brejdenton Bich,Cortez,Cortez Beach,bradenatana bica,bradntwn bych  flwryda,bu lei deng dun hai tan,Брејдентон Бич,برادنتون بیچ، فلوریدا,ब्राडेनटन बीच,布雷登顿海滩', 27.4669800, -82.7039900, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131388, 'Brandon', 'Brandon', 'Brando,Brandon,Brehndon,bryandana,burandon,Брандон,Брэндон,برینڈن، فلوریڈا,ब्र्यान्डन,ブランドン', 27.9378000, -82.2859200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131389, 'Brent', 'Brent', 'Brent,brenta,Брент,ब्रेन्ट', 30.4688100, -87.2360800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131390, 'Bristol', 'Bristol', 'Bristol,brayny bryzz,bristala,brystwl  flwryda,bu li si tuo er,Бристол,برايني بريزز,برسٹل، فلوریڈا,بریستول، فلوریدا,ब्रिस्टल,布里斯托尔', 30.4324700, -84.9770200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131391, 'Broadview Park', 'Broadview Park', '', 26.0995300, -80.2086600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131392, 'Bronson', 'Bronson', 'Bronson,branswn  flwryda,bronsana,brystwl,bu lang sen,Бронсон,برانسون، فلوریدا,برونسن، فلوریڈا,بريستول,ब्रोन्सन,布朗森', 29.4477400, -82.6423300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131393, 'Brookridge', 'Brookridge', '', 28.5511000, -82.4920400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131394, 'Brooksville', 'Brooksville', 'Bruksvil,brwksfyl,bu lu ke si,Бруксвил,بروكسفيل,بروکسویل، فلوریڈا,بروکس‌ویل، فلوریدا,ब्रुक्स्‌भिल्,布鲁克斯', 28.5555400, -82.3899100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131395, 'Broward Estates', 'Broward Estates', '', 26.1256400, -80.1933800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131396, 'Brownsville', 'Brownsville', '', 25.8217600, -80.2411600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131397, 'Buckhead Ridge', 'Buckhead Ridge', '', 27.1303300, -80.8936700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131398, 'Buckingham', 'Buckingham', '', 26.6750700, -81.7320300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131399, 'Buenaventura Lakes', 'Buenaventura Lakes', '', 28.3358400, -81.3531300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131400, 'Bunche Park', 'Bunche Park', '', 25.9206500, -80.2369900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131401, 'Bunnell', 'Bunnell', 'Banel,bang nai er,banl  flwryda,banyl,byunela,Банел,بانل، فلوریدا,بانيل,بونیل، فلوریڈا,ब्युनेल,邦乃尔', 29.4660900, -81.2578400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131402, 'Burnt Store Marina', 'Burnt Store Marina', '', 26.7650700, -82.0509200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131403, 'Bushnell', 'Bushnell', 'Bushnel,bu shen nei er,busanela,bwshnyl,Бушнел,بوشنيل,بوشنیل، فلوریڈا,بوش‌نل، فلوریدا,बुशनेल,布什内尔', 28.6649900, -82.1128600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131404, 'Butler Beach', 'Butler Beach', '', 29.7983000, -81.2670100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131405, 'Callahan', 'Callahan', 'Kalakhan,ka la han,kalahan,klahan  flwryda,kyalahyana,Калахан,كالاهان,کلاهان، فلوریدا,क्यालाह्यान,卡拉汉', 30.5621800, -81.8306600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131406, 'Callaway', 'Callaway', '', 30.1529800, -85.5699300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131407, 'Campbell', 'Campbell', 'Campbell,Campbell Station,Kehmpbell,Кэмпбелл', 28.2589000, -81.4564600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131408, 'Cantonment', 'Cantonment', 'Canton,Cantonment,North Pensacola', 30.6085300, -87.3399800, 'US', '2012-09-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131409, 'Cape Canaveral', 'Cape Canaveral', 'Artesia,Cabo Canaveral,Cabo Cañaveral,Cape Canaveral,Kejp Kanaveral,Port Canavera,Port Canaveral,ka na wei la er jiao,kepa kenabherala,kyb kanfral,kyp kanawral  flwryda,Кејп Канаверал,كيب كانفرال,کیپ کاناورال، فلوریدا,کیپ کیناوریل، فلوریڈا,केप केनाभेरल,卡纳维拉尔角', 28.4058400, -80.6047700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131410, 'Cape Coral', 'Cape Coral', 'Cabo Coral,Cape Coral,Keip Koralas,Kejp Koral,Kejp Korul,Kejp-Koral,kai pu ke lei er,keipeukoleol,kepa korala,kepukoraru,kyb kwral,kyp kwral  flwryda,qyyp qwrl,Кейп Коръл,Кейп-Корал,Кејп Корал,קייפ קורל,كيب كورال,کیپ کورال، فلوریدا,کیپ کورل، فلوریڈا,केप कोरल,ケープコーラル,開普科勒爾,케이프코럴', 26.5628500, -81.9495300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131411, 'Carol City', 'Carol City', 'Carol City', 25.9406500, -80.2456000, 'US', '2006-11-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131412, 'Carrabelle', 'Carrabelle', 'Karabel,ka la bei er,karabl  flwryda,karabyl,kyarabele,Карабел,كارابيل,کارابل، فلوریدا,क्याराबेले,卡拉贝尔', 29.8532600, -84.6643500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131413, 'Carrollwood', 'Carrollwood', 'Greater Carrollwood', 28.0500200, -82.4928700, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131414, 'Carrollwood Village', 'Carrollwood Village', '', 28.0675200, -82.5209300, 'US', '2006-01-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131415, 'Carver Ranches', 'Carver Ranches', '', 25.9884200, -80.1922700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131416, 'Casselberry', 'Casselberry', 'Kaselberi,ka xi bei li,kasylbyry,kslbry  flwryda,kyaselaberi,Каселбери,كاسيلبيري,کسلبری، فلوریدا,क्यासेलबेरी,卡西贝利', 28.6777800, -81.3278500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131417, 'Cedar Grove', 'Cedar Grove', '', 30.1710300, -85.6252000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131418, 'Celebration', 'Celebration', 'Selebrejshn,Selebrejshon,selebritiyana,slbryysn,Селебрейшн,Селебрејшон,סלבריישן,सेलेब्रिटियन', 28.3252900, -81.5331300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131419, 'Center Hill', 'Center Hill', '', 28.6499900, -81.9925800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131420, 'Century', 'Century', '', 30.9732400, -87.2638600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131421, 'Charlotte Harbor', 'Charlotte Harbor', '', 26.9583900, -82.0670300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131422, 'Charlotte Park', 'Charlotte Park', '', 26.9100600, -82.0539800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131423, 'Chattahoochee', 'Chattahoochee', 'Chattahooche,Chattahoochee,River Junction', 30.7054600, -84.8457400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131424, 'Cheval', 'Cheval', '', 28.1486200, -82.5145400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131425, 'Chiefland', 'Chiefland', '', 29.4749600, -82.8598400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131426, 'Chipley', 'Chipley', 'Chipley,Chipli,Orange,chyply  flwryda,cipali,qi pu li,tshybly,Чипли,تشيبلي,چیپلی، فلوریدا,चिपली,奇普利', 30.7818600, -85.5385400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131427, 'Christmas', 'Christmas', 'Krismas,Krismehs,krismasa,Крисмас,Крисмэс,क्रिस्मस', 28.5363900, -81.0175600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131428, 'Chuluota', 'Chuluota', '', 28.6419400, -81.1234000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131429, 'Citra', 'Citra', '', 29.4119200, -82.1098200, 'US', '2012-06-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131430, 'Citrus Hills', 'Citrus Hills', '', 28.8883100, -82.4326000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131431, 'Citrus Park', 'Citrus Park', '', 28.0783500, -82.5698200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131432, 'Citrus Ridge', 'Citrus Ridge', 'Citrus Ridge,Four Corners', 28.3338500, -81.6423200, 'US', '2010-06-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131433, 'Citrus Springs', 'Citrus Springs', '', 28.9974800, -82.4706500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131434, 'Clarcona', 'Clarcona', 'Clarcona,Clarconal', 28.6127800, -81.4986800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131435, 'Clearwater', 'Clearwater', 'CLW,Clearwater,Clearwater Harbor,Kliruoter,Klirvoter,Klirvoteris,Kliuruotur,ke li er wo te,keullieowoteo,kliyaravatara,klyrwatr,klyrwatr  flwryda,kuriau~ota,Клирвотер,Клируотер,Клиъруотър,Клірвотер,كليرواتر,کلیئرواٹر، فلوریڈا,کلیرواتر، فلوریدا,کلیرواٹر,क्लियरवाटर,クリアウォーター,克利爾沃特,클리어워터', 27.9658500, -82.8001000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131436, 'Clermont', 'Clermont', 'Klermont,ke lai meng,kleramonta,klrmwnt  flwryda,klyrmwnt,Клермонт,كليرمونت,کلرمونت، فلوریدا,क्लेरमोन्ट,克莱蒙', 28.5494400, -81.7728500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131437, 'Clewiston', 'Clewiston', 'Kluston,ke lai wei si dun,klevistana,klwstwn,klwystwn  flwryda,Клустон,كلوستون,کلویستون، فلوریدا,क्लेविस्टन,克莱维斯顿', 26.7542300, -80.9336800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131438, 'Cleveland', 'Cleveland', 'Klivlend,Кливленд', 26.9617300, -81.9839800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131439, 'Cocoa', 'Cocoa', 'COI,Cocoa,Koko,ke ke,koko''a,kwkaw,kwkw  flwryda,Коко,كوكاو,کوکو، فلوریدا,कोकोआ,可可', 28.3861200, -80.7420000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131440, 'Cocoa Beach', 'Cocoa Beach', 'COF,Cocoa Beach,Koko Bich,Koko Bijch,Koko-Bich,ke ke bi qi,koko''a bica,kokoabichi,kwkaw bytsh,kwkw bych  flwryda,Коко Бийч,Коко Бич,Коко-Бич,Коко-Біч,كوكاو بيتش,کوکو بیچ، فلوریدا,कोकोआ बीच,ココアビーチ,可可比奇,코코아비치', 28.3205500, -80.6092200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131441, 'Coconut Creek', 'Coconut Creek', 'Kokonat Krik,Kokonat-Krik,kokonata krika,kwkwnat kryk  flwryda,kwkwnt kryk,ye zi xi,Коконат Крик,Коконат-Крік,كوكونت كريك,کوکونات کریک، فلوریدا,کوکونٹ کریک، فلوریڈا,कोकोनट क्रीक,椰子溪', 26.2517500, -80.1789400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131442, 'Coconut Grove', 'Coconut Grove', 'Bay Heights,Cocoanut Grove,Coconut Grove,ye lin,椰林', 25.7126000, -80.2569900, 'US', '2014-07-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131443, 'Combee Settlement', 'Combee Settlement', '', 28.0583500, -81.9053600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131444, 'Conway', 'Conway', 'Konvej,Конвей', 28.5027800, -81.3306200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131445, 'Cooper City', 'Cooper City', 'Kuper Siti,Kuper-Siti,ku po shi,kupara siti,kwbr syty,kwpr syty  flwryda,Купер Сити,Купер-Сити,Купер-Сіті,كوبر سيتي,کوپر سٹی، فلوریڈا,کوپر سیتی، فلوریدا,कूपर सिटी,库珀市', 26.0573100, -80.2717200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131446, 'Coral Gables', 'Coral Gables', 'Koral Gejbls,Koral-Gejblz,ke lei er gai bu er si,koleolgeibeuljeu,korala gyabalsa,kwral ghyblz,kwral gyblz  flwryda,Корал Гејблс,Корал-Ґейблз,كورال غيبلز,کورال گیبلز، فلوریدا,कोरल ग्याबल्स,科勒尔盖布尔斯,코럴게이블즈', 25.7214900, -80.2683800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131447, 'Coral Springs', 'Coral Springs', 'Coral Springs,Koral Springs,Koral Springsas,Koral-Springs,ke lei er si pu lin si,koleolseupeulingseu,korala springas,korarusupuringusu,kwral aspryngz  flwryda,kwral sbrnghz,Корал Спрингс,Корал-Спрингс,Корал-Спрінгс,كورال سبرنغز,کورال اسپرینگز، فلوریدا,کورل اسپرنگز، فلوریڈا,कोरल स्प्रिङ्गस्,コーラルスプリングス,科勒爾斯普林斯,코럴스프링스', 26.2711900, -80.2706000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131448, 'Coral Terrace', 'Coral Terrace', '', 25.7459300, -80.3045000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131449, 'Cortez', 'Cortez', '', 27.4692100, -82.6862100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131450, 'Country Walk', 'Country Walk', '', 25.6339900, -80.4322800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131451, 'Country Club', 'Country Club', '', 25.9481500, -80.3170000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131452, 'Crawfordville', 'Crawfordville', '', 30.1760400, -84.3751800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131453, 'Crescent City', 'Crescent City', 'Kresent Siti,kres''senta siti,krsnt syty  flwryda,krysnt syty,xin yue cheng,Кресент Сити,كريسنت سيتي,کرسنت سیتی، فلوریدا,کریسنٹ سٹی، فلوریڈا,क्रेस्सेन्ट सिटी,新月城', 29.4302500, -81.5106300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131454, 'Crestview', 'Crestview', 'CEW,Krestvju,ke lei si te wei,krestabhyu,krystfyw,Крествју,كريستفيو,کرست‌ویو، فلوریدا,क्रेस्टभ्यू,克雷斯特韦', 30.7621300, -86.5705100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131455, 'Crooked Lake Park', 'Crooked Lake Park', '', 27.8291900, -81.5839700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131456, 'Cross City', 'Cross City', 'CTY,Kros Siti,Kross-Siti,kras syty  flwryda,krasa siti,krws syty,kua cheng,Крос Сити,Кросс-Сити,كروس سيتي,کراس سیتی، فلوریدا,क्रस सिटी,跨城', 29.6346500, -83.1269400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131457, 'Crystal Lake', 'Crystal Lake', '', 28.0355800, -81.9084100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131458, 'Crystal River', 'Crystal River', 'Kristal River,kristala ribhara,krystal ryfr,krystal rywr  flwryda,shui jing he,Кристал Ривер,كريستال ريفر,کریستال ریور، فلوریدا,क्रिस्टल रिभर,水晶河', 28.9024800, -82.5926000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131459, 'Crystal Springs', 'Crystal Springs', '', 28.1814000, -82.1575800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131460, 'Cudjoe Key', 'Cudjoe Key', '', 24.6715300, -81.4984200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131461, 'Cutler', 'Cutler', '', 25.6151000, -80.3106100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131462, 'Cutler Ridge', 'Cutler Ridge', '', 25.5806600, -80.3467200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131463, 'Cypress Gardens', 'Cypress Gardens', '', 27.9939100, -81.6900800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131464, 'Cypress Lake', 'Cypress Lake', '', 26.5381300, -81.8992500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131465, 'Cypress Quarters', 'Cypress Quarters', '', 27.2519900, -80.8139500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131466, 'Dade City', 'Dade City', 'Dejd Siti,dade siti,dai de shi,dyd syty,dyd syty  flwryda,Дејд Сити,ديد سيتي,دید سیتی، فلوریدا,डाडे सिटी,戴德市', 28.3647200, -82.1959200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131467, 'Dania Beach', 'Dania Beach', 'Dania,Dania Beach,Dejnija Bich,Modello,da ni ya tan,danya bych  flwryda,danya bytsh,dyaniya bica,Дејнија Бич,دانيا بيتش,دانیا بیچ، فلوریدا,ड्यानिया बीच,达尼亚滩', 26.0523100, -80.1439300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131468, 'Davenport', 'Davenport', 'Dehvenport,Дэвенпорт', 28.1614000, -81.6017400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131469, 'Davie', 'Davie', 'Davie,Dehvi,Dejvi,Devi,dai wei,debhi,dyfy,dywy  flwryda,Деві,Дейви,Дејви,Дэви,ديفي,دیوی، فلوریدا,डेभी,戴维', 26.0628700, -80.2331000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131470, 'Daytona Beach', 'Daytona Beach', 'DAB,Daytona,Daytona Beach,Dejtona Bich,Dejtona Bijch,Dejtona-Bich,dai tong na hai tan,daytwna bytsh,deitonabichi,detana bica,dytwna bych  flwryda,teytona katarkarai,Дейтона Бийч,Дейтона-Бич,Дейтона-Біч,Дејтона Бич,دايتونا بيتش,دیتونا بیچ، فلوریدا,डेटना बीच,டெய்டோனா கடற்கரை,デイトナビーチ,戴通納海灘,데이토나비치', 29.2108100, -81.0228300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131471, 'Daytona Beach Shores', 'Daytona Beach Shores', '', 29.1760900, -80.9828300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131472, 'DeFuniak Springs', 'DeFuniak Springs', 'De Fjunijak Springs,De Funiak Springs,De Funick Springs,de fen a ke quan,de phyuniyaka springas,dwfwnyak aspryngz  flwryda,dyfwnyak sbrnghz,Де Фјунијак Спрингс,دوفونیاک اسپرینگز، فلوریدا,ديفونياك سبرنغز,डे फ्युनियाक स्प्रिङ्गस्,德芬阿克泉', 30.7210200, -86.1152200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131473, 'DeLand', 'DeLand', 'De Land,DeLand,Deland,de lan,de lyanda,delandi,dwlnd  flwryda,dyland,Деланд,دولند، فلوریدا,ديلاند,डे ल्यांड,დელანდი,德兰', 29.0283200, -81.3031200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131474, 'De Leon Springs', 'De Leon Springs', 'De Leon Springs,DeLeon,DeLeon Springs,Deleon Springs', 29.1198900, -81.3528600, 'US', '2015-03-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131475, 'DeBary', 'DeBary', 'De Bary,Deberi,de bai rui,de byari,dwbary  flwryda,dybary,Дебери,دوباری، فلوریدا,ديباري,डे ब्यारी,徳拜瑞', 28.8830500, -81.3086800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131476, 'Deerfield Beach', 'Deerfield Beach', 'Deerfield,Deerfield Beach,Dirfild Bich,Dirfild-Bich,di er fei er de hai tan,dyaraphilda bica,dyrfyld bych  flwryda,dyrfyld bytsh,Дирфилд Бич,Дирфилд-Бич,Дірфілд-Біч,ديرفيلد بيتش,دیرفیلد بیچ، فلوریدا,ड्यरफिल्ड बीच,迪尔菲尔德海滩', 26.3184100, -80.0997700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131477, 'Delray Beach', 'Delray Beach', 'Delray Beach,Delrej Bich,Delrej-Bich,de la hai tan,delre bica,derureibichi,dlray bytsh,dlry bych  flwryda,dlryy byz,Делрей-Бич,Делрей-Біч,Делреј Бич,דלריי ביץ,دلراي بيتش,دلری بیچ، فلوریدا,डेल्रे बीच,デルレイビーチ,德拉海灘', 26.4614600, -80.0728200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131478, 'Deltona', 'Deltona', 'Deltona,de er tuo na,deltana,dltwna,dltwna  flwryda,Делтона,دلتونا,دلتونا، فلوریدا,डेल्टना,დელტონა,德尔托纳', 28.9005400, -81.2636700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131479, 'Desoto Lakes', 'Desoto Lakes', '', 27.3714300, -82.4898200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131480, 'Destin', 'Destin', 'DSI,Dester,Destin,VPS,de si tan,destina,dstyn  flwryda,dystn,Дестин,دستین، فلوریدا,ديستن,डेस्टिन,德斯坦', 30.3935300, -86.4957800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131481, 'Doctor Phillips', 'Doctor Phillips', '', 28.4494500, -81.4922900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131482, 'Doral', 'Doral', 'Doral,dorala,duo la,dwral,dwral  flwryda,Дорал,دورال,دورال، فلوریدا,डोराल,多拉', 25.8195400, -80.3553300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131483, 'Dover', 'Dover', 'Dover,Довер', 27.9941900, -82.2195300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131484, 'Dundee', 'Dundee', 'Dandi,Dendi,dandi,dandy,dandy  flwryda,dui ti,Данди,Денди,داندي,داندی، فلوریدا,डन्डी,敦提', 28.0225200, -81.6192400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131485, 'Dunedin', 'Dunedin', 'Danedin,Danidin,Dunedin,Jonesboro,da ni ding,dandyn  flwryda,dywndn  flwryda,Данедин,Данидин,داندین، فلوریدا,ديوندن، فلوريدا,达尼丁', 28.0199000, -82.7732300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131486, 'Dunnellon', 'Dunnellon', '', 29.0491400, -82.4609300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131487, 'Eagle Lake', 'Eagle Lake', 'Igl Lejk,aygl lyk  flwryda,ayjl lyk,igala leka,ying hu,Игл Лејк,إيجل ليك,ایگل لیک، فلوریدا,इगल लेक,鹰湖', 27.9783600, -81.7564700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131488, 'East Lake', 'East Lake', '', 28.1108500, -82.6948200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131489, 'East Milton', 'East Milton', '', 30.6151900, -87.0216300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131490, 'East Palatka', 'East Palatka', '', 29.6583000, -81.5984100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131491, 'East Pensacola Heights', 'East Pensacola Heights', '', 30.4288100, -87.1799700, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131492, 'East Perrine', 'East Perrine', '', 25.6087200, -80.3389400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131493, 'Eastpoint', 'Eastpoint', '', 29.7366000, -84.8785200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131494, 'Eatonville', 'Eatonville', 'Itonvil,Itonvill,aytwnfyl,itanabhila,yi dun wei er,Итонвил,Итонвилл,إيتونفيل,ایتون‌ویل، فلوریدا,इटनभिल,伊顿维尔', 28.6147200, -81.3806200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131495, 'Edgewater', 'Edgewater', '', 28.9888800, -80.9022800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131496, 'Edgewood', 'Edgewood', 'Edzvud,ai qi wu de,ajwwd  flwryda,aydjwwd,ejvuda,Еџвуд,إيدجوود,اجوود، فلوریدا,ایجووڈ، فلوریڈا,एज्वूड,埃奇伍德', 28.4861200, -81.3722900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131497, 'Eglin Village', 'Eglin Village', 'Eglin,Ehglin,Эглин', 30.4629800, -86.5394000, 'US', '2009-03-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131498, 'Egypt Lake-Leto', 'Egypt Lake-Leto', 'Egypt Lake-Leto,Egypt Lake-Leto CDP', 28.0176900, -82.5061900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131499, 'El Portal', 'El Portal', 'El Portal,ai er bo te,al bwrtal,al pwrtal  flwryda,ela portala,Ел Портал,إل بورتال,ال پورتال، فلوریدا,एल पोर्टल,艾尔波特', 25.8553700, -80.1931000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131500, 'Elfers', 'Elfers', '', 28.2166800, -82.7223200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131501, 'Ellenton', 'Ellenton', '', 27.5217100, -82.5276000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131502, 'Englewood', 'Englewood', 'Ehnglvud,Inglvud,eng-geul-udeu,enjelavuda,Инглвуд,Энглвуд,एंजेलवूड,엥글우드', 26.9620100, -82.3526000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131503, 'Ensley', 'Ensley', '', 30.5188100, -87.2727500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131504, 'Estero', 'Estero', 'Estero,Istero,estero,Естеро,Истеро,एस्तेरो', 26.4381400, -81.8067500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131505, 'Eustis', 'Eustis', 'Justis,awstys  flwryda,you si di si,yustisa,ywstys,Јустис,اوستیس، فلوریدا,يوستيس,युस्तिस,尤斯蒂斯', 28.8527700, -81.6853500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131506, 'Fairview Shores', 'Fairview Shores', '', 28.5911100, -81.3942400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131507, 'Feather Sound', 'Feather Sound', '', 27.9007900, -82.6734900, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131508, 'Fellsmere', 'Fellsmere', 'Felsmir,fei er si mi er,fylzmyr,phellsmera,Фелсмир,فلس‌مر، فلوریدا,فيلزمير,फेल्ल्स्मेर,费尔斯米尔', 27.7678100, -80.6014400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131509, 'Fern Park', 'Fern Park', '', 28.6491600, -81.3511800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131510, 'Fernandina Beach', 'Fernandina Beach', 'Amelia Beach,Egmont Town,Fernandina,Fernandina Beach,Fernandina Bich,fei nan di na bi qi,frnandyna bych  flwryda,frnandyna bytsh,pharn''yandina bica,Фернандина Бич,فرناندينا بيتش,فرناندینا بیچ، فلوریدا,फर्न्यांडिना बीच,费南迪纳比奇', 30.6696800, -81.4625900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131511, 'Ferry Pass', 'Ferry Pass', 'Feri Pas,Ferri-Pass,pheri pasa,Фери Пас,Ферри-Пасс,फेरी पास', 30.5102000, -87.2124700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131512, 'Fish Hawk', 'Fish Hawk', '', 27.8505800, -82.2109200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131513, 'Five Points', 'Five Points', '', 30.2091200, -82.6373500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131514, 'Flagami', 'Flagami', '', 25.7623200, -80.3161600, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131515, 'Flagler Beach', 'Flagler Beach', 'Flagler Bich,flaghlr bytsh,flglr bych  flwryda,fu la ge lei hai tan,phlyagalara bica,Флаглер Бич,فلاغلر بيتش,فلگلر بیچ، فلوریدا,फ्ल्यागलर बीच,弗拉格勒海滩', 29.4749800, -81.1270000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131516, 'Fleming Island', 'Fleming Island', '', 30.0933000, -81.7189800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131517, 'Floral City', 'Floral City', '', 28.7499900, -82.2967600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131518, 'Florida City', 'Florida City', 'Florida Siti,Urbo Florido,flwryda syty,flwryda syty  flwryda,fu luo li da shi,phlorida siti,Флорида Сити,فلوريدا سيتي,فلوریدا سیتی، فلوریدا,फ्लोरिडा सिटी,佛罗里达市', 25.4478900, -80.4792200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131519, 'Florida Ridge', 'Florida Ridge', '', 27.5803100, -80.3867200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131520, 'Forest City', 'Forest City', '', 28.6667800, -81.4433400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131521, 'Fort Lauderdale', 'Fort Lauderdale', 'FLL,Fort Lauderdale,Fort Loderdeil,Fort Loderdeilas,Fort Loderdejl,Fort Lodurdejl,Fort-Loderdejl,Fortloderdeila,Ft. Lauderdale,f xr tlxde xrdel,fotorodaderu,fwrt ladrdyl  flwryda,fwrt lawdrdal,lao de dai er bao,pharta la''udaradela,phorta lodaradela,poteulodeodeil,pwrt lwdrdyyl,Форт Лодердејл,Форт Лодърдейл,Форт-Лодердейл,פורט לודרדייל,فورت لادردیل، فلوریدا,فورت لاودردال,فورٹ لاؤڈرڈیل,فورٹ لاوڈرڈیل، فلوریڈا,फर्ट लाउदरदेल,फोर्ट लॉडरडेल,ฟอร์ตลอเดอร์เดล,フォートローダーデール,劳德代尔堡,포트로더데일', 26.1223100, -80.1433800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131522, 'Fort Meade', 'Fort Meade', 'Fort Mid,fwrt myd,fwrt myd  flwryda,mi de bao,pharta mida,Форт Мид,فورت ميد,فورت مید، فلوریدا,फर्ट मीड,米德堡', 27.7522500, -81.8017500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131523, 'Fort Myers', 'Fort Myers', 'FMY,Fort Majers,Fort Myers,Fort-Maers,Ft. Myers,Myers,fotomaiyazu,fwrt mayrz,fwrt mayrz  flwryda,mai er zi bao,pharta mayarsa,poteumaieoseu,Форт Мајерс,Форт-Маєрс,فورت مايرز,فورت مایرز، فلوریدا,फर्ट मायर्स,フォートマイヤーズ,麥爾茲堡,포트마이어스', 26.6216800, -81.8405900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131524, 'Fort Myers Beach', 'Fort Myers Beach', 'Crescent Beach,Fort Majers Bich,Fort Myers Beach,Fort-Majers-Bich,fwrt mayrz bych  flwryda,fwrt mayrz bytsh,mai er si bao hai tan,pharta mayarsa bica,Форт Мајерс Бич,Форт-Майерс-Бич,فورت مايرز بيتش,فورت مایرز بیچ، فلوریدا,फर्ट मायर्स बीच,迈尔斯堡海滩', 26.4527100, -81.9501100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131525, 'Fort Myers Shores', 'Fort Myers Shores', '', 26.7092400, -81.7459200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131526, 'Fort Pierce', 'Fort Pierce', 'FPR,Fort Pirs,Fort-Pirs,Ft. Pierce,fwrt byrs,fwrt pyrs  flwryda,pharta piyarsa,pi er si bao,Форт Пирс,Форт-Пірс,فورت بيرس,فورت پیرس، فلوریدا,फर्ट पियर्स,匹尔斯堡', 27.4467100, -80.3256100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131527, 'Fort Walton Beach', 'Fort Walton Beach', 'Camp Walton,Fort Volton Bich,Fort Walton Beach,Fort-Volton-Bich,VPS,fwrt waltwn bych  flwryda,fwrt waltwn bytsh,hua er dun bao tan,pharta valatana bica,Форт Волтон Бич,Форт-Волтон-Біч,فورت والتون بيتش,فورت والتون بیچ، فلوریدا,फर्ट वालटन बीच,华尔顿堡滩', 30.4207700, -86.6193900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131528, 'Fountainebleau', 'Fountainebleau', 'Fountainbleau', 25.7728800, -80.3478300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131529, 'Freeport', 'Freeport', 'Friport,frybwrt,frypwrt  flwryda,phriporta,zi you gang,Фрипорт,فريبورت,فری پورٹ، فلوریڈا,فریپورت، فلوریدا,फ्रीपोर्ट,自由港', 30.4982500, -86.1360500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131530, 'Frostproof', 'Frostproof', 'Frostproof,Frostpruf,Keystone City,frwstbrwf,fu luo si te pu lu fu,phrastaprupha,Фростпруф,فراست‌پروف، فلوریدا,فروستبروف,फ्रस्टप्रूफ,弗罗斯特普鲁夫', 27.7458600, -81.5306300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131531, 'Fruit Cove', 'Fruit Cove', '', 30.1110700, -81.6417600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131532, 'Fruitland Park', 'Fruitland Park', '', 28.8613800, -81.9064700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131533, 'Fruitville', 'Fruitville', '', 27.3297700, -82.4576000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131534, 'Fuller Heights', 'Fuller Heights', '', 27.9091900, -81.9981400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131535, 'Fussels Corner', 'Fussels Corner', '', 28.0541900, -81.8606400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131536, 'Gainesville', 'Gainesville', 'GNV,Gainesopolis,Gainesville,Geinsvilis,Gejnsvil,Gejnsvill,Hog Town,ga''insabhila,gai en si wei er,geinjeubil,geinzubiru,ghynzfyl,gynzwyl  flwryda,gyynswwyl,Гейнсвил,Гейнсвилл,Гейнсвілл,Гејнсвил,גיינסוויל,غينزفيل,گینزویل، فلوریدا,गाइन्सभिल,ゲインズビル,蓋恩斯維爾,게인즈빌', 29.6516300, -82.3248300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131537, 'Gandy', 'Gandy', '', 27.8685000, -82.6161200, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131538, 'Gateway', 'Gateway', '', 26.5775700, -81.7503600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131539, 'Geneva', 'Geneva', 'Zheneva,Женева', 28.7397200, -81.1150600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131540, 'Gibsonia', 'Gibsonia', '', 28.1147400, -81.9736900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131541, 'Gibsonton', 'Gibsonton', 'Gibsonton,Gibtown', 27.8536400, -82.3825900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131542, 'Gifford', 'Gifford', '', 27.6753100, -80.4092200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131543, 'Gladeview', 'Gladeview', '', 25.8392600, -80.2356000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131544, 'Glencoe', 'Glencoe', '', 29.0258200, -80.9720000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131545, 'Glenvar Heights', 'Glenvar Heights', '', 25.7076000, -80.3256100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131546, 'Golden Gate', 'Golden Gate', '', 26.1878700, -81.6950900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131547, 'Golden Glades', 'Golden Glades', '', 25.9117600, -80.2003300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131548, 'Goldenrod', 'Goldenrod', 'Golden Rod Station,Goldenrod', 28.6102800, -81.2886800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131549, 'Gonzalez', 'Gonzalez', '', 30.5815800, -87.2913600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131550, 'Gotha', 'Gotha', '', 28.5277800, -81.5231300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131551, 'Goulding', 'Goulding', '', 30.4429800, -87.2224700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131552, 'Goulds', 'Goulds', '', 25.5626100, -80.3822800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131553, 'Graceville', 'Graceville', 'Grejsvil,ge lei si wei er,ghrysfyl,gresabhila,Грејсвил,غريسفيل,گریس‌ویل، فلوریدا,ग्रेसभिल,格雷斯维尔', 30.9568500, -85.5166000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131554, 'Green Cove Springs', 'Green Cove Springs', 'Grin Kouv Springs,ghryn kwf sbrnghz,grina kobha springas,gryn kww aspryngz  flwryda,lu wan wen quan,Грин Коув Спрингс,غرين كوف سبرنغز,گرین کوو اسپرینگز، فلوریدا,گرین کوو سپرنگز، فلوریڈا,ग्रीन कोभ स्प्रिङ्गस्,绿湾温泉', 29.9919100, -81.6781500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131555, 'Greenacres City', 'Greenacres City', 'Greenacres,Greenacres City', 26.6236800, -80.1253200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131556, 'Gretna', 'Gretna', '', 30.6171400, -84.6599100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131557, 'Grove City', 'Grove City', '', 26.9142300, -82.3270400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131558, 'Groveland', 'Groveland', 'Grovland,ge luo fu lan,ghrwfland,grobhalyanda,grwwlnd  flwryda,Гровланд,غروفلاند,گروولند، فلوریدا,ग्रोभल्यान्ड,格罗夫兰', 28.5580500, -81.8511900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131559, 'Gulf Breeze', 'Gulf Breeze', 'Gulf Breeze,Pensacola Shores,Town Point', 30.3571400, -87.1638600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131560, 'Gulf Gate Estates', 'Gulf Gate Estates', '', 27.2517300, -82.5147100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131561, 'Gulfport', 'Gulfport', 'Galfport,Galfporta,Gulf Port,Gulfport,galphaporta,ge er fu bo te,ghwlfbwrt,Галфпорт,Галфпорта,غولفبورت,گالف‌پورت، فلوریدا,گلف پورٹ، فلوریڈا,गल्फपोर्ट,格尔夫波特', 27.7483600, -82.7034300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131562, 'Haines City', 'Haines City', 'Khejns Siti,hai en si cheng,hynz syty  flwryda,Хејнс Сити,هينز سيتي، فلوريدا,هینز سیتی، فلوریدا,海恩斯城', 28.1145000, -81.6200900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131563, 'Hallandale Beach', 'Hallandale Beach', 'Hallandale,Khalandejl Bich,ha lun dai er hai tan,halandyl bych,halandyl bytsh,halyandela,Халандејл Бич,هالانديل بيتش,هالاندیل بیچ,हल्यांडेल,哈伦代尔海滩', 25.9812000, -80.1483800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131564, 'Harbor Bluffs', 'Harbor Bluffs', '', 27.9094700, -82.8276000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131565, 'Harbour Heights', 'Harbour Heights', '', 26.9908900, -82.0023100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131566, 'Harlem', 'Harlem', '', 26.7375700, -80.9509000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131567, 'Harlem Heights', 'Harlem Heights', '', 26.5161900, -81.9278700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131568, 'Havana', 'Havana', 'Gavana,Khavana,ha wa na,habhana,hafana,hawana,Гавана,Хавана,هافانا,هاوانا,हभाना,哈瓦那', 30.6238100, -84.4146300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131569, 'Haverhill', 'Haverhill', 'Khaverkhill,Хаверхилл', 26.6911800, -80.1200400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131570, 'Hawthorne', 'Hawthorne', 'Hawthorn,Hawthorne,Khotorn,hahtharna,hawthwrn,huo sang,hwthwrn,Хоторн,هاوثورن,هوثورن,हःथर्न,霍桑', 29.5919100, -82.0873200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131571, 'Hawthorne', 'Hawthorne', '', 28.7613800, -81.8709100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131572, 'Heathrow', 'Heathrow', '', 28.7633300, -81.3722500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131573, 'Hernando', 'Hernando', '', 28.8999800, -82.3745400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131574, 'Hernando Beach', 'Hernando Beach', '', 28.4694400, -82.6592700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131575, 'Hialeah', 'Hialeah', 'Hajalija,Hialeah,Khajalia,Khajalija,hai e li ya,haiaria,haieollia,hayali''ah,hyalya  flwryda,hyalyh,Хайалиа,Хаялия,Хаяліа,Хајалија,هياليه,هیالیا، فلوریدا,ہیالیاہ، فلوریڈا,ہیالیح,हायालिआः,ハイアリア,海厄利亞,하이얼리아', 25.8576000, -80.2781100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131576, 'Hialeah Gardens', 'Hialeah Gardens', 'Khajalija Gardens,hayali''ah gardensa,hyalya gardnz  flwryda,hyalyh ghardnz,Хајалија Гарденс,هياليه غاردنز,هیالیا گاردنز، فلوریدا,हायालिआः गार्डेन्स', 25.8651000, -80.3245000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131577, 'High Springs', 'High Springs', 'Khaj Springs,gao quan,ha''i springas,hay aspryngz  flwryda,hay sbrnghz,Хај Спрингс,هاي سبرنغز,های اسپرینگز، فلوریدا,हाइ स्प्रिङ्गस्,高泉', 29.8269100, -82.5967800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131578, 'Highland Beach', 'Highland Beach', '', 26.3995200, -80.0656000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131579, 'Highland City', 'Highland City', '', 27.9653000, -81.8778600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131580, 'Hiland Park', 'Hiland Park', 'Highland City,Hiland Park', 30.2010300, -85.6268700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131581, 'Hill ''n Dale', 'Hill ''n Dale', 'Hill ''n Dale,Hill and Dale', 28.5197200, -82.2992600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131582, 'Hilliard', 'Hilliard', '', 30.6910700, -81.9173300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131583, 'Hillsboro Beach', 'Hillsboro Beach', '', 26.2939700, -80.0789300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131584, 'Hobe Sound', 'Hobe Sound', 'Khob Saund,hoba sa''unda,Хоб Саунд,होब साउन्ड', 27.0595000, -80.1364300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131585, 'Holden Heights', 'Holden Heights', '', 28.4966700, -81.3878500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131586, 'Holiday', 'Holiday', '', 28.1877900, -82.7395500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131587, 'Holley', 'Holley', '', 30.4468600, -86.9069100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131588, 'Holly Hill', 'Holly Hill', '', 29.2435900, -81.0375600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131589, 'Hollywood', 'Hollywood', 'Gollivud,HWO,Hollywood,Hollywood by the Sea,Kholivud,Khollivud,halivuda,halliudeu,halywwd  flwryda,hao lai wu,hariuddo,hwlywwd,Голливуд,Голлівуд,Холивуд,Холливуд,הוליווד,هالیوود، فلوریدا,هوليوود,ہالی ووڈ، فلوریڈا,ہولی وڈ,हलिवूड,ハリウッド,好萊塢,할리우드', 26.0112000, -80.1494900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131590, 'Holmes Beach', 'Holmes Beach', 'Holmes Beach,Ilexhurst', 27.4953200, -82.7109300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131591, 'Homestead', 'Homestead', 'Gomsted,HST,Homestead,Khomsted,homasteda,huo mu si te de,hwmstd  flwryda,hwmstyd,Гомстед,Хомстед,هومستد، فلوریدا,هومستيد,होमस्टेड,霍姆斯特德', 25.4687200, -80.4775600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131592, 'Homosassa', 'Homosassa', '', 28.7813700, -82.6151000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131593, 'Homosassa Springs', 'Homosassa Springs', '', 28.8035900, -82.5759300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131594, 'Howie In The Hills', 'Howie In The Hills', 'Howey,Howey in the Hills,Howey-In-The-Hills,Howey-in-the-Hills,Howie In The Hills', 28.7169400, -81.7734100, 'US', '2016-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131595, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 28.3644500, -82.6934300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131596, 'Hunters Creek', 'Hunters Creek', '', 28.3605600, -81.4222900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131597, 'Hypoluxo', 'Hypoluxo', '', 26.5664600, -80.0533700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131598, 'Immokalee', 'Immokalee', 'IMM,Immokali,Imokali,im''mokyali,Иммокали,Имокали,इम्मोक्याली', 26.4186900, -81.4173000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131599, 'Indialantic', 'Indialantic', 'Indialantik,Indijalantik,andyalanktyk,ayndyalantyk  flwryda,indiyalantika,yin di ya lan ti,Индиалантик,Индијалантик,إنديالانكتيك,ایندیالانتیک، فلوریدا,इन्डियालांटिक,印第亚兰提', 28.0894600, -80.5656100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131600, 'Indian Harbour Beach', 'Indian Harbour Beach', 'Indijan Kharbor Bich,andyan harbr bytsh,ayndyn harbr bych  flwryda,indiyana harbara bica,yin du gang kou hai tan,Индијан Харбор Бич,إنديان هاربر بيتش,ایندین هاربر بیچ، فلوریدا,इन्डियन हार्बर बीच,印度港口海滩', 28.1489000, -80.5883900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131601, 'Indian River Estates', 'Indian River Estates', '', 27.3644900, -80.3097700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131602, 'Indian River Shores', 'Indian River Shores', '', 27.7167000, -80.3842200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131603, 'Indian Rocks Beach', 'Indian Rocks Beach', 'Indian Rocks,Indian Rocks Beach', 27.8753000, -82.8512200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131604, 'Indian Shores', 'Indian Shores', 'Indian Rocks Beach South Shore,Indian Shores', 27.8628000, -82.8484400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131605, 'Indiantown', 'Indiantown', 'Indian Town,Indiantown', 27.0272800, -80.4856100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131606, 'Inglis', 'Inglis', '', 29.0302500, -82.6687200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131607, 'Interlachen', 'Interlachen', 'Inter Lachen,Interlachen,Interlaken', 29.6242100, -81.8925600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131608, 'Inverness', 'Inverness', 'Invernes,anfyrns,aynwrns  flwryda,inbeoneseu,inbharnes,yin fu nei si,Инвернес,إنفيرنس,اینورنس، فلوریدا,इन्भर्नेस्,因弗内斯,인버네스', 28.8358200, -82.3303700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131609, 'Inwood', 'Inwood', '', 28.0369700, -81.7650800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131610, 'Iona', 'Iona', '', 26.5203600, -81.9639800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131611, 'Islamorada', 'Islamorada', 'Ajlamorada,Islamorada,Islamorada Village,Islamorada  Village of Islands,a''ilamorada,aslamwrada,ayslamwrada  flwryda,yi si la mo la,Ајламорада,إسلامورادا,ایسلامورادا، فلوریدا,आइलामोराडा,伊斯拉摩拉', 24.9243000, -80.6278400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131612, 'Ives Estates', 'Ives Estates', '', 25.9623100, -80.1767100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131613, 'Jacksonville', 'Jacksonville', 'Ceksonvill,Cow Creek,Cow Ford,Cowford,Dzeksonvil,Dzeksonvila,Dzeksonvilis,Dzhaks"nvil,Dzhehksanvil,Dzhehksonvill,Dzheksonvill,Džeksonvila,Džeksonvilis,Iacsoniapolis,Iacsonvilla,JAX,Jacksonville,Tzaksonvil,Wakka Pilatka,Zhehksonvill,gqswnwwyl,jaegseunbil,jaikasanavila,jaiksanavila,jakcanvil,jakswnfyl,jakusonbiru,jeksanavhila,jeksonvili,jie ke xun wei er,jyakasanabhila,jyaksanabhila,jyksn wyl,Τζάκσονβιλ,Џексонвил,Джаксънвил,Джексонвілл,Джэксанвіл,Джэксонвилл,Жэксонвилл,Ջեքսոնվիլ,גקסונוויל,جاكسونفيل,جکسون‌ویل,جیکسن ویل,जॅक्सनव्हिल,जैक्सनविल,ज्याकसनभिल,জ্যাক্সনভিল,ਜੈਕਸਨਵਿਲ,ஜாக்சன்வில்,แจ็กสันวิลล์,ჯექსონვილი,ジャクソンビル,杰克逊维尔,잭슨빌', 30.3321800, -81.6556500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131614, 'Jacksonville Beach', 'Jacksonville Beach', 'Dzeksonvil Bich,Jacksonville Beach,Pablo Beach,jakswnfyl bytsh,jie ke xun wei er hai tan,jyakasanabhila bica,Џексонвил Бич,جاكسونفيل بيتش,جکسون‌ویل بیچ، فلوریدا,جککسونویل بیچ، فلوریڈا,ज्याकसनभिल बीच,杰克逊维尔海滩', 30.2946900, -81.3931400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131615, 'Jan-Phyl Village', 'Jan-Phyl Village', 'Jan Phyl Village', 28.0147400, -81.7717500, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131616, 'Jasmine Estates', 'Jasmine Estates', '', 28.2930600, -82.6901000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131617, 'Jasper', 'Jasper', 'Dzasper,gu si pa,jasbr,jspr  flwryda,jyaspara,Џаспер,جاسبر,جسپر، فلوریدا,جسپر، فلوریڈا,ज्यास्पर,贾斯帕', 30.5182700, -82.9481900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131618, 'Jensen Beach', 'Jensen Beach', 'Dzhensen-Bich,Jensen Bich,jensena bica,Јенсен Бич,Дженсен-Бич,जेन्सेन बीच', 27.2544900, -80.2297700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131619, 'June Park', 'June Park', '', 28.0722400, -80.6800600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131620, 'Juno Beach', 'Juno Beach', 'Dzhuno-Bich,Dzuno Bich,juno bica,jwnw bych  flwryda,jwnw bytsh,zhu nuo hai tan,Џуно Бич,Джуно-Бич,جونو بيتش,جونو بیچ، فلوریدا,جونو بیچ، فلوریڈا,जुनो बीच,朱诺海滩', 26.8797800, -80.0533700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131621, 'Jupiter', 'Jupiter', 'Dzhjupiter,Dzupiter,Jupiter,Júpiter,jupita,jwbytr  flwryda,zhu bi te,zhwpytr  flwryda,Џупитер,Джюпітер,Юпитер,جوبيتر، فلوريدا,ژوپیتر، فلوریدا,ジュピター,朱庇特', 26.9342200, -80.0942100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131622, 'Kathleen', 'Kathleen', '', 28.1208500, -82.0231400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131623, 'Kendale Lakes', 'Kendale Lakes', 'Kendale Lakes', 25.7081600, -80.4070000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131624, 'Kendall', 'Kendall', 'Kendal,Kendall,kendala,Кендал,Кендалл,केन्डल', 25.6792700, -80.3172700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131625, 'Kendall Green', 'Kendall Green', '', 26.2539700, -80.1239300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131626, 'Kenneth City', 'Kenneth City', '', 27.8155800, -82.7201000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131627, 'Kensington Park', 'Kensington Park', '', 27.3594900, -82.4964900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131628, 'Key Biscayne', 'Key Biscayne', 'Ki Biskeinas,Ki Biskejn,bi si kan wan,ki bis''sayana,ky byskayn,ky byskyn  flwryda,Ки Бискејн,كي بيسكاين,کی بیسکین، فلوریدا,की बिस्सायन,比斯坎湾', 25.6937100, -80.1628200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131629, 'Key Largo', 'Key Largo', 'Cayo Largo,KYL,Key Largo,Ki-Largo,ki largo,Ки-Ларго,की लार्गो', 25.0865200, -80.4472800, 'US', '2013-03-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131630, 'Key West', 'Key West', 'Allentown,Bone Island,Caio Os,Cayo Hueso,Cayo Huesso,Cayo de Huesos,EYW,Gorad Ki-Uehst,Key West,Keywest,Ki Vest,Ki Vestas,Ki-Uehst,Ki-Vest,ji wei si te,ki vesta,kiu~esuto,kiweseuteu,ky wst  flwryda,ky wyst,qy wst,Горад Кі-Уэст,Ки Вест,Ки-Уэст,Кі-Вест,קי וסט,كي ويست,کی وست، فلوریدا,की वेस्ट,კი-უესტი,キーウェスト,基韋斯特,키웨스트', 24.5552400, -81.7816300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131631, 'Keystone', 'Keystone', '', 28.1558500, -82.6212100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131632, 'Keystone Heights', 'Keystone Heights', 'Kistoun Khajts,kistona ha''itsa,kystwn hayts,ti xing gao de,Кистоун Хајтс,كيستون هايتس,کی‌استون هایتس، فلوریدا,कीस्टोन हाइट्स,梯形高地', 29.7860800, -82.0314900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131633, 'Kings Point', 'Kings Point', '', 26.4453500, -80.1397700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131634, 'Kissimmee', 'Kissimmee', 'Kisimi,Kissimmee,Kissimmi,ji xi mi,kishimi,kisime,kysymy,kysymy  flwryda,qysymy,Кисими,Киссимми,Кіссіммі,קיסימי,كيسيمي,کیسیمی، فلوریدا,किसिमे,キシミー,基西米', 28.3046800, -81.4166700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131635, 'LaBelle', 'LaBelle', 'La Belle,Label,Labelle,bei r,labele,labl,labl  flwryda,Лабел,لابل,لابل، فلوریدا,لابیلی، فلورایڈا,लाबेले,贝儿', 26.7617300, -81.4384100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131636, 'Lacoochee', 'Lacoochee', '', 28.4658300, -82.1720300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131637, 'Lady Lake', 'Lady Lake', 'Ledi-Lejk,Lejdi Lejk,ledi leka,lydy lyk,lydy lyk  flwryda,sheng mu hu,Леди-Лейк,Лејди Лејк,ليدي ليك,لیدی لیک، فلوریدا,لیڈی لیک، فلوریڈا,लेडी लेक,圣母湖', 28.9174900, -81.9228600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131638, 'Laguna Beach', 'Laguna Beach', 'Laguna Bich,Лагуна Бич', 30.2396500, -85.9241000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131639, 'Lake Alfred', 'Lake Alfred', 'Lejk Alfred,hu a er fu lei de,leka alphreda,lyk alfrd  flwryda,lyk alfryd,Лејк Алфред,ليك ألفريد,لیک الفرد، فلوریدا,لیک الفریڈ، فلورایڈا,लेक अल्फ्रेड,湖阿尔弗雷德', 28.0919600, -81.7234100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131640, 'Lake Belvedere Estates', 'Lake Belvedere Estates', '', 26.6892300, -80.1333800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131641, 'Lake Butler', 'Lake Butler', 'Lejk Batler,btlr lyk,lai ke ba te lei,leka batlara,lyk batlr  shhrstan ywnywn  flwryda,Лејк Батлер,بتلر ليك,لیک باتلر، شهرستان یونیون، فلوریدا,لیک بوٹلیر، یونین کاؤنٹی، فلورایڈا,लेक बट्लर,萊克巴特勒', 30.0227400, -82.3395600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131642, 'Lake Butler', 'Lake Butler', 'Lake Butler,Lake Butter', 28.5016700, -81.5409100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131643, 'Lake City', 'Lake City', 'LCQ,Lejk Siti,lai ke cheng,leka siti,lyk syty,lyk syty  flwryda,Лејк Сити,ليك سيتي,لیک سٹی، فلورایڈا,لیک سیتی، فلوریدا,लेक सिटी,莱克城', 30.1896800, -82.6392900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131644, 'Lake Clarke Shores', 'Lake Clarke Shores', '', 26.6453400, -80.0758800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131645, 'Lake Forest', 'Lake Forest', 'Lesnoe ozero,Лесное озеро', 25.9775900, -80.1831000, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131646, 'Lake Hamilton', 'Lake Hamilton', '', 28.0444600, -81.6278500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131647, 'Lake Helen', 'Lake Helen', 'Lejk Khelen,hu hai lun,leka helena,lyk hln  flwryda,lyk hylyn,Лејк Хелен,ليك هيلين,لیک هلن، فلوریدا,لیک ہیلین، فلورایڈا,लेक हेलेन,湖海伦', 28.9808200, -81.2333900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131648, 'Lake Lorraine', 'Lake Lorraine', '', 30.4415900, -86.5652300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131649, 'Lake Lucerne', 'Lake Lucerne', '', 25.9650900, -80.2414400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131650, 'Lake Magdalene', 'Lake Magdalene', '', 28.0741800, -82.4717600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131651, 'Lake Panasoffkee', 'Lake Panasoffkee', 'Lake Panasoffkee,Panasoffkee,Panasofkee', 28.7558200, -82.0948100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131652, 'Lake Park', 'Lake Park', 'Kelsey City,Lake Park,Lejk Park,Lejk-Park,hu gong yuan,leka parka,lyk bark,lyk park  flwryda,Лейк-Парк,Лејк Парк,ليك بارك,لیک پارک، فلورایڈا,لیک پارک، فلوریدا,लेक पार्क,湖公园', 26.8003400, -80.0664300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131653, 'Lake Placid', 'Lake Placid', 'Lake Placid,Lake Stearns,Lejk Plesid,Lejk-Plehsid,leka plasida,lyk blasyd,lyk plsyd  flwryda,pu lai xi de hu,Лейк-Плэсид,Лејк Плесид,ليك بلاسيد,لیک پلسید، فلوریدا,लेक प्लासिड,普莱西德湖', 27.2931000, -81.3628500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131654, 'Lake Sarasota', 'Lake Sarasota', '', 27.2925500, -82.4376000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131655, 'Lake Mary', 'Lake Mary', 'Lejk Meri,leka meri,lyk mary,lyk mry  flwryda,ma li hu,Лејк Мери,ليك ماري,لیک مری، فلوریدا,لیک میری، فلورایڈا,लेक मेरी,玛丽湖', 28.7588800, -81.3178400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131656, 'Lake Wales', 'Lake Wales', 'Lejk Vejls,leka velsa,lyk wylz,lyk wylz  flwryda,wei er shi hu,Лејк Вејлс,ليك ويلز,لیک ویلز، فلورایڈا,لیک ویلز، فلوریدا,लेक वेल्स,威尔士湖', 27.9014100, -81.5859100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131657, 'Lake Worth', 'Lake Worth', 'Lejk Vort,lai ke wo si,leka vartha,lyk wrth  flwryda,lyk wwrth,Лејк Ворт,ليك وورث,لیک ورتھ، فلورایڈا,لیک ورث، فلوریدا,लेक वर्थ,莱克沃思', 26.6170800, -80.0723100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131658, 'Lake Worth Corridor', 'Lake Worth Corridor', 'Lake Worth Corridor,Lake Worth Corridor CDP', 26.6164900, -80.1010200, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131659, 'Lakeland', 'Lakeland', 'LAL,Lakeland,Lejkland,Lejklend,lai ke lan,leikeullaendeu,lekalyanda,lykland,reikurando,Лейкленд,Лејкланд,ليكلاند,لیک لینڈ، فلورایڈا,لیک‌لند، فلوریدا,लेकल्यान्ड,レイクランド,莱克兰,레이클랜드', 28.0394700, -81.9498000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131660, 'Lakeland Highlands', 'Lakeland Highlands', '', 27.9597500, -81.9500800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131661, 'Lakes by the Bay', 'Lakes by the Bay', '', 25.5723300, -80.3253300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131662, 'Lakeside', 'Lakeside', '', 30.1299600, -81.7681500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131663, 'Lakewood Park', 'Lakewood Park', '', 27.5430900, -80.4022700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131664, 'Lakewood Park', 'Lakewood Park', '', 27.4814300, -80.3742200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131665, 'Land O'' Lakes', 'Land O'' Lakes', '', 28.2189000, -82.4575900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131666, 'Lantana', 'Lantana', 'Lantana,Lantona', 26.5867400, -80.0519900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131667, 'Largo', 'Largo', 'Largo,la ge,larghw,largo,largw  flwryda,Ларго,Ларґо,لارغو,لارگو، فلورایڈا,لارگو، فلوریدا,लार्गो,拉哥', 27.9097900, -82.7884200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131668, 'Lauderdale Lakes', 'Lauderdale Lakes', 'Loderdejl Lejks,lao de dai er hu,laundaradeladela leksa,lawdrdyl lyks,lwdrdyl lyks  flwryda,Лодердејл Лејкс,لاودرديل ليكس,لودردیل لیکس، فلوریدا,लौन्डरडेलडेल लेक्स,劳德代尔湖', 26.1664700, -80.2083800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131669, 'Lauderdale-by-the-Sea', 'Lauderdale-by-the-Sea', 'Lauderdale,Lauderdale by the sea', 26.1920300, -80.0964300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131670, 'Lauderhill', 'Lauderhill', '', 26.1403600, -80.2133800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131671, 'Laurel', 'Laurel', '', 27.1437800, -82.4615800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131672, 'Lealman', 'Lealman', 'Lealman,Lellman,Lellman Station', 27.8211400, -82.6792700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131673, 'Lecanto', 'Lecanto', '', 28.8516500, -82.4876000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131674, 'Leesburg', 'Leesburg', 'LEE,Lizburg,li si bao,lijbarga,lysbrg  flwryda,lysbrgh,Лизбург,ليسبرغ,لیزبرگ، فلوریڈا,لیسبرگ، فلوریدا,लीज्बर्ग,利斯堡', 28.8108200, -81.8778600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131675, 'Lehigh Acres', 'Lehigh Acres', 'Leeland Heights,Lehigh,Lehigh Acres', 26.6253500, -81.6248000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131676, 'Leisure City', 'Leisure City', '', 25.4953900, -80.4292200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131677, 'Lely', 'Lely', '', 26.1006500, -81.7284200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131678, 'Lely Resort', 'Lely Resort', '', 26.0809300, -81.6978600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131679, 'Lighthouse Point', 'Lighthouse Point', 'Lighthouse PT', 26.2756400, -80.0872700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131680, 'Limestone Creek', 'Limestone Creek', '', 26.9428400, -80.1411500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131681, 'Live Oak', 'Live Oak', 'Lajv Ouk,la''ibha oka,layf awk,layw awk  flwryda,li fu ao ke,Лајв Оук,لايف أوك,لایو اوک، فلوریدا,लाइभ ओक,利夫奥克', 30.2949500, -82.9840200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131682, 'Lochmoor Waterway Estates', 'Lochmoor Waterway Estates', '', 26.6442400, -81.9098100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131683, 'Lockhart', 'Lockhart', '', 28.6194400, -81.4425700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131684, 'Longboat Key', 'Longboat Key', 'Longbout Ki,langabota ki,langbwt ky  flwryda,lwnghbwt ky,zhang chuan jiao,Лонгбоут Ки,لانگبوت کی، فلوریدا,لونغبوت كي,लङ्गबोट की,长船礁', 27.4125400, -82.6589900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131685, 'Longwood', 'Longwood', 'Longvud,lang wu de,langavuda,lwnghwwd,Лонгвуд,لانگ‌وود، فلوریدا,لونغوود,लङ्गवूड,朗伍德', 28.7030500, -81.3384000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131686, 'Loughman', 'Loughman', '', 28.2419600, -81.5667400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131687, 'Lower Grand Lagoon', 'Lower Grand Lagoon', '', 30.1440900, -85.7507600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131688, 'Loxahatchee Groves', 'Loxahatchee Groves', 'Loxahatchee,Loxahatchee Groves,The Groves,Town of Loxahatchee Groves', 26.6836800, -80.2797700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131689, 'Lutz', 'Lutz', 'Lutc,Лутц', 28.1511200, -82.4614800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131690, 'Lynn Haven', 'Lynn Haven', 'Lin Khejven,layn hafn,lin en bi feng gang,lina hyabhena,lyn hywn  flwryda,Лин Хејвен,لاين هافن,لین هیون، فلوریدا,لین ہیون، فلوریڈا,लीन ह्याभेन,林恩避风港', 30.2454800, -85.6482600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131691, 'Macclenny', 'Macclenny', 'Macclenny,Maclenny,Makleni,McClenny,mai ke lun ni,maklyny,myakakleni,Маклени,ماكليني,مک‌کلنی، فلوریدا,میکلینی، فلورائیڈا,म्याकक्लेनी,麦克伦尼', 30.2821800, -82.1220600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131692, 'Madeira Beach', 'Madeira Beach', '', 27.7980800, -82.7973200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131693, 'Madison', 'Madison', 'Madison,Medison,Mehdison,madyswn,mai di xun,mdyswn  flwryda,myadisana,Мадисон,Медисон,Мэдисон,ماديسون,مدیسون، فلوریدا,میڈیسون، فلورائیڈا,म्याडिसन,麦迪逊', 30.4693800, -83.4129300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131694, 'Maitland', 'Maitland', 'Lake Maitland,Maitland,Mejtland,me''italyanda,mei te lan,mytland,Мејтланд,ميتلاند,میت‌لند، فلوریدا,मेइटल्यांड,梅特兰', 28.6277800, -81.3631200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131695, 'Malabar', 'Malabar', '', 28.0036300, -80.5656100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131696, 'Malone', 'Malone', '', 30.9576900, -85.1621500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131697, 'Manasota Key', 'Manasota Key', '', 26.9253400, -82.3520400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131698, 'Manatee Road', 'Manatee Road', 'Manatee Road,Manattee Road', 29.5130200, -82.9142900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131699, 'Mango', 'Mango', '', 27.9797400, -82.3064800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131700, 'Mangonia Park', 'Mangonia Park', 'Mangonija Park,Mangonija-Park,mang gu a yuan,manghwnya bark,mangwnya park  flwryda,myangoniya parka,Мангония-Парк,Мангонија Парк,مانغونيا بارك,مانگونیا پارک، فلوریدا,म्यांगोनिया पार्क,芒谷阿园', 26.7603400, -80.0736500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131701, 'Marathon', 'Marathon', 'MTH,Marathon,Maraton,ma la song,marathwn,maratwn  flwryda,myarathana,Маратон,ماراتون، فلوریدا,ماراثون,میراتھن، فلوریڈا,म्याराथन,马拉松', 24.7137500, -81.0903500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131702, 'Marco', 'Marco', 'Collier City North,Malco,Marco,Marco Island', 25.9726000, -81.7289800, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131703, 'Marco Island', 'Marco Island', 'MRK,Marko Ajland,ma ke dao,marko a''ilyanda,markw ayland,markw aylnd  flwryda,Марко Ајланд,ماركو آيلاند,مارکو آیلند، فلوریدا,मार्को आइल्यान्ड,马可岛', 25.9412100, -81.7184200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131704, 'Margate', 'Margate', 'Margejt,ma gai te,marageta,marghyt,margyt  flwryda,Маргейт,Маргејт,مارغيت,مارگیت، فلوریدا,मारगेट,马盖特', 26.2445300, -80.2064400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131705, 'Marianna', 'Marianna', 'Marijana,ma li an na,mariyana,maryana,maryana  flwryda,Маријана,ماريانا,ماریانا، فلوریدا,ماریانا، فلوریڈا,मारियाना,玛丽安娜', 30.7743600, -85.2268700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131706, 'Mary Esther', 'Mary Esther', '', 30.4101500, -86.6650900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131707, 'Masaryktown', 'Masaryktown', '', 28.4416700, -82.4570400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131708, 'Mascotte', 'Mascotte', '', 28.5783300, -81.8867500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131709, 'Mayo', 'Mayo', 'Mejo,mayo,mayw,mayw  flwryda,mei ao,Мейо,Мејо,مايو,مایو، فلوریدا,मायो,梅奥', 30.0530000, -83.1748600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131710, 'McGregor', 'McGregor', '', 26.5609100, -81.9145300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131711, 'Meadow Woods', 'Meadow Woods', '', 28.3855600, -81.3664600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131712, 'Medulla', 'Medulla', '', 27.9678000, -81.9734200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131713, 'Melbourne', 'Melbourne', 'MLB,Mel''burn,Melborn,Melbourne,Melburn,melbarna,meruborun,mlbwrn,mlbwrn  flwryda,mo er ben,Мелборн,Мелбурн,Мелбърн,Мельбурн,מלבורן,ملبورن,ملبورن، فلوریدا,ملبورن، فلوریڈا,मेल्बर्न,メルボルン,墨爾本', 28.0836300, -80.6081100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131714, 'Melbourne Beach', 'Melbourne Beach', 'Mel''burn-Bich,Melborn-Bich,Melburn Bich,melbarna bica,mlbwrn bych  flwryda,mlbwrn bytsh,mo er ben hai tan,Мелборн-Бич,Мелборн-Біч,Мелбурн Бич,Мельбурн-Бич,ملبورن بيتش,ملبورن بیچ، فلوریدا,मेल्बर्न बीच,墨尔本海滩', 28.0683500, -80.5603300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131715, 'Melrose Park', 'Melrose Park', '', 26.1134200, -80.1933800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131716, 'Memphis', 'Memphis', 'Memfis,Мемфис', 27.5358700, -82.5612100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131717, 'Merritt Island', 'Merritt Island', '', 28.5391700, -80.6720000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131718, 'Mexico Beach', 'Mexico Beach', '', 29.9480900, -85.4199500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131719, 'Miami', 'Miami', 'Gorad Majami,MIA,Maiami,Majami,Majamis,Mayami,Miami,Miamia,Miamo,mai a mi,mai ya mei,maiaemi,maiami,mayami,mayamy,miyami,myamy,myamy  flwryda,Μαϊάμι,Горад Маямі,Майами,Маями,Маямі,Мајами,Մայամի,מיאמי,مايامى,ميامي,میامی,میامی، فلوریدا,मायामी,मियामी,মায়ামি,માયામિ,மயாமி,మయామి,ಮಿಯಾಮಿ,ไมแอมี,မိုင်ယာမီမြို့,მაიამი,ማያሚ,マイアミ,迈阿密,邁亞美,邁阿密,마이애미', 25.7742700, -80.1936600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131720, 'Miami Beach', 'Miami Beach', 'Majami Bich,Majami Bijch,Majami-Bich,Miami Beach,Saut Bich,mai a mi hai tan,maiaemibichi,maiamibichi,mayami bica,myamy bych  flwryda,myamy bytsh,Майами-Бич,Маями Бийч,Маямі-Біч,Мајами Бич,Саут Бич,ميامي بيتش,میامی بیچ، فلوریدا,میامی بیچ، فلوریڈا,मायामी बीच,マイアミビーチ,迈阿密海滩,마이애미비치', 25.7906500, -80.1300500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131721, 'Miami Gardens', 'Miami Gardens', '', 25.9798100, -80.2025500, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131722, 'Miami Gardens', 'Miami Gardens', 'Majami Gardens,Majami-Gardens,mai a mi hua yuan,maiaemigadeunseu,maiamigadenzu,mayami gardensa,myamy gardnz  flwryda,myamy ghardnz,Майами-Гарденс,Маямі-Ґарденс,Мајами Гарденс,ميامي غاردنز,میامی گاردنز، فلوریدا,میامی گارڈنز,میامی گارڈنز، فلوریڈا,मायामी गार्डेन्स,マイアミガーデンズ,迈阿密花园,마이애미가든스', 25.9420400, -80.2456000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131723, 'Miami Lakes', 'Miami Lakes', 'Majami Lejks,Majami-Lejks,mai a mi hu,mayami leksa,myamy lyks,myamy lyks  flwryda,Майами-Лейкс,Мајами Лејкс,ميامي ليكس,میامی لیکس، فلوریدا,मायामी लेक्स,迈阿密湖', 25.9087100, -80.3086600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131724, 'Miami Shores', 'Miami Shores', 'Majami Shors,mai a mi hai an,mayami sorsa,myamy shwrz,myamy shwrz  flwryda,Мајами Шорс,ميامي شورز,میامی شورز، فلوریدا,मायामी शोर्स,迈阿密海岸', 25.8631500, -80.1928300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131725, 'Miami Springs', 'Miami Springs', 'Country Club Estates,Majami Springs,Miami Springs,mai a mi si pu lin si,mayami springas,myamy aspryngz  flwryda,myamy sbrnghz,Мајами Спрингс,ميامي سبرنغز,میامی اسپرینگز، فلوریدا,میامی سپرنگس، فلوریڈا,मायामी स्प्रिङ्गस्,迈阿密斯普林斯', 25.8223200, -80.2895000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131726, 'Micco', 'Micco', '', 27.8805800, -80.5003300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131727, 'Midway', 'Midway', '', 30.4954800, -84.4543500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131728, 'Midway', 'Midway', '', 28.7902700, -81.2309000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131729, 'Middleburg', 'Middleburg', 'Middlberg,Midlberg,Midlburg,midalabarga,Миддлберг,Мидлбург,Мідлберґ,मिडलबर्ग', 30.0688500, -81.8603800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131730, 'Milton', 'Milton', 'Mil''ton,Milton,mi er dun,milatana,myltwn,myltwn  flwryda,Милтон,Мильтон,ملٹن، فلوریڈا,ميلتون,میلتون، فلوریدا,मिलटन,米尔顿', 30.6324100, -87.0396900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131731, 'Mims', 'Mims', '', 28.6652700, -80.8447800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131732, 'Minneola', 'Minneola', 'Miniola,mine''ola,ming ni,mynywla,mynywla  flwryda,Миниола,مينيولا,مینیولا، فلوریدا,मिनेओला,明尼', 28.5744400, -81.7461900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131733, 'Miramar', 'Miramar', 'Miramar,mi la ma er,mirama,miramara,myramar,myramar  flwryda,Мирамар,Мірамар,ميرامار,میرامار، فلوریدا,मिरामार,ミラマー,米拉馬爾', 25.9873100, -80.2322700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131734, 'Miramar Beach', 'Miramar Beach', '', 30.3743700, -86.3585600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131735, 'Molino', 'Molino', '', 30.7240800, -87.3141400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131736, 'Monticello', 'Monticello', 'Montiselo,mantyslw  flwryda,meng di sai luo,montiselo,mwntysylw,Монтисело,مانتیسلو، فلوریدا,مونتيسيلو,मोन्टिसेलो,蒙蒂塞洛', 30.5451500, -83.8713000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131737, 'Montverde', 'Montverde', '', 28.6002800, -81.6739600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131738, 'Moore Haven', 'Moore Haven', 'Mur Khejven,maw r he wen,mu er hei wen,mura hyabhena,mwr hafn,mwr hywn  flwryda,Мур Хејвен,مور هافن,مور هیون، فلوریدا,मूर ह्याभेन,มัวร์เฮเวน,穆尔黑文', 26.8331200, -81.0931200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131739, 'Mount Dora', 'Mount Dora', 'Maunt Dora,Mt. Dora,ma''unta dora,mant dwra  flwryda,mwnt dwra,shan duo la,Маунт Дора,مانت دورا، فلوریدا,مونت دورا,माउन्ट डोरा,山多拉', 28.8024900, -81.6445200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131740, 'Mount Plymouth', 'Mount Plymouth', '', 28.8080500, -81.5331300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131741, 'Mulberry', 'Mulberry', '', 27.8953000, -81.9734200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131742, 'Myrtle Grove', 'Myrtle Grove', '', 30.4210300, -87.3074700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131743, 'Naples', 'Naples', 'APF,Neapol'',Neapolis,Nejpls,Nejplz,Nejpuls,na bu lei si,neipuruzu,nepalsa,nyblz,nyplz  flwryda,Неаполь,Нейплз,Нейплс,Нейпълс,Нејплс,نيبلز,نیپلز، فلوریدا,नेपल्स,ネイプルズ,那不勒斯', 26.1423400, -81.7959600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131744, 'Naples Manor', 'Naples Manor', '', 26.0887000, -81.7262000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131745, 'Naples Park', 'Naples Park', '', 26.2617500, -81.8092500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131746, 'Naranja', 'Naranja', '', 25.5181600, -80.4228300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131747, 'Navarre', 'Navarre', '', 30.4015900, -86.8635700, 'US', '2014-10-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131748, 'Neptune Beach', 'Neptune Beach', '', 30.3119100, -81.3964700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131749, 'New Port Richey', 'New Port Richey', 'Nju Port Richi,n''yu porta rici,nyw bwrt rytshy,nyw pwrt rychy  flwryda,xin li qi gang,Њу Порт Ричи,نيو بورت ريتشي,نیو پورت ریچی، فلوریدا,न्यु पोर्ट रिची,新里奇港', 28.2441800, -82.7192700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131750, 'New Smyrna Beach', 'New Smyrna Beach', 'Nea Smyrni,New Smyrna,New Smyrna Beach,Nju Smirna Bich,n''yu smirna bica,nyw asmyrna bych  flwryda,nyw smyrna bytsh,xin shi mai na hai tan,Νέα Σμύρνη,Њу Смирна Бич,نيو سميرنا بيتش,نیو اسمیرنا بیچ، فلوریدا,न्यु स्मीर्ना बीच,新士麦那海滩', 29.0258200, -80.9270000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131751, 'Newberry', 'Newberry', 'Njuberi,n''yuberi,niu bei li,nywbry  flwryda,nywbyry,Њубери,نيوبيري,نیوبری، فلوریدا,न्युबेरी,纽贝里', 29.6463500, -82.6065000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131752, 'Niceville', 'Niceville', 'Boggy,Najsvil,Niceville,Valparaiso,na''isabhila,naysfyl,ni si wei er,Најсвил,نائیسویل، فلوریڈا,نايسفيل,نایس‌ویل، فلوریدا,नाइसभिल,尼斯维尔', 30.5168600, -86.4821700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131753, 'Nocatee', 'Nocatee', 'Nakate,Nocatee', 27.1603300, -81.8823100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131754, 'Nokomis', 'Nokomis', '', 27.1192200, -82.4442600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131755, 'Norland', 'Norland', 'Norland,Норланд', 25.9489800, -80.2122700, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131756, 'North Andrews Gardens', 'North Andrews Gardens', '', 26.1914700, -80.1442100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131757, 'North Bay Village', 'North Bay Village', 'Nort Bej Vilidz,North Bay,North Bay Village,bei wan cun,nartha be bhileja,nwrth bay fylyj,nwrth by wylj  flwryda,Норт Беј Вилиџ,شمالی بے ولیج، فلوریڈا,نورث باي فيليج,نورث بی ویلج، فلوریدا,नर्थ बे भिलेज,北湾村', 25.8462100, -80.1539400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131758, 'North Brooksville', 'North Brooksville', '', 28.5730500, -82.4081500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131759, 'North DeLand', 'North DeLand', 'North De Land', 29.0494300, -81.2981200, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131760, 'North Fort Myers', 'North Fort Myers', 'North Ft. Myers', 26.6672900, -81.8800900, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131761, 'North Key Largo', 'North Key Largo', '', 25.2673400, -80.3233900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131762, 'North Lauderdale', 'North Lauderdale', 'Nort Loderdejl,Nort-Loderdejl,bei lao de dai er,nartha laundaradeladela,nwrth lawdrdyl,nwrth lwdrlyl  flwryda,Норт Лодердејл,Норт-Лодердейл,نورث لاودرديل,نورث لودرلیل، فلوریدا,नर्थ लौन्डरडेलडेल,北劳德代尔', 26.2173000, -80.2258800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131763, 'North Miami', 'North Miami', 'Nort Majami,Nort-Majami,bei mai a mi,nartha mayami,noseumaiaemi,nwrth myamy,nwrth myamy  flwryda,Норт Мајами,Норт-Маямі,شمالی میامی، فلوریڈا,نورث ميامي,نورث میامی، فلوریدا,नर्थ मायामी,北迈阿密,노스마이애미', 25.8900900, -80.1867100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131764, 'North Miami Beach', 'North Miami Beach', 'Nort Majami Bich,Nort-Majami-Bich,bei mai a mi hai tan,nartha mayami bica,nwrth myamy bych  flwryda,shmal myamy bytsh,Норт Мајами Бич,Норт-Маямі-Біч,شمال ميامي بيتش,شمالی میامی بیچ، فلوریڈا,نورث میامی بیچ، فلوریدا,नर्थ मायामी बीच,北迈阿密海滩', 25.9331500, -80.1625500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131765, 'North Palm Beach', 'North Palm Beach', 'Nort Pam Bich,bei zong lu tan,nartha pama bica,nwrth balm bytsh,nwrth palm bych  flwryda,Норт Пам Бич,نورث بالم بيتش,نورث پالم بیچ، فلوریدا,नर्थ पाम बीच,北棕榈滩', 26.8175600, -80.0819900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131766, 'North Port', 'North Port', 'Nort Pojnt,Nort-Port,North Port,North Port Charlotte,bei gang,nartha porta,nosupoto,nwrth bwrt,nwrth pwrt  flwryda,Норт Појнт,Норт-Порт,نورث بورت,نورث پورت، فلوریدا,नर्थ पोर्ट,ノースポート,北港', 27.0442200, -82.2359300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131767, 'North Redington Beach', 'North Redington Beach', '', 27.8161400, -82.8206600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131768, 'North River Shores', 'North River Shores', '', 27.2175500, -80.2697700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131769, 'North Sarasota', 'North Sarasota', '', 27.3739300, -82.5184300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131770, 'Oak Hill', 'Oak Hill', '', 28.8644300, -80.8545000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131771, 'Oak Ridge', 'Oak Ridge', '', 28.4711200, -81.4245200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131772, 'Oakland', 'Oakland', 'Oklend,Oukland,ao ke lan,awkland,awklnd  flwryda,okalyanda,Окленд,Оукланд,أوكلاند,اوکلند، فلوریدا,اوکلینڈ، فلوریڈا,ओकल्यान्ड,奥克兰', 28.5550000, -81.6331300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131773, 'Oakland Park', 'Oakland Park', 'Oklend-Park,Oukland Park,ao ke lan gong yuan,awkland bark,awklnd park  flwryda,okalyanda parka,Окленд-Парк,Оукланд Парк,أوكلاند بارك,اوکلند پارک، فلوریدا,ओकल्यान्ड पार्क,奥克兰公园', 26.1723100, -80.1319900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131774, 'Ocala', 'Ocala', 'OCF,Ocala,Ocola,Okala,ao ka la,awkala,awkala  flwryda,okaella,okala,okara,Окала,أوكالا,اوکالا، فلوریدا,ओकाला,オカラ,奥卡拉,오캘라', 29.1872000, -82.1400900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131775, 'Ocean City', 'Ocean City', '', 30.4410300, -86.6135600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131776, 'Ocean Ridge', 'Ocean Ridge', '', 26.5270200, -80.0483700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131777, 'Ocoee', 'Ocoee', 'Okoi,ao ke yi,awkwy,awkwyy  flwryda,oko''i,Окои,أوكوي,اوکوئی، فلوریدا,ओकोई,奥科伊', 28.5691700, -81.5439600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131778, 'Odessa', 'Odessa', 'Odessa,Одесса', 28.1939000, -82.5917600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131779, 'Ojus', 'Ojus', '', 25.9484300, -80.1506000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131780, 'Okeechobee', 'Okeechobee', 'OBE,Okechobee,Okeechobee,Okichobi,Tantic,ao ji qiao bi,awkychwby  flwryda,awkytshwby,okicobi,Окичоби,أوكيتشوبي,اوکیچوبی، فلوریدا,ओकीचोबी,奥基乔比', 27.2439300, -80.8297800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131781, 'Oldsmar', 'Oldsmar', 'Oldmars,Oldsmar,Tampashores,ao de ma er,awldsmar,awldzmar  flwryda,oldsmara,Олдсмар,أولدسمار,اولدزمار، فلوریدا,ओल्ड्स्मार,奥德马尔', 28.0341800, -82.6651000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131782, 'Olga', 'Olga', '', 26.7189600, -81.7123000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131783, 'Olympia Heights', 'Olympia Heights', 'Olympia Heights,Olympic Heights', 25.7267700, -80.3553300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131784, 'Opa-locka', 'Opa-locka', 'Apalocka,Opa Locka,Opa-Locka,Opa-locka,Opa-loka,Opalocka,ao pa luo ka,awba lwka,awpa-lwka  flwryda,opyaloka,Опа-лока,أوبا لوكا,اوپا-لوکا، فلوریدا,ओप्यालोका,奥帕洛卡', 25.9023200, -80.2503300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131785, 'Orange City', 'Orange City', '', 28.9488800, -81.2986700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131786, 'Orange Park', 'Orange Park', '', 30.1660700, -81.7064800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131787, 'Orangetree', 'Orangetree', '', 26.2928600, -81.5884200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131788, 'Oriole Beach', 'Oriole Beach', '', 30.3738100, -87.0913600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131789, 'Orlando', 'Orlando', 'ORL,Orlandas,Orlando,Orlando i Florida,Orlanto,ao lan duo,aralyando,awrlandw,awrlndw  flwryda,ollaendo,oralamdo,orando,orlando,orlanto,Ορλάντο,Орландо,Օռլանդո,אורלנדו,أورلاندو,اورلندو، فلوریدا,اورلینڈو,اورلینڈو، فلوریڈا,अरल्यान्दो,ओरलँडो,ઓર્લાન્ડો,ஒர்லாண்டோ,ออร์แลนโด,ორლანდო,オーランド,奥兰多,올랜도', 28.5383400, -81.3792400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131790, 'Orlovista', 'Orlovista', '', 28.5383400, -81.4603500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131791, 'Ormond Beach', 'Ormond Beach', 'New Britain,Ormond,Ormond Beach,Ormond Bich,ao meng de hai tan,armanda bica,awrmnd bych  flwryda,awrmwnd bytsh  flwryda,Ормонд Бич,اورمند بیچ، فلوریدا,اورموند بيتش، فلوريدا,अर्मंड बीच,奥蒙德海滩', 29.2858100, -81.0558900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131792, 'Ormond-by-the-Sea', 'Ormond-by-the-Sea', 'North Peninsula,Ormond-by-the-Sea', 29.3491400, -81.0664500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131793, 'Osprey', 'Osprey', '', 27.1961600, -82.4903700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131794, 'Oviedo', 'Oviedo', 'Ov''edo,Ovido,ao wei ye duo,awfydw,obhi''edo,Овидо,Овьедо,أوفيدو,اوویه‌دو، فلوریدا,ओभिएडो,奥维耶多', 28.6700000, -81.2081200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131795, 'Pace', 'Pace', '', 30.5993600, -87.1610800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131796, 'Pahokee', 'Pahokee', 'PHK,Pakhoki,bahwky,pa huo ji,pahoki,pahwky  flwryda,Пахоки,باهوكي,پاهوکی، فلوریدا,पाहोकी,帕霍基', 26.8200600, -80.6653400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131797, 'Palatka', 'Palatka', 'Palatka,Pilatka,balatka,pa la te ka,palatka,palatka  flwryda,Палатка,بالاتكا,پالاتکا، فلوریدا,पालाट्का,帕拉特卡', 29.6485800, -81.6375800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131798, 'Palm Aire', 'Palm Aire', '', 26.2061900, -80.1917100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131799, 'Palm Bay', 'Palm Bay', 'Palm Bay,Palm Bej,Palm-Bej,balm bay,palm by  flwryda,pama be,pamubei,zong lu wan,Палм Беј,Палм-Бей,بالم باي,پالم بی، فلوریدا,पाम बे,パームベイ,棕榈湾', 28.0344600, -80.5886600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131800, 'Palm Beach', 'Palm Beach', 'Palm Beach,Palm Bich,Palm-Bich,balm bytsh,palm bych  flwryda,pama bica,pambichi,pamubichi,pʼlm byz,zong lu tan,Палм Бич,Палм-Бич,Палм-Біч,פאלם ביץ,بالم بيتش,پالم بیچ، فلوریدا,पाम बीच,パームビーチ,棕榈滩,팜비치', 26.7056200, -80.0364300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131801, 'Palm Beach Gardens', 'Palm Beach Gardens', 'Palm Bich Gardens,Palm-Bich-Gardens,balm bytsh ghardnz,palm bych gardnz  flwryda,pama bica gardensa,zong lu tan hua yuan,Палм Бич Гарденс,Палм-Бич-Гарденс,Палм-Біч-Ґарденс,بالم بيتش غاردنز,پالم بیچ گاردنز، فلوریدا,پام بیچ گارڈنز، فلوریڈا,पाम बीच गार्डेन्स,棕櫚灘花園', 26.8233900, -80.1386500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131802, 'Palm Beach Shores', 'Palm Beach Shores', '', 26.7781200, -80.0356000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131803, 'Palm City', 'Palm City', '', 27.1678300, -80.2661600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131804, 'Palm Coast', 'Palm Coast', 'Palm Koust,Palm-Kost,balm kwst,palm kwst  flwryda,pama kosta,zong lu hai an,Палм Коуст,Палм-Кост,بالم كوست,پالم کوست، فلوریدا,پام کوسٹ، فلوریڈا,पाम कोस्ट,棕榈海岸', 29.5849700, -81.2078400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131805, 'Palm Harbor', 'Palm Harbor', 'Palm Harbor,Palm-Kharbor,Pam Kharbor,Southerland,Sutherland,pama harbara,Палм-Харбор,Пам Харбор,पाम हार्बर', 28.0780700, -82.7637100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131806, 'Palm Springs', 'Palm Springs', 'Palm Springs,balm sbrnghz,palm aspryngz  flwryda,pama springas,zong lu quan,Палм Спрингс,بالم سبرنغز,پالم اسپرینگز، فلوریدا,پام سپرنگز، فلوریڈا,पाम स्प्रिङ्गस्,棕榈泉', 26.6359000, -80.0961500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131807, 'Palm Springs North', 'Palm Springs North', 'Palm Springs North', 25.9351000, -80.3338300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131808, 'Palm Valley', 'Palm Valley', '', 30.1774600, -81.3875800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131809, 'Palmetto', 'Palmetto', 'Palmeto,balmytw,pa er mei tuo,palmeto,palmtw  flwryda,Палмето,بالميتو,پالمتو، فلوریدا,पाल्मेटो,帕尔梅托', 27.5214300, -82.5723200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131810, 'Palmetto Bay', 'Palmetto Bay', 'Pameto Bej,balmytw bay,palmtw by  flwryda,zong lu wan,Памето Беј,بالميتو باي,پالمتو بی، فلوریدا,棕榈湾', 25.6217700, -80.3247700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131811, 'Palmetto Estates', 'Palmetto Estates', '', 25.6214900, -80.3620000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131812, 'Palmona Park', 'Palmona Park', '', 26.6864600, -81.8964800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131813, 'Panama City', 'Panama City', 'ECP,PFN,Panama,Panama City,Panama Siti,Panama-Siti,ba na ma cheng,bnma syty,paeneomasiti,panama siti,panama syty  flwryda,panamashiti,Панама,Панама Сити,Панама-Сити,Панама-Сіті,بنما سيتي,پاناما سٹی، فلوریڈا,پاناما سیتی، فلوریدا,पनामा सिटी,パナマシティ,巴拿马城,패너마시티', 30.1594600, -85.6598300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131814, 'Panama City Beach', 'Panama City Beach', 'Panama City Beach,Panama Siti Bich,ba na ma shi hai tan,bnma syty bytsh,paeneomasitibichi,panama siti bica,panama syty bych  flwryda,Панама Сити Бич,بنما سيتي بيتش,پاناما سیتی بیچ، فلوریدا,पनामा सिटी बीच,巴拿马市海滩,패너마시티비치', 30.1765900, -85.8054900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131815, 'Paradise Heights', 'Paradise Heights', '', 28.6236100, -81.5439600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131816, 'Parker', 'Parker', 'Parker,barkr,pa ke,parkara,parkr  flwryda,Паркер,باركر,پارکر، فلوریدا,پارکر، فلوریڈا,पार्कर,帕克', 30.1310400, -85.6032600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131817, 'Parkland', 'Parkland', '', 26.3100800, -80.2372700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131818, 'Pebble Creek', 'Pebble Creek', '', 28.1483500, -82.3456500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131819, 'Pelican Bay', 'Pelican Bay', '', 26.2312000, -81.8056400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131820, 'Pembroke Park', 'Pembroke Park', 'Pembrok-Park,Pembruk Park,bymbrwk bark,pembroka parka,peng bu luo ke gong yuan,pmbrwk park  flwryda,Пемброк-Парк,Пембрук Парк,بيمبروك بارك,پمبروک پارک، فلوریدا,पेम्ब्रोक पार्क,彭布罗克公园', 25.9878700, -80.1747700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131821, 'Pembroke Pines', 'Pembroke Pines', 'Pembrok-Pajns,Pembroke Pines,Pembrouk Pajns,Pembruk Pajns,bymbrwk baynz,pembeulokeupainjeu,pembroka pa''insa,penburokupainzu,peng bu luo ke pai en si,pmbrwk paynz  flwryda,pmbrwk payynz,Пемброк-Пайнс,Пемброук Пайнс,Пембрук Пајнс,بيمبروك باينز,پمبروک پائینز,پمبروک پاینز، فلوریدا,پیمبروک پائنز، فلوریڈا,पेम्ब्रोक पाइन्स,ペンブロークパインズ,彭布羅克派恩斯,펨브로크파인즈', 26.0031500, -80.2239400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131822, 'Pensacola', 'Pensacola', 'PNS,Pansacolas,Panzacola,Pencocolos,Pensacola,Pensacola i Florida,Pensacolas,Pensakola,Pensicola,bynsakwla,peng sa ge la,peng sa ke la,pensakola,pensakora,penseokolla,pnsakwla  flwryda,Пенсакола,بينساكولا,پنساکولا، فلوریدا,पेन्साकोला,ペンサコーラ,彭萨科拉,彭薩哥拉,펜서콜라', 30.4213100, -87.2169100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131823, 'Perry', 'Perry', 'FPY,Peri,byry,pei li,peli,peri,pry  flwryda,Пери,بيري,پری، فلوریدا,پیری، فلوریڈا,पेरी,佩里,페리', 30.1176600, -83.5827400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131824, 'Pierson', 'Pierson', '', 29.2394200, -81.4656300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131825, 'Pine Castle', 'Pine Castle', '', 28.4719500, -81.3678500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131826, 'Pine Hills', 'Pine Hills', '', 28.5577800, -81.4534000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131827, 'Pine Island Center', 'Pine Island Center', '', 26.6136900, -82.1181500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131828, 'Pine Island Ridge', 'Pine Island Ridge', '', 26.0948100, -80.2739400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131829, 'Pine Manor', 'Pine Manor', '', 26.5728500, -81.8781400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131830, 'Pine Ridge', 'Pine Ridge', '', 28.9383100, -82.4734300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131831, 'Pine Ridge', 'Pine Ridge', '', 26.2306400, -81.7959200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131832, 'Pinecrest', 'Pinecrest', 'Pajnkrest,baynkryst,pa''inakresta,pai en ke lei si te,Пајнкрест,باينكريست,پاین‌کرست، فلوریدا,पाइनक्रेस्ट,派恩克雷斯特', 25.6670500, -80.3081100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131833, 'Pinellas Park', 'Pinellas Park', 'Pinelas Park,Pinellas City,Pinellas Park,Pinellas-Park,bynylas bark,pa''inallasa parka,paynlas park  flwryda,pi nei la si gong yuan,Пинелас Парк,Пінеллас-Парк,بينيلاس بارك,پاینلاس پارک، فلوریدا,पाइनlलस पार्क,皮内拉斯公园', 27.8428000, -82.6995400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131834, 'Pinewood', 'Pinewood', '', 25.8689800, -80.2169900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131835, 'Placid Lakes', 'Placid Lakes', '', 27.2414400, -81.4070200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131836, 'Plant City', 'Plant City', 'Plant Siti,blant syty,planta siti,plnt syty  flwryda,pu lan te cheng,Плант Сити,بلانت سيتي,پلنت سیتی، فلوریدا,प्लान्ट सिटी,普兰特城', 28.0188800, -82.1146900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131837, 'Plantation', 'Plantation', 'Plantacija,Plantejshn,Plantejshon,blantyshn,plantesana,plntyshn  flwryda,zhong zhi yuan,Плантация,Плантейшн,Плантејшон,بلانتيشن,پلانٹیشن، فلوریڈا,پلنتیشن، فلوریدا,प्लान्टेसन,种植园', 26.1342100, -80.2318400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131838, 'Plantation', 'Plantation', '', 24.9762400, -80.5522800, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131839, 'Plantation', 'Plantation', 'Plantacija,Плантация', 27.0681100, -82.3728700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131840, 'Plantation Mobile Home Park', 'Plantation Mobile Home Park', '', 26.7031200, -80.1322700, 'US', '2011-12-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131841, 'Poinciana', 'Poinciana', '', 28.1402900, -81.4584100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131842, 'Point Baker', 'Point Baker', '', 30.6901900, -87.0535800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131843, 'Polk City', 'Polk City', 'Polk Siti,bo ke cheng shi,bwlk syty,polka siti,pwlk syty  flwryda,Полк Сити,بولك سيتي,پولک سیتی، فلوریدا,पोल्क सिटी,波克城市', 28.1825100, -81.8239700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131844, 'Pompano Beach', 'Pompano Beach', 'PPM,Pompano,Pompano Beach,Pompano Bich,Pompano-Bich,bwmbanw syty,pang pa nuo bi qi,pompano bica,ponpanobichi,pwmpanw bych  flwryda,Помпано Бич,Помпано-Бич,Помпано-Біч,بومبانو سيتي,پومپانو بیچ، فلوریدا,پومپانو بیچ، فلوریڈا,पोम्पानो बीच,ポンパノビーチ,龐帕諾比奇', 26.2378600, -80.1247700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131845, 'Pompano Beach Highlands', 'Pompano Beach Highlands', '', 26.2828600, -80.1069900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131846, 'Ponce Inlet', 'Ponce Inlet', 'Pons Inlet,Pons-Inlet,bwns anlyt,pang sai jin,ponse inleta,pwns aynlt  flwryda,Понс Инлет,Понс-Инлет,بونس إنليت,پونس انلیٹ، فلوریڈا,پونس اینلت، فلوریدا,पोन्से इन्लेट,庞塞进', 29.0963700, -80.9370000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131847, 'Ponte Vedra Beach', 'Ponte Vedra Beach', 'Mineral City,Ponte Vedra Beach,Ponte-Vedra-Bich,Понте-Ведра-Бич', 30.2396900, -81.3856400, 'US', '2010-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131848, 'Port Charlotte', 'Port Charlotte', 'Port Sharlot,Port-Sharlott,porta sarlota,Порт Шарлот,Порт-Шарлотт,पोर्ट शार्लोट', 26.9761700, -82.0906400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131849, 'Port LaBelle', 'Port LaBelle', 'Port La Belle', 26.7564500, -81.4050800, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131850, 'Port Orange', 'Port Orange', '', 29.1383200, -80.9956100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131851, 'Port Richey', 'Port Richey', '', 28.2716800, -82.7195500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131852, 'Port Saint Joe', 'Port Saint Joe', 'Port St. Joe', 29.8118800, -85.3029700, 'US', '2017-05-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131853, 'Port Saint John', 'Port Saint John', '', 28.4769500, -80.7886700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131854, 'Port Saint Lucie', 'Port Saint Lucie', 'Port St. Lucie', 27.2939300, -80.3503300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131855, 'Port Salerno', 'Port Salerno', 'Port Salerno,Salerno', 27.1442200, -80.2006000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131856, 'Pretty Bayou', 'Pretty Bayou', '', 30.1965900, -85.6966000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131857, 'Princeton', 'Princeton', 'Prinston,Принстон', 25.5384400, -80.4089400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131858, 'Progress Village', 'Progress Village', '', 27.9003000, -82.3645400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131859, 'Punta Gorda', 'Punta Gorda', 'PGD,Panta Gorda,Punta-Gorda,bwnta ghwrda,peng ta ge er da,punta gorda,pwnta gwrda  flwryda,Панта Горда,Пунта-Ґорда,بونتا غوردا,پونتا گوردا، فلوریدا,पुन्टा गोर्डा,蓬塔戈尔达', 26.9297800, -82.0453700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131860, 'Punta Gorda Isles', 'Punta Gorda Isles', '', 26.9175600, -82.0784200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131861, 'Punta Rassa', 'Punta Rassa', 'Punta Rasa,Punta Rassa,Puntarasa,Puntarassa', 26.4878600, -82.0123100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131862, 'Quincy', 'Quincy', 'Kuinsi,Kvinsi,kun xi,kvinsi,kwynsy,kwyynsy  flwryda,Квинси,Куинси,كوينسي,کوئنسی، فلوریڈا,کوئینسی، فلوریدا,क्विन्सी,昆西', 30.5871400, -84.5832500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131863, 'Redington Beach', 'Redington Beach', '', 27.8086400, -82.8112100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131864, 'Redington Shores', 'Redington Shores', '', 27.8261400, -82.8289900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131865, 'Richmond Heights', 'Richmond Heights', 'Richmond Khajts,Richmond-Khajts,ricamanda ha''itsa,Ричмонд Хајтс,Ричмонд-Хайтс,रिचमंड हाइट्स', 25.6314900, -80.3689400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131866, 'Richmond West', 'Richmond West', 'Richmond West', 25.6105000, -80.4297100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131867, 'Ridge Manor', 'Ridge Manor', '', 28.5075000, -82.1703600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131868, 'Ridge Wood Heights', 'Ridge Wood Heights', '', 27.2872700, -82.5131500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131869, 'Ridgecrest', 'Ridgecrest', '', 27.8975000, -82.8052900, 'US', '2015-01-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131870, 'River Park', 'River Park', 'Port Saint Lucie-River Park', 27.3142100, -80.3472700, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131871, 'Riverview', 'Riverview', 'Riverv''ju,ribharabhyu,Ривервью,रिभरभ्यू', 27.8661400, -82.3264800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131872, 'Riviera Beach', 'Riviera Beach', 'Riviera,Riviera Beach,Rivijera Bich,li wei ai la hai tan,ribhi''era bica,ryfyyra bytsh,rywyra bych  flwryda,Ривијера Бич,ريفييرا بيتش,ریویرا بیچ، فلوریدا,रिभिएरा बीच,里维埃拉海滩', 26.7753400, -80.0581000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131873, 'Rock Island', 'Rock Island', 'Rok-Ajlend,Рок-Айленд', 26.1550900, -80.1769900, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131874, 'Rockledge', 'Rockledge', 'Rock Ledge,Rockledge,Rokledz,Rokledzh,luo ke lei zhi,rakaleja,rwklydj,Рокледж,Роклеџ,راک‌لج، فلوریدا,روكليدج,रकलेज,罗克雷治', 28.3508400, -80.7253300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131875, 'Roseland', 'Roseland', '', 27.8358600, -80.4931100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131876, 'Rotonda', 'Rotonda', 'Rotonda,Rotunda', 26.8836800, -82.2900900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131877, 'Royal Palm Beach', 'Royal Palm Beach', 'Rojal Pam Bich,huang jia zong lu tan,royala pama bica,rwyal balm bytsh,rwyal palm bych  flwryda,Ројал Пам Бич,رائل پام بیچ، فلوریڈا,رويال بالم بيتش,رویال پالم بیچ، فلوریدا,रोयल पाम बीच,皇家棕榈滩', 26.7084000, -80.2306000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131878, 'Royal Palm Estates', 'Royal Palm Estates', '', 26.6817300, -80.1250400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131879, 'Ruskin', 'Ruskin', 'Raskin,raskina,Раскин,रस्किन', 27.7208600, -82.4331500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131880, 'Safety Harbor', 'Safety Harbor', 'Sejfti Kharbor,an quan gang,sephti harbara,syfty harbr  flwryda,syfty harbwr,Сејфти Харбор,سفتے ہاربر، فلوریڈا,سيفتي هاربور,سیفتی هاربر، فلوریدا,सेफ्टी हार्बर,安全港', 27.9908500, -82.6931600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131881, 'Saint Augustine', 'Saint Augustine', 'Presidio de San Augustin,Saint Augustin,Saint Augustine,San Agustin,San Agustín,Sejnt-Ogastin,Sent-Ogastin,St. Augustine,UST,seinteuogeoseutin,senta agastina  phlorida,sentoogasutin,sheng ao gu si ding,snt agwstyn,syynt ʼwgwstyn,Сейнт-Огастін,Сент-Огастин,סיינט אוגוסטין,سنت آگوستین,सेन्त अगस्तिन  फ्लोरिदा,セントオーガスティン,聖奧古斯丁,세인트오거스틴', 29.8946900, -81.3145200, 'US', '2017-01-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131882, 'Saint Augustine Beach', 'Saint Augustine Beach', '', 29.8505300, -81.2653500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131883, 'Saint Augustine Shores', 'Saint Augustine Shores', '', 29.8108000, -81.3103500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131884, 'Saint Cloud', 'Saint Cloud', '', 28.2489000, -81.2811800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131885, 'Saint George', 'Saint George', '', 28.0564100, -82.7278800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131886, 'Saint James City', 'Saint James City', '', 26.4975800, -82.0784300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131887, 'Saint Leo', 'Saint Leo', '', 28.3372300, -82.2584200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131888, 'Saint Pete Beach', 'Saint Pete Beach', 'Saint Petersburg Beach,St. Pete Beach', 27.7253100, -82.7412100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131889, 'St. Petersburg', 'St. Petersburg', 'SPG,Saint Petersburg,St. Petersburg', 27.7708600, -82.6792700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131890, 'Samoset', 'Samoset', '', 27.4694800, -82.5414900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131891, 'San Antonio', 'San Antonio', 'San Antinio,San Antonio,San-Antonio,san antwnyw,sheng an dong ni ao,sn antwnyw  flwryda,syana entaniyo,Сан Антонио,Сан-Антонио,سان أنطونيو,سن آنتونیو، فلوریدا,स्यान एन्टनियो,圣安东尼奥', 28.3361100, -82.2745300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131892, 'San Carlos Park', 'San Carlos Park', '', 26.4673000, -81.8014700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131893, 'Sanibel', 'Sanibel', 'Sanibel,sa ni bei er,sanybl,snybl  flwryda,syanibela,Санибел,سانيبل,سنیبل، فلوریدا,स्यानिबेल,萨尼贝尔', 26.4489700, -82.0223100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131894, 'Sanford', 'Sanford', 'Fort Mellon,Mellonville,Sanford,Senford,saenpeodeu,sanfwrd,sang fu de,snfwrd  flwryda,syanpharda,Санфорд,Сенфорд,سانفورد,سنفورد، فلوریدا,स्यान्फर्ड,桑福德,샌퍼드', 28.8005500, -81.2731200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131895, 'Sarasota', 'Sarasota', 'SRQ,Sarasota,sa la suo ta,saeleosota,sarasota,saraswta,saraswta  flwryda,Сарасота,ساراسوتا,ساراسوتا، فلوریدا,सारासोटा,サラソータ,萨拉索塔,새러소타', 27.3364300, -82.5306500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131896, 'Sarasota Springs', 'Sarasota Springs', '', 27.3089400, -82.4795400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131897, 'Satellite Beach', 'Satellite Beach', 'Satelajt Bich,satylayt bytsh,stlayt bych  flwryda,syatela''ita bica,wei xing hai tan,Сателајт Бич,ساتيلايت بيتش,ستلایت بیچ، فلوریدا,स्याटेलाइट बीच,卫星海滩', 28.1761200, -80.5900500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131898, 'Sawgrass', 'Sawgrass', '', 30.1927400, -81.3706400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131899, 'Schall Circle', 'Schall Circle', '', 26.7156200, -80.1150400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131900, 'Scott Lake', 'Scott Lake', '', 25.9414800, -80.2319900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131901, 'Seaside', 'Seaside', 'Sisajd,Сисайд', 30.3210300, -86.1416100, 'US', '2009-03-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131902, 'Sebastian', 'Sebastian', 'Sebashchan,Sebastian,Sebastián,sai ba si di an,sbastyn  flwryda,sybastyan  flwryda,Себастіан,Себашчан,سباستین، فلوریدا,سيباستيان، فلوريدا,塞巴斯蒂安', 27.8164100, -80.4706100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131903, 'Sebring', 'Sebring', 'SEF,Sibring,sai bai ling,sbryng  flwryda,sebringa,sybryngh,Сибринг,سبرینگ، فلوریدا,سيبرينغ,सेब्रिंग,赛百灵', 27.4955900, -81.4409100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131904, 'Seffner', 'Seffner', '', 27.9836300, -82.2756500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131905, 'Seminole', 'Seminole', 'Seminol,sai mi nuo er,seminola,smynwl  flwryda,symynwl,Семинол,سمینول، فلوریدا,سيمينول,सेमिनोल,塞米诺尔', 27.8397500, -82.7912100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131906, 'Seminole Manor', 'Seminole Manor', '', 26.5836800, -80.1003200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131907, 'Sewall''s Point', 'Sewall''s Point', 'Sewall''s Point,Sewalls Point', 27.1994900, -80.2022700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131908, 'Shady Hills', 'Shady Hills', '', 28.4100000, -82.5428800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131909, 'Sharpes', 'Sharpes', '', 28.4322300, -80.7600500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131910, 'Siesta Key', 'Siesta Key', '', 27.2678500, -82.5452600, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131911, 'Silver Lake', 'Silver Lake', '', 28.8419300, -81.7984100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131912, 'Silver Springs Shores', 'Silver Springs Shores', 'Silver Springs', 29.1044200, -82.0206400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131913, 'Sky Lake', 'Sky Lake', '', 28.4572300, -81.3914600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131914, 'Sneads', 'Sneads', '', 30.7080100, -84.9255200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131915, 'South Bay', 'South Bay', '', 26.6639600, -80.7161700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131916, 'South Beach', 'South Beach', '', 27.5911500, -80.3442200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131917, 'South Bradenton', 'South Bradenton', '', 27.4631000, -82.5817600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131918, 'South Apopka', 'South Apopka', '', 28.6619400, -81.5095200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131919, 'South Brooksville', 'South Brooksville', '', 28.5358200, -82.3840300, 'US', '2016-01-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131920, 'South Daytona', 'South Daytona', '', 29.1658200, -81.0045000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131921, 'South Gate Ridge', 'South Gate Ridge', '', 27.2864400, -82.4967600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131922, 'South Highpoint', 'South Highpoint', '', 27.9169700, -82.7128800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131923, 'South Miami', 'South Miami', 'Saut Majami,nan mai a mi,sa''utha mayami,sauseumaiaemi,sawt myamy  flwryda,sawth myamy,Саут Мајами,ساوت میامی، فلوریدا,ساوث ميامي,साउथ मायामी,南迈阿密,사우스마이애미', 25.7076000, -80.2933800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131924, 'South Miami Heights', 'South Miami Heights', '', 25.5976100, -80.3806100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131925, 'South Palm Beach', 'South Palm Beach', '', 26.5889600, -80.0386500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131926, 'South Pasadena', 'South Pasadena', 'Coreytown,Juzhnaja Pasadena,South Pasadena,Южная Пасадена', 27.7550300, -82.7376000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131927, 'South Patrick Shores', 'South Patrick Shores', '', 28.2022300, -80.6095000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131928, 'South Sarasota', 'South Sarasota', '', 27.2861600, -82.5328800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131929, 'South Venice', 'South Venice', '', 27.0531100, -82.4242600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131930, 'Southchase', 'Southchase', '', 28.3930600, -81.3834000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131931, 'Southgate', 'Southgate', '', 27.3081000, -82.5098200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131932, 'Southwest Ranches', 'Southwest Ranches', 'Sautvest Ranchiz,xi nan nong chang,Саутвест Ранчиз,ساوت‌وست رنچز، فلوریدا,西南农场', 26.0587000, -80.3372700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131933, 'Spring Hill', 'Spring Hill', 'Spring Khil,Spring-Khill,springa hila,Спринг Хил,Спринг-Хилл,स्प्रिङ्ग हिल', 28.4768800, -82.5254600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131934, 'Springfield', 'Springfield', 'Springfild,sbrynghfyld,si pu lin fei er de,springaphilda,Спрингфилд,Спрінгфілд,اسپرینگ‌فیلد، فلوریدا,سبرينغفيلد,سپرنگفیلڈ، فلوریڈا,स्प्रिङ्गफिल्ड,སི་པི་རིང་ཧྥིལ་ཌི།,斯普林菲尔德', 30.1532600, -85.6113200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131935, 'Starke', 'Starke', 'Stark,astark  flwryda,si ta ke,stark,starki,Старк,استارک، فلوریدا,ستارك,स्टार्की,斯塔克', 29.9441300, -82.1098300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131936, 'Steinhatchee', 'Steinhatchee', 'Jena,Steinhatchee,Stephensville,Stewarts City', 29.6710600, -83.3876400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131937, 'Stock Island', 'Stock Island', '', 24.5670900, -81.7384200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131938, 'Stuart', 'Stuart', 'SUA,Stjuart,astwart  flwryda,seutyueoteu,si tu er te,stu''arta,stywart,Стјуарт,استوارت، فلوریدا,ستيوارت,स्टुआर्ट,斯图尔特,스튜어트', 27.1975500, -80.2528300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131939, 'Sugarmill Woods', 'Sugarmill Woods', '', 28.7322100, -82.5062100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131940, 'Sun City Center', 'Sun City Center', 'Greater Sun Center', 27.7180900, -82.3517600, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131941, 'Suncoast Estates', 'Suncoast Estates', '', 26.7117400, -81.8689700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131942, 'Sunny Isles Beach', 'Sunny Isles Beach', 'Sani Ajls Bich,Sanni-Ajls-Bich,Sunny Isles,Sunny Isles Beach,sanni a''ilsa bica,sany aylz bych  flwryda,sny aylz bytsh,yang guang dao hai tan,Сани Ајлс Бич,Санни-Айлс-Бич,Санні-Айлс-Біч,سانی آیلز بیچ، فلوریدا,سنی آئلز بیچ، فلوریڈا,صني آيلز بيتش,सन्नी आइल्स बीच,阳光岛海滩', 25.9506500, -80.1228200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131943, 'Sunrise', 'Sunrise', 'Sanrajz,sanrayz  flwryda,sen lai si,seonlaijeu,snrayz  flwryda,Санрайз,Санрајз,سانرایز، فلوریدا,صنرايز، فلوريدا,森赖斯,선라이즈', 26.1339700, -80.1131000, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131944, 'Sunset', 'Sunset', '', 25.7059400, -80.3522800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131945, 'Sunshine Ranches', 'Sunshine Ranches', '', 26.0459200, -80.3289400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131946, 'Surfside', 'Surfside', '', 25.8784300, -80.1256000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131947, 'Sweetwater', 'Sweetwater', 'Svitvoter,si wei te wo te,svitavatara,swytwatr,Свитвотер,سوئیت‌واتر، فلوریدا,سوئیٹ واٹر، میامی-ڈیڈ کاؤنٹی، فلوریڈا,سويتواتر,स्विटवाटर,斯威特沃特', 25.7634300, -80.3731100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131948, 'Taft', 'Taft', '', 28.4297300, -81.3650700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131949, 'Tallahassee', 'Tallahassee', 'Apalache Old Fields,Gorad Talakhasi,Newton,Newtown,Old Field Town,Pueblo Nueva,TLH,Talachasi,Talahasi,Talahasis,Talahasī,Talajasy,Talakhasi,Tallahassa,Tallahassee,Tallahassee Talofa,Tallahassia,Tallakhassi,Tonabys Town,Tunapy,Villanueva,da la ha xi,ta la he xi,taelleohaesi,talahaci,talahase,talahasi,talahasy,tarahashi,telahasi,Ταλαχάσι,Горад Талахасі,Талахаси,Таллахасси,Таллахассі,Թալահասի,טאלאהאסי,تالاهاسي,تالاهاسی,تالاہاسی، فلوریڈا,ٹالیحسی,टालाहासे,टॅलाहासी,तालाहासे,টালাহাসি,டலஹாசி,ടലഹാസി,แทลลาแฮสซี,ტალაჰასი,タラハシー,塔拉赫西,達拉哈西,탤러해시', 30.4382600, -84.2807300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131950, 'Tamarac', 'Tamarac', 'Tamarak,ta ma la ke,tamarak,tamarak  flwryda,tyamaraka,Тамарак,تاماراك,تاماراک، فلوریدا,ट्यामाराक,塔玛拉克', 26.2128600, -80.2497700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131951, 'Tamiami', 'Tamiami', 'Tamiami', 25.7587100, -80.3983900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131952, 'Tampa', 'Tampa', 'Gorad Tampa,TPA,Tampa,taempa,taimpa,tamba,tampa,tamppa,tan pa,tanpa,tmpa  flwryda,tmph,Τάμπα,Горад Тампа,Тампа,Տամպա,טמפה,تامبا,تمپا، فلوریدا,ٹیمپا، فلوریڈا,टँपा,टैम्पा,ताम्पा,டாம்ப்பா,แทมปา,ტამპა,タンパ,坦帕,탬파', 27.9475200, -82.4584300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131953, 'Tangelo Park', 'Tangelo Park', '', 28.4558400, -81.4459000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131954, 'Tangerine', 'Tangerine', '', 28.7649900, -81.6306300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131955, 'Tarpon Springs', 'Tarpon Springs', 'Tarpon Sprin''nks,Tarpon Springs,ta peng si pu lin si,tarbwn sbrynghz,tarpona springas,tarpwn aspryngz  flwryda,Τάρπον Σπρινγκς,Тарпон Спрингс,تاربون سبرينغز,تارپون اسپرینگز، فلوریدا,टार्पोन स्प्रिङ्गस्,塔彭斯普林斯', 28.1461200, -82.7567700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131956, 'Tavares', 'Tavares', 'Taveris,ta wa lei si,tafarys,tawars  flwryda,tyabhareja,Таверис,تافاريس,تاوارس، فلوریدا,ट्याभारेज,塔瓦雷斯', 28.8041600, -81.7256300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131957, 'Tavernier', 'Tavernier', '', 25.0115200, -80.5150600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131958, 'Taylor Creek', 'Taylor Creek', '', 27.2167100, -80.7895000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131959, 'Tedder', 'Tedder', '', 26.2842500, -80.1222700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131960, 'Temple Terrace', 'Temple Terrace', 'Templ Teras,miao tai,tempala teresa,tmbl tras,tmpl tras  flwryda,Темпл Терас,تمبل تراس,تمپل تراس، فلوریدا,टेम्पल टेरेस,庙台', 28.0353000, -82.3892600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131961, 'Tequesta', 'Tequesta', '', 26.9681100, -80.1286500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131962, 'Terra Mar', 'Terra Mar', '', 26.2161900, -80.0953200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131963, 'The Crossings', 'The Crossings', '', 25.6706600, -80.4011700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131964, 'The Hammocks', 'The Hammocks', 'The Hammocks', 25.6714900, -80.4445000, 'US', '2013-09-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131965, 'The Meadows', 'The Meadows', '', 27.3617100, -82.4689800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131966, 'The Villages', 'The Villages', 'Orange Blossom Gardens,Te-Villidzhis,The Villages,The Villages at Spanish Springs,Vilidzes,da bhilejesa,Вилиџес,Те-Виллиджис,द भिलेजेस', 28.9340800, -81.9599400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131967, 'Thonotosassa', 'Thonotosassa', '', 28.0614100, -82.3023100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131968, 'Three Lakes', 'Three Lakes', '', 25.6420500, -80.3983900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131969, 'Three Oaks', 'Three Oaks', '', 26.4700800, -81.7939700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131970, 'Tice', 'Tice', '', 26.6747900, -81.8150800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131971, 'Tierra Verde', 'Tierra Verde', '', 27.6919700, -82.7234300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131972, 'Tiger Point', 'Tiger Point', '', 30.3785300, -87.0555200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131973, 'Timber Pines', 'Timber Pines', '', 28.4702800, -82.6031600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131974, 'Titusville', 'Titusville', 'TIX,Tajtusvil,Tajtusvill,Titusvill,Titusvill'',Titusville,ta''itasabhila,tai te si wei er,taitasubiru,tytwsfyl,Тайтусвилл,Тајтусвил,Титусвилль,Тітусвілл,تيتوسفيل,تیتوس‌ویل، فلوریدا,ٹائٹسویل، فلوریڈا,टाइटसभिल,タイタスビル,泰特斯维尔', 28.6122200, -80.8075500, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131975, 'Town ''n'' Country', 'Town ''n'' Country', 'Town ''n'' Country', 28.0105700, -82.5773200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131976, 'Treasure Island', 'Treasure Island', 'Trezhur Ajland,jin yin dao,trejara a''ilyanda,tryshwr ayland,trzhr aylnd  flwryda,Трежур Ајланд,تريشور أيلاند,ترژر آیلند، فلوریدا,ٹریژر آئلینڈ، فلوریڈا,ट्रेजर आइल्यान्ड,金银岛', 27.7691900, -82.7689900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131977, 'Trenton', 'Trenton', 'Trenton,te lun dun,trentana,trntwn  flwryda,tryntwn,Трентон,ترنتون، فلوریدا,ترينتون,ٹرنٹن، فلوریڈا,ट्रेन्टन,特伦顿', 29.6132900, -82.8176200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131978, 'Twin Lakes', 'Twin Lakes', '', 26.1809200, -80.1600500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131979, 'Umatilla', 'Umatilla', 'Jumatila,awmatyla,awmatyla  flwryda,umatila,you ma di la,Јуматила,أوماتيلا,اوماتیلا، فلوریدا,उमातिला,尤马蒂拉', 28.9294300, -81.6656300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131980, 'Union Park', 'Union Park', '', 28.5680600, -81.2861800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131981, 'University Park', 'University Park', 'Juniversiti Park,Juniversiti-Park,yunibharsiti parka,Јуниверсити Парк,Юниверсити-Парк,युनिभर्सिटी पार्क', 25.7464900, -80.3675500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131982, 'Upper Grand Lagoon', 'Upper Grand Lagoon', '', 30.1632600, -85.7407600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131983, 'Valparaiso', 'Valparaiso', 'VPS,Val''paraiso,Valparaiso,Valparajso,Valpariso,bhyalapyariso,wa er pa lai suo,walparaysw  flwryda,Валпарајсо,Вальпараисо,والپارایسو، فلوریدا,भ्यालप्यारिसो,瓦尔帕莱索', 30.5085300, -86.5027300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131984, 'Valrico', 'Valrico', '', 27.9378900, -82.2364400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131985, 'Vamo', 'Vamo', '', 27.2220000, -82.4978700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131986, 'Venice', 'Venice', 'VNC,Venecija,Venis,bhenisa,wei ni si,wnys  flwryda,Венеция,Венис,ونیس، فلوریدا,भेनिस,威尼斯', 27.0997800, -82.4542600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131987, 'Venice Gardens', 'Venice Gardens', '', 27.0731100, -82.4076000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131988, 'Vero Beach', 'Vero Beach', 'VRB,Viro Bich,bhero bica,bilobichi,wei luo hai tan,wrw bych  flwryda,Виро Бич,ورو بیچ، فلوریدا,ویرو بیچ، فلوریڈا,भेरो बीच,维罗海滩,비로비치', 27.6386400, -80.3972700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131989, 'Villages of Oriole', 'Villages of Oriole', '', 26.4623000, -80.1528200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131990, 'Villano Beach', 'Villano Beach', '', 29.9385800, -81.3020200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131991, 'Vineyards', 'Vineyards', '', 26.2237300, -81.7279800, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131992, 'Virginia Gardens', 'Virginia Gardens', '', 25.8103800, -80.3022700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131993, 'Wabasso Beach', 'Wabasso Beach', '', 27.7647500, -80.3989400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131994, 'Wahneta', 'Wahneta', '', 27.9528000, -81.7270200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131995, 'Waldo', 'Waldo', 'Voldo,valdo,waldw,waldw  flwryda,wo er duo,Волдо,والدو,والدو، فلوریدا,वाल्डो,沃尔多', 29.7896900, -82.1673200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131996, 'Wallace', 'Wallace', '', 30.6774100, -87.1799700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131997, 'Warm Mineral Springs', 'Warm Mineral Springs', 'Salt Springs,Warm Mineral Springs', 27.0597800, -82.2600900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131998, 'Warrington', 'Warrington', '', 30.3840900, -87.2749700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(131999, 'Washington Park', 'Washington Park', '', 26.1325900, -80.1811600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132000, 'Watertown', 'Watertown', '', 30.1924500, -82.6145700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132001, 'Wauchula', 'Wauchula', 'Vochula,vaucula,wachwla  flwryda,wawtshwla,wo chu la,Вочула,واوتشولا,واچولا، فلوریدا,वौचुला,沃楚拉', 27.5472600, -81.8114700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132002, 'Wedgefield', 'Wedgefield', '', 28.4877800, -81.0772900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132003, 'Weeki Wachee Gardens', 'Weeki Wachee Gardens', '', 28.5336100, -82.6295400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132004, 'Wekiwa Springs', 'Wekiwa Springs', 'Wekiva Springs,Wekiwa Springs', 28.6986100, -81.4256300, 'US', '2013-05-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132005, 'Wellborn', 'Wellborn', '', 30.2310600, -82.8195700, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132006, 'Wellington', 'Wellington', 'Velington,Vellington,hui ling dun,velalingatana,wlyngtwn  flwryda,wylnghtwn,Велингтон,Веллингтон,Веллінгтон,ولینگتون، فلوریدا,ويلنغتون,ویلنگٹن، فلوریڈا,वेललिङ्गटन,惠灵顿', 26.6586800, -80.2414400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132007, 'Wesley Chapel', 'Wesley Chapel', 'Uehsli-Chepel,Vesli Chapel,vesli cyapela,Весли Чапел,Уэсли-Чепел,वेस्ली च्यापेल', 28.2397300, -82.3278700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132008, 'West Bradenton', 'West Bradenton', '', 27.5025400, -82.6139900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132009, 'Westchase', 'Westchase', 'West Chase,Westchase', 28.0550200, -82.6098200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132010, 'West DeLand', 'West DeLand', 'West De Land', 29.0158200, -81.3331200, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132011, 'West Gate', 'West Gate', '', 26.7025700, -80.0981000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132012, 'West Little River', 'West Little River', '', 25.8570400, -80.2369900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132013, 'West Melbourne', 'West Melbourne', 'Uehst-Melborn,Vest Melburn,Vest-Mel''born,vesta melbarna,wst mlbwrn  flwryda,wyst mlbwrn,xi mo er ben,Вест Мелбурн,Вест-Мельборн,Уэст-Мелборн,وست ملبورن، فلوریدا,ويست ملبورن,वेस्ट मेल्बर्न,西墨尔本', 28.0716800, -80.6533900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132014, 'West Miami', 'West Miami', 'Vest Majami,vesta mayami,wst myamy  flwryda,wyst myamy,xi mai a mi,Вест Мајами,وست میامی، فلوریدا,ويست ميامي,वेस्ट मायामी,西迈阿密', 25.7634300, -80.2961600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132015, 'West Palm Beach', 'West Palm Beach', 'Litus Palmense Occidentale,Okcidenta Palm Beach,PBI,Uehst-Palm-Bich,Vest Palm Bich,Vest-Palm-Bich,West Palm Beach,u~esutopamubichi,vesta pama bica,weseuteupambichi,wst palm bych  flwryda,wst pʼlm byz,wyst balm bytsh,xi zong lu tan,Вест Палм Бич,Вест-Палм-Біч,Уэст-Палм-Бич,וסט פאלם ביץ,وست پالم بیچ، فلوریدا,ويست بالم بيتش,ویسٹ پام بیچ، فلوریڈا,वेस्ट पाम बीच,ウェストパームビーチ,西棕榈滩,웨스트팜비치', 26.7153400, -80.0533700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132016, 'West Park', 'West Park', '', 25.9845400, -80.1989400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132017, 'West Pensacola', 'West Pensacola', 'Brownsville,West Pensacola', 30.4265900, -87.2796900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132018, 'West Perrine', 'West Perrine', '', 25.6059400, -80.3628300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132019, 'West Samoset', 'West Samoset', '', 27.4694800, -82.5567600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132020, 'West Vero Corridor', 'West Vero Corridor', 'West Vero Corridor', 27.6377500, -80.4857600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132021, 'West and East Lealman', 'West and East Lealman', 'West and East Lealman', 27.8199300, -82.6894400, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132022, 'Westchester', 'Westchester', 'Uehstchester,Vestchester,vestacestara,weseuteucheseuteo,Вестчестер,Уэстчестер,वेस्टचेस्टर,웨스트체스터', 25.7548200, -80.3272700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132023, 'Weston', 'Weston', 'Uehston,Veston,Weston,vestana,wei si dun,wstwn,wstwn  flwryda,Вестон,Уэстон,وستون,وستون، فلوریدا,वेस्टन,韦斯顿', 26.1003700, -80.3997700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132024, 'Westview', 'Westview', '', 25.8820400, -80.2419900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132025, 'Westwood Lake', 'Westwood Lake', 'Westwood Lakes', 25.7292700, -80.3728300, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132026, 'Wewahitchka', 'Wewahitchka', '', 30.1127000, -85.2004700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132027, 'Whiskey Creek', 'Whiskey Creek', '', 26.5725800, -81.8900900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132028, 'White City', 'White City', '', 27.3739300, -80.3339400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132029, 'Whitfield', 'Whitfield', '', 27.4117100, -82.5659300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132030, 'Wildwood', 'Wildwood', 'Vajldvud,huai er de wu de,vildavuda,wylwwd  flwryda,Вајлдвуд,وائلڈووڈ، فلوریڈا,ویلوود، فلوریدا,विल्डवूड,怀尔德伍德', 28.8654200, -82.0405800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132031, 'Williamsburg', 'Williamsburg', '', 28.4144500, -81.4428500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132032, 'Williston', 'Williston', 'Viliston,villijtana,wei li si dun,wylynstwn  flwryda,Вилистон,ویلینستون، فلوریدا,विल्लीज्टन,威利斯顿', 29.3874700, -82.4467700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132033, 'Williston Highlands', 'Williston Highlands', '', 29.3405200, -82.5415000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132034, 'Willow Oak', 'Willow Oak', '', 27.9161400, -82.0178600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132035, 'Wilton Manors', 'Wilton Manors', 'Vilton Manors,Wilton Manor,Wilton Manors,vilatana myanoras,wei er dun zhuang yuan,wyltwn manwrs  flwryda,Вилтон Манорс,ویلتون مانورس، فلوریدا,विलटन म्यानोरस्,威尔顿庄园', 26.1603600, -80.1389300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132036, 'Wimauma', 'Wimauma', '', 27.7125300, -82.2989800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132037, 'Windermere', 'Windermere', 'Uindermir,Vindermir,vindaramere,wen de mi er,wyndrmyr  flwryda,Виндермир,Уиндермир,ویندرمیر، فلوریدا,विन्डरमेरे,温德米尔', 28.4955600, -81.5348000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132038, 'Winston', 'Winston', '', 28.0316900, -82.0148100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132039, 'Winter Beach', 'Winter Beach', 'Quay,Waverly,Winter Beach', 27.7192000, -80.4206100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132040, 'Winter Garden', 'Winter Garden', 'Vinter Garden,dong ji hua yuan,vintara gardena,wyntr gardn  flwryda,Винтер Гарден,وینتر گاردن، فلوریدا,विन्टर गार्डेन,冬季花园', 28.5652800, -81.5861800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132041, 'Winter Haven', 'Winter Haven', 'GIF,Vinter Khejven,u~intaheibun,vintara hyabhena,wen te hei wen,wyntr hywn  flwryda,Винтер Хејвен,ونٹر ہیون، فلوریڈا,وینتر هیون، فلوریدا,विन्टर ह्याभेन,ウィンターヘイブン,温特黑文', 28.0222400, -81.7328600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132042, 'Winter Park', 'Winter Park', 'Uintur Park,Vinter Park,vintara parka,wen te pa ke,winteopakeu,wyntr park  flwryda,Винтер Парк,Уинтър Парк,ونٹر پارک، فلوریڈا,وینتر پارک، فلوریدا,विन्टर पार्क,温特帕克,윈터파크', 28.6000000, -81.3392400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132043, 'Winter Springs', 'Winter Springs', 'North Orlando,Vinter Springs,Winter Springs,dong quan,vintara springas,wyntr aspryngz  flwryda,Винтер Спрингс,ونٹر سپرنگس، فلوریڈا,وینتر اسپرینگز، فلوریدا,विन्टर स्प्रिङ्गस्,冬泉', 28.6988900, -81.3081200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132044, 'Woodlawn Beach', 'Woodlawn Beach', '', 30.3882500, -86.9908000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132045, 'Woodville', 'Woodville', '', 30.3140900, -84.2474000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132046, 'Wright', 'Wright', 'Rajt,Райт', 30.4557500, -86.6382900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132047, 'Yalaha', 'Yalaha', 'Yalaha,Yallaha', 28.7386000, -81.8086900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132048, 'Youngstown', 'Youngstown', '', 30.3643600, -85.4382600, 'US', '2012-06-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132049, 'Yulee', 'Yulee', '', 30.6319000, -81.6064900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132050, 'Zellwood', 'Zellwood', '', 28.7311100, -81.6011800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132051, 'Zephyrhills', 'Zephyrhills', 'Abbott''s Station,ZPH,Zephyr Hills,Zephyrhills', 28.2336200, -82.1811900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132052, 'Zolfo Springs', 'Zolfo Springs', '', 27.4933700, -81.7959200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132053, 'Abbeville', 'Abbeville', 'Abbeville,Abevil,Adams,a bi wei er,abfyl,abwyl  jarjya,abwyl  jwrjya,aebibil,ebebhila,Абевил,أبفيل,ابویل، جارجیا,ابویل، جورجیا,एबेभिल,阿比维尔,애비빌', 31.9921200, -83.3068200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132054, 'Acworth', 'Acworth', 'Ackworth,Acworth,Akvort,Northcutt Station,akwrs  jwrjya,akwwrth,ekvartha,Акворт,أكوورث,اکورس، جورجیا,ایکورتھ، جارجیا,एक्वर्थ', 34.0663500, -84.6783700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132055, 'Adairsville', 'Adairsville', 'Adersvil,adayrsfyl,adyrswyl  jwrjya,edarsabhila,Адерсвил,أدايرسفيل,ادیرسویل، جورجیا,اڈیرسویل، جارجیا,एडर्सभिल', 34.3687000, -84.9341100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132056, 'Adel', 'Adel', 'Adel,Ejdel,Puddleville,aderu,adl,adl  jwrjya,edela,Ејдел,أدل,ادل، جورجیا,ایڈل، جارجیا,एडेल,アデル', 31.1372700, -83.4240800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132057, 'Alamo', 'Alamo', 'Alamo,alamo,alamw,alamw  jarjya,alamw  jwrjya,Аламо,آلامو، جورجیا,ألامو,الامو، جارجیا,अलामो', 32.1471200, -82.7779200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132058, 'Albany', 'Albany', 'ABY,Albany,City of Opportunity,Olbani,albani,albany,albany  jarjya,albany  jwrjya,ao er ba ni,olbeoni,orubani,Олбани,Олбані,آلبانی، جورجیا,ألباني,البانی، جارجیا,अल्बानी,オールバニ,奧爾巴尼,올버니', 31.5785100, -84.1557400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132059, 'Alma', 'Alma', 'Alma,The Queen City,alma,alma  jarjya,alma  jwrjya,elma,Алма,آلما، جورجیا,ألما,الما، جارجیا,एल्मा', 31.5393700, -82.4623600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132060, 'Alpharetta', 'Alpharetta', 'Al''faretta,Alfareta,Alpharetta,New Prospect Campground,alfarta  jwrjya,alfaryta,alfaryta  jarjya,alphareta,Алфарета,Альфаретта,آلفارتا، جورجیا,ألفاريتا,الفاریتا، جارجیا,अल्फारेटा', 34.0753800, -84.2940900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132061, 'Alto', 'Alto', 'Alto,Long View,Longview Station,Lulah,Lulah City,Roul', 34.4673200, -83.5737800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132062, 'Americus', 'Americus', 'Amerikus,amerikasa,amrykas  jwrjya,amryks  jarjya,amyrykws,Америкус,أميريكوس,امریکاس، جورجیا,امریکس، جارجیا,अमेरिकस', 32.0723900, -84.2326900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132063, 'Appling', 'Appling', 'Appling,Applingville', 33.5460800, -82.3173000, 'US', '2015-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132064, 'Aragon', 'Aragon', 'Aragon,Long', 34.0456500, -85.0560600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132065, 'Arcade', 'Arcade', '', 34.0778900, -83.5615500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132066, 'Arlington', 'Arlington', 'Arlington,Арлингтон', 31.4399000, -84.7249200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132067, 'Ashburn', 'Ashburn', 'Ashbern,Ashburn,Marion,Troupville Crossroads,ashbrn  jarjya,ashbrn  jwrjya,ashbwrn,esbarna,Ашберн,أشبورن,اشبرن، جارجیا,اشبرن، جورجیا,एश्बर्न', 31.7060100, -83.6532200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132068, 'Athens', 'Athens', 'AHN,Atens,Atensas,Athens,Athens i Georgia,Athens-Clarke County,Atina,Atuns,Cedar Shoals,aeseonseu,asenzu,athensa,athyna,atn  jwrjya,atynz  jwrjya,ethensaklarka ka''unti,ya dian,Атенс,Атина,Атънс,אתנס,آتئنز، جورجیا,آتن، جورجیا,أثينا,ایتھنز، جارجیا,अथेन्स,एथेन्सक्लार्क काउन्टी,アセンズ,雅典,애선스', 33.9609500, -83.3779400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132069, 'Atlanta', 'Atlanta', 'ATL,Atlant,Atlanta,Atlantae,Atlonta,Canebrake,Gorad Atlanta,Marthasdale,Marthasville,Standing Peachtree,Terminus,White Hall,Whitehall,aeteullaenta,arr‌lanra nagaram,atalanta,ateullaenta,ateullanta,atlanta,atoranta,atʼlantʼa,etalanta,etlanta,ya te lan da,Ατλάντα,Атлантæ,Атланта,Горад Атланта,Ատլանտա,אטלאנטא,אטלנטה,آتلانتا,أتلانتا,ئەتڵانتا,اٹلانٹا,اٹلانٹا، جارجیا,अटलांटा,अटलान्टा,एट्लान्टा,एत्लान्ता,আটলান্টা,એટલાન્ટા,அட்லான்டா,అట్లాంటా,ಅಟ್ಲಾಂಟಾ,അറ്റ്‌ലാന്റാ നഗരം,แอตแลนตา,ཨ་ཊི་ལཱན་ཊཱ།,အတ္တလန္တာမြို့,ატლანტა,አትላንታ,アトランタ,亚特兰大,亞特蘭大,아틀란타,아틀랜타,애틀랜타', 33.7490000, -84.3879800, 'US', '2017-06-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132070, 'Auburn', 'Auburn', 'Auburn,Loughridge', 34.0137200, -83.8276800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132071, 'Augusta', 'Augusta', 'AGS,Augusta,Augusta-Richmond County,Ogasta,Ogusta,agasta,agasta ricamanda ka''unti,agwsta  jwrjya,ao gu si ta,awghsta,ogasuta,ogeoseuta,Огаста,Огъста,אוגוסטה,آگسٹا، جارجیا,آگوستا، جورجیا,أوغستا,अगस्टा,अगस्टा रिचमंड काउन्टी,অগাস্টা,オーガスタ,奥古斯塔,오거스타', 33.4709700, -81.9748400, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132072, 'Austell', 'Austell', 'Austell,Causeys Chapel,Cincinnati Junction,Irvine,Ostel,astela,astl  jwrjya,awstyl,Остел,آستل، جورجیا,آسٹیل، جارجیا,أوستيل,अस्टेल', 33.8126100, -84.6343800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132073, 'Avondale Estates', 'Avondale Estates', 'Avondale,Avondale Estates,Ingleside', 33.7714900, -84.2671400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132074, 'Bainbridge', 'Bainbridge', 'BGE,Bainbridge,Beinbridz,Beinbridž,Bejnbridz,Bejnbridzh,Burges,Fort Hughes,Puckanawhitla,bainabrija,byn brj  jarjya,bynbrdj,bynbryj  jwrjya,Бейнбридж,Бейнбрідж,Бејнбриџ,بينبردج,بین برج، جارجیا,بینبریج، جورجیا,बैनब्रिज', 30.9038000, -84.5754700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132075, 'Baldwin', 'Baldwin', 'Baldwin,Bolduin,Stonepile,Болдуин', 34.4917700, -83.5373900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132076, 'Ball Ground', 'Ball Ground', 'Ball Ground,Ballground', 34.3381500, -84.3765900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132077, 'Barnesville', 'Barnesville', 'Barnsvil,barns wyl  jwrjya,barnsabhila,barnsfyl,barnswyl  jarjya,Барнсвил,بارنس ویل، جورجیا,بارنسفيل,بارنسویل، جارجیا,बार्न्सभिल', 33.0545700, -84.1557500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132078, 'Baxley', 'Baxley', 'Baksli,baksly,bksly  jwrjya,byaksali,Баксли,باكسلي,بکسلی، جورجیا,بکسلے، جارجیا,ब्याक्सली', 31.7782500, -82.3484600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132079, 'Belvedere Park', 'Belvedere Park', '', 33.7548300, -84.2674200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132080, 'Berkeley Lake', 'Berkeley Lake', '', 33.9837100, -84.1865800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132081, 'Blackshear', 'Blackshear', 'Blekshir,blakshyr,blk shyr  jwrjya,blyakasiyara,blyk shyr  jarjya,Блекшир,بلاكشير,بلک شیر، جورجیا,بلیک شیر، جارجیا,ब्ल्याकशीयर', 31.3060500, -82.2420700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132082, 'Blairsville', 'Blairsville', 'Blersvil,bleyasbhila,blyrsfyl,blyrzwyl  jarjya,blyrzwyl  jwrjya,Блерсвил,بليرسفيل,بلیرزویل، جارجیا,بلیرزویل، جورجیا,ब्लेयस्भिल', 34.8762000, -83.9582400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132083, 'Blakely', 'Blakely', 'Blejkli,blakly,bleki,blkly  jwrjya,blykly  jarjya,Блејкли,بلاكلي,بلکلی، جورجیا,بلیکلی، جارجیا,ब्लेकी', 31.3776800, -84.9340900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132084, 'Bloomingdale', 'Bloomingdale', '', 32.1324200, -81.2990000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132085, 'Blue Ridge', 'Blue Ridge', 'Blu Ridz,blu rija,blw rj  jarjya,blw rydj,blwryj  jwrjya,Блу Риџ,بلو رج، جارجیا,بلو ريدج,بلوریج، جورجیا,ब्लु रीज', 34.8639700, -84.3240900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132086, 'Bogart', 'Bogart', 'Asseola,Bogart,Osceola', 33.9492800, -83.5346100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132087, 'Bonanza', 'Bonanza', '', 33.4656700, -84.3365900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132088, 'Boston', 'Boston', 'Boston,Бостон', 30.7918600, -83.7898900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132089, 'Bowdon', 'Bowdon', 'Boudon,Bowdon,Cerro Gordo,bodana,bwdwn,bwdwn  jwrjya,Боудон,بودون,بودون، جورجیا,بووڈن، جارجیا,बोडन', 33.5378900, -85.2532800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132090, 'Braselton', 'Braselton', 'Braselton,Braseltown,braseltana,brasyltwn,bureiseruton,Браселтон,براسيلتون,بریسیلٹن، جارجیا,ब्रासेल्टन,ブレイセルトン', 34.1092700, -83.7626700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132091, 'Bremen', 'Bremen', 'Bremen,Brimen,Kramer,Repose,Wolf Pen,bremena,brmn  jwrjya,brymn,brymn  jarjya,Бримен,برمن، جورجیا,بريمن,بریمن، جارجیا,ब्रेमेन', 33.7212200, -85.1455000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132092, 'Brookhaven', 'Brookhaven', 'Brookhaven,Brookhaven Heights,Nort Atlanta,North Atlanta,brwk hawn  jwrjya,brwkhafn,nartha etlanta,Норт Атланта,بروكهافن,بروک هاون، جورجیا,بروک ہیون، جارجیا,नर्थ एट्लान्टा', 33.8584400, -84.3402000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132093, 'Brooklet', 'Brooklet', '', 32.3796300, -81.6631700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132094, 'Broxton', 'Broxton', 'Broxton,Gully Branch', 31.6251900, -82.8868100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132095, 'Brunswick', 'Brunswick', 'Bransvik,Braunshvejg,Brunswick,Carrs Field,Port City,SSI,beuleonjeuwig,bransavika,brnswk  jarjya,brwns wyk  jwrjya,brwnzwyk,buranzuu~ikku,Брансвик,Брауншвейг,برنسوک، جارجیا,برونزويك,برونس ویک، جورجیا,ब्रन्सविक,ブランズウィック,브런즈윅', 31.1499500, -81.4914900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132096, 'Buchanan', 'Buchanan', 'Buchanan,Pierceville', 33.8026000, -85.1885600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132097, 'Buena Vista', 'Buena Vista', 'Bjuna Vista,Buena Vista,Pea Ridge,bwyna fysta,bwyna wysta  jwrjya,byuyana bhista,Бјуна Виста,بوئنا وسٹا، جارجیا,بوئنا ویستا، جورجیا,بوينا فيستا,ब्युयना भिस्टा', 32.3190400, -84.5171400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132098, 'Buford', 'Buford', 'Bjuford,bafrd  jwrjya,bapharda,bwfwrd,Бјуфорд,بافرد، جورجیا,بفرڈ، جارجیا,بوفورد,बफर्ड', 34.1206600, -84.0043500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132099, 'Butler', 'Butler', 'Batler,batlara,batlr  jwrjya,btlr,Батлер,باتلر، جورجیا,بتلر,بٹلر، جارجیا,बट्लर', 32.5570900, -84.2382500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132100, 'Byron', 'Byron', 'Bryon,Byron,Jackson,Jackson Station', 32.6537600, -83.7596300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132101, 'Cairo', 'Cairo', 'Cairo,Kejro,Millers Station,alqahrt,kayrw  jwrjya,siyaro,Кейро,Кејро,القاهرة,کائرہ، جارجیا,کایرو، جورجیا,सीयरो', 30.8775100, -84.2021400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132102, 'Calhoun', 'Calhoun', 'Calhoun,Dawsonville,Fork Ferry,Kalkhun,Oothcaloga,Oothcaloga Depot,kalhwn,kalhwn  jwrjya,kyal''hana,Калхун,كالهون,کالهون، جورجیا,کالہون، جارجیا,क्याल्हन', 34.5025900, -84.9510500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132103, 'Camilla', 'Camilla', 'Kamila,kamyla,kamyla  jwrjya,keomilla,kyamila,kymyla  jarjya,Камила,كاميلا,کامیلا، جورجیا,کیمیلا، جارجیا,क्यामिला,커밀라', 31.2312900, -84.2104600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132104, 'Canton', 'Canton', 'Canton,Etowah', 34.2367600, -84.4907600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132105, 'Carnesville', 'Carnesville', 'Karnsvil,karnesabhila,karnswyl  jarjya,karnswyl  jwrjya,kranysfyl,Карнсвил,كرانيسفيل,کارنسویل، جارجیا,کارنسویل، جورجیا,कार्नेसभिल', 34.3698300, -83.2351600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132106, 'Carrollton', 'Carrollton', 'Carrollton,Karolton,Troupsville,karwltwn,karwltwn  jwrjya,kyarolatana,Каролтон,كارولتون,کارولتون، جورجیا,کارولٹن، جارجیا,क्यारोलटन', 33.5801100, -85.0766100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132107, 'Cartersville', 'Cartersville', 'Birmingham,Cartersville,Kartersvil,kartarsabhila,kartrswyl  jwrjya,kartrzfyl,Картерсвил,كارترزفيل,کارترسویل، جورجیا,کیرٹرسویل، جارجیا,कार्टर्सभिल', 34.1653300, -84.8023100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132108, 'Cave Spring', 'Cave Spring', 'Cave Spring,Cave Springs,Cavespring,Kejv Spring,kaf sbryngh,kebha springa,kyw sprng  jarjya,kywaspryng  jwrjya,Кејв Спринг,كاف سبرينغ,کیو سپرنگ، جارجیا,کیواسپرینگ، جورجیا,केभ स्प्रिङ्ग', 34.1076000, -85.3363400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132109, 'Cedartown', 'Cedartown', 'Cedar Town,Cedartown,Sidartaun,kdartwn  jwrjya,kydrtwn,sedarata''una,Сидартаун,سیدار ٹاؤن، جارجیا,كيدرتون,کدارتون، جورجیا,सेडारटाउन', 34.0537100, -85.2549500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132110, 'Centerville', 'Centerville', 'Centerville,Hattie', 32.6301400, -83.6896300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132111, 'Chamblee', 'Chamblee', 'Chamblee,Cross Keys,Roswell Junction,Shambli,chmbly  jarjya,cyambli,kmbly  jwrjya,tshambly,Шамбли,تشامبلي,چمبلی، جارجیا,کمبلی، جورجیا,च्याम्ब्ली', 33.8920500, -84.2988100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132112, 'Chatsworth', 'Chatsworth', 'Chatsvort,chtswrth  jwrjya,cyatsvartha,tshatswwrth,Чатсворт,تشاتسوورث,چتسورث، جورجیا,چیٹسورتھ، جارجیا,च्याट्स्वर्थ', 34.7659100, -84.7699400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132113, 'Chattanooga Valley', 'Chattanooga Valley', '', 34.9328500, -85.3555100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132114, 'Chester', 'Chester', 'Chester,Честер', 32.3937800, -83.1529300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132115, 'Chickamauga', 'Chickamauga', 'Chickamauga,Chikamoga,Crawfish Spring,Crawfish Springs,Snow Hill,chykamaga  jwrjya,chykamawga  jarjya,cikamu''aga,tshykamawgha,Чикамога,تشيكاماوغا,چیکاماؤگا، جارجیا,چیکاماگا، جورجیا,चिकामुआगा', 34.8711900, -85.2907900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132116, 'Clarkesville', 'Clarkesville', 'Clarkesville,Clarksville,Klarksvil,klarksbhila,klarksfyl,klarkswyl  jarjya,klarkzwyl  jwrjya,Кларксвил,كلاركسفيل,کلارکزویل، جورجیا,کلارکسویل، جارجیا,क्लार्क्स्भिल', 34.6126000, -83.5248900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132117, 'Clarkston', 'Clarkston', 'Klarkston,klark astwn  jwrjya,klarkstana,klarkstwn,Кларкстон,كلاركستون,کلارک استون، جورجیا,کلارک سٹون، جارجیا,क्लार्क्स्टन', 33.8095500, -84.2396400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132118, 'Claxton', 'Claxton', 'Klakston,klaksatana,klakstwn,klgstwn  jwrjya,Клакстон,كلاكستون,کلگستون، جورجیا,کلیکسٹن، جارجیا,क्लाक्सटन', 32.1615800, -81.9040000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132119, 'Clayton', 'Clayton', 'Clayton,Claytonsville,Klejton,The Dividings,klaytwn,kletana,klytn  jwrjya,Клејтон,كلايتون,کلیتن، جورجیا,کلیٹن، جارجیا,क्लेटन', 34.8781500, -83.4009900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132120, 'Cleveland', 'Cleveland', 'Cleveland,Klivland,Klivlend,Mount Yonah,klibhalyanda,klwlnd  jwrjya,klyfland,Кливланд,Кливленд,كليفلاند,کلولند، جورجیا,کلیولینڈ، جارجیا,क्लिभल्यान्ड', 34.5970400, -83.7632400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132121, 'Cochran', 'Cochran', 'Cochran,Dykesboro,Kokran,kakryana,kchran  jwrjya,kwchryn  jarjya,kwtshran,Кокран,كوتشران,کوچرین، جارجیا,کچران، جورجیا,कक्र्यान', 32.3868300, -83.3546100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132122, 'College Park', 'College Park', 'College Park,Koledz Park,Kolledzh Park,Manchester,kaleja parka,kalj park  jarjya,kalj park  jwrjya,kwlyj bark,Колеџ Парк,Колледж Парк,كوليج بارك,کالج پارک، جارجیا,کالج پارک، جورجیا,कलेज पार्क', 33.6534400, -84.4493700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132123, 'Colquitt', 'Colquitt', 'Colquitt,Springtown', 31.1712900, -84.7332500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132124, 'Columbus', 'Columbus', 'CSG,Columbus,Kolambus,Kolumbas,Kolumbus,Kulumbus,ge lun bu,klmbws  jwrjya,kolambasa,kolleombeoseu,kolumbus,koronbasu,kwlmbs  jarjya,kwlwmbws,qwlwmbws,Коламбус,Колумбус,Кълъмбъс,קולומבוס,كولومبوس,کلمبوس، جورجیا,کولمبس، جارجیا,कोलम्बस,コロンバス,哥伦布,콜럼버스', 32.4609800, -84.9877100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132125, 'Comer', 'Comer', '', 34.0637200, -83.1254300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132126, 'Commerce', 'Commerce', 'Commerce,Groaning Rock,Harmony Grove,Komers,kamarsa,kamrs  jarjya,kamrs  jwrjya,kwmyrk,Комерс,كوميرك,کامرس، جارجیا,کامرس، جورجیا,कमर्स', 34.2040000, -83.4571100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132127, 'Conley', 'Conley', '', 33.6448300, -84.3257600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132128, 'Conyers', 'Conyers', 'Conyers,Conyers Station,Kanjerso,Koniurs,Konjers,Rockdale,kan''yirsa,knyrz  jwrjya,konieoseu,kwnyrz,kwnyrz  jarjya,Кониърс,Конјерс,كونيرز,کنیرز، جورجیا,کونیرز، جارجیا,कन्यीर्स,코니어스', 33.6676100, -84.0176900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132129, 'Cordele', 'Cordele', 'Kordil,kardela,krdl  jwrjya,kwrdyl,Кордил,كورديل,کردل، جورجیا,کورڈیل، جارجیا,कर्डेल', 31.9635100, -83.7823900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132130, 'Cornelia', 'Cornelia', 'Blaine,Cornelia,Kornilija,Paines,Rabun Gap Junction,karneliya,krnlya  jwrjya,krnylya  jarjya,kwrnylya,Корнилија,كورنيليا,کرنلیا، جورجیا,کرنیلیا، جارجیا,कर्नेलिया', 34.5114900, -83.5271200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132131, 'Country Club Estates', 'Country Club Estates', '', 33.9892800, -83.4096000, 'US', '2010-02-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132132, 'Country Club Estates', 'Country Club Estates', '', 31.2127300, -81.4642700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132133, 'Covington', 'Covington', 'Covington,Kavington,Newtonsboro,Newtonsborough,keobingteon,kobhingtana,kwfynghtwn,kwyngtn  jwrjya,Кавингтон,كوفينغتون,کوونگٹن، جارجیا,کوینگتن، جورجیا,कोभिंग्टन,커빙턴', 33.5967800, -83.8601800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132134, 'Crawfordville', 'Crawfordville', 'Crawfordsville,Crawfordville,Krofordvil,kraphardabhila,krawfwrdwyl  jwrjya,krwfwrdfyl,Крофордвил,كروفوردفيل,کرافورڈویل، جارجیا,کراوفوردویل، جورجیا,क्रफर्डभिल', 33.5540200, -82.8959800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132135, 'Cumming', 'Cumming', 'Cumming,Cummings,Kaming,kaminga,kamyng  jwrjya,keoming,kmng  jarjya,kwmyngh,Каминг,كومينغ,کامینگ، جورجیا,کمنگ، جارجیا,कमिंग,커밍', 34.2073200, -84.1401900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132136, 'Cusseta', 'Cusseta', 'Cusseta,Kasihta,Kusita,Kusseta,Sand Town,Usseta,kaseta,kasta  jwrjya,ksyta  jarjya,kwzyta,Кусита,Куссета,كوزيتا,کاستا، جورجیا,کسیتا، جارجیا,कसेटा', 32.3054300, -84.7727000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132137, 'Cuthbert', 'Cuthbert', 'Katbert,katbrt  jwrjya,kathbarta,kwthbrt,Катберт,كوثبرت,کاتبرت، جورجیا,کتھبرٹ، جارجیا,कठ्बर्ट', 31.7712700, -84.7893700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132138, 'Dacula', 'Dacula', 'Dacula,Freeman,Freemantown', 33.9887200, -83.8979600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132139, 'Dahlonega', 'Dahlonega', 'Dahlonega,Dalonega,Lick Log,Mexico,New Mexico,Tahlanauneca,Talonaga,Talonega,Taulonica,d''ahlonega,dahlwnga  jwrjya,dahlwngha,daronega,deollaneoga,Далонега,داهلونغا,داهلونگا، جورجیا,داہلونیگا، جارجیا,डाह्लोनेगा,ダロネガ,덜라너가', 34.5325900, -83.9849100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132140, 'Dalton', 'Dalton', 'Cross Plains,DNN,Dalton,Dolton,daltana,daltwn,daltwn  jwrjya,dolteon,Далтон,Долтон,دالتون,دالتون، جورجیا,ڈیلٹن، جارجیا,डाल्टन,돌턴', 34.7698000, -84.9702200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132141, 'Dallas', 'Dallas', 'Dalas,Dallas,dalas,dalas  jwrjya,dyalasa,Далас,Даллас,دالاس,دالاس، جورجیا,ڈلاس، جارجیا,ड्यालास', 33.9237100, -84.8407700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132142, 'Danielsville', 'Danielsville', 'Danijelsvil,danylsfyl,dnylzwyl  jwrjya,dyaniyalasbhila,Данијелсвил,دانيلسفيل,دنیلزویل، جورجیا,ڈینیلزویل، جارجیا,ड्यानियलस्भिल', 34.1242800, -83.2212600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132143, 'Darien', 'Darien', 'Darian,Darien,Darien City,Derijen,Fort Darien,New Inverness,daryn,daryn  jwrjya,deriyana,Деријен,دارين,دارین، جورجیا,ڈیرین، جارجیا,डेरियन', 31.3702300, -81.4339900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132144, 'Davisboro', 'Davisboro', 'Davisboro,Davisborough,Station Number 12', 32.9790400, -82.6079100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132145, 'Dawson', 'Dawson', 'Doson,Dousun,dahsana,dawswn,dawswn  jwrjya,Досон,Доусън,داوسون,داوسون، جورجیا,ڈاوسن، جارجیا,डःसन', 31.7738200, -84.4480000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132146, 'Dawsonville', 'Dawsonville', 'Dosonvil,dahsanabhila,dawswnfyl,dawswnwyl  jwrjya,Досонвил,داوسونفيل,داوسونویل، جورجیا,ڈاوسنویل، جارجیا,डःसनभिल', 34.4212100, -84.1190800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132147, 'Decatur', 'Decatur', 'Dekejter,Dekejtur,dekatara,dikeiteo,diketa,dykatr  jarjya,dykatr  jwrjya,dykatwr,Декейтер,Декејтур,ديكاتور,دیکاتر، جارجیا,دیکاتر، جورجیا,डेकाटर,ディケーター,디케이터', 33.7748300, -84.2963100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132148, 'Deenwood', 'Deenwood', '', 31.2220100, -82.3872500, 'US', '2015-03-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132149, 'Demorest', 'Demorest', 'Demorest,Domorest,demoresta,dmwrst  jwrjya,dmwryst  jarjya,dymwrst,Деморест,دمورست، جورجیا,دموریست، جارجیا,ديمورست,डेमोरेस्ट', 34.5651000, -83.5451700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132150, 'Dock Junction', 'Dock Junction', '', 31.2024500, -81.5167700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132151, 'Donalsonville', 'Donalsonville', 'Donalsonvil,danlsnwyl  jwrjya,donalasanabhila,dwnalswnfyl,Доналсонвил,دانلسنویل، جورجیا,دونالسونفيل,ڈونلسن ویل، جارجیا,डोनलसनभिल', 31.0404600, -84.8790900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132152, 'Doraville', 'Doraville', 'Cross Keys,Doravil,Doraville,dorabhila,drawyl  jwrjya,dwrafyl,Доравил,دراویل، جورجیا,دورافيل,ڈوراویل، جارجیا,डोराभिल', 33.8981600, -84.2832600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132153, 'Douglas', 'Douglas', 'Daglas,dagalasa,daglas  jwrjya,dwghlas,Даглас,داگلاس، جورجیا,دوغلاس,ڈگلس، جارجیا,डगलस', 31.5088100, -82.8498700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132154, 'Douglasville', 'Douglasville', 'Daglasvil,Douglasville,Skin Chestnut,Skint Chestnut,dagalasabhila,daglas wyl  jwrjya,dwghlasfyl,Дагласвил,داگلاس ویل، جورجیا,دوغلاسفيل,ڈگلس ویل، جارجیا,डगलसभिल', 33.7515000, -84.7477100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132155, 'Druid Hills', 'Druid Hills', 'Druid Hill,Druid Hills', 33.7803800, -84.3360400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132156, 'Dublin', 'Dublin', 'DBN,Dablin,Dublin,dablina,dablyn  jwrjya,daburin,dbln,Даблин,Дублин,دابلین، جورجیا,دبلن,ڈبلن، جارجیا,डब्लिन,ダブリン', 32.5404400, -82.9037500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132157, 'Duluth', 'Duluth', 'Dalut,Dulut,Duluth,Howells Crossroad,deolluseu,du lu si,dulutha,dwlwth,dwlwth  jwrjya,Далут,Дулут,دولوتھ، جارجیا,دولوث,دولوث، جورجیا,डुलुथ,杜魯斯,덜루스', 34.0028800, -84.1446400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132158, 'Dunwoody', 'Dunwoody', 'Danvudi,danvudi,danwwdy  jwrjya,deon-udi,dnwwdy,Данвуди,دانوودی، جورجیا,دنوودي,ڈنووڈی، جارجیا,डन्वूडी,던우디', 33.9462100, -84.3346500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132159, 'East Dublin', 'East Dublin', '', 32.5482200, -82.8718100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132160, 'East Griffin', 'East Griffin', '', 33.2437300, -84.2288100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132161, 'East Point', 'East Point', 'Ist Pojnt,ast pynt  jwrjya,ayst bwynt,ista po''inta,Ист Појнт,إيست بوينت,است پینت، جورجیا,ایسٹ پوائنٹ، جارجیا,इस्ट पोइन्ट', 33.6795500, -84.4393700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132162, 'East Newnan', 'East Newnan', '', 33.3506700, -84.7766000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132163, 'Eastman', 'Eastman', 'Eastman,Istman,Station Number 13,aystman,aystmn  jwrjya,istamyana,Истман,إيستمان,ایستمن، جورجیا,ایسٹ مین، جارجیا,इस्टम्यान', 32.1976700, -83.1776500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132164, 'Eatonton', 'Eatonton', 'Itonton,atwntwn,aytntn  jwrjya,itanatana,Итонтон,إتونتون,ایتنتن، جورجیا,ایٹنٹن، جارجیا,इटनटन', 33.3268000, -83.3885000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132165, 'Edison', 'Edison', 'Edison,Ehdison,Nubbintown,Эдисон', 31.5582300, -84.7382500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132166, 'Elberton', 'Elberton', 'Ehlberton,Elbert Court House,Elberton,Elbertville,albrtn  jwrjya,albyrtwn,elbartana,Елбертон,Элбертон,إلبيرتون,البرتن، جورجیا,البرٹن، جارجیا,एल्बर्टन', 34.1115900, -82.8686300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132167, 'Ellaville', 'Ellaville', 'Ellaville,Pond Town', 32.2382100, -84.3090800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132168, 'Ellijay', 'Ellijay', 'Allagae,Allejoy,Alljay,Alljoy,Elatsay Yi,Elechaye,Elidzej,Elija,Elijay,Ellija,Ellijay,Elljoy,alyjay,alyjy  jwrjya,ellije,Елиџеј,إليجاي,الیجی، جورجیا,ایلجے، جارجیا,एल्लिजे', 34.6948100, -84.4821500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132169, 'Emerson', 'Emerson', 'Emerson,Stegalls Station', 34.1270400, -84.7554900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132170, 'Enigma', 'Enigma', '', 31.4129700, -83.3290500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132171, 'Euharlee', 'Euharlee', 'Burges Mill,Euharlee,Euharley,Euharleyville', 34.1448200, -84.9330000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132172, 'Evans', 'Evans', 'Evans,Evens,Jenkins Station,ibhansa,Еванс,इभान्स', 33.5337500, -82.1306700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132173, 'Experiment', 'Experiment', '', 33.2653900, -84.2815900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132174, 'Fair Oaks', 'Fair Oaks', '', 33.9164900, -84.5446500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132175, 'Fairburn', 'Fairburn', 'Berryville,Cartersville,Fairburn,Ferbern,fyrbrn  jarjya,fyrbrn  jwrjya,fyrbwrn,pheyarabarna,Ферберн,فيربورن,فیربرن، جارجیا,فیربرن، جورجیا,फेयरबर्न', 33.5670600, -84.5810400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132176, 'Fairview', 'Fairview', '', 34.9456300, -85.2844000, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132177, 'Fayetteville', 'Fayetteville', 'Fejetvil,faytyfyl,fytwyl  jarjya,fytwyl  jwrjya,phayetabhila,Фејетвил,فايتيفيل,فیتویل، جارجیا,فیتویل، جورجیا,फायेटभिल', 33.4487300, -84.4549300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132178, 'Fitzgerald', 'Fitzgerald', 'Ficdzerald,Fitzgerald,Shack Town,Swan,fytzjrald  jwrjya,fytzjyrald,phitjgeralda,Фицџералд,فتزجیرالڈ، جارجیا,فيتزجيرالد,فیتزجرالد، جورجیا,फिट्ज्गेराल्ड', 31.7149100, -83.2526500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132179, 'Flowery Branch', 'Flowery Branch', 'Flowery Branch,Nattagasska', 34.1851000, -83.9251800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132180, 'Folkston', 'Folkston', 'Folkston,flkstwn  jwrjya,fu ke si tong,fwlkstwn,phoksatana,Фолкстон,فلکستون، جورجیا,فولكستون,فولکسٹن، جارجیا,फोक्सटन,福克斯通', 30.8309500, -82.0113100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132181, 'Forest Park', 'Forest Park', 'Astor,FOP,Forest Park,Forest Station,Forist Park,Forrest Park,Quick Station,frst park  jwrjya,fwrst bark,pharesta parka,Форист Парк,فاریسٹ پارک، جارجیا,فرست پارک، جورجیا,فورست بارك,फरेस्ट पार्क', 33.6220500, -84.3690900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132182, 'Forsyth', 'Forsyth', 'Forsajt,fwrsyt  jwrjya,fwrsyth,pharsitha,Форсајт,فورسيث,فورسیت، جورجیا,فورسیتھ، جارجیا,फर्सिथ', 33.0343000, -83.9382400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132183, 'Fort Gaines', 'Fort Gaines', 'A-con-hollo-wa Tal-lofa,A-con-hollo-way Tal-lofa,Fort Gaines,Fort Gejns,fwrt gyns  jwrjya,fwrt jaynz,pharta ga''ineja,Форт Гејнс,فورت جاينز,فورت گینس، جورجیا,فورٹ گینس، جارجیا,फर्ट गाइनेज', 31.6092400, -85.0493300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132184, 'Fort Oglethorpe', 'Fort Oglethorpe', '', 34.9489600, -85.2569000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132185, 'Fort Valley', 'Fort Valley', 'Fort Vali,Fort Valley,Fox Valley,fwrt faly,fwrt wly  jwrjya,pharta bhyali,Форт Вали,فورت فالي,فورت ولی، جورجیا,فورٹ ویلی، جارجیا,फर्ट भ्याली', 32.5537600, -83.8874100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132186, 'Franklin', 'Franklin', 'Franklin,Франклин', 33.2776200, -85.0980000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132187, 'Franklin Springs', 'Franklin Springs', '', 34.2848300, -83.1443200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132188, 'Gainesville', 'Gainesville', 'GVL,Gainesville,Gejnsvil,Gejnsvil'',Gejnsvill,Mule Camp Springs,Mules Crossing,Mules Junction,ga''inejabhila,geinjeubil,geinzubiru,ghynsfyl,gyns wyl  jarjya,gyns wyl  jwrjya,Гейнсвилл,Гејнсвил,Ґейнсвіль,غينسفيل,گینس ویل، جارجیا,گینس ویل، جورجیا,गाइनेजभिल,ゲインズビル,게인즈빌', 34.2978800, -83.8240700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132189, 'Garden City', 'Garden City', 'Garden City,Garden Siti,Industrial City Gardens,gardena siti,gardn syty  jwrjya,jardn syty,Гарден Сити,جاردن سيتي,گاردن سیتی، جورجیا,گارڈن سٹی، جارجیا,गार्डेन सिटी', 32.1143700, -81.1540000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132190, 'Georgetown', 'Georgetown', '', 31.9832600, -81.2273300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132191, 'Georgetown', 'Georgetown', 'Georgetown,Tabanana,Tobchanna', 31.8846100, -85.1074300, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132192, 'Gibson', 'Gibson', '', 33.2334800, -82.5954100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132193, 'Glennville', 'Glennville', '', 31.9365900, -81.9284500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132194, 'Gordon', 'Gordon', 'Gordon,Griswold Station,Griswoldville', 32.8820900, -83.3323800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132195, 'Grantville', 'Grantville', 'Calico Corner,Callico Corner,Callico Corners,Graniteville,Grantville', 33.2348400, -84.8357700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132196, 'Gray', 'Gray', 'Gray,James', 33.0095800, -83.5337800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132197, 'Grayson', 'Grayson', 'Berkeley,Grayson,Trip,Tripp', 33.8942700, -83.9557400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132198, 'Greensboro', 'Greensboro', 'Greenesborough,Greensboro,Greensborough,Greensburg,Grinsboro,ghrynsbwrw,grinasbaro,grynz brw  jarjya,grynzbwrw  jwrjya,Гринсборо,غرينسبورو,گرینز برو، جارجیا,گرینزبورو، جورجیا,ग्रीनस्बरो', 33.5756800, -83.1823800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132199, 'Greenville', 'Greenville', 'Greeneville,Greenville,Greenville Presbyterian Church,Grinvil,Grinvill,Old Greenville Presbyterian Church,ghrynfyl,grinabhila,gryn wyl  jarjya,gryn wyl  jwrjya,Гринвил,Гринвилл,غرينفيل,گرین ویل، جارجیا,گرین ویل، جورجیا,ग्रीनभिल', 33.0287400, -84.7129800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132200, 'Gresham Park', 'Gresham Park', '', 33.7034400, -84.3143700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132201, 'Griffin', 'Griffin', 'Griffin,Grifin,Pleasant Grove,ghryfyn,griphina,gryfyn  jarjya,gryfyn  jwrjya,Грифин,Гриффин,غريفين,گریفین، جارجیا,گریفین، جورجیا,ग्रिफिन', 33.2467800, -84.2640900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132202, 'Grovetown', 'Grovetown', 'Grouvtaun,Groveton,Grovetown,ghrwftawn,grobhata''una,grwtn  jwrjya,Гроувтаун,غروفتاون,گروتن، جورجیا,گروو ٹاؤن، جارجیا,ग्रोभटाउन', 33.4504200, -82.1981800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132203, 'Gumlog', 'Gumlog', '', 34.4917700, -83.0965400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132204, 'Guyton', 'Guyton', 'Guyton,Station Number 3', 32.3363000, -81.3915000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132205, 'Hahira', 'Hahira', '', 30.9913100, -83.3726600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132206, 'Hamilton', 'Hamilton', 'Gamil''ton,Khamilton,hamltwn,hmyltwn  jwrjya,hyamilatana,Гамильтон,Хамилтон,هاملتون,همیلتون، جورجیا,ہیملٹن، جارجیا,ह्यामिलटन', 32.7579100, -84.8749300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132207, 'Hampton', 'Hampton', 'Bear Creek,Bear Creek Station,Hampton,Hampton Mills,Khehmpton,Khempton,hambtwn,hmptwn  jwrjya,hyamptana,Хемптон,Хэмптон,هامبتون,همپتون، جورجیا,ہیمپٹن، جارجیا,ह्याम्प्टन', 33.3870600, -84.2829800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132208, 'Hannahs Mill', 'Hannahs Mill', 'Hannah Mill,Hannahs Mill,Hannas Mill', 32.9329100, -84.3493600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132209, 'Hapeville', 'Hapeville', 'Hapeville,Hopeville,Khejpvil,habfyl,hepabhila,hpwyl  jwrjya,Хејпвил,هابفيل,هپویل، جورجیا,ہیپویل، جارجیا,हेपभिल', 33.6601100, -84.4102000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132210, 'Hardwick', 'Hardwick', 'Hardwich,Hardwick,Midway,Midway-Hardwick', 33.0682000, -83.2234900, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132211, 'Harlem', 'Harlem', '', 33.4145800, -82.3126200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132212, 'Hartwell', 'Hartwell', 'Khartvel,hartavela,hartwl  jwrjya,hartwyl,Хартвел,هارتول، جورجیا,هارتويل,ہارٹ ویل، جارجیا,हार्टवेल', 34.3528800, -82.9320900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132213, 'Hawkinsville', 'Hawkinsville', 'Khokinsvil,hakingsabhila,hawkyns wyl  jwrjya,hawkynsfyl,Хокинсвил,هاوكينسفيل,هاوکینس ویل، جورجیا,ہاکنزویل، جارجیا,हकिंग्सभिल', 32.2837700, -83.4721200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132214, 'Hazlehurst', 'Hazlehurst', 'Hazelhurst,Hazlehurst,Khejzelkherst,hazlharst  jwrjya,hazlhwrst,hyajelaharsta,Хејзелхерст,هازلهارست، جورجیا,هازلهورست,ہیزل ہرسٹ، جارجیا,ह्याजेलहर्स्ट', 31.8696300, -82.5943000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132215, 'Helena', 'Helena', 'Khelena,Хелена', 32.0737900, -82.9145900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132216, 'Hephzibah', 'Hephzibah', 'Brothersville,Hephzibah,Khefziba,Lost Arcadia,hephjiba,hfzyba  jwrjya,hyfzybah,Хефзиба,هفزیبا، جورجیا,هيفزيباه,ہیفزیباہ، جارجیا,हेफ्जिबा', 33.3140300, -82.0967900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132217, 'Hiawassee', 'Hiawassee', 'Hiawassee,Hiwassee,Khajavosi,hayavasi,hyawasy,Хајавоси,هياواسي,हायावासी', 34.9492600, -83.7573900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132218, 'Hinesville', 'Hinesville', 'Khajnsvil,LIY,ha''insabhila,haynzfyl,Хајнсвил,هاينزفيل,ہینیسویل، جارجیا,हाइन्सभिल', 31.8468800, -81.5959500, 'US', '2017-07-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132219, 'Hiram', 'Hiram', '', 33.8756600, -84.7621600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132220, 'Hogansville', 'Hogansville', 'Khogansvil,hogansbhila,hwgans wyl  jwrjya,hwghansfyl,Хогансвил,هوغانسفيل,هوگانس ویل، جورجیا,ہوگنزویل، جارجیا,होगान्स्भिल', 33.1731800, -84.9149400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132221, 'Holly Springs', 'Holly Springs', 'Holly Springs,Hollysprings', 34.1739900, -84.5013200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132222, 'Homer', 'Homer', 'Allentown,Homer,Khomer,New Lebanon,homara,hwmyr,Хомер,هومير,होमर', 34.3337200, -83.4990500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132223, 'Homerville', 'Homerville', 'Homerville,Khomervil,Station Number 11,hmrwyl  jwrjya,homarabhila,hwmyrfyl,Хомервил,همرویل، جورجیا,هوميرفيل,ہومرویل، جارجیا,होमरभिल', 31.0366000, -82.7470800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132224, 'Hoschton', 'Hoschton', 'Hoschs Store,Hoschton', 34.0965000, -83.7612800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132225, 'Indian Springs', 'Indian Springs', 'Gunpowder Springs,Indian Spring,Indian Springs', 33.2426200, -83.9207400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132226, 'Indian Springs', 'Indian Springs', '', 34.9578500, -85.1644000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132227, 'Irondale', 'Irondale', '', 33.4806700, -84.3588100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132228, 'Irwinton', 'Irwinton', 'Bethel,Irwinton', 32.8112600, -83.1726500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132229, 'Isle of Hope', 'Isle of Hope', '', 31.9818800, -81.0609400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132230, 'Jackson', 'Jackson', 'Dzekson,Dzhekson,jakswn,jakuson,jkswn  jwrjya,jyakasana,jyksn  jarjya,Џексон,Джексон,جاكسون,جکسون، جورجیا,جیکسن، جارجیا,ज्याकसन,ジャクソン', 33.2945700, -83.9660200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132231, 'Jasper', 'Jasper', 'Dzasper,jasbyr,jaspr  jwrjya,jspr  jarjya,jyaspara,Џаспер,جاسبير,جاسپر، جورجیا,جسپر، جارجیا,ज्यास्पर', 34.4678700, -84.4290900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132232, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefferson,Jackson Court House,Jefferson,Jeffersonton,Jeffersonville,Thomocoggan,jepharasana,jfrsn  jarjya,jfrswn  jwrjya,jyfrswn,Џеферсон,Джефферсон,جفرسن، جارجیا,جفرسون، جورجیا,جيفرسون,जेफरसन', 34.1170500, -83.5723900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132233, 'Jefferson', 'Jefferson', '', 33.4493000, -83.3115500, 'US', '2012-04-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132234, 'Jeffersonville', 'Jeffersonville', 'Dzefersonvil,Jeffersonville,Rains Store,jepharsanabhila,jfrsn wyl  jarjya,jfrswn wyl  jwrjya,jyfrswnfyl,Џеферсонвил,جفرسن ویل، جارجیا,جفرسون ویل، جورجیا,جيفرسونفيل,जेफर्सनभिल', 32.6876500, -83.3465600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132235, 'Jesup', 'Jesup', 'Dzesup,Jessup,Jesup,jesapa,jysap  jwrjya,jysp  jarjya,jyswb,Џесуп,جيسوب,جیساپ، جورجیا,جیسپ، جارجیا,जेसप', 31.6078500, -81.8863400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132236, 'Jonesboro', 'Jonesboro', 'Dzhonsboro,Dzounsboro,Jonesboro,Jonesborough,Leaksville,Singleton,jonsabro,jwnzbrw  jarjya,jwnzbrw  jwrjya,jwnzbwrw,Џоунсборо,Джонсборо,جونزبرو، جارجیا,جونزبرو، جورجیا,جونزبورو,जोन्सब्रो', 33.5215000, -84.3538100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132237, 'Kennesaw', 'Kennesaw', 'Big Shanty,Keneso,Kennesaw,Kenneso,kenesah,keneso,knsaw  jwrjya,kynsaw  jarjya,kynysaw,Кенесо,Кеннесо,كينيساو,کنساو، جورجیا,کینساؤ، جارجیا,केनेसः,केनेसॉ', 34.0234300, -84.6154900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132238, 'Kingsland', 'Kingsland', 'Kingsland,kingaslyanda,knjzland,kyngzlnd  jwrjya,Кингсланд,كنجزلاند,کنگزلینڈ، جارجیا,کینگزلند، جورجیا,किङ्गस्ल्यान्ड', 30.7999600, -81.6898300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132239, 'Knoxville', 'Knoxville', '', 32.7243100, -83.9976900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132240, 'La Grange', 'La Grange', 'City of LaGrange,La Grange,LaGrange,Lagrange', 33.0392900, -85.0313300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132241, 'LaFayette', 'LaFayette', 'Benton,Chattooga,La Fayette,LaFayette,Lafayette,Lafejet,la phayeta,lafayt  jarjya,lafayt  jwrjya,lafayyt,Лафејет,لافائت، جارجیا,لافاييت,لافایت، جورجیا,ला फायेट', 34.7048000, -85.2819000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132242, 'Lake City', 'Lake City', '', 33.6065000, -84.3352000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132243, 'Lakeland', 'Lakeland', 'Alapaha,Alapaha Station,Lakeland,Lejkland,Mill Town,Milltown,lekalyanda,lykland,lyklnd  jwrjya,Лејкланд,ليكلاند,لکلینڈ، جارجیا,لیکلند، جورجیا,लेकल्यान्ड', 31.0410400, -83.0751500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132244, 'Lakeview', 'Lakeview', '', 34.9792400, -85.2588400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132245, 'Lakeview Estates', 'Lakeview Estates', '', 33.7067800, -84.0315800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132246, 'Lavonia', 'Lavonia', 'Lavonija,labhoniya,lafwnya,lawnya  jwrjya,lywwnya  jarjya,Лавонија,لافونيا,لاونیا، جورجیا,لیوونیا، جارجیا,लाभोनिया', 34.4359400, -83.1068200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132247, 'Lawrenceville', 'Lawrenceville', 'LZU,Lorensvil,larensabhila,larnswyl  jarjya,larnswyl  jwrjya,lwrynsfyl,Лоренсвил,لارنسویل، جارجیا,لارنسویل، جورجیا,لورينسفيل,लरेन्सभिल', 33.9562100, -83.9879600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132248, 'Leesburg', 'Leesburg', 'Leesburg,Leesburgh,Lisberg,Lisburg,Lizburg,Wooten,Wootons,lijbarga,lysbrg  jarjya,lysbrg  jwrjya,lysbwrgh,Лизбург,Лисберг,Лісбург,ليسبورغ,لیسبرگ، جارجیا,لیسبرگ، جورجیا,लीज्बर्ग', 31.7321200, -84.1707400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132249, 'Lexington', 'Lexington', 'Leksington,Лексингтон', 33.8698400, -83.1118200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132250, 'Lilburn', 'Lilburn', 'Bryan,Lilbern,Lilburn,McDaniel,lilbarna,lylbrn  jarjya,lylbrn  jwrjya,lylbwrn,Лилберн,ليلبورن,لیلبرن، جارجیا,لیلبرن، جورجیا,लिल्बर्न', 33.8901000, -84.1429700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132251, 'Lincolnton', 'Lincolnton', 'Linkolnton,linkanatana,lynklntwn  jwrjya,lynkwlntwn,Линколнтон,لنکلٹن، جارجیا,لينكولنتون,لینکلنتون، جورجیا,लिङ्कनटन', 33.7923500, -82.4790200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132252, 'Lindale', 'Lindale', '', 34.1867600, -85.1746700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132253, 'Lithia Springs', 'Lithia Springs', 'Bowden,Deer Lick,Lithia Springs,Salt Springs', 33.7940000, -84.6604900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132254, 'Lithonia', 'Lithonia', 'Crossroads,Georges Store,Lajtonija,Lithonia,lithoniya,lythwnya,lytnya  jwrjya,Лајтонија,لتھونیا، جارجیا,ليثونيا,لیتنیا، جورجیا,लिथोनिया', 33.7123300, -84.1051900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132255, 'Locust Grove', 'Locust Grove', 'Lokust Grouv,lokasta grobha,lwkast grw  jwrjya,lwkst grww  jarjya,lwkwst ghrwf,Локуст Гроув,لوكوست غروف,لوکاست گرو، جورجیا,لوکست گروو، جارجیا,लोकस्ट ग्रोभ', 33.3459500, -84.1090800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132256, 'Loganville', 'Loganville', 'Buncombe,Logansville,Loganvil,Loganville,lganwyl  jwrjya,loganabhila,lwgnwyl  jarjya,lwjanfyl,Логанвил,لوجانفيل,لوگنویل، جارجیا,لگانویل، جورجیا,लोगानभिल', 33.8390000, -83.9007400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132257, 'Lookout Mountain', 'Lookout Mountain', 'Fairyland,Lookout Mountain', 34.9775800, -85.3577400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132258, 'Louisville', 'Louisville', 'Lewisville,Louisville,Luisvil,lu''ibhila,lwyys wyl  jarjya,lwyys wyl  jwrjya,lwyzfyl,Луисвил,لوئیس ویل، جارجیا,لويزفيل,لوییس ویل، جورجیا,लुईभिल', 33.0015400, -82.4112400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132259, 'Lovejoy', 'Lovejoy', 'Lovejoy,Lovejoys,Lovejoys Station', 33.4362200, -84.3143700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132260, 'Ludowici', 'Ludowici', 'Johnston Station,Johnstons,Liberty City,Ludowici,Number 5', 31.7079900, -81.7423400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132261, 'Lula', 'Lula', 'Bellton,Belton,Lula,Lulah', 34.3876000, -83.6662900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132262, 'Lumber City', 'Lumber City', 'Artesian City,Camp Little Ocmulgee,Lumber City', 31.9293500, -82.6795800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132263, 'Lumpkin', 'Lumpkin', 'Lampkin,lampkina,lampkyn  jwrjya,lmpkn  jarjya,lwmbkyn,Лампкин,لامپکین، جورجیا,لمپکن، جارجیا,لومبكين,लम्प्किन', 32.0509900, -84.7990900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132264, 'Lyons', 'Lyons', 'Lajons,liyonja,lywnz,lywnz  jarjya,lywnz  jwrjya,Лајонс,ليونز,لیونز، جارجیا,لیونز، جورجیا,लीयोंज', 32.2043500, -82.3217900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132265, 'Mableton', 'Mableton', 'Mejblton,mebalatana,Мејблтон,مابلیٹون، جارجیا,मेबलटन', 33.8187200, -84.5824300, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132266, 'Macon', 'Macon', 'Fort Hawkins,MCN,Macon,Maiikon,Makon,Mejkon,Newtown,Tiger Town,Troy,makn  jwrjya,makwn,mei ken,meikeon,meikon,myakona,mykn  jarjya,myyqwn,Μαίηκον,Макон,Мейкон,Мејкон,מייקון,ماكون,ماکن، جورجیا,میکن، جارجیا,म्याकोन,メイコン,梅肯,메이컨', 32.8406900, -83.6324000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132267, 'Madison', 'Madison', 'Madison,Medison,Mehdison,madyswn,mdyswn  jwrjya,myadisana,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مدیسون، جورجیا,میڈیسن، جارجیا,म्याडिसन', 33.5956800, -83.4679400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132268, 'Manchester', 'Manchester', 'Manchester,manshstr,mnchstr  jwrjya,myanacestara,Манчестер,مانشستر,مانچسٹر، جارجیا,منچستر، جورجیا,म्यानचेस्टर', 32.8598500, -84.6199300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132269, 'Marietta', 'Marietta', 'MGE,Marieta,Marietta,Marijeta,ma li ai ta,maelieta,mari''eta,marietta,maryta,mryta  jwrjya,Мариета,Мариетта,Маријета,ماريتا,مریتا، جورجیا,مریٹا، جارجیا,मारिएटा,マリエッタ,玛丽埃塔,매리에타', 33.9526000, -84.5499300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132270, 'Marshallville', 'Marshallville', 'Marshallville,Marshalvil,Martialville,marsalabhila,marshal wyl  jwrjya,marshalfyl,marshl wyl  jarjya,Маршалвил,مارشال ویل، جورجیا,مارشالفيل,مارشل ویل، جارجیا,मार्शलभिल', 32.4562600, -83.9401900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132271, 'Martinez', 'Martinez', 'Martines,Мартинес', 33.5173600, -82.0756700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132272, 'Maysville', 'Maysville', 'Maysville,Maysville Station', 34.2528800, -83.5615500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132273, 'McCaysville', 'McCaysville', 'Harpertown,Hawkinstown,McCaysville', 34.9861900, -84.3713100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132274, 'McDonough', 'McDonough', 'Makdona,makdwnw,mikadanoh,mk dnw  jwrjya,mk dwnw  jarjya,Макдона,ماكدونو,مک دنو، جورجیا,مک دونو، جارجیا,मिकडनोः', 33.4473400, -84.1468600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132275, 'McRae', 'McRae', 'MQW,Makrej,makray,mikare,mk rayy  jwrjya,Макреј,ماكراي,مک رائی، جورجیا,مک رائے، جارجیا,मिकरे', 32.0679500, -82.9007000, 'US', '2017-03-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132276, 'Meigs', 'Meigs', '', 31.0724100, -84.0890700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132277, 'Metter', 'Metter', 'Meter,mettara,mtr  jwrjya,mytr,Метер,متر، جورجیا,ميتر,میٹر، جارجیا,मेट्टर', 32.3971200, -82.0601200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132278, 'Midway', 'Midway', 'Arcadia,Medway,Midway', 31.8057700, -81.4306600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132279, 'Milledgeville', 'Milledgeville', 'MLJ,Milledgeville', 33.0801400, -83.2321000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132280, 'Millen', 'Millen', 'Milen,Millen,Millen Junction,Millen Station,Old Seventynine,Seventy Nine,milena,myln,myln  jarjya,myln  jwrjya,Милен,ميلن,میلن، جارجیا,میلن، جورجیا,मिलेन', 32.8040500, -81.9492800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132281, 'Monroe', 'Monroe', 'Monro,Monroe,Walton Court House,men luo,meonlo,monro,munro,mwnrw,mwnrw  jwrjya,Монро,مونرو,مونرو، جورجیا,مونروئے، جارجیا,मुन्रो,モンロー,门罗,먼로', 33.7948400, -83.7132300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132282, 'Montezuma', 'Montezuma', 'Montezuma,montejuma,mwntyzwma,mwntyzwma  jarjya,mwntzwma  jwrjya,Монтезума,مونتزوما، جورجیا,مونتيزوما,مونتیزوما، جارجیا,मोन्तेजुमा', 32.3051600, -84.0274100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132283, 'Montgomery', 'Montgomery', 'Montgomeri,Монтгомери', 31.9404900, -81.1220500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132284, 'Monticello', 'Monticello', 'Montiselo,mantyslw  jwrjya,montiselo,mwntayslw,mwnty sylw  jarjya,Монтисело,مانتیسلو، جورجیا,مونتايسلو,مونتی سیلو، جارجیا,मोन्टिसेलो', 33.3048500, -83.6832300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132285, 'Morgan', 'Morgan', '', 31.5376700, -84.5993600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132286, 'Morrow', 'Morrow', 'Big Shanty,Marrow,Morou,Morrow,Morrow Station,Morrows Station,marw  jwrjya,morro,mwrw,mwrw  jarjya,Мороу,مارو، جورجیا,مورو,مورو، جارجیا,मोर्रो', 33.5831700, -84.3393700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132287, 'Mount Airy', 'Mount Airy', '', 34.5187100, -83.5007300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132288, 'Moultrie', 'Moultrie', 'MGR,Moltri,Moultrie,Ochlocknee,Ocklockney,maultri,mwltry,mwltry  jwrjya,Молтри,مولتري,مولتری، جورجیا,مولٹری، جارجیا,मौल्ट्री', 31.1799100, -83.7890600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132289, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,ma''unta bharnona,mawnt fyrnwn,mwnt wrnn  jwrjya,Маунт Вернон,ماؤنٹ ورنن، جارجیا,ماونت فيرنون,مونت ورنن، جورجیا,माउन्ट भर्नोन', 32.1785100, -82.5945800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132290, 'Mount Zion', 'Mount Zion', '', 33.6342800, -85.1871700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132291, 'Mount Zion', 'Mount Zion', '', 33.3612500, -83.0076500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132292, 'Mountain City', 'Mountain City', 'Mountain City,Passover', 34.9181500, -83.3854400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132293, 'Mountain Park', 'Mountain Park', '', 33.8442700, -84.1293600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132294, 'Nahunta', 'Nahunta', 'Nahunta,Nejkhanta,Victoria,nahanta  jwrjya,nahunta,nahwnta,Нејханта,ناهانتا، جورجیا,ناهونتا,ناہنٹا، جارجیا,नाहुन्टा', 31.2043900, -81.9812300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132295, 'Nashville', 'Nashville', 'Nashvill,Neshvil,n''yasabhila,nashfyl,nshwyl  jarjya,nshwyl  jwrjya,Нашвилл,Нешвил,ناشفيل,نشویل، جارجیا,نشویل، جورجیا,न्याशभिल', 31.2074200, -83.2501500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132296, 'Nelson', 'Nelson', '', 34.3820400, -84.3710300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132297, 'Newnan', 'Newnan', 'Bullsboro,N''junan,Newman,Newnan,Njunan,n''yun''yana,nyuneon,nywnan,nywnn  jarjya,nywnn  jwrjya,Њунан,Ньюнан,نيونان,نیونن، جارجیا,نیونن، جورجیا,न्युन्यान,뉴넌', 33.3806700, -84.7996600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132298, 'Newton', 'Newton', 'N''juton,Njuton,n''yutana,nywtn,nywtn  jwrjya,Њутон,Ньютон,نيوتن,نیوتن، جورجیا,نیوٹن، جارجیا,न्युटन', 31.3129600, -84.3357400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132299, 'Nicholls', 'Nicholls', 'Nicholls,Nichols', 31.5174200, -82.6348600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132300, 'Nicholson', 'Nicholson', 'Cooper,Nicholson', 34.1140000, -83.4315500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132301, 'Norcross', 'Norcross', 'Norkros,narasrasa,nwrkras  jarjya,nwrkras  jwrjya,nwrkrws,Норкрос,نوركروس,نورکراس، جارجیا,نورکراس، جورجیا,नरस्रस', 33.9412100, -84.2135300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132302, 'North Atlanta', 'North Atlanta', '', 33.8651000, -84.3365900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132303, 'North Decatur', 'North Decatur', '', 33.7903800, -84.3060300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132304, 'North Druid Hills', 'North Druid Hills', '', 33.8167700, -84.3132600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132305, 'Oakwood', 'Oakwood', '', 34.2276000, -83.8843500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132306, 'Oakwood', 'Oakwood', '', 33.5481700, -83.9743500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132307, 'Ocilla', 'Ocilla', 'Osila,asyla  jwrjya,awkyla,awsyla  jarjya,osilla,Осила,أوكيلا,اسیلا، جورجیا,اوسیلا، جارجیا,ओसिल्ला', 31.5944700, -83.2513000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132308, 'Oglethorpe', 'Oglethorpe', '', 32.2937700, -84.0610200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132309, 'Omega', 'Omega', 'Omega,Surrey', 31.3410200, -83.5935000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132310, 'Oxford', 'Oxford', 'Oksford,Оксфорд', 33.6190000, -83.8674100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132311, 'Palmetto', 'Palmetto', 'Palmeto,Palmetto,Palmetto Station,balmytw,palmeto,palmtw  jwrjya,Палмето,بالميتو,پالمتو، جورجیا,پالمیٹو، جارجیا,पाल्मेटो', 33.5178900, -84.6696500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132312, 'Panthersville', 'Panthersville', 'Panthersville,Pantherville', 33.7073300, -84.2718700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132313, 'Peachtree City', 'Peachtree City', 'Pichtri Siti,bytshtry syty,picatri siti,pychtry syty  jwrjya,Пичтри Сити,بيتشتري سيتي,پیچ ٹری سٹی، جارجیا,پیچتری سیتی، جورجیا,पीचट्री सिटी', 33.3967800, -84.5957600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132314, 'Peachtree Corners', 'Peachtree Corners', 'byshtry kwrnrz,pychtry krnrz  jwrjya,بيشتري كورنرز,پیچ ٹری کورنرز، جارجیا,پیچتری کرنرز، جورجیا', 33.9701000, -84.2215900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132315, 'Pearson', 'Pearson', 'Pirson,byrswn,pirasana,pyrsn  jarjya,pyrswn  jwrjya,Пирсон,بيرسون,پیرسن، جارجیا,پیرسون، جورجیا,पीरसन', 31.2977000, -82.8523700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132316, 'Pelham', 'Pelham', 'Pelam,bylham,pelahyama,plham  jwrjya,Пелам,بيلهام,پلهام، جورجیا,پلہام، جارجیا,पेलह्याम', 31.1280200, -84.1530400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132317, 'Pembroke', 'Pembroke', '', 32.1363400, -81.6234800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132318, 'Perry', 'Perry', 'Peri,Perri,Perry,Wattsville,byry,peri,pry  jwrjya,pyry  jarjya,Пери,Перри,Перрі,بيري,پری، جورجیا,پیری، جارجیا,पेरी', 32.4582100, -83.7315700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132319, 'Pine Mountain', 'Pine Mountain', '', 33.6759400, -84.1149200, 'US', '2010-02-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132320, 'Pine Mountain', 'Pine Mountain', 'Chipley,Harris,Hood,Old Hood,Pine Mountain', 32.8648500, -84.8541000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132321, 'Pooler', 'Pooler', '', 32.1154800, -81.2470600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132322, 'Port Wentworth', 'Port Wentworth', '', 32.1490900, -81.1631700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132323, 'Porterdale', 'Porterdale', 'Porterdale,Steadman', 33.5751100, -83.8938000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132324, 'Powder Springs', 'Powder Springs', 'Gunpowder Springs,Pauder Springs,Powder Springs,Powdersprings,Springfield,bwdr sbrynghz,pa''udara springas,pwdraspryng  jwrjya,Паудер Спрингс,بودر سبرينغز,پاؤڈر سپرنگز، جارجیا,پودراسپرینگ، جورجیا,पाउडर स्प्रिङ्गस्', 33.8595500, -84.6838200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132325, 'Preston', 'Preston', 'Lannahassee,Preston', 32.0659900, -84.5374200, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132326, 'Putney', 'Putney', 'Hardaway Station,Putney', 31.4701800, -84.1176800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132327, 'Quitman', 'Quitman', 'Kvitman,kvitamyana,kwyytmn  jwrjya,kywytman,Квитман,كيويتمان,کوئیتمن، جورجیا,کوئیٹ مین، جارجیا,क्विटम्यान', 30.7849200, -83.5598800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132328, 'Raoul', 'Raoul', '', 34.4495400, -83.5943400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132329, 'Ray City', 'Ray City', 'Ray City,Rays Mill,Rays Mills,Rays Pond', 31.0746400, -83.1993200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132330, 'Redan', 'Redan', 'Redan,Редан', 33.7453800, -84.1315800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132331, 'Reed Creek', 'Reed Creek', '', 34.4459400, -82.9248700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132332, 'Reidsville', 'Reidsville', 'Ridsvil,ridsabhila,rydsfyl,rydzwyl  jwrjya,Ридсвил,ريدسفيل,ریدزویل، جورجیا,ریڈزویل، جارجیا,रीड्सभिल', 32.0868600, -82.1179000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132333, 'Remerton', 'Remerton', '', 30.8440900, -83.3104300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132334, 'Reynolds', 'Reynolds', '', 32.5598700, -84.0963000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132335, 'Richland', 'Richland', 'Box Ankle,Chisholm,Richland,Richlend,ricalyanda,rychlnd  jwrjya,rytshland,Ричланд,Ричленд,ريتشلاند,رچلینڈ، جارجیا,ریچلند، جورجیا,रिचल्यान्ड', 32.0879300, -84.6674200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132336, 'Richmond Hill', 'Richmond Hill', 'Crossroads,Richmond Hill,Richmond Hill Plantation,Sterlings Bluff,Ways,Ways Station', 31.9382700, -81.3034400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132337, 'Rincon', 'Rincon', '', 32.2960300, -81.2353900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132338, 'Ringgold', 'Ringgold', 'Cross Roads,Ringgold,Ringold,Taylors Cross Roads,ringagolda,ryng gld  jwrjya,rynghwld,Ринголд,رنگ گولڈ، جارجیا,رينغولد,رینگ گلد، جورجیا,रिंगगोल्ड', 34.9159100, -85.1091200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132339, 'Riverdale', 'Riverdale', 'Rapes Crossing,Riverdale,Riverdejl,ribharadela,ryfrdyl,rywrdyl  jwrjya,Ривердејл,ريفرديل,ریوردیل، جورجیا,ریورڈیل، جارجیا,रिभरडेल', 33.5726100, -84.4132600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132340, 'Rochelle', 'Rochelle', 'Rochelle,Vineyard', 31.9510100, -83.4562700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132341, 'Rockmart', 'Rockmart', 'Rock Market,Rock Mart,Rockmart,Rokmart,rakamarta,rakmart  jwrjya,rwkmart,Рокмарт,راکمارت، جورجیا,راکمارٹ، جارجیا,روكمارت,रकमार्ट', 34.0026000, -85.0416100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132342, 'Rome', 'Rome', 'Chihara,Head of Coosa,RMG,Rom,Rome,Roum,lom,rm  jwrjya,roma,romu,rwm  jarjya,rwma,Ром,Роум,رم، جورجیا,روم، جارجیا,روما,रोम,ローム,롬', 34.2570400, -85.1646700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132343, 'Roswell', 'Roswell', 'Roswell,Rozvel,lojeuwel,luo si wei er,rosvela,rwzwl  jarjya,rwzwyl,rzwl  jwrjya,Розвел,رزول، جورجیا,روزول، جارجیا,روزويل,रोस्वेल,罗斯韦尔,로즈웰', 34.0231600, -84.3615900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132344, 'Rossville', 'Rossville', 'Popular Springs,Rossville,Rosvil,rasabhila,rwsfyl,rwzwyl  jarjya,rzwyl  jwrjya,Росвил,رزویل، جورجیا,روزویل، جارجیا,روسفيل,रसभिल', 34.9831300, -85.2860700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132345, 'Royston', 'Royston', 'Rojston,ro''ijtana,rwystwn,rwystwn  jwrjya,Ројстон,روئسٹن، جارجیا,رويستون,رویستون، جورجیا,रोइज्टन', 34.2870500, -83.1101500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132346, 'Russell', 'Russell', '', 33.9787200, -83.7001700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132347, 'Rydal', 'Rydal', '', 34.3353700, -84.7154900, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132348, 'St. Marys', 'St. Marys', 'Saint Mary,Saint Mary''s,Saint Marys,Saint Patrick,Sainte Marie,Sent Meriz,St. Marys,sant maryz,santa merij,synt marys  jwrjya,Сент Мериз,سانت ماريز,سینت ماریس، جورجیا,سینٹ میریز، جارجیا,सन्त मेरीज्', 30.7305100, -81.5464900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132349, 'Saint Simon Mills', 'Saint Simon Mills', 'Saint Simon Mills,Saint Simon''s Mills,Saint Simons Mills', 31.1707900, -81.4073200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132350, 'Saint Simons Island', 'Saint Simons Island', 'Saint Simon Island,Saint Simons,Saint Simons Island,Saint Simons Village,St. Simons,St. Simons Island', 31.1505100, -81.3695400, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132351, 'Sandersville', 'Sandersville', 'Sandersvil,Sandersville,Saunders Cross Road,Saunders Cross Roads,Saundersville,sandrfyl,sndrzwyl  jwrjya,syandarsabhila,Сандерсвил,ساندرفيل,سندرزویل، جورجیا,سینڈرزویل، جارجیا,स्यान्डर्सभिल', 32.9815400, -82.8101400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132352, 'Sandy Springs', 'Sandy Springs', 'Burdal,Sandi-Springs,Sandy Springs,Sendi Springs,sandisupuringusu,sandy sbrynghz,sang di si pu lin si,sndy aspryng  jwrjya,syandi springas,Санди-Спрингс,Санді-Спрінгс,Сенди Спрингс,ساندي سبرينغز,سندی اسپرینگ، جورجیا,سینڈی سپرنگز، جارجیا,स्यान्डी स्प्रिङ्गस्,サンディスプリングス,桑迪斯普林斯', 33.9242700, -84.3785400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132353, 'Sardis', 'Sardis', '', 32.7965200, -84.6388100, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132354, 'Savannah', 'Savannah', 'Gorad Savana,SAV,Sarannah,Savana,Savanah,Savanna,Savannah,Sawanna,Yamacraw,sa fan na,saban''na,sabhana,safana,savhana,sawana  jwrjya,seobaeneo,sha wa na,Горад Савана,Савана,Саванна,סאוואנאה,סוואנה,سافانا,ساوانا، جورجیا,ساواناہ، جارجیا,सभाना,सव्हाना,サバンナ,沙瓦納,薩凡納,서배너', 32.0835400, -81.0998300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132355, 'Scottdale', 'Scottdale', '', 33.7898300, -84.2640900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132356, 'Senoia', 'Senoia', '', 33.3023400, -84.5538200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132357, 'Shannon', 'Shannon', '', 34.3367600, -85.0713400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132358, 'Shannon', 'Shannon', '', 33.4045600, -84.4682600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132359, 'Skidaway Island', 'Skidaway Island', '', 31.9349400, -81.0470500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132360, 'Smyrna', 'Smyrna', 'Neal Dow,Smirna,Smyrna,Varners Station,asmyrna  jwrjya,shi mai na,smirna,smrna  jarjya,smyrna,Смирна,اسمیرنا، جورجیا,سمرنا، جارجیا,سميرنا,स्मीर्ना,士麦那', 33.8839900, -84.5143800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132361, 'Snellville', 'Snellville', 'Snell,Snellville,Snelvil,asnlwyl  jwrjya,snelabhila,snyl wyl  jarjya,snylfyl,Снелвил,اسنلویل، جورجیا,سنيلفيل,سنیل ویل، جارجیا,स्नेलभिल', 33.8573300, -84.0199100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132362, 'Social Circle', 'Social Circle', '', 33.6562300, -83.7182300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132363, 'Soperton', 'Soperton', '', 32.3771200, -82.5923600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132364, 'Sparks', 'Sparks', 'Afton,Sparks,Спаркс', 31.1668600, -83.4373800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132365, 'Sparks', 'Sparks', 'Mayview,Sparks', 33.0879300, -82.7376400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132366, 'Sparta', 'Sparta', 'Montour Village,Old Factory,Sparta,asparta  jwrjya,sbarta,sparta,Спарта,اسپارتا، جورجیا,سبارتا,سپارٹا، جارجیا,स्पार्टा', 33.2757000, -82.9762600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132367, 'Springfield', 'Springfield', 'Springfild,aspryng fyld  jwrjya,sbrynghfyld,springaphilda,Спрингфилд,Спрінгфілд,اسپرینگ فیلد، جورجیا,سبرينغفيلد,سپرنگ فیلڈ، جارجیا,स्प्रिङ्गफिल्ड', 32.3724100, -81.3115000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132368, 'Statenville', 'Statenville', 'Statenville,Statesville,Troublesome', 30.7032700, -83.0276400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132369, 'Statesboro', 'Statesboro', 'Statesboro,Statesborough,TBR', 32.4487900, -81.7831700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132370, 'Statham', 'Statham', 'Barbers Creek,De Lay,Delay,Statham', 33.9651100, -83.5965500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132371, 'Stockbridge', 'Stockbridge', 'Stokbridz,astwk bryj  jwrjya,stakabrija,stwkbrydj,Стокбриџ,استوک بریج، جورجیا,ستوكبريدج,سٹاک برج، جارجیا,स्टकब्रिज', 33.5442800, -84.2338100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132372, 'Stone Mountain', 'Stone Mountain', 'New Gibralter,Stone Mountain', 33.8081600, -84.1702000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132373, 'Sugar Hill', 'Sugar Hill', '', 34.1064900, -84.0335200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132374, 'Summerville', 'Summerville', 'Samervil,samarabhila,samrfyl,samrwyl  jwrjya,smrwyl  jarjya,Самервил,سامرفيل,سامرویل، جورجیا,سمرویل، جارجیا,समरभिल', 34.4806400, -85.3477300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132375, 'Sunnyside', 'Sunnyside', '', 31.2393800, -82.3420700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132376, 'Suwanee', 'Suwanee', 'Suvejni,Suwanee,Suwannee,sawany  jwrjya,suvani,swany,swany  jarjya,Сувејни,ساوانی، جورجیا,سواني,سوانی، جارجیا,सुवानी', 34.0514900, -84.0713000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132377, 'Swainsboro', 'Swainsboro', 'Paris,Svejnsboro,Swainsboro,Swainsborough,svenasbaro,swaynzbrw  jwrjya,swynsbwrgh,swynzbrw  jarjya,Свејнсборо,سواینزبرو، جورجیا,سوينسبورغ,سوینزبرو، جارجیا,स्वेनस्बरो', 32.5973900, -82.3337400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132378, 'Sylvania', 'Sylvania', 'Old Siccum,Silvejnija,Sylvania,silbhyaniya,sylfanya,sylwanya  jarjya,sylwanya  jwrjya,Силвејнија,سيلفانيا,سیلوانیا، جارجیا,سیلوانیا، جورجیا,सील्भ्यानिया', 32.7504400, -81.6367800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132379, 'Sylvester', 'Sylvester', 'Isabella Station,Silvester,Silvestur,Sylvester,silbhestara,sylfstr,sylwstr  jwrjya,Силвестер,Силвестър,سيلفستر,سیلوستر، جورجیا,سیلویسٹر، جارجیا,सील्भेस्टर', 31.5309200, -83.8369300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132380, 'Talbotton', 'Talbotton', 'Tolboton,talbatn  jwrjya,talbotatana,talbwtwn,Толботон,تالباتن، جورجیا,تالبوتون,ٹالبٹن، جارجیا,ताल्बोटटन', 32.6776400, -84.5393700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132381, 'Tallapoosa', 'Tallapoosa', 'Possum Snout,Talabouchi,Talapoosa,Talapusa,Tallapoosa,talabwsa,talapusa,talapwsa  jwrjya,Талапуса,تالابوسا,تالاپوسا، جورجیا,ٹالاپوسا، جارجیا,टालापूसा', 33.7445500, -85.2880100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132382, 'Temple', 'Temple', 'Ringers Cross Road,Temple', 33.7370500, -85.0324400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132383, 'Tennille', 'Tennille', 'Station Number 13,Tennelle,Tennille', 32.9359900, -82.8115300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132384, 'Thomasville', 'Thomasville', 'TVI,Tomasvil,thomasabhila,tomeoseubil,twmas wyl  jwrjya,twmasfyl,Томасвил,توماس ویل، جورجیا,توماسفيل,ٹامسویل، جارجیا,थोमसभिल,토머스빌', 30.8365800, -83.9787800, 'US', '2017-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132385, 'Thomaston', 'Thomaston', 'Tomaston,thomasatana,twmastwn,twmastwn  jwrjya,Томастон,توماستون,توماستون، جورجیا,ٹامسٹن، جارجیا,थोमसटन', 32.8881900, -84.3265900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132386, 'Thomson', 'Thomson', 'Frogpond,Hickory Level,Slashes,Thomson,Tomson,tamswn  jwrjya,thamsana,twmswn,Томсон,تامسون، جورجیا,طومسون,ٹامسن، جارجیا,थम्सन', 33.4706900, -82.5045700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132387, 'Thunderbolt', 'Thunderbolt', 'Thunder Bolt,Thunderbolt,Warsaw,Wassaw', 32.0335400, -81.0498300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132388, 'Tifton', 'Tifton', 'Lena,TMA,Tifton,tiphtana,tyftwn,tyftwn  jwrjya,Тифтон,تيفتون,تیفتون، جورجیا,ٹفٹن، جارجیا,टिफ्टन', 31.4504600, -83.5085000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132389, 'Toccoa', 'Toccoa', 'Dry Pond,TOC,Toccoa,Toccoa City,Tokoa,toko''a,tokoa,tuo ke a,twkwa,twkwa  jwrjya,Токоа,توكوا,توکوآ، جورجیا,ٹوکوآ، جارجیا,टोकोआ,トコア,托科阿', 34.5773200, -83.3323900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132390, 'Trenton', 'Trenton', 'Salem,Trenton,trentana,trntn  jwrjya,tryntwn,Трентон,ترنتن، جورجیا,ترينتون,ٹرینٹن، جارجیا,ट्रेन्टन', 34.8720200, -85.5091300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132391, 'Trion', 'Trion', 'Island Town,Trion,Trion Factory,Trion Station', 34.5439700, -85.3105100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132392, 'Tucker', 'Tucker', 'Taker,takara,Такер,टकर', 33.8545500, -84.2171400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132393, 'Twin City', 'Twin City', 'Graymont,Summit,Twin City', 32.5829400, -82.1551200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132394, 'Tybee Island', 'Tybee Island', 'Savannah Beach,Tajbi Ajland,Tajbi-Ajlend,Tybee Island,ta''ibi a''ilyanda,taibi dvip,tayabi,tayby aylnd  jwrjya,tyby ayland,Тайби-Айленд,Тайбі-Айленд,Тајби Ајланд,تایبی آیلند، جورجیا,تيبي أيلاند,ٹائی بی آئی لینڈ، جارجیا,टाइबी आइल्यान्ड,टायबी,ടൈബീ ദ്വീപ്', 32.0002200, -80.8456700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132395, 'Tyrone', 'Tyrone', 'Jay Bird,Tyrone', 33.4712300, -84.5971500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132396, 'Unadilla', 'Unadilla', '', 32.2615500, -83.7365700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132397, 'Union City', 'Union City', 'Junion-Siti,Юнион-Сити', 33.5870600, -84.5424300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132398, 'Union Point', 'Union Point', 'Cross Road,Scruggs,Scruggsville,Thornton,Thorntons,Thorntons Cross Roads,Thorntons Crossroads,Union Point', 33.6156800, -83.0746000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132399, 'Unionville', 'Unionville', '', 31.4349100, -83.5096100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132400, 'Valdosta', 'Valdosta', 'Troupville,VLD,Valdosta,barudosuta,bhyaladosta,faldwsta,waldsta  jwrjya,Валдоста,فالدوستا,والدستا، جورجیا,والڈوسٹا، جارجیا,भ्यालडोस्टा,バルドスタ', 30.8333400, -83.2803200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132401, 'Varnell', 'Varnell', 'Red Hill,Varnell,Varnells Station', 34.9011900, -84.9738300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132402, 'Vidalia', 'Vidalia', 'VDI,Vajdejlija,Vidalia,bhidaliya,fydalya,wydalya  jwrjya,Вајдејлија,فيداليا,وڈالیا، جارجیا,ویدالیا، جورجیا,भिडालिया', 32.2176900, -82.4134600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132403, 'Vienna', 'Vienna', 'Berrien,Brownville,Centerville,Centreville,Vajena,Vienna,bhi''ena,fyyna,wyna  jarjya,wyna  jwrjya,Вајена,فيينا,وینا، جارجیا,وینا، جورجیا,भिएना', 32.0915600, -83.7954500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132404, 'Villa Rica', 'Villa Rica', 'Hicktown,Hix Town,Hixtown,Vila Rika,Villa Rica,bhilla rika,fyla ryka,wyla ryka  jarjya,wylaryka  jwrjya,Вила Рика,فيلا ريكا,ویلا ریکا، جارجیا,ویلاریکا، جورجیا,भिल्ला रिका', 33.7320500, -84.9191100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132405, 'Vinings', 'Vinings', 'Crossroads,Vinings,Vinings Bridge,Vinings Station', 33.8648300, -84.4643700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132406, 'Wadley', 'Wadley', 'Bethany,Shake Rag,Wadley', 32.8668200, -82.4040200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132407, 'Walnut Grove', 'Walnut Grove', 'Walnut Grove,Walnutgrove', 33.7426100, -83.8524000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132408, 'Walthourville', 'Walthourville', 'Lambert,Sandhills,Walthourville,Walthourville Station', 31.7741000, -81.6326100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132409, 'Warner Robins', 'Warner Robins', 'Uorner-Robins,Vorner Robins,Vorner-Robins,WRB,Warner Robins,Wellston,York,varnara rabinsa,warnr rwbynz,warnrrabynz  jwrjya,warnz rwbnz  jarjya,Ворнер Робинс,Ворнер-Робінс,Уорнер-Робинс,وارنر روبينز,وارنررابینز، جورجیا,وارنز روبنز، جارجیا,वार्नर रबिन्स', 32.6157400, -83.6266400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132410, 'Warrenton', 'Warrenton', 'Vorenton,warntn  jwrjya,waryntwn,Ворентон,وارنتن، جورجیا,وارنٹن، جارجیا,وارينتون', 33.4070800, -82.6620800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132411, 'Washington', 'Washington', 'Fort Washington,Heards Fort,Vashington,Washington,vasingatana,washntn,washyngtn  jwrjya,Вашингтон,واشنطن,واشنگٹن، جارجیا,واشینگتن، جورجیا,वाशिङ्गटन', 33.7367900, -82.7393100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132412, 'Watkinsville', 'Watkinsville', 'Big Spring,Votkinsvil,Watkinsville,vatkingsabhila,watkynsfyl,Воткинсвил,واتكينسفيل,वाट्किंग्सभिल', 33.8629000, -83.4087700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132413, 'Waycross', 'Waycross', 'AYS,Old Nine,Pendleton,Station Number 9,Tebeauville,Vejkros,Way Cross,Waycross,Yankee Town,vekrasa,waykrws,wykras  jwrjya,Вејкрос,وايكروس,ویکراس، جورجیا,وے کراس، جارجیا,वेक्रस', 31.2136800, -82.3557000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132414, 'Waynesboro', 'Waynesboro', 'Vejnsboro,Waynesboro,Waynesborough,venasbro,waynysbwrw,wynyzbwrw  jarjya,wynzbrw  jwrjya,Вејнсборо,واينيسبورو,وینزبرو، جورجیا,وینیزبورو، جارجیا,वेनस्ब्रो', 33.0898700, -82.0156700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132415, 'West Point', 'West Point', 'Franklin,Vest Pojnt,West Point,Westpoint,vesta po''inta,wstpynt  jwrjya,wyst bwynt,Вест Појнт,وستپینت، جورجیا,ويست بوينت,वेस्ट पोइन्ट', 32.8779100, -85.1832700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132416, 'West Point', 'West Point', '', 32.7934700, -83.8074100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132417, 'Whitemarsh Island', 'Whitemarsh Island', '', 32.0288200, -81.0167800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132418, 'Willacoochee', 'Willacoochee', 'Willacoochee,Willicoochee', 31.3407600, -83.0459800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132419, 'Wilmington Island', 'Wilmington Island', '', 32.0035500, -80.9737200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132420, 'Winder', 'Winder', 'Brandon,Jug Tavern,Jug Tavern Crossroads,Snodon,The Jug,Vajnder,WDR,Winder,vindara,wyndr,wyndr  jwrjya,Вајндер,ونڈر، جارجیا,ويندر,ویندر، جورجیا,विन्डर', 33.9926100, -83.7201700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132421, 'Winterville', 'Winterville', 'Winters,Winters Station,Winterville', 33.9670600, -83.2782100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132422, 'Woodbine', 'Woodbine', 'Vudbajn,vudaba''ina,wwdbayn,wwdbayn  jwrjya,Вудбајн,وودباين,وودباین، جورجیا,ووڈبائن، جارجیا,वूडबाइन', 30.9639600, -81.7241600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132423, 'Woodstock', 'Woodstock', 'Vudstok,vudstaka,wu de si tuo ke,wwdastwk  jwrjya,wwdstwk,Вудсток,ووداستوک، جورجیا,وودستوك,ووڈسٹاک، جارجیا,वूड्स्टक,伍德斯托克', 34.1014900, -84.5193800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132424, 'Wrens', 'Wrens', '', 33.2076500, -82.3917900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132425, 'Wrightsville', 'Wrightsville', '', 32.7293300, -82.7198600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132426, 'Young Harris', 'Young Harris', 'Jang Kharis,McTyeire,Young Harris,yang harys  jwrjya,yanga hyaris,ywngh harys,Јанг Харис,يونغ هاريس,یانگ هاریس، جورجیا,یونگ ہررس، جارجیا,यंग ह्यारिस्', 34.9331500, -83.8471200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132427, 'Zebulon', 'Zebulon', '', 33.1023500, -84.3427000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132428, 'Albers', 'Albers', '', 38.5433800, -89.6123100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132429, 'Albion', 'Albion', 'Albion,albywn,albywn  aylynwy,elbiyana,Албион,آلبیون، ایلینوی,ألبيون,البیون، الینوائے,एल्बियन', 38.3775500, -88.0561500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132430, 'Alorton', 'Alorton', 'Alorton,Fireworks', 38.5897700, -90.1201100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132431, 'Altamont', 'Altamont', 'Altamont,altamonta,altamwnt,altamwnt  aylynwy,Алтамонт,آلتامونت، ایلینوی,ألتامونت,المتامونت، الینوائے,अल्तामोन्ट', 39.0619900, -88.7481100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132432, 'Alton', 'Alton', 'ALN,Olton,altana,altwn,altwn  aylynwy,eltana,Олтон,آلتون، ایلینوی,آلٹن، الینوائے,ألتون,आल्टन,एल्टन', 38.8906000, -90.1842800, 'US', '2017-06-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132433, 'Anna', 'Anna', 'Ana,an''na,ana,ana  aylynwy,enna,Ана,آنا,آنا، الینوائے,آنا، ایلینوی,एन्ना,アンナ', 37.4603300, -89.2470300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132434, 'Arcola', 'Arcola', '', 39.6847600, -88.3064400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132435, 'Arthur', 'Arthur', 'Arther,Arthur', 39.7147600, -88.4722800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132436, 'Ashland', 'Ashland', '', 39.8878300, -90.0078900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132437, 'Assumption', 'Assumption', '', 39.5203200, -89.0489700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132438, 'Athens', 'Athens', 'Ejtens,athyna,atn  aylynwy,ethensa,Ејтенс,آتن، ایلینوی,أثينا,ایتھنز، الینوائے,एथेन्स', 39.9608800, -89.7239900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132439, 'Atwood', 'Atwood', '', 39.7994800, -88.4622800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132440, 'Auburn', 'Auburn', '', 39.5917200, -89.7464900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132441, 'Aviston', 'Aviston', 'Aviston,Aviston Station,Hecker', 38.6067200, -89.6075900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132442, 'Barry', 'Barry', 'Barry,Worcester', 39.6942100, -91.0390200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132443, 'Beckemeyer', 'Beckemeyer', 'Beckemeyer,Buxton', 38.6056000, -89.4359200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132444, 'Bement', 'Bement', '', 39.9219800, -88.5720100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132445, 'Benld', 'Benld', 'Beneld,ben er de,benlda,bnld,bnld  aylynwy,Бенелд,بنلد,بنلد، ایلینوی,بنلڈ، الینوائے,बेन्ल्ड,本尔德', 39.0928200, -89.8039800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132446, 'Benton', 'Benton', 'Benton,benatana,benteon,bntwn,bntwn  aylynwy,Бентон,بنتون,بنتون، ایلینوی,بینٹن، الینوائے,बेनटन,벤턴', 37.9967200, -88.9200700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132447, 'Bethalto', 'Bethalto', 'Betalto,bethalo,bthaltw,Беталто,بثالتو,बेथालो', 38.9092100, -90.0406600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132448, 'Bethany', 'Bethany', '', 39.6455900, -88.7381300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132449, 'Belleville', 'Belleville', 'Bellvill,Belvil,belbil,belebhila,berubiru,blfyl,blwyl  aylynwy,Белвил,Беллвилл,Беллвілл,بلفيل,بلویل، ایلینوی,بیلویل، الینوائے,बेलेभिल,ベルビル,벨빌', 38.5200500, -89.9839900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132450, 'Blue Mound', 'Blue Mound', 'Blue Mound,Bluemound', 39.7011500, -89.1231400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132451, 'Breese', 'Breese', 'Breese,Briz,Shoal Creek,brisa,brys,bryz  aylynwy,Бриз,بريس,بریز، الینوائے,بریز، ایلینوی,ब्रीस', 38.6106000, -89.5270300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132452, 'Bridgeport', 'Bridgeport', '', 38.7058800, -87.7600300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132453, 'Brighton', 'Brighton', 'Brajton,Брайтон', 39.0397700, -90.1406600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132454, 'Bunker Hill', 'Bunker Hill', 'Bunker Hill,Bunkerhill,Lincoln,Wolf Ridge', 39.0428200, -89.9517700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132455, 'Cahokia', 'Cahokia', 'Cahokia,Cahos,Canokia,Caokia,Caoquias,Caouaouce,Cohokies,Fort Bowman,Kahokia,Kahokias,Kakhokija,Kaohia,Kaos,Notre Dame des Kohokias,Sainte Famille des Kaoquias,kahwkya,kyahokiya,Кахокија,كاهوكيا,क्याहोकिया', 38.5708800, -90.1901100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132456, 'Cairo', 'Cairo', 'CIR,Kejro,Kero,alqahrt,kai luo,kairo,qahrh  aylynwy,qhyr,siyaro,Кейро,Керо,קהיר,القاهرة,قاهره، ایلینوی,کائرو، الینوائے,सियरो,カイロ,开罗', 37.0053300, -89.1764600, 'US', '2017-06-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132457, 'Cambria', 'Cambria', 'Cambria,Reeves', 37.7814400, -89.1192500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132458, 'Carbondale', 'Carbondale', '', 37.7272700, -89.2167500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132459, 'Carlinville', 'Carlinville', 'Karlinvil,karalinabhila,karlynfyl,karlynwyl  aylynwy,Карлинвил,كارلينفيل,کارلنویل، الینوائے,کارلینویل، ایلینوی,कारलिनभिल', 39.2797700, -89.8817700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132460, 'Carlyle', 'Carlyle', 'Carlisle,Carlyle,Fredonia,Karlajl,karalili,karlayl  aylynwy,karlyl,Карлајл,كارليل,کارلائل، الینوائے,کارلایل، ایلینوی,कारलीली', 38.6103300, -89.3725800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132461, 'Carmi', 'Carmi', 'Karmaj,karmi,karmy  aylynwy,krmy,Кармај,كرمي,کارمی، الینوائے,کارمی، ایلینوی,कार्मी', 38.0908800, -88.1586500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132462, 'Carrier Mills', 'Carrier Mills', 'Carrier Mills,Carrier''s Mills,Carriers Mills,Cat Hide,Cat Skin,Morrillsville', 37.6842200, -88.6328300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132463, 'Carrollton', 'Carrollton', 'Karolton,kaeleolteon,karwltwn,karwltwn  aylynwy,kyarolatana,Каролтон,كارولتون,کارلٹن، الینوائے,کارولتون، ایلینوی,क्यारोलटन,캐럴턴', 39.3022700, -90.4070600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132464, 'Carterville', 'Carterville', 'Kartervil,kartarabhila,kartrwyl  aylynwy,Картервил,کارترویل، ایلینوی,کیٹرویل، الینوائے,कार्टरभिल', 37.7600500, -89.0773000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132465, 'Casey', 'Casey', '', 39.2992000, -87.9925300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132466, 'Caseyville', 'Caseyville', '', 38.6367200, -90.0256600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132467, 'Central City', 'Central City', '', 38.5489400, -89.1270100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132468, 'Centralia', 'Centralia', 'ENL,Sentrejlija,sntrylya  aylynwy,syntralya,Сентрејлија,سنتریلیا، ایلینوی,سينتراليا,سینٹریلیا، الینوائے', 38.5250500, -89.1334000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132469, 'Centreville', 'Centreville', 'Centerville,Centreville,Fireworks,Sentervil,sentarabhila,sntrfyl,sntrwyl  aylynwy,Сентервил,سنترفيل,سنترویل، ایلینوی,سینٹرویل، الینوائے,सेन्टरभिल', 38.5833800, -90.1251100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132470, 'Cerro Gordo', 'Cerro Gordo', 'Cerro Gordo,Cerrogordo', 39.8905900, -88.7281300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132471, 'Charleston', 'Charleston', 'Charlston,carlsatana,charlztwn  aylynwy,tsharlstwn,Чарлстон,تشارلستون,چارلزتون، ایلینوی,چارلسٹن، الینوائے,चार्ल्सटन', 39.4961500, -88.1761500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132472, 'Chatham', 'Chatham', '', 39.6761600, -89.7045400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132473, 'Chester', 'Chester', 'Chester,cestara,chstr  aylynwy,qie si te,tshystr,Честер,تشيستر,چستر، ایلینوی,چیسٹر، الینوائے,चेस्टर,切斯特', 37.9136600, -89.8220500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132474, 'Chrisman', 'Chrisman', '', 39.8036500, -87.6736400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132475, 'Christopher', 'Christopher', 'Kristofer,Kristofur,krisatapahara,krystwfr,krystwfr  aylynwy,Кристофер,Кристофър,كريستوفر,کرسٹوفر، الینوائے,کریستوفر، ایلینوی,क्रिसटपहर', 37.9725500, -89.0534100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132476, 'Cobden', 'Cobden', 'Cobden,Cobden Station,South Pass', 37.5314400, -89.2534200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132477, 'Collinsville', 'Collinsville', 'Kolinsvil,Kollinsvil'',klynsfyl,klynzwyl  aylynwy,kolinsabhila,Колинсвил,Коллинсвиль,كلينسفيل,کلینزویل، ایلینوی,کولنزویل، الینوائے,कोलिन्सभिल', 38.6703300, -89.9845500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132478, 'Columbia', 'Columbia', 'Kolambija,Kolumbija,klmbya  aylynwy,kolambiya,kwlwmbya,Коламбија,Колумбия,كولومبيا,کلمبیا، ایلینوی,کولمبیا، الینوائے,कोलम्बिया', 38.4436600, -90.2012200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132479, 'Crainville', 'Crainville', '', 37.7519900, -89.0678500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132480, 'De Soto', 'De Soto', 'De Soto,Desoto', 37.8175500, -89.2278600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132481, 'Decatur', 'Decatur', 'DEC,Decatur,Dekaturo,Dekejter,Dekejtur,dekatara,di kai te,dikatura,dikeiteo,diketa,diketara,dikhe the xr,dykadwr,dykytwr  aylynwy,Декейтер,Декејтур,ديكادور,دیکیتور، ایلینوی,ڈیکاٹر، الینوائے,डिकॅटर,डेकाटर,ডিকাটুর,ดิเคเทอร์,ディケーター,迪凯特,디케이터', 39.8403100, -88.9548000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132482, 'Divernon', 'Divernon', '', 39.5656100, -89.6573200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132483, 'Du Quoin', 'Du Quoin', 'Du Quoin,Du Quoin City,Duquoin', 38.0114400, -89.2361900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132484, 'Dupo', 'Dupo', '', 38.5161600, -90.2103900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132485, 'East Alton', 'East Alton', '', 38.8803300, -90.1112200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132486, 'East Saint Louis', 'East Saint Louis', 'East Saint Louis,East St. Louis,Illinoistown', 38.6245000, -90.1509400, 'US', '2013-07-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132487, 'Edinburg', 'Edinburg', 'Edinburg,Edinburgh,Ehdinburg,Эдинбург', 39.6572700, -89.3895300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132488, 'Edwardsville', 'Edwardsville', 'Edvardsvil,adwardzwyl  aylynwy,adwrdsfyl,edvardasbhila,Едвардсвил,إدوردسفيل,ادواردزویل، ایلینوی,ایڈورڈزویل، الینوائے,एड्वार्डस्भिल', 38.8114400, -89.9531600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132489, 'Effingham', 'Effingham', 'Efingkham,afynghm,ephingahyama,Ефингхам,إفينغم,افینگ‌هام، ایلینوی,ایفنگھم، الینوائے,एफिंगह्याम', 39.1200400, -88.5433800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132490, 'Eldorado', 'Eldorado', 'El Dorado,Eldorado,Eldorejdo,aldwradw,aldwradw  aylynwy,eldorado,Елдорејдо,إلدورادو,الدورادو، ایلینوی,ایل ڈوراڈو، الینوائے,एल्डोराडो', 37.8136600, -88.4381000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132491, 'Elizabethtown', 'Elizabethtown', 'Ehlizabettaun,Элизабеттаун', 37.4458800, -88.3050400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132492, 'Energy', 'Energy', 'Energy,Fordville', 37.7739400, -89.0264600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132493, 'Fairfield', 'Fairfield', 'Ferfild,Feurfild,fyrfyld,fyrfyld  aylynwy,pheyaraphilda,Ферфилд,Феърфилд,فيرفيلد,فیئرفیلڈ، الینوائے,فیرفیلد، ایلینوی,फेयरफिल्ड', 38.3789400, -88.3597700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132494, 'Fairmont City', 'Fairmont City', 'Fairmont City,Fairmount City,Willow Town', 38.6497700, -90.0931600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132495, 'Fairview Heights', 'Fairview Heights', 'Fairview,Fairview Heights', 38.5889400, -89.9903800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132496, 'Flora', 'Flora', 'Flora,flwra,flwra  aylynwy,phlora,Флора,فلورا,فلورا، الینوائے,فلورا، ایلینوی,फ्लोरा', 38.6689400, -88.4856000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132497, 'Forsyth', 'Forsyth', 'Forsyth,Forsythe', 39.9325400, -88.9511900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132498, 'Freeburg', 'Freeburg', 'Freeburg,Freeburgh', 38.4275500, -89.9137100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132499, 'Georgetown', 'Georgetown', '', 39.9753100, -87.6358500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132500, 'Germantown', 'Germantown', 'Germantown,Hanover', 38.5536600, -89.5384200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132501, 'Gillespie', 'Gillespie', 'Gilespi,Gillispie,ghylysby,glspy  aylynwy,jilepsi,Гилеспи,غيليسبي,گلسپی، الینوائے,گلسپی، ایلینوی,जिलेप्सी', 39.1297700, -89.8195400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132502, 'Glen Carbon', 'Glen Carbon', 'Glen Carbon,Glen Karbon,Peters,ghln karbwn,glena karbana,Глен Карбон,غلن كاربون,ग्लेन कार्बन', 38.7483800, -89.9831600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132503, 'Girard', 'Girard', 'Girard,Otter Creek,Pleasant Grove,Waytown', 39.4464400, -89.7809300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132504, 'Godfrey', 'Godfrey', 'Gadfri,Godfrey,Godfrey Station,Monticello,gadphre,ghwdfry,Гадфри,غودفري,गड्फ्रे', 38.9556000, -90.1867800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132505, 'Golconda', 'Golconda', 'Golconda,Sarahsville', 37.3672700, -88.4864300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132506, 'Goreville', 'Goreville', 'Goresville,Goreville', 37.5545000, -88.9722900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132507, 'Grandview', 'Grandview', '', 39.8164400, -89.6187100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132508, 'Granite City', 'Granite City', 'Granit Siti,Granite City,Kinder,ghranyt syty,grena''ita siti,Гранит Сити,غرانيت سيتي,گرانیت‌سیتی، ایلینوی,گرینائٹ سٹی، الینوائے,ग्रेनाइट सिटी', 38.7014400, -90.1487200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132509, 'Grayville', 'Grayville', 'Bonpas,Florence,Graysville,Grayville,Oxford', 38.2575500, -87.9936400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132510, 'Greenfield', 'Greenfield', 'Grinfild,Гринфилд', 39.3436600, -90.2126100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132511, 'Greenup', 'Greenup', '', 39.2478200, -88.1633700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132512, 'Greenville', 'Greenville', 'GRE,Grinvil,Grinvill,ghrynfyl,grinabhila,Гринвил,Гринвилл,غرينفيل,گرینویل، الینوائے,گرین‌ویل، ایلینوی,ग्रीनभिल', 38.8922700, -89.4131400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132513, 'Griggsville', 'Griggsville', 'Grigsvil,Grigsville,ghryghsfyl,grigsabhila,grygzwyl  aylynwy,Григсвил,غريغسفيل,گرگزویل، الینوائے,گریگزویل، ایلینوی,ग्रिग्सभिल', 39.7089400, -90.7245700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132514, 'Hardin', 'Hardin', '', 39.1567100, -90.6179000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132515, 'Harrisburg', 'Harrisburg', 'Garrisberg,Garrisburg,Harrisburg,Harrisburgh,Kharisburg,haeliseubeogeu,harysbwrgh,hryzbrg  aylynwy,hyarisabarga,Гаррисберг,Гаррісбург,Харисбург,هاريسبورغ,هریزبرگ، ایلینوی,ہیرزبرگ، الینوائے,ह्यारिसबर्ग,해리스버그', 37.7383800, -88.5406100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132516, 'Harristown', 'Harristown', '', 39.8539300, -89.0839700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132517, 'Hartford', 'Hartford', 'Hartford,Khartford,Saint Marie,Хартфорд', 38.8333800, -90.0959400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132518, 'Herrin', 'Herrin', 'Herrin,Herrin''s Prairie,Kherin,herrina,hryn  aylynwy,hyryn,Херин,هرین، ایلینوی,هيرين,ہیرین، الینوائے,हेर्रिन', 37.8031100, -89.0275700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132519, 'Highland', 'Highland', 'Khajland,hayland,haylnd  aylynwy,Хајланд,هايلاند,هایلند، ایلینوی,ہائی لینڈ، الینوائے', 38.7394900, -89.6712000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132520, 'Hillsboro', 'Hillsboro', 'Hillsboro,Hillsborough,Khillsboro,Хиллсборо', 39.1612800, -89.4954000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132521, 'Holiday Shores', 'Holiday Shores', '', 38.9219900, -89.9406600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132522, 'Ina', 'Ina', '', 38.1511600, -88.9039600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132523, 'Jacksonville', 'Jacksonville', 'Dzeksonvil,Dzheksonvill,IJX,Jacksonville,jakswnfyl,jyakasanabhila,Џексонвил,Джексонвилл,جاكسونفيل,جکسون‌ویل، ایلینوی,جیکسن ویل، الینوائے,ज्याकसनभिल', 39.7339400, -90.2290100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132524, 'Jerome', 'Jerome', '', 39.7675500, -89.6806600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132525, 'Jerseyville', 'Jerseyville', 'Dzerzivil,Hickory Grove,Jerseyville,jarsibhila,jyrsyfyl,Џерзивил,جرزی‌ویل، ایلینوی,جرسی ویل، الینوائے,جيرسيفيل,जर्सीभिल', 39.1200500, -90.3284500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132526, 'Johnston City', 'Johnston City', '', 37.8206100, -88.9275700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132527, 'Jonesboro', 'Jonesboro', 'Dzhonsboro,Dzounsboro,Jonesboro,Jonesborough,janzbrw  aylynwy,jonsbro,jwnzbwrw,Џоунсборо,Джонсборо,جانزبرو، ایلینوی,جونزبورو,جونزبورو، الینوائے,जोन्स्ब्रो', 37.4517200, -89.2681400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132528, 'Kincaid', 'Kincaid', '', 39.5886600, -89.4145400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132529, 'Lawrenceville', 'Lawrenceville', 'LWV,Lawrenceville', 38.7292100, -87.6816900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132530, 'Lebanon', 'Lebanon', 'Lebanon,lbnan,lbnan  aylynwy,lebanan,Лебанон,لبنان,لبنان، الینوائے,لبنان، ایلینوی,लेबानन्', 38.6039400, -89.8073200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132531, 'Leland Grove', 'Leland Grove', '', 39.7770000, -89.6792700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132532, 'Litchfield', 'Litchfield', 'Lichfild,licaphilda,lytshfyld,Личфилд,ليتشفيلد,لچ فیلڈ، الینوائے,لیچ‌فیلد، ایلینوی,लिचफिल्ड', 39.1753300, -89.6542600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132533, 'Long Creek', 'Long Creek', 'Long Creek,Longcreek', 39.8119800, -88.8475700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132534, 'Louisville', 'Louisville', 'Louis,Louis Station,Louisville,Luisvil,Луисвил', 38.7722700, -88.5025500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132535, 'Lovington', 'Lovington', '', 39.7155900, -88.6325600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132536, 'Macon', 'Macon', 'Macon,Makon,Mejkon,South Macon,makwn,makwn  aylynwy,mei ken,myakana,Макон,Мејкон,ماكون,ماکون، الینوائے,ماکون، ایلینوی,म्याकन,梅肯', 39.7128200, -88.9970200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132537, 'Madison', 'Madison', 'Madison,Medison,Mehdison,madyswn,madyswn  aylynwy,myadisana,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مادیسون، ایلینوی,میڈیسن، الینوائے,म्याडिसन', 38.6825500, -90.1570500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132538, 'Marion', 'Marion', 'MWA,Mehrion,Merion,marino,marion,marywn,marywn  aylynwy,Мерион,Мэрион,ماريون,ماریون، الینوائے,ماریون، ایلینوی,मारिनो,マリオン', 37.7306100, -88.9331300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132539, 'Marissa', 'Marissa', '', 38.2500500, -89.7501000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132540, 'Marshall', 'Marshall', 'Marshal,Marshall,marsala,marshal,marshal  aylynwy,Маршал,Маршалл,مارشال,مارشال، ایلینوی,مارشل، الینوائے,मार्शल', 39.3914300, -87.6936400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132541, 'Martinsville', 'Martinsville', 'Martinsvil,maratinsabhila,martynsfyl,martynz wyl  aylynwy,Мартинсвил,مارتينسفيل,مارتینز ویل، ایلینوی,مارٹنز ویل، الینوائے,मारटिन्सभिल', 39.3355900, -87.8819800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132542, 'Maryville', 'Maryville', '', 38.7236600, -89.9559300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132543, 'Mascoutah', 'Mascoutah', 'Mascoutah,Maskuta,Mechanicsburg,maskwta  aylynwy,maskwtah,myaskotha,Маскута,ماسكوتاه,ماسکوتا، الینوائے,ماسکوتا، ایلینوی,म्यास्कोथा', 38.4903300, -89.7931500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132544, 'Mattoon', 'Mattoon', 'Matun,ma dun,matwn,mtwn  aylynwy,myattona,Матун,ماتون,متون، ایلینوی,میٹن، الینوائے,म्याट्टोन,马顿', 39.4830900, -88.3728300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132545, 'McLeansboro', 'McLeansboro', 'Maklejnsboro,McLeansboro,McLeansborough,maekeulleinjeubeoleo,mai ke lai en si bo lei,maklynsbwrw,mikaleyanasbaro,mklynz bwrw  aylynwy,Маклејнсборо,ماكلينسبورو,مکلینز بورو، الینوائے,مکلینز بورو، ایلینوی,मिकलेयनस्बरो,麦克莱恩斯伯勒,매클레인즈버러', 38.0933800, -88.5356100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132546, 'Meredosia', 'Meredosia', 'Marais d''Ogee,Meredosha,Meredosia', 39.8311600, -90.5595700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132547, 'Metropolis', 'Metropolis', 'Metropolis,Metropolis City,mei te luo bo li si,metoroporisu,metropolisa,mtrwbwlys,mtrwpwlys  aylynwy,Метрополис,متروبوليس,متروپولیس، ایلینوی,میٹروپولس، الینوائے,मेट्रोपोलिस,メトロポリス,梅特罗波利斯', 37.1511700, -88.7320000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132548, 'Millstadt', 'Millstadt', '', 38.4614400, -90.0917800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132549, 'Mitchell', 'Mitchell', 'Mitchell,Mitchell Station', 38.7619900, -90.0853800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132550, 'Morrisonville', 'Morrisonville', '', 39.4200500, -89.4556500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132551, 'Mound City', 'Mound City', 'Maund Siti,ma''unda siti,mwnd syty  aylynwy,mwndy syty,Маунд Сити,موند سیتی، ایلینوی,موندي سيتي,مونڈ سٹی، الینوائے,माउन्ड सिटी', 37.0853300, -89.1625700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132552, 'Mount Carmel', 'Mount Carmel', 'Karmel,Karmel'',Karmelberget,Karmelbjerget,Karmelgebergte,Karmelio kalnas,Maunt Karmel,Mont Carmel,Monte Carmelo,Monto Karmel,Mount Carmel,krml,ma''unta karamela,maunteukameol,mawnt krml,Кармель,Маунт Кармел,כרמל,ماؤنٹ کارمل، الینوائے,ماونت كرمل,مونت‌کارمل، ایلینوی,माउन्ट कारमेल,마운트카멀', 38.4108800, -87.7614200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132553, 'Mount Olive', 'Mount Olive', 'Maunt Oliv,ma''unta olibha,mawnt awlyf,Маунт Олив,ماؤنٹ اولائیو، الینوائے,ماونت أوليف,مونت‌الیو، ایلینوی,माउन्ट ओलिभ', 39.0722700, -89.7273100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132554, 'Mount Sterling', 'Mount Sterling', 'Maunt Sterling,ma''unta staralinga,mawnt alastrlyny,Маунт Стерлинг,ماؤنٹ سٹرلنگ، الینوائے,ماونت الاسترليني,مونت‌استرلینگ، ایلینوی,माउन्ट स्टरलिङ्ग', 39.9872700, -90.7634600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132555, 'Mount Vernon', 'Mount Vernon', 'MVN,Maunt Vernon,Mount Vernon,Mt. Vernon,ma''unta bharnona,Маунт Вернон,ماؤنٹ ورنن، الینوائے,माउन्ट भर्नोन', 38.3172700, -88.9031200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132556, 'Mount Zion', 'Mount Zion', '', 39.7714300, -88.8742400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132557, 'Moweaqua', 'Moweaqua', '', 39.6247600, -89.0189700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132558, 'Murphysboro', 'Murphysboro', 'Merfisboro,Murphysboro,Murphysborough,mafizuboro,marphisbaro,meopijeubeoleo,mwrfysbwrw,Мерфисборо,مورفيسبورو,مورفیس بورو، الینوائے,مورفیس‌بورو، ایلینوی,मर्फीस्बरो,マーフィーズボロ,머피즈버러', 37.7645000, -89.3350900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132559, 'Nashville', 'Nashville', 'Nashvill,Neshvil,n''yasabhila,nashfyl,Нашвилл,Нешвил,ناش ویل، الینوائے,ناشفيل,ناش‌ویل، ایلینوی,न्याशभिल', 38.3436600, -89.3806400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132560, 'Neoga', 'Neoga', 'Nioga,ne''oga,nywga  aylynwy,nywgha,Ниога,نئوگا، ایلینوی,نيوغا,نیوگا، الینوائے,नेओगा', 39.3194800, -88.4528300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132561, 'New Athens', 'New Athens', 'Athens,New Athens', 38.3264400, -89.8770500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132562, 'New Baden', 'New Baden', '', 38.5350500, -89.7006500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132563, 'New Berlin', 'New Berlin', 'Novyj Berlin,Новый Берлин', 39.7253300, -89.9106600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132564, 'Nokomis', 'Nokomis', '', 39.3011600, -89.2850800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132565, 'Norris City', 'Norris City', '', 37.9811600, -88.3292100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132566, 'O''Fallon', 'O''Fallon', '', 38.5922700, -89.9112100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132567, 'Oblong', 'Oblong', '', 39.0019900, -87.9089200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132568, 'Odin', 'Odin', '', 38.6172700, -89.0522900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132569, 'Okawville', 'Okawville', 'Okau,Okawville', 38.4342200, -89.5503700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132570, 'Olney', 'Olney', 'OLY,Olney,Olni,awlny,awlny  aylynwy,olni,Олни,أولني,اولنی، الینوائے,اولنی، ایلینوی,ओल्नी', 38.7308800, -88.0853200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132571, 'Palestine', 'Palestine', '', 39.0036500, -87.6128000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132572, 'Pana', 'Pana', 'Pejna,bana,pana  aylynwy,Пејна,بانا,پانا، الینوائے,پانا، ایلینوی', 39.3889300, -89.0800800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132573, 'Paris', 'Paris', 'Parizh,Peris,barys,parys  aylynwy,Париж,Перис,باريس,پاریس، ایلینوی,پیرس، الینوائے', 39.6111500, -87.6961400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132574, 'Pawnee', 'Pawnee', '', 39.5917200, -89.5803700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132575, 'Payson', 'Payson', '', 39.8169900, -91.2423700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132576, 'Pinckneyville', 'Pinckneyville', 'Pinknivil,bynknyfyl,Пинкнивил,بينكنيفيل,پنکن ویل، الینوائے,پینک‌نویل، ایلینوی', 38.0803300, -89.3820300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132577, 'Pittsfield', 'Pittsfield', 'Pitsfild,bytsfyld,Питсфилд,بيتسفيلد,پٹس فیلڈ، الینوائے,پیتس‌فیلد، ایلینوی', 39.6078300, -90.8051300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132578, 'Pontoon Beach', 'Pontoon Beach', '', 38.7317200, -90.0803800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132579, 'Quincy', 'Quincy', 'Bluffs,Gem City,Kuinsi,Kvinsi,Quincy,UIN,kwinsi,kwynsy,kwyynsy  aylynwy,Квинси,Куинси,كوينسي,کوئنسی، الینوائے,کوئینسی، ایلینوی,퀸시', 39.9356000, -91.4098700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132580, 'Ramsey', 'Ramsey', 'Rehmsi,Рэмси', 39.1444900, -89.1086800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132581, 'Red Bud', 'Red Bud', '', 38.2117200, -89.9942700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132582, 'Riverton', 'Riverton', 'Howlett,Jamestown,Judys Ferry,Riverton,Ривертон', 39.8442200, -89.5395400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132583, 'Robinson', 'Robinson', 'Robinson,rabynswn  aylynwy,rwbnswn,Робинсон,رابنسن، الینوائے,رابینسون، ایلینوی,روبنسون', 39.0053200, -87.7391900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132584, 'Rochester', 'Rochester', 'Rochester,Рочестер', 39.7494900, -89.5317600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132585, 'Roodhouse', 'Roodhouse', 'Rood House,Roodhouse', 39.4839400, -90.3715100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132586, 'Rosewood Heights', 'Rosewood Heights', '', 38.8878300, -90.0848300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132587, 'Rosiclare', 'Rosiclare', 'Rose Clare,Roseclair,Rosiclare', 37.4236600, -88.3461500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132588, 'Roxana', 'Roxana', '', 38.8483800, -90.0762200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132589, 'Royalton', 'Royalton', '', 37.8769900, -89.1145200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132590, 'Saint Elmo', 'Saint Elmo', '', 39.0272700, -88.8481100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132591, 'Saint Jacob', 'Saint Jacob', 'Saint Jacob,Saint Jacobs', 38.7139400, -89.7681500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132592, 'Salem', 'Salem', 'Sejlem,salm,salm  aylynwy,Сейлем,Сејлем,سالم,سالم، ایلینوی,سیلم، الینوائے', 38.6269900, -88.9456200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132593, 'Sandoval', 'Sandoval', '', 38.6156000, -89.1142300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132594, 'Sesser', 'Sesser', '', 38.0917200, -89.0503500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132595, 'Shawneetown', 'Shawneetown', 'New Shawneetown Station,Shawneetown,Shonitaun,shawnytawn,shawnytwn  aylynwy,Шонитаун,شاونيتاون,شاونی ٹاؤن، الینوائے,شاونیتون، ایلینوی', 37.7131000, -88.1867000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132596, 'Shelbyville', 'Shelbyville', 'Shelbivil,shylbyfyl,Шелбивил,شلبی ویل، الینوائے,شلبی‌ویل، ایلینوی,شيلبيفيل', 39.4064300, -88.7900700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132597, 'Sherman', 'Sherman', 'Sherman,Шерман', 39.8936600, -89.6048200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132598, 'Shiloh', 'Shiloh', '', 38.5614400, -89.8973200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132599, 'Smithton', 'Smithton', '', 38.4086600, -89.9920500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132600, 'South Jacksonville', 'South Jacksonville', '', 39.7086600, -90.2281800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132601, 'South Roxana', 'South Roxana', '', 38.8294900, -90.0628800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132602, 'Southern View', 'Southern View', '', 39.7572700, -89.6537100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132603, 'Sparta', 'Sparta', 'SAR', 38.1231100, -89.7017700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132604, 'Springfield', 'Springfield', 'Campifons,Gorad Spryngfild,SPI,Sprin''nkfilnt,Springfield,Springfijld,Springfild,Springfilda,Springfildas,Springfilds,Springfīlda,Sprinqfild,icuppirinhpilt,sbrynj fyld  alynwy,seupeulingpildeu,si pu lin fei er de,sprimphilda,springaphilda,springfild,spryngpyld,supuringufirudo,Σπρίνγκφιλντ,Горад Спрынгфілд,Спрингфиелд,Спрингфийлд,Спрингфилд,Спрингфілд,Սփրինգֆիլդ,ספרינגפילד,اسپرنگ فیلڈ، الینوائے,اسپرینگ‌فیلد,سبرينج فيلد، إلينوي,سپرنگفیلڈ,स्प्रिंगफील्ड,स्प्रिङ्गफिल्द,স্প্রিংফিল্ড,இசுப்பிரிங்ஃபீல்ட்,สปริงฟิลด์,スプリングフィールド,斯普林菲尔德,스프링필드', 39.8017200, -89.6437100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132605, 'Staunton', 'Staunton', 'Stonton,Стонтон', 39.0122700, -89.7912100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132606, 'Steeleville', 'Steeleville', 'Steeles Mills,Steelesville,Steeleville', 38.0072700, -89.6584300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132607, 'Sullivan', 'Sullivan', 'Salivan,swlyfan,swlywan  aylynwy,Саливан,سوليفان,سولیوان، الینوائے,سولیوان، ایلینوی', 39.5994800, -88.6078400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132608, 'Sumner', 'Sumner', '', 38.7169900, -87.8614200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132609, 'Swansea', 'Swansea', '', 38.5339400, -89.9889900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132610, 'Taylorville', 'Taylorville', 'Tejlorvil,tlwrfyl,tylwr wyl  aylynwy,Тејлорвил,تلورفيل,تیلور ویل، ایلینوی,ٹیلرویل، الینوائے', 39.5489400, -89.2945300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132611, 'Teutopolis', 'Teutopolis', '', 39.1331000, -88.4719900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132612, 'Toledo', 'Toledo', 'Majority Point,Prairie City,Toledo,Толедо', 39.2736500, -88.2436500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132613, 'Tolono', 'Tolono', '', 39.9861400, -88.2589400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132614, 'Trenton', 'Trenton', 'Trenton,Трентон', 38.6056000, -89.6820400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132615, 'Troy', 'Troy', 'Columbia,Troj,Troja,Troy,trwy,trwy  aylynwy,Троя,Трој,تروي,تروی، ایلینوی,ٹروئے، الینوائے', 38.7292100, -89.8831500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132616, 'Tuscola', 'Tuscola', 'Taskola,taskola,twskwla,twskwla  aylynwy,Таскола,توسكولا,توسکولا، ایلینوی,ٹسکولا، الینوائے,টাস্কোলা', 39.7992000, -88.2831000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132617, 'Upper Alton', 'Upper Alton', '', 38.9114400, -90.1506600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132618, 'Valmeyer', 'Valmeyer', '', 38.3056100, -90.2765100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132619, 'Vandalia', 'Vandalia', 'VLA,Vandalia,Vandejlija,fandalya,vu~andaria,wandalya  aylynwy,Вандејлија,فانداليا,واندالیا، ایلینوی,وینڈالیا، الینوائے,ヴァンダリア', 38.9606000, -89.0936800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132620, 'Venice', 'Venice', 'Venecija,Венеция', 38.6722700, -90.1698300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132621, 'Vienna', 'Vienna', 'Vajena,fyyna,wyn  aylynwy,Вајена,فيينا,وین، ایلینوی,وینا، الینوائے', 37.4153300, -88.8978400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132622, 'Villa Grove', 'Villa Grove', 'Villa Grove,Villagrove', 39.8628100, -88.1622700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132623, 'Virden', 'Virden', '', 39.5008900, -89.7678700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132624, 'Virginia', 'Virginia', 'Virdzinija,Virginia,Virginia City,frjynya,wyrjynya  aylynwy,Вирџинија,فرجينيا,ورجینیا، الینوائے,ویرجینیا، ایلینوی', 39.9511600, -90.2123400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132625, 'Wamac', 'Wamac', '', 38.5089400, -89.1406300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132626, 'Warrensburg', 'Warrensburg', '', 39.9328200, -89.0620300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132627, 'Washington Park', 'Washington Park', '', 38.6350500, -90.0928900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132628, 'Waterloo', 'Waterloo', 'Vaterlo,Voterlu,watrlw,watrlw  aylynwy,Ватерло,Вотерлу,واترلو,واترلو، ایلینوی,واٹرلو، الینوائے', 38.3358900, -90.1498300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132629, 'Wayne City', 'Wayne City', '', 38.3453300, -88.5878300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132630, 'Waverly', 'Waverly', '', 39.5917200, -89.9528800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132631, 'West Frankfort', 'West Frankfort', 'Vest Frankfort,wst frankfwrt  aylynwy,wyst frankfwrt,Вест Франкфорт,وست فرانکفورت، ایلینوی,ويست فرانكفورت,ویسٹ فرینکفرٹ، الینوائے', 37.8978300, -88.9314600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132632, 'White Hall', 'White Hall', 'Loafers'' Grove,Vajt Khol,White Hall,Whitehall,wayt hal,wayt hal  aylynwy,Вајт Хол,وائٹ ہال، الینوائے,وايت هال,وایت هال، ایلینوی', 39.4369900, -90.4031800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132633, 'Williamsville', 'Williamsville', 'Benton,Williamsville', 39.9542200, -89.5487100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132634, 'Winchester', 'Winchester', 'Vinchester,wynchstr  aylynwy,wynshstr,Винчестер,ونچسٹر، الینوائے,وينشستر,وینچستر، ایلینوی', 39.6297700, -90.4562400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132635, 'Windsor', 'Windsor', 'Vindzor,Виндзор', 39.4408700, -88.5947800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132636, 'Wood River', 'Wood River', 'Vud River,wwd ryfr,wwd rywr  aylynwy,Вуд Ривер,وود ريفر,وود ریور، ایلینوی,ووڈ ریور، الینوائے', 38.8611600, -90.0976100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132637, 'Worden', 'Worden', '', 38.9314400, -89.8389900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132638, 'Zeigler', 'Zeigler', '', 37.8994900, -89.0520200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132639, 'Austin', 'Austin', 'Ostin,Остин', 38.7583900, -85.8080300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132640, 'Avon', 'Avon', 'Avon,Avon Station,Hampton,Smootsdell,Whitelink', 39.7628200, -86.3997200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132641, 'Bargersville', 'Bargersville', '', 39.5208800, -86.1677700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132642, 'Batesville', 'Batesville', 'Bartsville,Bates Ville,Batesville,HLB,Middleton', 39.3000500, -85.2221800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132643, 'Bedford', 'Bedford', 'BFR,Bedford,Бедфорд', 38.8611600, -86.4872100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132644, 'Beech Grove', 'Beech Grove', 'Beech Grove,Beech Grove Farm,Bich Grouv,bych grw  ayndyana,Бич Гроув,بیچ گرو، ایندیانا,بیچ گروو، انڈیانا', 39.7219900, -86.0899800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132645, 'Bicknell', 'Bicknell', '', 38.7742100, -87.3077900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132646, 'Bloomfield', 'Bloomfield', 'Bloomfield,Bloomington,Blumfild,Блумфилд,بلوم فیلڈ، انڈیانا', 39.0269900, -86.9375100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132647, 'Bloomington', 'Bloomington', 'BMG,Bloomington,Blumington,Blumingtona,Blumingtun,Blūmingtona,beullumingteon,blumintana,blwmnghtwn,blwmyngtwn,blwmyngtwn  ayndyana,bu lu ming dun,buruminton,Блумингтон,Блумингтън,Блумінгтон,בלומינגטון,بلومنغتون,بلومنگٹن، انڈیانا,بلومینگتون، ایندیانا,ব্লুমিংটন,ブルーミントン,布卢明顿,블루밍턴', 39.1653300, -86.5263900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132648, 'Boonville', 'Boonville', 'Booneville,Boonsboro,Boonsville,Boonville', 38.0492100, -87.2741700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132649, 'Brazil', 'Brazil', 'Brazil,brazila,brzyl  ayndyana,Бразил,برزیل، ایندیانا,ब्राज़ील', 39.5236500, -87.1250200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132650, 'Bright', 'Bright', 'Bright,Bunkuin', 39.2183900, -84.8560600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132651, 'Broad Ripple', 'Broad Ripple', '', 39.8667100, -86.1416500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132652, 'Brooklyn', 'Brooklyn', 'Bruklin,Бруклин', 39.5392100, -86.3691600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132653, 'Brookville', 'Brookville', 'Brooksville,Brookville,Brukvil,brwkwyl  ayndyana,Бруквил,بروکویل، ایندیانا', 39.4231100, -85.0127400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132654, 'Brownsburg', 'Brownsburg', 'Brownsburg,Brownsburgh,Harrisburg,Harrisburgh', 39.8433800, -86.3977700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132655, 'Brownstown', 'Brownstown', '', 38.8789400, -86.0419200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132656, 'Cambridge City', 'Cambridge City', '', 39.8125500, -85.1716300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132657, 'Cannelton', 'Cannelton', 'Cannelsburg,Cannelton,Cannelton Heights,Kanelton,Kannelton,kanyltwn,knltwn  ayndyana,Канелтон,Каннелтон,كانيلتون,کنلتون، ایندیانا,کینلٹن، انڈیانا', 37.9114400, -86.7444300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132658, 'Carmel', 'Carmel', 'Bethleham,Bethlehem,Carmel,Karmel,Karmel'',ka mei er,kameol,kameru,karml,karml  ayndyana,Кармел,Кармель,كارمل,کارمل، انڈیانا,کارمل، ایندیانا,カーメル,卡梅尔,카멀', 39.9783700, -86.1180400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132659, 'Cayuga', 'Cayuga', 'Cayuga,Eugene Station', 39.9486500, -87.4597400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132660, 'Centerville', 'Centerville', 'Centerville,Centreville,Sentervil,sntrfyl,Сентервил,سنترفيل,سینٹرویل، انڈیانا', 39.8178200, -84.9963500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132661, 'Chandler', 'Chandler', 'Chandler,Чандлер', 38.0417100, -87.3680600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132662, 'Charlestown', 'Charlestown', 'Charlstaun,cha er si dui,charlztawn  ayndyana,sharlstwn,Чарлстаун,شارلستون,چارلزتاون، ایندیانا,چارلس ٹاؤن، انڈیانا,查尔斯敦', 38.4531200, -85.6702400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132663, 'Clarksville', 'Clarksville', 'Clarksville,Clarkville,Klarksvil,ke la ke si wei er,klarksfyl,Кларксвил,كلاركسفيل,کلارکسویل، انڈیانا,克拉克斯维尔', 38.2967400, -85.7599600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132664, 'Clermont', 'Clermont', 'Clermont,Mechanicsburg,Mechanicsburgh', 39.8097700, -86.3224900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132665, 'Clinton', 'Clinton', 'Klinton,Клинтон', 39.6569800, -87.3980700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132666, 'Cloverdale', 'Cloverdale', 'Clover Dale,Cloverdale', 39.5147700, -86.7939000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132667, 'Columbus', 'Columbus', 'CLU,Columbus,Kolambus,Kolumbus,Tiptonia,ge lun bu,klmbws  ayndyana,koronbasu,kwlwmbws,Коламбус,Колумбус,كولومبوس,کلمبوس، ایندیانا,کولمبس، انڈیانا,コロンバス,哥伦布', 39.2014400, -85.9213800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132668, 'Connersville', 'Connersville', 'CEV,Konersvil,kanrzwyl  ayndyana,kwnrsfyl,Конерсвил,كونرسفيل,کانرزویل، ایندیانا,کونرزویل، انڈیانا', 39.6411600, -85.1410700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132669, 'Corydon', 'Corydon', 'Koridon,ke luo yi deng,kolideun,kwraydwn,Коридон,كورايدون,克罗伊登,코리든', 38.2120100, -86.1219200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132670, 'Country Squire Lakes', 'Country Squire Lakes', 'Country Squire Lakes,County Squire Lakes', 39.0347800, -85.6985800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132671, 'Crothersville', 'Crothersville', 'Crothersville,Haysville', 38.8006100, -85.8416400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132672, 'Cumberland', 'Cumberland', 'Kamberlend,Камберленд', 39.7761500, -85.9572000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132673, 'Dale', 'Dale', 'Dale,Elizabeth', 38.1689400, -86.9900000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132674, 'Danville', 'Danville', 'Danvil,danfyl,Данвил,دانفيل', 39.7606000, -86.5263900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132675, 'Darmstadt', 'Darmstadt', 'Darmstadt,Darnstadt', 38.0992100, -87.5789100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132676, 'Dillsboro', 'Dillsboro', 'Dillsboro,Dillsborough', 39.0178300, -85.0588400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132677, 'Edinburgh', 'Edinburgh', 'Edinburg,Edinburgh', 39.3542200, -85.9666600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132678, 'Ellettsville', 'Ellettsville', 'Ellettsville,Ellettville,Elliotville', 39.2339300, -86.6250000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132679, 'English', 'English', 'English,Hartford', 38.3345000, -86.4641500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132680, 'Evansville', 'Evansville', 'EVV,Ehvansvill,Evansvil,Evansvilis,Evansville,Gorad Ehvansvil,ai wen si wei er,awanzwyl  ayndyana,ayfansfyl,ebanzubiru,ebeonjeubil,evhansavhila,evu~anzuvu~iru,ivansavila,xe wan s will,Горад Эвансвіл,Евансвил,Евансвіл,Эвансвилл,אוונסוויל,إيفانسفيل,اوانزویل، ایندیانا,ایوانز ویل، انڈیانا,इवान्सविल,एव्हान्सव्हिल,เอวันส์วิลล์,エバンズビル,エヴァンズヴィル,埃文斯維爾,에번즈빌', 37.9747600, -87.5558500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132681, 'Fairview Park', 'Fairview Park', '', 39.6803100, -87.4175200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132682, 'Farmersburg', 'Farmersburg', 'Ascension,Farmersburg,Farmersburgh', 39.2486500, -87.3819600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132683, 'Ferdinand', 'Ferdinand', '', 38.2239400, -86.8622200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132684, 'Fishers', 'Fishers', 'Fishers,Fishers Station,Fishers Switch,fyshrz,Фишерс,فشرز، انڈیانا,فيشرز', 39.9555900, -86.0138700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132685, 'Fort Branch', 'Fort Branch', '', 38.2511600, -87.5811300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132686, 'Fortville', 'Fortville', 'Fortville,Phoebe Forts Corner,Walpole', 39.9322600, -85.8480400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132687, 'French Lick', 'French Lick', 'FRH,French Lick,French Lick Springs,French Lik,Frenchlick,frntsh lyk,Френч Лик,فرنتش ليك', 38.5489400, -86.6199900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132688, 'Galena', 'Galena', 'Galena,Germantown', 38.3517300, -85.9416400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132689, 'Geneva', 'Geneva', 'Geneva,Sulpher Hill,Sulphur Hill,Zheneva,Женева', 39.3917200, -85.7199800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132690, 'Georgetown', 'Georgetown', '', 38.2945100, -85.9755200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132691, 'Greencastle', 'Greencastle', 'Green Castle,Greencastel,Greencastle,Grinkasl,ghrynkasl,grynksl  ayndyana,Гринкасл,غرينكاسل,گرین کیسل، انڈیانا,گرینکسل، ایندیانا', 39.6444900, -86.8647300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132692, 'Greendale', 'Greendale', '', 39.1125600, -84.8641200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132693, 'Greenfield', 'Greenfield', 'GFD,Grinfild,ghrynfyld,grynfyld  ayndyana,gurinfirudo,Гринфилд,غرينفيلد,گرین فیلڈ، انڈیانا,گرینفیلد، ایندیانا,グリーンフィールド', 39.7850400, -85.7694200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132694, 'Greensburg', 'Greensburg', 'Greensburg,Greensburgh,Grinsburg,ghrynsbwrgh,grynzbrg  ayndyana,Гринсбург,غرينسبورغ,گرینزبرگ، انڈیانا,گرینزبرگ، ایندیانا', 39.3372700, -85.4835800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132695, 'Greenwood', 'Greenwood', 'Greenfield,Greenwood,Grinvud,Smockton,ghrynwwd,grynwwd  ayndyana,Гринвуд,غرينوود,گرین ووڈ، انڈیانا,گرینوود، ایندیانا', 39.6136600, -86.1066500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132696, 'Hagerstown', 'Hagerstown', 'Elizabethtown,Hagerstown', 39.9111600, -85.1616300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132697, 'Hanover', 'Hanover', 'Khanover,hanoba,hanwfr,Хановер,هانوفر,ハノーバー', 38.7142300, -85.4735700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132698, 'Haubstadt', 'Haubstadt', 'Haubs Station,Haubstadt', 38.2050400, -87.5741900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132699, 'Henryville', 'Henryville', 'Henryville,Morristown', 38.5417300, -85.7677400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132700, 'Hidden Valley', 'Hidden Valley', '', 39.1622800, -84.8430100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132701, 'Highland', 'Highland', '', 38.0397600, -87.5730700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132702, 'Hope', 'Hope', 'Goshen,Hope', 39.3039400, -85.7713700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132703, 'Huntingburg', 'Huntingburg', 'HNB,Huntingburg,Huntingburgh', 38.2989400, -86.9550000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132704, 'Indianapolis', 'Indianapolis', 'Gorad Indyjanapalis,IND,Indianapoles,Indianapoli,Indianapolis,Indianapolisa,Indianapolės,Indianapòlis,Indianàpolis,Indianápolis,Indijanapolis,Indiyanapolis,andyanabwlys,ayndyanapwlys,idi''anapolisa,indiaenapolliseu,indianaporisu,indiyanapolis,indiyanapolisa,intiyanapolis,xin deiy næ pho lis,yin di an na bo li si,İndianapolis,Ινδιανάπολη,Індіанаполіс,Горад Індыянапаліс,Индианаполис,Индијанаполис,Ինդիանապոլիս,אינדיאנאפאליס,אינדיאנפוליס,إنديانابوليس,انڈیاناپولس,انڈیاناپولس، انڈیانا,ایندیاناپولیس,इंडियानापोलिस,इन्डियानापोलिस,इन्डियानापोलिस्,इन्दियानापोलिस,ইন্ডিয়ানাপোলিস,ਇੰਡੀਆਨਾਪੋਲਿਸ,இண்டியானாபொலிஸ்,อินเดียแนโพลิส,ინდიანაპოლისი,ኢንዲያናፖሊስ,インディアナポリス,印第安納波利斯,인디애나폴리스', 39.7683800, -86.1580400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132705, 'Ingalls', 'Ingalls', '', 39.9569900, -85.8052600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132706, 'Jasonville', 'Jasonville', '', 39.1631000, -87.1991800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132707, 'Jasper', 'Jasper', 'Dzasper,jasbr,jspr  ayndyana,Џаспер,جاسبر,جسپر، انڈیانا,جسپر، ایندیانا', 38.3914400, -86.9311100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132708, 'Jeffersonville', 'Jeffersonville', 'Dzefersonvil,jfrswnwyl  ayndyana,jie fei xun wei er,jyfrswnfyly,Џеферсонвил,جفرسن ویل، انڈیانا,جفرسونویل، ایندیانا,جيفرسونفيلي,杰斐逊维尔', 38.2775700, -85.7371800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132709, 'Knightstown', 'Knightstown', 'Knightstown,La Fayette,West Liberty', 39.7956000, -85.5263600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132710, 'Lawrence', 'Lawrence', 'Lorens,Lourens,lawrns  ayndyana,lwrans,Лоренс,Лоуренс,لارنس، انڈیانا,لاورنس، ایندیانا,لورانس', 39.8386500, -86.0252600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132711, 'Lawrenceburg', 'Lawrenceburg', 'Lawrenceburg,Lawrenceburgh,Lorensburg,New Lawrenceburgh,Лоренсбург', 39.0908900, -84.8499500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132712, 'Liberty', 'Liberty', '', 39.6356000, -84.9310700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132713, 'Linton', 'Linton', 'Linton,New Jerusalem', 39.0347700, -87.1658500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132714, 'Loogootee', 'Loogootee', '', 38.6769900, -86.9141700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132715, 'Lowell', 'Lowell', 'Louel,Лоуел', 39.2531100, -85.9463800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132716, 'Madison', 'Madison', 'MDN,Madison,Medison,Mehdison,madyswn,mdyswn  ayndyana,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مدیسون، ایندیانا,میڈیسن، انڈیانا', 38.7358900, -85.3799600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132717, 'Martinsville', 'Martinsville', 'Martinsvil,Martinsvill,Martinsvill'',martynsfyl,martynzwyl  ayndyana,matinjeubil,Мартинсвил,Мартинсвилл,Мартінсвілль,مارتينسفيل,مارتینزویل، ایندیانا,مارٹنز ویل، انڈیانا,마틴즈빌', 39.4278300, -86.4283300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132718, 'McCordsville', 'McCordsville', '', 39.9081000, -85.9227600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132719, 'Melody Hill', 'Melody Hill', '', 38.0261500, -87.5158500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132720, 'Meridian Hills', 'Meridian Hills', '', 39.8900400, -86.1572100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132721, 'Middlebury', 'Middlebury', 'Martz,Middlebury', 39.2642100, -87.1189000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132722, 'Milan', 'Milan', 'Brooklyn,Milan,South Milan', 39.1211700, -85.1313500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132723, 'Mitchell', 'Mitchell', '', 38.7328300, -86.4736000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132724, 'Monrovia', 'Monrovia', 'Monrovija,Монровия', 39.5789400, -86.4822200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132725, 'Mooresville', 'Mooresville', '', 39.6128200, -86.3741600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132726, 'Morristown', 'Morristown', '', 39.6733800, -85.6985900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132727, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,McFadden''s Bluff,McFadden''s Landing,Mount Vernon,mawnt fyrnwn,Маунт Вернон,ماؤنٹ ورنن، انڈیانا,ماونت فيرنون,مونت‌ورنون، ایندیانا', 37.9322700, -87.8950300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132728, 'Nashville', 'Nashville', 'Jacksonburg,Nashvill,Nashville,Neshvil,nashfyl,nasshubiru,Нашвилл,Нешвил,ناشفيل,نیشویل، انڈیانا,ナッシュビル', 39.2072700, -86.2511000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132729, 'New Albany', 'New Albany', 'N''ju-Albani,Nju Olbani,Њу Олбани,Нью-Албани,Ню Олбани', 38.2856200, -85.8241300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132730, 'New Castle', 'New Castle', 'New Castle,Newcastle,Nju Kasl,niu ka si er,nyukaeseul,nyw kasl,nywkasl  ayndyana,Њу Касл,نيو كاسل,نیو کیسل، انڈیانا,نیوکاسل، ایندیانا,紐卡斯爾,뉴캐슬', 39.9289400, -85.3702500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132731, 'New Palestine', 'New Palestine', 'New Palestine,Palestine,Sugar Creek', 39.7219900, -85.8891500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132732, 'New Whiteland', 'New Whiteland', '', 39.5581000, -86.0952600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132733, 'Newburgh', 'Newburgh', 'Mount Prospect,N''juberg,Newburgh,Njuburg,Sprinklesburgh,niu bao,nywbwrgh,Њубург,Ньюберг,نيوبورغ,纽堡', 37.9444900, -87.4052900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132734, 'Newport', 'Newport', 'N''juport,Ньюпорт', 39.8842000, -87.4086300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132735, 'North Madison', 'North Madison', '', 38.7678400, -85.3966300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132736, 'North Terre Haute', 'North Terre Haute', '', 39.5278100, -87.3603000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132737, 'North Vernon', 'North Vernon', 'North Vernon,North Vernon City', 39.0061700, -85.6235800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132738, 'Oak Park', 'Oak Park', 'Ouk-Park,Оук-Парк', 38.3056200, -85.6963500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132739, 'Oakland City', 'Oakland City', 'Oakland,Oakland City', 38.3386600, -87.3450100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132740, 'Odon', 'Odon', 'Clark''s Prairie,Clark''s Spring,Clarksburg,Odon', 38.8428300, -86.9914000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132741, 'Oolitic', 'Oolitic', '', 38.9008800, -86.5252700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132742, 'Orleans', 'Orleans', '', 38.6617200, -86.4516600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132743, 'Osgood', 'Osgood', '', 39.1292200, -85.2916300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132744, 'Owensville', 'Owensville', '', 38.2719900, -87.6878000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132745, 'Paoli', 'Paoli', '', 38.5561700, -86.4683200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132746, 'Pendleton', 'Pendleton', 'Pendlton,byndltwn,Пендлтон,بيندلتون', 39.9975400, -85.7466400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132747, 'Petersburg', 'Petersburg', 'Peterburg,Petersburg,Petersburgh,Петербург', 38.4919900, -87.2786200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132748, 'Pittsboro', 'Pittsboro', 'Pittsboro,Pittsborough,Pittsburg', 39.8639300, -86.4669400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132749, 'Plainfield', 'Plainfield', 'Plejnfild,peulleinpildeu,Плейнфилд,Плейнфілд,Плејнфилд,پلینفیلڈ، انڈیانا,플레인필드', 39.7042100, -86.3994400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132750, 'Poseyville', 'Poseyville', 'Palestine,Poseyville', 38.1700400, -87.7830800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132751, 'Princes Lakes', 'Princes Lakes', 'Princes Lake,Princes Lakes', 39.3536600, -86.0980500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132752, 'Princeton', 'Princeton', 'Prinston,brnstwn,prynstwn  ayndyana,Принстон,برنستون,پرنسٹن، انڈیانا,پرینستون، ایندیانا', 38.3553200, -87.5675200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132753, 'Richmond', 'Richmond', 'Coxborough,RID,Richmond,Smithville,li shi man,lichimeondeu,ritchimondo,rychmwnd  ayndyana,rytshmwnd,Ричмонд,Річмонд,ريتشموند,رچمنڈ، انڈیانا,ریچموند، ایندیانا,リッチモンド,里士满,리치먼드', 39.8289400, -84.8902400, 'US', '2017-06-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132754, 'Rising Sun', 'Rising Sun', 'Rising Sun,Risingsun', 38.9495000, -84.8538400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132755, 'Rockport', 'Rockport', 'Copeland,Rockport,Rockport Mills,Wrights Mills', 39.8808700, -87.2789000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132756, 'Rockville', 'Rockville', 'Park,Rays Tavern,Rockville,Rokvil,Rokvill,Роквил,Роквилл', 39.7625400, -87.2291800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132757, 'Rockport', 'Rockport', 'Hanging Rock,Rockport', 37.8831100, -87.0494400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132758, 'Rushville', 'Rushville', 'Rashvil,rashwyl  ayndyana,rwshfyl,Рашвил,راشویل، ایندیانا,رشویل، انڈیانا,روشفيل', 39.6092100, -85.4463600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132759, 'Saint Paul', 'Saint Paul', 'Paultown,Saint Paul', 39.4281000, -85.6283100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132760, 'Salem', 'Salem', 'Salem (Indiana),Sejlem,salm,salm  ayndyana,Сейлем,Сејлем,سالم,سالم، ایندیانا,سیلم، انڈیانا', 38.6056100, -86.1010900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132761, 'Santa Claus', 'Santa Claus', 'Santa Claus,Santa Kloz,Santaclaus,Санта Клоз', 38.1200500, -86.9141600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132762, 'Scottsburg', 'Scottsburg', 'Scottsburg,Scottsburgh', 38.6856100, -85.7702500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132763, 'Seelyville', 'Seelyville', '', 39.4919800, -87.2672400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132764, 'Sellersburg', 'Sellersburg', 'Sellersburg,Sellersburgh', 38.3981200, -85.7549600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132765, 'Seymour', 'Seymour', 'SER,Simor,symwr,symwr  ayndyana,xi mo,Симор,سيمور,سیمور، انڈیانا,سیمور، ایندیانا,西摩', 38.9592200, -85.8902500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132766, 'Shelbyville', 'Shelbyville', 'Shelbivil,Shelby,Shelbyville,Shelly,sherubibiru,syelbibil,Шелбивил,シェルビービル,셸비빌', 39.5214400, -85.7769200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132767, 'Shelburn', 'Shelburn', '', 39.1783700, -87.3936300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132768, 'Shoals', 'Shoals', 'Daugherty''s Shoals,Shoals', 38.6664400, -86.7911100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132769, 'Southport', 'Southport', 'South Port,Southport', 39.6650500, -86.1277600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132770, 'Speedway', 'Speedway', 'Speedway,Speedway City,Spidvej,sbyd way,seupideuwei,supidou~ei,Спидвеј,سبيد واي,スピードウェイ,스피드웨이', 39.8022700, -86.2672100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132771, 'Spencer', 'Spencer', 'Spenser,Спенсер', 39.2867100, -86.7625100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132772, 'Sullivan', 'Sullivan', 'SIV,Salivan,salywan  ayndyana,swlyfan,Саливан,سالیوان، ایندیانا,سوليفان,سولیون، انڈیانا', 39.0953200, -87.4058500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132773, 'Sunman', 'Sunman', '', 39.2370000, -85.0946800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132774, 'Tell City', 'Tell City', 'Helvetia,Tel Siti,Tell City,Tell-Siti,tl syty,tl syty  ayndyana,Тел Сити,Телл-Сити,تل سيتي,تل سیتی، ایندیانا,ٹل سٹی، انڈیانا', 37.9514400, -86.7677700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132775, 'Terre Haute', 'Terre Haute', 'HUF,Tera Khout,Tere Khout,Terra Alta,Terre-Khot,te lei huo te,telehote,tere hauta,tere haute,terehoto,therre hot,trh‌hwt  ayndyana,tyr hwt,Тера Хоут,Тере Хоут,Терре-Хот,تر ہات، انڈیانا,تره‌هوت، ایندیانا,تير هوت,टेरे हौट,टेरे हौते,เทร์เรโฮต,テレホート,特雷霍特,테레호테', 39.4667000, -87.4139100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132776, 'Trafalgar', 'Trafalgar', 'Hensley Town,Liberty,Trafalgar', 39.4161600, -86.1508200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132777, 'Versailles', 'Versailles', 'Versaj,Версај', 39.0720000, -85.2519000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132778, 'Vevay', 'Vevay', 'New Switzerland,The Vineyard,Vevay,Vevej,wei wei,Вевеј,韦韦', 38.7478400, -85.0671700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132779, 'Vincennes', 'Vincennes', 'Au Poste,OEA,Post Ouabache,Post Saint Ange,Post Saint Vincent,Post Vincennes,Poste Ouabache,Vincennes,Vinsenne,Vinsens,fynsyns,wynsns  ayndyana,Винсенс,فينسينس,ونسینز، انڈیانا,وینسنس، ایندیانا', 38.6772700, -87.5286300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132780, 'Warren Park', 'Warren Park', '', 39.7819900, -86.0502600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132781, 'Washington', 'Washington', 'Liverpool,Vashington,Washington,Вашингтон', 38.6592200, -87.1727900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132782, 'Waterloo', 'Waterloo', '', 39.5625500, -86.1974900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132783, 'West Terre Haute', 'West Terre Haute', 'Macksville,West Terre Haute', 39.4650400, -87.4500200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132784, 'Westport', 'Westport', '', 39.1758900, -85.5730300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132785, 'Whiteland', 'Whiteland', '', 39.5500500, -86.0797100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132786, 'Whitestown', 'Whitestown', 'New Germantown,Whitestown', 39.9972600, -86.3458300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132787, 'Worthington', 'Worthington', '', 39.1250400, -86.9794500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132788, 'Zionsville', 'Zionsville', 'Zajonsvil,Зајонсвил', 39.9508700, -86.2619400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132789, 'Abilene', 'Abilene', 'Abilene,Abilin,Gorad Abilin,a bi lin,abirin,abylyn,abylyn  kanzas,abylyn  knsas,aebillin,Абилин,Абілін,Горад Абілін,أبيلين,ابیلین، کانزاس,ابیلین، کنساس,アビリーン,阿比林,애빌린', 38.9172200, -97.2139100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132790, 'Alma', 'Alma', 'Alma,alma,alma  kanzas,alma  knsas,Алма,آلما، کانزاس,ألما,الما، کنساس', 39.0166700, -96.2891600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132791, 'Altamont', 'Altamont', 'Altamont,Elston', 37.1903400, -95.2971900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132792, 'Andover', 'Andover', 'Andover,Cloud,Minneha,andwfr,andwwr  kanzas,Андовер,آندوور، کانزاس,أندوفر,اینڈوور، کنساس', 37.7139000, -97.1364300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132793, 'Anthony', 'Anthony', 'ANY,Entoni,antwny,antwny  kanzas,Ентони,آنتونی، کانزاس,أنتوني', 37.1533600, -98.0311700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132794, 'Arkansas City', 'Arkansas City', 'Adelphi,Arkansas City,Arkanzas Siti,Creswell,Fernandina,Walnut City,arkanzas syty  kanzas,arknsas syty,Арканзас Сити,آرکانزاس سیتی، کانزاس,أركنساس سيتي', 37.0619700, -97.0383700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132795, 'Arma', 'Arma', 'Arma,Rust', 37.5439400, -94.7002400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132796, 'Ashland', 'Ashland', 'Ashland,Clark', 37.1886400, -99.7656800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132797, 'Atchison', 'Atchison', 'Achison,Atcison,Atçison,achsn  kanzas,ai qi xun,atshyswn,aychysn  knsas,Ачисон,أتشيسون,اچسن، کانزاس,ایچیسن، کنساس,艾奇逊', 39.5630500, -95.1216400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132798, 'Auburn', 'Auburn', 'Auburn,Brownsville,Brownville', 38.9061100, -95.8161000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132799, 'Augusta', 'Augusta', 'Ogasta,awgasta  kanzas,awghsta,Огаста,آگسٹا، کنساس,أوغستا,اوگاستا، کانزاس', 37.6866800, -96.9767000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132800, 'Baldwin City', 'Baldwin City', 'Baldwin,Baldwin City,Boldvin Siti,Palmyra,bldwyn syty,bldwyn syty  kanzas,Болдвин Сити,بلدوين سيتي,بلدوین سیتی، کانزاس', 38.7750100, -95.1863600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132801, 'Basehor', 'Basehor', 'Baschor,Basehor', 39.1416700, -94.9385800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132802, 'Baxter Springs', 'Baxter Springs', 'Bakster Springs,bakstr sbrynghz,bkstr aspryngz  kanzas,Бакстер Спрингс,باكستر سبرينغز,بکستر اسپرینگز، کانزاس', 37.0236800, -94.7355000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132803, 'Bellaire', 'Bellaire', 'Bel Aire,Bellaire', 37.7625100, -97.2669900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132804, 'Belle Plaine', 'Belle Plaine', 'Belle Plain,Belle Plaine', 37.3939100, -97.2811500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132805, 'Belleville', 'Belleville', 'Belvil,blfyl,blwyl  kanzas,Белвил,بلفيل,بلویل، کانزاس', 39.8244500, -97.6325400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132806, 'Beloit', 'Beloit', 'Beloit,Belojt,Willow Springs,blwyt,blwyt  kanzas,Белојт,بلويت,بلویت، کانزاس', 39.4561200, -98.1061600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132807, 'Bonner Springs', 'Bonner Springs', 'Boner Springs,Bonner,Bonner Springs,Edwardsville,Tiblow,bwnr aspryngz  kanzas,bwnr sbrynghz,bwnr sprngz  knsas,Бонер Спрингс,بونر اسپرینگز، کانزاس,بونر سبرينغز,بونر سپرنگز، کنساس', 39.0597300, -94.8835800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132808, 'Buhler', 'Buhler', 'Buhler,Hamburg', 38.1344500, -97.7700500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132809, 'Burlington', 'Burlington', 'Berlington,Burlington,Hampden,brlnghtwn,bwrlyngtwn  kanzas,Берлингтон,برلنغتون,برلنگٹن، کنساس,بورلینگتون، کانزاس', 38.1944700, -95.7427600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132810, 'Caldwell', 'Caldwell', 'Kolduehll,Koldvel,kaldwyl,kldwl  kanzas,Колдвел,Колдуэлл,كالدويل,کلدول، کانزاس', 37.0322500, -97.6069900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132811, 'Caney', 'Caney', 'Cana,Caney,Caneyville', 37.0114600, -95.9352600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132812, 'Carbondale', 'Carbondale', 'Carbondale,Carbonhill', 38.8186200, -95.6891500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132813, 'Chanute', 'Chanute', 'CNU,Chanute,New Chicago,Shanut,shnwt  kanzas,tshanwt,Шанут,تشانوت,شانوٹ، کنساس,شنوت، کانزاس', 37.6792100, -95.4572000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132814, 'Chapman', 'Chapman', 'Chapman,Chapmans Creek,chpmn  kanzas,tshabman,Чапман,تشابمان,چپمن، کانزاس', 38.9722200, -97.0225100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132815, 'Cheney', 'Cheney', 'Cheney,Marshall', 37.6300100, -97.7825500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132816, 'Cherryvale', 'Cherryvale', 'Cherivejl,Cherry Vale,Cherryvale,Cherryville,chrywal  kanzas,tshyryfal,Черивејл,تشيريفال,چریوال، کانزاس', 37.2703400, -95.5524800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132817, 'Chetopa', 'Chetopa', '', 37.0372900, -95.0899600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132818, 'Clay Center', 'Clay Center', '', 37.5194600, -96.7711400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132819, 'Clay Center', 'Clay Center', 'Klej Senter,klay sntr,kly sntr  kanzas,Клеј Сентер,كلاي سنتر,کلی سنتر، کانزاس', 39.3769400, -97.1247400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132820, 'Clearwater', 'Clearwater', '', 37.5028000, -97.5044900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132821, 'Coffeyville', 'Coffeyville', 'CFV,Coffeyville,Cowtown,Koffivill,kafywyl  knsas,kwfyfyl,Коффивилл,كوفيفيل,کافیویل، کنساس,کافی‌ویل، کانزاس', 37.0373000, -95.6163700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132822, 'Coldwater', 'Coldwater', 'Koldvoter,Koulduoter,kwldwatr  kanzas,kwldwwtr,Колдвотер,Коулдуотер,كولدووتر,کولدواتر، کانزاس,کولڈواٹر، کنساس', 37.2689100, -99.3267800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132823, 'Columbus', 'Columbus', 'Center,Centrailia,Columbus,Kolambus,Kolumbus,klmbws  kanzas,kwlmbs  knsas,kwlwmbws,Коламбус,Колумбус,كولومبوس,کلمبوس، کانزاس,کولمبس، کنساس', 37.1692300, -94.8441200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132824, 'Colwich', 'Colwich', 'Kolvich,kwlwych  kanzas,kwlwytsh,Колвич,كولويتش,کولویچ، کانزاس', 37.7791800, -97.5364400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132825, 'Concordia', 'Concordia', 'CNK,Konkordija,kankwrdya  kanzas,kwnkwrdya,Конкордија,كونكورديا,کانکوردیا، کانزاس,کونکورڈیا، کنساس', 39.5708400, -97.6625400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132826, 'Conway Springs', 'Conway Springs', 'Cisne,Conway Springs,Cranmer Springs,Glen Valley,Northfield', 37.3903000, -97.6422700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132827, 'Cottonwood Falls', 'Cottonwood Falls', 'Cotton Wood Falls,Cottonwood Falls,Kotonvud Fols,katnwwd falz  kanzas,kwtnwwd fwlz,Котонвуд Фолс,كوتنوود فولز,کاتنوود فالز، کانزاس', 38.3722400, -96.5427800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132828, 'Council Grove', 'Council Grove', 'Kaunsil Grouv,knsyl grww  kanzas,kwnswl ghrwf,Каунсил Гроув,كونسول غروف,کنسیل گروو، کانزاس', 38.6611200, -96.4919500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132829, 'De Soto', 'De Soto', 'De Soto,Lexington,d swtw  kanzas,dy swtw,Де Сото,د سوتو، کانزاس,دي سوتو', 38.9791700, -94.9685800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132830, 'Derby', 'Derby', 'Derbi,Derby,El Paso,Sand Ford,drby  kanzas,dyrby,Дерби,دربی، کانزاس,ديربي,ڈربی، کنساس', 37.5455700, -97.2689300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132831, 'Douglass', 'Douglass', 'Daglas,daglas  kanzas,dwghlas,Даглас,داگلاس، کانزاس,دوغلاس', 37.5194600, -97.0128100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132832, 'Edgerton', 'Edgerton', 'Edgerton,Lanesfield,Martinsburgh', 38.7647300, -95.0080200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132833, 'Edwardsville', 'Edwardsville', '', 39.0611200, -94.8196800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132834, 'El Dorado', 'El Dorado', 'EDK,El Dorado,El Dorejdo,Eldorado,al dwradw  kanzas,aldwradw,ayl dwradw  knsas,Ел Дорејдо,إلدورادو,ال دورادو، کانزاس,ایل دورادو، کنساس', 37.8172400, -96.8622500, 'US', '2017-07-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132835, 'Ellinwood', 'Ellinwood', '', 38.3555700, -98.5809100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132836, 'Ellis', 'Ellis', 'Elis,alys,alys  kanzas,Елис,إليس,الیس، کانزاس', 38.9380700, -99.5606700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132837, 'Ellsworth', 'Ellsworth', 'Elsvort,alswrth,alzwrt  kanzas,Елсворт,إلسورث,الزورت، کانزاس', 38.7305600, -98.2281100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132838, 'Elwood', 'Elwood', 'Elwood,Roseport', 39.7555500, -94.8724700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132839, 'Emporia', 'Emporia', 'Columbia,EMP,Emporia,Emporija,ambwrya,ampwrya  kanzas,aympwrya  knsas,empolia,Емпория,Емпорија,إمبوريا,امپوریا، کانزاس,ایمپوریا، کنساس,엠포리아', 38.4039000, -96.1816600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132840, 'Erie', 'Erie', 'Ehri,Erie,Erie City,Iri,ary,ayry  kanzas,Ири,Эри,إري,ایری، کانزاس', 37.5681100, -95.2433100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132841, 'Eureka', 'Eureka', 'Ehvrika,Jurika,ywryka,ywryka  kanzas,Јурика,Эврика,يوريكا,یوریکا، کانزاس', 37.8239200, -96.2891700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132842, 'Eudora', 'Eudora', 'Judora,aywdra  kanzas,ywdwra,Јудора,ایودرا، کانزاس,يودورا', 38.9433400, -95.0985800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132843, 'Fairway', 'Fairway', 'Fervej,fyrway,fyrwy  kanzas,Фервеј,فيرواي,فیئروے، کنساس,فیروی، کانزاس', 39.0222300, -94.6319000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132844, 'Fort Scott', 'Fort Scott', 'FSK,Fort Skot,fwrt askat  kanzas,fwrt skwt,Форт Скот,فورت اسکات، کانزاس,فورت سكوت,فورٹ سکاٹ، کنساس', 37.8397600, -94.7083000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132845, 'Fredonia', 'Fredonia', 'Fredonia,Twin Mounds', 37.5339400, -95.8266500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132846, 'Galena', 'Galena', 'Galena,Galina,Leedsville,ghalyna,glyna  kanzas,Галина,غالينا,گلینا، کانزاس', 37.0759000, -94.6396700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132847, 'Frontenac', 'Frontenac', '', 37.4556000, -94.6891300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132848, 'Gardner', 'Gardner', 'Gardner,gardnr  kanzas,ghardnr,Гарднер,غاردنر,گاردنر، کانزاس,گارڈنر، کنساس', 38.8108400, -94.9271900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132849, 'Garnett', 'Garnett', 'Garnet,Garnett,Shannon,garnt  kanzas,gharnyt,Гарнет,غارنيت,گارنت، کانزاس', 38.2805800, -95.2419200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132850, 'Girard', 'Girard', 'Dzirard,jyrard,jyrard  kanzas,Џирард,جيرارد,جیرارد، کانزاس', 37.5111600, -94.8380200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132851, 'Goddard', 'Goddard', 'Blendon,Godard,Goddard,gadrd  kanzas,ghwdard,Годард,غودارد,گادرد، کانزاس', 37.6597400, -97.5753300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132852, 'Grandview Plaza', 'Grandview Plaza', '', 39.0291600, -96.7891700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132853, 'Great Bend', 'Great Bend', 'GBD,Great Bend,Greatbend,Grejt Bend,geuleiteubendeu,ghryt bynd,gryt bnd  kanzas,Грејт Бенд,غريت بيند,گریت بند، کانزاس,گریٹ بینڈ، کنساس,그레이트벤드', 38.3644600, -98.7648100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132854, 'Greensburg', 'Greensburg', 'Greensburg,Greensburgh,Grinsburg,Janes,ghrynsbwrj,grynzbrg  kanzas,grynzbrg  knsas,Гринсбург,غرينسبورج,گرینزبرگ، کانزاس,گرینزبرگ، کنساس', 37.6028000, -99.2926100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132855, 'Halstead', 'Halstead', 'Halstead,Khalstid,Lakin,halstyd,Халстид,هالستيد,هالستید', 38.0014000, -97.5086500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132856, 'Harper', 'Harper', 'Cora City,Harper', 37.2866900, -98.0258900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132857, 'Haven', 'Haven', '', 37.8989000, -97.7828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132858, 'Hays', 'Hays', 'Big Creek Station,HYS,Hays,Hays City,Khejz,hayz,heiseu,heizu,hesa,hyz  kanzas,Хејз,هايز,هیز، کانزاس,ہیئز، کنساس,हेस,ヘイズ,헤이스', 38.8791800, -99.3267700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132859, 'Haysville', 'Haysville', 'Khejzvil,haysfyl,hayswyl  kanzas,Хејзвил,هايسفيل,هایسویل، کانزاس,ہیزویل، کنساس', 37.5644600, -97.3522700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132860, 'Herington', 'Herington', 'Herington,Herrington,Kherington,hrynghtwn,hryngtwn  kanzas,Херингтон,هرينغتون,هرینگتون، کانزاس', 38.6711200, -96.9425100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132861, 'Hesston', 'Hesston', 'Elivon,Hesston', 38.1383400, -97.4314300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132862, 'Hiawatha', 'Hiawatha', 'Khajavota,haywata  kanzas,hyawatha,Хајавота,هایواتا، کانزاس,هياواثا', 39.8525000, -95.5358200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132863, 'Highland', 'Highland', 'Khajland,hayland,haylnd  kanzas,Хајланд,هايلاند,هایلند، کانزاس', 39.8597200, -95.2697000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132864, 'Hill City', 'Hill City', 'HLC,Hill,Hill City', 39.3647300, -99.8420600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132865, 'Hillsboro', 'Hillsboro', 'Hill City,Hillsboro,Khillsboro,Risley,Хиллсборо', 38.3519600, -97.2044700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132866, 'Hoisington', 'Hoisington', 'hwysynghtwn,hwysyngtwn  kanzas,هويسينغتون,هویسینگتون، کانزاس', 38.5180700, -98.7781400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132867, 'Holton', 'Holton', '', 39.4652700, -95.7363700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132868, 'Horton', 'Horton', 'Khorton,hwrtwn,hwrtwn  kanzas,Хортон,هورتون,هورتون، کانزاس', 39.6605600, -95.5263700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132869, 'Howard', 'Howard', 'Howard,Howard City', 37.4703100, -96.2636100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132870, 'Humboldt', 'Humboldt', '', 37.8106000, -95.4369300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132871, 'Hutchinson', 'Hutchinson', 'HUT,Khachinson,Khatchinson,hachynswn  kanzas,htshnswn,Хатчинсон,Хачинсон,هاچینسون، کانزاس,هتشنسون,ہچینسن، کنساس', 38.0608400, -97.9297700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132872, 'Independence', 'Independence', 'IDP,Independens,andybyndns,ayndypndns  kanzas,Индепенденс,إنديبيندنس,انڈیپینڈینس، کنساس,ایندیپندنس، کانزاس', 37.2242400, -95.7083100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132873, 'Inman', 'Inman', 'Aiken,Inman,Superior', 38.2319500, -97.7733800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132874, 'Iola', 'Iola', 'Ajola,Cofachique,Iola,aywla,aywla  kanzas,Ајола,إيولا,ایولا، کانزاس', 37.9244800, -95.3999800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132875, 'Jetmore', 'Jetmore', 'Buckner,Jetmore', 38.0844600, -99.8934600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132876, 'Junction City', 'Junction City', 'Dzankshon Siti,Junction,Junction City,Millard,jankshn syty  kanzas,jnkshn syty,zhang ke shen cheng,Џанкшон Сити,جانکشن سیتی، کانزاس,جنكشن سيتي,جنکشن سٹی، کنساس,章克申城', 39.0286100, -96.8314000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132877, 'Kansas City', 'Kansas City', 'Fort Cavagnolle,KCK,Kansas City,Kansas City i Kansas,Kanzas-Siti,kan sa si cheng,Канзас-Сити,堪薩斯城', 39.1141700, -94.6274600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132878, 'Kechi', 'Kechi', 'Kechi,Kechi City', 37.7958500, -97.2794900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132879, 'Kingman', 'Kingman', 'Kingman,Kingmen,Sherman,kngmyn  knsas,kynghman,kyngman  kanzas,Кингман,Кингмен,كينغمان,کنگمین، کنساس,کینگمان، کانزاس', 37.6458500, -98.1136700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132880, 'Kinsley', 'Kinsley', 'Kinsley,Peters,Petersburg', 37.9230700, -99.4098400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132881, 'Kiowa', 'Kiowa', 'Kiowa,New Kiowa', 37.0172500, -98.4853500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132882, 'La Crosse', 'La Crosse', 'La Crosse,La Kros,La-Kross,Lacross,Rock Castle,la krs  kanzas,la krws,la krws  knsas,Ла Крос,Ла-Кросс,لا كروس,لا کرس، کانزاس,لا کروس، کنساس', 38.5314000, -99.3087200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132883, 'La Cygne', 'La Cygne', 'La Cygne,LaCygne,Lacygne', 38.3500200, -94.7613500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132884, 'Lansing', 'Lansing', 'Lansing,Petersburg,lansng  knsas,lansyngh,lnsyng  kanzas,ranshingu,Лансинг,لانسنگ، کنساس,لانسينغ,لنسینگ، کانزاس,ランシング', 39.2486100, -94.9002400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132885, 'Larned', 'Larned', 'larnd  kanzas,larnyd,لارند، کانزاس,لارنيد,لارنیڈ، کنساس', 38.1805700, -99.0987100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132886, 'Lawrence', 'Lawrence', 'Gorad Lourehns,LWC,Lawrence,Lorens,Lourens,lao lun si,larns  knsas,lolenseu,lwrans,lwrns  kanzas,rorensu,Горад Лоўрэнс,Лоренс,Лоуренс,Լոուրենս,لارنس، کنساس,لورانس,لورنس، کانزاس,ローレンス,勞倫斯,로렌스', 38.9716700, -95.2352500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132887, 'Leavenworth', 'Leavenworth', 'Leavenworth,Leavenworth City,Levenvort,Livenvors,New Town,lebeon-woseu,lyfnwwrth,lywnwrt  kanzas,rebunwasu,Левенворт,Ливенворс,ليفنوورث,لیونورت، کانزاس,لیونورتھ، کنساس,レブンワース,레번워스', 39.3111100, -94.9224600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132888, 'Leawood', 'Leawood', 'Livud,lywwd,lywwd  kanzas,Ливуд,ليوود,لیوود، کانزاس,لیووڈ، کنساس', 38.9666700, -94.6169000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132889, 'Lenexa', 'Lenexa', 'Leneksa,Lenexa,Sherman,lnksa  kanzas,lynyksa  knsas,renekkusa,ynyksa,Ленекса,لنکسا، کانزاس,لینیکسا، کنساس,ينيكسا,レネックサ', 38.9536200, -94.7335700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132890, 'Lincoln', 'Lincoln', 'Lincoln,Lincoln Center,Lincoln Center City,Lincoln Centre,Linkol''n,Линкольн', 39.0408400, -98.1447700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132891, 'Lindsborg', 'Lindsborg', 'Lindsborg,Lindsburg City,lyndsbwrg  kanzas,lyndsbwrgh,Линдсборг,ليندسبورغ,لیندسبورگ، کانزاس', 38.5736200, -97.6744800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132892, 'Louisburg', 'Louisburg', 'Lodi,Louisburg,Louisburgh,Luisburg,Saint Louis,lwysbwrg  kanzas,lwysbwrgh,Луисбург,لويسبورغ,لویسبورگ، کانزاس', 38.6194600, -94.6807900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132893, 'Lyndon', 'Lyndon', 'Lyndon,Osage Centre', 38.6100100, -95.6844300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132894, 'Lyons', 'Lyons', 'Atlanta,Brookdale,LYO,Lajons,Lyons,laynz  kanzas,lywnz,Лајонс,لاینز، کانزاس,ليونز', 38.3450100, -98.2017300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132895, 'Maize', 'Maize', 'Hatfield,Maize', 37.7791800, -97.4672700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132896, 'Manhattan', 'Manhattan', 'MHK,Mankhehtten,Menkhetn,maenhaeteun,man ha dun,manhatn,manhattan,mnhtn  kanzas,Манхэттен,Менхетн,مانهاتن,منهتن، کانزاس,مینہٹن، کنساس,マンハッタン,曼哈頓,맨해튼', 39.1836100, -96.5716700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132897, 'Mankato', 'Mankato', 'Jewell Centre,Jewell City,Mankato', 39.7872300, -98.2100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132898, 'Marion', 'Marion', 'Marion,Marion Center,Marion Centre,Mehrion,marywn  kanzas,Марион,Мэрион,ماریون، کانزاس', 38.3483500, -97.0172500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132899, 'Marysville', 'Marysville', 'Merisvil,marysfyl,maryswyl  kanzas,melijeubil,myryzwyl  knsas,Мерисвил,ماريسفيل,ماریسویل، کانزاس,میریزویل، کنساس,메리즈빌', 39.8411100, -96.6472400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132900, 'McPherson', 'McPherson', 'MPR,Makferson,makfrswn,mkfyrsn  knsas,Макферсон,ماكفرسون,مکفیرسن، کنساس,مک‌فرسون، کانزاس', 38.3708400, -97.6642100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132901, 'Medicine Lodge', 'Medicine Lodge', 'Medisin Lodz,mdsyn laj  kanzas,mydysn lwdj,Медисин Лоџ,مدسین لاج، کانزاس,ميديسن لودج', 37.2811300, -98.5803600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132902, 'Merriam', 'Merriam', 'Campbellton,Campbelltown,Glenwood,Merijam,Merriam,Spring Place,mryam  kanzas,myryam,myrym  knsas,Меријам,مریام، کانزاس,ميريام,میریم، کنساس', 39.0236200, -94.6935700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132903, 'Minneapolis', 'Minneapolis', 'Mineapolis,Minneapolis,mineaporisu,mynyabwlys,mynyapwlys  kanzas,Минеаполис,Миннеаполис,مينيابوليس,مینیاپولیس، کانزاس,ミネアポリス', 39.1219400, -97.7067000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132904, 'Mission', 'Mission', 'Mishon,Missija,mshn  knsas,myshn  kanzas,mysn,Миссия,Мишон,مشن، کنساس,ميسن,میشن، کانزاس', 39.0277800, -94.6557900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132905, 'Mission Hills', 'Mission Hills', '', 39.0177800, -94.6169000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132906, 'Mound City', 'Mound City', 'Mound,Mound City,Moundville,Sugar Mound', 38.1428100, -94.8135700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132907, 'Moundridge', 'Moundridge', 'Christian,Crooked Creek,Mound Ridge,Moundridge', 38.2030700, -97.5192100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132908, 'Mulvane', 'Mulvane', 'Littleton,Mulvane', 37.4744600, -97.2439300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132909, 'Neodesha', 'Neodesha', '', 37.4183900, -95.6802600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132910, 'Ness City', 'Ness City', 'Iowa,Ness City', 38.4527900, -99.9065100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132911, 'Newton', 'Newton', 'EWK,N''juton,Newton,Newton City,Njuton,nywtn,nywtn  kanzas,Њутон,Ньютон,نيوتن,نیوتن، کانزاس,نیوٹن، کنساس', 38.0466800, -97.3450400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132912, 'Nickerson', 'Nickerson', '', 38.1472300, -98.0836700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132913, 'North Newton', 'North Newton', 'Bethel College,Nort NJuton,North Newton,nrt nwtn  kanzas,nwrth nywtn,Норт Њутон,نرت نوتن، کانزاس,نورث نيوتن', 38.0722300, -97.3455900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132914, 'Norton', 'Norton', 'Billingsville,Norton,nuo dun,nwrtwn,nwrtwn  kanzas,Нортон,نورتون,نورتون، کانزاس,诺顿', 39.8338900, -99.8915100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132915, 'Ogden', 'Ogden', 'Ogden,Ogdensburg,Огден', 39.1111100, -96.7061200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132916, 'Olathe', 'Olathe', 'Olat,Olathe,Olejt,Olejte,ao la xi,awlath,awlyta  kanzas,oreisa,Олейт,Олејте,أولاث,اولیتا، کانزاس,اولیتھی، کنساس,オレイサ,奧拉西', 38.8814000, -94.8191300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132917, 'Osage City', 'Osage City', 'Onion Creek,Osage,Osage City', 38.6339000, -95.8258200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132918, 'Osawatomie', 'Osawatomie', 'Osawatomie,Osawattamie,Ossawatamie,Ossawattamie,awsawatwmy,awsawatwmy  kanzas,أوساواتومي,اوساواتومی، کانزاس', 38.4972400, -94.9505200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132919, 'Osborne', 'Osborne', 'Osborne,Osborne City,Osburn,Penn,awzbwrn,azbrn  kanzas,Осбурн,آزبرن، کانزاس,أوزبورن', 39.4391400, -98.6962400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132920, 'Oskaloosa', 'Oskaloosa', '', 39.2152800, -95.3127500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132921, 'Oswego', 'Oswego', 'Little Town,Osvigo,Oswego,White Hairs Village,aswygww  kanzas,awswyghw,Освиго,آسویگوو، کانزاس,أوسويغو', 37.1675700, -95.1099600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132922, 'Ottawa', 'Ottawa', 'Otava,Ottawa,Ottawa Creek,awtawa,awtawa  kanzas,otava,otawa,Отава,أوتاوا,اوتاوا، کانزاس,اوٹاوا، کنساس,ओटावा,オタワ', 38.6155700, -95.2677500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132923, 'Overbrook', 'Overbrook', '', 38.7805600, -95.5572000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132924, 'Overland Park', 'Overland Park', 'Ouvurlund Park,Overland Park,Overlend-Park,awfrland bark,awwrlnd park  kanzas,obarandopaku,obeollaendeupakeu,ou fu lan pa ke,Оверланд Парк,Оверленд-Парк,Оувърлънд Парк,أوفرلاند بارك,اوورلند پارک، کانزاس,اوورلینڈ پارک، کنساس,オーバーランドパーク,歐弗蘭帕克,오벌랜드파크', 38.9822300, -94.6707900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132925, 'Oxford', 'Oxford', 'Napawalla,Nappawalla,Neptawah,Oksford,Oxford,Оксфорд', 37.2741900, -97.1689300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132926, 'Paola', 'Paola', 'Paola,Paoli,bawla,paywla  kanzas,Паола,باولا,پائولا، کانزاس', 38.5722400, -94.8791300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132927, 'Park City', 'Park City', 'Cosmosa,Park City', 37.8000100, -97.3183800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132928, 'Parsons', 'Parsons', 'Mendota,PPF,Parsons,Parsons City,barswnz,parsns  knsas,parswnz  kanzas,Парсонс,بارسونز,پارسنس، کنساس,پارسونز، کانزاس', 37.3403400, -95.2610800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132929, 'Peabody', 'Peabody', 'Coneburgh,Cowsburg,Peabody,Pibodi,bybwdy,pybady  kanzas,Пибоди,بيبودي,پیبادی، کانزاس', 38.1694600, -97.1067000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132930, 'Phillipsburg', 'Phillipsburg', 'Phillipsburg,Phillipsburgh', 39.7561200, -99.3239900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132931, 'Pittsburg', 'Pittsburg', 'Hopefield,New Pittsburg,New Pittsburgh,PTS,Pitsburg,Pittsburg,Pittsburgh,bytsbrgh,pytsbrg  kanzas,Питсбург,بيتسبرغ,پٹسبرگ، کنساس,پیتسبرگ، کانزاس', 37.4108800, -94.7049600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132932, 'Plainville', 'Plainville', 'Plejnvil,Plejnvill'',blynfyl,plynwyl  kanzas,Плейнвилль,Плејнвил,بلينفيل,پلینویل، کانزاس', 39.2347300, -99.2981600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132933, 'Pleasanton', 'Pleasanton', 'Hillsborough,Pleasanton,Plezantun,Potosi,Плезантън', 38.1778100, -94.7113500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132934, 'Prairie Village', 'Prairie Village', 'Preri Vilidz,bryry fylyj,pryry wylyj  kanzas,Прери Вилиџ,بريري فيليج,پریری ویلیج، کانزاس,پریری گاؤں، کنساس', 38.9916700, -94.6335700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132935, 'Pratt', 'Pratt', 'PTT,Prat,Pratt,Pratt Center,brat,peulaes,prt  kanzas,Прат,برات,پراٹ، کنساس,پرت، کانزاس,프랫', 37.6439100, -98.7375900, 'US', '2017-07-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132936, 'Roeland Park', 'Roeland Park', 'Roeland Park,Roland Park', 39.0375100, -94.6321800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132937, 'Rose Hill', 'Rose Hill', 'Rose Hill,Rosehill', 37.5583500, -97.1350400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132938, 'Rossville', 'Rossville', 'Edna,Rossville', 39.1361100, -95.9516600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132939, 'Russell', 'Russell', 'Fossil Station,RSL,Rasel,Russell,la sai er,rasl  kanzas,rwsyl,Расел,راسل، کانزاس,روسيل,拉塞尔', 38.8952700, -98.8610300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132940, 'Sabetha', 'Sabetha', '', 39.9022200, -95.8008200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132941, 'Saint John', 'Saint John', 'Saint John,Zion Valley', 38.0022400, -98.7600900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132942, 'Saint Marys', 'Saint Marys', 'Saint Mary Aleppo,Saint Marys,Saint Marys Catholic Mission', 39.1941600, -96.0711000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132943, 'Saint Marys', 'Saint Marys', '', 37.7066800, -97.6400500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132944, 'Salina', 'Salina', 'SLN,Salajna,Saliena,Salina,Saline,salayana,salyna,salyna  kanzas,saraina,seollaina,sylayna  knsas,Салајна,Салина,سالينا,سالینا، کانزاس,سیلائنا، کنساس,सलायना,サライナ,설라이나', 38.8402800, -97.6114200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132945, 'Sedan', 'Sedan', '', 37.1267200, -96.1869400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132946, 'Sedgwick', 'Sedgwick', '', 37.9166800, -97.4225400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132947, 'Seneca', 'Seneca', 'Castle Rock,Seneca', 39.8341600, -96.0641700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132948, 'Shawnee', 'Shawnee', 'Shani,Shoni,shany  knsas,shawny,shwny  kanzas,syoni,Шани,Шони,شانی، کنساس,شاوني,شونی، کانزاس,쇼니', 39.0416700, -94.7202400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132949, 'Silver Lake', 'Silver Lake', 'Hallet,Hallett,Silver Lake', 39.1041700, -95.8586000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132950, 'Smith Center', 'Smith Center', '', 39.7791800, -98.7850700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132951, 'Solomon', 'Solomon', 'Solomon,Solomon City,Wiskapella', 38.9194400, -97.3711400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132952, 'South Hutchinson', 'South Hutchinson', '', 38.0280700, -97.9403300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132953, 'Spring Hill', 'Spring Hill', 'Spring,Spring Hill,Spring-Khill,Springhill,Спринг-Хилл', 38.7430600, -94.8255200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132954, 'Sterling', 'Sterling', 'Peace,Sterling,astrlyng  kanzas,styrlyngh,Стерлинг,استرلینگ، کانزاس,ستيرلينغ', 38.2100100, -98.2070100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132955, 'Tonganoxie', 'Tonganoxie', '', 39.1097200, -95.0877500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132956, 'Towanda', 'Towanda', '', 37.7975200, -96.9997600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132957, 'Topeka', 'Topeka', 'Google,Gorad Topika,Mid-Continent,Pomme de Terre,TOP,To-pe-ka,To-poo-ka,Too Beega,Topage,Topeca,Topeka,Topika,Topikae,Topīka,topeka,topika,tuo pi ka,twbyka  kansas,twpyka,twpyqh,Τοπίκα,Горад Топіка,Топека,Топикæ,Топика,Топіка,Տոպիկա,טופיקה,توبيكا، كانساس,توپیکا,टोपेका,டொபீகா,トピカ,托皮卡,토피카', 39.0483300, -95.6780400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132958, 'Troy', 'Troy', 'Troj,Troja,trwy,trwy  kanzas,Троя,Трој,تروي,تروی، کانزاس,ٹرائے، کنساس', 39.7830500, -95.0899700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132959, 'Valley Center', 'Valley Center', '', 37.8347300, -97.3733800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132960, 'Valley Falls', 'Valley Falls', 'Grass Hopper Falls,Grasshopper Falls,Sautrell Falls,Sautrelle Falls,Valley Falls', 39.3433300, -95.4602500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132961, 'Victoria', 'Victoria', 'Hartsook,Herzog,Victoria,Viktorija,fyktwrya,wyktrya  kanzas,Виктория,Викторија,فيكتوريا,وکٹوریہ، کنساس,ویکتریا، کانزاس', 38.8527900, -99.1476000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132962, 'WaKeeney', 'WaKeeney', 'Vakini,Wa Keeney,Wa keeney,Wa-Keeney,WaKeeney,Wakeeney,wakny  kanzas,wakyny,Вакини,واكيني,واکنی، کانزاس', 39.0250100, -99.8795700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132963, 'Wamego', 'Wamego', 'Vomego,wamgw  kanzas,wamyghw,Вомего,واميغو,وامگو، کانزاس', 39.2019400, -96.3050000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132964, 'Washington', 'Washington', 'Vashington,washntn,washyngtn  kanzas,Вашингтон,واشنطن,واشنگٹن، کنساس,واشینگتن، کانزاس', 39.8180600, -97.0508600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132965, 'Wathena', 'Wathena', 'Petersburg,Wathena', 39.7591600, -94.9496900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132966, 'Wellington', 'Wellington', 'Velington,Vellington,wlnghtwn,wlyngtwn  kanzas,Велингтон,Веллингтон,ولنغتون,ولینگتون، کانزاس,ویلنگٹن، کنساس', 37.2653000, -97.3717100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132967, 'Wellsville', 'Wellsville', '', 38.7183400, -95.0816400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132968, 'Westmoreland', 'Westmoreland', '', 39.3938900, -96.4136100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132969, 'Westwood', 'Westwood', '', 39.0405600, -94.6169000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132970, 'Wichita', 'Wichita', 'Camp Beecher,Camp Davidson,Doo-Dah,Doodah,Gorad Uichyta,ICT,Ouitsita,Uichita,Uichito,Vichita,Vicita,Viçita,Vičita,Wichita,uichitʼo,u~ichita,vicita,wei qi tuo,wi chi thx,wichito,wychyta  kanzas,wychyta  knsas,wytshyta,wyzyth,Ουιτσίτα,Вичита,Вічіта,Горад Уічыта,Уичита,Уичито,Ուիչիտո,ויציטה,ويتشيتا,ویچیتا، کانزاس,ویچیتا، کنساس,विचिटा,วิชิทอ,უიჩიტო,ウィチタ,威奇托,위치토', 37.6922400, -97.3375400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132971, 'Winfield', 'Winfield', 'Legonda,Vinfild,WLD,Winfield,wynfyld,wynfyld  kanzas,Винфилд,ونفیلڈ، کنساس,وينفيلد,وینفیلد، کانزاس', 37.2397500, -96.9955900, 'US', '2017-05-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132972, 'Yates Center', 'Yates Center', 'Bath,Chellis,Kalida,Yates Center', 37.8811500, -95.7333200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132973, 'Albany', 'Albany', 'Albani,Olbani,albany,albany  kntaky,ao er ba ni,Албани,Олбани,آلبانی، کنتاکی,ألباني,البانی، کینٹکی,奥尔巴尼', 36.6909000, -85.1346800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132974, 'Alexandria', 'Alexandria', 'Aleksandrija,alaskndryt,alksandrya  kntaky,ya li shan de li ya,Александрия,Александрија,آلکساندریا، کنتاکی,الإسكندرية,الیگزینڈریا، کینٹکی,亚历山德里亚', 38.9595100, -84.3879900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132975, 'Anchorage', 'Anchorage', 'Anchorage,Ankoridzh,Enkoridz,Hobbs Station,an ke lei qi,ankryj  kntaky,anshwragh,Анкоридж,Енкориџ,آنکریج، کنتاکی,أنشوراغ,安克雷奇', 38.2667400, -85.5330200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132976, 'Annville', 'Annville', 'Annville,Anville', 37.3192500, -83.9704800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132977, 'Ashland', 'Ashland', 'Ehshland,Eshland,aesyullaendeu,ai xu lan,ashland,ashlnd  kntaky,ashurando,Ешланд,Эшланд,أشلاند,اشلند، کنتاکی,ایشلنڈ، کینٹکی,アシュランド,愛許蘭,애슐랜드', 38.4784100, -82.6379400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132978, 'Auburn', 'Auburn', 'Auburn,Black Lick,Federal Grove,Obern,Woodville,abrn  kntaky,ao ben,awbwrn,Аубурн,Оберн,آبرن، کنتاکی,آبرن، کینٹکی,أوبورن,奥本', 36.8642100, -86.7102700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132979, 'Audubon Park', 'Audubon Park', '', 38.2039600, -85.7252400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132980, 'Augusta', 'Augusta', 'Augusta,Ogasta,agwsta  kntaky,ao gu si ta,awghsta,Аугуста,Огаста,آگسٹا، کینٹکی,آگوستا، کنتاکی,أوغستا,奥古斯塔', 38.7717400, -84.0057600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132981, 'Barbourmeade', 'Barbourmeade', '', 38.2972900, -85.6032900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132982, 'Barbourville', 'Barbourville', 'Barborvil,Barbourville,Barbourville City,Barbuvill,ba bo wei er,barbwrfyl,barbwrwyl  kntaky,Барборвил,Барбувилл,باربورفيل,باربورویل، کنتاکی,巴伯维尔', 36.8664800, -83.8888100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132983, 'Bardstown', 'Bardstown', 'BRY,Bairdstown,Bards Town,Bardstaun,Bardstoun,Bardstown,Beardstown,Salem,Salem Town,ba ci dui,badeuseutaun,bardastawn  kntaky,bardstawn,Бардстаун,Бардстоун,بارداستاون، کنتاکی,باردستاون,巴兹敦,바드스타운', 37.8092300, -85.4669000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132984, 'Bardwell', 'Bardwell', '', 36.8706100, -89.0097900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132985, 'Beattyville', 'Beattyville', 'Beatty,Beatty Town,Beattyville,Carnahan Patent', 37.5717500, -83.7068600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132986, 'Beaver Dam', 'Beaver Dam', '', 37.4019900, -86.8758300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132987, 'Bedford', 'Bedford', 'Bedford,Бедфорд', 38.5925600, -85.3177300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132988, 'Beechwood Village', 'Beechwood Village', '', 38.2547900, -85.6313500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132989, 'Bellevue', 'Bellevue', '', 39.1064500, -84.4788300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132990, 'Benton', 'Benton', 'Benton,ben dun,benteon,bntn  kntaky,bntwn,Бентон,بنتن، کنتاکی,بنتون,بینٹن، کینٹکی,本顿,벤턴', 36.8572800, -88.3503100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132991, 'Berea', 'Berea', 'Barea,Berea,Berija,The Bresh,The Glades,bo li ya,brya  kntaky,byrya,Береа,Берија,بریا، کنتاکی,بيريا,伯里亚', 37.5686900, -84.2963200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132992, 'Bloomfield', 'Bloomfield', '', 37.9103400, -85.3166200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132993, 'Booneville', 'Booneville', '', 37.4762000, -83.6749100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132994, 'Bowling Green', 'Bowling Green', 'BWG,Bouling Grin,Bouling-Grin,Bowling Green,Bowlinggreen,bao ling ge lin,bolling-geulin,boringugurin,bwlyngh ghryn,bwwlyng gryn  kntaky,Боулинг Грин,Боулинг-Грин,باولنگ گرین، کینٹکی,بولينغ غرين,بوولینگ گرین، کنتاکی,ボーリンググリーン,鮑靈格林,볼링그린', 36.9903200, -86.4436000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132995, 'Brandenburg', 'Brandenburg', 'Brandenberg,Brandenburg,Brehndenburg,Buzzard Roost,bo lan deng bao,brandnbwrgh,brndnbrg  kntaky,Бранденберг,Брэнденбург,براندنبورغ,برندنبرگ، کنتاکی,勃兰登堡', 37.9989600, -86.1694100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132996, 'Breckinridge Center', 'Breckinridge Center', '', 37.6828200, -87.8630800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132997, 'Brodhead', 'Brodhead', 'Broadhead,Brodhead', 37.4042500, -84.4138300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132998, 'Brooks', 'Brooks', '', 38.0611800, -85.7096800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(132999, 'Brooksville', 'Brooksville', 'Brooksville,Brookville', 38.6825700, -84.0657600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133000, 'Brownsville', 'Brownsville', 'Braunsvil,Brounsvil,Brownsville,Point Pleasant,brawnzfyl,brawnzwyl  kntaky,bu lang si wei er,Браунсвил,Броунсвил,براونزفيل,براونزویل، کنتاکی,布朗斯维尔', 37.1925500, -86.2677500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133001, 'Buckner', 'Buckner', '', 38.3836800, -85.4399600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133002, 'Buechel', 'Buechel', 'Beargrass,Buechel,Two Mile Town', 38.1950700, -85.6519000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133003, 'Burkesville', 'Burkesville', 'Berkesvill,Berksvil,Burkesville,Cumberland Crossing,bo ke si wei er,brkswyl  kntaky,bwrksfyl,Беркесвилл,Берксвил,برکسویل، کنتاکی,بوركسفيل,伯克斯维尔', 36.7903400, -85.3705200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133004, 'Burlington', 'Burlington', 'Berligton,Berlington,Burlington,Craigs Camp,Wilmington,bo ling dun,brlyngtn  kntaky,Берлигтон,Берлингтон,برلنگٹن، کینٹکی,برلینگتن، کنتاکی,伯灵顿', 39.0275600, -84.7241100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133005, 'Cadiz', 'Cadiz', 'Kadis,Kadiz,jia de si,kadys  kntaky,kadyz,Кадиз,Кадис,كاديز,کادیس، کنتاکی,加的斯', 36.8650500, -87.8353000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133006, 'Calhoun', 'Calhoun', 'Calhoon,Calhoun,Fort Vienna,Rhoadsville,The Settlement at Long Falls,Vienna', 37.5389400, -87.2583300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133007, 'Calvert City', 'Calvert City', 'Calvert,Calvert City,Kal''vert Siti,Kalvert Siti,ka er fu te cheng,kalfyrt syty,klwrt syty  kntaky,Калверт Сити,Кальверт Сити,كالفيرت سيتي,کلورت سیتی، کنتاکی,卡尔弗特城', 37.0333900, -88.3500400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133008, 'Camargo', 'Camargo', '', 37.9942500, -83.8877000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133009, 'Campbellsville', 'Campbellsville', 'Buck Horn Lick,Campbellsville,Kampbehlsvill,Kampbelsvil,kamblsfyl,kan bei er si wei er,kmblswyl  kntaky,Кампбелсвил,Кампбэлсвилл,كامبلسفيل,کمبلسویل، کنتاکی,坎贝尔斯威尔', 37.3434000, -85.3419100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133010, 'Campton', 'Campton', 'Campton,Kampton,Kehmpton,Soldiers Camp Town,Swifts Camp Town,kambtwn,kan pu dun,kmptwn  kntaky,Камптон,Кэмптон,كامبتون,کمپتون، کنتاکی,坎普顿', 37.7342500, -83.5474100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133011, 'Carlisle', 'Carlisle', 'Karlajl,Karlisl,ka lai er,karlayl  kntaky,karlaysl,Карлајл,Карлисл,كارلايسل,کارلائل، کینٹکی,کارلایل، کنتاکی,卡莱尔', 38.3120200, -84.0274300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133012, 'Carrollton', 'Carrollton', 'Carrollton,Karolton,Karrolton,Port William,The Point,ka luo er dun,karwltwn,krltn  kntaky,Каролтон,Карролтон,كارولتون,کرلتن، کنتاکی,کیرولٹن، کینٹکی,卡罗尔顿', 38.6809000, -85.1794000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133013, 'Catlettsburg', 'Catlettsburg', 'Katlitsberg,Kehtlettsburg,ka te li ci bao,katlytsbwrgh,ktltsbwrg  kntaky,Катлитсберг,Кэтлеттсбург,كاتليتسبورغ,کتلتسبورگ، کنتاکی,卡特利茨堡', 38.4048000, -82.6004400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133014, 'Cave City', 'Cave City', 'Kehjv Siti,Kejv Siti,kai fu cheng,kyf syty,kyw syty  kntaky,Кејв Сити,Кэйв Сити,كيف سيتي,کیو سیتی، کنتاکی,凯夫城', 37.1367200, -85.9569200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133015, 'Central City', 'Central City', 'Cehntral Siti,Sentral Siti,sntr syty,sntral syty  kntaky,zhong yang shi,Сентрал Сити,Цэнтрал Сити,سنتر سيتي,سنترال سیتی، کنتاکی,中央市', 37.2939300, -87.1233300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133016, 'Claryville', 'Claryville', '', 38.9192300, -84.3954900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133017, 'Clay', 'Clay', 'Clay,Claysville', 37.4767100, -87.8200200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133018, 'Clay City', 'Clay City', 'Clay City,Mechanicsville,Smith and Clarks Forge,Smith and Clay Forge', 37.8592500, -83.9185300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133019, 'Clinton', 'Clinton', 'Klinton,Клинтон', 36.6672800, -88.9934000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133020, 'Cloverport', 'Cloverport', '', 37.8333900, -86.6327600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133021, 'Coal Run Village', 'Coal Run Village', 'Coal Run,Coal Run Village,Coalrun', 37.5131600, -82.5584900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133022, 'Cold Spring', 'Cold Spring', 'Cold Spring,Leitchs Station', 39.0217300, -84.4399400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133023, 'Coldstream', 'Coldstream', '', 38.3147900, -85.5238500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133024, 'Columbia', 'Columbia', 'Kolambija,Kolumbija,ge lun bi ya,klmbya  kntaky,kwlwmbya,Коламбија,Колумбия,كولومبيا,کلمبیا، کنتاکی,کولمبیا، کینٹکی,哥伦比亚', 37.1028400, -85.3063500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133025, 'Corbin', 'Corbin', 'Korbin,ke er bin,krbyn  kntaky,kwrbn,Корбин,كوربن,کربین، کنتاکی,科尔宾', 36.9487000, -84.0968800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133026, 'Covington', 'Covington', 'Kavington,Kovington,ka wen dun,kawyngtn  kntaky,keobingteon,kobinton,kwfynghtwn,Кавингтон,Ковингтон,Ковінгтон,كوفينغتون,کاوینگتن، کنتاکی,کوونگٹن، کینٹکی,コビントン,卡温顿,커빙턴', 39.0836700, -84.5085500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133027, 'Crescent Springs', 'Crescent Springs', '', 39.0514500, -84.5816100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133028, 'Crestview Hills', 'Crestview Hills', 'Crestview Hills,Dudley Pike', 39.0272800, -84.5849400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133029, 'Crestwood', 'Crestwood', '', 38.3242400, -85.4724600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133030, 'Crittenden', 'Crittenden', '', 38.7828400, -84.6052200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133031, 'Cumberland', 'Cumberland', 'Kamberlend,Камберленд', 36.9781500, -82.9885000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133032, 'Cynthiana', 'Cynthiana', 'Kinziana,Sintijana,kynthyana,synsyana  kntaky,xin xi ya na,Кинзиана,Синтијана,سینسیانا، کنتاکی,كينثيانا,辛西亚纳', 38.3903500, -84.2941000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133033, 'Danville', 'Danville', 'Crows Station,Danvil,Danville,Dehnvill,John Crows Station,daenbil,dan wei er,danfyl,dnwyl  kntaky,Данвил,Дэнвилл,دانفيل,دنویل، کنتاکی,ڈینویل، کینٹکی,丹維爾,댄빌', 37.6456300, -84.7721700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133034, 'Dawson Springs', 'Dawson Springs', 'Dawson,Dawson City,Dawson Springs,Dawsonsprings,Donson Springs,Douson Springs,Tradewater,dao sen si pu lin si,dawsn aspryngz  kntaky,dawswn sbrynghz,Донсон Спрингс,Доусон Спрингс,داوسن اسپرینگز، کنتاکی,داوسون سبرينغز,道森斯普林斯', 37.1672700, -87.6925100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133035, 'Dayton', 'Dayton', 'Brooklyn,Dayton,Dehjton,Dejton,Jamestown,dai dun,daytwn,detana,dytn  kntaky,Дейтон,Дејтон,Дэйтон,دايتون,دیتن، کنتاکی,ڈیٹن، کینٹکی,डेटन,代顿', 39.1128400, -84.4727200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133036, 'Dixon', 'Dixon', '', 37.5178200, -87.6902900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133037, 'Douglass Hills', 'Douglass Hills', '', 38.2378500, -85.5527400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133038, 'Dry Ridge', 'Dry Ridge', '', 38.6820100, -84.5899400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133039, 'Earlington', 'Earlington', '', 37.2742100, -87.5119400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133040, 'Eddyville', 'Eddyville', '', 37.0945000, -88.0803000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133041, 'Edgewood', 'Edgewood', '', 39.0186700, -84.5818900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133042, 'Edmonton', 'Edmonton', 'Edmonton,Ehdmonton,admntwn  kntaky,admwntwn,ai de meng dun,edeumeonteon,Едмонтон,Эдмонтон,إدمونتون,ادمنتون، کنتاکی,埃德蒙顿,에드먼턴', 36.9800600, -85.6121900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133043, 'Elizabethtown', 'Elizabethtown', 'EKX,Ehlizabettaun,Elizabettaun,alyzabttawn  kntaky,yi li sha bai,Елизабеттаун,Элизабеттаун,الیزابتتاون، کنتاکی,伊丽莎白', 37.6939500, -85.8591300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133044, 'Elk Creek', 'Elk Creek', '', 38.1003400, -85.3710700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133045, 'Elkfork', 'Elkfork', 'Elk Fork,Elkfork', 37.9648100, -83.1329500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133046, 'Elkton', 'Elkton', 'Elk Town,Elkton', 36.8100400, -87.1541700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133047, 'Elsmere', 'Elsmere', 'Elsmere,South Erlanger', 39.0125600, -84.6046700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133048, 'Eminence', 'Eminence', 'Ehminens,Eminens,ai mi nen si,amnns  kntaky,amynns,Еминенс,Эминенс,إميننس,امننس، کنتاکی,埃米嫩斯', 38.3700700, -85.1805100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133049, 'Erlanger', 'Erlanger', 'Ehrlanger,Erlanger,Greenwood Lake,Timberlake,aranga,ayrlanghr,e lan ge,rlngr  kntaky,Ерлангер,Эрлангер,إيرلانغر,ایرلینگیر، کینٹکی,رلنگر، کنتاکی,アーランガー,厄兰格', 39.0167300, -84.6007800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133050, 'Fairdale', 'Fairdale', 'Coral Ridge,Fairdale', 38.1050700, -85.7588500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133051, 'Falmouth', 'Falmouth', 'Falmouth,Falmut,Fehlmous,The Forks of the Licking,fa er mao si,falmawth,flmt  kntaky,Фалмут,Фэлмоус,فالماوث,فلمت، کنتاکی,法尔茅斯', 38.6767400, -84.3302100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133052, 'Fern Creek', 'Fern Creek', 'Fern Creek,Stringtown on the Pike', 38.1597900, -85.5877400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133053, 'Flatwoods', 'Flatwoods', '', 38.5225800, -82.7171100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133054, 'Flemingsburg', 'Flemingsburg', 'Flemingsburg,Stockton Station', 38.4223000, -83.7338100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133055, 'Florence', 'Florence', 'Connersville,Crossroads,Florence,Florencija,Florens,Maddensville,Maddentown,Maddontwon,flwrns,flwrns  kntaky,fu luo lun sa,furorensu,Флоренс,Флоренция,فلورنس,فلورنس، کنتاکی,فلورنس، کینٹکی,フローレンス,佛羅倫薩', 38.9989500, -84.6266100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133056, 'Fort Mitchell', 'Fort Mitchell', '', 39.0595000, -84.5474400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133057, 'Fort Thomas', 'Fort Thomas', 'Fort Thomas,Guyville,Mount Pleasant,Rossford', 39.0750600, -84.4471600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133058, 'Fort Wright', 'Fort Wright', 'Fort Wright,Lookout Hieghts,Lookout Hieghts-Fort Wright,South Hills', 39.0517300, -84.5341100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133059, 'Francisville', 'Francisville', '', 39.1050600, -84.7243900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133060, 'Frankfort', 'Frankfort', 'FFT,Fran''kfort,Frankfort,Frankforta,Frankfortas,Frankforts,Frankfurt,Frehnkfort,Frenkfort,Gorad Frankfart,The Big Bend,fa lan ke fu,frankfort,frankfwrt,frankfwrt  kntaky,furankufoto,peulaengkeupeoteu,phramkaphorta,phrankapharta,phryankaphorta,piranport,prnqpwrt,Φράνκφορτ,Горад Франкфарт,Франкфорт,Франкфурт,Френкфорт,Фрэнкфорт,Ֆրանկֆորտ,פרנקפורט,فرانكفورت,فرانکفورت، کنتاکی,فرینک فورٹ، کینٹکی,فرینکفورٹ,फ़्रांक्फ़ोर्ट्,फ्रँकफोर्ट,फ्राङ्कफर्त,फ्र्यांकफोर्ट,பிராங்போர்ட்,แฟรงก์เฟิร์ต,フランクフォート,法兰克福,프랭크퍼트', 38.2009100, -84.8732800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133061, 'Franklin', 'Franklin', 'Franklin,Frehnklin,franklyn,franklyn  kntaky,fu lan ke lin,Франклин,Фрэнклин,فرانكلين,فرانکلین، کنتاکی,فرینکلن، کینٹکی,富兰克林', 36.7222600, -86.5772200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133062, 'Frenchburg', 'Frenchburg', 'Frenchberg,Frenchburg,frnchbwrg  kntaky,frnshbwrgh,fu lun qi bao,Френчберг,Френчбург,فرنشبورغ,فرنچبورگ، کنتاکی,弗伦奇堡', 37.9509200, -83.6257500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133063, 'Fulton', 'Fulton', 'Fulton,fu er dun,fwltn  kntaky,fwltwn,Фултон,فلٹن، کینٹکی,فولتن، کنتاکی,فولتون,富尔顿', 36.5042300, -88.8742300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133064, 'Georgetown', 'Georgetown', 'Dzhorzhtaun,Dzordztaun,George Town,Georgetown,Lebanon Station,McClellans Station,jojitaun,jrj‌tawn  kntaky,jwrjtawn,qiao zhi dui,Џорџтаун,Джоржтаун,جارج ٹاؤن، کینٹکی,جرج‌تاون، کنتاکی,جورجتاون,ジョージタウン,乔治敦,조지타운', 38.2098000, -84.5588300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133065, 'Glasgow', 'Glasgow', 'GLW,Glazgou,ge la si ge,ghlaskw,glasgw  kntaky,Глазгоу,غلاسكو,گلاسگو، کنتاکی,格拉斯哥', 36.9958800, -85.9119200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133066, 'Graymoor-Devondale', 'Graymoor-Devondale', 'Devondale,Graymoor,Graymoor-Devondale', 38.2731300, -85.6230200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133067, 'Grayson', 'Grayson', '', 38.3325800, -82.9485000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133068, 'Greensburg', 'Greensburg', 'Grinsburg,ge lin,ghrynsbwrj,grynzbrg  kntaky,Гринсбург,غرينسبورج,گرینزبرگ، کنتاکی,گرینزبرگ، کینٹکی,格林', 37.2608900, -85.4988500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133069, 'Greenup', 'Greenup', 'Grinap,Grinup,ge li na pu,grynap  kntaky,Гринап,Гринуп,گریناپ، کنتاکی,格里纳普', 38.5731300, -82.8301700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133070, 'Greenville', 'Greenville', 'Grinvil,Grinvil'',Grinvill,ge lin wei er,ghrynfyl,grynwyl  kntaky,Гринвил,Гринвилл,Ґрінвіль,غرينفيل,گرینویل، کنتاکی,گرینویل، کینٹکی,格林维尔', 37.2011500, -87.1788900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133071, 'Guthrie', 'Guthrie', '', 36.6483800, -87.1663900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133072, 'Hardinsburg', 'Hardinsburg', 'Hardinsburg,Smoketown', 37.7800600, -86.4605300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133073, 'Harlan', 'Harlan', 'Kharlan,ha lun,harlan,harln  kntaky,Харлан,هارلان,هارلن، کنتاکی,哈伦', 36.8431400, -83.3218500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133074, 'Harrodsburg', 'Harrodsburg', 'Harrod''s Town,Harrodsburg,Harrodstown,Hogtown,Kharodsburg,Kharrodsburg,Old Town,ha luo ci bai ge,harwdsbwrg,harwdsbwrgh,Хародсбург,Харродсбург,هارودسبورغ,هارودسبورگ,哈洛兹柏格', 37.7623000, -84.8432900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133075, 'Hartford', 'Hartford', 'Fort Hartford,Hartford,Hartford Court House,Hartford Station,Hartsford,Hartsford Station,Khartford,ha te fu de,hartfrd  kntaky,hartfwrd,Хартфорд,هارتفرد، کنتاکی,هارتفورد,ہارٹفورڈ، کینٹکی,哈特福德', 37.4511600, -86.9091600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133076, 'Hawesville', 'Hawesville', 'Khauesvill,hawsfyl,hawswyl,huo si wei er,Хауесвилл,هاوسفيل,هاوسویل,霍斯维尔', 37.9000600, -86.7549900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133077, 'Hazard', 'Hazard', 'Khazard,ha ze de,haejeodeu,hazard,hzrd  kntaky,Хазард,هازارد,هزرد، کنتاکی,哈泽德,해저드', 37.2495400, -83.1932300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133078, 'Hebron', 'Hebron', 'Briar Patch,Hebron,Tailholt', 39.0658900, -84.7010600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133079, 'Hebron Estates', 'Hebron Estates', '', 38.0495100, -85.6660700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133080, 'Henderson', 'Henderson', 'Khenderson,hendason,heng de sen,hndrsn  kntaky,hndrswn,Хендерсон,هندرسن، کنتاکی,هندرسون,ہینڈرسن، کینٹکی,ヘンダーソン,亨德森', 37.8361500, -87.5900100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133081, 'Hendron', 'Hendron', '', 37.0395000, -88.6292200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133082, 'Hickman', 'Hickman', 'Hickman,Khikman,Mills Point,hykman,hykmn  kntaky,xi ke man,Хикман,هيكمان,هیکمن، کنتاکی,希克曼', 36.5711700, -89.1861800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133083, 'Highland Heights', 'Highland Heights', 'Highland Heights,The Highlands', 39.0331200, -84.4518900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133084, 'Highview', 'Highview', '', 38.1428500, -85.6241300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133085, 'Hillview', 'Hillview', 'Hillview,Maryville', 38.0697900, -85.6855100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133086, 'Hindman', 'Hindman', 'Fork of Troublesome,Hindman,Khajndman,hyndman,hyndmn  kntaky,xin de man,Хайндман,Хајндман,هيندمان,هیندمن، کنتاکی,辛德曼', 37.3359300, -82.9804400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133087, 'Hodgenville', 'Hodgenville', 'Khodzenvil,Khodzhenvill,hajnwyl  kntaky,huo jin wei er,hwdghnfyl,Ходженвилл,Хоџенвил,هاجنویل، کنتاکی,هودغنفيل,霍金维尔', 37.5739500, -85.7399600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133088, 'Hopkinsville', 'Hopkinsville', 'Elizabeth,Elizabethtown,HOP,Hopkinsville,Hoptown,Khopkinsvil,Khopkinsvill,Khopkinsville,Woods Settlement,hapkynzwyl,hopukinsubiru,huo pu jin si,hwbkynzfyl,Хопкинсвил,Хопкинсвилл,Хопкинсвилле,هاپکینزویل,هوبكينزفيل,ہاپکنزویل، کینٹکی,ホプキンスビル,霍普金斯', 36.8656100, -87.4911700, 'US', '2017-06-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133089, 'Horse Cave', 'Horse Cave', 'Khors Kehjv,Khors Kejv,huo si kai fu,hwrs kyf,hwrs kyw  kntaky,Хорс Кејв,Хорс Кэйв,هورس كيف,هورس کیو، کنتاکی,霍斯凯夫', 37.1795000, -85.9069200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133090, 'Hurstbourne Acres', 'Hurstbourne Acres', '', 38.2211800, -85.5891300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133091, 'Hurstbourne', 'Hurstbourne', '', 38.2381300, -85.5882900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133092, 'Hyden', 'Hyden', 'Khajden,Khehjden,hai dun,haydn,hydn  kntaky,Хајден,Хэйден,هايدن,هیدن، کنتاکی,海顿', 37.1609300, -83.3732400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133093, 'Independence', 'Independence', 'Independens,Independense,andbndns,ayndypndns  kntaky,du li cheng,indipendensu,Индепенденс,Индепенденсе,إندبندنس,انڈیپینڈینس، کینٹکی,ایندیپندنس، کنتاکی,インディペンデンス,独立城', 38.9431200, -84.5441100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133094, 'Indian Hills', 'Indian Hills', '', 38.2725700, -85.6627400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133095, 'Indian Hills Cherokee Section', 'Indian Hills Cherokee Section', 'Cherokee,Indian Hills Cherokee Section', 38.2795100, -85.6499600, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133096, 'Inez', 'Inez', 'Ajnez,Eden,Inez,anyz,aynz  kntaky,yi nei ci,Айнез,Ајнез,إنيز,اینز، کنتاکی,伊内兹', 37.8664800, -82.5387600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133097, 'Ironville', 'Ironville', '', 38.4564700, -82.6923800, 'US', '2012-07-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133098, 'Irvine', 'Irvine', 'Ervajn,Irvin,arfyn,arwyn  kntaky,eobain,ou wen,Ервајн,Ирвин,إرفين,اروین، کنتاکی,欧文,어바인', 37.7006400, -83.9738100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133099, 'Irvington', 'Irvington', '', 37.8803400, -86.2838600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133100, 'Jackson', 'Jackson', 'Dzekson,Dzhehkson,Dzhekson,jakswn,jakuson,jie ke xun,jksn  kntaky,Џексон,Джексон,Джэксон,جاكسون,جکسن، کنتاکی,جیکسن، کینٹکی,ジャクソン,杰克逊', 37.5531500, -83.3835100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133101, 'Jackson', 'Jackson', '', 37.8250800, -84.8707900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133102, 'Jamestown', 'Jamestown', 'Dzejmstaun,Dzhehjmstoun,Jacksonville,Jamestown,Jim Town,Jtown,jymstawn,jymztawn  kntaky,zhan mu si dui,Џејмстаун,Джэймстоун,جيمستاون,جیمز ٹاون، کینٹکی,جیمزتاون، کنتاکی,詹姆斯敦', 36.9847900, -85.0630100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133103, 'Jeffersontown', 'Jeffersontown', 'Bruners Town,Brunerstown,Dzefersontaun,Dzhehfferstoun,Jefferson,Jefferson Town,Jeffersontown,jfrsntawn  kntaky,Џеферсонтаун,Джэфферстоун,جفرسنتاون، کنتاکی', 38.1942400, -85.5644000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133104, 'Jeffersonville', 'Jeffersonville', 'Jeffersonville,Ticktown', 37.9736900, -83.8418600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133105, 'Jenkins', 'Jenkins', 'Dzenkins,Dzhenkins,jnkyns  kntaky,jynkynz,zhan jin si,Џенкинс,Дженкинс,جنکینس، کنتاکی,جينكينز,詹金斯', 37.1734400, -82.6309900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133106, 'Junction City', 'Junction City', 'Dzankshon Siti,Dzhankshn Siti,Goresburgh,Junction,Junction City,jankshn syty  kntaky,jnkshn syty,qiang ke xun cheng,Џанкшон Сити,Джанкшн Сити,جانکشن سیتی، کنتاکی,جنكشن سيتي,强克逊城', 37.5867400, -84.7938400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133107, 'Knottsville', 'Knottsville', 'Hearts Delight,Knottsville,Nottsville', 37.7717200, -86.9041600, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133108, 'La Center', 'La Center', 'Ballard Center,La Center,Maryville', 37.0767200, -88.9736800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133109, 'La Grange', 'La Grange', 'La Grange,LaGrange,The Crossroads', 38.4075700, -85.3788500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133110, 'Lakeside Park', 'Lakeside Park', '', 39.0356200, -84.5691100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133111, 'Lancaster', 'Lancaster', 'Lancaster,Lankaster,Wallaces Crossroads,lan kai si te,lankstr,lnkstr  kntaky,Ланкастер,لانكستر,لانکیسٹر، کینٹوکی,لنکستر، کنتاکی,兰开斯特', 37.6195200, -84.5780000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133112, 'Lawrenceburg', 'Lawrenceburg', 'Coffman Station,Kaufman Station,Kaufmans Station,Laurensburg,Lawrence,Lawrenceburg,Lorensburg,lao lun si bao,larnsbrg  kntaky,lolenseubeogeu,lwrns,rorensubagu,Лауренсбург,Лоренсбург,لارنسبرگ، کنتاکی,لورنس,ローレンスバーグ,劳伦斯堡,로렌스버그', 38.0373000, -84.8966200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133113, 'Lebanon', 'Lebanon', 'Lebanon,lbnan,lbnan  kntaky,lebeoneon,li ba nen,Лебанон,لبنان,لبنان، کنتاکی,黎巴嫩,레버넌', 37.5697900, -85.2527400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133114, 'Lebanon Junction', 'Lebanon Junction', '', 37.8345100, -85.7319000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133115, 'Ledbetter', 'Ledbetter', 'Ledbetter,Panhandle', 37.0475600, -88.4769900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133116, 'Leitchfield', 'Leitchfield', 'Lehjtchfild,Lichfild,li qi fei er de,lychfyld  kntaky,lytshfyld,Личфилд,Лэйтчфилд,ليتشفيلد,لیچفیلد، کنتاکی,利奇菲尔德', 37.4800500, -86.2938600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133117, 'Lewisport', 'Lewisport', 'L''juuisport,Lewisport,Little Yellow Banks,Luisport,Prentisport,lu yi si bo te,lwysbwrt,lwyspwrt  kntaky,Луиспорт,Льюуиспорт,لويسبورت,لویسپورت، کنتاکی,路易斯波特', 37.9370000, -86.9022100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133118, 'Lexington', 'Lexington', 'LEX,Leksington,Leksingtona,Leksingtonas,Leksingtono,Leksingtun,Leksinqton,Lexington,Lexington-Fayette,Lexintonia,legsingteon,leksingtana,lie ke xing dui,lksyngtwn  kntaky,lqsyngtwn,lyksynghtwn,rekishinton,Лексингтон,Лексингтън,לקסינגטון,ليكسينغتون,لکسینگتون، کنتاکی,لیکسنگٹن، کینٹکی,लेक्सिंग्टन,ലെക്സിങ്ടൺ,ლექსინგტონი,レキシントン,列克星敦,렉싱턴', 37.9886900, -84.4777200, 'US', '2016-05-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133119, 'Lexington-Fayette', 'Lexington-Fayette', 'Fayette County,Lexington,Lexington-Fayette', 38.0498000, -84.4585500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133120, 'Liberty', 'Liberty', 'Liberti,li bo di,lybrty,lybrty  kntaky,Либерти,ليبرتي,لیبرتی، کنتاکی,利伯蒂', 37.3184100, -84.9394000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133121, 'Livermore', 'Livermore', 'Livurmor,Ливърмор', 37.4931000, -87.1319400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133122, 'London', 'London', 'LOZ,Landon,London,Riceton,lndn,lndn  kntaky,lun dui,Ландон,Лондон,لندن,لندن، کنتاکی,伦敦', 37.1289800, -84.0832600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133123, 'Louisa', 'Louisa', 'Fork of the Big Sandy,Italy,Louisa,Luiza,Lujza,lu yi sha,lwyyza  kntaky,lwyza,Луиза,Луйза,لوئیزا، کنتاکی,لويزا,路易莎', 38.1142500, -82.6032100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133124, 'Louisville', 'Louisville', 'Gorad Luisvil,Louisvil,Louisville,Louisville-Jefferson County,Ludovicopolis,Luisvil,Luisvilis,Luisvill,Luivil,Luivila,Lujzvill,Lūivila,SDF,lu yi wei er,lu''ivhila,lu-ibil,lu-ijeubil,lubhala,luisvili,luizvili,luy s will,luyivil,lwyfyl,lwyywyl  kntaky,ruibiru,Λούισβιλ,Горад Луісвіл,Луивил,Луисвил,Луисвилл,Луйзвилл,Луїсвілл,Լուիսվիլ,לואיוויל,لوئیزویل، کینٹکی,لويفيل,لوییویل، کنتاکی,लुईव्हिल,লুভল,லூயிவில்,ลุยส์วิลล์,ლუიზვილი,ლუისვილი,ルイビル,路易維爾,루이빌,루이즈빌', 38.2542400, -85.7594100, 'US', '2017-06-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133125, 'Ludlow', 'Ludlow', 'Ladlou,ladlww  kntaky,lei de luo,lwdlw,Ладлоу,لادلوو، کنتاکی,لودلو,勒德洛', 39.0925600, -84.5474400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133126, 'Lyndon', 'Lyndon', 'Lindon,lin deng,lyndn  kntaky,lyndwn,Линдон,ليندون,لیندن، کنتاکی,林登', 38.2567400, -85.6016300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133127, 'Madisonville', 'Madisonville', 'Medisonvil,Mehdisonvil'',madisonbiru,madyswnfyl,mai di xun wei er,mdsnwyl  kntaky,medisanavhila,Медисонвил,Мэдисонвиль,ماديسونفيل,مدسنویل، کنتاکی,میڈیسونویلی، کینٹوکی,मॅडिसनव्हिल,マディソンビル,麦迪逊维尔', 37.3281000, -87.4988900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133128, 'Manchester', 'Manchester', 'Manchester,man che si te,manshstr,mnchstrr  kntaky,Манчестер,مانشستر,مانچسٹر، کینٹکی,منچسترر، کنتاکی,曼彻斯特', 37.1537000, -83.7618600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133129, 'Marion', 'Marion', 'Marion,Mehrion,ma li ang,marywn,mryan  kntaky,Марион,Мэрион,ماريون,ماریون، کینٹکی,مریان، کنتاکی,马里昂', 37.3328300, -88.0811300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133130, 'Masonville', 'Masonville', '', 37.6750500, -87.0347200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133131, 'Massac', 'Massac', 'Massac,Massack', 37.0167200, -88.7306100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133132, 'Mayfield', 'Mayfield', 'Mehjfild,Mejfild,mayfyld,mei fei er de,myfyld  kntaky,Мејфилд,Мэйфилд,مايفيلد,میفیلد، کنتاکی,梅菲尔德', 36.7417200, -88.6367200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133133, 'Maysville', 'Maysville', 'Maysville,Mehjsvil,Mejsvil,Plugtown,maysfyl,mayzwyl  kntaky,mei si wei er,meijeubil,Мејсвил,Мэйсвил,مايسفيل,مایزویل، کنتاکی,梅斯维尔,메이즈빌', 38.6411900, -83.7443700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133134, 'McKee', 'McKee', '', 37.4303600, -83.9979800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133135, 'Meads', 'Meads', '', 38.4125800, -82.7090500, 'US', '2012-07-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133136, 'Middlesboro', 'Middlesboro', 'Middlesboro,Middlesborough', 36.6084200, -83.7165800, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133137, 'Middletown', 'Middletown', '', 38.2453500, -85.5388500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133138, 'Midway', 'Midway', 'Middleway,Miduehj,Midvej,Midway,mi de wei,mydwy  kntaky,Мидвеј,Мидуэй,میدوی، کنتاکی,米德韦', 38.1509100, -84.6838300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133139, 'Heritage Creek', 'Heritage Creek', 'Heritage Creek,Minor Lane Heights', 38.1236800, -85.7196800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133140, 'Monticello', 'Monticello', 'Montichello,Montiselo,mantyslw  kntaky,meng di sai luo,mwntayslw,Монтисело,Монтичелло,مانتیسلو، کنتاکی,مونتايسلو,蒙蒂塞洛', 36.8297900, -84.8491100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133141, 'Monticello', 'Monticello', '', 37.9923000, -84.5502200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133142, 'Morehead', 'Morehead', 'Morkhid,mo er hei de,mwrhd  kntaky,mwrhyd,Морхид,مورهد، کنتاکی,مورهيد,莫尔黑德', 38.1839700, -83.4326800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133143, 'Morehead', 'Morehead', '', 37.2711500, -87.1763800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133144, 'Morganfield', 'Morganfield', '', 37.6833800, -87.9166900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133145, 'Morgantown', 'Morgantown', 'Funkhouser Hill,Morgantaun,Morgantown,Morgantuan,mo gen cheng,mwrgantawn  kntaky,mwrghantawn,Моргантаун,Моргантуан,مورغانتاون,مورگانتاون، کنتاکی,مورگن ٹاؤن، کینٹکی,摩根城', 37.2256000, -86.6836000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133146, 'Mount Olivet', 'Mount Olivet', '', 38.5314600, -84.0368700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133147, 'Mount Sterling', 'Mount Sterling', 'Maunt Sterling,Maunt Streling,mang te si te ling,mawnt astrlyng  kntaky,mawnt styrlyngh,Маунт Стерлинг,Маунт Стрелинг,ماونت استرلینگ، کنتاکی,ماونت ستيرلينغ,芒特斯特灵', 38.0564700, -83.9432600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133148, 'Mount Vernon', 'Mount Vernon', '', 38.0256300, -84.4952200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133149, 'Mount Vernon', 'Mount Vernon', 'Langford,Mount Vernon,Rockcastle,Spout Springs,White Rock', 37.3528600, -84.3404900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133150, 'Mount Washington', 'Mount Washington', 'Crossroads,Mount Vernon,Mount Washington,Mountvernon,The Cross Roads', 38.0500600, -85.5457900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133151, 'Munfordville', 'Munfordville', '', 37.2722800, -85.8910800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133152, 'Murray', 'Murray', 'CEY,Mari,Mjurrej,Murray,Murrehj,Pleasant Hill,Pooltown,Williston,mare,meoli,mu lei,mwray,mwry  kntaky,Мари,Муррэй,Мюррей,مرے، کینٹکی,موراي,موری، کنتاکی,マレー,穆雷,머리', 36.6103300, -88.3147600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133153, 'New Castle', 'New Castle', '', 38.4334000, -85.1696800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133154, 'Newburg', 'Newburg', '', 38.1600700, -85.6596800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133155, 'Newport', 'Newport', 'N''juport,Njuport,niu bo te,nyupoto,nywbwrt,nywpwrt  kntaky,Њупорт,Ньюпорт,نيوبورت,نیوپورت، کنتاکی,نیوپورٹ، کینٹکی,ニューポート,纽波特', 39.0914500, -84.4957800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133156, 'Nicholasville', 'Nicholasville', 'Nicholasvill,Nikolasvil,ni gu la si wei er,nikorasubiru,nyklaswyl  kntaky,nyshlsfyl,Николасвил,Ничоласвилл,نيشلسفيل,نیکلاسویل، کنتاکی,نیکولسویل، کینٹکی,ニコラスビル,尼古拉斯維爾', 37.8806300, -84.5730000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133157, 'North Corbin', 'North Corbin', '', 36.9606400, -84.0932600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133158, 'Northfield', 'Northfield', '', 38.2870100, -85.6410700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133159, 'Nortonville', 'Nortonville', 'Norton,Norton Village,Nortonville', 37.1908800, -87.4527800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133160, 'Oak Grove', 'Oak Grove', 'Oak Grove,Thompkinsville', 36.6650500, -87.4427900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133161, 'Oak Grove', 'Oak Grove', 'Flint Springs,Oak Grove', 37.3442100, -86.7547100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133162, 'Oakbrook', 'Oakbrook', '', 38.9997800, -84.6852200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133163, 'Okolona', 'Okolona', 'Lone Oak,Okolona,The Ponds Area', 38.1411800, -85.6877400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133164, 'Olive Hill', 'Olive Hill', '', 38.3000800, -83.1740700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133165, 'Orchard Grass Hills', 'Orchard Grass Hills', '', 38.3236800, -85.5213500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133166, 'Owensboro', 'Owensboro', 'OWB,Ouensboro,Ouensburou,Ounsboro,Owensboro,Owensborough,Yellow Banks,awwnzbrww  kntaky,awynsbwrw,o-eonjeubeoleo,oenzuboro,ou wen si bo lei,Оуенсборо,Оуенсбъроу,Оунсборо,أوينسبورو,اوونزبروو، کنتاکی,اوینسبورو، کینٹکی,オーエンズボロ,欧文斯伯勒,오언즈버러', 37.7742200, -87.1133300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133167, 'Owenton', 'Owenton', 'Ouenton,awwntwn  kntaky,awyntwn,ou wen dun,Оуентон,أوينتون,اوونتون، کنتاکی,欧文顿', 38.5367200, -84.8433800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133168, 'Owingsville', 'Owingsville', 'Ouingsvill,ao yin si wei er,awwyngswyl  kntaky,awynghsfyl,Оуингсвилл,أوينغسفيل,اووینگسویل، کنتاکی,奥因斯维尔', 38.1448000, -83.7640800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133169, 'Paintsville', 'Paintsville', 'Pehjntsvill,Pejnttsvil,byntsfyl,pei en ci wei er,pyntswyl  kntaky,Пејнттсвил,Пэйнтсвилл,بينتسفيل,پینتسویل، کنتاکی,佩恩茨维尔', 37.8145400, -82.8071100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133170, 'Park Hills', 'Park Hills', '', 39.0714500, -84.5321700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133171, 'Paris', 'Paris', 'Paris,Parizh,ba li,barys,parys  kntaky,Париж,Парис,باريس,پاریس، کنتاکی,پیرس، کینٹکی,巴黎', 38.2098000, -84.2529900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133172, 'Pewee Valley', 'Pewee Valley', 'Pivi Vali,Pivi Vehllej,bywy,pywy wly  kntaky,Пиви Вали,Пиви Вэллей,بيوي,پیوی ولی، کنتاکی', 38.3106200, -85.4874600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133173, 'Pikeville', 'Pikeville', 'Pajkvill,Pakjvil,bayksfyl,pai ke wei er,paikubiru,paykwyl  kntaky,Пайквилл,Пакјвил,بايكسفيل,پایکویل، کنتاکی,パイクビル,派克维尔', 37.4792700, -82.5187600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133174, 'Pine Knot', 'Pine Knot', 'High Point,Pine Knot', 36.6509100, -84.4385500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133175, 'Pineville', 'Pineville', 'Pajnvil,Pajnvill,bynyfyly,pai en wei er,paynwyl  kntaky,Пайнвилл,Пајнвил,بينيفيلي,پاینویل، کنتاکی,派恩维尔', 36.7620300, -83.6949200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133176, 'Pioneer Village', 'Pioneer Village', '', 38.0606200, -85.6777400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133177, 'Plano', 'Plano', 'Plano,Plano Store', 36.8803200, -86.4183200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133178, 'Pleasure Ridge Park', 'Pleasure Ridge Park', 'Painesville,Pleasure Ridge Park', 38.1453500, -85.8583000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133179, 'Prestonsburg', 'Prestonsburg', 'Prestonburg,Prestons Station,Prestonsberg,Prestonsburg,Prestonsburgh,Surlocks Station,brystwnzbwrgh,prstwnsbwrg  kntaky,pu lei si dun,Престонбург,Престонсберг,بريستونزبورغ,پرستونسبورگ، کنتاکی,پریسٹنسبرگ، کینٹکی,普勒斯顿', 37.6656500, -82.7715500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133180, 'Princeton', 'Princeton', 'Pricton,Prince Place,Princeton,Princetown,Prinston,brynstwn,prynstwn  kntaky,pu lin si dun,Принстон,Прицтон,برينستون,پرنسٹن، کینٹکی,پرینستون، کنتاکی,普林斯顿', 37.1092200, -87.8819600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133181, 'Prospect', 'Prospect', 'Prospect,Sand Hill', 38.3450700, -85.6155200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133182, 'Providence', 'Providence', '', 38.5745100, -85.2210700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133183, 'Providence', 'Providence', 'Providence,Providens,Savageville,Провиденс', 37.3975500, -87.7627900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133184, 'Raceland', 'Raceland', '', 38.5400800, -82.7285000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133185, 'Radcliff', 'Radcliff', 'Mill Creek,Rad Cliffe,Radcliff,Radcliffe,Radklif,Rehdkliff,lei de ke li fu,radklyf,radokurifu,rdklyf  kntaky,Радклиф,Рэдклифф,رادكليف,ردکلیف، کنتاکی,ریڈکلف، کینٹکی,ラドクリフ,雷德克里夫', 37.8403500, -85.9491300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133186, 'Reidland', 'Reidland', '', 37.0175600, -88.5314300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133187, 'Richmond', 'Richmond', 'Richmond,li shi man,lichimeondeu,rychmnd  kntaky,ryzmwnd,Ричмонд,ריצמונד,ریچمند، کنتاکی,里士滿,리치먼드', 37.7478600, -84.2946500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133188, 'Russell', 'Russell', '', 38.5173000, -82.6976600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133189, 'Russell Springs', 'Russell Springs', 'Allen Spring,Russell Springs,Seven Sister Spring', 37.0561800, -85.0885700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133190, 'Russellville', 'Russellville', 'Big Boiling Spring,Butchers Station,Cooks Station,Gasper,Logan Courthouse,Raselvil,Rassellvill,Rasselvil,Russellville,la sai er wei er,leoselbil,raslwyl  kntaky,Раселвил,Расселвил,Расселлвилл,راسلویل، کنتاکی,拉塞尔维尔,러셀빌', 36.8453200, -86.8872200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133191, 'Ryland Heights', 'Ryland Heights', '', 38.9575600, -84.4630000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133192, 'Saint Matthews', 'Saint Matthews', 'Gilmans Point,Saint Matthews', 38.2528500, -85.6557900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133193, 'Saint Regis Park', 'Saint Regis Park', '', 38.2267400, -85.6166300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133194, 'Salyersville', 'Salyersville', 'Adamsville,Salyersville,Sehliersvill,sa li er si wei er,salyrsfyl,slyrswyl  kntaky,Сэлиерсвилл,ساليرسفيل,سلیرسویل، کنتاکی,萨利尔斯维尔', 37.7525900, -83.0687800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133195, 'Sandy Hook', 'Sandy Hook', 'Martinsburg,Sandi Khuk,Sandy Hook,Sehndi Khuk,sandy hwk,sang di hu ke,sndy hwk  kntaky,Санди Хук,Сэнди Хук,ساندي هوك,سندی هوک، کنتاکی,桑迪胡克', 38.0864700, -83.1262800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133196, 'Scottsville', 'Scottsville', 'Skotsvil,Skotsvill,askatswyl  kntaky,si ke ci wei er,skwtsfyl,sukottsubiru,Скотсвил,Скотсвилл,اسکاتسویل، کنتاکی,سكوتسفيل,سکاٹسویل، کینٹکی,スコッツビル,斯科茨维尔', 36.7533800, -86.1905400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133197, 'Sebree', 'Sebree', 'McElroys Gap,Sebree,Springdale', 37.6069900, -87.5286200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133198, 'Shelbyville', 'Shelbyville', 'Shelbivil,Shelbivll,shlbywyl  kntaky,shylbyfyl,xie er bi wei er,Шелбивил,Шелбивлл,شلبیویل، کنتاکی,شيلبيفيل,谢尔比维尔', 38.2120100, -85.2235700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133199, 'Shepherdsville', 'Shepherdsville', '', 37.9884000, -85.7157900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133200, 'Shively', 'Shively', '', 38.2000700, -85.8227400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133201, 'Silver Grove', 'Silver Grove', '', 39.0345100, -84.3902200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133202, 'Simpsonville', 'Simpsonville', '', 38.2225700, -85.3552300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133203, 'Smithland', 'Smithland', 'Smithland,Smiths Landing,Smithtown', 37.1389400, -88.4033700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133204, 'Somerset', 'Somerset', 'SME,Samerset,Somerset,sa mo sai te,samrst  kntaky,swmrst,Самерсет,Сомерсет,سامرست، کنتاکی,سومرست,萨默塞特', 37.0920200, -84.6041100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133205, 'South Shore', 'South Shore', 'McCall,South Shore,Taylor', 38.7209100, -82.9582300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133206, 'Southgate', 'Southgate', '', 39.0720000, -84.4727200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133207, 'Springfield', 'Springfield', 'Springfild,aspryngfyld  kntaky,sbrynghfyld,si pu lin fei er de,Спрингфилд,Спрінґфілд,اسپرینگفیلد، کنتاکی,سبرينغفيلد,سپرنگفیلڈ، کینٹکی,斯普林菲尔德', 37.6853400, -85.2221800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133208, 'Saint Dennis', 'Saint Dennis', '', 38.1884000, -85.8458000, 'US', '2007-02-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133209, 'Stanford', 'Stanford', 'Logans Fort,Saint Asaph,Saint Asaph Station,Stanford,Stehnford,astnfrd  kntaky,si tan fu,stanfwrd,Станфорд,Стэнфорд,استنفرد، کنتاکی,ستانفورد,سٹینفورڈ، کینٹکی,斯坦福', 37.5311900, -84.6618900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133210, 'Stanton', 'Stanton', 'Beavers Pond,Stanton,Stehnton,astntn  kntaky,si tan dun,stantwn,Стантон,Стэнтон,استنتن، کنتاکی,ستانتون,斯坦顿', 37.8456400, -83.8582500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133211, 'Stearns', 'Stearns', 'Hemlock,Stearns', 36.6989700, -84.4774400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133212, 'Sturgis', 'Sturgis', '', 37.5467100, -87.9839100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133213, 'Taylor Mill', 'Taylor Mill', '', 38.9975600, -84.4963300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133214, 'Taylorsville', 'Taylorsville', 'Tehjlorsvill,Tejlorsvil,tai lei si wei er,taylwrsfyl,taylwrswyl  kntaky,Тејлорсвил,Тэйлорсвилл,تايلورسفيل,تایلورسویل، کنتاکی,泰勒斯维尔', 38.0317300, -85.3424500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133215, 'Tompkinsville', 'Tompkinsville', 'Tompkinsvil,Tompkinsvill,Tompkinsville,Watsons Store,tampkynswyl  kntaky,tang pu jin si wei er,twmbkynsfyl,Томпкинсвил,Томпкинсвилл,تامپکینسویل، کنتاکی,تومبكينسفيل,汤普金斯维尔', 36.7022800, -85.6916400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133216, 'Union', 'Union', 'Ehnion,Junion,anywn  kntaky,ywnywn,Јунион,Энион,انیون، کنتاکی,يونيون,یونین، کینٹکی', 38.9459000, -84.6805000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133217, 'Van Lear', 'Van Lear', '', 37.7712100, -82.7579400, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133218, 'Valley Station', 'Valley Station', '', 38.1111800, -85.8702400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133219, 'Vanceburg', 'Vanceburg', 'Vansbero,Vehnsburg,fankybwrgh,wan si bao,wnsbwrg  kntaky,Вансберо,Вэнсбург,فانكيبورغ,ونسبورگ، کنتاکی,万斯堡', 38.5992400, -83.3188000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133220, 'Verona', 'Verona', '', 38.8184000, -84.6607800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133221, 'Versailles', 'Versailles', 'Falling Spring,Versailles,Versaj,Versal'',fan er sai,frsaylys,wrsay  kntaky,Версаль,Версај,فرسايليس,ورسای، کنتاکی,凡尔赛', 38.0525800, -84.7299500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133222, 'Villa Hills', 'Villa Hills', '', 39.0633900, -84.5930000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133223, 'Vine Grove', 'Vine Grove', '', 37.8100700, -85.9813500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133224, 'Walton', 'Walton', 'Gaines Croosroads,Walton', 38.8756200, -84.6102200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133225, 'Warsaw', 'Warsaw', 'Fredricksburg,Great Landing,Johnsons Landing,Warsaw', 38.7834000, -84.9016200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133226, 'Watterson Park', 'Watterson Park', '', 38.1922900, -85.6832900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133227, 'West Buechel', 'West Buechel', '', 38.1970100, -85.6632900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133228, 'West Liberty', 'West Liberty', 'Vest Liberti,wst lybrty  kntaky,wyst lybrty,xi li bo di,Вест Либерти,وست لیبرتی، کنتاکی,ويست ليبرتي,西利伯蒂', 37.9214800, -83.2596200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133229, 'Westwood', 'Westwood', '', 38.4831400, -82.6698800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133230, 'Whitesburg', 'Whitesburg', 'BRG,Uajtsburg,Vajtsburg,huai ci bao,wytsbwrg  kntaky,wytsbwrgh,Вајтсбург,Уайтсбург,ويتسبورغ,ویتسبورگ، کنتاکی,怀茨堡', 37.1184300, -82.8268300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133231, 'Whitley City', 'Whitley City', 'Coolidge,Whitley,Whitley City', 36.7234100, -84.4704900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133232, 'Wickliffe', 'Wickliffe', '', 36.9647800, -89.0892300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133233, 'Wilder', 'Wilder', '', 39.0564500, -84.4868900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133234, 'Williamsburg', 'Williamsburg', 'Spring Ford,Uilliamsburg,Vilijamsburg,Williamsburg,Williamsburgh,wei lian si bao,wylyamzbrg  kntaky,wylyamzbwrgh,Вилијамсбург,Уиллиамсбург,ويليامزبورغ,ویلمزبرگ، کینٹکی,ویلیامزبرگ، کنتاکی,威廉斯堡', 36.7434200, -84.1596600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133235, 'Williamstown', 'Williamstown', '', 38.6381200, -84.5605000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133236, 'Wilmore', 'Wilmore', 'Locust Grove,Wilmore', 37.8620200, -84.6616100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133237, 'Winchester', 'Winchester', 'Uinchester,Vinchester,u~inchesuta,wen che si te,wincheseuteo,wynchstr  kntaky,wynshstr,Винчестер,Уинчестер,ونچیسٹر، کینٹکی,وينشستر,وینچستر، کنتاکی,ウィンチェスター,温彻斯特,윈체스터', 37.9900800, -84.1796500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133238, 'Windy Hills', 'Windy Hills', '', 38.2739600, -85.6344100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133239, 'Worthington', 'Worthington', '', 38.5484100, -82.7243300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133240, 'Worthington Hills', 'Worthington Hills', '', 38.3089600, -85.5269000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133241, 'Worthington', 'Worthington', '', 38.3156200, -85.5616300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133242, 'Wurtland', 'Wurtland', '', 38.5503600, -82.7779400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133243, 'Abbeville', 'Abbeville', 'Abbeville,Abevil,Ehbbivill,La Chapelle,a bu wei er,abfyl,abywyl  lwyyzyana,aebibil,Абевил,Эббивилл,أبفيل,ابیویل، لوئیزیانا,阿布维尔,애비빌', 29.9746500, -92.1342900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133244, 'Abita Springs', 'Abita Springs', 'Abeta Springs,Abita,Abita Springs,Christy Springs', 30.4786400, -90.0400800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133245, 'Addis', 'Addis', '', 30.3538000, -91.2653900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133246, 'Albany', 'Albany', 'Olbani,Олбани', 30.5043600, -90.5823100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133247, 'Alexandria', 'Alexandria', 'AEX,Aleksandrija,alaskndryt,alksandrya  lwyyzyana,allegsandeulia,ya li shan de li ya,Александрия,Александрија,الإسكندرية,الکساندریا، لوئیزیانا,الیگزینڈریا، لوزیانا,亚历山德里亚,알렉산드리아', 31.3112900, -92.4451400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133248, 'Ama', 'Ama', 'Ama,Madisonville', 29.9521500, -90.2964700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133249, 'Amelia', 'Amelia', '', 29.6663200, -91.1020400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133250, 'Amite', 'Amite', 'Amite,Amite City,Amitei', 30.7265700, -90.5089800, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133251, 'Arabi', 'Arabi', 'Arabi,Stock Landing', 29.9543700, -90.0053500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133252, 'Arcadia', 'Arcadia', 'Arkadija,Arkejdija,a ka di ya,arkadya  lwyyzyana,Аркадия,Аркејдија,آرکادیا، لوئیزیانا,آرکیڈیا، لوزیانا,阿卡迪亚', 32.5490400, -92.9201600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133253, 'Arnaudville', 'Arnaudville', 'Arnaudville,L''Habitation Des Arnauds,La Jonction', 30.3977000, -91.9315100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133254, 'Avondale', 'Avondale', 'Ejvondejl,Ейвондейл', 29.9129800, -90.2036900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133255, 'Baker', 'Baker', 'Baker,Bejker,Cottonville,bei ke,bykr,bykr  lwyyzyana,Бејкер,بيكر,بیکر، لوئیزیانا,贝克', 30.5882400, -91.1681600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133256, 'Baldwin', 'Baldwin', 'Baldwin,Bolduin,La Teche,Болдуин', 29.8379800, -91.5442800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133257, 'Ball', 'Ball', '', 31.4154600, -92.4118000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133258, 'Banks Springs', 'Banks Springs', '', 32.0821000, -92.0929100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133259, 'Barataria', 'Barataria', '', 29.7232700, -90.1236900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133260, 'Basile', 'Basile', 'Basile,Schamber', 30.4852000, -92.5959700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133261, 'Bastrop', 'Bastrop', 'Bastrop,ba si te luo pu,bstrp  lwyyzyana,Бастроп,بسترپ، لوئیزیانا,巴斯特罗普', 32.7562500, -91.8723500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133262, 'Baton Rouge', 'Baton Rouge', 'BTR,Baton Rouge,Baton Rouz,Baton Ruj,Baton Ruzas,Baton Ruzh,Baton Ruzos,Baton Ružas,Baton Ružos,Baton-Rouge,Baton-Ruzh,Batonruza,Batonrūža,Batun Ruzh,Bâton-Rouge,Dironbourg,Gorad Batan-Ruzh,New Richmond,Rubribaculum,ba tun lu ri,baeteonluji,batonruju,batwn rwj,batwn rwzh,batwn‌rwzh  lwyyzyana,betana ru,betana ruja,byatana ruja,bʼtwn rwz,patan ruj,Μπατόν Ρουζ,Батон Руж,Батон-Руж,Батън Руж,Горад Батан-Руж,Բաթոն Ռուժ,באטון רוז,باتون روج,باتون روژ,باتون‌روژ، لوئیزیانا,باٹن روگ,بیٹون روج، لوزیانا,बॅटन रूज,बेटन रु,बेटन रूज,ब्यातन रुज,பாடன் ரூஜ்,แบตันรูช,バトンルージュ,巴吞鲁日,배턴루지', 30.4507500, -91.1545500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133263, 'Bawcomville', 'Bawcomville', '', 32.4704200, -92.1673600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133264, 'Bayou Cane', 'Bayou Cane', '', 29.6241000, -90.7512000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133265, 'Bayou Gauche', 'Bayou Gauche', '', 29.7874300, -90.4131400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133266, 'Bayou Vista', 'Bayou Vista', 'Bayou Vista,Clarks,La Gorda', 29.6896500, -91.2709400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133267, 'Belle Chasse', 'Belle Chasse', 'BCS', 29.8549300, -89.9906300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133268, 'Belle Rose', 'Belle Rose', 'Belle Rose,Bellerose,Cranes Forge', 30.0504800, -91.0414900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133269, 'Benton', 'Benton', 'Benton,Бентон', 32.6948700, -93.7418500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133270, 'Bernice', 'Bernice', '', 32.8220900, -92.6579300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133271, 'Berwick', 'Berwick', 'Berwick,Berwick City', 29.6946500, -91.2189900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133272, 'Blanchard', 'Blanchard', '', 32.5809800, -93.8926800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133273, 'Bogalusa', 'Bogalusa', 'BXA,Bogaloosa,Bogalusa,bo jia lu sa,bwgalwsa  lwyyzyana,bwghalwsa,Богалуса,بوغالوسا,بوگالوسا، لوئیزیانا,博加卢萨', 30.7910200, -89.8486900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133274, 'Bossier City', 'Bossier City', 'Bossier,Bossier City,Bozher Siti,bo xi er cheng,bosyeositi,bwsyr syty,bwwzhr  lwyyzyana,Божер Сити,بوسير سيتي,بوسیئر سٹی، لوزیانا,بووژر، لوئیزیانا,波西尔城,보셔시티', 32.5159900, -93.7321200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133275, 'Bourg', 'Bourg', 'Bourg,Little Pass Des Ilettes', 29.5535500, -90.6023100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133276, 'Boutte', 'Boutte', 'Boutte,Boutte Station', 29.9024300, -90.3881400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133277, 'Breaux Bridge', 'Breaux Bridge', 'Breaux,Breaux Bridge,La Pointe,Le Pont Breaux,Pont Breaux,beulobeuliji,brawks bryj  lwyyzyana,brywks brydj,bu li ao ke si qiao,براوکس بریج، لوئیزیانا,بريوكس بريدج,布里奥克斯桥,브로브리지', 30.2735300, -91.8992800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133278, 'Bridge City', 'Bridge City', '', 29.9332600, -90.1700700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133279, 'Broussard', 'Broussard', 'Broussard,Broussardville,Cote Gelee,brwsard,brwsard  lwyyzyana,bu lu sa er,بروسارد,بروسارد، لوئیزیانا,布鲁萨尔', 30.1471500, -91.9612300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133280, 'Brownsfield', 'Brownsfield', 'Brownfields', 30.5465800, -91.1206600, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133281, 'Brownsville', 'Brownsville', 'Brownsville,Brownville', 32.4870900, -92.1543000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133282, 'Brusly', 'Brusly', '', 30.3943600, -91.2537200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133283, 'Bunkie', 'Bunkie', 'Bunkie,Bunkie Station,Irion', 30.9532500, -92.1826300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133284, 'Cade', 'Cade', 'Cade,Cades', 30.0874200, -91.9054000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133285, 'Cameron', 'Cameron', 'Cameron,Leesburg', 29.7977200, -93.3251500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133286, 'Campti', 'Campti', 'Campti,Compti', 31.8935000, -93.1182200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133287, 'Carencro', 'Carencro', 'Carencro,La Chapelle,Saint Pierre', 30.3171400, -92.0490100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133288, 'Carlyss', 'Carlyss', '', 30.1688200, -93.3759900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133289, 'Carville', 'Carville', 'Carville,Island', 30.2174200, -91.0962100, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133290, 'Catahoula', 'Catahoula', '', 30.2146400, -91.7090000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133291, 'Cecilia', 'Cecilia', 'Cecilia,Cecilia Station,Grand Point,Grand Pointe,La Grande Pointe,La Place', 30.3371400, -91.8531700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133292, 'Central', 'Central', '', 30.5543500, -91.0367700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133293, 'Chackbay', 'Chackbay', 'Chackbaie,Chackbay,Chackbe,Chackby,Chagbay,Chagby,Chegbey,Chegby,Chicbay,Chockbay', 29.8835400, -90.7973200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133294, 'Chalmette', 'Chalmette', 'Chalmette,Port Chalmette,cha er mei te,chalmt  lwyyzyana,شالمیٹ، لوزیانا,چالمت، لوئیزیانا,查尔梅特', 29.9429600, -89.9653700, 'US', '2014-08-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133295, 'Charenton', 'Charenton', 'Charenton,Indian Bend', 29.8815900, -91.5251100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133296, 'Chauvin', 'Chauvin', 'Bayou Petit Caillou,Chauvin,Little Caillou', 29.4385500, -90.5953700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133297, 'Church Point', 'Church Point', 'Church Point,Churchpoint,L''englise a la pointe,La Chapelle de la pointe de Plaquemine Brulee,Plaquemine Brule,Plaquemine Brulee,Plaquemine Point,Upper Plaquemine Brulee', 30.4029800, -92.2151300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133298, 'Claiborne', 'Claiborne', '', 32.5159800, -92.1918000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133299, 'Clarks', 'Clarks', 'Clark Spur,Clarks,The Dream City', 32.0265500, -92.1390300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133300, 'Clinton', 'Clinton', 'Klinton,Клинтон', 30.8657400, -91.0156600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133301, 'Colfax', 'Colfax', 'Kolfaks,ke er,kwlfaks,kwwlfks  lwyyzyana,Колфакс,كولفاكس,کوولفکس، لوئیزیانا,科尔', 31.5190600, -92.7068200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133302, 'Columbia', 'Columbia', 'Kolambija,Kolumbija,ge lun bi ya,klmbya  lwyyzyana,kwlmbya  lwzyana,kwlwmbya,Коламбија,Колумбия,كولومبيا,کلمبیا، لوئیزیانا,کولمبیا، لوزیانا,哥伦比亚', 32.1051600, -92.0779100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133303, 'Convent', 'Convent', '', 30.0207600, -90.8298200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133304, 'Cottonport', 'Cottonport', 'Cotton Port,Cottonport', 30.9840800, -92.0534600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133305, 'Covington', 'Covington', 'Covington,Kavington,Wharton,ka wen dun,kawyngtn  lwyyzyana,keobingteon,kwfynghtwn,Кавингтон,كوفينغتون,کاوینگتن، لوئیزیانا,کوونگٹن، لوزیانا,卡温顿,커빙턴', 30.4754900, -90.1004200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133306, 'Coushatta', 'Coushatta', 'Coushatta,Coushatta Chite,kao sha ta,kwshata,kwwshata  lwyyzyana,كوشاتا,کووشاتا، لوئیزیانا,考沙塔', 32.0148800, -93.3421200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133307, 'Crowley', 'Crowley', 'Krouli,ke luo li,keulolli,krawly,krawly  lwyyzyana,kurouri,Кроули,كراولي,کراولی، لوئیزیانا,クロウリー,克羅利,크롤리', 30.2140900, -92.3745800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133308, 'Cullen', 'Cullen', '', 32.9690300, -93.4507300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133309, 'Cut Off', 'Cut Off', 'Cut Off,Cut-Off,Cutoff', 29.5427200, -90.3381400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133310, 'DeQuincy', 'DeQuincy', 'De Quincy,DeQuincy,Dequincy', 30.4504800, -93.4332200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133311, 'DeRidder', 'DeRidder', 'De Ridder,DeKidder,DeRidder,Deridder,Schovall,de li de,dryddr  lwyyzyana,dyraydr,Дериддер,دریددر، لوئیزیانا,ديرايدر,德里德', 30.8463100, -93.2890500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133312, 'Delcambre', 'Delcambre', 'Delcambre,Grand Marais,Grand Marias,Gregg,Marais Carlin,Marias Carlin,Meadow,Meadows,Peigneur', 29.9482600, -91.9887300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133313, 'Delhi', 'Delhi', 'Delhi (Louisiana)', 32.4576400, -91.4931700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133314, 'Denham Springs', 'Denham Springs', 'Amite Springs,Denham Springs,Dunham Springs,Hills Springs', 30.4874000, -90.9575300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133315, 'Des Allemands', 'Des Allemands', 'Allemands,Des Allemands', 29.8238200, -90.4750800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133316, 'Destrehan', 'Destrehan', 'Destrehan,Destréhan,dstrhan  lwyyzyana,دسترهان، لوئیزیانا', 29.9432200, -90.3534500, 'US', '2015-07-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133317, 'Deville', 'Deville', '', 31.3574000, -92.1654100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133318, 'Donaldsonville', 'Donaldsonville', 'Ascension,Donaldsontown,Donaldsonvil,Donaldsonville,Donisonville,La Fourche,La Ville De Donaldson,donarudosonbiru,dwnaldswnfyl,dwnaldswnwyl  lwyyzyana,tang na sen wei er,Доналдсонвил,دونالدسونفيل,دونالدسونویل، لوئیزیانا,ドナルドソンビル,唐纳森维尔', 30.1010300, -90.9928800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133319, 'Dulac', 'Dulac', 'Dulac,Live Oak', 29.3888300, -90.7139800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133320, 'Duson', 'Duson', 'Duson,Duson Station', 30.2357600, -92.1854000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133321, 'Eastwood', 'Eastwood', '', 32.5562600, -93.5671200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133322, 'Eden Isle', 'Eden Isle', '', 30.2285300, -89.7986700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133323, 'Edgard', 'Edgard', 'Edgard,Saint John,Saint John Settlement', 30.0432600, -90.5600900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133324, 'Elmwood', 'Elmwood', '', 29.9565900, -90.1898000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133325, 'Elton', 'Elton', '', 30.4813100, -92.6957000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133326, 'Erath', 'Erath', '', 29.9582600, -92.0359600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133327, 'Erwinville', 'Erwinville', '', 30.5310200, -91.4078900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133328, 'Estelle', 'Estelle', '', 29.8457600, -90.1067400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133329, 'Eunice', 'Eunice', 'Eunice,Junis,Seeleyville,aywnys  lwyyzyana,you ni si,yunisu,ywnys,Јунис,ایونیس، لوئیزیانا,يونيس,ユーニス,尤尼斯', 30.4943700, -92.4176300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133330, 'Farmerville', 'Farmerville', 'Farmersville,Farmerville', 32.7734700, -92.4057000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133331, 'Ferriday', 'Ferriday', 'Feridej,fei li di,frydy  lwyyzyana,fyrydy,Феридеј,فریدی، لوئیزیانا,فيريدي,费里迪', 31.6301700, -91.5545600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133332, 'Franklin', 'Franklin', 'Franklin,Frenklin,franklyn,franklyn  lwyyzyana,frynkln  lwzyana,fu lan ke lin,furankurin,Франклин,Френклин,فرانكلين,فرانکلین، لوئیزیانا,فرینکلن، لوزیانا,フランクリン,富兰克林', 29.7960400, -91.5015000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133333, 'Franklinton', 'Franklinton', 'Franklin,Franklinton', 30.8473100, -90.1552700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133334, 'French Settlement', 'French Settlement', 'French Settlement,La Cote Francaise,Londell,Vausers Landing', 30.2951900, -90.7951000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133335, 'Galliano', 'Galliano', 'Galiano,Galliano,Gallino', 29.4421600, -90.2992500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133336, 'Gardere', 'Gardere', 'Gardere,Garders', 30.3457500, -91.1401100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133337, 'Garyville', 'Garyville', 'Garyville,Glencoe Plantation', 30.0560400, -90.6192600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133338, 'Glenmora', 'Glenmora', '', 30.9765800, -92.5851400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133339, 'Golden Meadow', 'Golden Meadow', '', 29.3791100, -90.2600800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133340, 'Gonzales', 'Gonzales', 'Gonzales,gang sa lei si,ghwnzalys,gwnzals  lwyyzyana,Гонзалес,غونزاليس,گونزالس، لوئیزیانا,冈萨雷斯', 30.2385300, -90.9201000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133341, 'Grambling', 'Grambling', 'Allen Greene,Grambling', 32.5276500, -92.7140400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133342, 'Gramercy', 'Gramercy', 'Gramercy,Grammercy', 30.0474200, -90.6898100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133343, 'Grand Isle', 'Grand Isle', '', 29.2366200, -89.9872900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133344, 'Grand Point', 'Grand Point', '', 30.0613100, -90.7534300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133345, 'Gray', 'Gray', 'Beatieville,Gray', 29.6977100, -90.7864800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133346, 'Greensburg', 'Greensburg', 'Greensburg,Greensburgh', 30.8307400, -90.6717600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133347, 'Greenwood', 'Greenwood', '', 32.4429300, -93.9729600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133348, 'Greenwood', 'Greenwood', '', 30.5449100, -91.1067700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133349, 'Gretna', 'Gretna', 'Gretna,Mechancisk Village,Mechanickkham,Mechanicks Village,Mechanikham,ge lei te na,ghrytna,grtna  lwyyzyana,Гретна,غريتنا,گرتنا، لوئیزیانا,格雷特纳', 29.9146500, -90.0539600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133350, 'Gueydan', 'Gueydan', '', 30.0260400, -92.5084700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133351, 'Hackberry', 'Hackberry', '', 29.9960500, -93.3421000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133352, 'Hahnville', 'Hahnville', 'Hahnville,Saint Charles,Tillys Store', 29.9765900, -90.4089700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133353, 'Hammond', 'Hammond', 'Hammond,Hammond Station,Hammonds Crossing,Khammond,Khamond,ha meng de,hamwnd,hmnd  lwyyzyana,Хаммонд,Хамонд,هاموند,همند، لوئیزیانا,ہیمنڈ، لوزیانا,哈蒙德', 30.5046300, -90.4629300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133354, 'Harahan', 'Harahan', '', 29.9404800, -90.2031300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133355, 'Harrisonburg', 'Harrisonburg', 'Harrisonbugh,Harrisonburg', 31.7721100, -91.8215200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133356, 'Harvey', 'Harvey', 'Cosmopolite City,Harvey,Kharvi,Харви', 29.9035400, -90.0772900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133357, 'Haughton', 'Haughton', 'Haughton,Lawrenceville', 32.5326500, -93.5040600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133358, 'Haynesville', 'Haynesville', '', 32.9620800, -93.1401600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133359, 'Henderson', 'Henderson', 'Henderson,Henderson Landing,Khenderson,New Henderson Landing,Хендерсон', 30.3132500, -91.7903900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133360, 'Homer', 'Homer', '', 32.7918100, -93.0557200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133361, 'Houma', 'Houma', 'HUM,Khouma,homa,huo ma,hwma,hwma  lwyyzyana,Хоума,هوما,هوما، لوئیزیانا,ہووما، لوزیانا,霍玛,호마', 29.5957700, -90.7195300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133362, 'Independence', 'Independence', 'Independence,Uncle Sam', 30.6355100, -90.5033500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133363, 'Inniswold', 'Inniswold', 'Inniswold,Petrie', 30.4049100, -91.0834400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133364, 'Iota', 'Iota', 'Cartville,Fabacher,Iota,Point-Aux-Loupes,Pointe-aux-Loupe,Wolf Point', 30.3313100, -92.4956900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133365, 'Iowa', 'Iowa', '', 30.2368700, -93.0137600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133366, 'Jackson', 'Jackson', 'Buncombe,Dzhekson,Jackson,Джексон', 30.8374000, -91.2176100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133367, 'Jean Lafitte', 'Jean Lafitte', '', 29.7360400, -90.1267400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133368, 'Jeanerette', 'Jeanerette', '', 29.9110400, -91.6634500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133369, 'Jefferson', 'Jefferson', 'Dzhefferson,Джефферсон', 29.9660400, -90.1531300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133370, 'Jena', 'Jena', 'Dzhena,Hemp Creek,Hemps Creek,Jejna,Jena,jyna,ye na,yyna  lwyyzyana,Јејна,Джена,جينا,یینا، لوئیزیانا,耶拿', 31.6832300, -92.1337400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133371, 'Jennings', 'Jennings', 'Dzenings,jnyngz  lwyyzyana,zhan ning si,Џенингс,جنینگز، لوئیزیانا,詹宁斯', 30.2224300, -92.6570800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133372, 'Jonesboro', 'Jonesboro', 'Coon Town,Coontown,Dzhonsboro,Jonesboro,Macedonia,Джонсборо', 32.2412700, -92.7159900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133373, 'Jonesville', 'Jonesville', 'Anilco,Dzhonsvil'',Dzhonsvill,Dzounsvil,Jonesville,Troyville,jwnsfyl,jwnswyl  lwyyzyana,qiong si wei er,Џоунсвил,Джонсвилл,Джонсвіль,جونسفيل,جونسویل، لوئیزیانا,琼斯维尔', 31.6265600, -91.8181800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133374, 'Kaplan', 'Kaplan', '', 29.9979800, -92.2848500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133375, 'Kenner', 'Kenner', 'Cannes Brulees,Kener,Kenner,ken na,kena,knr  lwyyzyana,kynr  lwzyana,kynyr,Кенер,Кеннер,كينير,کنر، لوئیزیانا,کینر، لوزیانا,ケナー,肯纳', 29.9940900, -90.2417400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133376, 'Kentwood', 'Kentwood', '', 30.9382400, -90.5089800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133377, 'Killian', 'Killian', '', 30.3588100, -90.5862000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133378, 'Kinder', 'Kinder', '', 30.4854800, -92.8507000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133379, 'Krotz Springs', 'Krotz Springs', '', 30.5368600, -91.7528900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133380, 'Labadieville', 'Labadieville', 'Labadie Plantation,Labadieville,Star', 29.8374300, -90.9562100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133381, 'Lacombe', 'Lacombe', 'Bayou Lacomb,Lacomb,Lacombe', 30.3135300, -89.9431300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133382, 'Lafayette', 'Lafayette', 'LFT,La Fayette,Lafajet,Lafayette,Lafejet,Lafejett,Little Manchac,Pinhool,Vermilion,Vermilionville,Vermillion Bridge,Vermillionville,Village of Saint Jean Au Vermilion,la fa ye,lafayt  lwyyzyana,lafayyt,lapies,rafaietto,Лафайет,Лафейетт,Лафејет,לפאייט,لافاييت,لافایت، لوئیزیانا,لافیت، لوسیانہ,ラファイエット,拉法葉,라피엣', 30.2240900, -92.0198400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133383, 'Lake Arthur', 'Lake Arthur', '', 30.0807600, -92.6715300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133384, 'Lake Charles', 'Lake Charles', 'Charlestown,LCH,Lake Charles,Lejk Charls,Lejk-Charl''z,lai ke cha er si,leikeuchalseu,lyk charlz  lwyyzyana,lyk tsharlz,reikucharuzu,Лейк-Чарльз,Лејк Чарлс,ليك تشارلز,لیک چارلز، لوئیزیانا,لیک چارلس، لوسیانہ,レイクチャールズ,莱克查尔斯,레이크찰스', 30.2130900, -93.2044000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133385, 'Lake Providence', 'Lake Providence', 'Lejk Providens,lai ke pu luo wei deng si,lyk brwfaydns,lyk prawydns  lwyyzyana,Лејк Провиденс,ليك بروفايدنس,لیک پراویدنس، لوئیزیانا,莱克普罗维登斯', 32.8043000, -91.1701100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133386, 'Lakeshore', 'Lakeshore', '', 32.5351400, -92.0295800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133387, 'Laplace', 'Laplace', 'Bonnet Carre,Eugenia,La Place,LaPlace,Laplace,Laplas,Ory,Лаплас', 30.0669800, -90.4814700, 'US', '2016-05-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133388, 'Larose', 'Larose', 'Canal Harang,La Rose,Larose', 29.5724400, -90.3817500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133389, 'Lawtell', 'Lawtell', '', 30.5185300, -92.1848500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133390, 'Lecompte', 'Lecompte', '', 31.0946300, -92.4004100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133391, 'Leesville', 'Leesville', 'Lisvil,li si wei er,lswyl  lwyyzyana,Лисвил,لسویل، لوئیزیانا,利斯维尔', 31.1435200, -93.2610000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133392, 'Leonville', 'Leonville', '', 30.4704700, -91.9784500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133393, 'Livingston', 'Livingston', 'Livingston,Ливингстон', 30.5021300, -90.7478700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133394, 'Livonia', 'Livonia', 'Livonija,Ливония', 30.5590800, -91.5559400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133395, 'Lockport', 'Lockport', 'Lockport,Longueville,Longville', 29.6460500, -90.5392500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133396, 'Lockport Heights', 'Lockport Heights', '', 29.6504900, -90.5464700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133397, 'Logansport', 'Logansport', 'Logans Ferry,Logansport,Waterloo', 31.9754500, -93.9979700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133398, 'Luling', 'Luling', '', 29.9321500, -90.3664700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133399, 'Lutcher', 'Lutcher', '', 30.0404800, -90.6989800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133400, 'Mamou', 'Mamou', '', 30.6338100, -92.4193000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133401, 'Mandeville', 'Mandeville', 'Mandervil,man de wei er,mandfyl,mndwyl  lwyyzyana,Мандервил,ماندفيل,مندویل، لوئیزیانا,曼德维尔', 30.3582500, -90.0656300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133402, 'Mansfield', 'Mansfield', 'Mehnsfild,Mensfild,maenseupildeu,man si fei er de,mansfyld,mnsfyld  lwyyzyana,Менсфилд,Мэнсфилд,مانسفيلد,منسفیلد، لوئیزیانا,曼斯菲尔德,맨스필드', 32.0376600, -93.7001800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133403, 'Mansura', 'Mansura', '', 31.0579700, -92.0490100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133404, 'Many', 'Many', 'Baldwins Store,Manny,Many,Meni,many,mei ni,mny  lwyyzyana,Мени,ماني,منی، لوئیزیانا,梅尼', 31.5687800, -93.4840600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133405, 'Maringouin', 'Maringouin', '', 30.4913000, -91.5195500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133406, 'Marksville', 'Marksville', 'Marksvil,Marksville,Markville,ma ke si wei er,marksfyl,markswyl  lwyyzyana,Марксвил,ماركسفيل,مارکسویل، لوئیزیانا,马克斯维尔', 31.1279700, -92.0662400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133407, 'Marrero', 'Marrero', 'Ames Plantation,Amesville,Marero,Marrero,marrw  lwyyzyana,myryrw  lwzyana,Мареро,Марреро,ماررو، لوئیزیانا,میریرو، لوزیانا', 29.8993700, -90.1003500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133408, 'Mathews', 'Mathews', 'Mathews,Matthews', 29.6863200, -90.5467500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133409, 'Maurice', 'Maurice', '', 30.1085400, -92.1245700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133410, 'Melville', 'Melville', '', 30.6929700, -91.7440000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133411, 'Meraux', 'Meraux', 'Melonie,Meraux', 29.9301700, -89.9162300, 'US', '2015-12-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133412, 'Merrydale', 'Merrydale', '', 30.5013000, -91.1084400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133413, 'Merryville', 'Merryville', '', 30.7543700, -93.5404500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133414, 'Metairie', 'Metairie', 'Maiterie,Metairie,Metairieburgh,Metairieville,Metari,metali,meteri,mitiry  lwyyzyana,Метари,مِتِری، لوئیزیانا,میٹیری، لوزیانا,メテリー,메타리', 29.9840900, -90.1528500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133415, 'Metairie Terrace', 'Metairie Terrace', '', 29.9785400, -90.1639600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133416, 'Midway', 'Midway', '', 31.6921200, -92.1523600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133417, 'Milton', 'Milton', '', 30.1038100, -92.0765100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133418, 'Minden', 'Minden', 'Minden,ming deng,mndn,myndn  lwyyzyana,Минден,مندن,میندن، لوئیزیانا,明登', 32.6154300, -93.2868400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133419, 'Minorca', 'Minorca', '', 31.5793300, -91.4817900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133420, 'Monroe', 'Monroe', 'Fort Miro,Fuerte Miro,MLU,Monro,Monroe,Post of Ouachita,Poste d''Ouachita,Poste du Ouachita,Prairie des Canots,Prairie of the Canoes,Puesto De Ouachitta,manro,men luo,meonlo,mnrww  lwyyzyana,monro,mwnrw,mwnrw  lwzyana,Монро,מונרו,منروو، لوئیزیانا,مونرو,مونرو، لوزیانا,मन्रो,モンロー,门罗,먼로', 32.5093100, -92.1193000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133421, 'Montegut', 'Montegut', '', 30.0707600, -90.5020300, 'US', '2016-05-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133422, 'Montegut', 'Montegut', 'Lower Terrebonne,Montegut', 29.4743900, -90.5570300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133423, 'Monticello', 'Monticello', '', 30.4890800, -91.0487200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133424, 'Montz', 'Montz', '', 30.0068700, -90.4686900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133425, 'Morgan City', 'Morgan City', 'Brashear City,Morgan City,Morgan Siti,mo gen cheng,mrgn syty  lwyyzyana,mwrghan syty,Морган Сити,مرگن سیتی، لوئیزیانا,مورغان سيتي,摩根城', 29.6993700, -91.2067700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133426, 'Moss Bluff', 'Moss Bluff', '', 30.3027000, -93.1907100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133427, 'Napoleonville', 'Napoleonville', 'Assumption,Napoleon City,Napoleonville,Napolionvil,na po lun wei er,napwlwnwyl  lwyyzyana,Наполионвил,ناپولونویل، لوئیزیانا,拿破仑维尔', 29.9404800, -91.0248200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133428, 'Natalbany', 'Natalbany', 'Natalbani,Natalbany,Talbany', 30.5462200, -90.4861900, 'US', '2015-07-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133429, 'Natchitoches', 'Natchitoches', 'Nachitoches,Nakitosh,Natchitoches,na qi tuo shen,nkytash  lwyyzyana,ntshtwshs,nychaytwchys  lwzyana,Накитош,نتشتوشس,نکیتاش، لوئیزیانا,نیچایتوچیس، لوزیانا,纳契托什', 31.7607200, -93.0862700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133430, 'New Iberia', 'New Iberia', 'ARA,Iberia,La Nouvelle-Iberie,La Nouvelle-Ibérie,New Iberia,New Town,Nju Ajbirija,Nouvelle Iberie,Nueva Iberia,Nuevo Iberia,nwwa aybyrya  lwyyzyana,nyw aybyrya,nyw aybyrya  lwzyana,xin yi bi li ya,Њу Ајбирија,ניו איבריה,نووا آیبیریا، لوئیزیانا,نيو أيبيريا,نیو آئبیریا، لوزیانا,新伊比利亚', 30.0035400, -91.8187300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133431, 'New Llano', 'New Llano', 'New Llano,Newllano,Stables', 31.1149100, -93.2715500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133432, 'New Orleans', 'New Orleans', 'Bagong Orleans,Big Easy,Cene Orlean,Crescent City,Gorad Novy Arlean,La Nouvelle-Orleans,La Nouvelle-Orléans,MSY,N''ju-Orlean,N''ju-Orleans,NOLA,Naujasis Orleanas,Nawlins,Nea Orleani,Neu Orleans,Neuva Orleans,New Orleans,Nieuw Orleans,Nju Orleans,Nju Orliuns,Nog Orlean,Nor Orlean,Nouvelle Orleans,Nov-Orleano,Nov-Orleans,Nova Aurelia,Nova Orleaes,Nova Orleans,Nova Orleáns,Nova Orleães,Novij Orlean,Novyj Orlean,Nowy Orlean,Nowy Uorlean,Nueva Orleans,Nuoba Orleanes,Nuorleana,Nyu-Orlean,Nòva Orleans,Orleans Parish,The Big Easy,U Orlean,Uz Orlean,Yancuic Orleans,Yengi Orlean,Yéngi Orléan,akhali orleani,awrlynz parsh,n''yu orlins,n''yu orlinsa,n''yu orliyansa,new orleans louisiana,ni wx xr lins,ni''u aralinsa,niu ao liang,niyu orlens,nyuollieonseu,nyuorinzu,nyw awrlynz,nywawrlyan  lwyyzyana,oralensa parisa,xin ao er liang,Çĕнĕ Орлеан,Ņūorleāna,Νέα Ορλεάνη,Њу Орлеанс,Горад Новы Арлеан,Жаңы орлеан,Новий Орлеан,Новый Орлеан,Ног Орлеан,Нью-Орлеан,Нью-Орлеанс,Ню Орлиънс,У Орлеан,Նոր Օռլեան,ניו אורלינס,ניו ארלינס,اورلینز پارش,نيو أورلينز,نیواورلئان، لوئیزیانا,न्यू ऑर्लिन्स,न्यू ओर्लियंस,न्‍यू आर्लीन्‍स,ওরলেন্স পারিশ,নিউ অরলিন্স,நியூ ஓர்லென்ஸ்,ನ್ಯೂ ಒರ್ಲೀನ್ಸ್,นิวออร์ลีนส์,ახალი ორლეანი,ニューオーリンズ,新奥尔良,紐奧良,뉴올리언스', 29.9546500, -90.0750700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133433, 'New Roads', 'New Roads', 'Chomin Neuf,HZR,New Roads,Newroads,Nju Rouds,Saint Marys,nyw rwdz,nyw rwdz  lwyyzyana,xin lu,Њу Роудс,نيو رودز,نیو رودز، لوئیزیانا,新路', 30.7015700, -91.4362200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133434, 'New Sarpy', 'New Sarpy', 'New Sarpy,Sarpy', 29.9781700, -90.3896300, 'US', '2015-07-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133435, 'Newellton', 'Newellton', '', 32.0726500, -91.2409500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133436, 'Norco', 'Norco', 'Norco,Norco-Goodhope', 29.9990900, -90.4123000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133437, 'North Vacherie', 'North Vacherie', '', 29.9968700, -90.7056500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133438, 'Oak Grove', 'Oak Grove', 'Oak Grove,Oake Grove,Oakgrove,Pin Hook', 32.8609600, -91.3884500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133439, 'Oak Hills Place', 'Oak Hills Place', '', 30.3599200, -91.0876000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133440, 'Oakdale', 'Oakdale', '', 30.8160300, -92.6604200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133441, 'Oakdale', 'Oakdale', '', 30.8054700, -92.6215300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133442, 'Oberlin', 'Oberlin', '', 30.6202000, -92.7626500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133443, 'Old Jefferson', 'Old Jefferson', '', 30.3826900, -91.0170500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133444, 'Olla', 'Olla', 'Castor Sulphur Springs,Olla,Sulphur Springs', 31.9029400, -92.2431900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133445, 'Opelousas', 'Opelousas', 'OPL,ao po lu sa si,aplwss  lwyyzyana,operusasu,آپلوسس، لوئیزیانا,オペルーサス,奥珀卢萨斯', 30.5335300, -92.0815100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133446, 'Ossun', 'Ossun', '', 30.2760300, -92.1123500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133447, 'Paradis', 'Paradis', '', 29.8796500, -90.4339700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133448, 'Patterson', 'Patterson', 'PTN,Patterson,Pattersonville', 29.6932600, -91.3020500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133449, 'Paulina', 'Paulina', 'Long View,Paulina', 30.0263100, -90.7131500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133450, 'Pearl River', 'Pearl River', '', 30.3760300, -89.7484000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133451, 'Pierre Part', 'Pierre Part', 'Pierre Part,Pierre Part Settlement,Pierre Pass,Pierre Port,The Lafourche Interior', 29.9652000, -91.2031600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133452, 'Pine Prairie', 'Pine Prairie', '', 30.7838100, -92.4254100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133453, 'Pineville', 'Pineville', 'El Rapido,Pajnvil,Pineville,Poste Du Rapides,pai en wei er,paynwyl  lwyyzyana,Пајнвил,پاینویل، لوئیزیانا,派恩维尔', 31.3224000, -92.4343000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133454, 'Plaquemine', 'Plaquemine', 'Placaminas,Plaquemine,blakywmyn,plakwmyn  lwyyzyana,pu la kui mai en,بلاكيومين,پلاکومین، لوئیزیانا,普拉奎迈恩', 30.2890800, -91.2342700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133455, 'Ponchatoula', 'Ponchatoula', 'bwntshatwla,pang sha tu la,pwnchatwwla  lwyyzyana,بونتشاتولا,پونچاتوولا، لوئیزیانا,پونچاٹولا، لوزیانا,庞沙图拉', 30.4388000, -90.4414800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133456, 'Port Allen', 'Port Allen', 'Allain,Port Allen,Saint Michael', 30.4521400, -91.2101100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133457, 'Port Barre', 'Port Barre', 'Barres Landing,Port Barre', 30.5602000, -91.9540100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133458, 'Port Sulphur', 'Port Sulphur', 'Grande Ecaille,Grande Port,Port Sulphur', 29.4804900, -89.6939500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133459, 'Poydras', 'Poydras', '', 29.8693700, -89.8889500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133460, 'Prairieville', 'Prairieville', '', 30.3029700, -90.9720500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133461, 'Presquille', 'Presquille', 'Presque Isle,Presquile,Presquille', 29.5638300, -90.6462000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133462, 'Prien', 'Prien', '', 30.1818700, -93.2737700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133463, 'Raceland', 'Raceland', '', 29.7274300, -90.5989800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133464, 'Rayne', 'Rayne', 'Pauppenville,Poupeville,Pouppeville,Queue Tortue,Rayne,lei en,rayn,rayn  lwyyzyana,rein,راين,راین، لوئیزیانا,レイン,雷恩', 30.2349300, -92.2684600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133465, 'Rayville', 'Rayville', '', 32.4773600, -91.7548500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133466, 'Reserve', 'Reserve', '', 30.0538100, -90.5517500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133467, 'Richwood', 'Richwood', '', 32.4487600, -92.0848600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133468, 'Ringgold', 'Ringgold', 'Ringgold,Slabtown', 32.3284900, -93.2798900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133469, 'River Ridge', 'River Ridge', '', 29.9602000, -90.2156300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133470, 'Roseland', 'Roseland', '', 30.7649100, -90.5117600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133471, 'Rosepine', 'Rosepine', '', 30.9199100, -93.2823900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133472, 'Ruston', 'Ruston', 'RSN,Raston,Ruston,la si dun,rastn  lwyyzyana,rwstwn,Растон,راستن، لوئیزیانا,رسٹن، لوزیانا,روستون,拉斯顿', 32.5232100, -92.6379300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133473, 'Saint Francisville', 'Saint Francisville', 'Post of Atakapas,Puesto de Attacapas,Saint Francisville,Webbsville', 30.7799000, -91.3765000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133474, 'Saint Gabriel', 'Saint Gabriel', 'Iberville,Saint Gabriel,Saint Gabriel Plantation,Sanford', 30.2577000, -91.0992700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133475, 'Saint Joseph', 'Saint Joseph', 'Sent-Dzhozef,Сент-Джозеф', 31.9184900, -91.2334500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133476, 'Saint Martinville', 'Saint Martinville', 'Le Poste Des Attakapas,Petit Paris,Saint Martinsville,Saint Martinville', 30.1252000, -91.8334500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133477, 'Saint Rose', 'Saint Rose', 'Elkinsville,Saint Rose,St. Rose', 29.9468700, -90.3231300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133478, 'Schriever', 'Schriever', '', 29.7421500, -90.8103700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133479, 'Scott', 'Scott', '', 30.2357600, -92.0945700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133480, 'Shenandoah', 'Shenandoah', '', 30.4013000, -91.0009400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133481, 'Shreveport', 'Shreveport', 'SHV,Shreve Town,Shreveport,Shreves Landing,Shrivport,shen li fu bo te,shryfbwrt,shrywpwrt  lwyyzyana,shuribupoto,srivaporta,srybpwrt,syulibeupoteu,Шревепорт,Шривпорт,שריבפורט,شريفبورت,شریوپورت، لوئیزیانا,شریوپورٹ، لوزیانا,श्रीवपोर्ट,シュリーブポート,什里夫波特,슈리브포트', 32.5251500, -93.7501800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133482, 'Sibley', 'Sibley', 'Overton,Sibley', 32.5393200, -93.2962800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133483, 'Simmesport', 'Simmesport', 'Simmesport,Simsport', 30.9835200, -91.8001200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133484, 'Slidell', 'Slidell', 'Slajdel,aslaydl  lwyyzyana,si lai de er,slydl,Слајдел,اسلایدل، لوئیزیانا,سلایڈیل، لوزیانا,سليدل,斯莱德尔', 30.2751900, -89.7811700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133485, 'Sorrento', 'Sorrento', 'Landry,Sorrento', 30.1843600, -90.8592600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133486, 'South Vacherie', 'South Vacherie', '', 29.9274300, -90.6998100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133487, 'Springhill', 'Springhill', '', 33.0059700, -93.4668400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133488, 'Sterlington', 'Sterlington', 'Hamilton,Sterlington', 32.6962500, -92.0859700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133489, 'Stonewall', 'Stonewall', '', 32.2818300, -93.8240700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133490, 'Sulphur', 'Sulphur', 'Salfer,Sulphur,Sulphur City,Sulphur Mine Station,sa er fu,salfr  lwyyzyana,slfr  lwzyana,swlfwr,Салфер,سالفر، لوئیزیانا,سلفر، لوزیانا,سولفور,萨尔弗', 30.2365900, -93.3773800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133491, 'Sunset', 'Sunset', 'Grand Coteau Depot,Sunset', 30.4113100, -92.0684500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133492, 'Supreme', 'Supreme', 'Supreme,Tallien,Tallieu', 29.8593700, -90.9812100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133493, 'Swartz', 'Swartz', 'Schwartz,Swartz', 32.5687500, -91.9851300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133494, 'Tallulah', 'Tallulah', 'Tallula,Tallulah,Talula,ta lu la,talwlah,tlwla  lwyyzyana,Талула,تالولاه,تلولا، لوئیزیانا,塔卢拉', 32.4084800, -91.1867800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133495, 'Terrytown', 'Terrytown', '', 29.9102100, -90.0325700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133496, 'Thibodaux', 'Thibodaux', 'Thibadeauxville,Thibodaux,Thibodauxville,Thibodeaux,Tibodo,di bo,thybwdwks,tybdww  lwyyzyana,Тибодо,تیبدوو، لوئیزیانا,ثيبودوكس,蒂博', 29.7957600, -90.8228700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133497, 'Timberlane', 'Timberlane', '', 29.8774300, -90.0320200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133498, 'Urania', 'Urania', 'Prestridge Spur,Urania', 31.8637800, -92.2959700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133499, 'Vidalia', 'Vidalia', 'Concord,Concordia,Post of Concord,Post of Concordia,Post of New Concordia,Vajdejlija,Vidalia,fydalya,wei da li ya,wydylya  lwyyzyana,Вајдејлија,فيداليا,ویدیلیا، لوئیزیانا,维达利亚', 31.5654400, -91.4259500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133500, 'Vienna Bend', 'Vienna Bend', '', 31.7323900, -93.0410000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133501, 'Village Saint George', 'Village Saint George', '', 30.3621400, -91.0673300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133502, 'Ville Platte', 'Ville Platte', 'Flat Town,Ville Platte,Villeplatte,fyl blat,wei le pu la te,wyl plt  lwyyzyana,فيل بلات,ویل پلت، لوئیزیانا,威乐普拉特', 30.6879700, -92.2715200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133503, 'Vinton', 'Vinton', '', 30.1907600, -93.5812700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133504, 'Violet', 'Violet', 'Bank Station,Borgne Mouth,Canal,Violet', 29.8957600, -89.8978400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133505, 'Vivian', 'Vivian', '', 32.8715300, -93.9874000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133506, 'Waggaman', 'Waggaman', 'Wagaman,Waggaman', 29.9185400, -90.2109100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133507, 'Walker', 'Walker', 'Melton Old Field,Milton Old Field,Walker', 30.4879700, -90.8614900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133508, 'Watson', 'Watson', '', 30.5757400, -90.9531600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133509, 'Welsh', 'Welsh', 'Welch,Welchs,Welsh,Welshs Station', 30.2360400, -92.8226500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133510, 'West Ferriday', 'West Ferriday', '', 31.6404400, -91.5731800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133511, 'West Monroe', 'West Monroe', 'Trenton,West Monroe', 32.5184800, -92.1476400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133512, 'Westlake', 'Westlake', 'Bryan,West Lake,West Lake Charles,Westlake', 30.2421500, -93.2507100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133513, 'Westwego', 'Westwego', 'Salaville,Westwego', 29.9060400, -90.1423000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133514, 'Westminster', 'Westminster', '', 30.4138000, -91.0876000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133515, 'White Castle', 'White Castle', 'Bellys Estate,Pemberton Plantation,White Castle,White Castle Plantation,Whitecastle,Zacharie Plantation', 30.1699200, -91.1470500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133516, 'Winnfield', 'Winnfield', 'Vinfild,waynfyld,wen fei er de,wynfyld  lwyyzyana,Винфилд,Вінфілд,واينفيلد,وینفیلد، لوئیزیانا,温菲尔德', 31.9255800, -92.6413100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133517, 'Winnsboro', 'Winnsboro', 'Winnsboro,Winnsborough', 32.1632100, -91.7206800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133518, 'Woodmere', 'Woodmere', '', 29.8579800, -90.0803500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133519, 'Woodworth', 'Woodworth', 'Morris,Woodworth', 31.1465800, -92.4973600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133520, 'Zachary', 'Zachary', '', 30.6485200, -91.1565000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133521, 'Youngsville', 'Youngsville', 'Le Blanc,Royville,Youngsville', 30.0996500, -91.9901200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133522, 'Zwolle', 'Zwolle', '', 31.6315600, -93.6440700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133523, 'Aberdeen', 'Aberdeen', 'APG,Aberdeen,Aberdin,Halls Cross Roads,Mechanicsville,a bo ding,abadin,abrdyn,abrdyn  mrylnd,aebeodin,Абердин,Աբերդին,آبردین، مریلند,أبردين,ایبرڈین، میری لینڈ,アバディーン,阿伯丁,애버딘', 39.5095600, -76.1641200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133524, 'Accokeek', 'Accokeek', 'Accokeek,Moyaone', 38.6676200, -77.0283100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133525, 'Adamstown', 'Adamstown', 'Adamstown,Adamstown Junction,Adamsville,Davis Warehouse', 39.3109400, -77.4747100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133526, 'Adelphi', 'Adelphi', 'Adelphi,Riggs Mill Village', 39.0031700, -76.9719200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133527, 'Algonquin', 'Algonquin', '', 38.5829000, -76.1057700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133528, 'Annapolis', 'Annapolis', 'ANP,Anapoles,Anapoli,Anapolis,Anapolisa,Anapolės,Anapołi,Annapolis,Annapòlis,Anne Arundel Town,Anne Arundel Towne,Anne Arundell Town,Anne Arundell Towne,Arundel Towne,Arundelton,Crabtown,Gorad Anapalis,Proctors,Providence,The Athens of America,The Paris of America,Todds Landing,Town Land at Proctors,an na bo li si,anabwlys,anapalis,anapealis,anapolis,anapolliseu,anaporisu,anapwlys,aynapwls,enapolisa,Αννάπολις,Анаполис,Аннаполис,Аннаполіс,Горад Анапаліс,Աննապոլիս,אנאפוליס,آناپولیس,أنابوليس,ایناپولس,ایناپولس، میری لینڈ,अ‍ॅनापोलिस,आनापालिस्,एनापोलिस,அனாபொலிஸ்,അനാപൊളിസ്,แอนแนโพลิส,አናፖሊስ,アナポリス,安納波里斯,安那波利斯,아나폴리스', 38.9784500, -76.4921800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133529, 'Arbutus', 'Arbutus', 'Arbjutus,Arbutus,Crowdentown,Sulpher Spring,Sulphur Springs,arbywts  mrylnd,Арбютус,آربیوتس، مریلند,آربیوٹس، میری لینڈ', 39.2545500, -76.6999700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133530, 'Arden on the Severn', 'Arden on the Severn', 'Arden-on-the-Severn', 39.0659400, -76.5788500, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133531, 'Arnold', 'Arnold', 'Arnol''d,Arnold,Arnolds Store,Арнольд', 39.0320600, -76.5027400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133532, 'Aspen Hill', 'Aspen Hill', '', 39.0795500, -77.0730300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133533, 'Baden', 'Baden', '', 38.6592800, -76.7777500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133534, 'Baltimore', 'Baltimore', 'BWI,Baltemore Town,Baltimor,Baltimor shaary,Baltimora,Baltimore,Baltimore City,Baltimorė,Baltimòra,Charm City,Gorad Baltymar,Jonas Town,Jones Town,Jonestown,Old Town,Oldtown,Valtimori,ba er de mo,balatimora,baltimor,baltimora,baltymwr,baltʼimori,boltimo-eo,boruchimoa,bwltymwr,bxl thim xr,palttimor,Βαλτιμόρη,Балтимор,Балтимор шаары,Горад Балтымар,Բալթիմոր,באלטימאר,בולטימור,بالتيمور,بالتیمور,بالٹیمور,بالٹیمور، میری لینڈ,बाल्टिमोर,बाल्टीमोर,বাল্টিমোর,ਬਾਲਟੀਮੋਰ,பால்ட்டிமோர்,ಬಾಲ್ಟಿಮೋರ್,ബാൾട്ടിമോർ,บอลทิมอร์,བྷལ་ཏྲི་མོར།,ဘော်လ်တီမိုးမြို့,ბალტიმორი,ボルチモア,巴爾的摩,볼티모어', 39.2903800, -76.6121900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133535, 'Baltimore Highlands', 'Baltimore Highlands', '', 39.2331600, -76.6366300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133536, 'Ballenger Creek', 'Ballenger Creek', '', 39.3726000, -77.4352600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133537, 'Bartonsville', 'Bartonsville', '', 39.3926000, -77.3580400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133538, 'Bel Air', 'Bel Air', 'Aquila Scotts Old Field,Behl Ehjr,Bel Air,Bel Er,Belair,Bell-Air,Bellair,Belly Air,bei lai er,bl ayr  mrylnd,byl ayr,Бел Ер,Бэл Эйр,بل ایر، مریلند,بيل أير,貝萊爾', 39.5359400, -76.3482900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133539, 'Bel Air', 'Bel Air', '', 39.5731400, -78.8497400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133540, 'Beltsville', 'Beltsville', 'Behltsvill,Beltsvil,Beltsville,Old Vansville,Vansville,ZFE,bltswyl  mrylnd,Белтсвил,Бэлтсвилл,بلتسویل، مریلند', 39.0348300, -76.9074700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133541, 'Bennsville', 'Bennsville', 'Bennsville,Bensville,Benville', 38.6092900, -77.0122000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133542, 'Berlin', 'Berlin', 'Ber Lin,Berlin,Burleigh Manor,Burley,Stephens Cross Roads,Stevensons Crossroads,brlyn,brlyn  mrylnd,Берлин,برلن، میری لینڈ,برلين,برلین، مریلند', 38.3226200, -75.2176900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133543, 'Berwyn Heights', 'Berwyn Heights', 'Berwyn Heights,Charlton Heights', 38.9940000, -76.9105300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133544, 'Bethesda', 'Bethesda', 'Betesda,Budezda,bei sai si da,beseoseuda,besesuda,btzda  mrylnd,bythysda,Бетесда,Бъдезда,بتزدا، مریلند,بيثيسدا,بیتھسڈا، میری لینڈ,ベセスダ,贝塞斯达,베서스다', 38.9806700, -77.1002600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133545, 'Bladensburg', 'Bladensburg', 'Beall Town,Bladensburg,Bladensburgh,Blejdensburg,Garrisons Landing,bladnsbwrg  mrylnd,bladynsbwrgh,Бладенсбург,Блејденсбург,بلادنسبورگ، مریلند,بلادينسبورغ', 38.9392800, -76.9338600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133546, 'Boonsboro', 'Boonsboro', 'Boonesboro,Boonsboro,Boonsborough,Boonsburg,Margarettsville,Margaretville', 39.5062100, -77.6524900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133547, 'Bowie', 'Bowie', 'Boui,Bovi,Bowie,Bowie Station,Bui,Huntington City,Huntington Station,bawy,bui,bwwy  mrylnd,Бови,Боуи,Буи,باوي,بووئی، میری لینڈ,بووی، مریلند,ブーイ', 38.9427800, -76.7302800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133548, 'Bowleys Quarters', 'Bowleys Quarters', '', 39.3353900, -76.3902400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133549, 'Bowling Green', 'Bowling Green', '', 39.6237000, -78.8044600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133550, 'Braddock Heights', 'Braddock Heights', '', 39.4187100, -77.5036000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133551, 'Brandywine', 'Brandywine', '', 38.6967800, -76.8477500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133552, 'Brentwood', 'Brentwood', 'Brentwood,Highland', 38.9431700, -76.9566400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133553, 'Brock Hall', 'Brock Hall', 'Brock Hall,Brock Hill', 38.8501100, -76.7610800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133554, 'Brooklyn Park', 'Brooklyn Park', '', 39.2284400, -76.6163600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133555, 'Brookmont', 'Brookmont', '', 38.9420600, -77.1202600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133556, 'Brunswick', 'Brunswick', 'Barry,Berlin,Bransvik,Braunshvejg,Brunswick,branzwyk  mrylnd,brwnzwyk,Брансвик,Брауншвейг,برانزویک، مریلند,برنزوک، میری لینڈ,برونزويك', 39.3142700, -77.6277700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133557, 'Bryans Road', 'Bryans Road', 'Bryans Crossroads,Bryans Road', 38.6270600, -77.0730300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133558, 'Buckeystown', 'Buckeystown', 'Buckey Town,Buckeys Town,Buckeystown', 39.3348200, -77.4316500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133559, 'Burtonsville', 'Burtonsville', 'Burton''s,Burtonsvill,Burtonsville,bwrtwnswyl  mrylnd,Буртонсвилл,بورتونسویل، مریلند', 39.1112200, -76.9324800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133560, 'Cabin John', 'Cabin John', 'Cabin John,Captain Johns Mill,Captain Johns Mills', 38.9753900, -77.1580300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133561, 'California', 'California', 'Benita,Benitia,California', 38.3004000, -76.5074500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133562, 'Calverton', 'Calverton', '', 39.0576100, -76.9358100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133563, 'Cambridge', 'Cambridge', 'CGE,Kehmbridzh,Kembridz,Kembridzh,jian qiao,kambrydj,kenburijji,kymbryj  mrylnd,Кембридж,Кембриџ,Кэмбридж,كامبريدج,کیمبرج، میری لینڈ,کیمبریج، مریلند,ケンブリッジ,劍橋', 38.5631700, -76.0788300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133564, 'Camp Springs', 'Camp Springs', 'ADW,Allentown,Camp Springs', 38.8040000, -76.9066400, 'US', '2013-05-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133565, 'Cape Saint Claire', 'Cape Saint Claire', 'Cape St. Claire', 39.0431700, -76.4449600, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133566, 'Capitol Heights', 'Capitol Heights', '', 38.8851100, -76.9158100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133567, 'Carney', 'Carney', 'Carney,Carny,Karni,Карни', 39.3942700, -76.5235800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133568, 'Catonsville', 'Catonsville', 'Catonsville,Johnny Cake,Johnnycake,Katonsvil,Katonsvill,kytnzwyl  mrylnd,Катонсвил,Катонсвилл,کیتنزویل، مریلند,کیٹونسویل، میری لینڈ', 39.2720500, -76.7319200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133569, 'Cavetown', 'Cavetown', 'Cave Town,Cavetown', 39.6442600, -77.5858200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133570, 'Centreville', 'Centreville', 'Centerville,Centreville,Chester Mills,Chesterfield,Sentervil,Sentrvill,shen te wei,sntrfyl,sntrwyl  mrylnd,Сентервил,Сентрвилл,سنترفيل,سنترویل، مریلند,申特維', 39.0417800, -76.0663300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133571, 'Charlestown', 'Charlestown', '', 39.2681600, -76.7052500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133572, 'Charlestown', 'Charlestown', 'Charles Town,Charlestown', 39.5737300, -75.9749500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133573, 'Charlotte Hall', 'Charlotte Hall', 'Charlotte Hall,Ye Cool Springs of Saint Maries,Ye Coole Springs,Ye Coole Springs of Saint Maries', 38.4809600, -76.7780200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133574, 'Chesapeake Beach', 'Chesapeake Beach', '', 38.6862300, -76.5346800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133575, 'Chesapeake Ranch Estates', 'Chesapeake Ranch Estates', '', 38.3462400, -76.4177300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133576, 'Chester', 'Chester', 'Chester,Честер', 38.9753900, -76.2894000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133577, 'Chestertown', 'Chestertown', 'Chestehrtaun,Chester,Chester Town,Chester-Town,Chestertaun,Chestertown,New Town,New-Town,Newtown,Port of Chester,chstrtwwn  mrylnd,qie si te dun,tshystrtawn,Честертаун,Честэртаун,تشيسترتاون,چسترتوون، مریلند,切斯特頓', 39.2090000, -76.0666100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133578, 'Cheverly', 'Cheverly', 'Chevehrli,Sheverli,chwrly  mrylnd,tshyfyrly,Чевэрли,Шеверли,تشيفيرلي,چورلی، مریلند', 38.9281700, -76.9158100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133579, 'Chevy Chase', 'Chevy Chase', 'Cheivy Chace,Chevi Chehjs,Chevi Chejs,Chevy Chase,Chevy Chase Section Four,chwy chys  mrylnd,Чеви Чејс,Чеви Чэйс,چوی چیس، مریلند', 39.0028700, -77.0711500, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133580, 'Chevy Chase Village', 'Chevy Chase Village', '', 38.9692800, -77.0788700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133581, 'Chillum', 'Chillum', '', 38.9637200, -76.9908100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133582, 'Clarksburg', 'Clarksburg', '', 39.2387200, -77.2794300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133583, 'Clover Hill', 'Clover Hill', '', 39.4562100, -77.4288700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133584, 'Cloverly', 'Cloverly', '', 39.1081600, -76.9977500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133585, 'Clinton', 'Clinton', 'Clinton,Klinton,Robeystown,Surrats,Surratsville,Surratts,Surrattsville,klyntn  mrylnd,Клинтон,کلنٹن، میری لینڈ,کلینتن، مریلند', 38.7651100, -76.8983100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133586, 'Cockeysville', 'Cockeysville', 'Kokizvil,Kokkehjsvill,kakyzwyl  mrylnd,Кокизвил,Коккэйсвилл,کاکیزویل-ہنٹ ویلی، میری لینڈ,کاکیزویل، مریلند', 39.4812200, -76.6438600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133587, 'Colesville', 'Colesville', '', 39.0756600, -77.0019200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133588, 'College Park', 'College Park', 'CGS,Koledz Park,Kolledzh Park,Saeptum Collegii,da xue gong yuan shi,kallijipakeu,kalyj park  mrylnd,karejjipaku,khxllec phar k,kwlyj bark,Колеџ Парк,Колледж Парк,كوليج بارك,کالج پارک، میری لینڈ,کالیج پارک، مریلند,คอลเลจพาร์ก,カレッジパーク,大學公園市,칼리지파크', 38.9806700, -76.9369200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133589, 'Colmar Manor', 'Colmar Manor', 'Beall Town,Colmar Manor,Garrisons Landing', 38.9331700, -76.9458100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133590, 'Columbia', 'Columbia', 'Columbia,Kolambija,Kolumbija,keolleombia,klmbya  mrylnd,koronbia,kwlwmbya,Коламбија,Колумбия,كولومبيا,کلمبیا، مریلند,کولمبیا، میریلینڈ,コロンビア,컬럼비아', 39.2403800, -76.8394200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133591, 'Coral Hills', 'Coral Hills', '', 38.8703900, -76.9210800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133592, 'Cottage City', 'Cottage City', 'Cottage City,Willen Heights', 38.9381700, -76.9483100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133593, 'Cresaptown', 'Cresaptown', 'Bradys Mill,Cresap Station,Cresapburg,Cresaptown', 39.5928700, -78.8333500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133594, 'Crofton', 'Crofton', 'Kroftona,Крофтона', 39.0017800, -76.6874700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133595, 'Crisfield', 'Crisfield', 'Annemessex,Crisfield,Krisfild,Somers Cove,krysfyld,krysfyld  mrylnd,Крисфилд,كريسفيلد,کریسفیلد، مریلند', 37.9834600, -75.8538200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133596, 'Croom', 'Croom', 'Croom,Croome', 38.7526200, -76.7638600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133597, 'Crownsville', 'Crownsville', 'Cronsville,Crownsville,Kraunsvil,Krounsvill,krwwnswyl  mrylnd,Краунсвил,Кроунсвилл,کروونسویل، مریلند', 39.0284400, -76.6013500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133598, 'Cumberland', 'Cumberland', 'CBE,Cumberland,Cumbria,Fort Cumberland,Kamberland,Kamberlend,Kjumberland,Washington Town,Will''s Creek,Wills Creek,kan bo lan,kanbarando,keombeollaendeu,kmbrland,Камберланд,Камберленд,Кюмберланд,كمبرلاند,کمبرلینڈ، میری لینڈ,カンバーランド,坎伯蘭,컴벌랜드', 39.6528700, -78.7625200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133599, 'Damascus', 'Damascus', 'Black Ankle,Damascus', 39.2884400, -77.2038700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133600, 'Darnestown', 'Darnestown', 'Darnes,Darnestown,Mount Pleasant', 39.1034400, -77.2908200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133601, 'Davidsonville', 'Davidsonville', '', 38.9228900, -76.6283000, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133602, 'Deale', 'Deale', '', 38.7765100, -76.5552400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133603, 'Delmar', 'Delmar', '', 38.4559500, -75.5774200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133604, 'Denton', 'Denton', 'Dehnton,Denton,Eden Town,Eden-Town,Edenton,Pig Point,deng dun,dntn  mrylnd,dntwn,Дентон,Дэнтон,دنتن، مریلند,دنتون,登頓', 38.8845600, -75.8271600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133605, 'Derwood', 'Derwood', '', 39.1173300, -77.1610900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133606, 'District Heights', 'District Heights', '', 38.8576100, -76.8894200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133607, 'Drum Point', 'Drum Point', '', 38.3267900, -76.4260600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133608, 'Dundalk', 'Dundalk', 'Avondale,Dandalk,Dandok,Dandolk,Dundalk,dandk  mrylnd,Дандалк,Дандок,Дандолк,داندک، مریلند,ڈنڈاک، میری لینڈ', 39.2506600, -76.5205200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133609, 'Dunkirk', 'Dunkirk', 'Dunkirk,Smithville', 38.7217800, -76.6605200, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133610, 'Dunkirk Town Center', 'Dunkirk Town Center', '', 38.7203900, -76.6585700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133611, 'East Riverdale', 'East Riverdale', '', 38.9620600, -76.9219200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133612, 'Easton', 'Easton', 'Court House,ESN,Easton,Iston,Pitts Bridge,Talbot Court House,Talbot Courthouse,Talbot Town,aystn  mrylnd,aystwn,yi si dun,Истон,ايستون,ایستن، مریلند,伊斯頓', 38.7742800, -76.0763300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133613, 'Edgemere', 'Edgemere', '', 39.2420500, -76.4480200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133614, 'Edgewater', 'Edgewater', '', 38.9570600, -76.5499600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133615, 'Edgewood', 'Edgewood', 'Edgewood,Edgewood Station', 39.4187200, -76.2944000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133616, 'Edmonston', 'Edmonston', '', 38.9467800, -76.9310900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133617, 'Eldersburg', 'Eldersburg', 'Eldersburg,Eldersburgh', 39.4037100, -76.9502600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133618, 'Elkton', 'Elkton', 'Ehlkton,Elk Town,Elkton,Elktown,Head of Elk,Hollingsworth,Sahakitko,ai er ke dun,alktwn,alktwn  mrylnd,Елктон,Элктон,إلكتون,الکتون، مریلند,埃尔克顿', 39.6067800, -75.8332700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133619, 'Elkridge', 'Elkridge', 'Ehlkridzh,Elk Ridge,Elk Ridge Landing,Elkridge,Elkridge Landing,Elkridz,alkrydg  mrylnd,Елкриџ,Элкридж,الکریدگ، مریلند,ایلکریج، میری لینڈ', 39.2126100, -76.7135800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133620, 'Ellicott City', 'Ellicott City', 'Ehllikot Siti,Elikot Siti,Ellicott,Ellicott City,Ellicott Mills,Ellicotts Lower Mills,Ellicotts Mills,ai li ke te cheng,alykt  mrylnd,erikottoshiti,Еликот Сити,Элликот Сити,الیکت، مریلند,ایلیکاٹ سٹی، میری لینڈ,エリコットシティ,埃利科特城', 39.2673300, -76.7983100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133621, 'Emmitsburg', 'Emmitsburg', 'Carrollsburg,Ehmmitsburg,Emitsberg,Emmetsburg,Emmettsburgh,Emmitsburg,Poplar Fields,Silver Fancy,Silver Field,amytsbwrg  mrylnd,amytsbwrgh,Емитсберг,Эммитсбург,إميتسبورغ,امیتسبورگ، مریلند', 39.7045400, -77.3269300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133622, 'Essex', 'Essex', 'Ehssehks,Ehsseks,Eseks,asyks  mrylnd,Есекс,Эссекс,Эссэкс,اسیکس، مریلند,ایسیکس، میری لینڈ', 39.3092700, -76.4749600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133623, 'Fairland', 'Fairland', '', 39.0762200, -76.9577500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133624, 'Fairmount Heights', 'Fairmount Heights', 'Fairmont Heights,Fairmount Heights', 38.9009500, -76.9155300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133625, 'Fallston', 'Fallston', 'Fallston,White House', 39.5145500, -76.4110700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133626, 'Federalsburg', 'Federalsburg', 'Federalsberg,Federalsburg,Federalsburgh,Northwest Fork Bridge,The Bridge,fdralsbwrg  mrylnd,fydyralsbwrgh,Федералсберг,Федералсбург,فدرالسبورگ، مریلند,فيديرالسبورغ', 38.6942800, -75.7721600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133627, 'Ferndale', 'Ferndale', 'Ferndale,Wellhams', 39.1831600, -76.6402400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133628, 'Forest Glen', 'Forest Glen', '', 39.0145500, -77.0547000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133629, 'Forest Heights', 'Forest Heights', '', 38.8095600, -76.9980300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133630, 'Forestville', 'Forestville', 'Forestville,Forrestville,Long Old Fields', 38.8451100, -76.8749700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133631, 'Fort George G Mead Junction', 'Fort George G Mead Junction', 'Centralia,Fort George G Mead Junction,Junction', 39.1259400, -76.7891400, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133632, 'Fort Washington', 'Fort Washington', 'Fort Vashington,Fort Voshington,Fort Warburton,Fort Washington Estates,Ft. Washington,fwrt washyngtn  mrylnd,Форт Вашингтон,Форт Вошингтон,فورت واشینگتن، مریلند', 38.7073400, -77.0230300, 'US', '2013-07-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133633, 'Four Corners', 'Four Corners', '', 39.0203900, -77.0127500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133634, 'Frederick', 'Frederick', 'FDK,Frederic Town,Frederick,Frederick City,Frederick Town,Frederick i Maryland,Fredericktown,Frederik,Frederikas,Frehderik,Fridericus,Friedrichtown,Monaquesy,Monocacy,Monockkasye,frdryk  mrylnd,frydryk,fu lei de li ke,furederikku,peuledeolig,Фредерик,Фредерік,Фрэдерик,فردریک، مریلند,فريدريك,فریڈرک، میری لینڈ,フレデリック,弗雷德里克,프레더릭', 39.4142700, -77.4105400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133635, 'Friendly', 'Friendly', '', 38.7517800, -76.9785900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133636, 'Friendship Village', 'Friendship Village', '', 38.9628900, -77.0888700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133637, 'Frostburg', 'Frostburg', 'Frost Town,Frostberg,Frostburg,Frostburgh,Mount Pleasant,frwstbwrg  mrylnd,frwstbwrgh,fu luo si te bao,Фростберг,Фростбург,فروستبورغ,فروستبورگ، مریلند,弗羅斯特堡', 39.6581400, -78.9283600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133638, 'Fruitland', 'Fruitland', 'Disharoons Crossroads,Forktown,Fruitland', 38.3220600, -75.6202000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133639, 'Fulton', 'Fulton', 'Fulton,Waters Store', 39.1509400, -76.9230300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133640, 'Gaithersburg', 'Gaithersburg', 'Forest Oak,GAI,Gaithersburg,Gaithersburgum,Gejtersberg,Gejtersburg,Gejtursburg,Gejzehrsburg,gai se si bao,geideoseubeogeu,geizasubagu,ghaythrsbyrgh,gytrzbrg  mrylnd,Гейзэрсбург,Гейтерсберг,Гейтърсбърг,Гејтерсбург,Ґейтерсбург,غايثرسبيرغ,گیترزبرگ، مریلند,گیتھرزبرگ، میری لینڈ,ゲイザースバーグ,盖瑟斯堡,게이더스버그', 39.1434400, -77.2013700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133641, 'Gambrills', 'Gambrills', 'Gambrills,Sappington,Sappington Station', 39.0670500, -76.6652400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133642, 'Garrett Park', 'Garrett Park', '', 39.0381600, -77.0930300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133643, 'Garrison', 'Garrison', '', 39.4059400, -76.7605300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133644, 'Germantown', 'Germantown', 'Dzermantaun,Dzhermantaun,jamantaun,jrmntawn  mrylnd,jyrmantawn,Џермантаун,Джермантаун,جرمن ٹاؤن، مونٹگمری کاؤنٹی، میری لینڈ,جرمنتاون، مریلند,جيرمانتاون,ジャーマンタウン', 39.1731600, -77.2716500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133645, 'Glassmanor', 'Glassmanor', '', 38.8190000, -76.9985900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133646, 'Glen Burnie', 'Glen Burnie', 'Glehn Bjurni,Glen Berni,Glen Burnie,Glenburnie,Myrtle,Traceys Station,ny  mrylnd,Глен Берни,Глэн Бюрни,نی، مریلند,گلین برنی، میری لینڈ', 39.1626100, -76.6246900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133647, 'Glenarden', 'Glenarden', '', 38.9292800, -76.8616400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133648, 'Glenmont', 'Glenmont', 'Glenmont,Glenmont Heights', 39.0578900, -77.0497000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133649, 'Glenn Dale', 'Glenn Dale', 'Glen Dale,Glendale,Glenn Dale,Glenn Ville,Glenndale,Glenndale Station,Glennville', 38.9876100, -76.8205300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133650, 'Goddard', 'Goddard', '', 38.9895500, -76.8533100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133651, 'Golden Beach', 'Golden Beach', '', 38.4898500, -76.6821800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133652, 'Grasonville', 'Grasonville', 'Ford''s Store,Fords Store,Grasonville,Graysonville,Winchester', 38.9581700, -76.2102300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133653, 'Green Haven', 'Green Haven', 'Green Haven,Outing Park', 39.1395500, -76.5477400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133654, 'Green Valley', 'Green Valley', 'Green Valley,Green Valley Estates', 39.3092700, -77.2972100, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133655, 'Greenbelt', 'Greenbelt', 'Grinbehlt,Grinbelt,Grinbelte,ghrynbylt,grynblt  mrylnd,gurinberuto,Гринбелт,Гринбелте,Гринбэлт,Ґрінбелт,غرينبيلت,گرین بیلٹ، میری لینڈ,گرینبلت، مریلند,グリーンベルト', 39.0045500, -76.8755300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133656, 'Greensboro', 'Greensboro', 'Bridge Town,Bridgetown,Choptank Bridge,Greensboro,Greensborough,Grinsboro,Head of Choptank,Гринсборо', 38.9737200, -75.8049300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133657, 'Hagerstown', 'Hagerstown', 'Elizabeth Hagers Town,Elizabeth Town,Elizabethtown,Gejgerstaun,HGR,Hagers Town,Hagers-Town,Hagerstown,Khagehrtaun,Khagerstaun,Khejgerstaun,hajrstawn,hei ge si dui,heigazutaun,heigeoseutaun,hygrztawn  mrylnd,Гейґерстаун,Хагерстаун,Хагэртаун,Хейгерстаун,هاجرستاون,هیگرزتاون، مریلند,ہیگرزٹاؤن، میری لینڈ,ヘイガーズタウン,黑格斯敦,헤이거스타운', 39.6417600, -77.7199900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133658, 'Halfway', 'Halfway', '', 39.6206500, -77.7588800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133659, 'Hampstead', 'Hampstead', 'Coxville,Hampstead,Spring Garden,Spring Gardens', 39.6048300, -76.8499800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133660, 'Hampton', 'Hampton', 'Khehmpton,Хэмптон', 39.4228800, -76.5846900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133661, 'Hancock', 'Hancock', 'Hancock,Hancocks,Hancocks Town,Handcocks,Khenkok,North Bend Settlement,han kao ke,hankwk,hnkak  mrylnd,Хенкок,هانكوك,هنکاک، مریلند,汉考克', 39.6989800, -78.1797300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133662, 'Hanover', 'Hanover', 'Hanover,Hanoversville,Hanoverville', 39.1928900, -76.7241400, 'US', '2012-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133663, 'Queen Anne', 'Queen Anne', 'Hardesty,Queen Anne', 38.8987200, -76.6783000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133664, 'Havre de Grace', 'Havre de Grace', 'French Town,Harmers Town,Havre de Grace,Khaver de Grejs,Khavr deh Grehjs,Le Havre de Grace,Stocketts Town,Susquehanna Lower Ferry,The Lower Ferry,habadigureisu,hafr dy ghrys,hwr da grys  mrylnd,Хавер де Грејс,Хавр дэ Грэйс,هافر دي غريس,هور دا گریس، مریلند,ہاوری ڈی گریس، میری لینڈ,ハバディグレイス', 39.5492800, -76.0916200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133665, 'Hebron', 'Hebron', 'Hebron,Nelsons', 38.4201200, -75.6877100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133666, 'Herald Harbor', 'Herald Harbor', '', 39.0537200, -76.5691300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133667, 'Highfield-Cascade', 'Highfield-Cascade', 'Highfield Cascade,Highfield-Cascade', 39.7161600, -77.4828200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133668, 'Highland', 'Highland', '', 39.1790000, -76.9574800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133669, 'Hillandale', 'Hillandale', '', 39.0265000, -76.9741400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133670, 'Hillcrest Heights', 'Hillcrest Heights', '', 38.8328900, -76.9594200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133671, 'Hillsmere Shores', 'Hillsmere Shores', '', 38.9401100, -76.4949600, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133672, 'Hughesville', 'Hughesville', 'Hughesville,Hughsville', 38.5326200, -76.7838600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133673, 'Hunt Valley', 'Hunt Valley', '', 39.4998300, -76.6410800, 'US', '2012-03-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133674, 'Huntingtown', 'Huntingtown', 'Hunting Town,Huntingtown', 38.6159500, -76.6130200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133675, 'Huntingtown Town Center', 'Huntingtown Town Center', '', 38.6209500, -76.6160700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133676, 'Hurlock', 'Hurlock', '', 38.6242800, -75.8543800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133677, 'Hyattsville', 'Hyattsville', 'Bealltown,Hart,Hyattsville,Khiatsvill,haytsfyl,haytswyl  mrylnd,Хиатсвилл,هايتسفيل,هایتسویل، مریلند', 38.9559400, -76.9455300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133678, 'Ilchester', 'Ilchester', 'Ilchester,Ilchester Mills', 39.2509400, -76.7646900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133679, 'Indian Head', 'Indian Head', 'Indian Head,Indian Khid,Indian-Ged,Indian-Khed,Indianhead,Infijan Khed,andyan hyd,ayndyan hd  mrylnd,Індіан-Гед,Индиан Хид,Индиан-Хед,Инфијан Хед,إنديان هيد,ایندیان هد، مریلند', 38.6001200, -77.1622000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133680, 'Jarrettsville', 'Jarrettsville', 'Carmens,Jarrettsville', 39.6045500, -76.4777400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133681, 'Jefferson', 'Jefferson', 'Jefferson,New Town,Newtons,Newtons Trap,Newtown Trap,The Trap,Trap Town', 39.3620500, -77.5316500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133682, 'Joppatowne', 'Joppatowne', 'Dzhoppataun,jwpatwwn  mrylnd,Джоппатаун,جوپاتوون، مریلند', 39.4578900, -76.3552400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133683, 'Keedysville', 'Keedysville', 'Centerville,Keedysville,kdyswyl  mrylnd,kydysfyl,كيديسفيل,کدیسویل، مریلند', 39.4862100, -77.6997100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133684, 'Kemp Mill', 'Kemp Mill', '', 39.0390000, -77.0191400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133685, 'Kensington', 'Kensington', 'Kensington,Knowles,Knowles Station,knsynghtwn,knzyngtn  mrylnd,Кенсингтон,كنسينغتون,کنزینگتن، مریلند', 39.0256700, -77.0763700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133686, 'Kettering', 'Kettering', 'Kettering,Кеттеринг', 38.8845600, -76.8146900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133687, 'Kingstown', 'Kingstown', 'Kings Town,Kingston,Kingstown', 39.2048300, -76.0513300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133688, 'Kingsville', 'Kingsville', 'Fork Meeting House,Kings Tavern,Kingsville', 39.4487200, -76.4177400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133689, 'La Plata', 'La Plata', 'La Plata,La-Plata,LaPlata,LaPlata Station,Laplata,Le Plateau,la blata,la plata  mrylnd,la pu la ta,Ла Плата,Ла-Плата,لا بلاتا,لا پلاتا، مریلند,لا پلاٹا، میری لینڈ,拉普拉塔', 38.5292900, -76.9752500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133690, 'La Vale', 'La Vale', 'La Vale,LaVale', 39.6556400, -78.8105800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133691, 'Lake Arbor', 'Lake Arbor', '', 38.9078900, -76.8296900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133692, 'Lake Shore', 'Lake Shore', 'Jacobs Store,Lake Shore,Lakeshore', 39.1070500, -76.4849600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133693, 'Landover', 'Landover', 'Greater Landover,Landover,Landover Depot,Landover Estates,Landover Road,landwwr  mrylnd,Ландовер,لاندوور، مریلند,لینڈاوور، میری لینڈ', 38.9340000, -76.8966400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133694, 'Landover Hills', 'Landover Hills', '', 38.9431700, -76.8922000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133695, 'Langley Park', 'Langley Park', '', 38.9887200, -76.9813600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133696, 'Lanham', 'Lanham', 'lanham-sabrwk  mrylnd,لانهام-سابروک، مریلند,لینہم، میری لینڈ', 38.9687500, -76.8634000, 'US', '2015-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133697, 'Lansdowne', 'Lansdowne', 'Lansdown,Lansdowne', 39.2451100, -76.6605200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133698, 'Largo', 'Largo', '', 38.8976100, -76.8302500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133699, 'Laurel', 'Laurel', 'Laurehl,Laurel,Laurel Factory,Lorel,loleol,lrl  mrylnd,lwryl,roreru,Лаурэл,Лорел,لرل، مریلند,لورل، میری لینڈ,لوريل,ローレル,로럴', 39.0992800, -76.8483100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133700, 'Layhill', 'Layhill', '', 39.0923300, -77.0444200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133701, 'Leonardtown', 'Leonardtown', 'Benedict Leonard Town,LTW,Leonard Town,Leonardtown,Lionardtaun,Seymour Town,Seymourtown,Shepherds Old Fields,Sheppards Old Fields,lun na de dun,lwnardtwwn  mrylnd,lywnardtawn,Лионардтаун,لوناردتوون، مریلند,ليوناردتاون,倫納德頓', 38.2912400, -76.6357900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133702, 'Lexington Park', 'Lexington Park', 'Centerville,Jarboesville,Lexington Park', 38.2667900, -76.4538400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133703, 'Linganore', 'Linganore', '', 39.4403800, -77.2080400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133704, 'Linthicum', 'Linthicum', 'Linsikum,Lintikam,Lintikum,lynthykwm  mrylnd,Линсикум,Линтикам,Линтикум,لینتهیکوم، مریلند', 39.2051100, -76.6527500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133705, 'Lochearn', 'Lochearn', '', 39.3406600, -76.7221900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133706, 'Lonaconing', 'Lonaconing', 'Coney,Lonaconing,Lonakoning,lwnakwnyng  mrylnd,lwnakwnyngh,Лонаконинг,لوناكونينغ,لوناکونینگ، مریلند', 39.5659200, -78.9803000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133707, 'Londontowne', 'Londontowne', 'Burgess Wharf,London Town,London Towne,Londontown,Londontowne', 38.9334500, -76.5494100, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133708, 'Long Beach', 'Long Beach', '', 38.4609600, -76.4688400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133709, 'Lusby', 'Lusby', 'Lusby,Lusbys', 38.4106800, -76.4552300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133710, 'Lutherville', 'Lutherville', 'Lutervil,Lutherville,Timonium Station,Лутервил,لوتھرویل، میری لینڈ', 39.4212200, -76.6260800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133711, 'Manchester', 'Manchester', 'Manchester,Noodle Doosey,manshstr,mnchstr  mrylnd,Манчестер,مانشستر,مانچسٹر، میری لینڈ,منچستر، مریلند', 39.6612100, -76.8849800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133712, 'Marlboro Meadows', 'Marlboro Meadows', '', 38.8362200, -76.7149700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133713, 'Marlow Heights', 'Marlow Heights', '', 38.8334500, -76.9516400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133714, 'Marlton', 'Marlton', '', 38.7737300, -76.7899700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133715, 'Maryland City', 'Maryland City', '', 39.0920500, -76.8177500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133716, 'Maugansville', 'Maugansville', 'Maugansville,Morgansville', 39.6928700, -77.7447200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133717, 'Mayo', 'Mayo', 'Mayo,Rhodes River', 38.8876100, -76.5119000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133718, 'Mays Chapel', 'Mays Chapel', '', 39.4331600, -76.6494100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133719, 'Mechanicsville', 'Mechanicsville', 'Harrisburg,Mechanicsville', 38.4429000, -76.7438500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133720, 'Mellwood', 'Mellwood', '', 38.8103900, -76.8241400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133721, 'Middle River', 'Middle River', '', 39.3342700, -76.4394100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133722, 'Middletown', 'Middletown', 'Middle Town,Middletown,Middltaun,Midltaun,Smithfield,mydltawn,mydltawn  mrylnd,Миддлтаун,Мидлтаун,ميدلتاون,مڈل ٹاؤن، میری لینڈ,میدلتاون، مریلند', 39.4437100, -77.5447100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133723, 'Milford Mill', 'Milford Mill', '', 39.3478800, -76.7699700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133724, 'Mitchellville', 'Mitchellville', 'Mitchellville,Mullikin,Mullikin Station', 38.9251100, -76.7427500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133725, 'Montgomery Village', 'Montgomery Village', '', 39.1767700, -77.1952600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133726, 'Morningside', 'Morningside', '', 38.8301100, -76.8913600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133727, 'Mount Airy', 'Mount Airy', 'Maunt Ehjri,Maunt Eri,Mount Airy,Mountairy,Parrs Spring Ridge,maunteueeoli,mawnt ayry,mawnt ayry  mrylnd,Маунт Ери,Маунт Эйри,ماونت إيري,ماونت ایری، مریلند,마운트에어리', 39.3762100, -77.1547000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133728, 'Mount Rainier', 'Mount Rainier', 'Maunt Rejnehr,Maunt Rejnir,Mount Rainier,Mud Ranier,mawnt rynyyr,rynyr  mrylnd,Маунт Рейнэр,Маунт Рејнир,رینیر، مریلند,ماؤنٹ رائنیر، میری لینڈ,ماونت رينيير', 38.9415000, -76.9649800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133729, 'Mountain Lake Park', 'Mountain Lake Park', 'Hoyes Big Pasture,Mountain Lake Park', 39.3984300, -79.3817100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133730, 'Myersville', 'Myersville', '', 39.5051000, -77.5663800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133731, 'New Carrollton', 'New Carrollton', '', 38.9698300, -76.8799700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133732, 'New Windsor', 'New Windsor', 'New Windsor,Sulphur Springs', 39.5420500, -77.1080400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133733, 'North Beach', 'North Beach', 'North Beach,North Chesapeake Beach', 38.7073400, -76.5310700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133734, 'North Bel Air', 'North Bel Air', '', 39.5398300, -76.3549600, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133735, 'North Bethesda', 'North Bethesda', 'N. Bethesda,Nors Bezehsda,Nort Betesda,nrt btzda  mrylnd,Норс Безэсда,Норт Бетесда,نرت بتزدا، مریلند', 39.0445500, -77.1188700, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133736, 'North East', 'North East', 'Herringtown,Nors Ist,Nort Ist,North East,North East Point,North-east,Northeast,Welch Port,nrtyst  mrylnd,nwrth ayst,Норс Ист,Норт Ист,نرتیست، مریلند,نورث إيست', 39.6001100, -75.9413300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133737, 'North Kensington', 'North Kensington', '', 39.0303900, -77.0724800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133738, 'North Laurel', 'North Laurel', 'Nors Laurehl,Nort Lorel,nrt lrl  mrylnd,Норс Лаурэл,Норт Лорел,نرت لرل، مریلند', 39.1390000, -76.8705300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133739, 'North Potomac', 'North Potomac', '', 39.0828900, -77.2649800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133740, 'Oakland', 'Oakland', 'Armstrongs,Armstrongs in the Green Glades,Glades,Green Glades,McCartys Mill,ODM,Oakland,Oaklehnd,Oklend,Oukland,Slabtown,Yough Glades,Yox Glades,ao ke lan,awkland,awwklnd  mrylnd,Оаклэнд,Окленд,Оукланд,أوكلاند,اووکلند، مریلند,奧克蘭', 39.4078700, -79.4067100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133741, 'Ocean City', 'Ocean City', 'OCE,Ocean City,Oushan Siti,Oushehn Siti,Oushun Siti,SBY,Sinepuxent Beach,The Ladies Resort to the Ocean,Urbs Oceana,awshn syty,awwshn syty  mrylnd,da yang cheng,oshanshiti,osyeon siti,Оушан Сити,Оушън Сити,Оушэн Сити,أوشن سيتي,اوشن سٹی، میری لینڈ,اووشن سیتی، مریلند,オーシャンシティ,大洋城,오션 시티', 38.3365000, -75.0849100, 'US', '2017-07-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133742, 'Ocean Pines', 'Ocean Pines', '', 38.3953900, -75.1557400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133743, 'Odenton', 'Odenton', '', 39.0840000, -76.7002500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133744, 'Olney', 'Olney', 'Fair Hill,Machanicsville,Mechanicsville,Olnehj,Olney,Olni,awlny  mrylnd,Олни,Олнэй,اولنی، مریلند,اولنی، میری لینڈ', 39.1531600, -77.0669200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133745, 'Overlea', 'Overlea', 'Langes Farm,Overlea', 39.3634400, -76.5205200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133746, 'Owings', 'Owings', '', 38.7176200, -76.6013500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133747, 'Owings Mills', 'Owings Mills', 'Ovings Mills,wwyngs mylz  mrylnd,Овингс Миллс,اوونگز ملز، میری لینڈ,ووینگس میلز، مریلند,オーウィングス・ミルズ', 39.4195500, -76.7802500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133748, 'Oxon Hill', 'Oxon Hill', 'Gilman Corner,Grimesville,Oxen Hill,Oxon,Oxon Hill', 38.8034500, -76.9897000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133749, 'Parkville', 'Parkville', 'Lavender Hill,Parkville', 39.3773300, -76.5396900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133750, 'Parole', 'Parole', 'Camp Parole,Parole,Roll Camp Stan,Roll Camp Station', 38.9795600, -76.5305200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133751, 'Pasadena', 'Pasadena', 'Pasadena,Pleasantena,Summit Knoll,psdyna  mrylnd,Пасадена,پسدینا، مریلند', 39.1073300, -76.5710800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133752, 'Perry Hall', 'Perry Hall', '', 39.4126100, -76.4635700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133753, 'Perryman', 'Perryman', 'Perryman,Perrymans,Perrymansville,Perrymanville', 39.4695500, -76.2044000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133754, 'Perryville', 'Perryville', 'Chesapeake,Lower Ferry,Pehrrivill,Perivil,Perry Point,Perryville,Susquehanna,byryfyl,prywyl  mrylnd,Перивил,Пэрривилл,بيريفيل,پریویل، مریلند', 39.5601100, -76.0713400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133755, 'Pikesville', 'Pikesville', 'Pajksvil,Pajksvill,Pajksvill'',paykswyl  mrylnd,pyyqswwyl,Пайксвилл,Пайксвилль,Пајксвил,פייקסוויל,پائکسویل، میری لینڈ,پایکسویل، مریلند', 39.3742700, -76.7224700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133756, 'Pittsville', 'Pittsville', 'Derricksons Cross Roads,Pittsville', 38.3953900, -75.4129700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133757, 'Pleasant Hills', 'Pleasant Hills', '', 39.4795500, -76.3941300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133758, 'Pocomoke City', 'Pocomoke City', 'Meeting House Landing,New Town,Newton,Newtown,Pitts Creek,Pocomocke,Pocomocke City,Pocomoke,Pocomoke City,Pokomok Siti,Pokomoke,Pokomouk Siti,Stevens Ferry,Stevens Landing,Warehouse Landing,bwkwmwk syty,pwkwmwk syty  mrylnd,Покомок Сити,Покомоук Сити,بوكوموك سيتي,پوکوموک سیتی، مریلند', 38.0756800, -75.5679800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133759, 'Point of Rocks', 'Point of Rocks', 'Nelsons Ferry,Point of Rocks,Trammelstown', 39.2759400, -77.5391500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133760, 'Poolesville', 'Poolesville', 'Pooles Store,Poolesville,Pulsvil,bwlysfyl,pwlswyl  mrylnd,Пулсвил,بوليسفيل,پولسویل، مریلند', 39.1459400, -77.4169300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133761, 'Potomac', 'Potomac', 'Offutt''s Crossroads,Offutts Cross Road,Potomac,Potomak,Potomak Khehjts,Section Eight,ptwwmk  mrylnd,Потомак,Потомак Хэйтс,پتوومک، مریلند,پوٹومیک، میری لینڈ', 39.0181700, -77.2085900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133762, 'Potomac Heights', 'Potomac Heights', '', 38.6087300, -77.1405300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133763, 'Potomac Park', 'Potomac Park', '', 39.6117600, -78.8058500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133764, 'Prince Frederick', 'Prince Frederick', 'Little Fields,Littlefields,Old Fields,Princ Fredehrik,Prince Frederic,Prince Frederick,Prince Fredericktown,Prins Frederik,Williams Old Fields,fu lei de li ke wang zi cheng,pryns frdryk  mrylnd,Принс Фредерик,Принц Фредэрик,پرینس فردریک، مریلند,弗雷德里克王子城', 38.5404000, -76.5844000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133765, 'Princess Anne', 'Princess Anne', 'Princess Ann,Princess Anne,Princess Anne Town,Princessa Anna,Prinses An,an ni gong zhu zhen,brnsys an,prynsys an  mrylnd,Принсес Ан,Принцесса Анна,برنسيس آن,پرینسیس ان، مریلند,安妮公主鎮', 38.2029000, -75.6924300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133766, 'Pumphrey', 'Pumphrey', '', 39.2173300, -76.6371900, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133767, 'Randallstown', 'Randallstown', '', 39.3673300, -76.7952500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133768, 'Redland', 'Redland', 'Redland,Redlands', 39.1453900, -77.1441500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133769, 'Reisterstown', 'Reisterstown', 'Rajsterstaun,Reisterstown,Reisterville,Washington,raystrztawn  mrylnd,Рајстерстаун,رایسترزتاون، مریلند,ریئسٹرٹاون، میری لینڈ', 39.4697600, -76.8319000, 'US', '2015-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133770, 'Ridgely', 'Ridgely', '', 38.9478900, -75.8843800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133771, 'Rising Sun', 'Rising Sun', 'Rajzig San,Rajzing San,Rising Sun,Risingsun,Summer Hill,Summerhill,rayzyng san  mrylnd,ryzyngh sn,Райзинг Сан,Рајзиг Сан,رایزینگ سان، مریلند,ريزينغ صن', 39.6978900, -76.0627300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133772, 'Riva', 'Riva', 'Riva,Riverview', 38.9520600, -76.5780200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133773, 'Riverdale Park', 'Riverdale Park', 'Rivehdejl Park,Riverdale,Riverdale Park,Riverdejl Park,ryfrdyl bark,rywrdyl park  mrylnd,Ривердејл Парк,Ривэдейл Парк,ريفرديل بارك,ریوردیل پارک، مریلند', 38.9634400, -76.9316400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133774, 'Riverside', 'Riverside', 'Riversajd,Риверсайд', 39.4737200, -76.2413400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133775, 'Riverside', 'Riverside', '', 39.1734400, -76.8852500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133776, 'Riviera Beach', 'Riviera Beach', 'Rivera Beach,Riviera Beach', 39.1667800, -76.5080200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133777, 'Robinwood', 'Robinwood', '', 38.9542800, -76.5146800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133778, 'Robinwood', 'Robinwood', '', 39.6370400, -77.6569400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133779, 'Robinwood', 'Robinwood', '', 39.6250000, -77.6625000, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133780, 'Rock Hall', 'Rock Hall', 'Eastern Neck,Rock Hall,Rockhall', 39.1381700, -76.2349500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133781, 'Rockville', 'Rockville', 'Hungerford''s Tavern,Hungerfords,Hungerfords Tavern,Montgomery Court House,Montgomery Courthouse,Owen''s Ordinary,Rockvilla,Rockville,Rokvil,Rokvil'',Rokvilis,Rokvill,Williamsburg,Williamsburgh,logbil,luo ke wei er,rakwyl  mrylnd,rokkubiru,rwkfyl,rwqwwyl,Роквил,Роквилл,Роквіль,רוקוויל,راکویل، مریلند,راکویل، میری لینڈ,روكفيل,როკვილი,ロックビル,羅克維爾,록빌', 39.0840000, -77.1527600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133782, 'Rosaryville', 'Rosaryville', '', 38.7567800, -76.8096900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133783, 'Rosedale', 'Rosedale', 'Mount Hayes,Mount Hays,Rosedale', 39.3201100, -76.5155200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133784, 'Rossmoor', 'Rossmoor', '', 39.1037200, -77.0710900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133785, 'Rossville', 'Rossville', '', 39.3384400, -76.4796800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133786, 'Saint Charles', 'Saint Charles', 'Saint Charles,Saint Charles City', 38.6031700, -76.9385800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133787, 'Saint James', 'Saint James', 'Lydia,Saint James,Saint James Station,Sent-Dzhejms,St. James,Сент-Джеймс', 39.5626000, -77.7580500, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133788, 'Saint Michaels', 'Saint Michaels', 'Saint Michaels,Shipping Creek', 38.7851200, -76.2243900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133789, 'Salisbury', 'Salisbury', 'Carrs Landing,Handys Landing,SBY,Salisbjuri,Salisbury,Salisbury Town,Salsbury,Sarisberia,Solsberi,Solsburi,salzbry  mrylnd,salzbwry,soljeubeli,soruzuberi,suo er zi bo li,Салисбюри,Солсбери,Солсбері,Солсбъри,سالزبری، مریلند,سالزبوري,سیلسبری، میری لینڈ,ソールズベリー,索爾茲伯里,솔즈베리', 38.3606700, -75.5993700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133790, 'Savage', 'Savage', 'Santa Heim,Savage,Savage Factory,Savidz,Савиџ', 39.1378900, -76.8238600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133791, 'Scaggsville', 'Scaggsville', '', 39.1451100, -76.9002500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133792, 'Seabrook', 'Seabrook', '', 38.9680500, -76.8465800, 'US', '2015-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133793, 'Seat Pleasant', 'Seat Pleasant', 'Chesapeake Junction,Seat Pleasant,Sit Plezant,Sit Plizant,syt blyzant,syt plznt  mrylnd,Сит Плезант,Сит Плизант,سيت بليزانت,سیت پلزنت، مریلند', 38.8962200, -76.9066400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133794, 'Selby-on-the-Bay', 'Selby-on-the-Bay', '', 38.9162200, -76.5224600, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133795, 'Severn', 'Severn', 'Boone,Sevehrn,Severn,Sevren,Sivern,aswrn  mrylnd,Северн,Севрен,Севэрн,Сиверн,اسورن، مریلند,سیورن، میری لینڈ', 39.1370500, -76.6983000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133796, 'Severna Park', 'Severna Park', 'Boon,Boons,Saverna Park,Severna Park', 39.0703900, -76.5452400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133797, 'Shady Side', 'Shady Side', 'Parrishes Choice,Rural Felicity,Shady Side,Shadyside,The Swamp', 38.8417800, -76.5121800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133798, 'Silver Hill', 'Silver Hill', '', 38.8417800, -76.9458100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133799, 'Silver Spring', 'Silver Spring', 'Fons Argenteus,Silvehr Spring,Silver Spring,Silver Springs Station,Silver-Spring,Silvur Spring,shirubasupuringu,silbeoseupeuling,sylwr aspryng  mrylnd,yin quan,Силвер Спринг,Силвер-Спринг,Силвър Спринг,Силвэр Спринг,Сілвер-Спрінг,سلور سپرنگ، میری لینڈ,سیلور اسپرینگ، مریلند,シルバースプリング,银泉,실버스프링', 38.9906700, -77.0260900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133800, 'Smithsburg', 'Smithsburg', 'Smithsburg,Smithsburgh', 39.6548200, -77.5727700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133801, 'Snow Hill', 'Snow Hill', 'Flawhill,Snow Hill,Snow Hill Towne,Snow-Hill Town,Snowhill,Snowhill Town', 38.1770600, -75.3927000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133802, 'Solomons', 'Solomons', 'Solomon,Solomons,slmn  mrylnd,Соломонс,سلمن، مریلند', 38.3184600, -76.4541200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133803, 'Somerset', 'Somerset', 'Somerset,Сомерсет', 38.9659400, -77.0960900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133804, 'South Bel Air', 'South Bel Air', '', 39.5331600, -76.3374600, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133805, 'South Gate', 'South Gate', '', 39.1290000, -76.6258000, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133806, 'South Kensington', 'South Kensington', '', 39.0190000, -77.0799800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133807, 'South Laurel', 'South Laurel', '', 39.0698300, -76.8502500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133808, 'Spencerville', 'Spencerville', '', 39.1142700, -76.9783100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133809, 'Spring Ridge', 'Spring Ridge', '', 39.4014900, -77.3524800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133810, 'Springdale', 'Springdale', '', 38.9376100, -76.8388600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133811, 'Stevensville', 'Stevensville', 'Broad Creek,Broak Creek,Kent Island,Stevensville,Stivensvil,Stivensvill,astwnswyl  mrylnd,Стивенсвил,Стивенсвилл,استونسویل، مریلند', 38.9806700, -76.3144000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133812, 'Suitland', 'Suitland', 'Sutland,swtlndsylwr  mrylnd,Сутланд,سوتلندسیلور، مریلند', 38.8487200, -76.9238600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133813, 'Sykesville', 'Sykesville', 'Sajksvil,Sajksvill,Sykes,Sykes Mill,Sykesville,asykswyl  mrylnd,skaysfyl,Сайксвилл,Сајксвил,اسیکسویل، مریلند,سكايسفيل', 39.3737100, -76.9677600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133814, 'Takoma Park', 'Takoma Park', 'Brightwood,City of Azaleas,North Takoma,Takoma,Takoma Park,takomapaku,takwma bark,tkwwma  mrylnd,Такома Парк,تاكوما بارك,تکووما، مریلند,ٹاکوما پارک، میری لینڈ,タコマパーク', 38.9778900, -77.0074800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133815, 'Taneytown', 'Taneytown', 'Tanejtaun,Taney Town,Taneytown,Tawneytown,Tonitaun,tanytawn,tanytwwn  mrylnd,Танейтаун,Тонитаун,تانيتاون,تانیتوون، مریلند', 39.6578800, -77.1744300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133816, 'Temple Hills', 'Temple Hills', 'Temple,Temple Hills', 38.8140000, -76.9455300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133817, 'Thurmont', 'Thurmont', 'Mechanics Town,Mechanicstown,Mechanicsville,Surmont,Tarmont,Thurmont,thwrmwnt,thwrmwnt  mrylnd,Сурмонт,Тармонт,تهورمونت، مریلند,ثورمونت', 39.6237100, -77.4108200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133818, 'Timonium', 'Timonium', '', 39.4370500, -76.6196900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133819, 'Towson', 'Towson', 'Tauson,Towson,Towson Town,Towsontown,tao sen,tauson,tawsn  mrylnd,Таусон,تاوسن، مریلند,ٹاوسن، میری لینڈ,タウソン,陶森', 39.4015000, -76.6019100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133820, 'Trappe', 'Trappe', 'Trap,Trappe', 38.6584500, -76.0580000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133821, 'Travilah', 'Travilah', '', 39.0690000, -77.2630400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133822, 'University Park', 'University Park', 'Juniversiti Park,aywnwrsyty park  mrylnd,ywnyfrsyty bark,Јуниверсити Парк,Юниверсити Парк,ایونورسیتی پارک، مریلند,يونيفرسيتي بارك', 38.9703900, -76.9419200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133823, 'Upper Marlboro', 'Upper Marlboro', 'Aper Marlboro,Appeh Marlboro,Marlboro,Marlborough,Marlborough Town,Upper Marlboro,Upper Marlborough,abr marlbwrw,apr marlww  mrylnd,shang ma er bo lei,Апер Марлборо,Аппэ Марлборо,آپر مارلوو، مریلند,أبر مارلبورو,上马尔伯勒', 38.8159500, -76.7496900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133824, 'Urbana', 'Urbana', '', 39.3259400, -77.3513700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133825, 'Waldorf', 'Waldorf', 'Beantown,Valdof,Voldorf,Waldorf,u~orudofu,waldwrf  mrylnd,woldopeu,Валдоф,Волдорф,والدورف، مریلند,والڈورف، میری لینڈ,ウォルドーフ,월도프', 38.6245600, -76.9391400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133826, 'Walker Mill', 'Walker Mill', '', 38.8753900, -76.8883100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133827, 'Walkersville', 'Walkersville', 'Georgetown,Uolkersvill,Vokersvil,Walkersville,walkrswyl  mrylnd,wwkrsfyl,Вокерсвил,Уолкерсвилл,والکرسویل، مریلند,ووكرسفيل', 39.4862100, -77.3519300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133828, 'West Elkridge', 'West Elkridge', '', 39.2070500, -76.7269200, 'US', '2010-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133829, 'West Laurel', 'West Laurel', '', 39.1012200, -76.8997000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133830, 'West Ocean City', 'West Ocean City', '', 38.3315000, -75.1068500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133831, 'Westernport', 'Westernport', 'Georges Creek,Hardscrabble,Vestehrnport,Vesternport,West Port,Western Port,Westernport,wstrnpwrt  mrylnd,wystrnbwrt,Вестернпорт,Вестэрнпорт,وسترنپورت، مریلند,ويسترنبورت', 39.4853700, -79.0447500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133832, 'Westminster', 'Westminster', 'Bedford,Grandadam Farm,Logsdon Tavern Land,New London Town,Vehstminster,Vestminster,Westminster,Westminster Town,Winchester,u~esutominsuta,wei si min si te,wstmnstr,wstmynstr  mrylnd,Вестминстер,Вэстминстер,وستمنستر,وستمینستر، مریلند,ویسٹ منسٹر، میری لینڈ,ウェストミンスター,威斯敏斯特', 39.5753800, -76.9958100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133833, 'Westphalia', 'Westphalia', '', 38.8453900, -76.8110800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133834, 'Wheaton', 'Wheaton', 'Mitchell''s Crossroads,Mitchells Cross Roads,Viton,Wheaton,wytwn,Витон,ويتون', 39.0398300, -77.0552600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133835, 'White Marsh', 'White Marsh', 'Cowanton,White Marsh,Whitemarsh', 39.3837200, -76.4321800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133836, 'White Oak', 'White Oak', 'White Oak,Whiteoak', 39.0398300, -76.9930300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133837, 'Williamsport', 'Williamsport', 'Potomac Valley Junction,Vilijamsport,Williams Port,Williams'' Ferry,Williamsport,willieomseupoteu,wylymzprt  mrylnd,Вилијамспорт,ویلیمزپرت، مریلند,윌리엄스포트', 39.6006500, -77.8205500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133838, 'Woodlawn', 'Woodlawn', 'Vudlon,wwdlawn  mrylnd,Вудлон,وودلاون، مریلند,ووڈلان، بالٹیمور کاؤنٹی، میری لینڈ', 39.3228800, -76.7280300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133839, 'Woodlawn', 'Woodlawn', '', 38.9495600, -76.8913600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133840, 'Woodmore', 'Woodmore', 'Woodmoor,Woodmore', 38.9212200, -76.8030300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133841, 'Woodsboro', 'Woodsboro', 'Woods Town,Woodsberry,Woodsboro,Woodsborough', 39.5331600, -77.3147100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133842, 'Adrian', 'Adrian', 'Adrian,Адриан', 38.3975200, -94.3516200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133843, 'Advance', 'Advance', 'Advance,Lakeville,New Lakeville', 37.1045500, -89.9095300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133844, 'Affton', 'Affton', 'aftn  myzwry,aftwn,أفتون,افتن، میزوری', 38.5506100, -90.3331700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133845, 'Albany', 'Albany', 'Ada,Albany,Ashton', 39.2233400, -94.1132800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133846, 'Alton', 'Alton', '', 36.6942300, -91.3993000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133847, 'Anderson', 'Anderson', 'Anderson,Андерсон', 36.6506300, -94.4435500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133848, 'Appleton City', 'Appleton City', 'Appleton City,Arlington', 38.1905800, -94.0293900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133849, 'Archie', 'Archie', '', 38.4816800, -94.3543900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133850, 'Arnold', 'Arnold', 'Arnol''d,Arnold,arnwld,arnwld  myzwry,Арнолд,Арнольд,آرنلڈ، مسوری,آرنولد، میزوری,أرنولد', 38.4328300, -90.3776200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133851, 'Ash Grove', 'Ash Grove', 'Ash Grove,Ashgrove', 37.3153300, -93.5852000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133852, 'Ashland', 'Ashland', '', 38.7744800, -92.2571300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133853, 'Aurora', 'Aurora', 'Avrora,Orora,arwra  mswry,awrwra,Аврора,Орора,أورورا,ارورا، مسوری', 36.9708900, -93.7179800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133854, 'Ava', 'Ava', 'Ava,Militia Springs', 36.9520000, -92.6604500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133855, 'Ballwin', 'Ballwin', 'Baldwin,Ballwin,Bolvin,balwn  mswry,balwyn,balwyn  myzwry,Болвин,بالون، مسوری,بالوين,بالوین، میزوری', 38.5950500, -90.5462300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133856, 'Barnhart', 'Barnhart', '', 38.3442200, -90.3934500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133857, 'Battlefield', 'Battlefield', '', 37.1156100, -93.3701900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133858, 'Bel-Nor', 'Bel-Nor', 'Behl-Nor,Bel-Nor,byl nwr,Бел-Нор,Бэл-Нор,بيل نور', 38.7020000, -90.3167800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133859, 'Bel-Ridge', 'Bel-Ridge', 'Behl-Ridzh,Bel-Ridz,byl rydj,Бел-Риџ,Бэл-Ридж,بيل ريدج', 38.7095000, -90.3253900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133860, 'Belle', 'Belle', '', 38.2858800, -91.7204400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133861, 'Bellefontaine Neighbors', 'Bellefontaine Neighbors', 'Bellefontaine Neighbors,Bellfontaine Neighbors', 38.7403300, -90.2265000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133862, 'Belton', 'Belton', 'Belton,Rankin,Белтон', 38.8119500, -94.5319000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133863, 'Benton', 'Benton', 'Benton,Бентон', 37.0978300, -89.5625800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133864, 'Berkeley', 'Berkeley', 'Behrkelej,Berkeley,Berkeley Acres,Berkli,Kinlock,Nuroad,byrkly,Беркли,Бэркелей,برکلے، مسوری,بيركلي', 38.7545000, -90.3312300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133865, 'Bernie', 'Bernie', '', 36.6689400, -89.9687000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133866, 'Billings', 'Billings', 'Billings,Биллингс', 37.0675500, -93.5521400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133867, 'Bismarck', 'Bismarck', 'Bismark,Бисмарк', 37.7692200, -90.6248500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133868, 'Black Jack', 'Black Jack', 'Black Jack,Blackjack', 38.7933800, -90.2673300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133869, 'Bloomfield', 'Bloomfield', '', 36.8858900, -89.9292600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133870, 'Blue Springs', 'Blue Springs', 'Blu Springs,blw aspryngz  myzwry,blw sbrynghz,blyw sprngz  mswry,Блу Спрингс,بلو اسپرینگز، میزوری,بلو سبرينغز,بلیو سپرنگز، مسوری', 39.0169500, -94.2816100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133871, 'Bolivar', 'Bolivar', '', 37.6144800, -93.4104700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133872, 'Bonne Terre', 'Bonne Terre', 'Bon Ter,Bonn Tehrr,Bonne Terre,Bonneterre,Bontear,Fullerton,Saint Joe Mines,bwn tyr,Бон Тер,Бонн Тэрр,بون تير,بونے تیتے، مسوری', 37.9231100, -90.5554000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133873, 'Boonville', 'Boonville', 'Bunvil,Bunvill,bwnfyl  myzwry,Бунвил,Бунвилл,بونفيل، ميزوري', 38.9736400, -92.7432400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133874, 'Bourbon', 'Bourbon', '', 38.1547700, -91.2440300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133875, 'Bowling Green', 'Bowling Green', 'Bouling Grin,Bouling-Grin,bao lin ge lin,bawlng gryn  mswry,bwlngh ghryn,Боулинг Грин,Боулинг-Грин,باولنگ گرین، مسوری,بولنغ غرين,鲍林格林', 39.3419900, -91.1951400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133876, 'Branson', 'Branson', 'Branson,Brehnson,Lucia,beulaenseun,branswn,brnswn  myzwry,brynsn  mswry,buranson,Брансон,Брэнсон,برانسون,برنسون، میزوری,برینسن، مسوری,ブランソン,브랜슨', 36.6436700, -93.2185100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133877, 'Breckenridge Hills', 'Breckenridge Hills', '', 38.7145000, -90.3673400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133878, 'Brentwood', 'Brentwood', 'Brentwood,Brentwood Station', 38.6175500, -90.3492800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133879, 'Bridgeton', 'Bridgeton', 'Bridgeton,Bridzhton,Bridzton,Marais des Liards,Owens Fort,Owens Station,Villa de Roberts,Village a Robert,brjtwn,bryjtwn  myzwry,Бриджтон,Бриџтон,برجتون,برجٹن، مسوری,بریجتون، میزوری', 38.7670000, -90.4115100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133880, 'Brookfield', 'Brookfield', 'Brookfield,The Scatters', 39.7844700, -93.0735300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133881, 'Buckner', 'Buckner', 'Buckner,Buckner Hill', 39.1325100, -94.1985600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133882, 'Buffalo', 'Buffalo', 'Buffalo,Буффало', 37.6439300, -93.0924100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133883, 'Butler', 'Butler', 'BUM,Batlehr,Batler,Butler,Butlur,bwtlr,Батлер,Батлэр,Бътлър,بوتلر,بٹلر، مسوری', 38.2586300, -94.3305100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133884, 'Byrnes Mill', 'Byrnes Mill', '', 38.4378300, -90.5817900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133885, 'Cabool', 'Cabool', 'Kabul,kabwl,kabwl  mswry,Кабул,كابول,کابول، مسوری', 37.1239400, -92.1012700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133886, 'California', 'California', 'Boonsborough,California', 38.6275300, -92.5665800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133887, 'Calverton Park', 'Calverton Park', '', 38.7647700, -90.3137300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133888, 'Camdenton', 'Camdenton', '', 38.0080900, -92.7446300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133889, 'Cameron', 'Cameron', '', 39.7402800, -94.2410600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133890, 'Campbell', 'Campbell', 'Kehmpbell,Кэмпбелл', 36.4933900, -90.0750900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133891, 'Cape Girardeau', 'Cape Girardeau', 'CGI,Cap-Girardeau,Cape Girardeau,Decatur - in-part,Kejp DZirardo,Kejp Zhirardo,kab jyrardw,kai pu ji la duo,keipeujilado,kepujirado,kyp jyradw  mswry,kyp zhrardw  myzwry,Кейп Жирардо,Кејп Џирардо,كاب جيراردو,کیپ جیرادو، مسوری,کیپ ژراردو، میزوری,ケープジラード,开普吉拉多,케이프지라도', 37.3058800, -89.5181500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133892, 'Carl Junction', 'Carl Junction', '', 37.1767200, -94.5655100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133893, 'Carrollton', 'Carrollton', '', 39.3583500, -93.4957700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133894, 'Carterville', 'Carterville', '', 37.1492300, -94.4430000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133895, 'Carthage', 'Carthage', 'Kartidz,Karzehjdzh,karthj  myzwry,kartj  myzwry,kasiji,Карзэйдж,Картиџ,كارثج، ميزوري,کارتج، میزوری,카시지', 37.1764500, -94.3102200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133896, 'Caruthersville', 'Caruthersville', '', 36.1931200, -89.6556400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133897, 'Cassville', 'Cassville', '', 36.6770100, -93.8688100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133898, 'Castle Point', 'Castle Point', '', 38.7581100, -90.2481700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133899, 'Cedar Hill', 'Cedar Hill', 'Cedar Hill,Cedarhill', 38.3533900, -90.6412400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133900, 'Centerville', 'Centerville', '', 37.4350500, -90.9584600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133901, 'Centralia', 'Centralia', '', 39.2103200, -92.1379500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133902, 'Chaffee', 'Chaffee', 'Chaffee,Leaming', 37.1800500, -89.6550900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133903, 'Charlack', 'Charlack', 'Charlak,charlak  mswry,tsharlak,Чарлак,تشارلاك,چارلاک، مسوری', 38.7025500, -90.3434500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133904, 'Charleston', 'Charleston', 'Charlston,Чарлстон', 36.9208900, -89.3506300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133905, 'Chesterfield', 'Chesterfield', 'Chehsterfild,Chesterfield,Chesterfild,Drews Station,chstrfyld  myzwry,tshystrfyld,Честерфилд,Чэстерфилд,تشيسترفيلد,چسترفیلد، میزوری,چیسٹرفیلڈ، مسوری', 38.6631100, -90.5770700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133906, 'Chillicothe', 'Chillicothe', 'Chillcothe,Chillicothe', 39.7952900, -93.5524400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133907, 'Clarkson Valley', 'Clarkson Valley', '', 38.6183900, -90.5892900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133908, 'Clarkton', 'Clarkton', 'Beech,Clarkton', 36.4517300, -89.9670400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133909, 'Claycomo', 'Claycomo', '', 39.2025000, -94.4924500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133910, 'Clayton', 'Clayton', 'Klehjton,Klejton,klaytwn,klytwn  myzwry,Клејтон,Клэйтон,كلايتون,کلیتون، میزوری,کلیٹن، مسوری', 38.6425500, -90.3237300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133911, 'Clever', 'Clever', '', 37.0303300, -93.4729700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133912, 'Clinton', 'Clinton', 'Klinton,klyntwn,Клинтон,كلينتون,کلنٹن، مسوری', 38.3686300, -93.7782700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133913, 'Cole Camp', 'Cole Camp', '', 38.4600200, -93.2027000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133914, 'Columbia', 'Columbia', 'COU,Columbia,Kolambija,Kolumbia,Kolumbija,ge lun bi ya,keolleombia,klmbya  myzwry,koronbia,kwlmbya  mswry,kwlwmbya,Коламбија,Коламбія,Колумбиа,Колумбия,كولومبيا,کلمبیا، میزوری,کولمبیا، مسوری,コロンビア,哥倫比亞,컬럼비아', 38.9517100, -92.3340700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133915, 'Concord', 'Concord', '', 38.5245000, -90.3573400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133916, 'Concordia', 'Concordia', '', 38.9833500, -93.5685500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133917, 'Cool Valley', 'Cool Valley', '', 38.7278300, -90.3101100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133918, 'Cottleville', 'Cottleville', 'Cotterville,Cottleville', 38.7461600, -90.6540100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133919, 'Country Club Hills', 'Country Club Hills', '', 38.7208800, -90.2748400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133920, 'Country Club Village', 'Country Club Village', 'Country Club,Country Club Village', 39.8322200, -94.8216300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133921, 'Crane', 'Crane', '', 36.9053400, -93.5715800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133922, 'Crestwood', 'Crestwood', 'Krehstvud,Krestvud,krystwwd,Крествуд,Крэствуд,كريستوود,کرست‌وود، میزوری,کریسٹووڈ، مسوری', 38.5570000, -90.3817800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133923, 'Creve Coeur', 'Creve Coeur', 'Kriv Koeur,Kriv Kour,krw kwr  myzwry,kryf kwyr,kryw kwyr  mswry,Крив Коеур,Крив Коур,كريف كوير,کرو کور، میزوری,کریو کویر، مسوری', 38.6608900, -90.4226200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133924, 'Crocker', 'Crocker', 'Krokehr,Kroker,krwkr  myzwry,Крокер,Крокэр,كروكر، ميزوري', 37.9489300, -92.2637800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133925, 'Crystal City', 'Crystal City', 'Crystal City,New Detroit,Plattins Landing', 38.2211700, -90.3790100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133926, 'Cuba', 'Cuba', 'Amanda,Cuba', 38.0628200, -91.4034800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133927, 'Dardenne Prairie', 'Dardenne Prairie', '', 38.7695000, -90.7290200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133928, 'De Soto', 'De Soto', 'De Soto,Deh Soto,Desoto,dy swtw,Де Сото,Дэ Сото,دي سوتو', 38.1395000, -90.5551300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133929, 'Dellwood', 'Dellwood', '', 38.7495000, -90.2856700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133930, 'Des Peres', 'Des Peres', 'Des Peres,Hathaway City,Saint Francis Xavier', 38.6008900, -90.4329000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133931, 'Desloge', 'Desloge', 'Desloge,Leadville', 37.8708800, -90.5273500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133932, 'Dexter', 'Dexter', '', 36.7958900, -89.9578700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133933, 'Dixon', 'Dixon', '', 37.9917100, -92.0937800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133934, 'Doniphan', 'Doniphan', 'Doniphan,Galigini', 36.6208900, -90.8234600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133935, 'Duenweg', 'Duenweg', '', 37.0836700, -94.4135600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133936, 'Duquesne', 'Duquesne', '', 37.0767300, -94.4593900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133937, 'East Independence', 'East Independence', 'Independence  Mo,Pixley,Pixleys', 39.0955600, -94.3552300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133938, 'East Prairie', 'East Prairie', '', 36.7797800, -89.3856300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133939, 'El Dorado Springs', 'El Dorado Springs', 'El Dorado Springs,Eldorado Springs', 37.8769800, -94.0213300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133940, 'Eldon', 'Eldon', 'Eldon,Elmira', 38.3483600, -92.5815800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133941, 'Ellisville', 'Ellisville', '', 38.5925500, -90.5870700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133942, 'Elsberry', 'Elsberry', 'Elsberry,Nelson,Nelsons Store', 39.1667200, -90.7809600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133943, 'Elvins', 'Elvins', 'Elvins,Setz', 37.8367200, -90.5329000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133944, 'Eminence', 'Eminence', '', 37.1506000, -91.3576400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133945, 'Esther', 'Esther', 'Columbia,Esther', 37.8503300, -90.4987400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133946, 'Eureka', 'Eureka', 'Ehureka,Ehvrika,Jurika,ywryka,ywryka  myzwry,Јурика,Эврика,Эурека,يوريكا,یوریکا، میزوری', 38.5025500, -90.6279000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133947, 'Excelsior Springs', 'Excelsior Springs', 'Ehkselsior Springs,Excelsior Springs,Golf Hill,Ikselsir Springs,akslsywr aspryngz  myzwry,ghkslsywr sbrnghz,Икселсир Спрингс,Экселсиор Спрингс,اکسلسیور اسپرینگز، میزوری,غكسلسيور سبرنغز', 39.3391700, -94.2260600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133948, 'Fair Grove', 'Fair Grove', 'Fair Grove,Fairgrove', 37.3839300, -93.1513000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133949, 'Farmington', 'Farmington', 'FAM,Farmington,Murphys Settlement,farmnghtwn,farmyngtwn  myzwry,Фармингтон,فارمنغتون,فارمنگٹن، مسوری,فارمینگتون، میزوری', 37.7808800, -90.4217900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133950, 'Fayette', 'Fayette', 'Fajehtt,Fejet,faietto,fayt,Файэтт,Фејет,فايت,ファイエット', 39.1458700, -92.6837900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133951, 'Fenton', 'Fenton', 'Fehnton,Fenton,fyntwn,Фентон,Фэнтон,فينتون', 38.5131100, -90.4359500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133952, 'Ferguson', 'Ferguson', 'Fergjuson,Ferguson,fagason,fei ge xun shi,frgwsn  myzwry,fu ge sen,fyrghswn,peogeoseun,perkucan,Фергусон,Фергюсон,فرگوسن، میزوری,فيرغسون,பெர்குசன்,ファーガソン,弗格森,費格遜市,퍼거슨', 38.7442200, -90.3053900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133953, 'Festus', 'Festus', 'Derby City,Fehstas,Festas,Festus,Limitville,Tanglefoot,fstws  myzwry,fystws,Фестас,Фэстас,فستوس، میزوری,فيستوس', 38.2206100, -90.3959500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133954, 'Flat River', 'Flat River', 'Flat River,Jay Bird Town,Taylor Town', 37.8500500, -90.5167900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133955, 'Florissant', 'Florissant', 'Ferdinand,Fleurissant,Florisant,Florissant,Saint Ferdinand,Saint Ferdinand Florissant,Saint Ferdinand de Florissant,San Fernando,San Fernando de Florissant,flwrysant,flwrysnt  myzwry,Флорисант,Флориссант,فلوريسانت,فلوریسنت، میزوری,فلوریسینٹ، مسوری', 38.7892200, -90.3226100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133956, 'Forsyth', 'Forsyth', 'Forsajt,Forsis,fwrsyth,Форсајт,Форсис,فورسيث', 36.6850600, -93.1199000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133957, 'Four Seasons', 'Four Seasons', 'Four Seasons,Village of Four Seasons', 38.1980900, -92.7110200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133958, 'Fredericktown', 'Fredericktown', 'Fredehriktaun,Fredericktown,Frederiktaun,Saint Michaels,The Village,frydyryktawn  myzwry,Фредериктаун,Фредэриктаун,فريديريكتاون، ميزوري', 37.5597800, -90.2940100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133959, 'Frontenac', 'Frontenac', '', 38.6356100, -90.4151200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133960, 'Fulton', 'Fulton', 'Fulton,Volney,fu er dun,furuton,fwltn  myzwry,fwltwn,Фултон,فلٹن، مسوری,فولتن، میزوری,فولتون,ფულტონი,フルトン,富尔顿', 38.8467100, -91.9479600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133961, 'Gainesville', 'Gainesville', '', 36.6031200, -92.4282200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133962, 'Galena', 'Galena', 'Galena,Jamestown', 36.8053400, -93.4665800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133963, 'Gallatin', 'Gallatin', '', 39.9144500, -93.9621700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133964, 'Garden City', 'Garden City', 'Garden Siti,Гарден Сити', 38.5611200, -94.1913300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133965, 'Gerald', 'Gerald', 'Gerald,Shotwell', 38.3997700, -91.3307100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133966, 'Gideon', 'Gideon', '', 36.4520100, -89.9192600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133967, 'Gladstone', 'Gladstone', 'Evanston,Gladston,Gladstone,Gladstoun,Gledston,Linden,Thomas Heights,ghladstwn,gldastwn  myzwry,Гладстон,Гладстоун,Гледстон,غلادستون,گلداستون، میزوری,گلیڈسٹون، مسوری', 39.2038900, -94.5546800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133968, 'Glasgow Village', 'Glasgow Village', '', 38.7536600, -90.1984400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133969, 'Glasgow', 'Glasgow', '', 39.2272500, -92.8465800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133970, 'Glendale', 'Glendale', 'Glendejl,Глендейл', 38.5958900, -90.3770600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133971, 'Goodman', 'Goodman', 'Erie Station,Goodman,New Erie,Wade', 36.7417400, -94.3991100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133972, 'Gower', 'Gower', '', 39.6108300, -94.5994000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133973, 'Grain Valley', 'Grain Valley', '', 39.0150100, -94.1985600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133974, 'Granby', 'Granby', '', 36.9192300, -94.2552200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133975, 'Grandview', 'Grandview', 'GVW,Grandview', 38.8858400, -94.5330100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133976, 'Gray Summit', 'Gray Summit', 'Gray Summit,Grays Gap,Grays Summit,Point Labaddie,Port William', 38.4897800, -90.8168000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133977, 'Green Park', 'Green Park', '', 38.5236600, -90.3384500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133978, 'Greenfield', 'Greenfield', 'Grinfild,Гринфилд', 37.4153200, -93.8410400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133979, 'Greenville', 'Greenville', 'Grinvill,Гринвилл', 37.1272700, -90.4501100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133980, 'Greenwood', 'Greenwood', '', 38.8516800, -94.3438400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133981, 'Hallsville', 'Hallsville', '', 39.1169900, -92.2207400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133982, 'Hamilton', 'Hamilton', 'Gamil''ton,Гамильтон', 39.7436200, -93.9982700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133983, 'Hanley Hills', 'Hanley Hills', '', 38.6858800, -90.3237300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133984, 'Hannibal', 'Hannibal', 'Gannibal,Hannibal,Khanibal,Khannibal,North Hannibal,South Hannibal,Staveley''s Landing,Stavelys Landing,han''nibaru,hanybal,Ганнибал,Ганнібал,Ханибал,Ханнибал,هانيبال,هانیبال,ハンニバル', 39.7083800, -91.3584800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133985, 'Harrisonville', 'Harrisonville', 'Garrisonvill,Kharisonvil,Kharrisonvill,haryswnfyl  myzwry,Гаррісонвілл,Харисонвил,Харрисонвилл,هاريسونفيل، ميزوري,هریسون‌ویل، میزوری', 38.6533400, -94.3488400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133986, 'Hartville', 'Hartville', 'Khartvil,Khartvill,hartfyl,Хартвил,Хартвилл,هارتفيل', 37.2508800, -92.5104400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133987, 'Hayti', 'Hayti', '', 36.2336800, -89.7495300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133988, 'Hazelwood', 'Hazelwood', 'Khejzelvud,Khejzlvud,hazlwwd,Хейзлвуд,Хејзелвуд,هازلوود,هیزل‌وود، میزوری,ہیزلووڈ، مسوری', 38.7714400, -90.3709500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133989, 'Herculaneum', 'Herculaneum', 'Khehrkulaneum,Kherkjulejnijum,hyrkywlanwm,Херкјулејнијум,Хэркуланеум,هيركيولانوم', 38.2683900, -90.3801200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133990, 'Hermann', 'Hermann', 'Khehrmann,hyrman  myzwry,Хэрманн,هيرمان، ميزوري', 38.7042100, -91.4373800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133991, 'Hermitage', 'Hermitage', '', 37.9414200, -93.3163100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133992, 'Higginsville', 'Higginsville', '', 39.0725100, -93.7171600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133993, 'High Ridge', 'High Ridge', 'High Ridge,Highridge', 38.4589400, -90.5365100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133994, 'Hillsboro', 'Hillsboro', 'Hillsboro,Hillsborough,Khillsboro,Monticello,Хиллсборо', 38.2322800, -90.5629000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133995, 'Hillsdale', 'Hillsdale', '', 38.6833800, -90.2840000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133996, 'Holden', 'Holden', '', 38.7141800, -93.9913300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133997, 'Hollister', 'Hollister', '', 36.6211700, -93.2154600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133998, 'Holts Summit', 'Holts Summit', '', 38.6403200, -92.1224100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(133999, 'Houston', 'Houston', 'Houston,Kh''juston,Mineral Springs City,Хьюстон', 37.3261600, -91.9559900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134000, 'Humansville', 'Humansville', '', 37.7944800, -93.5779800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134001, 'Huntsville', 'Huntsville', 'Khantsvill,Хантсвилл', 39.4405900, -92.5451800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134002, 'Imperial', 'Imperial', 'Imperial,Liberty,West Kimmswick', 38.3697800, -90.3784500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134003, 'Independence', 'Independence', 'Bristol,Indehpendens,Independence,Independens,Independensas,Indipenduns,andybndns,ayndypndns  myzwry,du li cheng,indipendensu,indipendeonseu,Індепенденс,Индепенденс,Индипендънс,Индэпенденс,אינדפנדנס,إنديبندنس,انڈیپینڈینس، مسوری,ایندیپندنس، میزوری,インディペンデンス,独立城,인디펜던스', 39.0911200, -94.4155100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134004, 'Ironton', 'Ironton', 'Ironton,Wilsonville', 37.5972700, -90.6273400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134005, 'Jackson', 'Jackson', 'Dzekson,Dzhehkson,Dzhekson,jaikasana,jakswn,jakuson,jkswn  myzwry,jyksn  mswry,Џексон,Джексон,Джэксон,جاكسون,جکسون، میزوری,جیکسن، مسوری,ਜੈਕਸਨ,ジャクソン', 37.3822700, -89.6662100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134006, 'Jefferson City', 'Jefferson City', 'City of Jefferson,Dinas Jefferson,Dzeferson Siti,Dzeferson Sitis,Dzefersonsitija,Dzhefersun Siti,Dzhefferson Siti,Dzhefferson-Siti,Dzhehfferson Siti,Džeferson Sitis,Džefersonsitija,Gorad Dzhehfersan-Sici,JEF,Jefferson,Jefferson City,Jeffersonurbo,Kota Jefferson,Lungsod ng Jefferson,Tzeferson Siti,gprswn syty,jefasonshiti,jeparcan nakaram,jepeoseunsiti,jepharasana siti,jepharsan-nagaram,jepharsana siti,jfrswn syty,jie fei xun cheng,Τζέφερσον Σίτι,Џеферсон Сити,Горад Джэферсан-Сіці,Джеферсън Сити,Джефферсон Сити,Джефферсон-Сити,Джефферсон-Сіті,Джэфферсон Сити,Ջեֆերսոն Սիթի,גפרסון סיטי,جفرسون سيتي,جفرسون‌سیتی,جیفرسن سٹی,جیفرسن سٹی، مسوری,जेफरसन सिटी,जेफर्सन सिटी,जेफर्सन सिति,जेफर्सन्-नगरम्,ஜெபர்சன் நகரம்,ジェファーソンシティ,杰斐逊城,제퍼슨시티', 38.5767000, -92.1735200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134007, 'Jennings', 'Jennings', 'Dogtown,Dzenings,Dzhehnnings,Jennings,jnyngz  myzwry,jynynghz,Џенингс,Джэннингс,جنینگز، میزوری,جينينغز', 38.7192200, -90.2603900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134008, 'Joplin', 'Joplin', 'Dzhoplin,Dzoplin,JLN,Joplin,Union City,gwplyn,japlyn  myzwry,jopurin,jwbln,jwpln  mswry,Џоплин,Джоплин,גופלין,جاپلین، میزوری,جوبلن,جوپلن، مسوری,ジョプリン', 37.0842300, -94.5132800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134009, 'Kansas City', 'Kansas City', 'Caasimada Kansas,City of Kansas,Dinas Kansas,Gorad Kanzas-Sici,Greenwood,Ilu Kansas,Kansas City,Kansas City i Missouri,Kansas Lakanbalen,Kansas Sity,Kansasurbo,Kanzas Shehiri,Kanzas Siti,Kanzas Sitis,Kanzas-Siti,Kanzassitija,Kota Kansas,Lungsod ng Kansas,MKC,Maple Gardens,Milton,Moscow,Town of Kansas,Westport,Winnetonka,Winnwood,kaenjaseusiti,kan sa si cheng,kanasasa siti,kansas syty,kanzasushiti,kanzas‌syty  myzwry,kencas nakaram,kensasa siti,kʼanzas-sitʼi,qnzs syty,Ìlú Kansas,Κάνσας Σίτυ,Горад Канзас-Сіці,Канзас Сити,Канзас-Сити,Канзас-Сіті,Կանզաս Սիթի,קנזס סיטי,كانساس سيتي,کانزاس‌سیتی، میزوری,کنساس شہر، مسوری,कॅन्सस सिटी,কানসাস সিটি,கேன்சஸ் நகரம்,แคนซัสซิตี,კანზას-სიტი,カンザスシティ,堪薩斯城,캔자스시티', 39.0997300, -94.5785700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134010, 'Kearney', 'Kearney', 'Centerville,Kearney,Kerni,Керни', 39.3677800, -94.3621700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134011, 'Kennett', 'Kennett', 'Butler,KNT,Kehnnett,Kenit,Kennett,Kennett''s,knt  myzwry,kynyt,Кенит,Кэннетт,كينيت,کنت، میزوری', 36.2361800, -90.0556500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134012, 'Keytesville', 'Keytesville', 'Kehjtesvill,ji si wei er,kitesubiru,kytyzfyl,Кэйтесвилл,كيتيزفيل,キーテスビル,基斯维尔', 39.4344700, -92.9382500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134013, 'Kimberling City', 'Kimberling City', '', 36.6334000, -93.4168500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134014, 'Kingston', 'Kingston', 'Kingston,Кингстон', 39.6441700, -94.0385500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134015, 'Kirkwood', 'Kirkwood', 'Kirkvud,Kirkvuda,ke ke wu de,kyrkwwd,Кирквуд,Кирквуда,كيركوود,کرکووڈ، مسوری,کرک‌وود، میزوری,柯克伍德', 38.5833900, -90.4067800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134016, 'Kissee Mills', 'Kissee Mills', '', 36.6836700, -93.0499000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134017, 'Knob Noster', 'Knob Noster', 'Knob Noster,Knobnoster', 38.7666800, -93.5585500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134018, 'La Monte', 'La Monte', 'La Monte,Lamonte', 38.7741800, -93.4252100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134019, 'Ladue', 'Ladue', 'Ladue,Ladue Village,ladyw,لاديو,لاڈوی، مسوری', 38.6497700, -90.3806700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134020, 'Lake Lotawana', 'Lake Lotawana', '', 38.9230600, -94.2441100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134021, 'Lake Ozark', 'Lake Ozark', 'Lake Ozark,Lakeside', 38.1986400, -92.6388000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134022, 'Lake Saint Louis', 'Lake Saint Louis', '', 38.7975500, -90.7856800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134023, 'Lake Winnebago', 'Lake Winnebago', '', 38.8314000, -94.3585600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134024, 'Lakeshire', 'Lakeshire', '', 38.5386600, -90.3351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134025, 'Lamar', 'Lamar', 'Lamar,la ma er,lamar,lamar  mswry,lamar  myzwry,Ламар,لامار,لامار، مسوری,لامار، میزوری,拉马尔', 37.4950500, -94.2766100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134026, 'Lathrop', 'Lathrop', '', 39.5483400, -94.3299500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134027, 'Lawson', 'Lawson', '', 39.4383400, -94.2041100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134028, 'Leadwood', 'Leadwood', 'Hoffman,Leadwood,Owl Creek,Owlcreek', 37.8672700, -90.5931800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134029, 'Lebanon', 'Lebanon', 'Lebanon,Lehbanon,lbann  myzwry,lybanwn,Лебанон,Лэбанон,لبانن، میزوری,ليبانون', 37.6806000, -92.6637900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134030, 'Lee''s Summit', 'Lee''s Summit', 'Lee''s Summit,Lee’s Summit,Lis Samit,Lis Sammit,Strother,lyz samyt  myzwry,Лис Самит,Лис Саммит,ليز ساميت، ميزوري,リーズ・サミット', 38.9108400, -94.3821700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134031, 'Lemay', 'Lemay', 'Le May,Lemay,Luxemburg', 38.5333900, -90.2792800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134032, 'Lexington', 'Lexington', 'Leksington,Leksingtun,lksynghtwn,Лексингтон,Лексингтън,لكسينغتون,لیکسنگٹن، مسوری', 39.1847300, -93.8799400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134033, 'Liberty', 'Liberty', 'Libehrti,Liberti,Liberty,White Hall Fields,lybrty,lybrty  myzwry,Либерти,Либэрти,لبرٹی، مسوری,ليبرتي,لیبرتی، میزوری', 39.2461100, -94.4191200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134034, 'Licking', 'Licking', 'Licking,The Lick', 37.4994900, -91.8571000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134035, 'Lilbourn', 'Lilbourn', 'Lilbourn,Pawpaw', 36.5922800, -89.6153600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134036, 'Lincoln', 'Lincoln', 'Linkol''n,Линкольн', 38.3908600, -93.3346500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134037, 'Linneus', 'Linneus', 'Linneus,Linnville,Linville', 39.8786300, -93.1888200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134038, 'Lone Jack', 'Lone Jack', 'Lone Jack,Lonejack', 38.8708400, -94.1738300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134039, 'Louisiana', 'Louisiana', 'Louisiana,Louisianaville,Luiziana,Luizijana,lwyzyana,Луизиана,Луизијана,لويزيانا', 39.4489400, -91.0515300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134040, 'Macon', 'Macon', 'Macon,Macon City,Makon,Mehkon,Mejkon,mei ken,mykwn,mykwn  myswry,Макон,Мејкон,Мэкон,ميكون,میکون، میسوری,梅肯', 39.7422600, -92.4726900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134041, 'Malden', 'Malden', 'MAW', 36.5570000, -89.9664800, 'US', '2017-06-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134042, 'Manchester', 'Manchester', 'Manchester,Манчестер', 38.5970000, -90.5092900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134043, 'Mansfield', 'Mansfield', 'Mehnsfild,Мэнсфилд', 37.1067200, -92.5807200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134044, 'Maplewood', 'Maplewood', '', 38.6125500, -90.3245600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134045, 'Marble Hill', 'Marble Hill', 'Dallas,Greene,Marble Hill,New California', 37.3058900, -89.9703800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134046, 'Marceline', 'Marceline', '', 39.7119700, -92.9482500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134047, 'Marionville', 'Marionville', '', 37.0031100, -93.6374200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134048, 'Marlborough', 'Marlborough', 'Marlboro,Марлборо', 38.5703300, -90.3370600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134049, 'Marshall', 'Marshall', 'MHL,Marshal,Marshall,marshal,marshal  myzwry,marshl  mswry,Маршал,Маршалл,مارشال,مارشال، میزوری,مارشل، مسوری', 39.1230800, -93.1968700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134050, 'Marshfield', 'Marshfield', 'Marshfijld,Marshfild,masipildeu,Маршфийлд,Маршфилд,마시필드', 37.3386600, -92.9071200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134051, 'Marthasville', 'Marthasville', '', 38.6283800, -91.0576400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134052, 'Maryland Heights', 'Maryland Heights', 'Maryland Heights,Maryland Heights Station,Mehrilehnd Khehjts,Meriland Khajts,mrylnd hayts  myzwry,Мериланд Хајтс,Мэрилэнд Хэйтс,مریلند هایتس، میزوری,میری لینڈ ہائٹس، مسوری', 38.7131100, -90.4298400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134053, 'Maysville', 'Maysville', '', 39.8891700, -94.3619000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134054, 'Mehlville', 'Mehlville', '', 38.5083900, -90.3228900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134055, 'Merriam Woods', 'Merriam Woods', '', 36.7139500, -93.1618500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134056, 'Mexico', 'Mexico', 'Meksiko,Mexico,New Mexico,mksykw,mkzykw  myzwry,mo xi ge,myksykw  mswry,Мексико,مكسيكو,مکزیکو، میزوری,میکسیکو، مسوری,墨西哥', 39.1697600, -91.8829500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134057, 'Moberly', 'Moberly', 'Magic City,Mobehrli,Moberli,Moberly,mwbrly,mwbrly  myzwry,Моберли,Мобэрли,موبرلي,موبرلی، میزوری', 39.4183700, -92.4382400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134058, 'Moline Acres', 'Moline Acres', 'Moline Acres,Moline Heights', 38.7469900, -90.2401100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134059, 'Monett', 'Monett', 'Forest Park,Monett,Plymouth Junction', 36.9289500, -93.9277100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134060, 'Monroe City', 'Monroe City', 'Monroe,Monroe City', 39.6536500, -91.7346100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134061, 'Montgomery City', 'Montgomery City', 'Montgomery,Montgomery City', 38.9775400, -91.5048800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134062, 'Moscow Mills', 'Moscow Mills', 'Moscow,Moscow Mills,Moscow on the Cuivre', 38.9478300, -90.9181900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134063, 'Mount Vernon', 'Mount Vernon', '', 37.1036700, -93.8185400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134064, 'Mountain Grove', 'Mountain Grove', 'Fyan,Mountain Grove', 37.1306100, -92.2634900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134065, 'Mountain View', 'Mountain View', 'Campbell Town,Mauntin-V''ju,Mountain View,Маунтин-Вью', 36.9953300, -91.7037600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134066, 'Murphy', 'Murphy', '', 38.4903300, -90.4870700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134067, 'Neosho', 'Neosho', 'EOS,Niosho,Nisho,nywshw  myzwry,Ниошо,Нишо,نیوشو، میزوری', 36.8689600, -94.3680000, 'US', '2017-06-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134068, 'Nevada', 'Nevada', 'Hog Eye,NVD,Nevada,Nevada City,Невада', 37.8392100, -94.3546700, 'US', '2017-07-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134069, 'New Franklin', 'New Franklin', '', 39.0172500, -92.7374100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134070, 'New Haven', 'New Haven', 'Baltimore,Blish Mill,Blish Mills,Millers Bend,Millers Landing,Millers Station,Millersburg,N''ju-Khejven,New Haven,Newhaven,Нью-Хейвен', 38.6083800, -91.2190400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134071, 'New London', 'New London', 'N''ju-London,Нью-Лондон', 39.5853200, -91.4009800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134072, 'New Madrid', 'New Madrid', 'N''ju Madrid,New Madrid,Nju Madrid,Nouveau Madrid,Nova Madrid,Nueva Madrid,Њу Мадрид,Нью Мадрид,نیو میڈرڈ، مسوری', 36.5864500, -89.5278500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134073, 'Nixa', 'Nixa', 'Niksa,nyksa  myzwry,Никса,نیکسا، میزوری', 37.0433900, -93.2943500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134074, 'Noel', 'Noel', '', 36.5456300, -94.4852200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134075, 'Normandy', 'Normandy', 'Normandi,Норманди', 38.7208800, -90.2973400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134076, 'North Kansas City', 'North Kansas City', 'Nors Kanzas Siti,Nort Kansas Siti,North Kansas City,Норс Канзас Сити,Норт Кансас Сити', 39.1300000, -94.5621800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134077, 'Northwoods', 'Northwoods', 'Norsvuds,Nortvuds,Норсвудс,Нортвудс', 38.7042200, -90.2834500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134078, 'O''Fallon', 'O''Fallon', 'O''Fallon,O''Fallon Station', 38.8106100, -90.6998500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134079, 'Oak Grove', 'Oak Grove', 'Lickskillet,Oak Grove', 39.0050100, -94.1293900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134080, 'Oakland', 'Oakland', 'Oakland,Oakland Station,Oklend,Окленд', 38.5764400, -90.3856700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134081, 'Oakville', 'Oakville', '', 38.4700500, -90.3045600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134082, 'Odessa', 'Odessa', 'Odessa,Одесса', 38.9991700, -93.9535600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134083, 'Olivette', 'Olivette', '', 38.6653300, -90.3759500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134084, 'Oran', 'Oran', 'Oran,Saint Cloud', 37.0850500, -89.6553600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134085, 'Oregon', 'Oregon', 'Finley,Oregon,Орегон', 39.9869400, -95.1449800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134086, 'Oronogo', 'Oronogo', 'Center Creek,Leadville Hollow,Minersville,Oronogo', 37.1883900, -94.4702300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134087, 'Osage Beach', 'Osage Beach', 'OSB,Osage Beach,Zebra', 38.1295600, -92.6527700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134088, 'Osceola', 'Osceola', 'Crossing of the Osage at Crow and Crutchfield,Crow and Crutchfield,Osceola', 38.0467000, -93.7043800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134089, 'Overland', 'Overland', '', 38.7011600, -90.3623400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134090, 'Owensville', 'Owensville', '', 38.3456000, -91.5015500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134091, 'Ozark', 'Ozark', 'Ozark,awzark,awzark  myzwry,Озарк,أوزارك,اوزارک، میزوری', 37.0208900, -93.2060200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134092, 'Pacific', 'Pacific', 'Franklin,Pacific,Pasifik,Пасифик', 38.4820000, -90.7415200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134093, 'Pagedale', 'Pagedale', 'MIdland,Midland Heights,Pagedale,Pehjdzhdehjl,Pejdzdejl,Пејџдејл,Пэйдждэйл', 38.6833800, -90.3076100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134094, 'Palmyra', 'Palmyra', 'Athens of Missouri,Battle of Athens State Park,City of Flowers,Pal''mira,Palmajra,Palmira,Palmyra,Springfield,palmyra  myzwry,Палмајра,Палмира,Пальмира,پالمیرا، میزوری', 39.7942100, -91.5232100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134095, 'Paris', 'Paris', 'Parizh,Париж', 39.4808700, -92.0012800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134096, 'Park Hills', 'Park Hills', '', 37.8542200, -90.5181800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134097, 'Parkville', 'Parkville', 'Englishs Landing,Parkville', 39.1950000, -94.6821800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134098, 'Peculiar', 'Peculiar', '', 38.7191800, -94.4585600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134099, 'Perryville', 'Perryville', 'Pehrrivill,Perivil,peribiru,Перивил,Пэрривилл,ペリービル', 37.7242200, -89.8612200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134100, 'Pevely', 'Pevely', '', 38.2833900, -90.3951200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134101, 'Piedmont', 'Piedmont', 'Danielsville,Piedmont', 37.1544900, -90.6956700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134102, 'Pierce City', 'Pierce City', 'Peirce City,Pierce City', 36.9459000, -94.0002100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134103, 'Pine Lawn', 'Pine Lawn', 'Goodfellow Terrace,Pajn Laun,Pajn Lon,Pine Lawn,Pinelawn,Пайн Лаун,Пајн Лон', 38.6958800, -90.2751100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134104, 'Pineville', 'Pineville', 'Marysville,Maryville,Pineville', 36.5945200, -94.3841000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134105, 'Platte City', 'Platte City', 'Martinsville,Platte,Platte City,Platte Falls', 39.3702800, -94.7824600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134106, 'Plattsburg', 'Plattsburg', 'Concord,Plattsburg,Springfield', 39.5655500, -94.4480100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134107, 'Pleasant Hill', 'Pleasant Hill', '', 38.7875100, -94.2693900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134108, 'Pleasant Valley', 'Pleasant Valley', 'Pleasant Valley,Ravena Gardens', 39.2163900, -94.4841200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134109, 'Poplar Bluff', 'Poplar Bluff', 'Ashcroft Addition,Bluff City,East Poplar Bluff,Kelley Town,POF,Poplar Blaf,Poplar Blaff,Poplar Bluff,The Bluff,Vinegar Hill,paplr blwf  myzwry,Поплар Блаф,Поплар Блафф,پاپلر بلوف، میزوری', 36.7570000, -90.3928900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134110, 'Portageville', 'Portageville', '', 36.4253400, -89.6995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134111, 'Potosi', 'Potosi', 'Mine-a-Breton,Potosi,Потоси', 37.9364400, -90.7879100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134112, 'Purdy', 'Purdy', 'Purdy,Winslow', 36.8172900, -93.9207600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134113, 'Raymore', 'Raymore', '', 38.8019500, -94.4527300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134114, 'Raytown', 'Raytown', 'Ray,Raytown,Rehjtaun,Rejtaun,Рејтаун,Рэйтаун,ری‌تاون، میزوری,رے ٹاؤن، مسوری', 39.0086200, -94.4635600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134115, 'Republic', 'Republic', 'Repablik,rybablk,rypablyk  myzwry,rypblk  mswry,Репаблик,ريبابلك,ریپابلیک، میزوری,ریپبلک، مسوری', 37.1200500, -93.4801900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134116, 'Rich Hill', 'Rich Hill', '', 38.0964200, -94.3610600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134117, 'Richland', 'Richland', 'Richland,Richlend,Ричланд,Ричленд', 37.8569800, -92.4043400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134118, 'Richmond', 'Richmond', 'Richmond,Ричмонд', 39.2786200, -93.9768900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134119, 'Richmond Heights', 'Richmond Heights', '', 38.6286600, -90.3195600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134120, 'Riverside', 'Riverside', 'Illinois,Riverside', 38.2867200, -90.3801200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134121, 'Riverside', 'Riverside', 'Riversajd,Риверсайд', 39.1775000, -94.6130100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134122, 'Riverview', 'Riverview', '', 38.2758600, -93.0696400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134123, 'Riverview', 'Riverview', 'Riverview,Riverview Gardens', 38.7478300, -90.2115000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134124, 'Rock Hill', 'Rock Hill', '', 38.6075500, -90.3784500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134125, 'Rogersville', 'Rogersville', 'Rodgersville,Rogersville', 37.1170000, -93.0557300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134126, 'Rolla', 'Rolla', 'RLA,Rola,Rolla,Weber,luo la,rwla,rwla  myzwry,Рола,Ролла,رولا,رولا، میزوری,罗拉', 37.9514300, -91.7712700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134127, 'Saint Ann', 'Saint Ann', 'Mary Ridge,Saint Ann,Sent-Ehnn,Сент-Энн', 38.7272700, -90.3831700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134128, 'Saint Charles', 'Saint Charles', 'City of Saint Charles,Las Pequenas Cuestas,Le Village de Cotes,Le Village du Cote,Les Petites Cotes,Petit Cotes,Saint Andrew,Saint Charles,Saint Charles City,San Carlos del Missouri,San Carlos del Misuri,San Fernando,Sehjnt Charlz,Sent Charls,Sent-Charl''z,St. Charles,sent chal s,snt charlz  myzwry,Сент Чарлс,Сент-Чарльз,Сэйнт Чарлз,سنت چارلز، میزوری,เซนต์ชาลส์', 38.7839400, -90.4812300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134129, 'Saint Clair', 'Saint Clair', 'Saint Clair,The Ridge,Travelers Repose,Travellers Repose', 38.3453300, -90.9809700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134130, 'Saint George', 'Saint George', '', 38.5367200, -90.3148400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134131, 'Saint James', 'Saint James', 'Big Prairie,Saint James,Sent-Dzhejms,Сент-Джеймс', 37.9972600, -91.6143200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134132, 'Saint John', 'Saint John', '', 38.7148400, -90.3462700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134133, 'Saint Johns', 'Saint Johns', 'Home Heights,Home Station,Saint Johm,Saint John,Saint Johns,Saint Johns Station', 38.7133800, -90.3431700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134134, 'Saint Joseph', 'Saint Joseph', 'Robidoux Landing,STJ,Saint Joseph,Sankta Jozefo,Sejnt Dzhouzef,Sent DZozef,Sent Dzhozef,Sent-Dzhozef,South Saint Joseph,St. Joseph,seinteujojipeu,snt jwzf  myzwry,Сейнт Джоузеф,Сент Џозеф,Сент Джозеф,Сент-Джозеф,سنت جوزف، میزوری,세인트조지프', 39.7686100, -94.8466300, 'US', '2017-07-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134135, 'St. Louis', 'St. Louis', 'City of Saint Louis,Gorad Sent-Luis,Lacledes Village,Mound City,Pain Court,Pancore,STL,Saint Lewis,Saint Louis,Saint Louis City,Saint-Louis,San Luis,Sankta Luiso,Sejnt Luis,Sent Loisos,Sent Luis,Sent Luisas,Sent-Luis,Sentluisa,Sint-Louis,St Louis,St. Louis,Urbs Sancti Ludovici,ceyint luyis,saint luyis,sant lwys,seinteulu-iseu,senta lu''isa,senthluys,sentoruisu,seyint luyis,sheng lu yi si,snt lwyys,Σαιντ Λούις,Горад Сент-Луіс,Сейнт Луис,Сент Луис,Сент-Луис,Сент-Луїс,סנט לואיס,سانت لويس,سنت لوئیس,سینٹ لوئس,सेंट लुईस,செயின்ட் லூயிஸ்,సెయింట్ లూయిస్,ಸೈಂಟ್ ಲೂಯಿಸ್,เซนต์หลุยส์,სენტ-ლუისი,セントルイス,圣路易斯,세인트루이스', 38.6272700, -90.1978900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134136, 'Saint Martins', 'Saint Martins', 'Saint Martin,Saint Martins', 38.5942000, -92.3371300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134137, 'Saint Paul', 'Saint Paul', '', 38.8614400, -90.7417900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134138, 'Saint Peters', 'Saint Peters', 'City of Saint Peters,Sankt-Peterbu,Санкт-Петербу', 38.8003300, -90.6265100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134139, 'Saint Robert', 'Saint Robert', '', 37.8281000, -92.1776700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134140, 'Sainte Genevieve', 'Sainte Genevieve', 'Misere,Saint Genevieve,Sainte Genevieve,Santa Genoveva,St. Genevieve,Town of Saint Jude Acres', 37.9814400, -90.0417800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134141, 'Salem', 'Salem', 'Salem,Sejlem,Салем,Сейлем,Сејлем', 37.6456000, -91.5359800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134142, 'Salisbury', 'Salisbury', '', 39.4239200, -92.8015800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134143, 'Sappington', 'Sappington', '', 38.5370000, -90.3798400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134144, 'Sarcoxie', 'Sarcoxie', 'Centerville,Sarcoxie', 37.0692300, -94.1166000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134145, 'Savannah', 'Savannah', 'Savana,Savanna,Савана,Саванна', 39.9416600, -94.8302500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134146, 'Scott City', 'Scott City', 'Ancell,Fornfelt,Scott City', 37.2167200, -89.5245300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134147, 'Sedalia', 'Sedalia', 'DMO,Sedalia,Seoville,Sidejlija,sdalya  myzwry,sydalya,Седалиа,Сидејлија,سدالیا، میزوری,سيداليا', 38.7044600, -93.2282600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134148, 'Senath', 'Senath', '', 36.1342300, -90.1598200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134149, 'Seneca', 'Seneca', '', 36.8414600, -94.6110600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134150, 'Seymour', 'Seymour', 'Ketcher,Seymour', 37.1464400, -92.7687800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134151, 'Shelbina', 'Shelbina', '', 39.6939300, -92.0429500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134152, 'Shelbyville', 'Shelbyville', '', 39.8058700, -92.0415600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134153, 'Shell Knob', 'Shell Knob', '', 36.6322900, -93.6343600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134154, 'Shrewsbury', 'Shrewsbury', 'Shrjusbjuri,Shrouzberi,Shrusberi,shrwzbry,Шроузбери,Шрусбери,Шрюсбюри,شروزبري', 38.5903300, -90.3367800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134155, 'Sikeston', 'Sikeston', 'SIK,Sajkston,sai ke si dun,saykstwn  myzwry,Сайкстон,Сајкстон,سایکستون، میزوری,赛克斯顿', 36.8767200, -89.5878600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134156, 'Slater', 'Slater', '', 39.2180800, -93.0690900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134157, 'Smithville', 'Smithville', 'Smiths Mill,Smithville', 39.3869400, -94.5810700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134158, 'Spanish Lake', 'Spanish Lake', 'Rich Valley,Spanish Lake', 38.7878300, -90.2159400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134159, 'Sparta', 'Sparta', '', 37.0011600, -93.0815700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134160, 'Springfield', 'Springfield', 'North Springfield,SGF,Springfield,Springfijld,Springfild,aspryngfyld  myzwry,sbrynghfyld,seupeulingpildeu,si pu lin fei er de,spryngpyld,supuringufirudo,Спрингфийлд,Спрингфилд,Спрингфілд,ספרינגפילד,اسپرینگفیلد، میزوری,سبرينغفيلد,سپرنگفیلڈ، مسوری,スプリングフィールド,斯普林菲尔德,스프링필드', 37.2153300, -93.2982400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134161, 'Steele', 'Steele', '', 36.0839600, -89.8292500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134162, 'Steelville', 'Steelville', '', 37.9681000, -91.3548700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134163, 'Stockton', 'Stockton', 'Fremont,Lancaster,Stockton,Stoktun,Стоктън', 37.6989300, -93.7960400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134164, 'Stover', 'Stover', 'Newstover,Stover', 38.4408600, -92.9918700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134165, 'Strafford', 'Strafford', 'Stafford,Strafford,Stratford', 37.2683800, -93.1171300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134166, 'Sugar Creek', 'Sugar Creek', '', 39.1097300, -94.4446700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134167, 'Sullivan', 'Sullivan', 'Mount Helicon,Salivan,Sullivan,Sullivans Station,Саливан,Сулливан', 38.2081000, -91.1604200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134168, 'Sunset Hills', 'Sunset Hills', '', 38.5389400, -90.4073400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134169, 'Sweet Springs', 'Sweet Springs', 'Brownsville,Sweet Springs', 38.9636300, -93.4149300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134170, 'Taos', 'Taos', 'Blocktown,Taos', 38.5064300, -92.0710100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134171, 'Terre du Lac', 'Terre du Lac', 'Terre Du Lac,Terre du Lac', 37.9117200, -90.6254100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134172, 'Thayer', 'Thayer', 'Augusta,Thayer', 36.5245100, -91.5382000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134173, 'Tipton', 'Tipton', '', 38.6555800, -92.7799200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134174, 'Town and Country', 'Town and Country', 'Taun ehnd Kauntri,Taun end Kantri,tawn and kantry  myzwry,tawn and kawntry,Таун енд Кантри,Таун энд Каунтри,تاون أند كاونتري,تاون اند کانتری، میزوری,ٹاؤن اینڈ کنٹری، مسوری', 38.6122800, -90.4634500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134175, 'Troy', 'Troy', 'Troj,Troja,trwy,trwy  myzwry,Трой,Троя,Трој,تروي,تروی، میزوری,ٹرائے، مسوری', 38.9794900, -90.9807000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134176, 'Tuscumbia', 'Tuscumbia', '', 38.2330900, -92.4585200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134177, 'Union', 'Union', 'Union,Union City', 38.4500500, -91.0084800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134178, 'University City', 'University City', '', 38.6558800, -90.3092800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134179, 'Valley Park', 'Valley Park', 'Meramec,Nasby,Vali Park,Vallehj Park,Valley Park,Valleypark,faly bark,wly park  myzwry,wyly park  mswry,Вали Парк,Валлэй Парк,فالي بارك,ولی پارک، میزوری,ویلی پارک، مسوری', 38.5492200, -90.4926200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134180, 'Van Buren', 'Van Buren', 'Van Bjuren,fan bwrn,wn bwrn  myzwry,Ван Бюрен,Ван Бјурен,فان بورن,ون بورن، میزوری', 36.9956100, -91.0145700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134181, 'Vandalia', 'Vandalia', '', 39.3108700, -91.4884900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134182, 'Velda Village', 'Velda Village', 'Velda,Velda City,Velda Village', 38.6900500, -90.2942800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134183, 'Velda Village Hills', 'Velda Village Hills', '', 38.6906100, -90.2873400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134184, 'Versailles', 'Versailles', 'VRS,Versailles', 38.4314100, -92.8410300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134185, 'Vienna', 'Vienna', '', 38.1867100, -91.9471100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134186, 'Vinita Park', 'Vinita Park', 'Vanita Park,Vinita Park', 38.6900500, -90.3426200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134187, 'Wardsville', 'Wardsville', '', 38.4889200, -92.1743500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134188, 'Warrensburg', 'Warrensburg', 'Varrehnsburg,Vorensburg,warnsbwrgh,warnzbrg  myzwry,Варрэнсбург,Воренсбург,وارنزبرگ، میزوری,وارنسبورغ', 38.7627900, -93.7360500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134189, 'Warrenton', 'Warrenton', '', 38.8114400, -91.1415400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134190, 'Warsaw', 'Warsaw', 'Uarsav,Vorso,Ворсо,Уарсав', 38.2430800, -93.3818700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134191, 'Warson Woods', 'Warson Woods', 'Royal Oak,Warson Woods', 38.6072700, -90.3834500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134192, 'Washington', 'Washington', 'Bassora,Goosetown,New Washington,Owensville,Vashington,Washington,Washington Landing,washntn,washyngtn  myzwry,Вашингтон,واشنطن,واشنگٹن، مسوری,واشینگتن، میزوری', 38.5581100, -91.0120900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134193, 'Waynesville', 'Waynesville', 'Vehjnesvill,Vejnsvil,Вејнсвил,Вэйнесвилл', 37.8286500, -92.2007200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134194, 'Weatherby Lake', 'Weatherby Lake', '', 39.2377800, -94.6960700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134195, 'Webb City', 'Webb City', 'Veb Siti,Vehbb Siti,wb syty  myzwry,wyb syty,Веб Сити,Вэбб Сити,وب سیتی، میزوری,ويب سيتي', 37.1464500, -94.4630000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134196, 'Webster Groves', 'Webster Groves', 'Vebster Grouvs,Webster,Webster Groves,wbstr grwwz  myzwry,wybstr ghrwfz,Вебстер Гроувс,وبستر گرووز، میزوری,ويبستر غروفز', 38.5925500, -90.3573400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134197, 'Weldon Spring', 'Weldon Spring', 'Weldon Spring,Weldon Springs', 38.7133900, -90.6892900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134198, 'Wellston', 'Wellston', 'Rinkelville,Wellston', 38.6728300, -90.2992800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134199, 'Wellsville', 'Wellsville', '', 39.0719800, -91.5701600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134200, 'Wentzville', 'Wentzville', 'Vehntsvill,Ventzvil,wntzfyl,wyntzwyl  myzwry,Вентзвил,Вэнтсвилл,ونتزفيل,وینتزویل، میزوری,وینٹزویل، مسوری', 38.8114400, -90.8529100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134201, 'West Plains', 'West Plains', 'Summers Addition,Vehst Plehjns,Vest Plejns,West Plains,Westplains,wst plynz  myzwry,Вест Плејнс,Вэст Плэйнс,وست پلینز، میزوری', 36.7281200, -91.8523700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134202, 'Weston', 'Weston', 'Uehston,Уэстон', 39.4111100, -94.9016300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134203, 'Wildwood', 'Wildwood', 'Vajldvud,Vildvud,wayldwwd,wayldwwd  myzwry,Вајлдвуд,Вилдвуд,وائلڈووڈ، مسوری,وايلدوود,وایلدوود، میزوری', 38.5828300, -90.6629000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134204, 'Willard', 'Willard', 'Robertson,Willard', 37.3050500, -93.4285300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134205, 'Willow Springs', 'Willow Springs', '', 36.9922800, -91.9698700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134206, 'Winchester', 'Winchester', '', 38.5903300, -90.5279000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134207, 'Windsor', 'Windsor', 'Belmont,Spring Grove,Vindzor,Windsor,Виндзор', 38.5322400, -93.5221500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134208, 'Winfield', 'Winfield', '', 38.9972700, -90.7384600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134209, 'Winona', 'Winona', 'Vajnona,Вайнона', 37.0097700, -91.3234700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134210, 'Woodson Terrace', 'Woodson Terrace', '', 38.7250500, -90.3584500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134211, 'Wright City', 'Wright City', 'Wright,Wright City,Wrights City', 38.8275500, -91.0201400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134212, 'Aberdeen', 'Aberdeen', 'Aberdeen,Aberdin,Dundee,New Aberdeen,a bo ding,abrdyn,abrdyn  mysysypy,aebeodin,Абердин,أبردين,ابردین، میسیسیپی,ایبرڈین، مسیسپی,阿伯丁,애버딘', 33.8251100, -88.5436600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134213, 'Ackerman', 'Ackerman', '', 33.3101200, -89.1728400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134214, 'Amory', 'Amory', 'Amori,Ejmori,amwry,amwry  msyspy,aymry  mysysypy,eimoli,Амори,Ејмори,أموري,اموری، مسیسپی,ایمری، میسیسیپی,에이모리', 33.9842800, -88.4881000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134215, 'Arnold Line', 'Arnold Line', '', 31.3351700, -89.3734000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134216, 'Ashland', 'Ashland', '', 34.8328700, -89.1759000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134217, 'Baldwyn', 'Baldwyn', '', 34.5095400, -88.6353300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134218, 'Batesville', 'Batesville', 'Batesville,Behjtesvill,Bejtsvil,Bejtsvil'',Bejtsvill,Panola,btswyl  mysysypy,bytsfyl,Бейтсвилл,Бейтсвіль,Бејтсвил,Бэйтесвилл,بتسویل، میسیسیپی,بيتسفيل,بیٹسویل، مسیسپی', 34.3115000, -89.9442600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134219, 'Bay Saint Louis', 'Bay Saint Louis', 'Bay Saint Louis,Bay St. Louis,Chicapoula,Shieldsboro', 30.3088100, -89.3300500, 'US', '2013-07-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134220, 'Bay Springs', 'Bay Springs', 'Bay Springs,Bayspring,Behj Springs,Bej Springs,bay sbrynghz,by aspryngz  mysysypy,Беј Спрингс,Бэй Спрингс,باي سبرينغز,بی اسپرینگز، میسیسیپی,بے سپرنگز، مسیسپی', 31.9790400, -89.2872800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134221, 'Beechwood', 'Beechwood', '', 32.3276500, -90.8267700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134222, 'Belmont', 'Belmont', 'Belmont,Belmont Mill,Belmont Springs', 31.5687700, -88.4839100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134223, 'Belmont', 'Belmont', 'Belmont,Gum Springs,Белмонт', 34.5098200, -88.2092100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134224, 'Belzoni', 'Belzoni', 'Bel''zoni,Belzona,Belzoni,Fisks Landing,blzwny,blzwny  mysysypy,bylzwny  msyspy,Белзони,Бельзони,بلزوني,بلزونی، میسیسیپی,بیلزونی، مسیسپی', 33.1842900, -90.4892600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134225, 'Biloxi', 'Biloxi', 'Biloksi,Biloxi,bi luo ke xi,billeogsi,birokushi,bylaksy  mysysypy,bylwksy,bylwksy  msyspy,Билокси,Білоксі,بيلوكسي,بیلاکسی، میسیسیپی,بیلوکسی، مسیسپی,ビロクシ,比洛克西,빌럭시', 30.3960300, -88.8853100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134226, 'Booneville', 'Booneville', 'Boones Camp,Booneville,Bunvil,Buunevill'',Cross Ridge,bwnfyl,bwnwyl  msyspy,bwnwyl  mysysypy,Бунвил,Бууневилль,بونفيل,بونویل، مسیسپی,بونویل، میسیسیپی', 34.6581500, -88.5667200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134227, 'Brandon', 'Brandon', 'Brandon,Brehndon,brandwn,brndn  mysysypy,Брандон,Брэндон,براندون,برندن، میسیسیپی,برینڈن، مسیسپی', 32.2732000, -89.9859200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134228, 'Brookhaven', 'Brookhaven', 'Brukkhehven,Brukkhejven,brwkhafn,brwkhywn  mysysypy,Брукхејвен,Брукхэвен,بروكهافن,بروکهیون، میسیسیپی,بروکہیون، مسیسپی', 31.5790600, -90.4406500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134229, 'Brooksville', 'Brooksville', 'Brooksville,Brookville', 33.2345700, -88.5822700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134230, 'Bruce', 'Bruce', '', 33.9920600, -89.3489600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134231, 'Bude', 'Bude', '', 31.4629500, -90.8501000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134232, 'Byhalia', 'Byhalia', 'Bajkhalija,Bikhalia,bai hei li ya,byhalya,byhalya  mysysypy,Байхалия,Бихалиа,بيهاليا,بیهالیا، میسیسیپی,拜黑利亚', 34.8723200, -89.6906400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134233, 'Byram', 'Byram', '', 32.1793200, -90.2453700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134234, 'Caledonia', 'Caledonia', 'Kaledonija,Каледония', 33.6828900, -88.3244800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134235, 'Calhoun City', 'Calhoun City', 'Burkett,Calhoun City', 33.8553900, -89.3114600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134236, 'Canton', 'Canton', '', 32.6126400, -90.0367500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134237, 'Carriere', 'Carriere', 'Carriere,Carriere Station,Highland,Lacey', 30.6168600, -89.6525600, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134238, 'Carrollton', 'Carrollton', 'Karolton,Karrollton,karwltwn,krltn  mysysypy,Каролтон,Карроллтон,كارولتون,کرلتن، میسیسیپی,کیرولٹن، مسیسپی', 33.5081800, -89.9203600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134239, 'Carthage', 'Carthage', 'Carthage,Kartehjdzh,Kartidz,Leakille,kartyj  mysysypy,qrtaj,Картиџ,Картэйдж,قرطاج,کارتھیج، مسیسپی,کارتیج، میسیسیپی', 32.7326400, -89.5361800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134240, 'Centreville', 'Centreville', 'Centerville,Centreville,Sentervil,Sentrvill,sntrfyl,sntrwyl  mysysypy,Сентервил,Сентрвилл,سنترفيل,سنترویل، میسیسیپی', 31.0896200, -91.0684400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134241, 'Charleston', 'Charleston', 'Charl''ston,Charlston,charlztwn  mysysypy,tsharlstwn,Чарлстон,Чарльстон,تشارلستون,چارلزتون، میسیسیپی,چارلسٹن، مسیسپی', 34.0067800, -90.0567600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134242, 'Clarksdale', 'Clarksdale', 'CKM,Clarksdale,Clarksville,Diamond of the Delta,Golden Buckle of the Cotton Belt,Klarksdehjl,Klarksdejl,Little New York,klarksdyl,klarksdyl  mysysypy,kurakusuderu,Кларксдејл,Кларксдэйл,كلاركسديل,کلارکسدیل، میسیسیپی,کلارکسڈیل، مسیسپی,クラークスデール', 34.2001100, -90.5709300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134243, 'Cleary', 'Cleary', '', 32.1654300, -90.1806400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134244, 'Cleveland', 'Cleveland', 'Cleveland,Coleman,Coleman Station,Fontaine,Kleveland,Klivland,Klivlend,Sims,klyfland,klywlnd  mysysypy,Клевеланд,Кливланд,Кливленд,كليفلاند,کلیولند، میسیسیپی,کلیولینڈ، مسیسپی', 33.7440000, -90.7248200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134245, 'Clinton', 'Clinton', 'Clinton,Klinton,Mount Dexter,Mount Salus,klyntn  mysysypy,klyntwn,Клинтон,كلينتون,کلنٹن، مسیسپی,کلینتن، میسیسیپی', 32.3415300, -90.3217600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134246, 'Coldwater', 'Coldwater', 'Coldwater,Darden Ridge', 32.7148600, -89.2142300, 'US', '2010-02-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134247, 'Coldwater', 'Coldwater', 'Cold Water,Coldwater,Coldwater Depot', 34.6917700, -89.9773100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134248, 'Collins', 'Collins', 'Collins,Kolins,Kollins,Williamsburg Depot,kalynz  mysysypy,kwlnz  msyspy,kwlynz,Колинс,Коллинс,كولينز,کالینز، میسیسیپی,کولنز، مسیسپی', 31.6454400, -89.5553500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134249, 'Collinsville', 'Collinsville', 'Kollinsvil'',Коллинсвиль', 32.4979200, -88.8458800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134250, 'Columbus', 'Columbus', 'Columbus,Kolambus,Kolumbus,Kulumbus,Possum Town,UBS,ge lun bu,klmbws  mysysypy,kwlmbs  msyspy,kwlwmbws,Коламбус,Колумбус,Кълъмбъс,كولومبوس,کلمبوس، میسیسیپی,کولمبس، مسیسپی,哥伦布', 33.4956700, -88.4272600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134251, 'Columbia', 'Columbia', 'Columbia,Kolambija,Kolumbia,Kolumbija,Lotts Bluff,klmbya  mysysypy,kwlmbya  msyspy,kwlwmbya,Коламбија,Колумбиа,Колумбия,كولومبيا,کلمبیا، میسیسیپی,کولمبیا، مسیسپی', 31.2518400, -89.8375800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134252, 'Como', 'Como', 'Como,Como Depot,Komo,kwmw,kwmw  mysysypy,Комо,كومو,کومو، میسیسیپی', 34.5106600, -89.9398100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134253, 'Conehatta', 'Conehatta', 'Centreville,Conehatta', 32.4512500, -89.2853400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134254, 'Corinth', 'Corinth', 'CRX,Corinth,Cross City,Korinf,Korint,krynt  mysysypy,kwrynth,Коринт,Коринф,كورينث,کرینت، میسیسیپی,کورنتھ، مسیسپی', 34.9342500, -88.5222700, 'US', '2017-04-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134255, 'Crystal Springs', 'Crystal Springs', 'Crystal,Crystal Springs,Kristal Springs,krystal aspryngz  mysysypy,krystal sbrynghz,Кристал Спрингс,كريستال سبرينغز,کرسٹل سپرنگز، مسیسپی,کریستال اسپرینگز، میسیسیپی', 31.9873800, -90.3570400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134256, 'D''Iberville', 'D''Iberville', 'D''Iberville,Diberville,Seymour', 30.4263100, -88.8908600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134257, 'De Kalb', 'De Kalb', 'De Kalb,DeKalb', 32.7676300, -88.6508800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134258, 'De Lisle', 'De Lisle', 'De Lisle,Wolftown', 30.3793600, -89.2644900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134259, 'Decatur', 'Decatur', 'Dekejter,Декейтер', 32.4390300, -89.1083900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134260, 'Derma', 'Derma', '', 33.8556700, -89.2845200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134261, 'Diamondhead', 'Diamondhead', '', 30.3946400, -89.3639400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134262, 'Drew', 'Drew', 'Drju,Dru,drw,drw  mysysypy,Дру,Дрю,درو,درو، میسیسیپی,ڈریو، مسیسپی', 33.8095600, -90.5264800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134263, 'Duck Hill', 'Duck Hill', 'Duck Hill,Duckhill', 33.6331800, -89.7111900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134264, 'Durant', 'Durant', '', 33.0751300, -89.8545300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134265, 'Edwards', 'Edwards', 'Edwards,Edwards Depot,Liverpool', 32.3301500, -90.6056500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134266, 'Ellisville', 'Ellisville', 'Ehllisvil,Elisvil,Ellisville,Ellisville Depot,Leesburg,alsfyl,alyzwyl  mysysypy,aylswyl  msyspy,Елисвил,Эллисвил,إلسفيل,الیزویل، میسیسیپی,ایلسویل، مسیسپی', 31.6040500, -89.1956100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134267, 'Escatawpa', 'Escatawpa', '', 30.4404800, -88.5436300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134268, 'Eupora', 'Eupora', 'Early Grove,Eupora', 33.5406800, -89.2670100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134269, 'Farmington', 'Farmington', 'Farmington,Фармингтон', 34.9300900, -88.4522700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134270, 'Fayette', 'Fayette', 'Fajette,Fejet,fayt,fayt  mysysypy,Файетте,Фејет,فائیٹ، مسیسپی,فايت,فایت، میسیسیپی', 31.7115500, -91.0606600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134271, 'Flora', 'Flora', '', 32.5432000, -90.3092600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134272, 'Florence', 'Florence', 'Florence,Florencija,Steens Creek,Флоренция', 32.1534800, -90.1312000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134273, 'Flowood', 'Flowood', '', 32.3095900, -90.1389800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134274, 'Forest', 'Forest', '', 32.3645900, -89.4742300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134275, 'Friars Point', 'Friars Point', 'Frajers Pojnt,Friar Point,Friar''s Point,Friars Point,Friars Pojnt,Union,frayr pwynt  mysysypy,fryrz bwynt,Фрајерс Појнт,Фриарс Пойнт,فرایر پوینت، میسیسیپی,فريرز بوينت', 34.3667700, -90.6376000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134276, 'Fulton', 'Fulton', 'Fulton,fwltn  mysysypy,fwltwn,Фултон,فلٹن، مسیسپی,فولتن، میسیسیپی,فولتون', 34.2739900, -88.4092100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134277, 'Gautier', 'Gautier', 'Gautier,Got''e,Got''er,Gotijej,West Pascagoula,ghwtyr,gwwtyy  mysysypy,Готијеј,Готье,Готьер,غوتير,گاوٹیر، مسیسپی,گووتیی، میسیسیپی', 30.3857500, -88.6116900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134278, 'Glendale', 'Glendale', 'Glendale,Hickory Grove', 31.3646200, -89.3061700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134279, 'Goodman', 'Goodman', '', 32.9701300, -89.9123100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134280, 'Greenville', 'Greenville', 'GLH,Grinvil,Grinvill,ghrynfyl,grynwyl  msyspy,grynwyl  mysysypy,Гринвил,Гринвилл,غرينفيل,گرینویل، مسیسپی,گرینویل، میسیسیپی', 33.4101200, -91.0617700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134281, 'Greenwood', 'Greenwood', 'GWO,Greenwood,Grijnud,Grinvud,Williams Landing,ghrynwwd,grynwwd  mysysypy,Грийнуд,Гринвуд,غرينوود,گرینوود، میسیسیپی,گرینووڈ، مسیسپی', 33.5162300, -90.1795300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134282, 'Grenada', 'Grenada', 'Grenada,Grenejda,Pittsburg,Tullahoma,ghrynada,grynyda  mysysypy,Гренада,Гренејда,غرينادا,گریناڈا، مسیسپی,گرینیدا، میسیسیپی', 33.7690000, -89.8084200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134283, 'Gulf Hills', 'Gulf Hills', '', 30.4304800, -88.8422500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134284, 'Gulf Park Estates', 'Gulf Park Estates', '', 30.3918700, -88.7611400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134285, 'Gulfport', 'Gulfport', 'GPT,Galfport,Galfporta,Gulfport,galfpwrt  mysysypy,garufupoto,ge er fu bo te,ghwlfbwrt,Галфпорт,Галфпорта,Гулфпорт,Гълфпорт,Ґалфпорт,غولفبورت,گالفپورت، میسیسیپی,گلف پورٹ، مسیسپی,ガルフポート,格尔夫波特', 30.3674200, -89.0928200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134286, 'Guntown', 'Guntown', '', 34.4431600, -88.6597800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134287, 'Hattiesburg', 'Hattiesburg', 'Gordonville,HBG,Hattiesburg,Hattiesburgh,Hub City,Khatisberg,Khattisberg,The Hub,Twin Forks,ha di si bao,haetijeubeogeu,hattizubagu,hatysbwrgh,htyzbrg  mysysypy,Хатисберг,Хаттисберг,هاتيسبورغ,هتیزبرگ، میسیسیپی,ہیٹیسبرگ، مسیسپی,ハッティズバーグ,哈蒂斯堡,해티즈버그', 31.3271200, -89.2903400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134288, 'Hazlehurst', 'Hazlehurst', 'Khazlzurst,Khejzelkherst,Khejzulkhurst,hazlhwrst,hyzlhwrst  mysysypy,Хазлзурст,Хейзълхърст,Хејзелхерст,هازلهورست,هیزلهورست، میسیسیپی,ہیزلہرسٹ، مسیسپی', 31.8604400, -90.3959300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134289, 'Helena', 'Helena', 'Khelena,Хелена', 30.4946400, -88.4958500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134290, 'Hernando', 'Hernando', 'Hernando,Jefferson,Khernando,hrnandw  mysysypy,hyrnandw,Хернандо,هرناندو، میسیسیپی,هيرناندو,ہرنینڈو، مسیسپی', 34.8239900, -89.9937000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134291, 'Hickory Hills', 'Hickory Hills', '', 30.4568700, -88.6391900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134292, 'Hillsboro', 'Hillsboro', 'Hillsboro,Hillsborough', 32.4593100, -89.5114600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134293, 'Hollandale', 'Hollandale', 'Kholandejl,Khollandehjl,hwlndyl,hwlndyl  mysysypy,Холандејл,Холландэйл,هولنديل,هولندیل، میسیسیپی,ہولنڈیل، مسیسپی', 33.1690100, -90.8539900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134294, 'Holly Springs', 'Holly Springs', '', 31.3157300, -89.9778600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134295, 'Holly Springs', 'Holly Springs', 'Holly Springs,Kholi Springs,Kholli Springs,Suavatooky,haly aspryngz,hwly sbrynghz,Холи Спрингс,Холли Спрингс,هالی اسپرینگز,هولي سبرينغز,ہالی سپرنگز، مسیسپی', 34.7676000, -89.4486900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134296, 'Horn Lake', 'Horn Lake', '', 34.9553700, -90.0348100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134297, 'Houston', 'Houston', 'Kh''juston,Khauston,hywstn,hywstn  mysysypy,Хаустон,Хьюстон,هيوستن,هیوستن، میسیسیپی,ہیوسٹن، مسیسپی', 33.8984500, -88.9992300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134298, 'Hurley', 'Hurley', '', 30.6610300, -88.4941800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134299, 'Indianola', 'Indianola', 'Belegante,Eureka,Indian Bayou,Indianola,Indijanola,andyanwla,ayndyanwwla  mysysypy,yin di an nuo la,Индианола,Индијанола,إنديانولا,انڈینولا، مسیسپی,ایندیانوولا، میسیسیپی,印第安诺拉', 33.4509500, -90.6550900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134300, 'Itta Bena', 'Itta Bena', 'Ita Bena,Itta Bena,Ittabena,ayta bna  mysysypy,ayta byna,Ита Бена,Итта Бена,إيتا بينا,اٹا بینا، مسیسپی,ایتا بنا، میسیسیپی', 33.4951200, -90.3198100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134301, 'Iuka', 'Iuka', 'Ajuka,Greshams Mills,Iuka,aywka,aywka  mysysypy,ayywka  msyspy,iuka,Ајука,آئیوکا، مسیسپی,إيوكا,ایوکا، میسیسیپی,イウカ', 34.8117600, -88.1900400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134302, 'Jackson', 'Jackson', 'Dzekson,Dzeksona,Dzeksonas,Dzeksons,Dzhaksun,Dzhekson,Džeksona,Džeksonas,Džeksons,Gorad Dzhehksan,JAN,Jackson,Jackson i Mississippi,Le Fleurs Bluff,Siti of Dzhekson,Tzakson,Zhehkson,gqswn,jaegseun,jakcan,jaksan,jakswn,jakuson,jeksana,jie ke xun,jkswn  mysysypy,jyakasana,jyaksana,jyksn,jyksn  msyspy,Τζάκσον,Џексон,Горад Джэксан,Джаксън,Джексон,Жэксон,Сити оф Джексон,Ջեքսոն,גקסון,جاكسون,جکسون، میسیسیپی,جیکسن,جیکسن، مسیسپی,जाक्सन्,जॅक्सन,ज्याकसन,ज्याक्सन,ஜாக்சன்,ジャクソン,杰克逊,잭슨', 32.2987600, -90.1848100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134303, 'Jonestown', 'Jonestown', 'Jonestown,Swan Lake', 34.3195500, -90.4556500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134304, 'Kearney Park', 'Kearney Park', '', 32.5890300, -90.3153700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134305, 'Kiln', 'Kiln', '', 30.4090800, -89.4350500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134306, 'Kosciusko', 'Kosciusko', 'Attala,Cosciusco,Kosciusko,Kosijasko,Kosk''jusko,OSX,Paris,Parrish,Peakedend,Peking,Perish,Red Bud Springs,kaskywskww  mysysypy,kwsyaskw  msyspy,kwsywskw,Косијаско,Коскьюско,كوسيوسكو,کاسکیوسکوو، میسیسیپی,کوسیاسکو، مسیسپی', 33.0580000, -89.5895600, 'US', '2017-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134307, 'Lambert', 'Lambert', 'Lambert,O''Neal Switch', 34.2017800, -90.2834300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134308, 'Latimer', 'Latimer', '', 30.5346400, -88.8667000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134309, 'Laurel', 'Laurel', 'LUL,Laurel,Lawurell,Lorel,larl  mysysypy,loleol,lwrl  msyspy,Лаурел,Лорел,لارل، میسیسیپی,لورل، مسیسپی,로럴', 31.6940500, -89.1306100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134310, 'Leakesville', 'Leakesville', '', 31.1557400, -88.5578000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134311, 'Leland', 'Leland', 'Leland,Liland,Snowden,lyland,lylnd  mysysypy,Леланд,Лиланд,ليلاند,لیلند، میسیسیپی,لیلینڈ، مسیسپی', 33.4053900, -90.8976000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134312, 'Lexington', 'Lexington', 'Leksington,lkzyngtn  mysysypy,lyksynghtwn,Лексингтон,ليكسينغتون,لکزینگتن، میسیسیپی,لیکسنگٹن، مسیسپی', 33.1131800, -90.0531400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134313, 'Liberty', 'Liberty', 'Liberti,li bo di,lybrty,lybrty  mysysypy,Либерти,ليبرتي,لیبرتی، میسیسیپی,利伯蒂', 31.1582300, -90.8123200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134314, 'Long Beach', 'Long Beach', 'Long Beach,Long Bich,Long-Bich,Scotts Station,lang bych  msyspy,lang bych  mysysypy,lwngh bytsh,Лонг Бич,Лонг-Бич,لانگ بیچ، مسیسپی,لانگ بیچ، میسیسیپی,لونغ بيتش', 30.3504800, -89.1528200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134315, 'Louisville', 'Louisville', 'LMS,Luisvil,Lujsvill,lwyyzwyl  msyspy,lwyyzwyl  mysysypy,lwyzfyl,Луисвил,Луйсвилл,لوئیزویل، مسیسپی,لوئیزویل، میسیسیپی,لويزفيل', 33.1237400, -89.0550600, 'US', '2017-06-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134316, 'Lucedale', 'Lucedale', 'Ljukedehjl,Lusdejl,lwsydyl,lwsydyl  mysysypy,Лусдејл,Люкедэйл,لوسيديل,لوسڈیل، مسیسپی,لوسیدیل، میسیسیپی', 30.9251900, -88.5900200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134317, 'Lumberton', 'Lumberton', '', 31.0012900, -89.4522900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134318, 'Lyman', 'Lyman', '', 30.4947400, -89.1256100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134319, 'Lynchburg', 'Lynchburg', '', 34.9623200, -90.0959300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134320, 'Lynchburg', 'Lynchburg', '', 32.4401400, -90.5489900, 'US', '2010-02-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134321, 'Macon', 'Macon', 'Makon,Mehkon,Mejkon,makwn,mei ken,mykn  mysysypy,mykwn  msysypy,Макон,Мејкон,Мэкон,ماكون,میکن، میسیسیپی,میکون، مسیسیپی,梅肯', 33.1054000, -88.5608800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134322, 'Madison', 'Madison', 'DXE,Madison,Madison Station,Medison,Mehdison,madyswn,mdsn  mysysypy,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مدسن، میسیسیپی,میڈیسون، مسیسیپی', 32.4618100, -90.1153600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134323, 'Magee', 'Magee', 'Magee,Magi,Mangum,Mehgi,maghy,mgy  mysysypy,mygy  msyspy,Маги,Мэги,ماغي,مگی، میسیسیپی,میگی، مسیسپی', 31.8737700, -89.7336900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134324, 'Magnolia', 'Magnolia', 'Magnolia,Magnolija,maghnwlya,mgnwlya  mysysypy,mygnwlya  msyspy,Магнолиа,Магнолија,ماغنوليا,مگنولیا، میسیسیپی,میگنولیا، مسیسپی', 31.1432300, -90.4587100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134325, 'Mantachie', 'Mantachie', 'Mantachie,Mataches', 34.3242700, -88.4911600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134326, 'Marion', 'Marion', 'Marion,Marion Station,Mehrion,Мэрион', 32.4173600, -88.6478200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134327, 'Marks', 'Marks', 'Marks,Riverside,ma ke si,mark  mysysypy,marks,marks  msyspy,Маркс,ماركس,مارک، میسیسیپی,مارکس، مسیسپی,马克斯', 34.2568300, -90.2729800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134328, 'Mayersville', 'Mayersville', 'Gibson,Gibsons Landing,Mayersville,Mount Level,Wadelawn', 32.9020700, -91.0512200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134329, 'McComb', 'McComb', 'MakKomb,Makom,maekom,mai ku mu,makwmb,mk kwmb  msyspy,МакКомб,Маком,ماكومب,مک کومب، مسیسپی,مک‌کام، میسیسیپی,麦库姆,매콤', 31.2437900, -90.4531500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134330, 'Meadville', 'Meadville', '', 31.4723900, -90.8967700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134331, 'Mendenhall', 'Mendenhall', 'Edna,Mendenhall', 31.9618200, -89.8700800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134332, 'Meridian', 'Meridian', 'MEI,Meridian,Meridijan,Ragsdale City,Sowashee Station,meolidieon,meridian,mrydyan  mysysypy,myrydyan,Меридиан,Меридијан,مریدیان، میسیسیپی,ميريديان,میریڈیئن، مسیسپی,メリディアン,머리디언', 32.3643100, -88.7036600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134333, 'Metcalfe', 'Metcalfe', 'Metcalfe,Wilczinski', 33.4540000, -91.0073300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134334, 'Mikoma', 'Mikoma', 'Mikoma,Omar', 33.9503900, -90.2839800, 'US', '2012-07-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134335, 'Monticello', 'Monticello', 'Montikehllo,Montiselo,mantyslw  mysysypy,meng di sai luo,mwntayslw,Монтикэлло,Монтисело,مانتیسلو، میسیسیپی,مونتايسلو,蒙蒂塞洛', 31.5537800, -90.1073100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134336, 'Moorhead', 'Moorhead', '', 33.4501200, -90.5056400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134337, 'Morgantown', 'Morgantown', '', 31.5726700, -91.3476100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134338, 'Morton', 'Morton', '', 32.3537600, -89.6545200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134339, 'Moss Point', 'Moss Point', 'Mos Pojnt,Moss Pojnt,mas pwynt  mysysypy,mws bwynt,Мос Појнт,Мосс Пойнт,ماس پوائنٹ، مسیسپی,ماس پوینت، میسیسیپی,موس بوينت', 30.4115900, -88.5344600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134340, 'Mound Bayou', 'Mound Bayou', 'Maund Baju,Mound Baju,mawnd bayw  mysysypy,mwnd bayw,Маунд Бају,Моунд Баю,ماؤنڈ بائیو، مسیسپی,ماوند بایو، میسیسیپی,موند بايو', 33.8781700, -90.7273200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134341, 'Natchez', 'Natchez', 'Fort Panmure,Fort Rosalie,HEZ,Naches,Nachez,Natches,Natchez,na qi ci,nachezu,natshyz,nchyz  mysysypy,nchz  msyspy,Натчез,Начез,ناتشيز,نچز، مسیسپی,نچیز، میسیسیپی,ナチェズ,纳奇兹', 31.5604400, -91.4031700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134342, 'Nellieburg', 'Nellieburg', '', 32.4068100, -88.7772700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134343, 'Nettleton', 'Nettleton', '', 34.0890000, -88.6222700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134344, 'New Albany', 'New Albany', 'N''ju Albani,N''ju-Albani,Nju Olbani,nyw albany,nyw albany  msyspy,nyw albany  mysysypy,xin ao er ba ni,Њу Олбани,Нью Албани,Нью-Албани,Ню Олбани,نيو ألباني,نیو آلبانی، میسیسیپی,نیو البانی، مسیسپی,新奥尔巴尼', 34.4942700, -89.0078400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134345, 'New Augusta', 'New Augusta', '', 31.2026300, -89.0366800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134346, 'New Hope', 'New Hope', '', 33.4681700, -88.3267000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134347, 'Newton', 'Newton', 'N''juton,Newton,Newton Depot,Ньютон', 32.3212600, -89.1633900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134348, 'Nicholson', 'Nicholson', 'Crescent City,Nicholson', 30.4771400, -89.6936700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134349, 'North Tunica', 'North Tunica', '', 34.7009300, -90.3781500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134350, 'Ocean Springs', 'Ocean Springs', 'Ocean Springs,Old Biloxi,Oshan Springs,Oushen Springs,Vieux Biloxi,awshn aspryngz  mysysypy,awshn sbrynghz,awshn sprngz  msyspy,hai quan shi,Оушен Спрингс,Ошан Спрингс,أوشن سبرينغز,اوشن اسپرینگز، میسیسیپی,اوشن سپرنگز، مسیسپی,海泉市', 30.4113100, -88.8278100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134351, 'Okolona', 'Okolona', 'Okolona,Rose Hill,akwlwna  mysysypy,awkwlwna,awkwlwna  msyspy,Околона,أوكولونا,اوکولونا، مسیسپی,اکولونا، میسیسیپی', 34.0017800, -88.7553300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134352, 'Olive Branch', 'Olive Branch', 'OLV,Oliv Branch,Oliv Brehnch,alyw brnch  mysysypy,awlyf bransh,awlyw branch  msyspy,Олив Бранч,Олив Брэнч,أوليف برانش,الیو برنچ، میسیسیپی,اولیو برانچ، مسیسپی', 34.9617600, -89.8295300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134353, 'Oxford', 'Oxford', 'Oksford,UOX,aksfwrd,aksfwrd  mysysypy,niu jin,ogseupeodeu,Оксфорд,آکسفورد، میسیسیپی,آکسفورڈ، مسیسپی,أكسفورد,牛津,옥스퍼드', 34.3665000, -89.5192500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134354, 'Pascagoula', 'Pascagoula', 'PGL,Paskagula,baskaghwla,pa si ka gu la,paskagwla  msyspy,pasukagura,pskgwla  mysysypy,Паскагула,Паскаґула,باسكاغولا,پاسکاگولا، مسیسپی,پسکگولا، میسیسیپی,パスカグーラ,帕斯卡古拉', 30.3657600, -88.5561300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134355, 'Pass Christian', 'Pass Christian', 'Pas Krischan,Pass Christian,Pass Krishtian,Scranton,bas krystyan,pas krschyn  msyspy,ps krystyn  mysysypy,Пас Крисчан,Пасс Криштиан,باس كريستيان,پاس کرسچین، مسیسپی,پس کریستین، میسیسیپی', 30.3157500, -89.2475400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134356, 'Pearl', 'Pearl', 'Perl,byarl,prl  msyspy,prl  mysysypy,Перл,بيارل,پرل، مسیسپی,پرل، میسیسیپی', 32.2745900, -90.1320300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134357, 'Pearl River', 'Pearl River', '', 32.7834700, -89.2278400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134358, 'Pearlington', 'Pearlington', 'Little Jerusalem,Pearlington', 30.2465800, -89.6111700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134359, 'Pelahatchie', 'Pelahatchie', 'Pelahatchee,Pelahatches,Pelahatchie', 32.3129200, -89.7984100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134360, 'Petal', 'Petal', '', 31.3465600, -89.2600600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134361, 'Philadelphia', 'Philadelphia', 'Filadel''fija,Filadelfia,Filadelfija,fyladlfya,fyladlfya  mysysypy,Филаделфија,Филадельфия,فلاڈیلفیا، مسیسپی,فيلادلفيا,فیلادلفیا، میسیسیپی', 32.7715200, -89.1167300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134362, 'Picayune', 'Picayune', 'PCU,Picayune,Pickayune,Pikajun,Pikijun,bykaywn,pykaywn  msyspy,pykywn  mysysypy,Пикаюн,Пикијун,بيكايون,پیکایون، مسیسپی,پیکیون، میسیسیپی', 30.5255600, -89.6778800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134363, 'Pickens', 'Pickens', 'Boles Ferry,Montgomery,Pickens,Pickens Station,Shiloh', 32.8837400, -89.9714700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134364, 'Pittsboro', 'Pittsboro', 'Orrsville,Pittsboro,Pittsborough', 33.9403900, -89.3375700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134365, 'Plantersville', 'Plantersville', '', 34.2134400, -88.6645000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134366, 'Pontotoc', 'Pontotoc', 'Pontotoc,Pontotock,Pontotok,bwntwtwk,pantwtwk  mysysypy,Понтоток,بونتوتوك,پانتوتوک، میسیسیپی,پونٹوٹاک، مسیسپی', 34.2478800, -88.9986700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134367, 'Poplarville', 'Poplarville', '', 30.8401900, -89.5342300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134368, 'Port Gibson', 'Port Gibson', 'Fort Gibson,Gibsons Landing,Gibsons Port,Port Gibson,Port-Gibson,bwrt jybswn,pwrt gybsn  mysysypy,Порт Гибсон,Порт-Гибсон,Порт-Ґібсон,بورت جيبسون,پورت گیبسن، میسیسیپی,پورٹ گبسن، مسیسپی', 31.9609900, -90.9839900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134369, 'Prentiss', 'Prentiss', 'Blountville,Prentiss', 31.5985000, -89.8670200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134370, 'Purvis', 'Purvis', 'Purvis,bwrfys,prwys  mysysypy,pwrwys  msyspy,Пурвис,بورفيس,پرویس، میسیسیپی,پورویس، مسیسپی', 31.1432400, -89.4097900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134371, 'Quitman', 'Quitman', 'Kuitman,Kvitman,kwytman,kwytmn  mysysypy,Квитман,Куитман,كويتمان,کوئٹمین، مسیسپی,کویتمن، میسیسیپی', 32.0401500, -88.7281000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134372, 'Raleigh', 'Raleigh', 'Indian Springs,Raleigh,Roli,Роли', 32.0334900, -89.5222900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134373, 'Rawls Springs', 'Rawls Springs', 'Rawles Springs,Rawls Springs', 31.3807300, -89.3714500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134374, 'Raymond', 'Raymond', 'Rehjmond,Rejmond,rymwnd,rymwnd  mysysypy,Рејмонд,Рэймонд,ريموند,ریمنڈ، مسیسپی,ریموند، میسیسیپی', 32.2593100, -90.4226000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134375, 'Richland', 'Richland', 'Lakeland,Plain,Plainview,Richland,Richlend,Ричленд', 32.2390400, -90.1584200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134376, 'Richton', 'Richton', '', 31.3493400, -88.9400500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134377, 'Ridgeland', 'Ridgeland', 'Highland Colony,Ridgeland,Ridzhland,Ridzland,rydjland,ryjlnd  mysysypy,Риджланд,Риџланд,ريدجلاند,ریجلند، میسیسیپی,ریجلینڈ، مسیسپی', 32.4284800, -90.1323100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134378, 'Ripley', 'Ripley', 'Riplej,Ripli,li pu li,rply  msyspy,rybly,ryply  mysysypy,Риплей,Рипли,ريبلي,رپلی، مسیسپی,ریپلی، میسیسیپی,里普利', 34.7298200, -88.9506200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134379, 'Rolling Fork', 'Rolling Fork', 'Head of Rolling Fork,RFK,Rolling Fork', 32.9065200, -90.8781600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134380, 'Ruleville', 'Ruleville', 'Rulevill,Rulvil,rwlfyl,rwlwyl  msyspy,rwlwyl  mysysypy,Рулвил,Рулевилл,رولفيل,رولویل، مسیسپی,رولویل، میسیسیپی', 33.7259500, -90.5514800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134381, 'Saltillo', 'Saltillo', '', 34.3764900, -88.6817200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134382, 'Sardis', 'Sardis', 'Bellmont,Belmont,Danville,Sardis,asardys  mysysypy,sards,Сардис,اساردیس، میسیسیپی,ساردس', 34.4370500, -89.9159200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134383, 'Saucier', 'Saucier', '', 30.6357500, -89.1350400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134384, 'Senatobia', 'Senatobia', 'Senatobia,Senatobija,Sennatoba,snatwbya  mysysypy,synatwbya,Сенатобиа,Сенатобија,سناتوبیا، میسیسیپی,سيناتوبيا,سیناٹوبیا، مسیسپی', 34.6176000, -89.9687000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134385, 'Shannon', 'Shannon', '', 34.1162200, -88.7117200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134386, 'Sharon', 'Sharon', '', 31.7896000, -89.0986700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134387, 'Shelby', 'Shelby', 'Bellevue,Bellevue Plantation,Shelby', 33.9509400, -90.7678800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134388, 'Southaven', 'Southaven', 'Sautaven,Southhaven,Soutkhehven,sausuheibun,sawthywn  mysysypy,Саутавен,Соутхэвен,ساؤتھایون، مسیسپی,ساوتهیون، میسیسیپی,サウスヘイブン', 34.9889800, -90.0125900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134389, 'Saint Martin', 'Saint Martin', '', 30.4379800, -88.8680900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134390, 'Starkville', 'Starkville', 'Boardtown,Starkvil,Starkville,astarkwyl  mysysypy,seutagbil,si ta ke wei er,starkfyl,Старквил,استارکویل، میسیسیپی,ستاركفيل,سٹارکویل، مسیسپی,斯塔克維爾,스탁빌', 33.4504900, -88.8196100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134391, 'Stonewall', 'Stonewall', 'Newtown,Stonewall,Stonewall Station', 32.1318100, -88.7933800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134392, 'Summit', 'Summit', '', 31.2837900, -90.4684300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134393, 'Sumrall', 'Sumrall', '', 31.4173900, -89.5422900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134394, 'Sunflower', 'Sunflower', 'Sunflower,Sunflower City', 33.5429000, -90.5370300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134395, 'Taylorsville', 'Taylorsville', 'Taylorsville,Taylorville', 31.8296000, -89.4281200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134396, 'Tchula', 'Tchula', '', 33.1829000, -90.2228600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134397, 'Terry', 'Terry', '', 32.0962600, -90.2942600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134398, 'Tunica', 'Tunica', 'Tunica,Tunika,UTM,twnyka,twnyka  mysysypy,Туника,تونيكا,تونیکا، میسیسیپی,ٹونیکا، مسیسپی', 34.6845500, -90.3828800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134399, 'Tupelo', 'Tupelo', 'Gum Pond,TUP,Tjupulou,Tupelo,te~yupero,tu po luo,tupeollo,twbylw,twplww  mysysypy,Тупело,Тюпълоу,توبيلو,توپلوو، میسیسیپی,ٹوپولو، مسیسپی,テューペロ,图珀洛,투펄로', 34.2580700, -88.7046400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134400, 'Tutwiler', 'Tutwiler', '', 34.0148300, -90.4317600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134401, 'Tylertown', 'Tylertown', 'Magees Creek,Tyler Town,Tylers Mill,Tylertown', 31.1160100, -90.1420300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134402, 'Union', 'Union', '', 32.5715300, -89.1214500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134403, 'University', 'University', '', 34.3659400, -89.5253600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134404, 'Vancleave', 'Vancleave', 'Bluff Creek,Van Cleave,Vancleave', 30.5404700, -88.6875200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134405, 'Vardaman', 'Vardaman', 'Ticky Bin,Timberville,Vardaman', 33.8756700, -89.1772900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134406, 'Verona', 'Verona', '', 34.1942700, -88.7197700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134407, 'Vicksburg', 'Vicksburg', 'Fort McHenry,Fort Nogales,Nogales,VKS,Vicksburg,Vicksburgh,Vicksburgum,Viksberg,Viksburg,Walnut Hills,bigseubeogeu,fyksbyrgh,vu~ikkusubagu,wei ke si bao,wyksbrg  msyspy,wyksbrg  mysysypy,Виксберг,Виксбург,Виксбърг,Віксбург,فيكسبيرغ,ویکسبرگ، مسیسپی,ویکسبرگ، میسیسیپی,ヴィックスバーグ,维克斯堡,빅스버그', 32.3526500, -90.8778800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134408, 'Wade', 'Wade', '', 30.6424200, -88.5697400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134409, 'Walls', 'Walls', 'Alpika,Walls', 34.9582400, -90.1525600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134410, 'Walnut Grove', 'Walnut Grove', '', 32.5904200, -89.4584000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134411, 'Walthall', 'Walthall', 'Mount Tabor,Walthall', 33.6073400, -89.2772900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134412, 'Water Valley', 'Water Valley', 'Oke Chukma,Water Valley', 34.1515000, -89.6314700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134413, 'Waveland', 'Waveland', 'Uehjvland,Vejvland,wyfland,wywlnd  mysysypy,Вејвланд,Уэйвланд,ويفلاند,ویولند، میسیسیپی,ویولینڈ، مسیسپی', 30.2868600, -89.3761600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134414, 'Waynesboro', 'Waynesboro', 'Uehjnesboro,Vejnsboro,Waynesboro,Waynesborough,waynysbwrw,wynzbwrw  mysysypy,wyynzbwrw  msyspy,Вејнсборо,Уэйнесборо,واينيسبورو,ویئنزبورو، مسیسپی,وینزبورو، میسیسیپی', 31.6748800, -88.6461500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134415, 'Wesson', 'Wesson', 'Vehsson,Veson,Wessen,Wesson,wswn  mysysypy,wyswn,Весон,Вэссон,وسون، میسیسیپی,ويسون', 31.7012800, -90.3975900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134416, 'West Gulfport', 'West Gulfport', '', 30.4040900, -89.0942000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134417, 'West Hattiesburg', 'West Hattiesburg', '', 31.3190600, -89.3750600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134418, 'West Point', 'West Point', 'Robertsons Store,Vest Pojnt,West Point,wst pwynt  mysysypy,wyst bwynt,Вест Пойнт,Вест Појнт,وست پوینت، میسیسیپی,ويست بوينت,ویسٹ پوائنٹ، مسیسپی', 33.6076200, -88.6503300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134419, 'Wiggins', 'Wiggins', 'Niles City,Viggings,Vigins,Wiggins,wyghynz,wygyns  mysysypy,wygynz  msyspy,Виггингс,Вигинс,ويغينز,ویگینز، مسیسپی,ویگینس، میسیسیپی', 30.8582400, -89.1353300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134420, 'Winona', 'Winona', 'Vajnona,wynwna,wynwna  msyspy,wynwna  mysysypy,Вайнона,Вајнона,وينونا,وینونا، مسیسپی,وینونا، میسیسیپی', 33.4820700, -89.7281400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134421, 'Woodville', 'Woodville', 'Vudvil,Vudvill,wwdfyl,wwdwyl  mysysypy,Вудвил,Вудвилл,وودفيل,وودویل، میسیسیپی', 31.1046200, -91.2995600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134422, 'Yazoo City', 'Yazoo City', 'Hanans Bluff,Jazu Siti,Jazuu Siti,Queen City of the Delta,Yazoo City,yazw syty,yazw syty  mysysypy,Јазу Сити,Язуу Сити,يازو سيتي,یازو سیتی، میسیسیپی,یضو سٹی، مسیسپی', 32.8551300, -90.4056500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134423, 'Aberdeen', 'Aberdeen', 'Aberdeen,Aberdin,Blue''s Crossing,Абердин', 35.1315500, -79.4294800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134424, 'Advance', 'Advance', 'Advance,Shady Grove', 35.9412500, -80.4092200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134425, 'Ahoskie', 'Ahoskie', 'Ahoskey,Ahoskie,Ahosky,Ahosky Ridge,Ahostskey,Ahostsky,Akhoski,ahwsky,ahwsky  karwlynay shmaly,Ахоски,أهوسكي,اهوسکی، کارولینای شمالی', 36.2868200, -76.9846800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134426, 'Albemarle', 'Albemarle', 'Albemarde,Albemarl,Albemarle,albmarl  karwlynay shmaly,albymarl,albymarl  shmaly kyrwlayna,arubemaru,Албемарл,ألبيمارل,البمارل، کارولینای شمالی,البیمارل، شمالی کیرولائنا,アルベマール', 35.3501400, -80.2000600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134427, 'Andrews', 'Andrews', 'Andrews,Endruz,Valley Town,andrwz  karwlynay shmaly,Ендруз,اندروز، کارولینای شمالی', 35.2017500, -83.8240700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134428, 'Angier', 'Angier', '', 35.5071000, -78.7391800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134429, 'Apex', 'Apex', 'Apeks,Ejpeks,ai pei ke si,apekkusu,aypks  karwlynay shmaly,aypyks  shmaly kyrwlayna,Апекс,Ејпекс,ایپکس، کارولینای شمالی,ایپیکس، شمالی کیرولائنا,アペックス,埃佩克斯', 35.7326500, -78.8502900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134430, 'Archdale', 'Archdale', 'Archdale,Bush Hill', 35.9145800, -79.9719800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134431, 'Archer Lodge', 'Archer Lodge', 'Archer Lodge,Archers Lodge', 35.6940400, -78.3755600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134432, 'Asheboro', 'Asheboro', 'Ashboro,a shen bo lei,ashbwrw,ashuboro,ashww  karwlynay shmaly,ayshbrw  shmaly kyrwlayna,Ашборо,آشبورو,اشوو، کارولینای شمالی,ایشبرو، شمالی کیرولائنا,アシュボロ,阿什伯勒', 35.7079100, -79.8136400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134433, 'Asheville', 'Asheville', 'AVL,Asheville,Biltmore,Ehshvill,Eshvil,Eshvil'',Kasdu''yi,Keniworth,Montford,Morristown,Ramoth,Sunset Park,Victoria,West Asheville,Woolsey,a shen wei er,aesyubil,ashfyl,ashubiru,ashwyl  karwlynay shmaly,ayshwyl  shmaly kyrwlayna,Ешвил,Ешвіль,Эшвилл,אשוויל,آشفيل,اشویل، کارولینای شمالی,ایشویل، شمالی کیرولائنا,アシュビル,阿什维尔,애슈빌', 35.6009500, -82.5540200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134434, 'Atlantic Beach', 'Atlantic Beach', 'Atlantik Bich,aeteullaentigbichi,atlntyk bych  karwlynay shmaly,Атлантик Бич,اتلنتیک بیچ، کارولینای شمالی,애틀랜틱비치', 34.6990500, -76.7402100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134435, 'Avery Creek', 'Avery Creek', '', 35.4634500, -82.5826200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134436, 'Ayden', 'Ayden', 'Ayden,Harriston', 35.4726600, -77.4155200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134437, 'Badin', 'Badin', 'Baden,Badin', 35.4059700, -80.1167200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134438, 'Bakersville', 'Bakersville', 'Bakersfield,Bakersville,Davis', 36.0156700, -82.1587400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134439, 'Balfour', 'Balfour', '', 35.3465100, -82.4720600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134440, 'Banner Elk', 'Banner Elk', 'Banner Elk,Banners Elk,Shawneehaw', 36.1631800, -81.8715000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134441, 'Barker Heights', 'Barker Heights', '', 35.3112300, -82.4440100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134442, 'Bayboro', 'Bayboro', '', 35.1429400, -76.7702100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134443, 'Bayshore', 'Bayshore', '', 34.2896100, -77.7874800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134444, 'Beaufort', 'Beaufort', 'Beaufort,Bofort,Fishtown,Wareiock,bofoto,bopeoteu,bwfwrt,bwwfrt  karwlynay shmaly,Бофорт,بوفورت,بووفرت، کارولینای شمالی,بیوفورٹ، شمالی کیرولائنا,ボーフォート,보퍼트', 34.7182200, -76.6638200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134445, 'Belhaven', 'Belhaven', '', 35.5401700, -76.6229900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134446, 'Belmont', 'Belmont', 'Belmont,Garibaldi,Garibuldi,blmant  karwlynay shmaly,blmwnt,Белмонт,بلمانت، کارولینای شمالی,بلمونت', 35.2429200, -81.0373000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134447, 'Belville', 'Belville', '', 34.2307300, -77.9658200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134448, 'Benson', 'Benson', '', 35.3821100, -78.5486200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134449, 'Bent Creek', 'Bent Creek', '', 35.5090000, -82.6079000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134450, 'Bermuda Run', 'Bermuda Run', '', 36.0037500, -80.4220000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134451, 'Bessemer City', 'Bessemer City', 'Bessemer City,Crowders Mountain', 35.2848600, -81.2839700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134452, 'Bethel', 'Bethel', '', 35.8071000, -77.3788600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134453, 'Bethlehem', 'Bethlehem', 'Vifleem,Вифлеем', 35.8256900, -81.3070300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134454, 'Beulaville', 'Beulaville', '', 34.9237800, -77.7738700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134455, 'Biltmore Forest', 'Biltmore Forest', '', 35.5337200, -82.5284600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134456, 'Biscoe', 'Biscoe', 'Biscoe,Filo', 35.3598600, -79.7797600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134457, 'Black Mountain', 'Black Mountain', 'Black Mountain,Grey Eagle,Grey Eagle Mountain', 35.6179000, -82.3212300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134458, 'Bladenboro', 'Bladenboro', '', 34.5387800, -78.7875200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134459, 'Blowing Rock', 'Blowing Rock', 'Blouing Rok,blwwyng rak  karwlynay shmaly,Блоуинг Рок,بلووینگ راک، کارولینای شمالی', 36.1351300, -81.6776100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134460, 'Boiling Spring Lakes', 'Boiling Spring Lakes', '', 34.0304500, -78.0672100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134461, 'Boiling Springs', 'Boiling Springs', 'Boiling Springs,Bojling Springs,Metal,bwylyng aspryngz  karwlynay shmaly,bwylyngh sbrynghz,Бојлинг Спрингс,بويلينغ سبرينغز,بویلینگ اسپرینگز، کارولینای شمالی', 35.2542900, -81.6670400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134462, 'Bolivia', 'Bolivia', '', 34.0676700, -78.1483300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134463, 'Boone', 'Boone', 'Boon,Boone,Bun,Councills Store,bun,bwn,bwn  karwlynay shmaly,bwn  shmaly kyrwlayna,Бун,بون,بون، شمالی کیرولائنا,بون، کارولینای شمالی,ブーン', 36.2167900, -81.6745500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134464, 'Boonville', 'Boonville', '', 36.2326400, -80.7081200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134465, 'Brevard', 'Brevard', 'Brevard,brward  karwlynay shmaly,bryfard,Бревард,بروارد، کارولینای شمالی,بريفارد', 35.2334500, -82.7342900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134466, 'Brices Creek', 'Brices Creek', '', 35.0559900, -77.0877300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134467, 'Broad Creek', 'Broad Creek', '', 34.7207200, -76.9363300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134468, 'Broadway', 'Broadway', '', 35.4579300, -79.0530800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134469, 'Brogden', 'Brogden', '', 35.2926600, -78.0344300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134470, 'Brunswick', 'Brunswick', 'Braunshvejg,Brunswick,Brunswik,Брауншвейг', 34.2868400, -78.7011300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134471, 'Bryson City', 'Bryson City', 'Brajson Siti,Bryson,Bryson City,Charleston,Thanh pho Bryson,Thành phố Bryson,brayswn syty,bryswn syty  karwlynay shmaly,Брајсон Сити,برايسون سيتي,بریسون سیتی، کارولینای شمالی,بریسوں سٹی، شمالی کیرولائنا', 35.4312700, -83.4494400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134472, 'Buies Creek', 'Buies Creek', '', 35.4132200, -78.7355700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134473, 'Burgaw', 'Burgaw', 'Burgaw,Stanford', 34.5521100, -77.9261000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134474, 'Burlington', 'Burlington', 'Berlington,Berlingtona,Bjorlington,Burlington,Bērlingtona,Company Shops,barinton,brlnghtwn,lyngtn  karwlynay shmaly,Берлингтон,Берлінгтон,Бёрлингтон,برلنغتون,برلنگٹن، شمالی کیرولائنا,لینگتن، کارولینای شمالی,バーリントン', 36.0956900, -79.4378000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134475, 'Burnsville', 'Burnsville', 'Burnsville,Hammonds Store', 35.1123700, -80.2445100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134476, 'Burnsville', 'Burnsville', 'Bernsvil,brnzwyl  karwlynay shmaly,bwrnzfyl,Бернсвил,برنزویل، کارولینای شمالی,بورنزفيل', 35.9173400, -82.3009600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134477, 'Butner', 'Butner', 'Butner,Camp Butner', 36.1320900, -78.7566700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134478, 'Buxton', 'Buxton', 'Buxton,The Cape', 35.2676800, -75.5423700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134479, 'Cajahs Mountain', 'Cajahs Mountain', 'Cajah''s Mountain,Cajahs Mountain', 35.8348500, -81.5414800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134480, 'Calabash', 'Calabash', 'Calabash,Pea Landing', 33.8907300, -78.5683400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134481, 'Camden', 'Camden', 'Camden,Jonesborough,Plank Bridge', 36.3284900, -76.1718800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134482, 'Canton', 'Canton', 'Buford,Canton,Pigeon River', 35.5328800, -82.8373600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134483, 'Cape Carteret', 'Cape Carteret', '', 34.6915500, -77.0630000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134484, 'Carolina Beach', 'Carolina Beach', '', 34.0351700, -77.8936000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134485, 'Carolina Shores', 'Carolina Shores', '', 33.9010100, -78.5805700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134486, 'Carrboro', 'Carrboro', 'Carrboro,Karboro,Venable,ka bo luo,kaboro,karbwrw,karbwrw  shmaly kyrwlayna,krbwrw  karwlynay shmaly,Карборо,كاربورو,کاربورو، شمالی کیرولائنا,کربورو، کارولینای شمالی,カーボロ,卡勃羅', 35.9101400, -79.0752900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134487, 'Carthage', 'Carthage', 'Carthage,Fagansville', 35.3459900, -79.4169700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134488, 'Cary', 'Cary', 'Cary,Kehri,Keri,Keris,Pages Siding,Pages Tavern,Pages Turnout,ka rui,kary,keli,keri,kry  karwlynay shmaly,kyry  shmaly kyrwlayna,Кери,Кері,Кэри,كاري,کری، کارولینای شمالی,کیری، شمالی کیرولائنا,ケーリー,卡瑞,케리', 35.7915400, -78.7811200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134489, 'Castle Hayne', 'Castle Hayne', 'Castle Hayne,Castle Haynes,Spring Garden', 34.3557200, -77.8999900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134490, 'Cedar Point', 'Cedar Point', '', 34.6876600, -77.0724500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134491, 'Chadbourn', 'Chadbourn', '', 34.3221100, -78.8269700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134492, 'Chapel Hill', 'Chapel Hill', '', 35.9132000, -79.0558400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134493, 'Charlotte', 'Charlotte', 'CLT,Carolinum,Charlotte,Charlotte i Nord-Carolina,Charlottesburg,Charlottesburgh,Gorad Sharlat,Sarlot,Sarlota,Sarlote,Sarlott,Sharl"t,Sharlot,Sharlott,carlat,charlxtt,saralata,sarlata,sarlet,sharlotʼi,sharlwt  karwlynay shmaly,sharotto,syalleos,tsharlwt,xia luo te,Şarlott,Šarlota,Šarlotė,Σάρλοτ,Горад Шарлат,Шарлот,Шарлотт,Шарлът,Շառլոթ,שארלוט,تشارلوت,شارلوت، کارولینای شمالی,شارلوٹ، شمالی کیرولائنا,शार्लट,শার্লট,ਸ਼ਾਰਲਟ,சார்லட்,షార్లెట్,ಷಾರ್ಲೆಟ್,ชาร์ลอตต์,შარლოტი,シャーロット,夏洛特,샬럿', 35.2270900, -80.8431300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134494, 'Cherokee', 'Cherokee', 'Cherokee,Cheroki,Elawa diyi,chrwky  karwlynay shmaly,Чероки,چروکی، کارولینای شمالی', 35.4742700, -83.3148700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134495, 'Cherryville', 'Cherryville', 'Cherivil,Cherry Ville,Cherryville,White Pines,chrywyl  karwlynay shmaly,shyryfyl,Черивил,شيريفيل,چریویل، کارولینای شمالی', 35.3787400, -81.3789700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134496, 'China Grove', 'China Grove', 'China Grove,Luthersville,Savage', 35.5693100, -80.5817300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134497, 'Claremont', 'Claremont', 'Charlotte Crossing,Claremont,Klermont,Клермонт', 35.7145800, -81.1461900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134498, 'Clayton', 'Clayton', 'Clayton,Klejton,Stallings Station,klaytwn,klytn  karwlynay shmaly,kureiton,Клејтон,كلايتون,کلیتن، کارولینای شمالی,کلیٹن، شمالی کیرولائنا,クレイトン', 35.6507100, -78.4563900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134499, 'Clemmons', 'Clemmons', 'Clementsville,Clemmons,Clemmonstown', 36.0215300, -80.3820000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134500, 'Clinton', 'Clinton', 'CTZ,Klinton,klyntn  karwlynay shmaly,klyntwn,Клинтон,كلينتون,کلینتن، کارولینای شمالی', 34.9979500, -78.3233300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134501, 'Clyde', 'Clyde', 'Clyde,Lower Pigeon', 35.5334400, -82.9106900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134502, 'Coats', 'Coats', 'Coats,Trowville', 35.4079400, -78.6719600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134503, 'Columbia', 'Columbia', 'Columbia,Elizabeth Town,Hearts Desire,Kolumbija,Shallops Landing,Колумбия', 35.9176600, -76.2521500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134504, 'Columbus', 'Columbus', 'Kolumbus,Колумбус', 35.2531700, -82.1970600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134505, 'Concord', 'Concord', 'Concord,Konkord,USA,kankrd  karwlynay shmaly,konkodo,kwnkwrd,Конкорд,كونكورد,کانکرد، کارولینای شمالی,کونکورڈ، شمالی کیرولائنا,コンコード', 35.4088800, -80.5815800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134506, 'Connelly Springs', 'Connelly Springs', 'Connelly Springs,Connellys Springs,Murry', 35.7429100, -81.5134300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134507, 'Conover', 'Conover', 'Konover,kwnwfr,kwnwwr  karwlynay shmaly,kwnwwr  shmaly kyrwlayna,Коновер,كونوفر,کونوور، شمالی کیرولائنا,کونوور، کارولینای شمالی', 35.7065200, -81.2186900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134508, 'Cordova', 'Cordova', '', 34.9129300, -79.8220000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134509, 'Cornelius', 'Cornelius', 'Kornelius,Корнелиус', 35.4868000, -80.8600700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134510, 'Cove Creek', 'Cove Creek', '', 35.6064900, -83.0112500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134511, 'Cramerton', 'Cramerton', 'Cramerton,Mayesworth,Mayworth', 35.2387500, -81.0750800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134512, 'Creedmoor', 'Creedmoor', 'Kridmur,krdmwr  karwlynay shmaly,krydmwr,Кридмур,كريدمور,کردمور، کارولینای شمالی', 36.1223700, -78.6861100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134513, 'Cricket', 'Cricket', '', 36.1715200, -81.1939800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134514, 'Cullowhee', 'Cullowhee', 'Cullowhee,Kullaughee Valley,Painter,kwlwwh  karwlynay shmaly,کولووه، کارولینای شمالی', 35.3137100, -83.1765300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134515, 'Currituck', 'Currituck', '', 36.4498800, -76.0154800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134516, 'Dallas', 'Dallas', 'Dalas,Dallas,dalas,dls  karwlynay shmaly,Далас,Даллас,دالاس,دلس، کارولینای شمالی', 35.3165300, -81.1761900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134517, 'Dana', 'Dana', '', 35.3292800, -82.3754000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134518, 'Danbury', 'Danbury', 'Crawford,Danberi,Danbury,danbwry,dnbry  karwlynay shmaly,Данбери,دانبوري,دنبری، کارولینای شمالی', 36.4093000, -80.2058800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134519, 'Davidson', 'Davidson', 'Davidson,Davidson College,Davison College,Dejvidson,dafydswn,dywydsn  karwlynay shmaly,Дејвидсон,دافيدسون,دیویدسن، کارولینای شمالی', 35.5023300, -80.8391200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134520, 'Denton', 'Denton', 'Denton,Finchs Cross Roads,Finchs Crossroads', 35.6334700, -80.1158800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134521, 'Denver', 'Denver', 'Denver,Dry Pond,Денвер', 35.5312500, -81.0298000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134522, 'Dobson', 'Dobson', '', 36.3956900, -80.7225700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134523, 'Drexel', 'Drexel', 'Baker,Drexel', 35.7579100, -81.6042600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134524, 'Dunn', 'Dunn', 'Dan,Dunn,Lucknow,Tearshirt,dan,dwn,dwn  karwlynay shmaly,Дан,دون,دون، کارولینای شمالی,ڈن، شمالی کیرولائنا,ダン', 35.3062700, -78.6089000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134525, 'Durham', 'Durham', 'Daram,Darem,Daremas,Duram,Durham,Durhamsville,Gorad Darehm,RDU,daramu,de han,deoleom,dwrham,dyurema,Горад Дарэм,Дарам,Дарем,Дърам,דרהאם,دورهام,ڈرہم، شمالی کیرولائنا,ड्युरॅम,เดอแรม,ダーラム,德罕,더럼', 35.9940300, -78.8986200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134526, 'East Flat Rock', 'East Flat Rock', '', 35.2801200, -82.4220600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134527, 'East Rockingham', 'East Rockingham', '', 34.9182100, -79.7625600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134528, 'East Spencer', 'East Spencer', 'East Spencer,Southern City', 35.6818100, -80.4322800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134529, 'Eastover', 'Eastover', '', 35.1000000, -78.8000000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134530, 'Eden', 'Eden', 'Draper,Eden,Iden,Leaksville,Spray,aydn,iden,Иден,إيدن,ایڈن، شمالی کیرولائنا,イーデン', 36.4884700, -79.7667000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134531, 'Edenton', 'Edenton', 'EDE,Edenton,Identon,Town on Matecomack Creek,Town on Queen Annes Creek,adntwn  karwlynay shmaly,adyntwn,Идентон,إدينتون,ادنتون، کارولینای شمالی', 36.0579400, -76.6077200, 'US', '2017-07-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134532, 'Edneyville', 'Edneyville', '', 35.3940100, -82.3409500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134533, 'Elizabeth City', 'Elizabeth City', 'ECG,Elizabeth City,Elizabethtown,Ilizabet Siti,Reading,Redding,alyzabyth syty,aylyzbt syty  karwlynay shmaly,erizabesushiti,Илизабет Сити,إليزابيث سيتي,الزبتھ شہر، شمالی کیرولائنا,ایلیزبت سیتی، کارولینای شمالی,エリザベスシティ', 36.2946000, -76.2510500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134534, 'Elizabethtown', 'Elizabethtown', 'Ehlizabettaun,Elizabettaun,alyzabythtawn,Елизабеттаун,Элизабеттаун,إليزابيثتاون,الزبتھ ٹاؤن، شمالی کیرولائنا,الیزابت‌تاون، کارولینای شمالی', 34.6293400, -78.6052900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134535, 'Elkin', 'Elkin', 'Elkin,alkyn,alkyn  karwlynay shmaly,Елкин,ألكين,الکین، کارولینای شمالی', 36.2443000, -80.8484000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134536, 'Ellerbe', 'Ellerbe', 'Ellerbe,The Fair Grounds', 35.0712600, -79.7614400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134537, 'Elm City', 'Elm City', 'Elm City,Toisnot', 35.8065500, -77.8633200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134538, 'Elon', 'Elon', 'Elon,Elon College', 36.1029100, -79.5066900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134539, 'Elroy', 'Elroy', 'El Roy,Elroy,Elroy Store', 35.3426600, -77.9085900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134540, 'Emerald Isle', 'Emerald Isle', '', 34.6779400, -76.9507800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134541, 'Enfield', 'Enfield', 'Enfield,Huckleberry Swamp', 36.1809900, -77.6666400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134542, 'Enochville', 'Enochville', '', 35.5298600, -80.6681200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134543, 'Erwin', 'Erwin', 'Duke,Erwin', 35.3268300, -78.6761300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134544, 'Etowah', 'Etowah', '', 35.3176200, -82.5942900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134545, 'Fairfield Harbour', 'Fairfield Harbour', 'Fairfield Harbor,Fairfield Harbour', 35.0765500, -76.9635600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134546, 'Fairmont', 'Fairmont', 'Ashpole,Fairmont,Union City', 34.4968300, -79.1142000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134547, 'Fairplains', 'Fairplains', 'Fairplain,Fairplains', 36.1984700, -81.1528600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134548, 'Fairview', 'Fairview', '', 35.5140100, -82.3959500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134549, 'Fairview', 'Fairview', 'Benton Crossroads,Coburn Store,Coburns,Fairview,Fairview Crossroads,Oakville,Stewart', 35.1384800, -80.5375700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134550, 'Farmville', 'Farmville', 'Coalgen,Farmville', 35.5707100, -79.2200200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134551, 'Farmville', 'Farmville', 'Farmville,New Town', 35.5954400, -77.5852500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134552, 'Fearrington Village', 'Fearrington Village', 'Fearrington', 35.8037600, -79.0902900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134553, 'Fayetteville', 'Fayetteville', 'Campbellton,Cross Creek,FAY,Fajetvil,Fayetteville,Feetvil'',Fejetvil,Fejetvill,Lower Campbellton,Upper Campbellton,faiettobiru,fayytfyl,fei ye te wei er,fey xett will,fyytwyl  karwlynay shmaly,peiesbil,Файетвил,Фейетвилл,Феєтвіль,Фејетвил,פאייטוויל,فائیٹویل، شمالی کیرولائنا,فاييتفيل,فییتویل، کارولینای شمالی,เฟย์เอตต์วิลล์,ファイエットビル,費耶特維爾,페이엣빌', 35.0526600, -78.8783600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134554, 'Flat Rock', 'Flat Rock', '', 35.2712300, -82.4415100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134555, 'Flat Rock', 'Flat Rock', 'Flat Rock,Flatrock', 36.5123600, -80.5697800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134556, 'Fletcher', 'Fletcher', '', 35.4306700, -82.5012300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134557, 'Forest City', 'Forest City', 'Burnt Chimney,Forest City,Forist Siti,fryst syty  karwlynay shmaly,fwrst syty,Форист Сити,فریست سیتی، کارولینای شمالی,فورست سيتي', 35.3340100, -81.8651000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134558, 'Forest Oaks', 'Forest Oaks', '', 35.9881900, -79.7061400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134559, 'Foscoe', 'Foscoe', '', 36.1617900, -81.7656600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134560, 'Four Oaks', 'Four Oaks', '', 35.4448800, -78.4269500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134561, 'Franklin', 'Franklin', 'Franklin,frankln,frnklyn  karwlynay shmaly,frynkln  shmaly kyrwlayna,Франклин,فرانكلن,فرنکلین، کارولینای شمالی,فرینکلن، شمالی کیرولائنا', 35.1823200, -83.3815400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134562, 'Franklin', 'Franklin', 'Franklin,Franklinville', 35.7212500, -80.4989500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134563, 'Franklinton', 'Franklinton', 'Franklin Depot,Franklinton,franklyntwn,franklyntwn  karwlynay shmaly,Франклинтон,فرانكلينتون,فرانکلینتون، کارولینای شمالی', 36.1018200, -78.4580500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134564, 'Franklinville', 'Franklinville', 'Franklinsville,Franklinville', 35.7437500, -79.6922500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134565, 'Fremont', 'Fremont', 'Frimont,Фримонт', 35.5454400, -77.9747100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134566, 'Fruitland', 'Fruitland', '', 35.3965100, -82.3931700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134567, 'Fuquay-Varina', 'Fuquay-Varina', 'F''jukvej-Varina,Fjukvej-Varina,Fuquay Springs,Fuquay Varina,Fuquay-Varina,Sippehaw,Varina,fakway faryna,fukibarina,fwkway-waryna  karwlynay shmaly,Фьюквей-Варина,Фюквей-Варіна,فاكواي فارينا,فوکئے-وارینا، شمالی کیرولینا,فوکوای-وارینا، کارولینای شمالی,フキーバリナ', 35.5843200, -78.8000100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134568, 'Gamewell', 'Gamewell', '', 35.8693000, -81.5962100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134569, 'Garner', 'Garner', 'Gardners Station,Garner,gana,garnr  karwlynay shmaly,garnr  shmaly kyrwlyna,gharnr,Гарнер,غارنر,گارنر، شمالی کیرولینا,گارنر، کارولینای شمالی,ガーナー', 35.7112600, -78.6141700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134570, 'Gastonia', 'Gastonia', 'Gastonija,gaeseutonia,gasutonia,ghastwnya,gstwwnya  karwlynay shmaly,jia si tuo ni ya,kastaniya,Гастония,Гастонија,Ґастонія,غاستونيا,گستوونیا، کارولینای شمالی,گیسٹونیا، شمالی کیرولائنا,கஸ்டானியா,แกสโตเนีย,ガストニア,加斯托尼亞,개스토니아', 35.2620800, -81.1873000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134571, 'Gatesville', 'Gatesville', 'Bennetts Creek Landing,Gates Courthouse,Gatesville,Gejtsvil,gatswyl  karwlynay shmaly,ghytsfyl,Гејтсвил,غيتسفيل,گاتسویل، کارولینای شمالی', 36.4034900, -76.7530100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134572, 'Gaston', 'Gaston', 'Camps Store,Gaston,Wilkins Ferry', 36.5004300, -77.6449800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134573, 'Gibsonville', 'Gibsonville', '', 36.1056900, -79.5422500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134574, 'Glen Alpine', 'Glen Alpine', 'Glen Alpine,Glen Alpine Station,Sigmonsburg,Sigmundsville,Turkey Tail', 35.7290200, -81.7792700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134575, 'Glen Raven', 'Glen Raven', '', 36.1131900, -79.4764100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134576, 'Goldsboro', 'Goldsboro', 'GSB,Goldsboro,Goldsborough,ghwldzbwrw,goruzuboro,gwwldzww  karwlynay shmaly,Голдсборо,Ґолдсборо,غولدزبورو,گولڈزبرو، شمالی کیرولائنا,گوولدزوو، کارولینای شمالی,ゴールズボロ', 35.3848800, -77.9927700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134577, 'Gorman', 'Gorman', '', 36.0365300, -78.8233400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134578, 'Graham', 'Graham', 'Grejam,Grejgem,ghraham,grym  karwlynay shmaly,gurahamu,Грейам,Грејам,Ґрейгем,غراهام,گراہم، شمالی کیرولائنا,گریم، کارولینای شمالی,グラハム', 36.0690300, -79.4005800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134579, 'Granite Falls', 'Granite Falls', 'Catawba View,Falls of Gunpowder,Granite Falls', 35.7965200, -81.4306500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134580, 'Granite Quarry', 'Granite Quarry', 'Granite Quarry,Woodside', 35.6123600, -80.4467300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134581, 'Green Level', 'Green Level', 'Green Level,Green Valley Acres', 36.1209700, -79.3441900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134582, 'Green Level', 'Green Level', '', 35.7820900, -78.9039000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134583, 'Greensboro', 'Greensboro', 'GSO,Gorad Grynsbara,Greensboro,Grijnsburo,Grinsboras,Grinsboro,Qrinsboro,ge lin si bo lei,geulinjeubeoleo,ghrynzbwrw,grinsaboro,grynsbwrw,grynzbwrw  karwlynay shmaly,grynzbwrw  shmaly kyrwlayna,gurinzuboro,kri ns bo ro,Горад Грынсбара,Грийнсбъро,Гринсборо,Ґрінсборо,Գրինսբորո,גרינסבורו,غرينزبورو,گرینزبورو، شمالی کیرولائنا,گرینزبورو، کارولینای شمالی,ग्रीन्सबोरो,กรีนส์โบโร,グリーンズボロ,格林斯伯勒,그린즈버러', 36.0726400, -79.7919800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134584, 'Greenville', 'Greenville', 'Greenesville,Greensville,Greenville,Grinvil,Grinvill,Martinsborough,PGV,ghrynfyl,grynwwyl,grynwyl  karwlynay shmaly,grynwyl  shmaly kyrwlayna,gurinbiru,Гринвил,Гринвилл,גרינוויל,غرينفيل,گرینویل، شمالی کیرولائنا,گرینویل، کارولینای شمالی,グリーンビル', 35.6126600, -77.3663500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134585, 'Grifton', 'Grifton', 'Bells Ferry,Blounts Ford,Griffton,Grifton,Peters Ferry', 35.3726600, -77.4374600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134586, 'Half Moon', 'Half Moon', '', 34.8260000, -77.4594100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134587, 'Halifax', 'Halifax', 'Khalifaks,halyfaks,hlyfks  karwlynay shmaly,Халифакс,هاليفاكس,هلیفکس، کارولینای شمالی', 36.3284900, -77.5894200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134588, 'Hamlet', 'Hamlet', '', 34.8848800, -79.6942200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134589, 'Hampstead', 'Hampstead', '', 34.3676700, -77.7105300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134590, 'Harkers Island', 'Harkers Island', 'Kharkers Ajland,harkrs aylnd,Харкерс Ајланд,هارکرس آیلند', 34.6951600, -76.5593700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134591, 'Harrisburg', 'Harrisburg', 'Garrisberg,Harris Depot,Harrisburg,Гаррисберг', 35.3239500, -80.6578400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134592, 'Havelock', 'Havelock', 'Khavlok,haburokku,haflwk,hwlak  karwlynay shmaly,Хавлок,هافلوك,هولاک، کارولینای شمالی,ہیولاک، شمالی کیرولائنا,ハブロック', 34.8790500, -76.9013300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134593, 'Haw River', 'Haw River', '', 36.0915300, -79.3641900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134594, 'Hayesville', 'Hayesville', 'Khejzvil,hayswyl  karwlynay shmaly,hayzfyl,Хејзвил,هايزفيل,هایسویل، کارولینای شمالی', 35.0462000, -83.8179500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134595, 'Hays', 'Hays', 'Hay Meadow,Hays,Mount View', 36.2498500, -81.1156400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134596, 'Hazelwood', 'Hazelwood', '', 35.4687100, -83.0040300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134597, 'Hemby Bridge', 'Hemby Bridge', '', 35.1037100, -80.6279800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134598, 'Henderson', 'Henderson', 'Henderson,Khenderson,Lonesome Valley,hendason,hendeoseun,hndrsn  karwlynay shmaly,hndrswn,Хендерсон,هندرسن، کارولینای شمالی,هندرسون,ہینڈرسن، شمالی کیرولائنا,ヘンダーソン,헨더슨', 36.3295900, -78.3991600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134599, 'Hendersonville', 'Hendersonville', 'Khendersonvil,hendasonbiru,hendeoseunbil,hndrsnwyl  karwlynay shmaly,hyndyrswnfyl,Хендерсонвил,هندرسنویل، کارولینای شمالی,هينديرسونفيل,ہینڈرسنویل، شمالی کیرولائنا,ヘンダーソンビル,헨더슨빌', 35.3187300, -82.4609500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134600, 'Hertford', 'Hertford', 'Hartford,Hertford,Khartford,Phelps Point,harfrd,hrtfwrd,Хартфорд,هارفرد,هرتفورد', 36.1901600, -76.4660500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134601, 'Hickory', 'Hickory', 'Berryville,Gikori,HKY,Hickory,Hickory Tavern,Khikori,West Hickory,hikkori,hykry,hykry  karwlynay shmaly,xi ke li,Гікорі,Хикори,هيكري,هیکری، کارولینای شمالی,ہیکری، شمالی کیرولائنا,ヒッコリー,希科里', 35.7331900, -81.3412000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134602, 'High Point', 'High Point', 'Khaj Pojnt,Khaj-Pojnt,hai bo yin te,haipointo,hay bwynt,hay pwynt  karwlynay shmaly,Хай-Пойнт,Хај Појнт,هاي بوينت,های پوینت، کارولینای شمالی,ہائی پوائنٹ، شمالی کیرولائنا,ハイポイント,海波因特', 35.9556900, -80.0053200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134603, 'Hildebran', 'Hildebran', '', 35.7140200, -81.4220300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134604, 'Hillsborough', 'Hillsborough', 'Childsburg,Childsburgh,Corbinton,Hillsboro,Hillsborough', 36.0754200, -79.0997300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134605, 'Holly Ridge', 'Holly Ridge', '', 34.4954400, -77.5549700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134606, 'Holly Springs', 'Holly Springs', 'Kholi Springs,haly aspryngz,horisupuringusu,hwly sbrynghz,Холи Спрингс,هالی اسپرینگز,هولي سبرينغز,ہالی سپرنگز، شمالی کیرولائنا,ホリースプリングス', 35.6512700, -78.8336200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134607, 'Hoopers Creek', 'Hoopers Creek', '', 35.4390000, -82.4667900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134608, 'Hope Mills', 'Hope Mills', 'Khoup Mils,hopumiruzu,hwb mylz,hwwp mylz  karwlynay shmaly,Хоуп Милс,هوب ميلز,هووپ میلز، کارولینای شمالی,ہوپ ملز، شمالی کیرولائنا,ホープミルズ', 34.9704400, -78.9453100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134609, 'Horse Shoe', 'Horse Shoe', 'Horse Shoe,Horsehoe,Horseshoe', 35.3431700, -82.5565100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134610, 'Hudson', 'Hudson', 'Gudzon,Hudson,Lovelady,Гудзон', 35.8484600, -81.4959300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134611, 'Huntersville', 'Huntersville', 'Khantersvil,hantazubiru,hantrsfyl,hwntrswyl  karwlynay shmaly,Хантерсвил,هانترسفيل,هونترسویل، کارولینای شمالی,ہنٹرزویل، شمالی کیرولائنا,ハンターズビル', 35.4106900, -80.8428500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134612, 'Icard', 'Icard', 'Drowning,Icard', 35.7273500, -81.4706500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134613, 'Indian Trail', 'Indian Trail', '', 35.0768100, -80.6692400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134614, 'Jackson', 'Jackson', 'Atherton,Dzhekson,Jackson,Northampton Court House,Potecase Bridge,Джексон', 36.3896000, -77.4213600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134615, 'Jacksonville', 'Jacksonville', 'Dzeksonvil,Dzhaksunvil,Dzhehksonvill,Dzheksonvil'',Dzheksonvill,Jacksonville,OAJ,Onslow Court House,jakswnfyl,jakusonbiru,jksnwyl  karwlynay shmaly,jyksn wyl  shmaly kyrwlayna,Џексонвил,Джаксънвил,Джексонвилл,Джексонвіль,Джэксонвилл,جاكسونفيل,جکسنویل، کارولینای شمالی,جیکسن ویل، شمالی کیرولائنا,ジャクソンビル', 34.7540500, -77.4302400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134616, 'James City', 'James City', '', 35.0887700, -77.0349500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134617, 'Jamestown', 'Jamestown', 'Dzejmstaun,jymstawn,jymztawn  karwlynay shmaly,Џејмстаун,جيمستاون,جیمز ٹاون، شمالی کیرولائنا,جیمزتاون، کارولینای شمالی', 35.9943000, -79.9353100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134618, 'Jefferson', 'Jefferson', 'Dzhefferson,Джефферсон', 36.4204000, -81.4734400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134619, 'Jonesville', 'Jonesville', 'Jonesville,Martinsborough', 36.2393000, -80.8445200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134620, 'Kannapolis', 'Kannapolis', 'Kanapolis,Kannapolis,kanabwlys,kanaporisu,knplys  karwlynay shmaly,kynapwls  shmaly kyrwlayna,Канаполис,Каннаполис,Каннаполіс,كانابوليس,کنپلیس، کارولینای شمالی,کیناپولس، شمالی کیرولائنا,カナポリス', 35.4873600, -80.6217300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134621, 'Kenansville', 'Kenansville', 'Grovemont,Kenansville', 34.9623900, -77.9622100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134622, 'Kenly', 'Kenly', '', 35.5962700, -78.1241600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134623, 'Kernersville', 'Kernersville', 'Dobson,Dobsons Crossroads,Kerners Crossroads,Kernersvil,Kernersville,kanazubiru,krnrswyl  karwlynay shmaly,kyrnrzwyl  shmaly kyrwlayna,kyrnyrsfyl,Кернерсвил,كيرنيرسفيل,کرنرسویل، کارولینای شمالی,کیرنرزویل، شمالی کیرولائنا,カーナーズビル', 36.1198600, -80.0736500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134624, 'Kill Devil Hills', 'Kill Devil Hills', 'Croatan Shores,FFA,Kill Devil Hills', 36.0307200, -75.6760100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134625, 'King', 'King', 'Five Forks,King,Kings Cabin,Spainhours Store', 36.2806900, -80.3592200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134626, 'Kings Grant', 'Kings Grant', '', 34.2629500, -77.8636000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134627, 'Kings Mountain', 'Kings Mountain', 'King Mountain,Kings Mount,Kings Mountain', 35.2451300, -81.3411900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134628, 'Kinston', 'Kinston', 'Atkins Bank,Caswell,ISO,Kinston,jin si dun,kinsuton,kynstn  karwlynay shmaly,kynstwn,Кинстон,كينستون,کینستن، کارولینای شمالی,کینسٹن، شمالی کیرولائنا,キンストン,金斯顿', 35.2626600, -77.5816400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134629, 'Kitty Hawk', 'Kitty Hawk', 'Chickehauk,Kiti Khok,Kitti-Khok,Kitty Hawk,New Inlet,kiti haka,kitihokeu,kitihoku,kyty hwk,kytyhk  karwlynay shmaly,Кити Хок,Китти-Хок,Кітті-Хок,كيتي هوك,کیتیهک، کارولینای شمالی,किटि हाक,キティホーク,키티호크', 36.0646100, -75.7057300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134630, 'Knightdale', 'Knightdale', 'Najtdejl,knaytdyl,knyghtdal  karwlynay shmaly,Најтдејл,كنايتديل,نائٹڈیل، شمالی کیرولینا,کنیگهتدال، کارولینای شمالی', 35.7876500, -78.4805600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134631, 'Kure Beach', 'Kure Beach', '', 33.9968400, -77.9072100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134632, 'La Grange', 'La Grange', 'La Grange,LaGrange,Moseley Hall,Rantersville', 35.3068300, -77.7880300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134633, 'Lake Junaluska', 'Lake Junaluska', 'Junaluska,Lake Junaluska', 35.5278800, -82.9595800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134634, 'Lake Lure', 'Lake Lure', 'Lake Lure,Lake Lure Village', 35.4279000, -82.2048300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134635, 'Lake Norman of Catawba', 'Lake Norman of Catawba', 'Lake Norman of Catawba', 35.5868000, -80.9595200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134636, 'Lake Park', 'Lake Park', '', 35.0862600, -80.6350700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134637, 'Lake Waccamaw', 'Lake Waccamaw', 'Flemington,Lake Waccamaw', 34.3190600, -78.5000100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134638, 'Landis', 'Landis', '', 35.5456900, -80.6109000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134639, 'Laurel Hill', 'Laurel Hill', '', 34.8090500, -79.5478300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134640, 'Laurel Park', 'Laurel Park', 'Laurel Park,Laurel Park Village', 35.3137300, -82.4934500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134641, 'Laurinburg', 'Laurinburg', 'Laurenburg,Laurinburg,Lorinberg,lao lin bao,lawrynbrg  shmaly kyrwlayna,lrynbrg  karwlynay shmaly,lwrynbrgh,rorinbagu,Лоринберг,لاورینبرگ، شمالی کیرولائنا,لرینبرگ، کارولینای شمالی,لورينبرغ,ローリンバーグ,劳林堡', 34.7740500, -79.4628200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134642, 'Leland', 'Leland', '', 34.2562800, -78.0447100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134643, 'Lenoir', 'Lenoir', 'Lenoir,Lenor,Tuckers Barn,lnwar  karwlynay shmaly,lynwr  shmaly kyrwlayna,lynwyr,renoa,Ленор,لنوار، کارولینای شمالی,لينوير,لینور، شمالی کیرولائنا,レノア', 35.9140200, -81.5389800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134644, 'Lewisville', 'Lewisville', 'Lewisville,Thornton', 36.0970800, -80.4192200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134645, 'Lexington', 'Lexington', 'Leksington,lie ke xing dui,lksyngtwn  karwlynay shmaly,lyksynghtwn,rekishinton,Лексингтон,ليكسينغتون,لکسینگتون، کارولینای شمالی,لیکسنگٹن، شمالی کیرولائنا,レキシントン,列克星敦', 35.8240300, -80.2533800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134646, 'Liberty', 'Liberty', '', 35.8534700, -79.5716900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134647, 'Lillington', 'Lillington', 'Lilington,Lillington,Long Creek Village,lylynghtwn,lylyngtwn  karwlynay shmaly,Лилингтон,ليلينغتون,لیلینگتون، کارولینای شمالی', 35.3993300, -78.8158500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134648, 'Lincolnton', 'Lincolnton', 'Linkolnton,lynklntwn  karwlynay shmaly,lynkntwn,Линколнтон,لينكنتون,لینکلنتون، کارولینای شمالی', 35.4737500, -81.2545300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134649, 'Locust', 'Locust', 'Locust,Locust Level', 35.2598700, -80.4253400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134650, 'Long Beach', 'Long Beach', 'Long-Bich,Лонг-Бич', 33.9104500, -78.1177700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134651, 'Longview', 'Longview', 'Long View,Longview', 35.7293000, -81.3834200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134652, 'Louisburg', 'Louisburg', 'LFN,Lewisburg,Louisburg,Luisburg,lwysbrg  karwlynay shmaly,lwysbrgh,Луисбург,لويسبرغ,لویسبرگ، کارولینای شمالی', 36.0990400, -78.3011100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134653, 'Lowell', 'Lowell', 'Louel,Lowell,Wrights Station,Лоуел', 35.2679200, -81.1028500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134654, 'Lowesville', 'Lowesville', '', 35.4170800, -81.0111900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134655, 'Lucama', 'Lucama', 'Lucama,Lucass Crossroads', 35.6454400, -78.0097100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134656, 'Lumberton', 'Lumberton', 'LBT,Lamberton,lambrtn  karwlynay shmaly,lan bo dun,lwmbyrtwn,ranbaton,Ламбертон,لامبرتن، کارولینای شمالی,لمبرٹن، شمالی کیرولائنا,لومبيرتون,ランバートン,兰伯顿', 34.6183400, -79.0104500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134657, 'Madison', 'Madison', 'Madison,Мадисон', 36.3854200, -79.9594900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134658, 'Maggie Valley', 'Maggie Valley', 'Maggie,Maggie Valley', 35.5181600, -83.0976400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134659, 'Maiden', 'Maiden', 'Mejden,maydn,mydn  karwlynay shmaly,Мејден,مايدن,میدن، کارولینای شمالی', 35.5756900, -81.2117500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134660, 'Manteo', 'Manteo', 'MEO,Manteo,maente-o,mantw  karwlynay shmaly,mantyw,Мантео,مانتو، کارولینای شمالی,مانتيو,맨테오', 35.9082300, -75.6757300, 'US', '2017-06-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134661, 'Mar-Mac', 'Mar-Mac', '', 35.3348800, -78.0558200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134662, 'Marion', 'Marion', 'Marion,Mehrion,marywn,marywn  shmaly kyrwlayna,mryan  karwlynay shmaly,Марион,Мэрион,ماريون,ماریون، شمالی کیرولائنا,مریان، کارولینای شمالی', 35.6840100, -82.0092700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134663, 'Mars Hill', 'Mars Hill', '', 35.8265000, -82.5493000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134664, 'Marshall', 'Marshall', 'Marshall,Маршалл', 35.7973300, -82.6840300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134665, 'Marshville', 'Marshville', 'Beaverdam,Griffinsville,Marshville', 34.9884900, -80.3670100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134666, 'Marvin', 'Marvin', 'Marvin,Poortith', 34.9918200, -80.8147900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134667, 'Masonboro', 'Masonboro', 'Grainger Point,Masonboro', 34.1793400, -77.8474800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134668, 'Matthews', 'Matthews', 'Fullwood,Fullwoods Store,Matthews,Metjuz,mashuzu,mathywz,mtywz  karwlynay shmaly,Метјуз,ماثيوز,متیوز، کارولینای شمالی,میتھیوز، شمالی کیرولائنا,マシューズ', 35.1168100, -80.7236800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134669, 'Maury', 'Maury', '', 35.4821100, -77.5860800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134670, 'Maxton', 'Maxton', 'MXE,Mackstown,Maxton,Quhele,Shoe Heel,Tilden', 34.7351600, -79.3489300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134671, 'Mayodan', 'Mayodan', '', 36.4123600, -79.9669900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134672, 'Maysville', 'Maysville', 'Cross Roads,Maysville,Youngs,Youngs Cross Roads', 34.9048800, -77.2313400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134673, 'McLeansville', 'McLeansville', '', 36.1073600, -79.6586400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134674, 'Mebane', 'Mebane', 'Mebane,Mebansville,Mebejn,mban  karwlynay shmaly,mybany,Мебејн,مبان، کارولینای شمالی,ميباني', 36.0959700, -79.2669600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134675, 'Midland', 'Midland', 'Garmon,Midland', 35.2273700, -80.5006200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134676, 'Midway', 'Midway', 'Eller,Midway', 35.9534700, -80.2181000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134677, 'Millers Creek', 'Millers Creek', 'Miller Creek,Millers Creek,Millers Creek Village', 36.1893000, -81.2375900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134678, 'Mills River', 'Mills River', '', 35.3884500, -82.5667900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134679, 'Mineral Springs', 'Mineral Springs', '', 34.9379300, -80.6686800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134680, 'Mint Hill', 'Mint Hill', '', 35.1795900, -80.6472900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134681, 'Mocksville', 'Mocksville', 'Mocks Old Field Bay,Mocksville,Moksvil,mwksfyl,mwkswyl  karwlynay shmaly,Моксвил,موكسفيل,موکسویل، کارولینای شمالی', 35.8940300, -80.5614500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134682, 'Monroe', 'Monroe', 'Monro,meonlo,mnrww  karwlynay shmaly,monro,mwnrw,mwnrw  shmaly kyrwlayna,Монро,מונרו,منروو، کارولینای شمالی,مونرو,مونرو، شمالی کیرولائنا,モンロー,먼로', 34.9854300, -80.5495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134683, 'Mooresville', 'Mooresville', 'Fallston,Mooresville,Mursvil,muazubiru,mwrswyl  karwlynay shmaly,mwrysfyl,mwrzwyl  shmaly kyrwlayna,Мурсвил,مورزویل، شمالی کیرولائنا,مورسویل، کارولینای شمالی,موريسفيل,ムーアズビル', 35.5848600, -80.8100700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134684, 'Moravian Falls', 'Moravian Falls', 'Forks of the Road,Moravian Falls,Petersburg', 36.0968000, -81.1823100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134685, 'Morehead City', 'Morehead City', 'Morehead City,Shepherds Point,moaheddoshiti,mwrhad syty  karwlynay shmaly,mwrhyd syty,مورهاد سیتی، کارولینای شمالی,مورهيد سيتي,مورہیڈ سٹی، شمالی کیرولائنا,モアヘッドシティ', 34.7229400, -76.7260400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134686, 'Morganton', 'Morganton', 'MRN,Morganton,moganton,mrgntn  karwlynay shmaly,mwrghantwn,Моргантон,مرگنتن، کارولینای شمالی,مورغانتون,مورگنٹن، شمالی کیرولائنا,モーガントン', 35.7454100, -81.6848200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134687, 'Morrisville', 'Morrisville', 'Morisvil,morisubiru,mwrswyl  shmaly kyrwlayna,mwryzwyl  karwlynay shmaly,Морисвил,مورسویل، شمالی کیرولائنا,موریزویل، کارولینای شمالی,モリスビル', 35.8234800, -78.8255600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134688, 'Mount Airy', 'Mount Airy', 'Maunt Eri,Mount Airy,Mountairy,The Hallow,The Hollow,mang te ai li,maunteueeoli,mawnt ayry,mawnt ayry  karwlynay shmaly,Маунт Ери,ماونت إيري,ماونت ایری، کارولینای شمالی,マウント・エアリー,芒特艾里,마운트에어리', 36.4993000, -80.6072900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134689, 'Mount Gilead', 'Mount Gilead', '', 35.2148700, -80.0022800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134690, 'Mount Holly', 'Mount Holly', 'Huntersville,Maunt Kholi,Mount Holly,Woodland,Woodlawn,mawnt haly  karwlynay shmaly,mwnt hwly,Маунт Холи,ماونت هالی، کارولینای شمالی,مونت هولي', 35.2981900, -81.0159100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134691, 'Mount Olive', 'Mount Olive', '', 35.1965500, -78.0663800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134692, 'Mount Pleasant', 'Mount Pleasant', 'Maunt Plezant,Mt Pleasant,mawnt plznt  karwlynay shmaly,mwnt blystant,Маунт Плезант,ماؤنٹ پلیزینٹ، شمالی کیرولینا,ماونت پلزنت، کارولینای شمالی,مونت بليستانت', 35.3993100, -80.4359000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134693, 'Mountain Home', 'Mountain Home', '', 35.3695600, -82.4929000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134694, 'Mountain View', 'Mountain View', 'Mauntin-V''ju,Маунтин-Вью', 35.6831900, -81.3689800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134695, 'Moyock', 'Moyock', '', 36.5246000, -76.1782700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134696, 'Mulberry', 'Mulberry', '', 36.2395800, -81.1806400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134697, 'Murfreesboro', 'Murfreesboro', 'Merfrisboro,Murfrees Ferry,Murfrees Landing,Murfreesboro,Murfrizboro,mwrfrysbwrw,mwrfryzbwrw  karwlynay shmaly,Мерфрисборо,Мурфризборо,مورفريسبورو,مورفریزبورو، کارولینای شمالی', 36.4423800, -77.0985800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134698, 'Murphy', 'Murphy', 'Christie Ford,Huntersville,Merfi,Murphy,Tlanusi''yi,mrfy  karwlynay shmaly,myrfy,Мерфи,مرفی، کارولینای شمالی,ميرفي', 35.0875800, -84.0346300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134699, 'Murraysville', 'Murraysville', '', 34.2957200, -77.8474800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134700, 'Myrtle Grove', 'Myrtle Grove', '', 34.1346200, -77.8816500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134701, 'Nags Head', 'Nags Head', 'Nag''s Head,Nags Head', 35.9573900, -75.6240600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134702, 'Nashville', 'Nashville', 'Nashvill,Нашвилл', 35.9746000, -77.9655400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134703, 'Navassa', 'Navassa', '', 34.2554500, -78.0074900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134704, 'Neuse Forest', 'Neuse Forest', '', 34.9637700, -76.9446700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134705, 'New Bern', 'New Bern', 'EWN,N''ju-Bern,New Bern,Newbern,Nju Bern,nyuban,nyw brn  karwlynay shmaly,nyw brn  shmaly kyrwlayna,nywbyrn,Њу Берн,Нью-Берн,نيوبيرن,نیو برن، شمالی کیرولائنا,نیو برن، کارولینای شمالی,ニューバーン', 35.1084900, -77.0441100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134706, 'Newland', 'Newland', 'Newland,Old Fields of Toe', 36.0873500, -81.9273400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134707, 'Newport', 'Newport', 'Bells Corner,Bells Corners,N''juport,Newport,Ньюпорт', 34.7865500, -76.8591100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134708, 'Newton', 'Newton', 'N''juton,Njuton,nyuton,nywtn,nywtwn  karwlynay shmaly,Њутон,Ньютон,نيوتن,نیوتون، کارولینای شمالی,نیوٹن، شمالی کیرولائنا,ニュートン', 35.6698600, -81.2214700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134709, 'Norlina', 'Norlina', 'Mount Regis,Norlina,Regio', 36.4457000, -78.1983300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134710, 'North Wilkesboro', 'North Wilkesboro', 'Mulberry Fields,Nort Vilkesboro,North Wilkesboro,Northwilkesboro,nrt wylksbwrw  karwlynay shmaly,nwrth wylkysbwrw,Норт Вилкесборо,نرت ویلکسبورو، کارولینای شمالی,نورث ويلكيسبورو', 36.1584700, -81.1475800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134711, 'Northlakes', 'Northlakes', '', 35.7818000, -81.3750900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134712, 'Norwood', 'Norwood', 'Centre,Norwood', 35.2195900, -80.1189500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134713, 'Oak Island', 'Oak Island', 'Long Beach (in part),Oak Island,Yaupon Beach (in part)', 33.9165600, -78.1611100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134714, 'Oak Ridge', 'Oak Ridge', '', 36.1734700, -79.9889300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134715, 'Oakboro', 'Oakboro', 'Furr City,Oakboro', 35.2257000, -80.3289500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134716, 'Ogden', 'Ogden', 'Baymeade,Ogden,Огден', 34.2723900, -77.8185900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134717, 'Oxford', 'Oxford', 'Oksford,aksfwrd  karwlynay shmaly,awksfwrd,Оксфорд,آکسفورد، کارولینای شمالی,آکسفورڈ، شمالی کیرولائنا,أوكسفورد', 36.3107000, -78.5908300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134718, 'Pembroke', 'Pembroke', 'Campbells Mill,Pembroke,Scuffletown', 34.6801600, -79.1950400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134719, 'Pilot Mountain', 'Pilot Mountain', 'Pilot Mountain,Pilotmountain', 36.3865300, -80.4695000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134720, 'Pine Knoll Shores', 'Pine Knoll Shores', '', 34.6973800, -76.8132700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134721, 'Pine Level', 'Pine Level', '', 35.5132200, -78.2444400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134722, 'Pinebluff', 'Pinebluff', '', 35.1098800, -79.4722600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134723, 'Pinehurst', 'Pinehurst', 'Pajnkherst,bynhwrst,pynhwrst  karwlynay shmaly,Пајнхерст,بينهورست,پینهورست، کارولینای شمالی', 35.1954300, -79.4694800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134724, 'Pinetops', 'Pinetops', '', 35.7884900, -77.6377500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134725, 'Pineville', 'Pineville', 'Pajnvil,bynfyl,paynwyl  karwlynay shmaly,Пајнвил,بينفيل,پاینویل، کارولینای شمالی', 35.0832000, -80.8923000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134726, 'Piney Green', 'Piney Green', '', 34.7160000, -77.3202400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134727, 'Pittsboro', 'Pittsboro', 'Pitsboro,bytsbwrw,pytsbwrw  karwlynay shmaly,Питсборо,بيتسبورو,پیتسبورو، کارولینای شمالی', 35.7201500, -79.1772400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134728, 'Plain View', 'Plain View', '', 35.2485000, -78.5552900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134729, 'Pleasant Garden', 'Pleasant Garden', 'Fentress,Pleasant Garden', 35.9620800, -79.7622500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134730, 'Pleasant Hill', 'Pleasant Hill', '', 35.8734700, -79.4816900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134731, 'Plymouth', 'Plymouth', 'Plimut,blymwth,playmawt  shmaly kyrwlayna,plymwth  karwlynay shmaly,Плимут,بليموث,پلایماؤت، شمالی کیرولائنا,پلیموث، کارولینای شمالی', 35.8668300, -76.7485600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134732, 'Polkton', 'Polkton', 'Luneville,Polkton', 35.0076500, -80.2008900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134733, 'Princeton', 'Princeton', 'Boon Hill,Freedom Hill,Princeton,Prinston,Принстон', 35.4659900, -78.1605500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134734, 'Princeville', 'Princeville', 'Freedom Hill,Princeville', 35.8896000, -77.5321900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134735, 'Pumpkin Center', 'Pumpkin Center', '', 35.5193000, -81.1411900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134736, 'Pumpkin Center', 'Pumpkin Center', '', 34.7915500, -77.3724600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134737, 'Raeford', 'Raeford', '', 34.9810000, -79.2242000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134738, 'Raleigh', 'Raleigh', 'Gorad Roli,RDU,Ralei,Raleigh,Rali,Roles,Roli,Rolis,Rolės,Wake Court House,lolli,luo li,ra li,raley,rali,raly,raly  shmaly kyrwlyna,rele,reli,roli,rori,ryale''i,Ράλεϊ,Горад Ролі,Рали,Ралі,Роли,Ռոլի,ראלי,رالي,رالی,رالی، شمالی کیرولینا,रालेय्,रॅले,रेली,र्यालेइ,র‌্যালি,ராலீ,ราลี,როლი,ローリー,罗利,롤리', 35.7721000, -78.6386100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134739, 'Ramseur', 'Ramseur', 'Allens Fall,Columbia,Ramseur,Ramsure', 35.7334700, -79.6525300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134740, 'Randleman', 'Randleman', 'Dicks,Randleman,Randleman Mills,Union Factory', 35.8179100, -79.8030900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134741, 'Ranlo', 'Ranlo', '', 35.2862500, -81.1303500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134742, 'Red Oak', 'Red Oak', 'Jones Store,Red Oak', 36.0384900, -77.9063700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134743, 'Red Springs', 'Red Springs', 'Dora,Red Springs', 34.8151600, -79.1830900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134744, 'Reidsville', 'Reidsville', 'Ridsvil,rizubiru,rydsfyl,rydzwyl  karwlynay shmaly,Ридсвил,ريدسفيل,ریدزویل، کارولینای شمالی,ریڈزویل، شمالی کیرولائنا,リーズビル', 36.3548600, -79.6644700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134745, 'Rhodhiss', 'Rhodhiss', 'Cliffs,Rhodhiss', 35.7740200, -81.4312000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134746, 'Richlands', 'Richlands', '', 34.8993300, -77.5466300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134747, 'River Bend', 'River Bend', '', 35.0690500, -77.1469000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134748, 'River Road', 'River Road', '', 35.5068300, -76.9907800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134749, 'Roanoke Rapids', 'Roanoke Rapids', 'Great Falls,RZZ,Roanoke Rapids,Rounok Rapids,roanokurapizzu,rwnwk rabydz,rwwnwwk rpyd  karwlynay shmaly,Роунок Рапидс,روانوک ریپڈس، شمالی کیرولائنا,رونوك رابيدز,روونووک رپید، کارولینای شمالی,ロアノークラピッズ', 36.4615400, -77.6541500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134750, 'Robbins', 'Robbins', 'Elise,Elsie,Hemp,Mechanicks Hill,Mechanics Hill,Mechanicsville,Robbins', 35.4340300, -79.5869700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134751, 'Robbinsville', 'Robbinsville', 'Robbinsville,Robinsvil,Robinsville,rwbbynswyl  karwlynay shmaly,rwbnzfyl,Робинсвил,روببینسویل، کارولینای شمالی,روبنزفيل', 35.3228700, -83.8074000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134752, 'Robersonville', 'Robersonville', 'Robersonvil,rwbrswnwyl  karwlynay shmaly,Роберсонвил,روبرسونویل، کارولینای شمالی', 35.8251600, -77.2491300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134753, 'Rockfish', 'Rockfish', '', 34.9926600, -79.0661400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134754, 'Rockingham', 'Rockingham', 'Richmond Court House,Rockingham', 34.9393200, -79.7739500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134755, 'Rockwell', 'Rockwell', 'Rockville,Rockwell', 35.5512500, -80.4064500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134756, 'Rocky Point', 'Rocky Point', '', 34.4351700, -77.8877600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134757, 'Rocky Mount', 'Rocky Mount', 'RWI,Rocky Mount,Roki Maunt,Roki-Maunt,raky mawnt  karwlynay shmaly,rokkimaunto,rwky mawnt,Роки Маунт,Роки-Маунт,Рокі-Маунт,راکی ماؤنٹ، شمالی کیرولائنا,راکی ماونت، کارولینای شمالی,روكي ماونت,ロッキーマウント', 35.9382100, -77.7905300, 'US', '2017-05-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134758, 'Rolesville', 'Rolesville', '', 35.9232100, -78.4575000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134759, 'Rose Hill', 'Rose Hill', '', 34.8282200, -78.0230400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134760, 'Roseboro', 'Roseboro', '', 34.9529500, -78.5086200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134761, 'Rowland', 'Rowland', '', 34.5365500, -79.2914300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134762, 'Roxboro', 'Roxboro', 'Moccasin Gap,Roksboro,Roxboro,Roxborough,rwksbwrw,rwksbwrw  karwlynay shmaly,Роксборо,روكسبورو,روکسبورو، کارولینای شمالی', 36.3937500, -78.9827900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134763, 'Royal Pines', 'Royal Pines', '', 35.4751100, -82.5159500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134764, 'Rural Hall', 'Rural Hall', '', 36.2404200, -80.2933800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134765, 'Rutherford College', 'Rutherford College', 'Excelsior,Rutherford College', 35.7484600, -81.5225900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134766, 'Rutherfordton', 'Rutherfordton', 'Raderfordton,Rutherford,Rutherford Court House,Rutherford Town,Rutherfordton,rwdhrfwrdtwn,rwthrfwrdtwn  karwlynay shmaly,Радерфордтон,روتهرفوردتون، کارولینای شمالی,روذرفوردتون', 35.3692900, -81.9567700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134767, 'Saint James', 'Saint James', '', 33.9293400, -78.1163800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134768, 'Saint Pauls', 'Saint Pauls', '', 34.8065500, -78.9711400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134769, 'Salem', 'Salem', 'Sejlem,Сейлем', 35.6987400, -81.6970400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134770, 'Salisbury', 'Salisbury', 'SRW,Solsberi,salysbry,salzbry  karwlynay shmaly,soruzuberi,sylsbry  shmaly kyrwlayna,Солсбери,Солсбері,سالزبری، کارولینای شمالی,ساليسبري,سیلسبری، شمالی کیرولائنا,ソールズベリー', 35.6709700, -80.4742300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134771, 'Sanford', 'Sanford', 'Sanford,Sehnford,Senford,asnfrd  karwlynay shmaly,sanfodo,sanfwrd,Санфорд,Сенфорд,Сэнфорд,اسنفرد، کارولینای شمالی,سانفورد,سینفورڈ، شمالی کیرولائنا,サンフォード', 35.4798800, -79.1803000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134772, 'Sawmills', 'Sawmills', '', 35.8248500, -81.4745400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134773, 'Saxapahaw', 'Saxapahaw', '', 35.9473600, -79.3219600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134774, 'Scotland Neck', 'Scotland Neck', '', 36.1296000, -77.4202500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134775, 'Sea Breeze', 'Sea Breeze', 'Sea Breeze,Seabreeze', 34.0632300, -77.8913700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134776, 'Seagate', 'Seagate', '', 34.2093400, -77.8435900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134777, 'Selma', 'Selma', 'Mitchenors Station,Sel''ma,Selma,Сельма', 35.5365500, -78.2844400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134778, 'Seven Lakes', 'Seven Lakes', '', 35.2784900, -79.5644800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134779, 'Shallotte', 'Shallotte', '', 33.9732300, -78.3858400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134780, 'Sharpsburg', 'Sharpsburg', '', 35.8671000, -77.8291500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134781, 'Shelby', 'Shelby', 'Shelbi,sherubi,shlby  karwlynay shmaly,shylby,shylby  shmaly kyrwlayna,Шелби,شلبی، کارولینای شمالی,شيلبي,شیلبی، شمالی کیرولائنا,シェルビー', 35.2923500, -81.5356500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134782, 'Sherrills Ford', 'Sherrills Ford', 'Sherrill Ford,Sherrills Ford,Sherrills Mill', 35.6204100, -80.9864700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134783, 'Siler City', 'Siler City', 'Matthews Cross Roads,Sajler Siti,Siler City,Silers Station,Silers Store,sylr syty  karwlynay shmaly,Сајлер Сити,سیلر سیتی، کارولینای شمالی', 35.7234700, -79.4622400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134784, 'Silver Lake', 'Silver Lake', '', 34.1487800, -77.9136000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134785, 'Skippers Corner', 'Skippers Corner', '', 34.3460000, -77.9024900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134786, 'Smithfield', 'Smithfield', 'Johnston Court House,Smitfild,Smithfield,asmytfyld  karwlynay shmaly,smythfyld,sumisufirudo,Смитфилд,اسمیتفیلد، کارولینای شمالی,سمتھفیلڈ، شمالی کیرولائنا,سميثفيلد,スミスフィールド', 35.5084900, -78.3394500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134787, 'Sneads Ferry', 'Sneads Ferry', 'Lower Ferry,Sneads Ferry', 34.5526700, -77.3971800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134788, 'Snow Hill', 'Snow Hill', '', 35.4515500, -77.6810900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134789, 'South Gastonia', 'South Gastonia', '', 35.2193000, -81.2056300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134790, 'South Henderson', 'South Henderson', '', 36.3082000, -78.4066600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134791, 'South Rosemary', 'South Rosemary', '', 36.4515400, -77.6972000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134792, 'Southern Pines', 'Southern Pines', 'SOP,Sadern Pajns,Southern Pines,Vineland,nan pai en si,sadrn paynz  karwlynay shmaly,sazanpainzu,sdrn paynz  shmaly kyrwlayna,Садерн Пајнс,سادرن پاینز، کارولینای شمالی,سدرن پائنز، شمالی کیرولائنا,サザンパインズ,南派恩斯', 35.1740500, -79.3922500, 'US', '2017-07-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134793, 'Southern Shores', 'Southern Shores', '', 36.1390500, -75.7315700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134794, 'Southmont', 'Southmont', 'Fairmont,Southmont', 35.6679200, -80.2670000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134795, 'Southport', 'Southport', 'Fort Johnston,Sautport,Smithville,Southport,sawthbwrt,swtprt  karwlynay shmaly,Саутпорт,ساوثبورت,سوتپرت، کارولینای شمالی', 33.9215600, -78.0202700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134796, 'Sparta', 'Sparta', 'Bowers Store,Gap,Sparta,asparta  karwlynay shmaly,sbarta,Спарта,اسپارتا، کارولینای شمالی,سبارتا', 36.5054100, -81.1209200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134797, 'Spencer', 'Spencer', '', 35.6923600, -80.4347800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134798, 'Spindale', 'Spindale', '', 35.3601200, -81.9292700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134799, 'Spring Hope', 'Spring Hope', '', 35.9451500, -78.1119300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134800, 'Spring Lake', 'Spring Lake', '', 35.1679400, -78.9728100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134801, 'Spruce Pine', 'Spruce Pine', 'Sprus Pajn,asprws payn  karwlynay shmaly,Спрус Пајн,اسپروس پاین، کارولینای شمالی', 35.9154000, -82.0645600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134802, 'Saint Stephens', 'Saint Stephens', '', 35.7645800, -81.2731400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134803, 'Stallings', 'Stallings', '', 35.0907000, -80.6861800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134804, 'Stanfield', 'Stanfield', '', 35.2334800, -80.4270100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134805, 'Stanley', 'Stanley', 'Brevard,Brevard Station,Brovard,Stanley,Stanley Center,Stanley Creek', 35.3590300, -81.0970200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134806, 'Statesville', 'Statesville', 'SVH,Statesville,Stejtsvil'',Stejtsvill,astytswyl,suteitsubiru,Стейтсвилл,Стейтсвіль,استیتسویل,ステイツビル', 35.7826400, -80.8873000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134807, 'Stedman', 'Stedman', 'Blockers,Blockersville,Stedman', 35.0135000, -78.6939100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134808, 'Stokesdale', 'Stokesdale', 'Pine,Stokesdale', 36.2370800, -79.9794800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134809, 'Stoneville', 'Stoneville', 'Mayo,Stoneville', 36.4665300, -79.9069800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134810, 'Stony Point', 'Stony Point', 'Sloan,Sloans Station,Stony Point', 35.8634700, -81.0473000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134811, 'Summerfield', 'Summerfield', 'Bruces Crossroads,Summerfield', 36.2087500, -79.9047600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134812, 'Summerfield', 'Summerfield', '', 35.5682200, -77.4027400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134813, 'Sunset Beach', 'Sunset Beach', '', 33.8807300, -78.5122300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134814, 'Surf City', 'Surf City', '', 34.4271100, -77.5460800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134815, 'Swannanoa', 'Swannanoa', 'Cooper,Swannanoa,Swannanona', 35.5978900, -82.3998400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134816, 'Swanquarter', 'Swanquarter', '', 35.4062800, -76.3290900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134817, 'Swansboro', 'Swansboro', 'Bogie,Bogue,New Town,Swannsborough,Swansboro,The Wharf,Weeks Point', 34.6876600, -77.1191200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134818, 'Swepsonville', 'Swepsonville', '', 36.0212500, -79.3614100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134819, 'Sylva', 'Sylva', 'Silva,sylfa,sylwa  karwlynay shmaly,Силва,سيلفا,سیلوا، کارولینای شمالی', 35.3737100, -83.2259800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134820, 'Tabor City', 'Tabor City', 'Tabor,Tabor City,Tejbor Siti,tybr syty  karwlynay shmaly,Тејбор Сити,تیبر سیتی، کارولینای شمالی', 34.1487800, -78.8766900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134821, 'Tarboro', 'Tarboro', 'Tarboro,Tawboro,taboro,tarbwrw,tarbwrw  karwlynay shmaly,tarbwrw  shmaly kyrwlayna,Тарборо,تاربورو,تاربورو، شمالی کیرولائنا,تاربورو، کارولینای شمالی,ターボロ', 35.8968200, -77.5358000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134822, 'Taylorsville', 'Taylorsville', '', 35.9218000, -81.1764700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134823, 'Thomasville', 'Thomasville', 'Thomas Village,Thomasville,Tomasvil,tamswyl  karwlynay shmaly,tomasubiru,tomeoseubil,twmasfyl,Томасвил,تامسویل، کارولینای شمالی,توماسفيل,تھامسویل، شمالی کیرولائنا,トマスビル,토머스빌', 35.8826400, -80.0819900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134824, 'Thurmond', 'Thurmond', 'Termond,Термонд', 36.3665200, -80.9284100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134825, 'Toast', 'Toast', '', 36.5004100, -80.6264500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134826, 'Tobaccoville', 'Tobaccoville', 'Hansers,Hausers,Reeds,Tobaccoville', 36.2381900, -80.3714400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134827, 'Trent Woods', 'Trent Woods', '', 35.0821000, -77.0863400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134828, 'Trenton', 'Trenton', 'Trent,Trenton,Трентон', 35.0671000, -77.3527400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134829, 'Trinity', 'Trinity', '', 35.8945800, -79.9908700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134830, 'Troutman', 'Troutman', 'Troutman,Troutmans,Troutmens', 35.7006900, -80.8881300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134831, 'Troy', 'Troy', 'Troja,Троя', 35.3584700, -79.8944900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134832, 'Tryon', 'Tryon', 'Trajon,Trajun,trywn  karwlynay shmaly,Трайън,Трајон,تریون، کارولینای شمالی', 35.2081700, -82.2384500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134833, 'Tryon', 'Tryon', '', 35.3398600, -81.3220300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134834, 'Tyro', 'Tyro', 'Cason,Tyro', 35.8090300, -80.3728300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134835, 'Unionville', 'Unionville', '', 35.0873700, -80.5089600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134836, 'Valdese', 'Valdese', '', 35.7406900, -81.5631500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134837, 'Valley Hill', 'Valley Hill', '', 35.2984500, -82.4831800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134838, 'Vander', 'Vander', 'East Gate,Vander', 35.0321100, -78.7947400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134839, 'Wadesboro', 'Wadesboro', 'New Town,Vejdsboro,Wadesboro,Wadesborough,wadsbwrw  karwlynay shmaly,wydsbwrw,Вејдсборо,وادسبورو، کارولینای شمالی,ويدسبورو', 34.9682100, -80.0767300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134840, 'Wake Forest', 'Wake Forest', 'Town of Wake Forest College,Vejk Forist,Wake Forest,u~eikuforesuto,wyk fryst  karwlynay shmaly,Вејк Форист,ویک فارسٹ، شمالی کیرولائنا,ویک فریست، کارولینای شمالی,ウェイクフォレスト', 35.9798700, -78.5097200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134841, 'Walkertown', 'Walkertown', '', 36.1754100, -80.1531000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134842, 'Walkertown', 'Walkertown', '', 35.2857200, -78.8136300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134843, 'Wallace', 'Wallace', 'Volas,walys  karwlynay shmaly,Волас,والیس، کارولینای شمالی', 34.7357200, -77.9952600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134844, 'Wallburg', 'Wallburg', '', 36.0101400, -80.1392100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134845, 'Walnut Cove', 'Walnut Cove', 'Lash,Walnut Cove', 36.2954100, -80.1417100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134846, 'Wanchese', 'Wanchese', '', 35.8426700, -75.6385100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134847, 'Warrenton', 'Warrenton', 'Hastings,Vorenton,Warrenton,warntwn  karwlynay shmaly,waryntwn,Ворентон,وارنتون، کارولینای شمالی,وارنٹن، شمالی کیرولائنا,وارينتون', 36.3984800, -78.1552700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134848, 'Warsaw', 'Warsaw', '', 34.9993300, -78.0911000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134849, 'Washington', 'Washington', 'Bonner,Forks of Tar River,Vashington,Washington,washntn,washyngtn  karwlynay shmaly,wosingteon,Вашингтон,واشنطن,واشنگٹن، شمالی کیرولائنا,واشینگتن، کارولینای شمالی,워싱턴', 35.5465500, -77.0521700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134850, 'Waxhaw', 'Waxhaw', '', 34.9245900, -80.7434000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134851, 'Waynesville', 'Waynesville', 'Mount Prospect,Vejnsvil,Waynesville,u~einzubiru,waynswyl  karwlynay shmaly,wynzfyl,wynzwyl  shmaly kyrwlayna,Вејнсвил,واینسویل، کارولینای شمالی,وينزفيل,وینزویل، شمالی کیرولائنا,ウェインズビル', 35.4887100, -82.9887500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134852, 'Weaverville', 'Weaverville', 'Elkwood,Pine Cabbin,Salem Camp Ground,Vivervil,Weaverville,wawrwyl  karwlynay shmaly,Вивервил,واورویل، کارولینای شمالی', 35.6970500, -82.5606900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134853, 'Weddington', 'Weddington', 'Providence,Weddington', 35.0223700, -80.7609000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134854, 'Welcome', 'Welcome', 'Hinklesville,Welcome', 35.9029200, -80.2569900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134855, 'Weldon', 'Weldon', 'Veldon,Weldon,Weldons,Weldons Orchard,Weldons Place,wldwn  karwlynay shmaly,Велдон,ولدون، کارولینای شمالی', 36.4271000, -77.5955300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134856, 'Wentworth', 'Wentworth', 'Rockingham Courthouse,Rockingham Springs,Wentworth', 36.4001400, -79.7744800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134857, 'Wesley Chapel', 'Wesley Chapel', '', 35.0070900, -80.6745100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134858, 'Wendell', 'Wendell', 'Vendl,Wendel,Wendell,wndl  karwlynay shmaly,Вендл,وندل، کارولینای شمالی', 35.7809900, -78.3697200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134859, 'West Canton', 'West Canton', '', 35.5378800, -82.8581900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134860, 'West Jefferson', 'West Jefferson', 'Vest DZeferson,wst jfrsn  karwlynay shmaly,Вест Џеферсон,وست جفرسن، کارولینای شمالی', 36.4037400, -81.4928800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134861, 'West Marion', 'West Marion', '', 35.6579000, -82.0253900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134862, 'West Raleigh', 'West Raleigh', '', 35.7868200, -78.6638900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134863, 'Westport', 'Westport', '', 35.5012500, -80.9786900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134864, 'Whispering Pines', 'Whispering Pines', '', 35.2557100, -79.3722500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134865, 'White Plains', 'White Plains', '', 35.2340200, -81.3981400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134866, 'White Plains', 'White Plains', 'White Plains,Whiteplains', 36.4456900, -80.6334000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134867, 'Whiteville', 'Whiteville', 'Vajtvil,Vineland,Whites Crossing,Whitesville,Whiteville,waytfyl,whytwyl  karwlynay shmaly,Вајтвил,وايتفيل,وهیتویل، کارولینای شمالی', 34.3387800, -78.7030700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134868, 'Wilkesboro', 'Wilkesboro', 'Mulberry Fields,Vilksboro,Wilkesboro,Wilkesborough,wylksbwrw,wylksbwrw  karwlynay shmaly,Вилксборо,ويلكسبورو,ویلکسبورو، کارولینای شمالی', 36.1459600, -81.1606400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134869, 'Williamston', 'Williamston', 'Skewarky,Squhawky,Vilijamston,Williamston,Williamstown,wylyamstwn,wylyamstwn  karwlynay shmaly,Вилијамстон,ويليامستون,ویلیامستون، کارولینای شمالی', 35.8546000, -77.0555100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134870, 'Wilmington', 'Wilmington', 'ILM,New Carthage,New Liverpool,New Town,Newton,Uilmington,Uilmingtun,Vilmington,Wilmington,u~iruminton,wei er ming dun,wilmingteon,wylmynghtwn,wylmyngtn  karwlynay shmaly,wylmyngtwn,Вилмингтон,Вілмінгтон,Уилмингтон,Уилмингтън,וילמינגטון,ويلمينغتون,ویلمینگتن، کارولینای شمالی,ویلمینگٹن، شمالی کیرولائنا,ウィルミントン,威尔明顿,윌밍턴', 34.2257300, -77.9447100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134871, 'Wilson', 'Wilson', 'Hickory Grove,Tosnot Depot,Uilson,Vilson,Wilson,u~iruson,wlsn  shmaly kyrwlayna,wylsn  karwlynay shmaly,wylswn,Вилсон,Вілсон,Уилсон,ولسن، شمالی کیرولائنا,ويلسون,ویلسن، کارولینای شمالی,ウィルソン', 35.7212700, -77.9155400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134872, 'Wilsons Mills', 'Wilsons Mills', 'Wilson,Wilsons Mills', 35.5840500, -78.3558300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134873, 'Windsor', 'Windsor', 'Bertie,Grays Landing,Rosemont,Vindzor,Windsor,wynzr  karwlynay shmaly,wynzwr,Виндзор,وينزور,وینزر، کارولینای شمالی', 35.9984900, -76.9460600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134874, 'Windsor', 'Windsor', '', 35.5529400, -77.3610800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134875, 'Wingate', 'Wingate', 'Ames Turnout,Beaver Dam,Wingate', 34.9843200, -80.4492300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134876, 'Winston-Salem', 'Winston-Salem', 'INT,Uinston-Sejlem,Uinstun-Sejlum,Vinston-Salem,Vinston-Sejlem,Vinstonas-Seilemas,Winston,Winston Salem,Winston-Salem,wen si dun-sai lei mu,winseuteonseilleom,wynstwn-salm  karwlayna alshmalyt,wynstwn-sylm,Винстон-Салем,Винстон-Сейлем,Винстон-Сејлем,Уинстон-Сейлем,Уинстън-Сейлъм,وينستون-سالم، كارولاينا الشمالية,وینستون-سیلم,ウィンストン・セーラム,温斯顿-塞勒姆,윈스턴세일럼', 36.0998600, -80.2442200, 'US', '2017-05-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134877, 'Winterville', 'Winterville', '', 35.5290500, -77.4010800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134878, 'Winton', 'Winton', 'Winton,Wynnton', 36.3957100, -76.9319000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134879, 'Woodfin', 'Woodfin', '', 35.6334400, -82.5820700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134880, 'Wrightsboro', 'Wrightsboro', '', 34.2885000, -77.9211000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134881, 'Wrightsville Beach', 'Wrightsville Beach', '', 34.2085000, -77.7963700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134882, 'Yadkinville', 'Yadkinville', 'Wilson,Yadkinville', 36.1345800, -80.6595100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134883, 'Yanceyville', 'Yanceyville', 'Caswell Court House,Jansivil,Yanceyville,yansyfyl,yansywyl  karwlynay shmaly,yynsywyl  shmaly kyrwlayna,Јансивил,يانسيفيل,یئنسیویل، شمالی کیرولائنا,یانسیویل، کارولینای شمالی', 36.4040300, -79.3361300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134884, 'Youngsville', 'Youngsville', 'Pacific,Youngsville', 36.0248700, -78.4744400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134885, 'Zebulon', 'Zebulon', 'Zebjulon,zbylan  karwlynay shmaly,Зебјулон,زبیلان، کارولینای شمالی', 35.8243200, -78.3147200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134886, 'Absecon', 'Absecon', 'Absecom,Absecom Village,Absecombe,Absecon,Absecum,Absehkon,Absikon,Lower Island,Mount Eagle,Ragtown,abskwn  nywjrsy,Абсикон,Абсэкон,ابسکون، نیوجرسی', 39.4284500, -74.4957100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134887, 'Alloway', 'Alloway', 'Alloway,Alloways Town,Allowaystown,Thompson''s Bridge', 39.5609500, -75.3624200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134888, 'Ashland', 'Ashland', '', 39.8631700, -75.0060000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134889, 'Atlantic City', 'Atlantic City', 'ACY,AIY,Absecon Beach,Absecum Beach,Abseon Beach,Atlantic City,Atlantic city,Atlantik Siti,Atlantik Sitis,Atlantik-Siti,Atlantiksitija,Kota Atlantic,Thanh pho Atlantic,Thành phố Atlantic,aeteullaentigsiti,atlantyk syty,atlantyk syty  nywjrsy,atorantikkushiti,da xi yang cheng,Ατλάντικ Σίτι,Атлантик Сити,Атлантик-Сити,Атлантик-Сіті,אטלאנטיק סיטי,אטלנטיק סיטי,آتلانتیک سیتی، نیوجرسی,اتلانتيك سيتي,اٹلانٹک سٹی، نیو جرسی,アトランティックシティ,大西洋城,애틀랜틱시티', 39.3642800, -74.4229300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134890, 'Audubon', 'Audubon', 'Audjubon park,Odjubon,Odubon,awdwban  nywjrsy,Аудюбон парк,Одубон,Одюбон,اودوبان، نیوجرسی', 39.8909500, -75.0729500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134891, 'Audubon Park', 'Audubon Park', 'Odobon Park,awdwban park  nywjrsy,Одобон Парк,اودوبان پارک، نیوجرسی', 39.8965000, -75.0876700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134892, 'Avalon', 'Avalon', 'Avalon,Ehvalon,Leaming,Piermont,Seven Mile Beach,awalwn  nywjrsy,aywalwn  nyw jrsy,Авалон,Эвалон,اوالون، نیوجرسی,ایوالون، نیو جرسی', 39.1012200, -74.7176600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134893, 'Barnegat', 'Barnegat', '', 39.7531800, -74.2229200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134894, 'Barrington', 'Barrington', 'Barington,Barrington,Dentdale,baryngtwn  nywjrsy,Барингтон,Баррингтон,بارینگتون، نیوجرسی,بیرنگٹن، نیو جرسی', 39.8648400, -75.0551700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134895, 'Beach Haven', 'Beach Haven', 'Beach Haven,Beachhaven,Beyehaven,Bich Khehjvn,Bich Khejven,Eyerhaven,bych hywn  nywjrsy,Бич Хејвен,Бич Хэйвн,بیچ هیون، نیوجرسی', 39.5592800, -74.2432000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134896, 'Beach Haven West', 'Beach Haven West', '', 39.6698400, -74.2318100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134897, 'Beachwood', 'Beachwood', 'Bichvud,bychwwd  nywjrsy,Бичвуд,بیچ ووڈ، نیو جرسی,بیچوود، نیوجرسی', 39.9390100, -74.1929200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134898, 'Beckett', 'Beckett', '', 39.7540000, -75.3574100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134899, 'Bellmawr', 'Bellmawr', 'Behllmavr,Belmar,blmawr  nywjrsy,Белмар,Бэллмавр,بلماور، نیوجرسی', 39.8676100, -75.0946200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134900, 'Berlin', 'Berlin', 'Berlin,Long-a-coming,Longacoming,Magnolia,brlyn  nywjrsy,Берлин,برلین، نیوجرسی', 39.7912300, -74.9290500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134901, 'Blackwood', 'Blackwood', 'Blackwood,Blackwoodtown,Blehkvud,Blekvud,Блеквуд,Блэквуд', 39.8023400, -75.0640600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134902, 'Brigantine', 'Brigantine', 'Atmoonica,Bridzhantajn,Brigantin,Brigantine,Brigantine Beach,Brigantine City,Brigintine,brygntyn  nywjrsy,Бригантин,Бриджантайн,بریگنتین، نیوجرسی', 39.4101200, -74.3645900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134903, 'Bridgeton', 'Bridgeton', 'Bridgeton,Bridgetown,Bridzhton,Bridzhtun,Bridzton,Cohansey Bridge,The Bridge,bryjtwn  nywjrsy,bu li qi dun,burijjiton,Бриджтон,Бриджтън,Бриџтон,برجٹن، نیو جرسی,بریجتون، نیوجرسی,ブリッジトン,布里奇頓', 39.4273400, -75.2340800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134904, 'Brooklawn', 'Brooklawn', 'Bruklon,brwklawn  nywjrsy,Бруклон,بروکلاون، نیوجرسی', 39.8781700, -75.1207300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134905, 'Brooklawn', 'Brooklawn', '', 39.8742800, -75.1196200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134906, 'Browns Mills', 'Browns Mills', 'Biddle''s Mills,Biddles Mills,Brown Mills,Brown''s Mills,Browns Mills,Browns Mills-in-the-Pines', 39.9726100, -74.5829300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134907, 'Buena', 'Buena', 'Buehna,Buena,Buena Vista,Buna,bwyna  nywjrsy,Буна,Буэна,بوئنا، نیوجرسی', 39.5137300, -74.9246200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134908, 'Camden', 'Camden', 'Camden,Camden Village,Cooper''s Ferry,Cooper''s Point Ferry Village,Coopers Ferry,Coopersville,Dogwood,Kaighnton,Kamdehn,Kamden,Kamdun,Pinchtown,Spicers,Stockton,Wrightsville,kaemdeon,kamdn,kamuden,kemdena,ken dun,kmdn  nywjrsy,qmdn,Камден,Камдън,Камдэн,קמדן,كامدن,کمدن، نیوجرسی,کیڈمن، نیو جرسی,कॅम्डेन,カムデン,肯頓,캠던', 39.9259500, -75.1196200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134909, 'Cape May Court House', 'Cape May Court House', 'Cape May,Cape May Court House,Kehjp Mehj Kurt Khaus,Kejp Maj Kort Khaus,Kejp-Mehj Kort Khaus,Middletown,Romney Marsh,Rumly Moch,kai pu mei fa yuan,Кейп-Мэй Корт Хаус,Кејп Мај Корт Хаус,Кэйп Мэй Курт Хаус,開普梅法院', 39.0826100, -74.8237800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134910, 'Cape May', 'Cape May', 'Caep May,Cape Island,Cape May,Cape May City,Cape May Town,Kehjp Mehj,Kejp Mej,Kejp-Mej,Kep-Mej,kai pu mei,kyp my  nywjrsy,Кейп Мей,Кейп-Мей,Кеп-Мей,Кејп Меј,Кэйп Мэй,کیپ می، نیوجرسی,開普梅', 38.9351100, -74.9060100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134911, 'Carneys Point', 'Carneys Point', 'Carney''s Point,Carneys Point', 39.7112200, -75.4702000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134912, 'Cedar Glen Lakes', 'Cedar Glen Lakes', '', 39.9523400, -74.3998700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134913, 'Cherry Hill', 'Cherry Hill', 'Cherry Hill,Ellisburg', 39.9348400, -75.0307300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134914, 'Cherry Hill Mall', 'Cherry Hill Mall', '', 39.9359500, -75.0090600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134915, 'Chesilhurst', 'Chesilhurst', 'Chesilkherst,Chesilkhjorst,chzylhwrst  nywjrsy,Чесилхерст,Чесилхёрст,چزیلهورست، نیوجرسی', 39.7323400, -74.8810000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134916, 'Cinnaminson', 'Cinnaminson', 'Cinnaminson,Lower Chester,Westfield', 39.9967800, -74.9926700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134917, 'Clayton', 'Clayton', 'Clayton,Fislertown,Fislerville,Glehjton,Klejton,klaytwn  nywjrsy,Глэйтон,Клејтон,کلایتون، نیوجرسی', 39.6601100, -75.0921200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134918, 'Clementon', 'Clementon', 'Cementon,Clementon,Klemehnton,Klementon,Newman''s Mills,klmntwn  nywjrsy,Клементон,Клемэнтон,کلمنتون، نیوجرسی', 39.8115000, -74.9829400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134919, 'Collings Lakes', 'Collings Lakes', '', 39.5956700, -74.8815600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134920, 'Collingswood', 'Collingswood', 'Collingswood,Kolingsvud,Kollingsvud,Newton Colony,kalyngswwd  nywjrsy,Колингсвуд,Коллингсвуд,کالینگسوود، نیوجرسی', 39.9181700, -75.0712800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134921, 'Country Lake Estates', 'Country Lake Estates', '', 39.9426200, -74.5440400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134922, 'Crestwood Village', 'Crestwood Village', '', 39.9481700, -74.3607000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134923, 'Dover Beaches North', 'Dover Beaches North', '', 39.9912300, -74.0637500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134924, 'Dover Beaches South', 'Dover Beaches South', '', 39.9556700, -74.0743000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134925, 'Echelon', 'Echelon', '', 39.8484500, -74.9957200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134926, 'Egg Harbor City', 'Egg Harbor City', 'Eg Kharbor Siti,Egg Harbor,Egg Harbor City,Ehgg Kharbor Siti,Gloucester Landing,ag harbwr syty  nywjrsy,Ег Харбор Сити,Эгг Харбор Сити,اگ هاربور سیتی، نیوجرسی', 39.5287300, -74.6479400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134927, 'Ellisburg', 'Ellisburg', 'Ellis,Ellisburg,Ellisburgh', 39.9137200, -75.0104500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134928, 'Elmer', 'Elmer', 'Cohockan,Ehlmer,Elmer,Pittstown,Terrapin Town,Ticktown,almr  nywjrsy,Елмер,Элмер,المر، نیوجرسی', 39.5951100, -75.1701800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134929, 'Elwood', 'Elwood', 'Colville,Elwood,Elwood-Magnolia', 39.5765100, -74.7168300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134930, 'Erma', 'Erma', 'Erma,Swaintown', 38.9877600, -74.9017000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134931, 'Estell Manor', 'Estell Manor', 'Ehstehll Manor,Estel Manor,Estell Manor,Estelle Manor,Risley,astl manwr  nywjrsy,Естел Манор,Эстэлл Манор,استل مانور، نیوجرسی', 39.4120600, -74.7423900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134932, 'Fairton', 'Fairton', 'Fairfield,Fairton,New England Town Cross Roads', 39.3817800, -75.2199100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134933, 'Folsom', 'Folsom', 'Folsom,Germantown,New Germany,fwlswm  nywjrsy,Фолсом,فولسوم، نیوجرسی', 39.6020600, -74.8426700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134934, 'Forked River', 'Forked River', '', 39.8398400, -74.1901400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134935, 'Gibbsboro', 'Gibbsboro', 'Gibbsboro,Gibbsborough,Gibsboro,gybbsbwrw  nywjrsy,Гиббсборо,Гибсборо,گیببسبورو، نیوجرسی', 39.8381700, -74.9648900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134936, 'Gibbstown', 'Gibbstown', '', 39.8251100, -75.2835200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134937, 'Glassboro', 'Glassboro', 'Glasboro,Glass Town,Glassboro,Glassborough,Glassworks,ge la si bao luo,glsbwrw  nywjrsy,Гласборо,Глассборо,گلسبورو، نیوجرسی,葛拉斯堡罗', 39.7028900, -75.1118400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134938, 'Glendora', 'Glendora', 'Glendora,Hillmanton', 39.8395600, -75.0735100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134939, 'Gloucester City', 'Gloucester City', 'Axwamus,Glocester,Gloster Siti,Gloucester,Gloucester City,Gloucester Point,Gloucester Town,Gloucestertown,Glousestehr Siti,glastr syty  nywjrsy,Глостер Сити,Глоусестэр Сити,گلاستر سیتی، نیوجرسی', 39.8917800, -75.1162900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134940, 'Golden Triangle', 'Golden Triangle', '', 39.9278900, -75.0387800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134941, 'Greentree', 'Greentree', '', 39.8970600, -74.9557200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134942, 'Haddon Heights', 'Haddon Heights', 'Baker''s Corner,Borton''s Hill,Haddon Heights,Khaddon Khehjts,Khadon Khajkhts,hdn hayts  nywjrsy,Хаддон Хэйтс,Хадон Хајхтс,هدن هایتس، نیوجرسی', 39.8773400, -75.0646200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134943, 'Haddonfield', 'Haddonfield', 'Haddanfield,Haddenfield,Haddonfield,Heddonfield,Khaddonfild,Khadonfild,hdnfyld  nywjrsy,Хаддонфилд,Хадонфилд,هدنفیلد، نیوجرسی', 39.8915000, -75.0376700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134944, 'Hammonton', 'Hammonton', 'Coffin''s Mill,Hammond Town,Hammondtown,Hammonton,Khammonton,Khamonton,hamwntn,Хаммонтон,Хамонтон,هامونتن', 39.6365100, -74.8023900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134945, 'Holiday Heights', 'Holiday Heights', '', 39.9459500, -74.2540300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134946, 'Island Heights', 'Island Heights', 'Ajland Khajts,Ajland Khehjts,aylnd hayts  nywjrsy,Айланд Хэйтс,Ајланд Хајтс,آیلند هایتس، نیوجرسی', 39.9420600, -74.1498600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134947, 'Jackson', 'Jackson', '', 39.7765000, -74.8623800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134948, 'Kingston Estates', 'Kingston Estates', '', 39.9237200, -74.9879500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134949, 'Laurel Lake', 'Laurel Lake', '', 39.3395600, -75.0299000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134950, 'Lavallette', 'Lavallette', 'Lavalet,Lavallehtt,laballeteu,lwlt  nywjrsy,Лавалет,Лаваллэтт,لولت، نیوجرسی,라발레트', 39.9704000, -74.0687500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134951, 'Lawnside', 'Lawnside', 'Free Haven,Lawnside,Lonsajd,Snow Hill,lawnsayd  nywjrsy,Лонсайд,Лонсајд,لاونساید، نیوجرسی', 39.8665000, -75.0282300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134952, 'Laurel Springs', 'Laurel Springs', 'Laurehl Springs,Lorel Springs,lawrl aspryngz  nywjrsy,Лаурэл Спрингс,Лорел Спрингс,لاورل اسپرینگز، نیوجرسی', 39.8201100, -75.0062800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134953, 'Leisuretowne', 'Leisuretowne', '', 39.8923400, -74.7021000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134954, 'Lindenwold', 'Lindenwold', 'Lindehnvold,Lindenvold,Линденволд,Линдэнволд,لیندن‌وولد، نیوجرسی', 39.8242800, -74.9976700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134955, 'Linwood', 'Linwood', 'Leedsville,Linvud,Linwood,Pearville,Steelmanville,lynwwd  nywjrsy,Линвуд,لینوود، نیوجرسی', 39.3398400, -74.5751600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134956, 'Magnolia', 'Magnolia', '', 39.9498400, -74.6607100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134957, 'Magnolia', 'Magnolia', 'Greenland,Magnolia,Magnolija,Scrapetown,Turkeytown,mgnwlya  nywjrsy,mygnwlya  nyw jrsy,Магнолия,Магнолија,مگنولیا، نیوجرسی,میگنولیا، نیو جرسی', 39.8545600, -75.0390600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134958, 'Manahawkin', 'Manahawkin', 'Manahawkin,Manahocking,Manakhavkin,Манахавкин', 39.6954000, -74.2587500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134959, 'Maple Shade', 'Maple Shade', 'Mapl Shehjd Taunship,Maple Shade Township,Municipio de Maple Shade,mypl shyd  nywjrsy,Мапл Шэйд Тауншип,میپل شید، نیوجرسی', 39.9526100, -74.9923900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134960, 'Margate City', 'Margate City', 'Margate,Margate City,Margehjt Siti,Margejt Siti,South Atlantic City,margyt syty  nywjrsy,Маргејт Сити,Маргэйт Сити,مارگیت سیتی، نیوجرسی', 39.3278900, -74.5034900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134961, 'Marlton', 'Marlton', 'Evesham,Marlton,Mehrlton,Rising Sun,Swain''s,Марлтон,Мэрлтон', 39.8912200, -74.9218300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134962, 'Mays Landing', 'Mays Landing', 'Hamilton,Iliff Town,Ilifftown,May''s Landing,May''s Place,Mays Landing,Mayslanding,Mehjs Lehnding,Mejs Landing,mei si lan ding,Мејс Ландинг,Мэйс Лэндинг,梅斯兰丁', 39.4523400, -74.7276600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134963, 'Medford Lakes', 'Medford Lakes', 'Aetna Furnace,Ballinger''s Mills,Etna,Etna Furnace,Etna Mills,Medford Lakes,Medford Lejks,Mehdford Lehjks,Taunton Furnace,mdfwrd lyks  nywjrsy,Медфорд Лејкс,Мэдфорд Лэйкс,مدفورد لیکس، نیوجرسی,میڈفورڈ لیکس، نیو جرسی', 39.8584500, -74.8029400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134964, 'Millville', 'Millville', 'MIV,Maurice River Bridge,Millvill,Millville,Milvil,Shingle Landing,mylwyl  nywjrsy,Милвил,Миллвилл,میلویل، نیوجرسی', 39.4020600, -75.0393400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134965, 'Mount Ephraim', 'Mount Ephraim', 'Ephraim''s Mount,Maunt Ehfrehjm,Maunt Ifram,Mount Ephraim,mawnt afrym  nywjrsy,Маунт Ифрам,Маунт Эфрэйм,ماونت افریم، نیوجرسی', 39.8784500, -75.0926700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134966, 'Mount Holly', 'Mount Holly', 'Bridgeton,Crips Mount,LLY,Mount Holly,Mounthalli,Mountholly', 39.9928900, -74.7876600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134967, 'Mount Laurel', 'Mount Laurel', '', 39.9340000, -74.8910000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134968, 'Mullica Hill', 'Mullica Hill', 'Blue Bell,Mullica Hill,Spicerville', 39.7392800, -75.2240700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134969, 'Mystic Island', 'Mystic Island', 'Mystic Island,Mystic Islands', 39.5442800, -74.3823700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134970, 'National Park', 'National Park', 'Nashonal Park,Nehjshnal Park,nshnal park  nywjrsy,Нашонал Парк,Нэйшнал Парк,نشنال پارک، نیوجرسی', 39.8659500, -75.1787900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134971, 'Newfield', 'Newfield', 'N''jufild,Njufild,nywfyld  nywjrsy,Њуфилд,Ньюфилд,نیوفیلد، نیوجرسی', 39.5468800, -75.0263600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134972, 'North Beach Haven', 'North Beach Haven', '', 39.5731700, -74.2315300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134973, 'North Cape May', 'North Cape May', 'Cape May Beach,North Cape May', 38.9820600, -74.9579500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134974, 'North Wildwood', 'North Wildwood', 'Anglesea,Nors Vildvud,Nort Vajlvud,North Wildwood,wyldwwd shmaly  nywjrsy,Норс Вилдвуд,Норт Вајлвуд,ویلدوود شمالی، نیوجرسی', 39.0006700, -74.7993300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134975, 'Northfield', 'Northfield', 'Bakersville,Dolphin,Norsfild,Nortfild,Northfield,nwrthfyld  nywjrsy,Норсфилд,Нортфилд,نارتھفیلڈ، نیو جرسی,نورثفیلد، نیوجرسی', 39.3703900, -74.5501500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134976, 'Oaklyn', 'Oaklyn', 'Oaklin,Ouklin,awaklyn  nywjrsy,Оаклин,Оуклин,اواکلین، نیوجرسی', 39.9009500, -75.0846200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134977, 'Ocean Acres', 'Ocean Acres', '', 39.7434500, -74.2809800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134978, 'Ocean City', 'Ocean City', 'New Brighton,Ocean City,Oushan Siti,Oushehn Siti,Oushun Siti,Peck''s Beach,Pecks Beach,Pet''s Beach,Peter''s Beach,awshn syty  nywjrsy,oshanshiti,Оушан Сити,Оушън Сити,Оушэн Сити,اوشن سٹی، نیو جرسی,اوشن سیتی، نیوجرسی,オーシャンシティ', 39.2776200, -74.5746000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134979, 'Ocean Gate', 'Ocean Gate', 'Ocean Gate,Oceangate,Oushan Gejt,Oushehn Gehjt,awshn gyt  nywjrsy,Оушан Гејт,Оушэн Гэйт,اوشن گیت، نیوجرسی', 39.9267900, -74.1337500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134980, 'Olivet', 'Olivet', '', 39.5481700, -75.1546300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134981, 'Paulsboro', 'Paulsboro', 'Crown Point,Paulsboro,Paulsborough,Polsboro,paywlsbwrw  nywjrsy,Паулсборо,Полсборо,پائولسبورو، نیوجرسی', 39.8303900, -75.2404600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134982, 'Pemberton', 'Pemberton', 'Hampton Hanover,New Mills,Pehmberton,Pemberton,Пембертон,Пэмбертон', 39.9720600, -74.6829400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134983, 'Pemberton Heights', 'Pemberton Heights', '', 39.9626100, -74.6787700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134984, 'Penns Grove', 'Penns Grove', 'Helm''s Cove,Pehnns Grouv,Penn Grove,Penn''s Grove,Penngrove,Penns Grove,Pennsgrove,Pens Grouv,pns grww  nywjrsy,Пенс Гроув,Пэннс Гроув,پنس گروو، نیوجرسی', 39.7295600, -75.4679700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134985, 'Pennsauken', 'Pennsauken', 'Pennsauken,Pennsoakin', 39.9562200, -75.0579500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134986, 'Pennsville', 'Pennsville', 'Craven''s Ferry,Kinseyville,Municipio de Pennsville,Obisquahassit,Pehnnsvill Taunship,Pennsville,Pennsville Township,Pensvil,pnswyl  nywjrsy,Пенсвил,Пэннсвилл Тауншип,پنسویل، نیوجرسی', 39.6534500, -75.5165900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134987, 'Pine Beach', 'Pine Beach', 'Pajn Bich,payn bych  nywjrsy,Пайн Бич,Пајн Бич,پاین بیچ، نیوجرسی', 39.9359500, -74.1709700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134988, 'Pine Hill', 'Pine Hill', '', 39.7842800, -74.9921100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134989, 'Pine Ridge at Crestwood', 'Pine Ridge at Crestwood', '', 39.9545600, -74.3151500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134990, 'Pitman', 'Pitman', 'Camp Meeting Town,Pitman,Pitman Grove,Pitmehn,pytmn  nywjrsy,Питман,Питмэн,پیتمن، نیوجرسی', 39.7328900, -75.1315700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134991, 'Pleasantville', 'Pleasantville', 'Adamstown,Lakestown,Pleasantville,Plezantvil,Plisantvill,Risleytown,Smith''s Landing,plyzntwyl  nywjrsy,Плезантвил,Плисантвилл,پلیزنتویل، نیوجرسی', 39.3898400, -74.5240400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134992, 'Pomona', 'Pomona', 'Cedar Bridge,Doughty Station,Pomerania,Pomona,Swamp Siding,Помона', 39.4784500, -74.5751600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134993, 'Port Norris', 'Port Norris', 'Dallas Ferry,Port Norris', 39.2459500, -75.0351800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134994, 'Port Republic', 'Port Republic', 'Clark''s Mills,Port Repablik,Port Republic,Union,Uniontown,Unionville,Wrangleboro,pwrt rypablyk  nywjrsy,Порт Репаблик,پورت ریپابلیک، نیوجرسی', 39.5206700, -74.4857100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134995, 'Presidential Lakes Estates', 'Presidential Lakes Estates', '', 39.9137300, -74.5646000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134996, 'Ramblewood', 'Ramblewood', '', 39.9287200, -74.9437800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134997, 'Richwood', 'Richwood', 'Campbell''s Crossroads,Five Points,Mount Pleasant,Richwood,White Horse', 39.7226100, -75.1654600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134998, 'Rio Grande', 'Rio Grande', 'Hildreths,Rio Grande,Riogrande', 39.0145600, -74.8815600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(134999, 'Rosenhayn', 'Rosenhayn', '', 39.4781700, -75.1312900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135000, 'Salem', 'Salem', 'Fenwick''s Colony,Ferkens Creek,New Salem,Oijtsessing,Salam,Salam Town,Salem,Salem Town,Sejlem,Watcessi,sai lei mu,sylm  nyw jrsy,sylm  nywjrsy,Сейлем,Сејлем,سیلم، نیو جرسی,سیلم، نیوجرسی,塞勒姆', 39.5717800, -75.4671400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135001, 'Runnemede', 'Runnemede', 'Marlboro,New Hope,Rannehmid,Runnemede,ranamd  nywjrsy,Раннэмид,رانامد، نیوجرسی', 39.8523400, -75.0679500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135002, 'Sea Isle City', 'Sea Isle City', 'Ludlam''s Beach,Sea Isle City,Si Ajl Siti,Si Ajsl Siti,Strathmere,sy ayl syty  nywjrsy,Си Айсл Сити,Си Ајл Сити,سی آیل سیتی، نیوجرسی', 39.1534500, -74.6929400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135003, 'Seabrook Farms', 'Seabrook Farms', '', 39.5009500, -75.2179600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135004, 'Seaside Heights', 'Seaside Heights', 'Sisajd Khajts,Sisajd Khehjts,sysayd hayts  nywjrsy,Сисайд Хэйтс,Сисајд Хајтс,سیساید هایتس، نیوجرسی', 39.9442900, -74.0729100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135005, 'Seaside Park', 'Seaside Park', 'Sisajd Park,sysayd park  nywjrsy,Сисайд Парк,Сисајд Парк,سیساید پارک، نیوجرسی', 39.9267900, -74.0770800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135006, 'Ship Bottom', 'Ship Bottom', 'Arlington,Ship Botom,Ship Bottom,Ship Bottom Beach,shyp batm  nywjrsy,Шип Ботом,Шип Боттом,شیپ باتم، نیوجرسی', 39.6429000, -74.1804200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135007, 'Sicklerville', 'Sicklerville', 'Sicklertown,Sicklerville,Waretown', 39.7173400, -74.9693300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135008, 'Silver Ridge', 'Silver Ridge', 'Silver Ridge,Silver Ridge Park', 39.9592800, -74.2184800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135009, 'Smithville', 'Smithville', 'Galloway Cross Roads,Smithville', 39.4940100, -74.4570900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135010, 'Somerdale', 'Somerdale', 'Samerdehjl,Samerdejl,samrdyl  nywjrsy,Самердејл,Самердэйл,سامردیل، نیوجرسی', 39.8440000, -75.0226700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135011, 'Somers Point', 'Somers Point', 'Job''s Point,Samers Pojnt,Somehrs Pojnt,Somers Ferry,Somers Point,samrs pwynt  nywjrsy,Самерс Појнт,Сомэрс Пойнт,سامرس پوینت، نیوجرسی', 39.3176200, -74.5946000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135012, 'South Toms River', 'South Toms River', 'Saut Toms River,Sous Toms Riveh,tamz rywr jnwby  nywjrsy,Саут Томс Ривер,Соус Томс Ривэ,تامز ریور جنوبی، نیوجرسی', 39.9420600, -74.2043100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135013, 'South Vineland', 'South Vineland', '', 39.4459500, -75.0287900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135014, 'Springdale', 'Springdale', '', 39.9026100, -74.9662800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135015, 'Stratford', 'Stratford', 'Stratford,astrtfwrd  nywjrsy,stratfwrd,Стратфорд,استرتفورد، نیوجرسی,ستراتفورد', 39.8267800, -75.0154500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135016, 'Surf City', 'Surf City', 'Culver,Long Beach City,Mansion of Health,Serf Siti,Sjurf Siti,Surf,Surf City,swrf syty  nywjrsy,Серф Сити,Сюрф Сити,سورف سیتی، نیوجرسی', 39.6620600, -74.1651400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135017, 'Swedesboro', 'Swedesboro', 'Laddtown,Raccoon,Svedehsboro,Svidensboro,Swedesboro,Swedesborough,aswdsbwrw  nywjrsy,Сведэсборо,Свиденсборо,اسودسبورو، نیوجرسی', 39.7476100, -75.3104700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135018, 'Toms River', 'Toms River', 'Goose Creek,MJX,Main Branch Toms River,North Branch Toms River,Tom''s River,Toms Creek,Toms Rivehr Taunship,Toms River,Toms River Bay,Toms Rivur,tamz rywr  nywjrsy,tang mu si he,tomseulibeo,tomuzuriba,Томс Ривер,Томс Ривър,Томс Ривэр Тауншип,تامز ریور، نیوجرسی,トムズリバー,湯姆斯河,톰스리버', 39.9537300, -74.1979200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135019, 'Tuckerton', 'Tuckerton', 'Clamtown,Little Egg Harbour,Middle-of-the-Shore,Takerton,Takkehrton,Tucker Town,Tuckerton,takrtwn  nywjrsy,Такертон,Таккэртон,تاکرتون، نیوجرسی', 39.6031700, -74.3401500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135020, 'Turnersville', 'Turnersville', '', 39.7731700, -75.0512800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135021, 'Ventnor City', 'Ventnor City', 'Ventnor,Ventnor City,Ventnor Siti,wntnwr syty  nywjrsy,Вентнор Сити,ونتنور سیتی، نیوجرسی', 39.3403900, -74.4773700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135022, 'Victory Lakes', 'Victory Lakes', '', 39.6331700, -74.9660000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135023, 'Villas', 'Villas', 'Fisher''s Creek,Villas,Wildwood Villas', 39.0287200, -74.9385100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135024, 'Vineland', 'Vineland', 'Vajnland,bainrando,waynlnd  nywjrsy,Вайнланд,Вајнланд,وائنلینڈ، نیو جرسی,واینلند، نیوجرسی,バインランド', 39.4862300, -75.0257300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135025, 'Waretown', 'Waretown', 'Waer Town,Waertown,Waiers Mill,Waretown,Wiretown', 39.7915100, -74.1951400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135026, 'Wenonah', 'Wenonah', 'Vehnonakh,Venona,wnwna  nywjrsy,Венона,Вэнонах,ونونا، نیوجرسی', 39.7945600, -75.1487900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135027, 'West Cape May', 'West Cape May', 'Vehst Kehjp Mehj,Vest Kejp Mej,kyp my ghrby  nywjrsy,Вест Кејп Меј,Вэст Кэйп Мэй,کیپ می غربی، نیوجرسی', 38.9387200, -74.9418400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135028, 'Westville', 'Westville', 'Vehstvill,Vestvil,wstwyl  nywjrsy,Вествил,Вэствилл,وستویل، نیوجرسی', 39.8678900, -75.1315600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135029, 'Whitesboro', 'Whitesboro', 'White,Whitesboro', 39.0390000, -74.8568400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135030, 'Wildwood', 'Wildwood', 'Five Mile Beach,Holly Beach,Vajldvud,Vildvud,WWD,Wildwood,Wildwood-By-The-Sea,Woodland,wyldwwd  nywjrsy,Вайлдвуд,Вајлдвуд,Вилдвуд,Вілдвуд,وائلڈووڈ، نیو جرسی,ویلدوود، نیوجرسی', 38.9917800, -74.8148900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135031, 'Wildwood Crest', 'Wildwood Crest', 'Vajldvud Krest,Vildvud Krehst,wyldwwd krst  nywjrsy,Вајлдвуд Крест,Вилдвуд Крэст,ویلدوود کرست، نیوجرسی', 38.9748400, -74.8335000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135032, 'Williamstown', 'Williamstown', 'Squankum,Squankum Neck,Squankum Village,Vilijamstaun,Villiamstaun,Williams Town,Williamstown,Вилијамстаун,Виллиамстаун,ولیمزٹاؤن، نیو جرسی', 39.6862300, -74.9951700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135033, 'Wood-Lynne', 'Wood-Lynne', 'Wood-Lynne,Woodlynne', 39.9173400, -75.0962900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135034, 'Woodbine', 'Woodbine', 'Vudbajn,wwdbyn  nywjrsy,Вудбайн,Вудбајн,وودبین، نیوجرسی', 39.2417800, -74.8151700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135035, 'Woodbury', 'Woodbury', 'Piscozackasing,Vudbari,Vudberi,Vudbjuri,Woodbury,wu de bo li,wwdbwry  nywjrsy,Вудбари,Вудбери,Вудбюри,وودبوری، نیوجرسی,伍德伯里', 39.8381700, -75.1526800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135036, 'Woodbury Heights', 'Woodbury Heights', 'Vudberi Khajts,Vudbjuri Khehjts,wwdbwry hayts  nywjrsy,Вудбери Хајтс,Вудбюри Хэйтс,وودبوری هایتس، نیوجرسی', 39.8170600, -75.1551800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135037, 'Woodstown', 'Woodstown', 'Millbrooke,Pilesgrove,Vudstaun,Wood Town,Wood''s Town,Woodstown,wwdstawn  nywjrsy,Вудстаун,وودستاون، نیوجرسی', 39.6515000, -75.3282500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135038, 'Aberdeen', 'Aberdeen', 'Aberdin,abrdyn,abrdyn  awhyw,aebeodin,Абердин,أبردين,ابردین، اوهیو,애버딘', 38.6556300, -83.7610300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135039, 'Amberley', 'Amberley', '', 39.2047800, -84.4280000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135040, 'Amelia', 'Amelia', 'Amelia,Milltown,Milton', 39.0284000, -84.2177100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135041, 'Arcanum', 'Arcanum', 'Arcanum,Smithville', 39.9900500, -84.5532900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135042, 'Ashville', 'Ashville', 'Asheville,Ashville,Eshvil,aesyubil,ashfyl,Ешвил,أشفيل,애슈빌', 39.7156200, -82.9529600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135043, 'Athens', 'Athens', 'ATO,Afiny,Asehns,Atens,Athens,Coates Ferry,Elizabethtown,Harpers Ferry,Middletown,a sen si,aeseonseu,asenzu,athyns,atn  awhayw,Асэнс,Атенс,Афины,آتن، اوهایو,أثينس,ایتھنز، اوہائیو,アセンズ,阿森斯,애선스', 39.3292400, -82.1012600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135044, 'Baltimore', 'Baltimore', 'Baltimor,Baltimore,Basil,Liberty,New Market,Балтимор', 39.8453400, -82.6007200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135045, 'Barnesville', 'Barnesville', 'Barnesville,Barnsvil,Barnsville,barnsfyl,Барнсвил,بارنسفيل', 39.9881300, -81.1765000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135046, 'Batavia', 'Batavia', 'Batavija,Batejvija,batafya,Батавия,Батејвија,باتافيا', 39.0770100, -84.1768800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135047, 'Beavercreek', 'Beavercreek', 'Beaver Creek,Beavercreek,Bivehrkrik,Biverkrik,bawrkrk  awhayw,bibakuriku,byfrkryk,Биверкрик,Бивэркрик,باورکرک، اوهایو,بيفركريك,ビーバークリーク', 39.7092300, -84.0632700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135048, 'Beckett Ridge', 'Beckett Ridge', '', 39.3470000, -84.4352200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135049, 'Bellbrook', 'Bellbrook', 'Behllbruk,Belbrook,Belbruk,Bellbrook,blbrwk  awhayw,bylbrwk,Белбрук,Бэллбрук,بلبروک، اوهایو,بيلبروك', 39.6356200, -84.0707700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135050, 'Belpre', 'Belpre', 'Behlpr,Bell Pre,Belle Prairie,Belle Pre,Bellepre,Belleprie,Bellpre,Belpre,Belpri,blpr  awhayw,bylbryh,Белпри,Бэлпр,بلپر، اوهایو,بيلبريه', 39.2739600, -81.5729000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135051, 'Bethel', 'Bethel', 'Bethel,Denhams Town,Denhamsville,Dunhamstown,Plainfield', 38.9636800, -84.0807700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135052, 'Bethel', 'Bethel', '', 39.7303400, -83.3935300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135053, 'Beverly', 'Beverly', '', 39.5478500, -81.6395700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135054, 'Bexley', 'Bexley', 'Bekslehj,bksly  awhayw,byksly  awhayw,Бекслэй,بيكسلي، أوهايو,بکسلی، اوهایو', 39.9689500, -82.9376800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135055, 'Blacklick Estates', 'Blacklick Estates', '', 39.9050600, -82.8643400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135056, 'Blanchester', 'Blanchester', '', 39.2931200, -83.9888200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135057, 'Blue Ash', 'Blue Ash', 'Blju Ash,Blu Esh,Blue Ash,Blueash,Harper,blw ash,blw aysh  awhayw,Блу Еш,Блю Аш,بلو أش,بلو ایش، اوهایو', 39.2320000, -84.3782700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135058, 'Bridgetown', 'Bridgetown', '', 39.1531100, -84.6371700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135059, 'Brookville', 'Brookville', 'Brookfield,Brooksville,Brookville', 39.8367200, -84.4113400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135060, 'Buckeye Lake', 'Buckeye Lake', '', 39.9336800, -82.4723800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135061, 'Burlington', 'Burlington', 'Berlington,Берлингтон', 38.4073000, -82.5357100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135062, 'Byesville', 'Byesville', 'Byers Mills,Byes Mill,Byesville', 39.9697900, -81.5365100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135063, 'Caldwell', 'Caldwell', 'Kolduehll,Koldvel,klaydwl,Колдвел,Колдуэлл,كلايدول', 39.7478500, -81.5165100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135064, 'Camden', 'Camden', 'Camden,Dover,Newcomb,Newcombe,Newcome', 39.6289400, -84.6485600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135065, 'Canal Winchester', 'Canal Winchester', 'Canal Winchester,Kanal Vinchester,Winchester,kanal wnshstr  awhayw,Канал Винчестер,كانال ونشستر، أوهايو', 39.8428400, -82.8046200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135066, 'Carlisle', 'Carlisle', 'Carlisle,Carlisle Junction,Carlisle Station,Jersey Settlement', 39.5820000, -84.3202200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135067, 'Cedarville', 'Cedarville', 'Adarville,Cedarville,Hannas Store,Massies Creek,Milford,Newports Mill,Sidervil,sydarfyl,Сидервил,سيدارفيل', 39.7442300, -83.8085400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135068, 'Centerville', 'Centerville', 'Centerville,Centreville,Sehntervill,Sentervil,sntrfyl,sntrwyl  awhayw,Сентервил,Сэнтервилл,سنترفيل,سنترویل، اوهایو,سینٹرویل، مونٹگمری کاؤنٹی، اوہائیو', 39.6283900, -84.1593800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135069, 'Chauncey', 'Chauncey', 'Chauncey,Chauncy', 39.3978500, -82.1293100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135070, 'Cherry Grove', 'Cherry Grove', 'Cherry Grove,Cherrygrove,Forrestville', 39.0725600, -84.3218800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135071, 'Cheviot', 'Cheviot', 'Cheviot,Cheviot Station,Cheviott', 39.1570000, -84.6132800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135072, 'Choctaw Lake', 'Choctaw Lake', 'Chocktou Lake,Choctaw Lake', 39.9600600, -83.4849200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135073, 'Cincinnati', 'Cincinnati', 'CVG,Cincinnati,Cincinnatopolis,Covalts Station,Fort Washington,Gorad Cyncynaci,Losantiville,Porkopolis,Queen City,Queen City of the West,Sinsinati,Sinsinatis,Sinsinatti,Sinsinnati,cincinatti,shinshinati,sinasinati,sinsinaeti,synsynaty,synsynty,synsynty  awhayw,xin xin na ti,Σινσινάτι,Горад Цынцынаці,Синсинати,Синсинатти,Цинциннати,Цинциннаті,Ցինցինատի,סינסינטי,سنسیناٹی,سينسيناتي,سینسینتی، اوهایو,सिनसिनाटी,சின்சினாட்டி,ซินซินแนติ,ცინცინატი,シンシナティ,辛辛那提,신시내티', 39.1271100, -84.5143900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135074, 'Circleville', 'Circleville', 'Circleville,Round Town,Serkelvil,Soklvill,syrklfyl,syrklwyl  awhayw,Серкелвил,Соклвилл,سيركلفيل,سیرکلویل، اوهایو', 39.6006200, -82.9460100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135075, 'Clayton', 'Clayton', 'Clayton,Klehjton,Klejton,Salem,Salem Pike,klaytwn,klaytwn  awhayw,Клејтон,Клэйтон,كلايتون,کلایتون، اوهایو,کلیٹن، اوہائیو', 39.8631100, -84.3605000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135076, 'Cleves', 'Cleves', 'Cleves,Clevestown', 39.1617200, -84.7491200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135077, 'Coal Grove', 'Coal Grove', 'Coal Grove,Coalgrove,Petersburg,Petersburgh', 38.5034100, -82.6471100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135078, 'Columbus', 'Columbus', 'CMH,Columbopolis,Columbus,Columbus i Ohio,Franklin,Franklinton,Gorad Kalumbus,Kolambus,Kolompous,Kolumbas,Kolumbs,Kolumbu,Kolumbus,Kolumbusa,Kulumbus,ge lun bu,kalabasa,kalambasa,kholambas,klmbws  awhayw,kolambas,kolambasa,kolampas,kolleombeoseu,koronbasu,kwlwmbws,qwlwmbws,Κολόμπους,Горад Калумбус,Коламбус,Колумбус,Кълъмбъс,Կոլումբուս,קאלומבוס,קולומבוס,كولومبوس,کلمبوس، اوهایو,کولمبس، اوہائیو,कोलंबस,कोलम्बस,कोलम्बस्,কলম্বাস,ਕਲੰਬਸ,கொலம்பஸ்,โคลัมบัส,კოლუმბუსი,コロンバス,哥伦布,哥倫布,콜럼버스', 39.9611800, -82.9987900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135079, 'Commercial Point', 'Commercial Point', 'Becketts Store,Commercial Point,Genoa,Rome', 39.7684000, -83.0571300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135080, 'Covedale', 'Covedale', '', 39.1211700, -84.6063300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135081, 'Crooksville', 'Crooksville', 'Clay City,Crooksville', 39.7689600, -82.0920900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135082, 'Crystal Lakes', 'Crystal Lakes', '', 39.8892300, -84.0266000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135083, 'Day Heights', 'Day Heights', '', 39.1739500, -84.2263300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135084, 'Dayton', 'Dayton', 'Cabintown,DAY,Dayton,Dehjton,Deitonas,Dejton,Dejtun,Venice,dai dun,daytwn  awhayw,deiteon,deiton,detana,dytwn,dyytwn,Дейтон,Дейтън,Дејтон,Дэйтон,דייטון,دايتون، أوهايو,دیتون,डेटन,デイトン,代顿,데이턴', 39.7589500, -84.1916100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135085, 'Deer Park', 'Deer Park', 'Dia Park,Dir Park,dyr bark,dyr park  awhayw,Диа Парк,Дир Парк,دير بارك,دیر پارک، اوهایو', 39.2053400, -84.3946600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135086, 'Dent', 'Dent', 'Challengeville,Dent', 39.1858900, -84.6513400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135087, 'Devola', 'Devola', 'De Vola,DeVola,Devol,Devola', 39.4736900, -81.4790100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135088, 'Dillonvale', 'Dillonvale', '', 39.2181100, -84.4021600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135089, 'Drexel', 'Drexel', 'Drexel,Drexel Park', 39.7464500, -84.2866100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135090, 'Dry Ridge', 'Dry Ridge', 'Bridgetown,Dry Ridge', 39.2592200, -84.6191100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135091, 'Dry Run', 'Dry Run', '', 39.1042300, -84.3304900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135092, 'Dunlap', 'Dunlap', 'Colerain,Dunlap,Dunlap''s Station,Dunlaps Station,Fort Dunlap,Georgetown', 39.2922800, -84.6180000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135093, 'Eaton', 'Eaton', 'Iton,aytwn,aytwn  awhayw,Итон,إيتون,ایتون، اوهایو', 39.7439400, -84.6366200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135094, 'Elmwood Place', 'Elmwood Place', 'Elmwood,Elmwood Place', 39.1872800, -84.4880000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135095, 'Englewood', 'Englewood', 'Englewood,Harrisburg,Harrisburgh,Iamton,Jamton,Jamtown', 39.8775600, -84.3021700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135096, 'Enon', 'Enon', '', 39.8781200, -83.9368800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135097, 'Etna', 'Etna', 'Carthage,Etna', 39.9572900, -82.6818300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135098, 'Evendale', 'Evendale', '', 39.2561700, -84.4180000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135099, 'Fairborn', 'Fairborn', 'Fairborn,Fairfield,Fajabon,Ferborn,Osborn,fayrbwrn  awhayw,fyrbwrn,Файабон,Ферборн,فایربورن، اوهایو,فيربورن,فیئربورن، اوہائیو', 39.8208900, -84.0193800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135100, 'Fairfax', 'Fairfax', '', 39.1453400, -84.3932700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135101, 'Fairfield', 'Fairfield', 'Feurfild,Феърфилд', 39.3458900, -84.5605000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135102, 'Fairfield Beach', 'Fairfield Beach', '', 39.9159000, -82.4751600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135103, 'Farmersville', 'Farmersville', '', 39.6795000, -84.4291100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135104, 'Finneytown', 'Finneytown', 'Finnetytown,Finneytown', 39.2003400, -84.5205000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135105, 'Five Points', 'Five Points', '', 39.5686700, -84.1929900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135106, 'Forest Park', 'Forest Park', '', 39.2903400, -84.5041100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135107, 'Forestville', 'Forestville', '', 39.0750600, -84.3449400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135108, 'Fort McKinley', 'Fort McKinley', '', 39.7975600, -84.2535500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135109, 'Frankfort', 'Frankfort', 'Chillicothe,Frankford,Frankfort,Frankfurt,Old Chillicothe,Old Town,Oldtown,Франкфурт', 39.4014500, -83.1807400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135110, 'Franklin', 'Franklin', 'Franklin,franklyn,franklyn  awhayw,Франклин,فرانكلين,فرانکلین، اوهایو,فرینکلن، اوہائیو', 39.5589500, -84.3041100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135111, 'Franklin Furnace', 'Franklin Furnace', '', 38.6450800, -82.8487800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135112, 'Fruit Hill', 'Fruit Hill', 'Cedar Point,Fruit Hill,Fruithill', 39.0756200, -84.3643800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135113, 'Gallipolis', 'Gallipolis', 'French City,Galipolis,Galliopolis,Gallipolis,ghalybwlys,Галиполис,غاليبوليس', 38.8098000, -82.2023700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135114, 'Geneva', 'Geneva', 'Flagdale,Geneva,Genova', 39.6620100, -82.4334900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135115, 'Georgetown', 'Georgetown', 'Dzordztaun,George Town,Georgetown,jwrjtawn,Џорџтаун,جارج ٹاؤن، اوہائیو,جورجتاون', 38.8645100, -83.9040900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135116, 'Germantown', 'Germantown', 'German Town,Germantown,Twin City', 39.6261700, -84.3693900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135117, 'Glendale', 'Glendale', 'Fosdick,Glendale,Glendejl,Глендейл', 39.2706100, -84.4593900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135118, 'Glouster', 'Glouster', 'Glouster,Sedalia', 39.5031300, -82.0845900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135119, 'Golf Manor', 'Golf Manor', '', 39.1872800, -84.4463300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135120, 'Goshen', 'Goshen', 'Goshen,Гошен', 39.2333900, -84.1613200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135121, 'Grandview', 'Grandview', '', 39.1942200, -84.7243900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135122, 'Grandview Heights', 'Grandview Heights', '', 39.9797900, -83.0407400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135123, 'Green Meadows', 'Green Meadows', '', 39.8689500, -83.9443800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135124, 'Greenfield', 'Greenfield', 'Greenfield,Grinfild,Massietown,McArthurs Town,Гринфилд', 39.3520100, -83.3826900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135125, 'Greenhills', 'Greenhills', 'Green Hills,Greenhills', 39.2681100, -84.5230000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135126, 'Groesbeck', 'Groesbeck', 'Goesbeck,Groesbeck,Grosbeck,West Union', 39.2231100, -84.5868900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135127, 'Grove City', 'Grove City', 'Grouv Siti,Grove,Grove City,ghrwf syty,grww syty  awhayw,Гроув Сити,غروف سيتي,گروو سیتی، اوهایو', 39.8814500, -83.0929600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135128, 'Groveport', 'Groveport', 'Groveport,Grovport,Rarey''s Port,Wert''s Grove,ghrwfbwrt,Гровпорт,غروفبورت', 39.8784000, -82.8837900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135129, 'Hamilton', 'Hamilton', 'Fort Hamilton,Gamil''ton,HAO,Hamilton,Hamilton!,Khamilton,Khamiltun,Khehmilton,Rossville,haemilteon,hamiruton,hamltn,han mi er dun,hmyltwn  awhayw,Гамильтон,Гамільтон,Хамилтон,Хамилтън,Хэмилтон,هاملتن,همیلتون، اوهایو,ہیملٹن، اوہائیو,ハミルトン,漢密爾頓,해밀턴', 39.3995000, -84.5613400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135130, 'Harbor Hills', 'Harbor Hills', '', 39.9367300, -82.4351500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135131, 'Harrison', 'Harrison', 'Kharrison,Харрисон', 39.2620000, -84.8199500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135132, 'Hebron', 'Hebron', '', 39.9617300, -82.4912700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135133, 'Highpoint', 'Highpoint', 'High Point,Highpoint', 39.2883900, -84.3502200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135134, 'Hillsboro', 'Hillsboro', 'Hillsboro,Hillsborough,Hillsbury,Khillsboro,Хиллсборо', 39.2022900, -83.6115900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135135, 'Holiday Valley', 'Holiday Valley', '', 39.8561700, -83.9685400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135136, 'Huber Heights', 'Huber Heights', 'Khabehr Khehjts,hwbr hayts,hywbr hayts  awhayw,Хабэр Хэйтс,هوبر هايتس,هیوبر هایتس، اوهایو,وین ٹاؤن شپ، مونٹگمری کاؤنٹی، اوہائیو', 39.8439500, -84.1246600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135137, 'Hunter', 'Hunter', '', 39.4928400, -84.2896600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135138, 'Ironton', 'Ironton', 'Ajronton,Iron Town,Ironton,New Town,Newtown,ayrntwn,ayrwntwn  awhayw,Ајронтон,Иронтон,أيرنتون,ایرونتون، اوهایو', 38.5367500, -82.6829400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135139, 'Jackson', 'Jackson', 'Dzekson,Dzhehkson,Dzhekson,Jackson,Jackson Court House,Poplar Row,Salt Lick,Scioto Salt Licks,Scioto Salt Works,jakswn,jakuson,jkswn  awhayw,Џексон,Джексон,Джэксон,جاكسون,جکسون، اوهایو,جیکسن، اوہائیو,ジャクソン', 39.0520200, -82.6365500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135140, 'Jamestown', 'Jamestown', 'James Town,Jamestown', 39.6581200, -83.7349200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135141, 'Jeffersonville', 'Jeffersonville', '', 39.6536700, -83.5638100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135142, 'Kenwood', 'Kenwood', '', 39.2106100, -84.3671600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135143, 'Kettering', 'Kettering', 'Kehttering,Ketering,Kettering,katrngh,keteoling,ktryng  awhayw,Кетеринг,Кеттеринг,Кэттеринг,كاترنغ,کترینگ، اوهایو,کیٹرنگ، اوہائیو,케터링', 39.6895000, -84.1688300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135144, 'Kings Mills', 'Kings Mills', 'Gainsboro,King''s Mills,Kings Mills', 39.3556100, -84.2485500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135145, 'Kingston', 'Kingston', 'Ingstown,Kingston,Kingstown,Кингстон', 39.4739500, -82.9107300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135146, 'Lake Darby', 'Lake Darby', '', 39.9572800, -83.2288000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135147, 'Lancaster', 'Lancaster', 'Lancaster,Lankastehr,Lankaster,New Lancaster,lankstr,lankstr  awhayw,Ланкастер,Ланкастэр,لانكستر,لانکستر، اوهایو,لانکیسٹر، اوہائیو', 39.7136800, -82.5993300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135148, 'Landen', 'Landen', '', 39.3120000, -84.2829900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135149, 'Lebanon', 'Lebanon', 'Lebanon,lbanwn  awhayw,lbnan,lebeoneon,Лебанон,لبانون، اوهایو,لبنان,레버넌', 39.4353400, -84.2029900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135150, 'Leesburg', 'Leesburg', 'Leesburg,Leesburgh,Lexington,Lexington Station', 39.3450600, -83.5529700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135151, 'Lewisburg', 'Lewisburg', 'Lewisburg,Lewisburgh', 39.8461600, -84.5396700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135152, 'Lincoln Heights', 'Lincoln Heights', '', 39.2389500, -84.4555000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135153, 'Lincoln Village', 'Lincoln Village', '', 39.9547900, -83.1307400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135154, 'Lisbon', 'Lisbon', '', 39.8608900, -83.6352000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135155, 'Lithopolis', 'Lithopolis', 'Centerville,Centreville,Lithopolis,Lower Centreville,Lythopolis', 39.8028400, -82.8062800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135156, 'Lockland', 'Lockland', 'Lokland,lwkland,Локланд,لوكلاند', 39.2292200, -84.4577200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135157, 'Logan', 'Logan', 'Logan,lwgan  awhayw,lwghan,Логан,لوغان,لوگان، اوهایو', 39.5400700, -82.4071000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135158, 'Logan Elm Village', 'Logan Elm Village', '', 39.5697800, -82.9518500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135159, 'London', 'London', 'Landon,Limerick,London,New London,lndn,lndn  awhayw,Ландон,لندن,لندن، اوهایو', 39.8864500, -83.4482500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135160, 'Loveland', 'Loveland', 'Lavland,Lavlehnd,Lavlend,Loveland,Lovelands,Lovlend,Paxton,lawlnd  awhayw,leobeulaendeu,luo fu lan de,lwfland,raburando,Лавланд,Лавленд,Лавлэнд,Ловленд,لاولند، اوهایو,لوفلاند,لولینڈ، اوہائیو,ラブランド,洛弗兰德,러브랜드', 39.2689500, -84.2638300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135161, 'Loveland Park', 'Loveland Park', '', 39.2997800, -84.2632700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135162, 'Lucasville', 'Lucasville', 'George,Lucasville', 38.8795200, -82.9968400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135163, 'Lynchburg', 'Lynchburg', '', 39.2417300, -83.7913100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135164, 'Mack', 'Mack', '', 39.1581100, -84.6496700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135165, 'Madeira', 'Madeira', 'Madeira,Maderia Station,Madiera,Medeira', 39.1908900, -84.3635500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135166, 'Manchester', 'Manchester', 'Manchester,Masseys Station,Манчестер', 38.6881300, -83.6093600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135167, 'Mariemont', 'Mariemont', 'Mariemont,Marimont', 39.1450600, -84.3743800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135168, 'Marietta', 'Marietta', 'Adelphi,Adelphia,Campus Martius,Marietta,Marijeta,Muskingham,ma li ai ta,maelieta,maryta  awhayw,maryyta,Мариетта,Маријета,مارييتا,ماریتا، اوهایو,玛丽埃塔,매리에타', 39.4153500, -81.4548400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135169, 'Mason', 'Mason', 'Kirkwood,Mason,Mehjson,Mehson,Mejson,Palmyra,maswn  awhayw,maysn,Мейсон,Мејсон,Мэйсон,Мэсон,ماسون، اوهایو,مايسن,میسن، اوہائیو', 39.3600600, -84.3099400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135170, 'Mayfield', 'Mayfield', '', 39.4947800, -84.3727200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135171, 'McArthur', 'McArthur', 'Makartur,McArthur,McArthurstown,mk arthr,Макартур,مك أرثر', 39.2464600, -82.4784900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135172, 'McConnelsville', 'McConnelsville', 'Makonelsvil,McConnellsville,McConnelsville,Mcconnelsville,Old Town,mk kwnylsfyl,Маконелсвил,مك كونيلسفيل', 39.6486800, -81.8531900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135173, 'Miami Heights', 'Miami Heights', '', 39.1650600, -84.7205000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135174, 'Miamisburg', 'Miamisburg', 'Holes Station,Majamisberg,Majamisburg,Miamis Berg,Miamisburg,myamysbwrg  awhayw,myamysbyrgh,Майамисбург,Мајамисберг,مياميسبيرغ,میامیسبورگ، اوهایو', 39.6428400, -84.2866100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135175, 'Miamitown', 'Miamitown', 'Miami,Miami Town,Miamitown', 39.2158900, -84.7041100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135176, 'Middleport', 'Middleport', 'Coal Port,Coalport,Middleport,Midlport,Salisbury,Sheffield,mydlbwrt,Мидлпорт,ميدلبورت', 39.0017500, -82.0487500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135177, 'Middletown', 'Middletown', 'Middle Town,Middletown,Middltaun,Midltaun,mideultaun,mydltawn,mydltawwn  awhayw,Миддлтаун,Мидлтаун,Мідлтаун,ميدلتاون,مڈل ٹاؤن، اوہائیو,میدلتاوون، اوهایو,미들타운', 39.5150600, -84.3982800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135178, 'Milford', 'Milford', 'Hagamans Mills,Hagemans Mills,Milford,Millford,mylfwrd  awhayw,Милфорд,ميلفورد، أوهايو,میلفورد، اوهایو', 39.1753400, -84.2943800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135179, 'Millersport', 'Millersport', '', 39.9000600, -82.5340500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135180, 'Monroe', 'Monroe', 'Monro,Monroe,Monroe Station,Monroj,mwnrw,mwnrw  awhayw,Монро,Монрой,مونرو,مونرو، اوهایو', 39.4403400, -84.3621600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135181, 'Monfort Heights', 'Monfort Heights', 'Monfort Heights,Montfort Heights', 39.1883900, -84.5952200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135182, 'Montgomery', 'Montgomery', 'Montgomeri,Montgomery,Montgomery Station,meng ge ma li,mwntghwmry,mwntgwmry  awhayw,Монтгомери,مونتغومري,مونتگومری، اوهایو,مونٹگمری، اوہائیو,蒙哥马利', 39.2281100, -84.3541100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135183, 'Moraine', 'Moraine', 'Morajn,Morejn,mwrayn  awhayw,mwryn,Морайн,Морејн,موراین، اوهایو,مورين', 39.7061700, -84.2193800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135184, 'Morrow', 'Morrow', 'Morrow,Morrows', 39.3545000, -84.1271600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135185, 'Mount Carmel', 'Mount Carmel', 'Cherry Grove,Glenrose,Karmel'',Mount Carmel,Union Town,Кармель', 39.1058900, -84.3041000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135186, 'Mount Healthy', 'Mount Healthy', 'Mount Healthy,Mount Pleasant', 39.2336700, -84.5457800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135187, 'Mount Healthy Heights', 'Mount Healthy Heights', '', 39.2703300, -84.5680000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135188, 'Mount Orab', 'Mount Orab', 'Mount Horab,Mount Orab,Mount Oreb', 39.0275700, -83.9196500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135189, 'Mount Repose', 'Mount Repose', '', 39.2006200, -84.2243800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135190, 'Mount Sterling', 'Mount Sterling', 'Coaldale,Mount Starling,Mount Sterling,Mount Stirling', 39.7195100, -83.2651900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135191, 'Mulberry', 'Mulberry', 'Mulberry,New Salisbury,New Salsberry,New Salsbury,Newberry', 39.1933900, -84.2421600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135192, 'Nelsonville', 'Nelsonville', 'Englishtown,Nehlsonvill,Nelsonvil,Nelsonville,Nelsunvil,nlswnwyl  awhayw,nylswnfyl,Нелсонвил,Нелсънвил,Нэлсонвилл,نلسونویل، اوهایو,نيلسونفيل', 39.4586800, -82.2318200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135193, 'New Boston', 'New Boston', '', 38.7523000, -82.9368400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135194, 'New Burlington', 'New Burlington', 'Burlington,New Burlington,Transit', 39.2595000, -84.5571700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135195, 'New Carlisle', 'New Carlisle', 'Carlisle,Monroe,New Carlisle,York', 39.9361700, -84.0254900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135196, 'New Concord', 'New Concord', 'Concord,Concord Station,New Concord', 39.9936800, -81.7340200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135197, 'New Lebanon', 'New Lebanon', 'Medill,New Lebanon', 39.7453300, -84.3849500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135198, 'New Lexington', 'New Lexington', 'Lexington,N''ju-Leksington,New Lexington,Nju Leksington,Nju Leksingtun,nyw lksynghtwn,nyw lksyngtwn  awhayw,Њу Лексингтон,Нью-Лексингтон,Нью-Лексінґтон,Ню Лексингтън,نيو لكسينغتون,نیو لکسینگتون، اوهایو', 39.7139600, -82.2084800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135199, 'New Matamoras', 'New Matamoras', 'Matamoras,Metamoras,New Matamora,New Matamoras,New Metamoras', 39.5245200, -81.0670500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135200, 'New Miami', 'New Miami', 'New Miami,New River Junction', 39.4347800, -84.5368900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135201, 'New Paris', 'New Paris', 'New Paris,Paris', 39.8569900, -84.7932900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135202, 'New Richmond', 'New Richmond', 'New Richmond,Susanna,Susannah', 38.9486800, -84.2799400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135203, 'New Vienna', 'New Vienna', 'Buzzards Glory,New Vienna,New Viennia,North Vienna,Vienna,Vienna Station', 39.3236700, -83.6910300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135204, 'Newport', 'Newport', 'Newport,Upper Newport', 39.3909100, -81.2267800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135205, 'Newtown', 'Newtown', 'Mercers Station,Mercersburg,Mercersburgh,New Town,Newton,Newtown,Njutaun,nywthn,Њутаун,نيوثن,نیو ٹاؤن، اوہائیو', 39.1245000, -84.3616100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135206, 'North College Hill', 'North College Hill', 'Clarks Store,Clarksburg,Clovernook,North College Hill', 39.2183900, -84.5507800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135207, 'North Fork Village', 'North Fork Village', 'North Folk Village,North Fork Village', 39.3359000, -83.0290700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135208, 'North Zanesville', 'North Zanesville', '', 39.9786800, -82.0034700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135209, 'Northbrook', 'Northbrook', '', 39.2464500, -84.5835600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135210, 'Northgate', 'Northgate', '', 39.2528300, -84.5924500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135211, 'Northridge', 'Northridge', '', 39.9917300, -83.7785400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135212, 'Northridge', 'Northridge', 'Ebenezer,Northridge', 39.8075600, -84.1968900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135213, 'Norwood', 'Norwood', 'Norvud,Norwood,Sharpsburg,nwrwwd,nwrwwd  awhayw,Норвуд,نوروود,نوروود، اوهایو', 39.1556100, -84.4596600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135214, 'Oak Hill', 'Oak Hill', 'Menager,Oak Hill,Oakhill,Portland', 38.8939600, -82.5734900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135215, 'Oakwood', 'Oakwood', 'Oakvud,Oukvud,awakwwd  awhayw,awkwwd,Оаквуд,Оуквуд,أوكوود,اواکوود، اوهایو,اوکووڈ، مونٹگمری کاؤنٹی، اوہائیو', 39.7253400, -84.1741100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135216, 'Obetz', 'Obetz', 'Obetz,Obetz Junction', 39.8789500, -82.9507400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135217, 'Oxford', 'Oxford', 'OXD,Oksford,aksfwrd  awhayw,awksfwrd,Оксфорд,آکسفورڈ، اوہائیو,أوكسفورد,اکسفورد، اوهایو', 39.5070000, -84.7452300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135218, 'Park Layne', 'Park Layne', '', 39.8864500, -84.0396600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135219, 'Pataskala', 'Pataskala', 'Pataskala,bataskala,pataskala  awhayw,Патаскала,باتاسكالا,پاتاسکالا، اوهایو', 39.9956200, -82.6743300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135220, 'Peebles', 'Peebles', '', 38.9489600, -83.4057500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135221, 'Pickerington', 'Pickerington', 'Jacksonville,Pickering,Pickerington,Pikerington,bykyrynghtwn,pykryngtwn  awhayw,Пикерингтон,بيكيرينغتون,پیکرینگتون، اوهایو', 39.8842300, -82.7535000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135222, 'Piketon', 'Piketon', 'Jefferson,Millers Bank,Pajkton,Piketon,bykytwn,Пайктон,Пајктон,بيكيتون', 39.0681300, -83.0143400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135223, 'Pleasant Grove', 'Pleasant Grove', '', 39.9520100, -81.9590200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135224, 'Pleasant Run', 'Pleasant Run', 'Pleasant Run,Pleasantrun', 39.2997800, -84.5635600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135225, 'Pleasant Run Farm', 'Pleasant Run Farm', '', 39.3031100, -84.5480000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135226, 'Pomeroy', 'Pomeroy', 'Nyesville,Pamroj,Pomeroy,Памрој', 39.0275800, -82.0337500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135227, 'Portsmouth', 'Portsmouth', 'Logtown,PMH,Portsmaus,Portsmouth,Portsmut,bwrtsmwth,pu ci mao si,pwrtsmwth  awhayw,Портсмаус,Портсмут,بورتسموث,پورتسموث، اوهایو,朴次茅斯', 38.7317400, -82.9976700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135228, 'Powhatan Point', 'Powhatan Point', 'Pawhattan Point,Powhatan,Powhatan Point,Powhattan,Powhattan Point', 39.8600800, -80.8153700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135229, 'Reading', 'Reading', 'Reading,Reding,Vorheestown,Рединг', 39.2236700, -84.4421600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135230, 'Reno', 'Reno', '', 39.3728500, -81.3956700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135231, 'Reynoldsburg', 'Reynoldsburg', 'Frenchtown,Rehjnoldsburg,Rejnoldsberg,Reynoldsburg,Reynoldsburgh,Roynoldsburg,rynwldsbwrg  awhayw,rynwldzbwrgh,Рејнолдсберг,Рэйнолдсбург,رينولدزبورغ,رینولدسبورگ، اوهایو', 39.9547900, -82.8121200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135232, 'Ripley', 'Ripley', 'Ripley,Rixs Mills,Staunton', 38.7456300, -83.8449200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135233, 'Riverside', 'Riverside', 'Harshmanville,Rivehsajd,River Side,Riversajd,Riverside,ryfrsayd,rywrsayd  awhayw,Риверсайд,Риверсајд,Ривэсайд,رورسائیڈ، اوہائیو,ريفرسايد,ریورساید، اوهایو', 39.7797800, -84.1241000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135234, 'Rosemount', 'Rosemount', 'Rosemont,Rosemont Hollow,Rosemount,Rosemount Hollow', 38.7861900, -82.9790600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135235, 'Ross', 'Ross', 'Ross,Venice,Venince,Venus,Vince', 39.3122800, -84.6505000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135236, 'Roseville', 'Roseville', 'Milford,New Milford,Roseville,Rozvell,Розвелл', 39.8072900, -82.0712500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135237, 'Rossmoyne', 'Rossmoyne', 'East Sycamore,Mill Dale,Rossmoyne', 39.2136700, -84.3868800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135238, 'Sabina', 'Sabina', 'Sabina,Sapina', 39.4886700, -83.6368700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135239, 'Saint Bernard', 'Saint Bernard', '', 39.1670000, -84.4985500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135240, 'Salem Heights', 'Salem Heights', '', 39.0717300, -84.3782700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135241, 'Sciotodale', 'Sciotodale', '', 38.7548000, -82.8687800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135242, 'Shadyside', 'Shadyside', 'Shady Side,Shadyside,Shadyside Station', 39.9709100, -80.7506400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135243, 'Sharonville', 'Sharonville', 'Sharon,Sharon Station,Sharon Village,Sharonvil,Sharonvill,Sharonville,Sharron,Sharunvil,sharwnfyl,sharwnwyl  awhayw,Шаронвил,Шаронвилл,Шарънвил,شارونفيل,شارونویل، اوهایو', 39.2681100, -84.4132700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135244, 'Shawnee Hills', 'Shawnee Hills', '', 39.6528400, -83.7868700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135245, 'Sherwood', 'Sherwood', '', 39.0847800, -84.3607700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135246, 'Shiloh', 'Shiloh', '', 39.8186700, -84.2285500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135247, 'Silverton', 'Silverton', 'Mosner,Silverton', 39.1928400, -84.4005000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135248, 'Sixteen Mile Stand', 'Sixteen Mile Stand', 'Sixteen Mile Stand,Sixteenmile Stand', 39.2728400, -84.3274400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135249, 'Skyline Acres', 'Skyline Acres', '', 39.2286700, -84.5668900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135250, 'Somerset', 'Somerset', 'Middleton,Samerset,Somerset,samrst,Самерсет,Сомерсет,سامرست', 39.8070100, -82.2970900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135251, 'South Bloomfield', 'South Bloomfield', 'Bloomfield,South Bloomfield', 39.7184000, -82.9868500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135252, 'South Charleston', 'South Charleston', 'Charleston,Charlestown,South Charleston,South Charlestown', 39.8253400, -83.6343700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135253, 'South Lebanon', 'South Lebanon', 'Deerfield,Deerfieldville,South Lebanon', 39.3708900, -84.2132700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135254, 'South Point', 'South Point', 'Greens Store,Saut Pojnt,South Point,Southpoint,sawt bwynt,Саут Појнт,ساوت بوينت', 38.4178600, -82.5862700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135255, 'South Zanesville', 'South Zanesville', 'Natchez,South Zanesville', 39.8992300, -82.0062500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135256, 'Springboro', 'Springboro', 'Sprigbaro,Springboro,Springborou,Springborough,Springsboro,aspryngbwrw  awhayw,sbrynghbwrw,Спригбаро,Спрингбороу,اسپرینگبورو، اوهایو,سبرينغبورو', 39.5522800, -84.2332700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135257, 'Springdale', 'Springdale', 'Spring Dale,Springdale,Springdale Village,Springdehjl,Springdejl,Springfield,aspryngdyl  awhayw,sbrynghdyl,Спрингдејл,Спрингдэйл,اسپرینگدیل، اوهایو,سبرينغديل', 39.2870000, -84.4852200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135258, 'Springfield', 'Springfield', 'Gillistown,Post Town,SGH,Springfield,Springfild,aspryngfyld  awhayw,sbrynghfyld,seupeulingpildeu,si pu lin fei er de,spryngpyld,supuringufirudo,Спрингфилд,Спрінгфілд,ספרינגפילד,اسپرینگفیلد، اوهایو,سبرينغفيلد,سپرنگفیلڈ، اوہائیو,སི་པི་རིང་ཧྥིལ་ཌི།,スプリングフィールド,斯普林菲尔德,스프링필드', 39.9242300, -83.8088200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135259, 'Summerside', 'Summerside', '', 39.1047800, -84.2882700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135260, 'Terrace Park', 'Terrace Park', 'Camden City,Miami Grove,Terrace Park,Terrace Park Station', 39.1592300, -84.3071600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135261, 'The Plains', 'The Plains', '', 39.3689600, -82.1323700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135262, 'The Village of Indian Hill', 'The Village of Indian Hill', '', 39.1794900, -84.3351700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135263, 'Thornport', 'Thornport', 'New Lebanon,Thornport,Thornville Station', 39.9131200, -82.4109900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135264, 'Tipp City', 'Tipp City', 'Hyattsville,Livingston,Tip Siti,Tipp City,Tipp Siti,Tippecanoe,Tippecanoe City,tyb syty,typ syty  awhayw,Тип Сити,Типп Сити,تيب سيتي,تیپ سیتی، اوهایو', 39.9583900, -84.1721600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135265, 'Trenton', 'Trenton', 'Bloomfield,Tenton,Trenton,trntwn  awhayw,Трентон,ترنتون، اوهایو', 39.4808900, -84.4577200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135266, 'Trotwood', 'Trotwood', 'Higgins Station,Trotvud,Trotwood,trwtwwd,Тротвуд,تروتوود,تروت‌وود، اوهایو', 39.7972800, -84.3113300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135267, 'Union', 'Union', '', 39.8978300, -84.3063300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135268, 'Upper Arlington', 'Upper Arlington', 'Aper Arlington,Appa Arlington,apr arlyngtwn  awhayw,awbyr arlynghtwn,Апер Арлингтон,Аппа Арлингтон,أوبير أرلينغتون,اپر ارلینگتون، اوهایو', 39.9945100, -83.0624100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135269, 'Urbancrest', 'Urbancrest', '', 39.8975600, -83.0868500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135270, 'Vandalia', 'Vandalia', 'Vandalia,Vandejlija,fandalya,wan da li ya,wndalya  awhayw,Вандалиа,Вандејлија,فانداليا,وندالیا، اوهایو,万达利亚', 39.8906100, -84.1988300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135271, 'Washington Court House', 'Washington Court House', 'Vashington Kourt Khaus,Voshington Kort Khaus,Washington,Washington Court House,Washington Courthouse,washntn kwrt haws,washyngtn kwrt haws  awhayw,Вашингтон Коурт Хаус,Вошингтон Корт Хаус,واشنطن كورت هاوس,واشنگٹن، اوہائیو,واشینگتن کورت هاوس، اوهایو', 39.5364500, -83.4390800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135272, 'Waverly', 'Waverly', 'Union,Uniontown,Waverly,Waverly City,wyfrly,wywrly  awhayw,ويفرلي,ویورلی، اوهایو', 39.1267300, -82.9854600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135273, 'Waynesville', 'Waynesville', 'Vejnsvil,Вејнсвил', 39.5297800, -84.0866000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135274, 'Wellston', 'Wellston', '', 39.1234100, -82.5329400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135275, 'West Alexandria', 'West Alexandria', 'Alexander,West Alexander,West Alexandria', 39.7445000, -84.5321700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135276, 'West Carrollton City', 'West Carrollton City', 'Alexandersville,Alexanderville,Alexandriaville,Carrollton,Carrolton,West Carrollton City,West Carrolton', 39.6722800, -84.2521600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135277, 'West Jefferson', 'West Jefferson', 'Hamden,Jefferson,New Hamden,New Hampton,West Jefferson,West Jefferson Station', 39.9447800, -83.2688000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135278, 'West Milton', 'West Milton', 'Milton,West Milton', 39.9625500, -84.3280000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135279, 'West Portsmouth', 'West Portsmouth', 'Bertha,Nauvoo,Union Mill,Union Mills,West Portsmouth', 38.7584100, -83.0290600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135280, 'West Union', 'West Union', 'Adamsville,Scant,Vest Junion,West Union,wst ywnywn,xi you ning,Вест Јунион,وست يونيون,ویسٹ یونین، اوہائیو,西尤宁', 38.7945200, -83.5451900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135281, 'Wetherington', 'Wetherington', '', 39.3636700, -84.3774400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135282, 'Wheelersburg', 'Wheelersburg', 'Concord,Wheelersburg,Wheelersburgh', 38.7303500, -82.8554500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135283, 'White Oak', 'White Oak', 'Creedville,White Oak', 39.2131100, -84.5993900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135284, 'Whitehall', 'Whitehall', 'Uajtkhol,Vajtkhol,wayt hwl,wythal  awhayw,Вајтхол,Уайтхол,وائٹ ہال، اوہائیو,وايت هول,ویتهال، اوهایو', 39.9667300, -82.8854600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135285, 'Wilberforce', 'Wilberforce', 'Tawawa Springs,Wilberforce', 39.7161700, -83.8777100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135286, 'Williamsburg', 'Williamsburg', 'Lytles Town,Lytlestown,Williamsburg,Williamsburgh', 39.0542300, -84.0529900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135287, 'Williamsport', 'Williamsport', '', 39.5859000, -83.1204600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135288, 'Wilmington', 'Wilmington', 'Armenia,Clinton,ILN,Mount Pleasant,Robertsons Mills,Uilmington,Vilmington,Wilmington,u~iruminton,wylmnghtwn,wylmyngtwn  awhayw,Вилмингтон,Уилмингтон,ويلمنغتون,ویلمینگتون، اوهایو,ویلمینگٹن، اوہائیو,ウィルミントン', 39.4453400, -83.8285400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135289, 'Winchester', 'Winchester', 'New Market,Scott,South Winchester,Winchester', 38.9417400, -83.6507500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135290, 'Withamsville', 'Withamsville', 'Withams,Withamsville', 39.0622800, -84.2882700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135291, 'Woodlawn', 'Woodlawn', '', 39.2520000, -84.4702200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135292, 'Woodsfield', 'Woodsfield', 'Woodfield,Woodsfield', 39.7625700, -81.1153800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135293, 'Wyoming', 'Wyoming', 'Vajoming,waywmyng  awhayw,wwywmyngh,Вайоминг,Вајоминг,وائیومنگ، اوہائیو,وایومینگ، اوهایو,وويومينغ', 39.2311700, -84.4657800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135294, 'Xenia', 'Xenia', 'Exenia,Ksenia,Ksenija,Xenia,Zenea,Zinija,znya  awhayw,zynya,Зинија,Ксениа,Ксения,زنیا، اوهایو,زينيا', 39.6847800, -83.9296500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135295, 'Yellow Springs', 'Yellow Springs', 'Forest Village,Forrest Village,Jelou Springs,Ludlow,Yellow Spring,Yellow Springs,Yellowsprings,ylw sbrynghz,Јелоу Спрингс,يلو سبرينغز,یلو اسپرنگس، اوہائیو', 39.8064500, -83.8868700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135296, 'Zanesville', 'Zanesville', 'Westbourne,ZZV,Zanes Town,Zanesville,Zehjnsvill,Zejnsvil,ceng si wei er,zanysfyl,zeinzubiru,znswyl  awhayw,Зејнсвил,Зэйнсвилл,زانيسفيل,زنسویل، اوهایو,ゼインズビル,曾斯維爾', 39.9403500, -82.0131900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135297, 'Ada', 'Ada', 'ADT,Ada,Ejda,ada,ayda  aklahma,eida,Ада,Ејда,أدا,ایدا، اکلاهما,ایڈا، اوکلاہوما,에이다', 34.7745300, -96.6783400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135298, 'Afton', 'Afton', 'Aftan,Ehfton,aftwn,aftwn  aklahma,Афтан,Эфтон,أفتون,افتون، اکلاهما', 36.6936900, -94.9630200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135299, 'Altus', 'Altus', 'Altus,Frazier,LTS,altws,altws  aklahma,Алтус,آلتوس، اکلاهما,ألتوس', 34.6381300, -99.3339800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135300, 'Alva', 'Alva', 'Alva,alfa,alwa  aklahma,Алва,آلوا، اکلاهما,ألفا', 36.8049900, -98.6671800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135301, 'Anadarko', 'Anadarko', 'Anadarko,Vetapahaetoe-mahoevehoeno,Vétapâhaetoe-mâhoévehoéno,anadarkw,anadarkw  aklahma,Анадарко,أناداركو,انادارکو، اکلاهما', 35.0725600, -98.2436600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135302, 'Antlers', 'Antlers', 'ATE,Antlehrs,Antlers,antlr  aklahma,antlyrs,Антлерс,Антлэрс,أنتليرس,انتلر، اکلاهما', 34.2312100, -95.6202500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135303, 'Apache', 'Apache', '', 34.8936800, -98.3658900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135304, 'Arapaho', 'Arapaho', '', 35.5778300, -98.9645300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135305, 'Ardmore', 'Ardmore', 'ADM,Ardmor,admwr,ardmr  aklahma,Ардмор,آردمر، اکلاهما,آرڈمور، اوکلاہوما,أدمور', 34.1742600, -97.1436300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135306, 'Arkoma', 'Arkoma', '', 35.3545400, -94.4341000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135307, 'Arnett', 'Arnett', '', 36.1350400, -99.7748400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135308, 'Atoka', 'Atoka', 'Ato,Atoka,atwka,atwka  aklahma,Атока,أتوكا,اتوکا، اکلاهما', 34.3859300, -96.1283300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135309, 'Barnsdall', 'Barnsdall', 'Barnsdall,Bigheart', 36.5620200, -96.1616700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135310, 'Bartlesville', 'Bartlesville', 'BVO,Bartlehsvill,Bartlesvil,Bartlsvill,bartlzwyl  aklahma,bateuljeubil,brtlsfyl,Бартлесвил,Бартлсвилл,Бартлэсвилл,بارتلزویل، اکلاهما,بارٹلزویل، اوکلاہوما,برتلسفيل,바틀즈빌', 36.7473100, -95.9808200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135311, 'Beggs', 'Beggs', '', 35.7426000, -96.0702700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135312, 'Bethany', 'Bethany', 'Behsani,Betani,btny  aklahma,bythany,Бетани,Бэсани,بتنی، اکلاهما,بيثاني,بیتھانی، اوکلاہوما', 35.5186700, -97.6322600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135313, 'Bethel Acres', 'Bethel Acres', '', 35.3086800, -97.0255800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135314, 'Bixby', 'Bixby', 'Biksbi,byksby,byksby  aklahma,Биксби,بيكسبي,بیکسبی، اوکلاہوما,بیکسبی، اکلاهما', 35.9420400, -95.8833200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135315, 'Blackwell', 'Blackwell', 'BWL,Blackwell,Blakvehll,Blekvel,Parker,blakwyl,blkwl  aklahma,Блаквэлл,Блеквел,بلاكويل,بلکول، اکلاهما', 36.8044800, -97.2828200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135316, 'Blanchard', 'Blanchard', 'Blanchard,Blehnkhard,blanchard  aklahma,blanshard,Бланчард,Блэнхард,بلانشارد,بلانچارد، اکلاهما', 35.1378400, -97.6580900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135317, 'Boley', 'Boley', 'Boli,bwly  aklahma,Боли,بولی، اکلاهما', 35.4934100, -96.4836200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135318, 'Bray', 'Bray', '', 34.6378600, -97.8175300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135319, 'Bristow', 'Bristow', 'Bristou,brystw,brystww  aklahma,Бристоу,بريستو,بریستوو، اکلاهما', 35.8306300, -96.3911200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135320, 'Broken Arrow', 'Broken Arrow', 'Broken Arou,Broken Arrow,Broken-Ehrrou,Broken-Errov,Broukehn Arrou,beulokeun-aelo,brwkn arw,brwkn arww  aklahma,burokun''aro,Брокен Ароу,Брокен-Ерров,Брокен-Эрроу,Броукэн Арроу,ברוקן ארו,بروكن أرو,بروکن اروو، اکلاهما,بروکن ایرو، اوکلاہوما,ブロークンアロー,브로큰애로', 36.0526000, -95.7908200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135321, 'Broken Bow', 'Broken Bow', 'Broken Bou,Broukehn Bou,brwkn baw  aklahma,brwkn bw,Брокен Боу,Броукэн Боу,بروكن بو,بروکن باو، اکلاهما', 34.0292800, -94.7391000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135322, 'Buffalo', 'Buffalo', 'Brule,Bufalo,Buffalo,bwfalw,bwfalw  aklahma,Буфало,Буффало,بفیلو، اوکلاہوما,بوفالو,بوفالو، اکلاهما', 36.8355900, -99.6304000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135323, 'Burns Flat', 'Burns Flat', '', 35.3489400, -99.1703600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135324, 'Bushyhead', 'Bushyhead', '', 36.4614800, -95.4941400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135325, 'Byng', 'Byng', '', 34.8612000, -96.6655700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135326, 'Cache', 'Cache', 'Kach,Kesh,kash,ksh  aklahma,Кач,Кеш,كاش,کش، اکلاهما', 34.6295200, -98.6286700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135327, 'Caddo', 'Caddo', '', 34.1267600, -96.2633200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135328, 'Calera', 'Calera', 'Cale,Calera,Sterrett', 33.9345400, -96.4286000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135329, 'Carnegie', 'Carnegie', '', 35.1036700, -98.6036700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135330, 'Catoosa', 'Catoosa', 'Katusa,katwsa,ktwsa  aklahma,Катуса,كاتوسا,کتوسا، اکلاهما', 36.1889900, -95.7458200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135331, 'Central High', 'Central High', '', 34.6231300, -98.0897600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135332, 'Chandler', 'Chandler', 'Chandlehr,Chandler,chndlr  aklahma,tshandlr,Чандлер,Чандлэр,تشاندلر,چندلر، اکلاهما', 35.7017300, -96.8808600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135333, 'Checotah', 'Checotah', 'Chekota,Chekotakh,chkwtah  aklahma,tshykwta,Чекота,Чекотах,تشيكوتا,چکوتاه، اکلاهما', 35.4701000, -95.5230400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135334, 'Chelsea', 'Chelsea', '', 36.5356500, -95.4324700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135335, 'Cherokee', 'Cherokee', 'CKA,Cherokee,Cheroki,chrky  aklahma,shyrwky,Чероки,شيروكي,چرکی، اکلاهما', 36.7544700, -98.3567400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135336, 'Cheyenne', 'Cheyenne', 'Chejni,Shajen,Shajenn,shayn  aklahma,tshyny,Чейни,Шайенн,Шајен,تشيني,شاین، اکلاهما', 35.6139400, -99.6714900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135337, 'Chickasha', 'Chickasha', 'CHK,Chichashej,Chickasha,Chikasha,Pensee,chykshy  aklahma,tshykasha,Чикаша,Чичашеј,تشيكاشا,چیکشی، اکلاهما', 35.0525700, -97.9364300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135338, 'Choctaw', 'Choctaw', 'Choctaw,Choctaw City', 35.4975600, -97.2689200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135339, 'Chouteau', 'Chouteau', 'Choteau,Chouteau,Chouteau Station', 36.1859300, -95.3430200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135340, 'Claremore', 'Claremore', 'Klehrmor,Klermor,klarmwr,klyrmr  aklahma,Клермор,Клэрмор,كلارمور,کلیرمر، اکلاهما', 36.3126000, -95.6160900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135341, 'Cleora', 'Cleora', 'Cleora,Klaus', 36.5789700, -94.9710700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135342, 'Cleveland', 'Cleveland', 'Cleveland,Herbert,Klivlend,Кливленд', 36.3103200, -96.4658400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135343, 'Clinton', 'Clinton', 'CSM,Klinton,Tsex-hotoxaha,Tséx-hótôxáha,klyntn  aklahma,klyntwn,Клинтон,كلينتون,کلنٹن، اوکلاہوما,کلینتن، اکلاهما', 35.5156100, -98.9673100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135344, 'Colbert', 'Colbert', '', 33.8531600, -96.5024900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135345, 'Collinsville', 'Collinsville', 'Collins,Collinsville,Kollinsvil'',Коллинсвиль', 36.3645400, -95.8388800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135346, 'Comanche', 'Comanche', 'Comanche,Tucker', 34.3689700, -97.9639200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135347, 'Commerce', 'Commerce', 'Commerce,Komers,Kommehrs,North Miami,kamrs  aklahma,kwmyrk,Комерс,Коммэрс,كوميرك,کامرس، اوکلاہوما,کامرس، اکلاهما', 36.9334000, -94.8730100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135348, 'Copeland', 'Copeland', 'Copeland,Copeland Switch', 36.6559100, -94.8282900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135349, 'Cordell', 'Cordell', 'Cordell,New Cordell', 35.2906100, -98.9884100, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135350, 'Coweta', 'Coweta', 'Coveda Mission,Coveta Mission,Coweta,Cowetah,Kauehta,Kauita,kwwta  aklahma,kwyta,Кауита,Кауэта,كويتا,کووتا، اکلاهما', 35.9517700, -95.6508100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135351, 'Crescent', 'Crescent', '', 35.9525400, -97.5947700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135352, 'Cushing', 'Cushing', 'CUH,Kashing,Kushing,ku xin,kusing,kwshyng  aklahma,kwshyngh,Кашинг,Кушинг,كوشينغ,کوشینگ، اکلاهما,库欣,쿠싱', 35.9850600, -96.7669700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135353, 'Cyril', 'Cyril', '', 34.8964600, -98.2006000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135354, 'Davis', 'Davis', 'Dehvis,Dejvis,dyfys,dywys  aklahma,Дейвис,Дејвис,Дэвис,ديفيس,دیویس، اکلاهما,ڈیوس، اوکلاہوما', 34.5045300, -97.1194600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135355, 'Del City', 'Del City', 'Dehl Siti,Del City,Del Siti,Dell City,dl syty  aklahma,dyl syty,Дел Сити,Дэл Сити,دل سیتی، اکلاهما,ديل سيتي,ڈیل سٹی، اوکلاہوما', 35.4420100, -97.4408700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135356, 'Dewey', 'Dewey', '', 36.7959200, -95.9355400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135357, 'Dickson', 'Dickson', '', 34.1873200, -96.9844600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135358, 'Drumright', 'Drumright', 'Dramrajt,Drumrajt,drwmrayt,drwmryght  aklahma,Драмрајт,Друмрайт,درومرايت,درومریگهت، اکلاهما', 35.9884000, -96.6011300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135359, 'Duncan', 'Duncan', 'DUC,Dankan,Dunkan,dankn  aklahma,dnkan,Данкан,Дункан,دانکن، اکلاهما,دنكان,ڈنکن، اوکلاہوما', 34.5023000, -97.9578100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135360, 'Durant', 'Durant', 'DUA,Djurant,Durant,drnt  aklahma,dywrant,Дурант,Дюрант,درنت، اکلاهما,ديورانت', 33.9939900, -96.3708200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135361, 'Edmond', 'Edmond', 'Edmond,Edmont,Ehdmon,Ehdmond,Ehdmont,admnd  aklahma,admwnd,edeumeondeu,edomondo,Едмонд,Едмонт,Эдмон,Эдмонд,Эдмонт,אדמונד,إدموند,ادمند، اکلاهما,ایڈمونڈ، اوکلاہوما,エドモンド,에드먼드', 35.6528300, -97.4781000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135362, 'El Reno', 'El Reno', 'Ehl Reno,El Reno,Elreno,Ponoe,al rnw  aklahma,alrynw,Ел Рено,Эл Рено,إلرينو,ال رنو، اکلاهما', 35.5322700, -97.9550500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135363, 'Elgin', 'Elgin', 'Ceegee,Elgin', 34.7803500, -98.2922700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135364, 'Elk City', 'Elk City', 'Busch,ELK,Ehlk Siti,Elk City,Elk Siti,alk syty,alk syty  aklahma,Елк Сити,Элк Сити,إلك سيتي,الک سیتی، اکلاهما', 35.4119900, -99.4042600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135365, 'Enid', 'Enid', 'Ehnid,Enid,Inid,WDG,anyd,aynyd  aklahma,inideu,Енід,Инид,Энид,إنيد,اینڈ، اوکلاہوما,اینید، اکلاهما,이니드', 36.3955900, -97.8783900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135366, 'Erick', 'Erick', 'Ehrik,Erik,aryk,aryk  aklahma,Ерик,Эрик,إريك,اریک، اکلاهما', 35.2153300, -99.8664900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135367, 'Eufaula', 'Eufaula', 'Ehufaula,Eufaula,Jufola,North Fork Town,aywfla  aklahma,ywfawla,Јуфола,Эуфаула,ایوفلا، اکلاهما,يوفاولا', 35.2872200, -95.5825000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135368, 'Fairfax', 'Fairfax', 'Fajafaks,Ferfaks,frfks  aklahma,fyrfaks,Фаяфакс,Ферфакс,فرفکس، اکلاهما,فيرفاكس,فیئرفیکس، اوکلاہوما', 36.5736600, -96.7042000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135369, 'Fairland', 'Fairland', '', 36.7511800, -94.8474600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135370, 'Fairview', 'Fairview', '', 36.2689200, -98.4798000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135371, 'Fletcher', 'Fletcher', '', 34.8231200, -98.2442200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135372, 'Forest Park', 'Forest Park', '', 35.5042300, -97.4461500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135373, 'Fort Gibson', 'Fort Gibson', 'Fort Gibson,frt gybsn  aklahma,fwrt ghybswn,Форт Гибсон,فرت گیبسن، اکلاهما,فورت غيبسون', 35.7976000, -95.2505200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135374, 'Frederick', 'Frederick', 'FDR,Frederik,frdryk  aklahma,frydryk,Фредерик,فردریک، اکلاهما,فريدريك,فریڈرک، اوکلاہوما', 34.3920300, -99.0184100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135375, 'Geary', 'Geary', '', 35.6311600, -98.3172900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135376, 'Geronimo', 'Geronimo', '', 34.4811900, -98.3831100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135377, 'Glenpool', 'Glenpool', '', 35.9553700, -96.0088800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135378, 'Goldsby', 'Goldsby', '', 35.1411800, -97.4769800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135379, 'Granite', 'Granite', '', 34.9622800, -99.3806400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135380, 'Grove', 'Grove', 'Grouv,ghrwf,grww  aklahma,Гроув,غروف,گروو، اکلاهما', 36.5936900, -94.7691200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135381, 'Guthrie', 'Guthrie', 'GOK,Gazri,Guthrie,gatry  aklahma,Газри,گاتری، اکلاهما', 35.8789400, -97.4253200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135382, 'Hall Park', 'Hall Park', '', 35.2370100, -97.4064200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135383, 'Harrah', 'Harrah', '', 35.4895100, -97.1636400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135384, 'Hartshorne', 'Hartshorne', '', 34.8451000, -95.5574800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135385, 'Haskell', 'Haskell', '', 35.8203800, -95.6741500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135386, 'Healdton', 'Healdton', 'Khildton,haldtwn  aklahma,hyldtwn,Хилдтон,هالدتون، اکلاهما,هيلدتون', 34.2331500, -97.4878000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135387, 'Heavener', 'Heavener', 'Khevener,Khivenehr,hawnr  aklahma,hyfnr,Хевенер,Хивенэр,هاونر، اکلاهما,هيفنر', 34.8892700, -94.6007800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135388, 'Helena', 'Helena', 'Khelena,Хелена', 36.5461400, -98.2700700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135389, 'Hennessey', 'Hennessey', '', 36.1092000, -97.8986700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135390, 'Henryetta', 'Henryetta', 'Khenriehtta,hnryta,hnryta  aklahma,Хенриэтта,هنريتا,هنریتا، اکلاهما', 35.4398300, -95.9819400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135391, 'Hinton', 'Hinton', '', 35.4714400, -98.3556200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135392, 'Hobart', 'Hobart', 'Khobart,hwbart,hwwbrt  aklahma,Хобарт,هوبارت,هووبرت، اکلاهما', 35.0295000, -99.0931300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135393, 'Holdenville', 'Holdenville', 'Kholdenvil,Kholdenvill,hwldnfyl,hwldnwyl  aklahma,Холденвил,Холденвилл,هولدنفيل,هولدنویل، اکلاهما', 35.0803600, -96.3991800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135394, 'Hollis', 'Hollis', 'Khalis,Khollis,hwlys,hwlys  aklahma,Халис,Холлис,هوليس,هولیس، اکلاهما', 34.6883900, -99.9120500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135395, 'Hominy', 'Hominy', 'Khomini,hamny  aklahma,hwmyny,Хомини,هامنی، اکلاهما,هوميني', 36.4142400, -96.3953000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135396, 'Hugo', 'Hugo', 'HUJ,Khjugo,Khugo,hwghw,hywgw  aklahma,Хуго,Хјуго,هوغو,هیوگو، اکلاهما', 34.0106600, -95.5096800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135397, 'Idabel', 'Idabel', 'Bokhoma,Idabehl,Idabel,aydabl  aklahma,aydabyl,Идабэл,إيدابيل,ایدابل، اکلاهما', 33.8956600, -94.8263300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135398, 'Inola', 'Inola', '', 36.1512100, -95.5094200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135399, 'Jay', 'Jay', 'Dzej,Dzhehj,jay,jie li,jy  aklahma,Џеј,Джэй,جاي,جی، اکلاهما,傑里', 36.4211900, -94.7969000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135400, 'Jenks', 'Jenks', 'Dzenks,Dzhenks,jnks,jnks  aklahma,Џенкс,Дженкс,جنكس,جنکس، اکلاهما', 36.0228700, -95.9683300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135401, 'Jones', 'Jones', '', 35.5658900, -97.2869800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135402, 'Justice', 'Justice', '', 36.2928700, -95.5666400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135403, 'Kellyville', 'Kellyville', 'Kelleyville,Kellyville', 35.9437000, -96.2136100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135404, 'Kenwood', 'Kenwood', '', 36.3145300, -94.9857900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135405, 'Kiefer', 'Kiefer', '', 35.9448200, -96.0652800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135406, 'Kingfisher', 'Kingfisher', 'Kingfisher,Kingsfishehr,kyngfyshr  aklahma,kynghfyshr,Кингсфишэр,Кингфишер,كينغفيشر,کینگفیشر، اکلاهما', 35.8614300, -97.9317200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135407, 'Kingston', 'Kingston', 'Kingston,Кингстон', 33.9987100, -96.7197200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135408, 'Konawa', 'Konawa', '', 34.9595300, -96.7528000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135409, 'Krebs', 'Krebs', '', 34.9278700, -95.7158200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135410, 'Langston', 'Langston', 'Langston,Lehngston,langhstwn,lngstn  aklahma,Лангстон,Лэнгстон,لانغستون,لانگسٹن، اوکلاہوما,لنگستن، اکلاهما', 35.9450500, -97.2553100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135411, 'Laverne', 'Laverne', '', 36.7097500, -99.8934600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135412, 'Lawton', 'Lawton', 'LAW,Lavton,Lawton,Loton,Louton,lao dun,loteon,ltn  aklahma,lwtwn,roton,Лавтон,Лотон,Лоутон,לוטון,لاٹن، اوکلاہوما,لتن، اکلاهما,لوتون,ロートン,劳顿,로턴', 34.6086900, -98.3903300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135413, 'Lexington', 'Lexington', 'Leksington,lie ke xing dun,lksyngtn  aklahma,lyksynghtwn,Лексингтон,ليكسينغتون,لکسینگتن، اکلاهما,لیکسنگٹن، اوکلاہوما,列克星頓', 35.0147900, -97.3355800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135414, 'Lindsay', 'Lindsay', '', 34.8348000, -97.6025300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135415, 'Locust Grove', 'Locust Grove', '', 36.2000900, -95.1677400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135416, 'Lone Grove', 'Lone Grove', '', 34.1753700, -97.2627900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135417, 'Longtown', 'Longtown', '', 35.2453800, -95.5127600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135418, 'Luther', 'Luther', '', 35.6617300, -97.1955900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135419, 'Madill', 'Madill', 'Madil,Madill,madyl,madyl  aklahma,Мадил,Мадилл,ماديل,مادیل، اکلاهما,میڈیل، اوکلاہوما', 34.0903800, -96.7716700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135420, 'Mangum', 'Mangum', '', 34.8720000, -99.5042600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135421, 'Mannford', 'Mannford', 'Manford,Mannford,New Mannford', 36.1334100, -96.3544600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135422, 'Marietta', 'Marietta', 'Mariehtta,Marietta,maryta,Мариетта,Мариэтта,ماريتا', 33.9370400, -97.1166800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135423, 'Marlow', 'Marlow', '', 34.6481300, -97.9580900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135424, 'Marlow', 'Marlow', '', 34.5903600, -97.9558700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135425, 'Maud', 'Maud', '', 35.1303600, -96.7758500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135426, 'Maysville', 'Maysville', 'Beef Creek,Maysville', 34.8173000, -97.4058600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135427, 'McAlester', 'McAlester', 'MLC,MacAlister,MacAllister,Mak Alester,Makalester,McAlester,South McAlester,makalstr,mklystr  aklahma,Мак Алестер,Макалестер,ماكالستر,مکلیستر، اکلاهما', 34.9334300, -95.7697100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135428, 'McCord', 'McCord', '', 36.6784700, -97.0400000, 'US', '2015-06-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135429, 'McLoud', 'McLoud', '', 35.4359000, -97.0914200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135430, 'Medford', 'Medford', 'Medford,Mehdford,mdfrd  aklahma,mydfwrd,Медфорд,Мэдфорд,مدفرد، اکلاهما,ميدفورد,میڈفورڈ، اوکلاہوما', 36.8069700, -97.7336600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135431, 'Meeker', 'Meeker', 'Clifton,Meeker', 35.5034000, -96.9028000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135432, 'Meridian', 'Meridian', 'Meridian,Меридиан', 34.4273100, -97.9780900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135433, 'Miami', 'Miami', 'MIO,Majami,myamy,myamy  aklahma,Майами,Мајами,ميامي,میامی، اوکلاہوما,میامی، اکلاهما', 36.8745100, -94.8774600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135434, 'Midwest City', 'Midwest City', 'Miduehst-Siti,Midvehst Siti,Midvest Siti,Midvest-Siti,mydwst syty  aklahma,mydwyst syty,Мидвест Сити,Мидвэст Сити,Мидуэст-Сити,Мідвест-Сіті,ميدويست سيتي,مڈویسٹ سٹی، اوکلاہوما,میدوست سیتی، اکلاهما', 35.4495100, -97.3967000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135435, 'Minco', 'Minco', '', 35.3128400, -97.9444900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135436, 'Moore', 'Moore', 'Mur,mu er,mua,mueo,mwr,mwr  aklahma,Мур,مور,مور، اکلاهما,موور، اوکلاہوما,ムーア,穆尔,무어', 35.3395100, -97.4867000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135437, 'Mooreland', 'Mooreland', '', 36.4392000, -99.2048200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135438, 'Morris', 'Morris', '', 35.6076000, -95.8602700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135439, 'Mounds', 'Mounds', '', 35.8764800, -96.0611100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135440, 'Muldrow', 'Muldrow', '', 35.4062000, -94.5988300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135441, 'Muskogee', 'Muskogee', 'MKO,Maskodzh,Maskogi,Muscogee,Muskogee,Muskogy,ma si ke ji,maskwwgy  aklahma,meoseukoji,Маскоги,Маскодж,ماسکووگی، اکلاهما,مسکوگی، اوکلاہوما,馬斯科吉,머스코지', 35.7478800, -95.3696900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135442, 'Mustang', 'Mustang', '', 35.3842300, -97.7244900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135443, 'Newcastle', 'Newcastle', 'N''jukastl,Njukasl,nywkasl,nywkasl  aklahma,Њукасл,Ньюкастл,نيوكاسل,نیوکاسل، اکلاهما', 35.2472900, -97.5997600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135444, 'Newkirk', 'Newkirk', 'N''jukirk,Njukirk,nywkyrk,nywkyrk  aklahma,Њукирк,Ньюкирк,نيوكيرك,نیوکیرک، اکلاهما', 36.8822500, -97.0533700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135445, 'Nichols Hills', 'Nichols Hills', '', 35.5508900, -97.5489300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135446, 'Nicoma Park', 'Nicoma Park', '', 35.4911700, -97.3230900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135447, 'Ninnekah', 'Ninnekah', 'East Ninnekah,Minnekah,Ninnekah', 34.9478500, -97.9239300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135448, 'Noble', 'Noble', '', 35.1392400, -97.3947500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135449, 'Norman', 'Norman', 'Norman,OUN,noman,nomeon,normana,nuo man,nwrmn  aklahma,Норман,نورمن، اکلاهما,नॉर्मन,ノーマン,諾曼,노먼', 35.2225700, -97.4394800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135450, 'Nowata', 'Nowata', 'Metz,Novata,Nowata,Noweta,nwata,nwwata  aklahma,Новата,نواتا,نوواتا، اکلاهما,ᎠᎹᏗᎧᏂᎬᎾᎬᎾ', 36.7006500, -95.6380300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135451, 'Oakhurst', 'Oakhurst', '', 36.0753700, -96.0644400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135452, 'Oakland', 'Oakland', 'Oklend,Окленд', 34.1001000, -96.7938900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135453, 'Oilton', 'Oilton', '', 36.0845100, -96.5836300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135454, 'Okarche', 'Okarche', '', 35.7258800, -97.9764400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135455, 'Okeene', 'Okeene', 'O''Keene,Okeene', 36.1161500, -98.3170200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135456, 'Okemah', 'Okemah', '', 35.4325900, -96.3050100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135457, 'Oklahoma City', 'Oklahoma City', 'Caayr Oklahoma,Cathair Oklahoma,Dinas Oklahoma,Gorad Aklakhoma-Sici,Kota Oklahoma,Kutha Oklahoma,Lungsod ng Oklahoma,Maxeponoe,Maxepónoe,OKC,Oklachoma Siti,Oklahoma,Oklahoma Ceety,Oklahoma City,Oklahoma Sites,Oklahoma Siti,Oklahoma Sitis,Oklahoma Sitės,Oklahoma Station,Oklahoma llaqta,Oklahomasitija,Oklahomaurbo,Oklakhoma,Oklakhoma Siti,Oklakhoma-Siti,Oklakhomae-Siti,Oklaxoma Shehiri,aklahma syty,ao ke la he ma shi,awklahwma syty,e ke la he ma cheng,okalahoma siti,okeullahomasiti,oklahoma nakaram,oklahoma siti,oklahoma-siti,okurahomashiti,xo khla ho ma si ti,Οκλαχόμα Σίτι,Горад Аклахома-Сіці,Оклахомæ-Сити,Оклахома,Оклахома Сити,Оклахома-Сити,Оклахома-Сіті,Օկլահոմա Սիթի,אוקלהומה סיטי,أوكلاهوما سيتي,اوکلاہوما شہر، اوکلاہوما,اکلاهما سیتی,ओक्लाहोमा सिटी,ওকলাহোমা সিটি,ஓக்லஹோமா நகரம்,โอคลาโฮมาซิตี,ოკლაჰომა-სიტი,ოქლაჰომა-სითი,オクラホマシティ,俄克拉荷馬城,奧克拉荷馬市,오클라호마시티', 35.4675600, -97.5164300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135458, 'Okmulgee', 'Okmulgee', 'OKM,Ockmulgee,Okmalgi,Okmulgee,Okmulgi,Okmulkee,awkmalgy  aklahma,awkmwlghy,Окмалги,Окмулги,أوكمولغي,اوکمالگی، اکلاهما', 35.6234400, -95.9605500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135459, 'Oologah', 'Oologah', 'Oolagah,Oologah', 36.4470400, -95.7083200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135460, 'Owasso', 'Owasso', 'Ovaso,Ovasso,awasw,awwasw  aklahma,Овасо,Овассо,أواسو,اواسو، اوکلاہوما,اوواسو، اکلاهما', 36.2695400, -95.8547100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135461, 'Panama', 'Panama', '', 35.1673200, -94.6724500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135462, 'Park Hill', 'Park Hill', '', 35.8612000, -94.9588400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135463, 'Pawhuska', 'Pawhuska', 'Paukhuska,Pawhuska,Pawluska,bwhwska,pawhwska  aklahma,poheoseuka,Паухуска,بوهوسكا,پاوهوسکا، اکلاهما,포허스카', 36.6678400, -96.3372300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135464, 'Pawnee', 'Pawnee', 'Pavni,Poni,bawny,pany  aklahma,Павни,Пони,باوني,پانی، اکلاهما', 36.3378300, -96.8039200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135465, 'Pauls Valley', 'Pauls Valley', 'Pauls Vallehj,Pols Vali,bwls faly,pl wly  aklahma,Паулс Валлэй,Полс Вали,بولس فالي,پل ولی، اکلاهما', 34.7400800, -97.2222500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135466, 'Perkins', 'Perkins', '', 35.9739400, -97.0336400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135467, 'Perry', 'Perry', 'Pehrri,Peri,Perri,byry,pry  aklahma,Пери,Перри,Пэрри,بيري,پری، اکلاهما,پیری، اوکلاہوما', 36.2894900, -97.2881000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135468, 'Piedmont', 'Piedmont', '', 35.6420000, -97.7464300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135469, 'Pink', 'Pink', 'Pink,pynk  aklahma,Пинк,پینک، اکلاهما', 35.2606300, -97.1197500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135470, 'Pocola', 'Pocola', '', 35.2312100, -94.4780000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135471, 'Ponca City', 'Ponca City', 'PNC,Ponca,Ponca City,Ponka,Ponka Siti,bwnka syty,pang ka cheng,panka syty  aklahma,Понка Сити,بونكا سيتي,پانکا سیتی، اکلاهما,پونکا سٹی، اوکلاہوما,庞卡城', 36.7069800, -97.0855900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135472, 'Poteau', 'Poteau', 'Potiu,Poto,RKR,bwtw,pwtaw  aklahma,Потиу,Пото,بوتو,پوتاو، اکلاهما', 35.0537100, -94.6235600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135473, 'Prague', 'Prague', 'Pragju,Prejg,bragh,prag  aklahma,Прагю,Прејг,براغ,پراگ، اکلاهما', 35.4867400, -96.6850200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135474, 'Pryor', 'Pryor', 'Coo-y-yah,Pryor,Pryor Creek', 36.3084300, -95.3169100, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135475, 'Purcell', 'Purcell', 'Parsel,Pursehll,bwrsyl,prsl  aklahma,Парсел,Пурсэлл,بورسيل,پرسل، اکلاهما', 35.0136800, -97.3611400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135476, 'Quinton', 'Quinton', '', 35.1228800, -95.3710900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135477, 'Ringling', 'Ringling', '', 34.1784300, -97.5925300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135478, 'Roland', 'Roland', '', 35.4212000, -94.5146600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135479, 'Rush Springs', 'Rush Springs', '', 34.7825700, -97.9569800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135480, 'Salina', 'Salina', 'Salina,Saline,Салина', 36.2928700, -95.1533000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135481, 'Sallisaw', 'Sallisaw', 'Childer''s Station,Salaiseau,Salisaw,Sallisaw,Sollisau,salysw,slysaw  aklahma,Соллисау,ساليسو,سلیساو، اکلاهما', 35.4603700, -94.7874500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135482, 'Sand Springs', 'Sand Springs', '', 36.1398100, -96.1088900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135483, 'Sapulpa', 'Sapulpa', 'Sapalpa,Sapulpa,sabwlba,spalpa  aklahma,Сапалпа,Сапулпа,سابولبا,سپالپا، اکلاهما', 35.9987000, -96.1141700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135484, 'Sayre', 'Sayre', 'Sajr,Sejri,sai er,sayr,syr  aklahma,Сайр,Сејри,ساير,سیر، اکلاهما,塞尔', 35.2911600, -99.6401000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135485, 'Seminole', 'Seminole', 'Seminol,asmnwwl  aklahma,symynwl,Семинол,اسمنوول، اکلاهما,سيمينول', 35.2245200, -96.6705700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135486, 'Shattuck', 'Shattuck', '', 36.2761400, -99.8827600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135487, 'Shawnee', 'Shawnee', 'SNL,Shani,Shauni,Shavni,Shoni,Shouni,Soni,shany  aklahma,shoni,shwny,syoni,xiao ni,Šonī,Шавни,Шани,Шауні,Шони,Шоуни,شانی، اوکلاہوما,شانی، اکلاهما,شوني,ショーニー,肖尼,쇼니', 35.3272900, -96.9253000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135488, 'Skiatook', 'Skiatook', 'Skajatuk,Ski-a-took,Skiatook,Skiotook,askyatwk  aklahma,Скаятук,اسکیاتوک، اکلاهما', 36.3684200, -96.0013800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135489, 'Slaughterville', 'Slaughterville', '', 35.0872900, -97.3350300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135490, 'Snyder', 'Snyder', '', 34.6589600, -98.9517400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135491, 'Spencer', 'Spencer', 'Spence,Spencer', 35.5228400, -97.3772600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135492, 'Sperry', 'Sperry', '', 36.2973100, -95.9913900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135493, 'Spiro', 'Spiro', '', 35.2412100, -94.6199400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135494, 'Stigler', 'Stigler', 'Stiglehr,astyglr  aklahma,styghlr,Стиглэр,استیگلر، اکلاهما,ستيغلر', 35.2537100, -95.1230200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135495, 'Stillwater', 'Stillwater', 'SWO,Stilgouoter,Stilluateh,Stilvoter,astylwatr  aklahma,seutil-woteo,si di er wo te,stilavotara,stylwwtr,sutiruu~ota,Στίλγουοτερ,Стилвотер,Стиллуатэ,استیلواتر، اکلاهما,ستيلووتر,سٹیلواٹر، اوکلاہوما,स्टिलवॉटर,スティルウォーター,斯蒂尔沃特,스틸워터', 36.1156100, -97.0583700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135496, 'Stilwell', 'Stilwell', 'Stillvehll,Stiluehll,Stilvel,Stilvell,astylwl  aklahma,stylwyl,Стилвел,Стиллвэлл,Стилуэлл,Стілвелл,استیلول، اکلاهما,ستيلويل', 35.8145300, -94.6285600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135497, 'Stratford', 'Stratford', 'Stratford,Стратфорд', 34.7967500, -96.9594600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135498, 'Stroud', 'Stroud', 'SUD,Straud,Stroud,astrawd  aklahma,strwd,Страуд,Строуд,استراود، اکلاهما,سترود', 35.7486800, -96.6580700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135499, 'Sulphur', 'Sulphur', 'Salfer,salfr  aklahma,swlfwr,Салфер,سالفر، اکلاهما,سولفور', 34.5078700, -96.9683500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135500, 'Tahlequah', 'Tahlequah', 'Takhlguakh,Talekva,tahlkwah  aklahma,tahlykwa,tallekwa,Талеква,Тахлгуах,تاهليكوا,تاهلکواه، اکلاهما,ᏓᎵᏆ,탈레콰', 35.9153700, -94.9699600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135501, 'Talihina', 'Talihina', '', 34.7514900, -95.0480200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135502, 'Taloga', 'Taloga', '', 36.0386500, -98.9637100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135503, 'Tecumseh', 'Tecumseh', '', 35.2578500, -96.9366900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135504, 'Texanna', 'Texanna', '', 35.3473200, -95.4369200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135505, 'The Village', 'The Village', '', 35.5608900, -97.5514300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135506, 'Thomas', 'Thomas', '', 35.7442200, -98.7475800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135507, 'Tishomingo', 'Tishomingo', 'Tishomingo,tyshwmynghw,tyshwmyngw  aklahma,Тишоминго,تيشومينغو,تیشومینگو، اکلاهما', 34.2362100, -96.6786100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135508, 'Tonkawa', 'Tonkawa', 'Tonkava,twnkawa,twnkawa  aklahma,Тонкава,تونكاوا,تونکاوا، اکلاهما', 36.6783700, -97.3100400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135509, 'Tulsa', 'Tulsa', 'T"lsa,TUL,Talsa,Tulsa,tarusa,tu er sa,Талса,Тълса,タルサ,圖爾薩', 36.1539800, -95.9927700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135510, 'Turley', 'Turley', '', 36.2420400, -95.9758300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135511, 'Tuttle', 'Tuttle', '', 35.2908900, -97.8122700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135512, 'Union City', 'Union City', 'Junion-Siti,Union,Union City,Юнион-Сити', 35.3917200, -97.9414400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135513, 'Verdigris', 'Verdigris', '', 36.2348200, -95.6910900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135514, 'Vian', 'Vian', '', 35.4984300, -94.9696700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135515, 'Vinita', 'Vinita', 'Vinita,Vinita City,fynyta,wynyta  aklahma,Винита,فينيتا,وینیتا، اکلاهما', 36.6386900, -95.1541300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135516, 'Wagoner', 'Wagoner', 'Vagonehr,Vagoner,waghwnr,wgnr  aklahma,Вагонер,Вагонэр,واغونر,وگنر، اکلاهما', 35.9595400, -95.3694100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135517, 'Walters', 'Walters', 'Uehlters,Voters,Walter,Walters,waltrz,waltrz  aklahma,Вотерс,Уэлтерс,والترز,والترز، اکلاهما', 34.3598100, -98.3078300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135518, 'Warr Acres', 'Warr Acres', '', 35.5225600, -97.6189300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135519, 'Warner', 'Warner', '', 35.4942600, -95.3055200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135520, 'Watonga', 'Watonga', 'Tseh-maehoaeta,Tséh-maêhoaëta,Vatonga,Votonga,watwnga  aklahma,watwngha,Ватонга,Вотонга,واتونغا,واتونگا، اکلاهما', 35.8447700, -98.4131300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135521, 'Waukomis', 'Waukomis', '', 36.2803100, -97.8981100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135522, 'Waurika', 'Waurika', 'Vaurika,Vorika,wawryka,wawryka  aklahma,Ваурика,Ворика,واوريكا,واوریکا، اکلاهما', 34.1670400, -97.9975400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135523, 'Weatherford', 'Weatherford', '', 35.5261600, -98.7075700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135524, 'Westville', 'Westville', 'Vestvil,Vestvill,wstwyl  aklahma,Вествил,Вествилл,وستویل، اکلاهما', 35.9925800, -94.5680000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135525, 'Wetumka', 'Wetumka', 'Wetumka,Wetumpka', 35.2375900, -96.2416700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135526, 'Wewoka', 'Wewoka', 'Uehvoka,We-wo-ka,Wewoka,wwka  aklahma,wywka,Уэвока,ووکا، اکلاهما,ويوكا', 35.1586900, -96.4933500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135527, 'Wilburton', 'Wilburton', 'Vilbarton,Vilberton,wylbwrtwn,wylbwrtwn  aklahma,Вилбартон,Вилбертон,ويلبورتون,ویلبورتون، اکلاهما', 34.9187100, -95.3091400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135528, 'Wilson', 'Wilson', 'Uilson,Уилсон', 34.1620400, -97.4258600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135529, 'Wilson', 'Wilson', '', 35.5076000, -96.0347200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135530, 'Wister', 'Wister', '', 34.9673200, -94.7246700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135531, 'Woodward', 'Woodward', 'Vudvard,WWR,wwdward,wwdward  aklahma,Вудвард,وودوارد,وودوارد، اکلاهما', 36.4336500, -99.3903900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135532, 'Wynnewood', 'Wynnewood', '', 34.6434200, -97.1644700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135533, 'Yale', 'Yale', '', 36.1142300, -96.6991900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135534, 'Yukon', 'Yukon', 'Jukon,aywkan  aklahma,yu kong,ywkwn,Јукон,Юкон,ایوکان، اکلاهما,يوكون,یکون، اوکلاہوما,育空', 35.5067200, -97.7625400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135535, 'Abbottstown', 'Abbottstown', 'Abbottstown,Berwick,Berwick Borough', 39.8864900, -76.9847000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135536, 'Aldan', 'Aldan', '', 39.9215000, -75.2879600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135537, 'Atglen', 'Atglen', '', 39.9492700, -75.9735600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135538, 'Avondale', 'Avondale', 'Ejvondejl,Ейвондейл', 39.8234400, -75.7832700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135539, 'Berlin', 'Berlin', '', 39.9206400, -78.9578000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135540, 'Biglerville', 'Biglerville', 'Biglervil,Biglerville,Middletown,Биглервил', 39.9303700, -77.2480400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135541, 'Bonneauville', 'Bonneauville', 'Bonaughton,Bonaughtown,Bonneauville', 39.8120400, -77.1372100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135542, 'Boothwyn', 'Boothwyn', 'Boothwyn,Chichester', 39.8301100, -75.4415800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135543, 'Brookhaven', 'Brookhaven', 'Brook Haven,Brookhaven', 39.8692800, -75.3824100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135544, 'Broomall', 'Broomall', '', 39.9815000, -75.3565800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135545, 'Caln', 'Caln', 'Caln,Calne', 39.9909400, -75.7802200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135546, 'Carroll Valley', 'Carroll Valley', '', 39.7492600, -77.3830400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135547, 'Chambersburg', 'Chambersburg', 'Chambers-town,Chambersburg,Chejmbersberg,chenbazubagu,chymbrzbrg  pnslwanya,qian bo si bao,Чејмберсберг,چیمبرزبرگ، پنسلوانیا,チェンバーズバーグ,钱伯斯堡', 39.9375900, -77.6611000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135548, 'Chester', 'Chester', 'Chester,Chester Town,Oplandt,Upland,Uplandt,cheseuteo,chesuta,chstr  pnsylwanya,tshystr,Честер,تشيستر,چستر، پنسیلوانیا,چیسٹر، پنسلوانیا,チェスター,체스터', 39.8496700, -75.3570700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135549, 'Chester Heights', 'Chester Heights', 'Chester Heights,Chester Khajts,Logtown,Peters Mill,Честер Хајтс', 39.8901100, -75.4754800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135550, 'Christiana', 'Christiana', '', 39.9548300, -75.9968900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135551, 'Clifton Heights', 'Clifton Heights', 'Clifton,Clifton Heights', 39.9292800, -75.2963000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135552, 'Coatesville', 'Coatesville', 'CTH,Koutsvil,Koutsvil'',Koutsvill,kwtsfyl,kwtswyl  pnsylwanya,Коутсвил,Коутсвилл,Коутсвіль,كوتسفيل,کوتسویل، پنسیلوانیا', 39.9831600, -75.8238400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135553, 'Collingdale', 'Collingdale', '', 39.9117800, -75.2771300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135554, 'Colwyn', 'Colwyn', '', 39.9123400, -75.2537900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135555, 'Conestoga', 'Conestoga', 'Conestoga,Conestoga Center', 39.9406600, -76.3463500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135556, 'Dallastown', 'Dallastown', '', 39.8995400, -76.6402500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135557, 'Darby', 'Darby', 'Darbi,Darby,Derby Town,Дарби,ڈاربی، پنسلوانیا', 39.9184500, -75.2590700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135558, 'Drexel Hill', 'Drexel Hill', '', 39.9470600, -75.2921300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135559, 'Dunbar', 'Dunbar', '', 39.9778500, -79.6144800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135560, 'East Berlin', 'East Berlin', 'Berlin,East Berlin', 39.9376000, -76.9785900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135561, 'East Lansdowne', 'East Lansdowne', 'East Lansdowne,Pattonville', 39.9456700, -75.2612900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135562, 'East Uniontown', 'East Uniontown', '', 39.8998000, -79.6978200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135563, 'East York', 'East York', '', 39.9737100, -76.6863600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135564, 'Eddystone', 'Eddystone', '', 39.8601100, -75.3443600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135565, 'Fairchance', 'Fairchance', 'Fairchance,Fairchance Iron Works', 39.8248000, -79.7544900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135566, 'Fairdale', 'Fairdale', '', 39.8870200, -79.9681100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135567, 'Fayetteville', 'Fayetteville', '', 39.9112000, -77.5499900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135568, 'Folsom', 'Folsom', '', 39.8898300, -75.3251900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135569, 'Folcroft', 'Folcroft', 'Flokroft,Флокрофт', 39.8909500, -75.2838000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135570, 'Gap', 'Gap', '', 39.9873200, -76.0205100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135571, 'Georgetown', 'Georgetown', 'Bart,Georgetown', 39.9376000, -76.0832900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135572, 'Gettysburg', 'Gettysburg', 'GTY,Getisburg,Getizburg,Gettisberg,Gettys-town,Gettysburg,Gettystown,gai ci bao,getijeubeogeu,getisubagu,gtyzbrg  pnsylwanya,ket tis beirk,ketticuperkku,Гетизбург,Гетисбърг,Геттисберг,گتیزبرگ، پنسیلوانیا,கெட்டிசுபெர்க்கு,เกตตีสเบิร์ก,ゲティスバーグ,蓋茨堡,게티즈버그', 39.8309300, -77.2311000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135573, 'Glen Rock', 'Glen Rock', '', 39.7931600, -76.7302500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135574, 'Glenolden', 'Glenolden', 'Glen Olden,Glenolden', 39.9001100, -75.2890700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135575, 'Grantley', 'Grantley', '', 39.9403800, -76.7291300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135576, 'Greencastle', 'Greencastle', 'Green Castle,Greencastle,Grinkasl,Гринкасл', 39.7903700, -77.7277700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135577, 'Guilford Siding', 'Guilford Siding', 'Guilford,Guilford Siding,New Franklin', 39.8653700, -77.6124900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135578, 'Hanover', 'Hanover', 'Hanover,Hickory-Town,Khanover,McAllister,McAllisters Folly,McAllisters Town,Rogues Harbor,Rogues Resort,hanoba,hanwwr  pnsylwanya,Хановер,هانوور، پنسیلوانیا,ハノーバー', 39.8006600, -76.9830400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135579, 'Hopwood', 'Hopwood', 'Hopwood,Monroe', 39.8770200, -79.7019900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135580, 'Jacobus', 'Jacobus', '', 39.8831600, -76.7105200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135581, 'Kennett Square', 'Kennett Square', 'Kenit Skver,Кенит Сквер', 39.8467800, -75.7116000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135582, 'Lake Heritage', 'Lake Heritage', '', 39.8095400, -77.1838700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135583, 'Lake Meade', 'Lake Meade', '', 39.9851000, -77.0372000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135584, 'Lampeter', 'Lampeter', '', 39.9901000, -76.2396800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135585, 'Lansdowne', 'Lansdowne', 'Lansdaun,Лансдаун', 39.9381700, -75.2718500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135586, 'Lima', 'Lima', 'Lima,Лима', 39.9173300, -75.4404700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135587, 'Linwood', 'Linwood', '', 39.8265000, -75.4254700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135588, 'Littlestown', 'Littlestown', 'Kleina Stedtle,Kleine-staedtel,Litltaun,Littlestown,Petersburg,Литлтаун', 39.7445400, -77.0880400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135589, 'Loganville', 'Loganville', 'Logansville,Loganville', 39.8556600, -76.7074700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135590, 'Luzerne', 'Luzerne', '', 39.9992400, -79.9628300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135591, 'Marcus Hook', 'Marcus Hook', 'Chichester,Maartes Hook,Marcus Hook,Marretie''s Hook,Marreties Hoeck', 39.8192800, -75.4185300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135592, 'Masontown', 'Masontown', '', 39.8467400, -79.8997800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135593, 'McConnellsburg', 'McConnellsburg', 'Makonelsberg,Маконелсберг', 39.9325900, -77.9988900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135594, 'McSherrystown', 'McSherrystown', '', 39.8073200, -77.0113700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135595, 'Media', 'Media', 'Midija,Мидија', 39.9167800, -75.3876900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135596, 'Mercersburg', 'Mercersburg', 'Mersersberg,Мерсерсберг', 39.8278700, -77.9033300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135597, 'Meyersdale', 'Meyersdale', 'Majersdejl,Мајерсдејл', 39.8136900, -79.0247500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135598, 'Midway', 'Midway', '', 39.8084300, -77.0027600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135599, 'Milford', 'Milford', '', 39.9531300, -79.1041900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135600, 'Millbourne', 'Millbourne', '', 39.9634500, -75.2501800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135601, 'Millersville', 'Millersville', '', 39.9978800, -76.3541300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135602, 'Mont Alto', 'Mont Alto', 'Mont Alto,Mount Alto', 39.8442600, -77.5583200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135603, 'Morrisville', 'Morrisville', 'Bridgeport,Morrisville', 39.8948000, -80.1617300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135604, 'Morton', 'Morton', '', 39.9098300, -75.3235200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135605, 'Mount Pleasant', 'Mount Pleasant', '', 39.7337100, -77.0755400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135606, 'New Freedom', 'New Freedom', 'Freedom,New Freedom,New Freedom Summit', 39.7378800, -76.7013600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135607, 'New Oxford', 'New Oxford', 'New Oxford,Oxford Town', 39.8637100, -77.0558100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135608, 'North York', 'North York', '', 39.9781500, -76.7330200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135609, 'Norwood', 'Norwood', 'Norwood,Norwood Park,Norwood Station', 39.8917800, -75.2996300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135610, 'Oliver', 'Oliver', '', 39.9186900, -79.7178200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135611, 'Oxford', 'Oxford', 'Oksford,Оксфорд,آکسفورڈ، پنسلوانیا', 39.7853900, -75.9788300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135612, 'Parkesburg', 'Parkesburg', '', 39.9587200, -75.9193900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135613, 'Parkside', 'Parkside', '', 39.8642800, -75.3785300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135614, 'Parkville', 'Parkville', '', 39.7812100, -76.9633100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135615, 'Penn Wynne', 'Penn Wynne', '', 39.9862200, -75.2754600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135616, 'Pennville', 'Pennville', '', 39.7895400, -76.9980400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135617, 'Philadelphia', 'Philadelphia', 'Coaquannock,Fi-sang,Fi-sàng,Filadel''fi,Filadel''fij,Filadel''fija,Filadelfi,Filadelfia,Filadelfiae,Filadelfie,Filadelfii,Filadelfija,Filadelfijo,Filadelfio,Filadelfiya,Filadelfiye,Filadelfiä,Filadèlfia,Filadélfia,Filadélfiye,Ga-na-ta-jen-go-na,Gorad Filadehl''fija,PHL,Philadelpheia,Philadelphia,Philadelphie,Philly,Quequenakee,Tsi wahswen:to Tekahso:ken,Tsi wahswèn:to Tekahsó:ken,fei cheng,fi la delfeiy,filadailafi''a,firaderufia,flaڈylfya,fyladlfya,fyladlfya  pnsylwanya,philadelaphiya,philadelphiya,piladelpia,pilatelpiya,pilladelpia,pyldlpyh,Φιλαδέλφεια,Горад Філадэльфія,Филаделфиа,Филаделфия,Филаделфија,Филадельфи,Филадельфий,Филадельфия,Філадельфія,Ֆիլադելֆիա,פילאדעלפיע,פילדלפיה,فلاڈیلفیا,فلاڈیلفیا، پنسلوانیا,فيلادلفيا,فیلادلفیا,فیلادلفیا، پنسیلوانیا,फिलाडेल्फिया,ফিলাডেলফিয়া,ਫ਼ਿਲਾਡੈਲਫ਼ੀਆ,ફિલાડેલ્ફિયા,பிலடெல்பியா,ఫిలడెల్ఫియా,ಫಿಲಡೆಲ್ಫಿಯಾ,ഫിലഡെൽഫിയ,ฟิลาเดลเฟีย,ဖီလာဒဲလ်ဖီးယားမြို့,ფილადელფია,ፊላዴልፊያ,ភីឡាដេលផ្យា,フィラデルフィア,費城,费城,필라델피아', 39.9523300, -75.1637900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135618, 'Point Marion', 'Point Marion', '', 39.7389700, -79.8986700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135619, 'Prospect Park', 'Prospect Park', '', 39.8878900, -75.3082400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135620, 'Quarryville', 'Quarryville', '', 39.8970500, -76.1635700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135621, 'Red Lion', 'Red Lion', '', 39.9009300, -76.6058000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135622, 'Republic', 'Republic', '', 39.9625800, -79.8767100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135623, 'Ridley Park', 'Ridley Park', '', 39.8812200, -75.3238000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135624, 'Scotland', 'Scotland', '', 39.9687000, -77.5872100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135625, 'Sharon Hill', 'Sharon Hill', '', 39.9065000, -75.2715700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135626, 'Shiloh', 'Shiloh', '', 39.9781500, -76.7971900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135627, 'Shrewsbury', 'Shrewsbury', 'Shrusberi,Шрусбери', 39.7687100, -76.6796900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135628, 'South Connellsville', 'South Connellsville', '', 39.9967400, -79.5858700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135629, 'South Coatesville', 'South Coatesville', 'Boxtown,South Coatesville', 39.9742700, -75.8199500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135630, 'South Uniontown', 'South Uniontown', 'South Union,South Uniontown', 39.8928500, -79.7469900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135631, 'Spring Grove', 'Spring Grove', '', 39.8745400, -76.8658100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135632, 'Springfield', 'Springfield', 'Springfild,Спрингфилд', 39.9306700, -75.3201900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135633, 'Spry', 'Spry', '', 39.9184300, -76.6849700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135634, 'State Line', 'State Line', 'Middleburg,State Line', 39.7248200, -77.7244400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135635, 'Stewartstown', 'Stewartstown', '', 39.7537100, -76.5913600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135636, 'Stonybrook', 'Stonybrook', '', 39.9870400, -76.6441300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135637, 'Strasburg', 'Strasburg', 'Bettelhausen,Strasburg', 39.9831600, -76.1841200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135638, 'Susquehanna Trails', 'Susquehanna Trails', '', 39.7587200, -76.3680200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135639, 'Swarthmore', 'Swarthmore', 'Svortmor,Swarthmore,Swarthmore Boro,Свортмор', 39.9020600, -75.3499100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135640, 'Thorndale', 'Thorndale', '', 39.9928800, -75.7452200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135641, 'Toughkenamon', 'Toughkenamon', '', 39.8315000, -75.7574400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135642, 'Trainer', 'Trainer', '', 39.8276100, -75.4143600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135643, 'Uniontown', 'Uniontown', 'Beesons-town,Juniontaun,Union-town,Uniontown,you ning dui,ywnywntawn,Јунионтаун,Юніонтаун,انیون‌تاوون، پنسیلوانیا,يونيونتاون,یونین ٹاؤن، پنسلوانیا,尤宁敦', 39.9000800, -79.7164300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135644, 'Upland', 'Upland', '', 39.8865000, -75.7743900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135645, 'Upland', 'Upland', 'Apland,Апланд', 39.8526100, -75.3826900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135646, 'Valley View', 'Valley View', '', 39.9501000, -76.7010800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135647, 'Wayne Heights', 'Wayne Heights', '', 39.7437100, -77.5538800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135648, 'Waynesboro', 'Waynesboro', 'Vejnsboro,Wallacetown,Waynesboro,Waynesborough,Waynsboro,Вејнсборо', 39.7559300, -77.5777700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135649, 'Waynesburg', 'Waynesburg', 'Vejnsburg,Вејнсбург', 39.8964600, -80.1792300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135650, 'Weigelstown', 'Weigelstown', '', 39.9837100, -76.8224700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135651, 'West Chester', 'West Chester', 'Vest Chester,u~esutochesuta,wei che si te,weseuteucheseuteo,Вест Честер,ویسٹ چیسٹر، پنسلوانیا,ウェストチェスター,威徹斯特,웨스트체스터', 39.9609700, -75.6080400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135652, 'West Grove', 'West Grove', '', 39.8220500, -75.8274400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135653, 'West York', 'West York', '', 39.9526000, -76.7513600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135654, 'Willow Street', 'Willow Street', '', 39.9792700, -76.2763500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135655, 'Windsor', 'Windsor', 'Vindzor,Виндзор', 39.9162100, -76.5844100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135656, 'Woodlyn', 'Woodlyn', '', 39.8723300, -75.3371300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135657, 'Yoe', 'Yoe', '', 39.9089900, -76.6369100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135658, 'York', 'York', 'Jork,THV,Yarrick,yokeu,yoku,yue ke,ywrk  bnslfanya,ywrk  pnsylwanya,Јорк,Йорк,يورك، بنسلفانيا,یورک، پنسیلوانیا,ヨーク,約克,요크', 39.9626000, -76.7277400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135659, 'Yeadon', 'Yeadon', '', 39.9390000, -75.2554600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135660, 'Yorklyn', 'Yorklyn', '', 39.9923200, -76.6463500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135661, 'Abbeville', 'Abbeville', 'Abbeville,Abevil,Ebbivil'',Ehbbivill,Townville,a bu wei er,abebiru,abfyl,abywyl  karwlynay jnwby,aebibil,aybywyl  jnwby kyrwlayna,Абевил,Еббівіль,Эббивилл,أبفيل,ابیویل، کارولینای جنوبی,ایبیویل، جنوبی کیرولائنا,アベビル,阿布维尔,애비빌', 34.1781700, -82.3790100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135662, 'Aiken', 'Aiken', 'AIK,Aiken,Ajken,Ejken,Plunkett,ai ken,aykn,aykn  jnwby kyrwlayna,aykn  karwlynay jnwby,eikin,Айкен,Ејкен,أيكن,ایکن، جنوبی کیرولائنا,ایکن، کارولینای جنوبی,エイキン,艾肯', 33.5604200, -81.7195500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135663, 'Allendale', 'Allendale', 'Alendejl,a lun da,alndal  karwlynay jnwby,Алендејл,آلندال، کارولینای جنوبی,ایلنڈیل، جنوبی کیرولائنا,阿倫達', 33.0079300, -81.3084400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135664, 'Anderson', 'Anderson', 'AND,Anderson,Anderson Court House,aendeoseun,an de sen,andason,andrswn,andrswn  karwlynay jnwby,Андерсон,أندرسون,اندرسون، کارولینای جنوبی,اینڈرسن، جنوبی کیرولائنا,アンダーソン,安德森,앤더슨', 34.5034400, -82.6501300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135665, 'Andrews', 'Andrews', 'ADR,Andrews,Rosemary', 33.4512800, -79.5609000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135666, 'Arcadia', 'Arcadia', '', 34.9581800, -81.9906600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135667, 'Arial', 'Arial', 'Ariail,Arial', 34.8459500, -82.6415200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135668, 'Awendaw', 'Awendaw', 'Awendaw,Awensdaw,Owendaw', 33.0376700, -79.6131300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135669, 'Bamberg', 'Bamberg', 'Bamberg,Lowrys Station,Lowrys Turnout,bambrj,ban bei ge,bmbrg  karwlynay jnwby,Бамберг,بامبرج,بمبرگ، کارولینای جنوبی,班贝格', 33.2971000, -81.0348200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135670, 'Barnwell', 'Barnwell', 'BNL,Barnuel,Barnvel,Barnwell,Barnwell Court House,Barnwell Hill,Red Hill,ba en wei er,barnwl  karwlynay jnwby,barnwyl,barnwyl  jnwby kyrwlayna,Барнвел,Барнуел,بارنول، کارولینای جنوبی,بارنويل,بارنویل، جنوبی کیرولائنا,巴恩韦尔', 33.2448700, -81.3587200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135671, 'Batesburg', 'Batesburg', 'Batesburg,Batesburg-Leesville,Batesburgh,Batesville', 33.9079200, -81.5473300, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135672, 'Batesburg-Leesville', 'Batesburg-Leesville', 'Batesburg,Batesburg-Leesville,Bejtsburg-Lizvil,Leesville,batsbwrg-lswyl  karwlynay jnwby,bei te si bo ge-li si wei er,Бејтсбург-Лизвил,باتسبورگ-لسویل، کارولینای جنوبی,بیٹسبرگ-لیزویل، جنوبی کیرولائنا,贝特斯伯格-利斯维尔', 33.9101400, -81.5373300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135673, 'Beaufort', 'Beaufort', 'BFT,Beaufort,Bjufort,Granville,bo fu te,bwwfrt  karwlynay jnwby,byafwrt,byufoto,byupeoteu,Бјуфорт,بووفرت، کارولینای جنوبی,بيافورت,بیوفورٹ، جنوبی کیرولائنا,ビューフォート,博福特,뷰퍼트', 32.4315800, -80.6698300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135674, 'Belton', 'Belton', 'Belton,Brown,Sugar Hill,bei er dun,bltwn,bltwn  karwlynay jnwby,Белтон,بلتون,بلتون، کارولینای جنوبی,بیلٹن، جنوبی کیرولائنا,贝尔顿', 34.5228900, -82.4942900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135675, 'Belvedere', 'Belvedere', '', 33.5309700, -81.9448400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135676, 'Bennettsville', 'Bennettsville', 'BTN,Benetsvil,Bennettsville,Bennetville,Carlisle,Winfieldville,bntswyl  karwlynay jnwby,byntsfyl,ni ci wei er,Бенетсвил,بنتسویل، کارولینای جنوبی,بينتسفيل,بینیٹسویل، جنوبی کیرولائنا,尼茨维尔', 34.6173800, -79.6847800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135677, 'Berea', 'Berea', 'Berea,Berea Cross Roads,Berea Crossroads,Береа', 34.8854000, -82.4559600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135678, 'Bishopville', 'Bishopville', 'Bishopvil,bi xia pu wei er,byshwbfyl,byshwpwyl  karwlynay jnwby,Бишопвил,بيشوبفيل,بیشوپویل، کارولینای جنوبی,比夏普维尔', 34.2182100, -80.2484100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135679, 'Blackville', 'Blackville', 'Blackville,Clinton', 33.3579300, -81.2706600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135680, 'Blacksburg', 'Blacksburg', 'Black''s,Black''s Station,Blacks,Blacks Station,Blacksburg,Blehksburg,Bleksburg,Stark''s Folly,Starks Folly,blksbwrg  karwlynay jnwby,bu lai ke si bao,Блексбург,Блэксбург,بلکسبورگ، کارولینای جنوبی,布莱克斯堡', 35.1212400, -81.5159200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135681, 'Bluffton', 'Bluffton', 'Blafton,blaftwn,blwftwn  karwlynay jnwby,bu la fu dun,Блафтон,بلافتون,بلفٹن، جنوبی کیرولائنا,بلوفتون، کارولینای جنوبی,布拉夫顿', 32.2371500, -80.8603900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135682, 'Blythewood', 'Blythewood', 'Blythewood,Doko', 34.2143200, -80.9739800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135683, 'Boiling Springs', 'Boiling Springs', 'Boiling Springs,Caters Boiling Spring,Lyndhurst', 33.1351500, -81.4312200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135684, 'Boiling Springs', 'Boiling Springs', '', 35.0465100, -81.9817700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135685, 'Bonneau Beach', 'Bonneau Beach', '', 33.3198900, -80.0003600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135686, 'Brookdale', 'Brookdale', '', 33.5068200, -80.8234200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135687, 'Buffalo', 'Buffalo', 'Buffalo,Буффало', 34.7256900, -81.6834300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135688, 'Burnettown', 'Burnettown', '', 33.5154100, -81.8490000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135689, 'Burton', 'Burton', 'Berton,Бертон', 32.4357500, -80.7240000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135690, 'Calhoun Falls', 'Calhoun Falls', 'Calhoun Falls,Terry Town,Terryville', 34.0923400, -82.5956900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135691, 'Camden', 'Camden', 'CDN,Camden,Fredericksburg,Friends Neck,Kamden,Pine Tree Hill,Pinetree,ka mu deng,kaemdeon,kamdn,kamuden,kmdn  karwlynay jnwby,Камден,كامدن,کمدن، کارولینای جنوبی,کیمڈن، جنوبی کیرولائنا,カムデン,卡姆登,캠던', 34.2465400, -80.6070200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135692, 'Cane Savannah', 'Cane Savannah', '', 33.9018200, -80.4503600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135693, 'Catawba', 'Catawba', 'Catawba,Catawba Junction', 34.8529200, -80.9111900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135694, 'Cayce', 'Cayce', 'Cayce,Cayces Siding,Cayces Tavern,Granby,Kejsi,kai xi,keishi,kysy,kysy  jnwby kyrwlayna,kysy  karwlynay jnwby,Кејси,كيسي,کیسی، جنوبی کیرولائنا,کیسی، کارولینای جنوبی,ケイシー,凯西', 33.9657100, -81.0739800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135695, 'Centerville', 'Centerville', '', 34.5320500, -82.7040200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135696, 'Centerville', 'Centerville', '', 32.9957300, -80.1703700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135697, 'Central', 'Central', 'Center,Central,Garvin,Sentral,sntral,sntrl  karwlynay jnwby,zhong yang,Сентрал,سنترال,سنترل، کارولینای جنوبی,中央', 34.7242700, -82.7812500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135698, 'Chapin', 'Chapin', 'Chaplin,chapyn  karwlynay jnwby,cui ping,tshabyn,Чаплин,تشابين,چاپین، کارولینای جنوبی,翠萍', 34.1659800, -81.3498200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135699, 'Charleston', 'Charleston', 'Carolopolis,Charles Town,Charles Towne,Charleston,Charleston i Sor-Carolina,Charleston i Sør-Carolina,Charlestowne,Charlston,Charlstoun,Charlstown,Charlstun,Tsarleston,cha er si dun,chalseuteon,charlstwn  karwlynay jnwby,charusuton,tsharlstwn,zʼrlstwn,Τσάρλεστον,Чарлстон,Чарлстън,צארלסטון,تشارلستون,چارلستون، کارولینای جنوبی,چارلسٹن، جنوبی کیرولائنا,チャールストン,查尔斯顿,찰스턴', 32.7765700, -79.9309200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135700, 'Cheraw', 'Cheraw', 'Chatham,Chera,Cherah,Cheraw,Cheraw Hill,Cheraw Hills,HCW,Sara,Saraw,Serah,Shero,chraw  karwlynay jnwby,qi luo,tshyraw,Шеро,تشيراو,چراو، کارولینای جنوبی,奇罗', 34.6976600, -79.8834000, 'US', '2017-07-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135701, 'Cherryvale', 'Cherryvale', '', 33.9557100, -80.4581400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135702, 'Chesterfield', 'Chesterfield', 'Chesterfild,chstrfyld  karwlynay jnwby,qie si te fei er de,tshystrfyld,Честерфилд,تشيسترفيلد,چسترفیلد، کارولینای جنوبی,چیسٹرفیلڈ، جنوبی کیرولائنا,切斯特菲尔德', 34.7359900, -80.0881200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135703, 'Chester', 'Chester', 'Chester,Chester Court House,Chesterville,chstr  karwlynay jnwby,qie si te,tshystr,Честер,تشيستر,چستر، کارولینای جنوبی,چیسٹر، جنوبی کیرولائنا,切斯特', 34.7048600, -81.2142600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135704, 'City View', 'City View', '', 34.8615100, -82.4315100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135705, 'Clearwater', 'Clearwater', '', 33.4968000, -81.8920600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135706, 'Clemson', 'Clemson', 'CEU,Calhoun,Clemson,Klemson,ke lai mu sen,klmswn  karwlynay jnwby,klymswn,kuremuson,Клемсон,كليمسون,کالہون، جنوبی کیرولائنا,کلمسون، کارولینای جنوبی,クレムソン,克莱姆森', 34.6834400, -82.8373700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135707, 'Clinton', 'Clinton', 'Clinton,Five Forks,Five Points,Hollands Store,Klinton,ke lin dun,klyntwn,klyntwn  karwlynay jnwby,Клинтон,كلينتون,کلنٹن، جنوبی کیرولائنا,کلینتون، کارولینای جنوبی,克林顿', 34.4726300, -81.8806600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135708, 'Clover', 'Clover', '', 35.1112500, -81.2264600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135709, 'Columbia', 'Columbia', 'CAE,Columbia,Columbia i Sor-Carolina,Columbia i Sør-Carolina,Colùmbia,Colúmbia,Gorad Kalumbija,Kolambija,Koloumpia,Kolumbi,Kolumbia,Kolumbija,Kuolumbeje,Kuolumbėjė,ge lun bi ya,kalambiya,keolleombia,klmbya  karwlynay jnwby,kolambiya,kolampiya,koronbia,kwlmbya  jnwby kyrwlayna,kwlwmbya,qwlwmbyh,Κολούμπια,Горад Калумбія,Коламбија,Колумби,Колумбия,Колумбија,Колумбія,Կոլումբիա,קאלאמביע,קולומביה,كولومبيا,کلمبیا، کارولینای جنوبی,کولمبیا، جنوبی کیرولائنا,कोलंबिया,कोलम्बिया,কলাম্বিয়া,કોલંબિયા,கொலம்பியா,కొలంబియా,კოლუმბია,コロンビア,哥伦比亚,컬럼비아', 34.0007100, -81.0348100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135710, 'Conway', 'Conway', 'Conway,Conway Boro,Conwayboro,Conwayborough,Kingston,Konuej,Konvej,kang wei,kanwy  karwlynay jnwby,kwnway,Конвей,Конвеј,Конуей,كونواي,کانوی، کارولینای جنوبی,کونوے، جنوبی کیرولائنا,康威', 33.8360000, -79.0478100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135711, 'Cowpens', 'Cowpens', 'Cowpens,Hanna''s Cow-pens,Hannahs Cowpens,Saunders Cowpens,The Cowpens', 35.0167900, -81.8039900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135712, 'Dalzell', 'Dalzell', '', 34.0168200, -80.4300800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135713, 'Darlington', 'Darlington', 'Darlington,Darlington Court House,da lin dun,darlyngtwn  karwlynay jnwby,Дарлингтон,دارلینگتون، کارولینای جنوبی,ڈارلنگٹن، جنوبی کیرولائنا,达林顿', 34.2998800, -79.8761700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135714, 'Denmark', 'Denmark', 'Denmark,Grahams,Grahams Turn Out,Grahams Turnout,Sato,dan mai,danmark  karwlynay jnwby,dnmark,Денмарк,دانمارک، کارولینای جنوبی,دنمارك,丹麦', 33.3226500, -81.1423200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135715, 'Dentsville', 'Dentsville', 'Dents,Dents Station,Dentsville', 34.0640400, -80.9581500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135716, 'Dillon', 'Dillon', 'DLL,Dilon,di long,dylwn,dylwn  karwlynay jnwby,Дилон,ديلون,دیلون، کارولینای جنوبی,ڈلن، جنوبی کیرولائنا,狄龙', 34.4165500, -79.3711600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135717, 'Due West', 'Due West', 'De Witts Corner,DeWitt,DeWitt''s Corner,DeWitts,Devises,Devises Corner,Dewises,Dewises Corner,Dewiss Corner,Dewitts Corner,Drumtochty,Du Vest,Due West,Due West Corner,Duets,Duets Corner,Duetts,Duetts Corner,Duewest,Jewitts Corner,Selma,di wei si te,dw wst,dw wst  karwlynay jnwby,Ду Вест,دو وست,دو وست، کارولینای جنوبی,迪韦斯特', 34.3334500, -82.3879000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135718, 'Duncan', 'Duncan', 'Duncan,Duncans Cross Roads,Dunkan,Vernonsville,Дункан', 34.9379000, -82.1451100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135719, 'Dunean', 'Dunean', '', 34.8248400, -82.4192900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135720, 'Easley', 'Easley', 'Easley,Easley Station,Izli,aysly,ayzly  karwlynay jnwby,ayzyly  jnwby kyrwlayna,izuri,yi si li,Изли,إيسلي,ایزلی، کارولینای جنوبی,ایزیلی، جنوبی کیرولائنا,イーズリー,伊斯利', 34.8298400, -82.6015200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135721, 'East Gaffney', 'East Gaffney', '', 35.0801300, -81.6328700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135722, 'East Sumter', 'East Sumter', '', 33.9254400, -80.2961900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135723, 'Edgefield', 'Edgefield', 'Edgefield,Edgefield Court House,Edzfild,adgfyld  karwlynay jnwby,adyghfyld,ai qi fei er de,Еџфилд,إديغفيلد,ادگفیلد، کارولینای جنوبی,ایجفیلڈ، جنوبی کیرولائنا,埃奇菲尔德', 33.7895800, -81.9295600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135724, 'Edisto', 'Edisto', '', 33.4765400, -80.8987000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135725, 'Elgin', 'Elgin', 'Blaney,Elgin,Woodville', 34.1709800, -80.7942500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135726, 'Elgin', 'Elgin', 'Elgin,Saint Luke,Woodville', 34.6729300, -80.7189600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135727, 'Estill', 'Estill', '', 32.7548900, -81.2420500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135728, 'Eureka Mill', 'Eureka Mill', '', 34.7176400, -81.1937000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135729, 'Fairfax', 'Fairfax', 'Campbellton,Fairfax,First Variant,Sanders', 32.9590500, -81.2365000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135730, 'Fairforest', 'Fairforest', 'Fair Forest,Fairforest', 34.9565100, -82.0101100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135731, 'Five Forks', 'Five Forks', '', 34.8048400, -82.2295600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135732, 'Florence', 'Florence', 'FLO,Florencija,Florens,flrns  karwlynay jnwby,flwrns,flwrns  jnwby kyrwlayna,fu luo lun sa,furorensu,peullolenseu,Флоренс,Флоренция,فلرنس، کارولینای جنوبی,فلورنس,فلورنس، جنوبی کیرولائنا,フローレンス,佛罗伦萨,플로렌스', 34.1954300, -79.7625600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135733, 'Folly Beach', 'Folly Beach', '', 32.6551800, -79.9403700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135734, 'Forest Acres', 'Forest Acres', '', 34.0193200, -80.9898100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135735, 'Forestbrook', 'Forestbrook', '', 33.7223900, -78.9580900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135736, 'Fort Mill', 'Fort Mill', 'Fort Mil,Fort Mill,Fort Mills,Fort Station,Ft. Mill,frt myl  karwlynay jnwby,fwrt myl,mi er bao,Форт Мил,فرت میل، کارولینای جنوبی,فورت ميل,فورٹ مل، جنوبی کیرولائنا,米尔堡', 35.0073700, -80.9450800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135737, 'Fountain Inn', 'Fountain Inn', 'Fauntin In,fawntn ann,fawntn ayn  karwlynay jnwby,pen quan ke zhan,Фаунтин Ин,فاؤنٹین ان، جنوبی کیرولائنا,فاونتن إنن,فاونتن این، کارولینای جنوبی,喷泉客栈', 34.6890100, -82.1956700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135738, 'Gadsden', 'Gadsden', 'Gadsden,Gadsden Depot', 33.8457100, -80.7659200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135739, 'Gaffney', 'Gaffney', 'Gaffney,Gaffney City,Gaffney''s Cross Roads,Gaffneys Cross Roads,Gaffneys Old Field,Gafni,gafuni,gfny  karwlynay jnwby,gpny,gyfny  jnwby kyrwlayna,jafny,jia fu ni,Гафни,גפני,جافني,گفنی، کارولینای جنوبی,گیفنی، جنوبی کیرولائنا,ガフニー,加夫尼', 35.0717900, -81.6498200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135740, 'Gantt', 'Gantt', '', 34.8001200, -82.4242900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135741, 'Garden City', 'Garden City', 'Garden Siti,Гарден Сити', 33.5929500, -79.0086500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135742, 'Gaston', 'Gaston', '', 33.8171000, -81.1009300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135743, 'Georgetown', 'Georgetown', 'Dzordztaun,Džordžtaun,GGE,George Town,Georges Town,Georgetown,jrj‌tawn  karwlynay jnwby,jwrjtawn,qiao zhi dui,Џорџтаун,جارج ٹاؤن، جنوبی کیرولائنا,جرج‌تاون، کارولینای جنوبی,جورجتاون,乔治敦', 33.3768300, -79.2945000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135744, 'Gloverville', 'Gloverville', 'Gloversville,Gloverville', 33.5259700, -81.8301100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135745, 'Golden Grove', 'Golden Grove', '', 34.7340100, -82.4437400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135746, 'Goose Creek', 'Goose Creek', 'Gus Krik,e xi,ghws kryk,gusukuriku,gws kryk  karwlynay jnwby,gwz kryk  jnwby kyrwlayna,Гус Крик,غوس كريك,گوز کریک، جنوبی کیرولائنا,گوس کریک، کارولینای جنوبی,グースクリーク,鹅溪', 32.9810100, -80.0325900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135747, 'Graniteville', 'Graniteville', '', 33.5637500, -81.8078900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135748, 'Great Falls', 'Great Falls', 'Grejt Fols,da pu bu,ghryt fals,gryt falz  karwlynay jnwby,Грејт Фолс,غريت فالس,گریت فالز، کارولینای جنوبی,گریٹ فالز، جنوبی کیرولائنا,大瀑布', 34.5751400, -80.9020200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135749, 'Greenville', 'Greenville', 'GSP,Greenville,Greenville City,Greenville Court House,Greenville Courthouse,Grijnvil,Grinvil,Grinvil'',Grinvill,Pleasantburg,Pleasantville,ge lin wei er,geulinbil,ghrynfyl,grinvili,grynwwyl,grynwyl  jnwby kyrwlayna,grynwyl  karwlynay jnwby,gurinbiru,Грийнвил,Гринвил,Гринвилл,Ґрінвіль,גרינוויל,غرينفيل,گرینویل، جنوبی کیرولائنا,گرینویل، کارولینای جنوبی,გრინვილი,グリーンビル,格林维尔,그린빌', 34.8526200, -82.3940100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135750, 'Greenwood', 'Greenwood', 'GRD,Green Wood,Greenwood,Grinvud,Old Greenwood,Woodville,ge lin wu de,ghrynwwd,grynwwd  karwlynay jnwby,gurin''uddo,Гринвуд,غرينوود,گرینوود، کارولینای جنوبی,گرینووڈ، جنوبی کیرولائنا,グリーンウッド,格林伍德', 34.1954000, -82.1617900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135751, 'Greer', 'Greer', 'Greer,Greer''s Depot,Greers Depot,Grer,Grir,ge li er,ghryr,gryr  jnwby kyrwlayna,gryr  karwlynay jnwby,guria,Грер,Грир,غرير,گریر، جنوبی کیرولائنا,گریر، کارولینای جنوبی,グリア,格里尔', 34.9387300, -82.2270600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135752, 'Hampton', 'Hampton', 'Hampton,Hampton Court House,Hoovers Crossing,Khehmpton,Khempton,hambtwn,han pu dun,hmptwn  karwlynay jnwby,Хемптон,Хэмптон,هامبتون,همپتون، کارولینای جنوبی,汉普顿', 32.8779400, -81.1276100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135753, 'Hanahan', 'Hanahan', 'Hanahan,Khanakhan,Saxon,ha na han,hanahan,hnhn  karwlynay jnwby,Ханахан,هاناهان,هنهن، کارولینای جنوبی,哈那汗', 32.9185100, -80.0220300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135754, 'Hardeeville', 'Hardeeville', 'Khardivil,ha di wei er,hardwyl  karwlynay jnwby,hardyfyl,Хардивил,هاردویل، کارولینای جنوبی,هارديفيل,ہارڈیویل، جنوبی کیرولائنا,哈迪维尔', 32.2871400, -81.0806700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135755, 'Hartsville', 'Hartsville', 'HVS,Khartsvil,ha ci wei er,hartsfyl,hartswyl  karwlynay jnwby,Хартсвил,هارتسفيل,هارتسویل، کارولینای جنوبی,哈茨维尔', 34.3740400, -80.0734000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135756, 'Hilton Head Island', 'Hilton Head Island', 'Gilton-Ged-Ajlend,Great Wassaw Island,Hilton Head Island,Hilton''s Head Island,Ile de Hilton-Head,Isla De Los Osos,Isle De Tranches,Khilton Khed Ajland,Khilton-Khed-Ajlend,Trenches Island,Trenchs Island,hirutonheddoairando,hyltn hd aylnd  karwlynay jnwby,hyltwn hyd ayland,xi er dun hei de dao,Île de Hilton-Head,Гілтон-Гед-Айленд,Хилтон Хед Ајланд,Хилтон-Хед-Айленд,هيلتون هيد أيلاند,هیلتن هد آیلند، کارولینای جنوبی,ہلٹن ہیڈ جزیرہ، جنوبی کیرولائنا,ヒルトンヘッドアイランド,希尔顿黑德岛', 32.1938200, -80.7381600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135757, 'Hilton Head', 'Hilton Head', 'HHH,Hilton Head,Hilton Head Island,Hiltonhead', 32.2163200, -80.7526100, 'US', '2016-10-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135758, 'Holly Hill', 'Holly Hill', '', 33.3226600, -80.4137000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135759, 'Hollywood', 'Hollywood', 'Gollivud,Голливуд', 32.7343400, -80.2417700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135760, 'Honea Path', 'Honea Path', 'Honea Path,Honeapath,Honey Path', 34.4465000, -82.3915100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135761, 'Homeland Park', 'Homeland Park', '', 34.4706600, -82.6706900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135762, 'Hopkins', 'Hopkins', 'Hopkins,Hopkins Turnout', 33.9043200, -80.8770300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135763, 'India Hook', 'India Hook', 'India Hook,Indian Hook', 35.0073700, -81.0217400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135764, 'Inman', 'Inman', '', 35.0470600, -82.0901100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135765, 'Inman Mills', 'Inman Mills', '', 35.0415100, -82.1042800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135766, 'Irmo', 'Irmo', 'Ermo,aiamo,armw  jnwby kyrwlayna,ayrmw,ayrmw  karwlynay jnwby,e mo,Ермо,إيرمو,ارمو، جنوبی کیرولائنا,ایرمو، کارولینای جنوبی,アイアモ,厄莫', 34.0859800, -81.1831500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135767, 'Irwin', 'Irwin', '', 34.6937600, -80.8222900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135768, 'Isle of Palms', 'Isle of Palms', 'Ajl ov Pams,airuobupamuzu,ayl af pamz  jnwby kyrwlayna,ayl aw pam  karwlynay jnwby,ayzly,formerly Long Island,zong lu dao,Ајл ов Памс,آئل آف پامز، جنوبی کیرولائنا,آیل آو پام، کارولینای جنوبی,إيزلي,アイルオブパームズ,棕榈岛', 32.7868400, -79.7948000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135769, 'Iva', 'Iva', 'Cooks,Cooks Station,Iva', 34.3065000, -82.6637400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135770, 'Jackson', 'Jackson', 'Dzhekson,Jackson,Jackson Station,Silver Town,Silverton,Джексон', 33.3254200, -81.7878900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135771, 'Joanna', 'Joanna', 'Goldville,Huntsville,Joanna,Martins Depot,Milton', 34.4149100, -81.8124000, 'US', '2015-05-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135772, 'Johnsonville', 'Johnsonville', '', 33.8179400, -79.4492200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135773, 'Johnston', 'Johnston', 'Johnson,Johnston,Lotts', 33.8320800, -81.8009400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135774, 'Judson', 'Judson', '', 34.8331700, -82.4276200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135775, 'Kershaw', 'Kershaw', 'Kershaw,Kersho,Welchs,Welchs Station,Welshs Station,ke xiao,krshaw  karwlynay jnwby,kyrshaw,Кершо,كيرشاو,کرشاو، کارولینای جنوبی,克肖', 34.5518200, -80.5836800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135776, 'Kiawah Island', 'Kiawah Island', '', 32.6082400, -80.0848200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135777, 'Kingstree', 'Kingstree', 'Kings Tree,Kingstree,Kingstri,Williamsburgh,jin si te li,kynghstry,kyngstr  karwlynay jnwby,Кингстри,كينغستري,کنگزٹری، جنوبی کیرولائنا,کینگستر، کارولینای جنوبی,金斯特里', 33.6676600, -79.8306300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135778, 'Ladson', 'Ladson', 'Ladson,Ladsons', 32.9857300, -80.1098100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135779, 'Lake City', 'Lake City', 'Grahams Crossroads,Lake City,Lejk Siti,Lynches Lake,McCreas Crossroads,The Crossroads,lai ke cheng,lyk syty,lyk syty  karwlynay jnwby,Лејк Сити,ليك سيتي,لیک سٹی، جنوبی کیرولائنا,لیک سیتی، کارولینای جنوبی,莱克城', 33.8710000, -79.7553500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135780, 'Lake Secession', 'Lake Secession', '', 34.2845500, -82.5945700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135781, 'Lake Wylie', 'Lake Wylie', '', 35.1084800, -81.0428500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135782, 'Lakewood', 'Lakewood', 'Lejkvud,Лейквуд', 33.8468300, -80.3500800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135783, 'Lancaster', 'Lancaster', 'Barnetsville,Barnettsville,Lancaster,Lancasterville,Lankaster,lan kai si te,lankstr,lnkstr  karwlynay jnwby,Ланкастер,لانكستر,لنکاسٹر، جنوبی کیرولائنا,لنکستر، کارولینای جنوبی,兰开斯特', 34.7204300, -80.7709000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135784, 'Lancaster Mill', 'Lancaster Mill', '', 34.7093100, -80.7947900, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135785, 'Landrum', 'Landrum', 'Earles Ford,Earlesville,Earleville,Landrum', 35.1751100, -82.1892800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135786, 'Langley', 'Langley', 'Langley,Marshes', 33.5179100, -81.8440000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135787, 'Latta', 'Latta', 'Bishopville,Lata,Latta,Sardis,la ta,lata,lata  jnwby kyrwlayna,lata  karwlynay jnwby,Лата,لاتا,لاتا، جنوبی کیرولائنا,لاتا، کارولینای جنوبی,拉塔', 34.3371000, -79.4311600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135788, 'Laurel Bay', 'Laurel Bay', '', 32.4501900, -80.7848300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135789, 'Laurens', 'Laurens', 'Laurens,Laurens Court House,Laurensville,Lorens,lao lun si,laryns  jnwby kyrwlayna,lrnz  karwlynay jnwby,lwrns,Лоренс,لارینس، جنوبی کیرولائنا,لرنز، کارولینای جنوبی,لورنس,劳伦斯', 34.4990100, -82.0142600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135790, 'Leesville', 'Leesville', 'Batesburg-Leesville,Leesville', 33.9165300, -81.5134400, 'US', '2010-02-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135791, 'Lesslie', 'Lesslie', 'Leslie,Lesslie', 34.8907000, -80.9564700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135792, 'Lexington', 'Lexington', 'Leksington,Lexington,Pompeytown,Saxe-Gotha,lie ke xing dui,lksyngtwn  karwlynay jnwby,lyksynghtwn,rekishinton,Лексингтон,ليكسينغتون,لکسینگتون، کارولینای جنوبی,لیکسنگٹن، جنوبی کیرولائنا,レキシントン,列克星敦', 33.9815400, -81.2362100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135793, 'Liberty', 'Liberty', 'Liberti,Liberty,Salubrity,li bo di,lybrty,lybrty  karwlynay jnwby,Либерти,لبرٹی، جنوبی کیرولائنا,ليبرتي,لیبرتی، کارولینای جنوبی,利伯蒂', 34.7878900, -82.6923600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135794, 'Lincolnville', 'Lincolnville', '', 33.0068400, -80.1553700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135795, 'Little River', 'Little River', '', 33.8732300, -78.6141800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135796, 'Loris', 'Loris', 'Lollise,Loris', 34.0562800, -78.8903000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135797, 'Lyman', 'Lyman', 'Groce,Lyman', 34.9481700, -82.1273300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135798, 'Manning', 'Manning', 'Mening,man ning,manyngh,mnyng  karwlynay jnwby,Менинг,مانينغ,منینگ، کارولینای جنوبی,曼宁', 33.6951600, -80.2109100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135799, 'Marion', 'Marion', 'Gilesborough,Marion,Marion Court House,Mehrion,ma li ang,marywn,marywn  jnwby kyrwlayna,mrywn  karwlynay jnwby,Марион,Мэрион,ماريون,ماریون، جنوبی کیرولائنا,مریون، کارولینای جنوبی,马里昂', 34.1782200, -79.4006100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135800, 'Mauldin', 'Mauldin', 'Butler''s Crossroads,Huntersville,Mauldin,Moldin,mldn  karwlynay jnwby,mo er ding,morudin,mwldyn,Молдин,ماولڈن، جنوبی کیرولائنا,ملدن، کارولینای جنوبی,مولدين,モールディン,莫尔丁', 34.7787300, -82.3101200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135801, 'Mayo', 'Mayo', '', 35.0840100, -81.8598300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135802, 'McColl', 'McColl', 'McCall,McColl', 34.6687700, -79.5453300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135803, 'McCormick', 'McCormick', 'Dorns Mines,Makormik,McCormick,mai kao mi ke,mk kwrmk  jnwby kyrwlayna,mk kwrmyk,Макормик,مك كورميك,مک کورمک، جنوبی کیرولائنا,مک‌کورمیک، کارولینای جنوبی,麦考密克', 33.9134600, -82.2934600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135804, 'Meggett', 'Meggett', '', 32.7179600, -80.2389900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135805, 'Moncks Corner', 'Moncks Corner', 'Manks Korner,Moncks Corner,Monks Corner,meng ke si ke na,mwnks krnr  karwlynay jnwby,mwnks kwrnr,mwnks kwrnr  jnwby kyrwlayna,Манкс Корнер,مونكس كورنر,مونکس کرنر، کارولینای جنوبی,مونکس کورنر، جنوبی کیرولائنا,蒙克斯科纳', 33.1963200, -80.0142900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135806, 'Mount Pleasant', 'Mount Pleasant', 'Maunt Plezant,Mt. Pleasant,mang te pu lin sen,mauntopurezanto,mawnt plznt  karwlynay jnwby,mwnt blystant,Маунт Плезант,ماؤنٹ پلیزینٹ، جنوبی کیرولائنا,ماونت پلزنت، کارولینای جنوبی,مونت بليستانت,マウントプレザント,芒特普林森', 32.7940700, -79.8625900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135807, 'Mullins', 'Mullins', 'Malins,ma lin si,mwlyns  karwlynay jnwby,mwlynz,Малинс,مولينز,مولینس، کارولینای جنوبی,马林斯', 34.2057200, -79.2544900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135808, 'Murphys Estates', 'Murphys Estates', 'Murphy Estates,Murphy Village,Murphy''s Village,Murphys Estates', 33.6012500, -81.9442800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135809, 'Murrells Inlet', 'Murrells Inlet', 'Marels Inlet,Morrall Inlet,Murrells Inlet,Murrels Inlet,mwrls aynlt  karwlynay jnwby,myrtl bytsh,Марелс Инлет,مورلس اینلت، کارولینای جنوبی,ميرتل بيتش', 33.5510000, -79.0414300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135810, 'Myrtle Beach', 'Myrtle Beach', 'Long Bay,MYR,Mertl Bich,Mertl-Bich,Myrtle Beach,New Town,matorubichi,mo te er bi qi,mrtl bych  karwlynay jnwby,myrtl bytsh,Мертл Бич,Мертл-Бич,Мертл-Біч,مرتل بیچ، کارولینای جنوبی,ميرتل بيتش,میرٹل بیچ، جنوبی کیرولائنا,マートルビーチ,默特尔比奇', 33.6890600, -78.8866900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135811, 'New Ellenton', 'New Ellenton', '', 33.4215300, -81.6856700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135812, 'Newberry', 'Newberry', 'New Berry,Newberry,Newberry Court House,Njuberi,Vanduslah Spring,niu bei li,nyuberi,nywbry  karwlynay jnwby,nywbyry,nywbyry  jnwby kyrwlayna,Њубери,نيوبيري,نیوبری، کارولینای جنوبی,نیوبیری، جنوبی کیرولائنا,ニューベリー,纽贝里', 34.2745800, -81.6187200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135813, 'Newport', 'Newport', 'N''juport,New Port,Newport,Ньюпорт', 34.9898600, -81.1009100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135814, 'Ninety Six', 'Ninety Six', 'Cambridge,Fort Ninety Six,Najnti Siks,Ninety Six,Ninety-Six,Ninety-six,Ninetysix,jiu shi liu,naynty syks,naynty syks  karwlynay jnwby,Најнти Сикс,ناينتي سيكس,ناینتی سیکس، کارولینای جنوبی,九十六', 34.1751300, -82.0240100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135815, 'North Augusta', 'North Augusta', 'Nort Ogasta,bei ao gu si ta,nosuogasuta,nwrt agasta  karwlynay jnwby,nwrth awghwsta,Норт Огаста,شمالی آگسٹا، جنوبی کیرولائنا,نورت اگاستا، کارولینای جنوبی,نورث أوغوستا,ノースオーガスタ,北奥古斯塔', 33.5018000, -81.9651200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135816, 'North Charleston', 'North Charleston', 'CHS,N. Charleston,Nort Charlston,Nort-Charlston,North Charleston,bei cha er si dun,nosucharusuton,nwrt charlstn  karwlynay jnwby,nwrth tsharlstwn,Норт Чарлстон,Норт-Чарлстон,شمالی چارلسٹن، جنوبی کیرولائنا,نورت چارلستن، کارولینای جنوبی,نورث تشارلستون,ノースチャールストン,北查尔斯顿', 32.8546200, -79.9748100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135817, 'North Hartsville', 'North Hartsville', '', 34.3937700, -80.0695100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135818, 'North Myrtle Beach', 'North Myrtle Beach', 'Chicora,Nort Mertl Bich,North Myrtle Beach,Palmetto,Windy Hill Beach,mei te er hai tan,nosumatorubichi,nrt mrtl bych  karwlynay jnwby,nwrth myrtl bytsh,Норт Мертл Бич,نارتھ میرٹل بیچ، جنوبی کیرولائنا,نرت مرتل بیچ، کارولینای جنوبی,نورث ميرتل بيتش,ノースマートルビーチ,美特尔海滩', 33.8160100, -78.6800200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135819, 'Northlake', 'Northlake', '', 34.5662200, -82.6840200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135820, 'Oak Grove', 'Oak Grove', '', 33.7782100, -80.9667600, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135821, 'Oakland', 'Oakland', 'Oklend,Окленд', 33.9829300, -80.4884200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135822, 'Orangeburg', 'Orangeburg', 'OGB,Orangeburg,Orangeburgh', 33.4918200, -80.8556500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135823, 'Pacolet', 'Pacolet', 'Pacolet,Pakolet,Pooles Springs,Trough,Trough Shoals,bakwlyt,pa ke li te,pakwlt  karwlynay jnwby,Паколет,باكوليت,پاکولت، کارولینای جنوبی,帕科利特', 34.8990200, -81.7617700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135824, 'Pageland', 'Pageland', 'Old Store,Pageland', 34.7732100, -80.3917300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135825, 'Pamplico', 'Pamplico', '', 33.9960000, -79.5700600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135826, 'Parker', 'Parker', 'Parker,Паркер', 34.8506700, -82.4534600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135827, 'Pendleton', 'Pendleton', 'Pendlton,byndltwn,peng de er dun,pndltn  karwlynay jnwby,Пендлтон,بيندلتون,پندلتن، کارولینای جنوبی,پینڈلٹن، جنوبی کیرولائنا,彭德尔顿', 34.6517700, -82.7837500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135828, 'Pickens', 'Pickens', 'LQK,Pickens,Pickens Court House,Pickensville,Pikens,byknz,pi ken si,pkynz  jnwby kyrwlayna,pyknz  karwlynay jnwby,Пикенс,بيكنز,پکینز، جنوبی کیرولائنا,پیکنز، کارولینای جنوبی,皮肯斯', 34.8834500, -82.7073600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135829, 'Piedmont', 'Piedmont', '', 34.7023400, -82.4645700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135830, 'Pineridge', 'Pineridge', 'Pine Ridge,Pineridge', 33.9104300, -81.1045400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135831, 'Port Royal', 'Port Royal', 'Port Rojal,Port Royal,Port Royall,Saint Ellens,huang jia gang kou,prt rwyl  karwlynay jnwby,Порт Ројал,پرت رویل، کارولینای جنوبی,皇家港口', 32.3790800, -80.6926100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135832, 'Powdersville', 'Powdersville', 'Powdersville,Powderville', 34.7917800, -82.4929100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135833, 'Privateer', 'Privateer', '', 33.8332100, -80.4142500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135834, 'Prosperity', 'Prosperity', 'Frog Ievel,Frog Level,Prosperity,The Level', 34.2093100, -81.5331600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135835, 'Ravenel', 'Ravenel', 'Ravenel,Ravenels', 32.7632300, -80.2501000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135836, 'Red Bank', 'Red Bank', 'Irene,Red Bank,Redbank', 33.9320900, -81.2384300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135837, 'Red Hill', 'Red Hill', '', 33.9996100, -79.2581000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135838, 'Red Hill', 'Red Hill', '', 33.8207300, -79.0189200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135839, 'Ridgeland', 'Ridgeland', 'Gopher Hill,Ridgeland,Ridzland,li qi lan,rydgland  karwlynay jnwby,Риџланд,ریدگلاند، کارولینای جنوبی,里奇兰', 32.4807400, -80.9803900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135840, 'Ridgeville', 'Ridgeville', 'Ridgeville,Timothy Creek', 33.0957200, -80.3153700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135841, 'Rock Hill', 'Rock Hill', 'Ebenezer Depot,Rock Hill,Rockhill,Rocky Hill', 34.9248700, -81.0250800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135842, 'Roebuck', 'Roebuck', 'Becca,Roebuck', 34.8795700, -81.9662100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135843, 'Saint Andrews', 'Saint Andrews', '', 34.0454300, -81.1292600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135844, 'Saint George', 'Saint George', 'Georges Station,Saint George,Saint George''s,Svjatoj Georgij,Святой Георгий', 33.1860000, -80.5756500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135845, 'Saint Matthews', 'Saint Matthews', 'Lewisburg,Lewisville,Saint Matthews', 33.6648800, -80.7778700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135846, 'Saint Stephen', 'Saint Stephen', 'Saint Stephen,Saint Stephens,Saint Stephens Depot', 33.4043300, -79.9217400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135847, 'Saluda', 'Saluda', 'Old Saluda Town,Saluda,sa lu da,slwda  karwlynay jnwby,Салуда,سلودا، کارولینای جنوبی,萨卢达', 34.0015200, -81.7720500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135848, 'Sangaree', 'Sangaree', '', 33.0354500, -80.1278700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135849, 'Sans Souci', 'Sans Souci', '', 34.8779000, -82.4240100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135850, 'Saxon', 'Saxon', 'Saxon,Saxon Mills', 34.9612300, -81.9673300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135851, 'Seabrook Island', 'Seabrook Island', '', 32.5771300, -80.1706500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135852, 'Seneca', 'Seneca', 'Seneca,Seneca City,Seneka,sai nei ka,snyka  karwlynay jnwby,synyka,synyka  jnwby kyrwlayna,Сенека,سنیکا، کارولینای جنوبی,سينيكا,سینیکا، جنوبی کیرولائنا,塞内卡', 34.6856600, -82.9532000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135853, 'Seven Oaks', 'Seven Oaks', '', 34.0487600, -81.1464800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135854, 'Shell Point', 'Shell Point', '', 32.3835300, -80.7359400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135855, 'Shell Point', 'Shell Point', '', 32.7890700, -80.1067600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135856, 'Simpsonville', 'Simpsonville', 'Plain,Simpsonvil,Simpsonville,shinpusonbiru,smpsnwyl  jnwby kyrwlayna,symbswnfyl,sympswnwyl  karwlynay jnwby,xin pu sen wei er,Симпсонвил,سمپسنویل، جنوبی کیرولائنا,سيمبسونفيل,سیمپسونویل، کارولینای جنوبی,シンプソンビル,辛普森维尔', 34.7370600, -82.2542800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135857, 'Socastee', 'Socastee', '', 33.6835000, -78.9983700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135858, 'South Congaree', 'South Congaree', 'Congaree,South Congaree', 33.9109900, -81.1356500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135859, 'South Sumter', 'South Sumter', '', 33.9057100, -80.3461900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135860, 'Southern Shops', 'Southern Shops', '', 34.9859500, -81.9945500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135861, 'Spartanburg', 'Spartanburg', 'SPA,Spartanberg,Spartanburg,Spartanburgh,aspartnbwrg  karwlynay jnwby,sbartanbrgh,seupateonbeogeu,si pa tan bao,supatanbagu,Спартанберг,Спартанбург,اسپارتنبورگ، کارولینای جنوبی,سبارتانبرغ,سپارٹنبرگ، جنوبی کیرولائنا,スパータンバーグ,斯帕坦堡,스파턴버그', 34.9495700, -81.9320500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135862, 'Springdale', 'Springdale', '', 34.6893100, -80.7861800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135863, 'Springdale', 'Springdale', '', 33.9593200, -81.1089800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135864, 'Stateburg', 'Stateburg', 'Stateburg,Stateburgh,Statesborough,Statesburg', 33.9576500, -80.5348100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135865, 'Sullivans Island', 'Sullivans Island', 'Isola di Sullivan,Moultrieville,Sullivan''s Island,Sullivans Island,Sullivanuv ostrov,Sullivanův ostrov,Sullivan’s Island,saribanzuairando,sha li wen de dao,swlywans aylnd  karwlynay jnwby,סאליבנס איילנד,سولیوانز جزیرہ، جنوبی کیرولائنا,سولیوانس آیلند، کارولینای جنوبی,サリバンズアイランド,沙利文的岛', 32.7632300, -79.8367500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135866, 'Summerville', 'Summerville', 'Flower Town In the Pines,Samervil,Sammervill,Summerville,sa mo wei er,samabiru,samrwyl  karwlynay jnwby,smrwyl  jnwby kyrwlayna,Самервил,Саммервилл,سامرویل، کارولینای جنوبی,سمرویل، جنوبی کیرولائنا,サマービル,萨默维尔', 33.0185000, -80.1756500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135867, 'Sumter', 'Sumter', 'SSC,Samter,Sumter,Sumterville,sa mu te,samtr  karwlynay jnwby,smtr,Самтер,سامتر، کارولینای جنوبی,سمتر,سمٹر، جنوبی کیرولائنا,萨姆特', 33.9204400, -80.3414700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135868, 'Surfside Beach', 'Surfside Beach', 'Floral Beach,Surfside Beach', 33.6060000, -78.9730900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135869, 'Taylors', 'Taylors', 'Taylor,Taylors', 34.9203900, -82.2962300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135870, 'Tega Cay', 'Tega Cay', '', 35.0243100, -81.0278500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135871, 'Tigerville', 'Tigerville', 'Tigerville,Tygerville', 35.0684500, -82.3684500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135872, 'Timmonsville', 'Timmonsville', '', 34.1348800, -79.9397900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135873, 'Travelers Rest', 'Travelers Rest', 'Otis,Pontiac,Travelers Rest,Travellers Rest,Tray,lu ke xiu xi,traflrz ryst,trwlr rst  karwlynay jnwby,Травелерс Рест,ترافلرز ريست,ترولر رست، کارولینای جنوبی,ٹریولرزریسٹ، جنوبی کیرولائنا,旅客休息', 34.9676200, -82.4434500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135874, 'Union', 'Union', 'Junion,USC,Union,Union Station,Unionville,aywnyn  karwlynay jnwby,lian he,ywnyn  jnwby kyrwlayna,ywnywn,Јунион,ایونین، کارولینای جنوبی,يونيون,یونین، جنوبی کیرولائنا,联合', 34.7154100, -81.6237100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135875, 'Utica', 'Utica', 'Jordania,Lonsdale,Utica', 34.6781600, -82.9315400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135876, 'Valley Falls', 'Valley Falls', 'Lola,Martel Mills,McMakins,Valley Falls,Valley Falls Mill', 35.0159500, -81.9748300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135877, 'Varnville', 'Varnville', 'Dixie,Varnville', 32.8504400, -81.0792700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135878, 'Wade Hampton', 'Wade Hampton', '', 34.9037300, -82.3331700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135879, 'Walhalla', 'Walhalla', 'Valkhala,walhala,walhala  karwlynay jnwby,wo er ha la,Валхала,والهالا,والهالا، کارولینای جنوبی,والہالا، جنوبی کیرولائنا,沃尔哈拉', 34.7648200, -83.0640400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135880, 'Walterboro', 'Walterboro', 'Ireland Creek,RBW,Volterboro,Walterboro,Walterborough,Waterboro,waltrbwrw,waltrbwrw  karwlynay jnwby,wo er te bo lei,Волтерборо,والتربورو,والتربورو، کارولینای جنوبی,والٹربورو، جنوبی کیرولائنا,沃尔特伯勒', 32.9051700, -80.6667700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135881, 'Ware Shoals', 'Ware Shoals', 'Ware Shoals,Wares Mills', 34.3984500, -82.2467900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135882, 'Warrenville', 'Warrenville', '', 33.5509700, -81.8040000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135883, 'Wedgefield', 'Wedgefield', 'Wedgewood', 33.8926600, -80.5181400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135884, 'Wedgewood', 'Wedgewood', '', 33.8837700, -80.5125800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135885, 'Welcome', 'Welcome', '', 34.8265100, -82.4390100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135886, 'Wellford', 'Wellford', 'Welford,Wellford', 34.9509500, -82.1059400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135887, 'West Columbia', 'West Columbia', 'Aretasville,Brookland,Green Hill,New Brookland,Vest Kolambija,West Columbia,wst klmbya  karwlynay jnwby,wyst kwlwmbya,xi ge lun bi ya,Вест Коламбија,وست کلمبیا، کارولینای جنوبی,ويست كولومبيا,ویسٹ کولمبیا، جنوبی کیرولائنا,西哥伦比亚', 33.9934900, -81.0739800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135888, 'Westminster', 'Westminster', 'Vestminster,wei si min si te,wstmnstr,wstmynstr  karwlynay jnwby,Вестминстер,وستمنستر,وستمینستر، کارولینای جنوبی,ویسٹ منسٹر، جنوبی کیرولائنا,威斯敏斯特', 34.6648200, -83.0965400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135889, 'Whitmire', 'Whitmire', 'Whitmire,Whitmires', 34.5029100, -81.6114900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135890, 'Wilkinson Heights', 'Wilkinson Heights', '', 33.5021000, -80.8331500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135891, 'Williamston', 'Williamston', 'Mineral Springs,Williamson,Williamston', 34.6184500, -82.4779100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135892, 'Williston', 'Williston', '', 33.4026500, -81.4201100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135893, 'Winnsboro', 'Winnsboro', 'Vinsboro,Winnsboro,Winnsborough,Winsborough,Wynnesbourg,wen si bo lei,wynsbwrw  karwlynay jnwby,Винсборо,وینسبورو، کارولینای جنوبی,温斯伯勒', 34.3807000, -81.0864800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135894, 'Winnsboro Mills', 'Winnsboro Mills', '', 34.3618100, -81.0853700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135895, 'Woodfield', 'Woodfield', '', 34.0593200, -80.9309200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135896, 'Woodruff', 'Woodruff', 'Cross Roads,The Mill,Vudraf,Woodruff,Woodruff Tavern,Woodruff''s,Woodruffs,wu de la fu,wwdrwf,wwdrwf  karwlynay jnwby,Вудраф,وودروف,وودروف، کارولینای جنوبی,伍德拉夫', 34.7395700, -82.0370500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135897, 'York', 'York', 'Fergus Cross Roads,Fergusons Cross Roads,Jork,York,Yorkville,yark  jnwby kyrwlayna,yue ke,ywrk,ywrk  karwlynay jnwby,Јорк,Йорк,يورك,یارک، جنوبی کیرولائنا,یورک، کارولینای جنوبی,约克', 34.9943000, -81.2420200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135898, 'Adamsville', 'Adamsville', '', 35.2359100, -88.3906000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135899, 'Alamo', 'Alamo', 'Alamo,Cageville', 35.7847900, -89.1172900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135900, 'Alcoa', 'Alcoa', 'Alcoa,North Maryville,alkwa,alkwa  tnsy,ألكوا,الکوا، تنسی', 35.7895300, -83.9737900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135901, 'Algood', 'Algood', 'Algood,Algoods Old Fields', 36.1958900, -85.4485800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135902, 'Altamont', 'Altamont', '', 35.4295200, -85.7230300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135903, 'Apison', 'Apison', '', 35.0239600, -85.0238400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135904, 'Ardmore', 'Ardmore', 'Ardmore,Austin', 34.9920300, -86.8466700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135905, 'Arlington', 'Arlington', 'Arlington,Haysville,Withe Depot,Арлингтон', 35.2962000, -89.6614700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135906, 'Ashland City', 'Ashland City', 'Ashland,Ashland City,Eshland Siti,aesyullaendeusiti,ashland syty,ashlnd syty  tnsy,Ешланд Сити,أشلاند سيتي,اشلند سیتی، تنسی,애슐랜드시티', 36.2742200, -87.0641700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135907, 'Athens', 'Athens', 'Atens,Athens,MMI,Pumpkintown,athyna,atn  tnsy,Атенс,آتن، تنسی,أثينا,ایتھنز، ٹینیسی', 35.4428500, -84.5929900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135908, 'Atoka', 'Atoka', '', 35.4411900, -89.7781400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135909, 'Banner Hill', 'Banner Hill', '', 36.1306600, -82.4245800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135910, 'Bartlett', 'Bartlett', 'Bartlet,Bartlett,Union Depot,bartlyt,bartlyt  tnsy,Бартлет,Бартлетт,بارتليت,بارتلیت، تنسی,بارٹلیٹ، ٹینیسی', 35.2045300, -89.8739800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135911, 'Baxter', 'Baxter', 'Ai,Baxter,Lowlands,Mine Lick', 36.1536700, -85.6435900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135912, 'Bean Station', 'Bean Station', '', 36.3437000, -83.2840600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135913, 'Belle Meade', 'Belle Meade', 'Belle Mead,Belle Meade', 36.0958900, -86.8569400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135914, 'Bells', 'Bells', 'Bells,Bells Depot', 35.7111800, -89.0875600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135915, 'Benton', 'Benton', 'Benton,Four Mile Stand,bntwn,bntwn  tnsy,Бентон,بنتون,بنتون، تنسی,بینٹن، ٹینیسی', 35.1742400, -84.6535500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135916, 'Blaine', 'Blaine', 'Blain,Blaine,Blains Cross Roads,Blainville,Plains Cross Roads', 36.1542500, -83.7040700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135917, 'Bloomingdale', 'Bloomingdale', '', 36.5845500, -82.4893200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135918, 'Blountville', 'Blountville', 'Blountville,Bluntsville', 36.5331600, -82.3268100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135919, 'Bluff City', 'Bluff City', 'Bluff City,Choates Ford,Middletown,Shoates Ford,Union,Union Depot,Zollicoffer', 36.4742700, -82.2609700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135920, 'Bolivar', 'Bolivar', 'Bolivar,Hatchie', 35.2561900, -88.9878400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135921, 'Bon Aqua Junction', 'Bon Aqua Junction', '', 35.9278400, -87.3108400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135922, 'Bradford', 'Bradford', 'Bradford,Kimble', 36.0764500, -88.8100600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135923, 'Brentwood', 'Brentwood', 'Brentvud,brntwwd  tnsy,bryntwwd,burentouddo,Брентвуд,برنتوود، تنسی,برينتوود,برینٹووڈ، ٹینیسی,ブレントウッド', 36.0331200, -86.7827800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135924, 'Brentwood Estates', 'Brentwood Estates', '', 36.0250600, -86.7791700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135925, 'Brighton', 'Brighton', '', 35.0800900, -86.4391600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135926, 'Brighton', 'Brighton', 'Brajton,Брайтон', 35.4839700, -89.7250800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135927, 'Bristol', 'Bristol', 'Bristol,Sapling Grove,brystwl,brystwl  tnsy,bu li si tuo er,burisutoru,Бристол,برسٹل، ٹینیسی,بريستول,بریستول، تنسی,ブリストル,布里斯托爾', 36.5951100, -82.1887400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135928, 'Brownsville', 'Brownsville', 'Braunsvil,brawnzfyl,brawnzwyl  tnsy,bu lang si wei er,Браунсвил,براونزفيل,براونزویل، تنسی,布朗斯维尔', 35.5939700, -89.2622900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135929, 'Bruceton', 'Bruceton', 'Bruceton,Hollow Rock Junction,Junction City,New One', 36.0381200, -88.2444900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135930, 'Burns', 'Burns', 'Burns,Burns Station,Grade Fortytwo,Halls Station', 36.0533900, -87.3125100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135931, 'Byrdstown', 'Byrdstown', '', 36.5745100, -85.1288400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135932, 'Camden', 'Camden', 'Camden,Glovers Gap,Kamden,Tranquility,kaemdeon,kamdn,kmdn  tnsy,Камден,كامدن,کمدن، تنسی,کیمڈن، ٹینیسی,캠던', 36.0589500, -88.0978200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135933, 'Carthage', 'Carthage', 'Kartidz,jia tai ji,karthagh,kartyj  tnsy,kasiji,Картиџ,كارثاغ,کارتھیج، ٹینیسی,کارتیج، تنسی,迦太基,카시지', 36.2522800, -85.9516500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135934, 'Caryville', 'Caryville', 'Careyville,Caryville', 36.2989700, -84.2232600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135935, 'Celina', 'Celina', '', 36.5500600, -85.5052500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135936, 'Centerville', 'Centerville', 'Centerville,Centreville,GHM', 35.7789600, -87.4669600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135937, 'Central', 'Central', 'Central,Central Heights', 36.3262200, -82.2895800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135938, 'Central', 'Central', '', 35.8036900, -89.5373000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135939, 'Chapel Hill', 'Chapel Hill', 'Chapel Hill,Chapelhill', 35.6264600, -86.6933300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135940, 'Charlotte', 'Charlotte', 'Charlotte,Charlottesville,Sharlott,Шарлотт', 36.1772800, -87.3397300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135941, 'Chattanooga', 'Chattanooga', 'A''tla''nuwa,Atala''nuwa'',CHA,Catanuga,Chatanuga,Chattanooga,Chattanuga,Lookout City,Old French Store,Ross Landing,Ross''s Landing,Ross''s Store,Ross''s Warehouse,Ross''s Wharf,Tsattanounka,cetanuga,cha ta nu jia,chaeteonuga,chatanuga,chatanwga  tnsy,tshatanwgha,ztnwgh,Čatanuga,Τσαττανούγκα,Чатануга,Чаттануга,Чаттануґа,צטנוגה,تشاتانوغا,چاتانوگا، تنسی,چٹانوگا، ٹینیسی,चॅटानूगा,チャタヌーガ,查塔努加,채터누가', 35.0456300, -85.3096800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135942, 'Christiana', 'Christiana', '', 35.7100700, -86.3994400, 'US', '2017-03-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135943, 'Church Hill', 'Church Hill', 'Church Hill,Patterson Mill', 36.5223200, -82.7134900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135944, 'Clarksville', 'Clarksville', 'CKV,Clarksville,Klarksvil,Klarksvilis,Klarksvill,ke la ke si wei er,klarks vyl  tynysy,klarksavhila,klarksfyl,kurakusubiru,Кларксвил,Кларксвилл,Кларксвілл,קלארקסוויל,كلاركسفيل,کلارکس ڤیل، تئنئسی,کلارکسویل، ٹینیسی,کلارک‌اسویل، تنسی,क्लार्क्सव्हिल,クラークスビル,克拉克斯维尔', 36.5297700, -87.3594500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135945, 'Cleveland', 'Cleveland', 'Klivland,Klivlend,klyfland,klywlnd  tnsy,Кливланд,Кливленд,كليفلاند,کلیولند، تنسی,کلیولینڈ، ٹینیسی', 35.1595200, -84.8766100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135946, 'Clifton', 'Clifton', 'Clifton,Clifton City,Klifton,Клифтон', 35.3870200, -87.9953100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135947, 'Clinton', 'Clinton', 'Burrville,Clinton,Klinton,ke lin dun,klyntwn,klyntwn  tnsy,Клинтон,كلينتون,کلنٹن، ٹینیسی,کلینتون، تنسی,克林顿', 36.1034100, -84.1318600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135948, 'Coalfield', 'Coalfield', 'Coalfield,Rio,Ruffners Station', 36.0289700, -84.4207600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135949, 'Collegedale', 'Collegedale', '', 35.0531300, -85.0502300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135950, 'Collierville', 'Collierville', 'Kolervil,klyrfyl,kwlyrwyl  tnsy,Колервил,كليرفيل,کولیرویل، تنسی', 35.0420400, -89.6645300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135951, 'Colonial Heights', 'Colonial Heights', '', 36.4851000, -82.5032000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135952, 'Columbia', 'Columbia', 'Columbia,Kolambija,Kolumbija,MRC,klmbya  tnsy,kwlwmbya,Коламбија,Колумбия,كولومبيا,کلمبیا، تنسی,کولمبیا، ٹینیسی', 35.6150700, -87.0352800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135953, 'Condon', 'Condon', 'Condon,Meltabarger,Plainview', 36.1811900, -83.7938000, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135954, 'Cookeville', 'Cookeville', 'Cookeville,Cooksville,Cookville,Kukvil,ku ke wei er,kwkfl,kwkwyl  tnsy,Куквил,كوكفل,کوکویل، تنسی,庫克維爾', 36.1628400, -85.5016400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135955, 'Coopertown', 'Coopertown', 'Cooperstown,Coopertown', 36.4375500, -86.9672200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135956, 'Cornersville', 'Cornersville', 'Cornersville,Marathon', 35.3614600, -86.8397200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135957, 'Covington', 'Covington', '', 35.5642500, -89.6464700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135958, 'Cowan', 'Cowan', 'Cowan,Hawkins', 35.1645300, -86.0105400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135959, 'Cross Plains', 'Cross Plains', 'Cross Plains,Crossplains', 36.5486600, -86.6961100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135960, 'Crossville', 'Crossville', 'CSV,Crossville,Krosvil,Lambeth Crossroads,Lambeths Crossroads,Rail Road Plains,Railroad Plain,krwsfyl,krwswyl  tnsy,Кросвил,كروسفيل,کراسویل، ٹینیسی,کروسویل، تنسی', 35.9489600, -85.0269000, 'US', '2017-06-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135961, 'Crump', 'Crump', '', 35.2217500, -88.3180900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135962, 'Dandridge', 'Dandridge', 'Danbridz,Dehndridzh,Dendridzh,dandrydg  tnsy,dandrydj,Данбриџ,Дендрідж,Дэндридж,داندريدج,داندریدگ، تنسی', 36.0153700, -83.4148900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135963, 'Dayton', 'Dayton', 'Dayton,Dejton,Sequatchie,Sequatchie Station,Smiths Cross Roads,daytwn,detana,dytn  tnsy,Дейтон,Дејтон,دايتون,دیتن، تنسی,ڈیٹن، ٹینیسی,डेटन', 35.4939600, -85.0124500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135964, 'Decatur', 'Decatur', 'Decatur,Dekejter,Dekejtur,Reagan,di kai te,dykatwr,dykytr  tnsy,Декейтер,Декејтур,ديكاتور,دیکیتر، تنسی,迪凯特', 35.5147900, -84.7902200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135965, 'Decaturville', 'Decaturville', '', 35.5842400, -88.1194800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135966, 'Decherd', 'Decherd', 'Dechard,Decherd', 35.2098000, -86.0794300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135967, 'Dickson', 'Dickson', 'Dickson,Dickson Station,Forty-Two,Smeedville,Sneedsville,Sneedville,Sneedville Station', 36.0770000, -87.3877900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135968, 'Dodson Branch', 'Dodson Branch', 'Dodson Branch,Dotson Branch', 36.3125600, -85.5322000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135969, 'Dover', 'Dover', 'Dover,Monroe,dwfr,dwwr  tnsy,Довер,دوفر,دوور، تنسی,ڈوور، ٹینیسی', 36.4878300, -87.8383600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135970, 'Dresden', 'Dresden', '', 36.2914500, -88.7081100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135971, 'Dunlap', 'Dunlap', 'Coops Creek,Dunlap', 35.3714600, -85.3905200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135972, 'Dyer', 'Dyer', 'Dyer,Dyer Station', 36.0667300, -88.9939500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135973, 'Dyersburg', 'Dyersburg', 'Dajersberg,Dyersburg,Dyersburgh,Dyersville,McIvers Bluff,dayrzbwrg  tnsy,dyyrsbwrgh,Дајерсберг,دایرزبورگ، تنسی,دييرسبورغ', 36.0345200, -89.3856300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135974, 'Eagleton Village', 'Eagleton Village', '', 35.7950800, -83.9318500, 'US', '2016-08-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135975, 'East Brainerd', 'East Brainerd', '', 34.9959100, -85.1502300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135976, 'East Chattanooga', 'East Chattanooga', '', 35.0653500, -85.2491200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135977, 'East Cleveland', 'East Cleveland', 'Vostochnyj Klivlend,Восточный Кливленд', 35.1609100, -84.8577200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135978, 'East Ridge', 'East Ridge', 'East Ridge,East Side,Nickel Row,Penny Row,Smokey Row', 35.0142400, -85.2519000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135979, 'Elizabethton', 'Elizabethton', 'Elizabeth,Elizabethton,Elizabeton,Sycamore Shoals,alyzabythwn,erizabesuton,Елизабетон,إليزابيثون,الزبتھٹن، ٹینیسی,ایلیزابت‌تون، تنسی,エリザベストン', 36.3487200, -82.2106900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135980, 'Englewood', 'Englewood', 'Englewood,Tellico Junction', 35.4245200, -84.4874300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135981, 'Englewood', 'Englewood', '', 36.3667300, -89.1547900, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135982, 'Erin', 'Erin', '', 36.3183900, -87.6947400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135983, 'Erwin', 'Erwin', 'Ervin,Erwin,Longmire,Unika,Vanderbilt', 36.1451100, -82.4168100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135984, 'Estill Springs', 'Estill Springs', 'Ansonia,Estill Springs', 35.2706400, -86.1280400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135985, 'Etowah', 'Etowah', '', 35.3234100, -84.5249300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135986, 'Fairfield Glade', 'Fairfield Glade', '', 36.0003500, -84.8863400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135987, 'Fairmount', 'Fairmount', 'Fair Mount,Fairmount', 35.1814600, -85.3235700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135988, 'Fairmount', 'Fairmount', 'Fairmont,Fairmount', 36.5851100, -82.1709700, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135989, 'Fairview', 'Fairview', 'Barren,Barrens,Fairview,Jinge,Jingo', 35.9820100, -87.1214000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135990, 'Fall Branch', 'Fall Branch', 'Fall Branch,Fallbranch,Falls Branch', 36.4181600, -82.6237600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135991, 'Falling Water', 'Falling Water', '', 35.2031200, -85.2535700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135992, 'Farragut', 'Farragut', 'Faragut,faraghwt,frgt  tnsy,Фарагут,فاراغوت,فرگت، تنسی', 35.8845200, -84.1535300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135993, 'Fayetteville', 'Fayetteville', 'FYM,Fayetteville,Fejetvil,faytyfyl,fyytwyl  tnsy,Фејетвил,فايتيفيل,فییتویل، تنسی', 35.1520300, -86.5705500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135994, 'Fincastle', 'Fincastle', '', 36.4098000, -84.0477000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135995, 'Forest Hills', 'Forest Hills', '', 36.0683900, -86.8441700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135996, 'Franklin', 'Franklin', 'Franklin,franklyn,franklyn  tnsy,furankurin,peulaengkeullin,Франклин,فرانكلين,فرانکلین، تنسی,فرینکلن، ٹینیسی,フランクリン,프랭클린', 35.9250600, -86.8688900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135997, 'Gainesboro', 'Gainesboro', 'Gainesboro,Gainesborough,Gainsboro', 36.3556100, -85.6588700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135998, 'Gallatin', 'Gallatin', 'Galatin,galtyn  tnsy,ghalatyn,Галатин,غالاتين,گالتین، تنسی', 36.3883800, -86.4466600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(135999, 'Gatlinburg', 'Gatlinburg', 'GKT,Gatlinberg,Gatlinburg,Gatlinburgh,White Oak Flats,ghatlynbwrgh,gtlnbrg  tnsy,Гатлинберг,غاتلينبورغ,گتلنبرگ، تنسی', 35.7145300, -83.5118900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136000, 'Germantown', 'Germantown', 'Dzermantaun,jrmntawn  tnsy,jyrmantawn,Џермантаун,جرمنتاون، تنسی,جيرمانتاون', 35.0867600, -89.8100900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136001, 'Gleason', 'Gleason', 'Gleason,Gleeson Station,Oakwood', 36.2136700, -88.6125500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136002, 'Goodlettsville', 'Goodlettsville', '', 36.3231100, -86.7133300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136003, 'Gordonsville', 'Gordonsville', '', 36.1725600, -85.9297100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136004, 'Gray', 'Gray', 'Gray,Grays Station', 36.4198300, -82.4765400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136005, 'Graysville', 'Graysville', 'Advent Town,Graysville', 35.4470100, -85.0844000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136006, 'Green Hill', 'Green Hill', 'Green Hill,Greenhill', 36.2228300, -86.5494400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136007, 'Greenback', 'Greenback', 'Alleghany Station,Greenback', 35.6611900, -84.1721400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136008, 'Greenbrier', 'Greenbrier', 'Cheathams Station,Green Brier,Greenbrier', 36.4275500, -86.8047200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136009, 'Greeneville', 'Greeneville', 'GCY,Greeneville,Greenville,Grinvil,ge lin wei er,grynwyl  tnsy,Гринвил,گرینویل، تنسی,格林维尔', 36.1631600, -82.8309900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136010, 'Greenfield', 'Greenfield', 'Grinfild,Гринфилд', 36.1534000, -88.8006200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136011, 'Grimsley', 'Grimsley', '', 36.2670100, -84.9844000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136012, 'Gruetli-Laager', 'Gruetli-Laager', '', 35.3723000, -85.6180300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136013, 'Halls', 'Halls', 'Halls,Halls Station', 35.8756300, -89.3961800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136014, 'Harriman', 'Harriman', '', 35.9339600, -84.5524400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136015, 'Harrison', 'Harrison', 'Kharrison,Харрисон', 35.1136800, -85.1380100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136016, 'Harrogate', 'Harrogate', 'Harrogate-Shawanee,Kharogejt,harwgat,harwghyt,Харогејт,هاروغيت,هاروگات', 36.5823000, -83.6568600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136017, 'Hartsville', 'Hartsville', 'Damascus,Donoho''s Mill,Hartsville,Hartsville-Trousdale County', 36.3908800, -86.1672100, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136018, 'Henderson', 'Henderson', 'Dayton,Henderson,Henderson City,Henderson Station,Hendersons Station,Khenderson,hndrswn,hndrswn  tnsy,Хендерсон,هندرسون,هندرسون، تنسی', 35.4392400, -88.6414400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136019, 'Hendersonville', 'Hendersonville', 'Khendersonvil,hendason''vu~iru,hendeoseunbil,hndrsnwyl  tnsy,hyndrswnfyl,Хендерсонвил,هندرسنویل، تنسی,هيندرسونفيل,ہینڈرسنویل، ٹینیسی,ヘンダーソンヴィル,헨더슨빌', 36.3047700, -86.6200000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136020, 'Hickory Withe', 'Hickory Withe', 'Hickory Withe,Hickory Withe Springs', 35.2439800, -89.5886900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136021, 'Hohenwald', 'Hohenwald', 'City of High Forest,Hohenwald,Khoenvold,New Switzerland,hwhnwald  tnsy,hwhynwald,Хоенволд,هوهنوالد، تنسی,هوهينوالد', 35.5478500, -87.5519600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136022, 'Hopewell', 'Hopewell', 'Khopuehlla,Хопуэлла', 35.2347900, -84.8880000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136023, 'Humboldt', 'Humboldt', 'Humboldt,Humbolt', 35.8197900, -88.9159000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136024, 'Hunter', 'Hunter', '', 36.3623000, -84.1404800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136025, 'Hunter', 'Hunter', 'Hunter,Hunter Station', 36.3717800, -82.1587400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136026, 'Huntingdon', 'Huntingdon', 'Huntingdon,Huntsville,Khantingdon,hantynghdwn,hantyngtwn,Хантингдон,هانتينغدون,هانتینگتون,ہنٹنگڈن، ٹینیسی', 36.0006200, -88.4281100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136027, 'Huntsville', 'Huntsville', 'Hunters Spring,Huntsville,Khantsvill,Хантсвилл', 36.4098000, -84.4904900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136028, 'Jacksboro', 'Jacksboro', 'Jacksboro,Jacksborough', 36.3300800, -84.1838200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136029, 'Jackson', 'Jackson', 'Dzekson,Dzhaksun,Dzhekson,Jackson,MKL,jaegseun,jakswn,jakuson,jie ke xun,jksn  tnsy,Џексон,Джаксън,Джексон,جاكسون,جکسن، تنسی,جیکسن، ٹینیسی,ジャクソン,傑克遜,잭슨', 35.6145200, -88.8139500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136030, 'Jamestown', 'Jamestown', 'Dzejmstaun,Jamestown,Jimtown,Obedstown,Sand Springs,jymstawn,jymztawn  tnsy,Џејмстаун,جيمستاون,جیمز ٹاون، ٹینیسی,جیمزتاون، تنسی', 36.4275700, -84.9318900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136031, 'Jasper', 'Jasper', 'Dzasper,jasbr,jspr  tnsy,Џаспер,جاسبر,جسپر، تنسی,جسپر، ٹینیسی', 35.0742400, -85.6260800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136032, 'Jefferson City', 'Jefferson City', 'Dzhefferson-Siti,Jefferson City,Mossy Creek,Джефферсон-Сити', 36.1223100, -83.4924000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136033, 'Jellico', 'Jellico', 'Jellico,Smithburg,jlykw  tnsy,jylykw,جلیکو، تنسی,جيليكو', 36.5878600, -84.1268700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136034, 'Johnson City', 'Johnson City', 'Blue Plum Station,Dzonson Siti,Haynesville,Johnson City,Johnsons Depot,Johnsons Tank,gwnswn syty,janswn syty  tnsy,jonseunsiti,jonsonshiti,jwnswn syty,yue han xun cheng,Џонсон Сити,גונסון סיטי,جانسن سٹی، ٹینیسی,جانسون سیتی، تنسی,جونسون سيتي,ジョンソンシティ,約翰遜城,존슨시티', 36.3134400, -82.3534700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136035, 'Johnsonville', 'Johnsonville', '', 36.0600600, -87.9528100, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136036, 'Jonesborough', 'Jonesborough', 'Dzonsboro,Jonesboro,Jonesborough,jwnzbwrw,zhwhansbwrg  tnsy,Џонсборо,جونزبورو,ژوهانسبورگ، تنسی', 36.2942700, -82.4734800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136037, 'Kenton', 'Kenton', '', 36.2022900, -89.0122900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136038, 'Kimball', 'Kimball', 'Kimball,Wallsville', 35.0478600, -85.6719100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136039, 'Kingsport', 'Kingsport', 'Boat Yard,Boatyard,Christiansville,Island Flats,Kings Port,Kingsport,Peace Island,jin si bo te,kynghsbwrt,kyngzprt  tnsy,Кингспорт,Кінгспорт,كينغسبورت,کنگزپورٹ، ٹینیسی,کینگزپرت، تنسی,金斯波特', 36.5484300, -82.5618200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136040, 'Kingston', 'Kingston', 'Kingston,jin si dun,kingseuteon,kingusuton,kynghstwn,kyngztwn  tnsy,Кингстон,كينغستون,کنگسٹن، ٹینیسی,کینگزتون، تنسی,キングストン,金斯顿,킹스턴', 35.8809100, -84.5085400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136041, 'Kingston Springs', 'Kingston Springs', '', 36.1020000, -87.1150100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136042, 'Knoxville', 'Knoxville', 'Knoxville,Noksvil,Noksvill,Noxvil,TYS,Whites Fort,Whites Mill,nakswyl  tnsy,nogseubil,nokkusubiru,noksavhila,nuo ke si wei er,nwksfyl,nwqswwyl,Νόξβιλ,Ноксвил,Ноксвилл,Ноксвілл,נוקסוויל,ناکسویل، تنسی,نوكسفيل,नॉक्सव्हिल,ノックスビル,諾克斯維爾,녹스빌', 35.9606400, -83.9207400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136043, 'La Vergne', 'La Vergne', 'La Vergne,LaVergne,Laveren,Lavergne', 36.0156200, -86.5819400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136044, 'LaFollette', 'LaFollette', 'Big Creek Gap,LaFollette,Lafollette', 36.3828600, -84.1199300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136045, 'Lafayette', 'Lafayette', 'La Fayette,Lafajet,Lafayette,Lafejet,lafayyt,lfyt  tnsy,Лафайет,Лафејет,لافاييت,لافیت، ٹینیسی,لفیت، تنسی', 36.5211600, -86.0263700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136046, 'Lafayette', 'Lafayette', '', 36.1858900, -85.7160900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136047, 'Rocky Top', 'Rocky Top', 'Adkins,Coal Creek,Coalcreek,Cole Creek,Lake City,Rocky Top', 36.2178600, -84.1546500, 'US', '2014-08-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136048, 'Lake Tansi', 'Lake Tansi', '', 35.8728500, -85.0544000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136049, 'Lakeland', 'Lakeland', '', 35.2306400, -89.7403600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136050, 'Lakesite', 'Lakesite', '', 35.2086800, -85.1269000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136051, 'Lakewood', 'Lakewood', 'DuPontonia,Dupontonia,Duptonia,Lakewood,Lejkvud,Old Hickory,Лейквуд', 36.2431100, -86.6355500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136052, 'Lawrenceburg', 'Lawrenceburg', 'Lawrenceburg,Lawrenceburgh,Lorensburg,lwrnsbrg  tnsy,lwrnsbwrgh,Лоренсбург,لورنسبرگ، تنسی,لورنسبورغ', 35.2423000, -87.3347400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136053, 'Lebanon', 'Lebanon', 'Lebanon,lbnan,lebeoneon,Лебанон,لبنان,레버넌', 36.2081100, -86.2911000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136054, 'Lenoir City', 'Lenoir City', 'Lenoir,Lenoir City,Lenoirs,Lenor Siti,lnwar syty  tnsy,Ленор Сити,لنوار سیتی، تنسی', 35.7973000, -84.2560300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136055, 'Lewisburg', 'Lewisburg', 'Lewisburg,Lewisburgh,Louisburgh,Luisburg,lwysbwrg  tnsy,lwysbwrgh,ruisubagu,Луисбург,لوئیسبرگ، ٹینیسی,لويسبورغ,لویسبورگ، تنسی,ルイスバーグ', 35.4492400, -86.7888900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136056, 'Lexington', 'Lexington', 'Leksington,Лексингтон', 35.6509000, -88.3933800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136057, 'Linden', 'Linden', 'Linden,lyndn  tnsy,lyndyn,Линден,ليندين,لیندن، تنسی', 35.6172900, -87.8394700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136058, 'Livingston', 'Livingston', 'Livingston,lyfynghstwn,lywyngstwn  tnsy,Ливингстон,ليفينغستون,لیونگسٹن، ٹینیسی,لیوینگستون، تنسی', 36.3834000, -85.3230200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136059, 'Lone Oak', 'Lone Oak', 'Browns Chapel,Lone Oak,Top of the Mountain', 35.2006300, -85.3641300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136060, 'Lookout Mountain', 'Lookout Mountain', 'Lookout Mountain,Summer Town,Summertown', 34.9942400, -85.3494000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136061, 'Loretto', 'Loretto', 'Glen Rock,Loretto', 35.0778600, -87.4397400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136062, 'Loudon', 'Loudon', '', 35.7328500, -84.3338100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136063, 'Louisville', 'Louisville', 'Luisvil,Луисвил', 35.8217500, -84.0479600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136064, 'Luttrell', 'Luttrell', 'Cedar Ford,Luttrell,Luttrells', 36.1995300, -83.7418500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136065, 'Lynchburg', 'Lynchburg', 'Linchburg,Lynchburg,Lynchburgh,lynchbwrg  tnsy,lynshbwrgh,Линчбург,لينشبورغ,لینچبرگ، ٹینیسی,لینچبورگ، تنسی', 35.2831400, -86.3741600, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136066, 'Madisonville', 'Madisonville', 'Medisonvil,madyswnfyl,mdyswnwyl  tnsy,Медисонвил,ماديسونفيل,مدیسونویل، تنسی,میڈیسونویلی، ٹینیسیی', 35.5198000, -84.3635300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136067, 'Manchester', 'Manchester', 'Manchester,manshstr,mnchstr  tnsy,Манчестер,مانشستر,مانچسٹر، ٹینیسی,منچستر، تنسی', 35.4817400, -86.0886000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136068, 'Martin', 'Martin', 'Frost,Green Briar Glade,Greenbrier Glade,Martin,martn,martyn  tnsy,Мартин,مارتن,مارتین، تنسی,مارٹن، ٹینیسی', 36.3434000, -88.8503400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136069, 'Maryville', 'Maryville', 'Marysville,Maryville,Merivil,melibil,mrfyl,mrywyl  tnsy,Меривил,مرفيل,مریویل، تنسی,메리빌', 35.7564700, -83.9704600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136070, 'Mascot', 'Mascot', 'Mascot,Meek', 36.0612000, -83.7457300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136071, 'Mason', 'Mason', 'Mason,Masons Station,Mejson,Мейсон', 35.4117500, -89.5328500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136072, 'Maynardville', 'Maynardville', 'Maynardsville,Maynardville,Mejnardvil,maynardfyl,maynardwyl  tnsy,Мејнардвил,مايناردفيل,مایناردویل، تنسی', 36.2506400, -83.7974100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136073, 'McEwen', 'McEwen', 'Buttermilk,Little Ireland,McEwen,McEwens', 36.1078400, -87.6330700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136074, 'McKenzie', 'McKenzie', 'Dundas,McKenzie,McKenzie Station', 36.1325600, -88.5186600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136075, 'McMinnville', 'McMinnville', 'Maminvil,McMinnville,RNC,maegminbil,mai ke ming wei er,mykmynfyl,Маминвил,ميكمينفيل,مک‌مینویل، تنسی,麦克明维尔,맥민빌', 35.6834000, -85.7699800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136076, 'Medina', 'Medina', 'Medina,Медина', 35.8028500, -88.7747800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136077, 'Memphis', 'Memphis', 'Gorad Memfis,MEM,Memfis,Memfisa,Memphis,Memphis Tennesiae,Menfis,Mémfis,Mênfis,memfis,memhpis,memphisa,mempiseu,mempisi,menfisu,meng fei si,mmfys,mmfys  tnsy,mmpys,Μέμφις,Горад Мемфіс,Мемфис,Мемфіс,Մեմֆիս,ממפיס,מעמפיס,ممفيس,ممفیس,ممفیس، تنسی,میمفس، ٹینیسی,मेम्फिस,মেম্ফিস,மெம்ஃபிஸ்,เมมฟิส,მემფისი,メンフィス,孟菲斯,孟非斯,멤피스', 35.1495300, -90.0489800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136078, 'Middle Valley', 'Middle Valley', '', 35.1959000, -85.1846800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136079, 'Midway', 'Midway', '', 36.3001100, -82.4237500, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136080, 'Midtown', 'Midtown', 'Midtown,Pine Grove', 35.8795200, -84.5641000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136081, 'Milan', 'Milan', 'Milan,Milan Depot,My Land,Shady Grove', 35.9197900, -88.7589500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136082, 'Millersville', 'Millersville', '', 36.3711600, -86.7100000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136083, 'Millington', 'Millington', 'Millington,Millwood', 35.3414700, -89.8973100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136084, 'Monteagle', 'Monteagle', 'Moffat,Moffat Station,Moffatts Station,Mont Eagle,Monteagle,Mount Eagle', 35.2400800, -85.8397000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136085, 'Monterey', 'Monterey', 'Monterej,Монтерей', 36.1475600, -85.2683000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136086, 'Morristown', 'Morristown', 'MOR,Morstaun,mwrystawn,mwrystawn  tnsy,Морстаун,مورس ٹاؤن، ٹینیسی,موريستاون,موریستاون، تنسی', 36.2139800, -83.2948900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136087, 'Mosheim', 'Mosheim', 'Blue Springs,Mosheim', 36.1895400, -82.9584900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136088, 'Mount Carmel', 'Mount Carmel', '', 35.4978500, -88.0078100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136089, 'Mount Carmel', 'Mount Carmel', 'Karmel'',Mount Carmel,Solitude,Кармель', 36.5453800, -82.6609900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136090, 'Mount Juliet', 'Mount Juliet', '', 36.2000500, -86.5186100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136091, 'Mount Pleasant', 'Mount Pleasant', 'Hurricane Store,Mount Pleasant,Mountpleasant', 35.5342400, -87.2069500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136092, 'Mountain City', 'Mountain City', 'Mountain City,Taylorsville', 36.4745600, -81.8048400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136093, 'Munford', 'Munford', 'Mount Zion,Munford', 35.4492500, -89.8150800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136094, 'Murfreesboro', 'Murfreesboro', 'Cannonsburgh,Merfrisboro,Murfreesboro,Murfreesborough,Murfreysburo,Murfrijzburou,Murfrisboro,Murfrizboro,mafurizuboro,meopeulijeubeoleo,mo fu li si bo lei,mrprysbwrw,mwrfryzbwrw  tnsy,Мерфрисборо,Мурфризборо,Мурфрисборо,Мърфрийзбъроу,מרפריסבורו,مورفریزبورو، تنسی,مورفریزبورو، ٹینیسی,マーフリーズボロ,默弗里斯伯勒,머프리즈버러', 35.8456200, -86.3902700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136095, 'Nashville', 'Nashville', 'BNA,French Lick,Gorad Nashvil,Nachville,Nasburgum,Nashboro,Nashborough,Nashfile,Nashvil,Nashvill,Nashville,Nashville-Davidson,Nashwil,Nasvelis,Nasvil,Nasvila,Nasvilo,Naŝvilo,Našvila,Našvėlis,Nehshvill,Neshvil,Nesvil,Nesvilis,Nesvill,Neşvill,Nešvilis,n''yasabhila,n''yasbhila,n''yasbhilla,na shen wei er,na shu wei er,naesyubil,nashfyl,nasshubiru,nasvil,nesavhila,neshvili,nshwyl,Νάσβιλ,Горад Нашвіл,Нашвил,Нашвилл,Нашвілл,Нешвил,Нэшвилл,Նեշվիլ,נאשוויל,ناشفيل,ناشولے,نشویل,نیشویل، ٹینیسی,नाश्विल्,नॅशव्हिल,न्याश्भिल,न्यास्भिल्ल,ন্যাশভিল,நாஷ்வில்,แนชวิลล์,ნეშვილი,ナッシュビル,納殊維爾,纳什维尔,내슈빌', 36.1658900, -86.7844400, 'US', '2014-10-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136096, 'New Hope', 'New Hope', 'Antioch,New Hope', 35.0050800, -85.6583000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136097, 'New Johnsonville', 'New Johnsonville', 'Johnsonville,Johnsville,New Johnsonville', 36.0211700, -87.9669800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136098, 'New Market', 'New Market', '', 36.1039800, -83.5526800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136099, 'New South Memphis', 'New South Memphis', '', 35.0867600, -90.0567600, 'US', '2012-07-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136100, 'New Tazewell', 'New Tazewell', 'Cowan City,New Tazewell', 36.4425800, -83.5996300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136101, 'New Union', 'New Union', '', 35.5325800, -86.0808200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136102, 'Newbern', 'Newbern', '', 36.1128500, -89.2617400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136103, 'Newport', 'Newport', 'Clifton,Gorman,Gormans Depot,Gormans Eddy,N''juport,Newport,Njuport,nywbwrt,nywpwrt  tnsy,Њупорт,Ньюпорт,نيوبورت,نیوپورت، تنسی,نیوپورٹ، ٹینیسی', 35.9670400, -83.1876600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136104, 'Nolensville', 'Nolensville', '', 35.9522900, -86.6694400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136105, 'Norris', 'Norris', '', 36.1956300, -84.0679700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136106, 'Oak Grove', 'Oak Grove', '', 36.4117700, -82.4245900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136107, 'Oak Hill', 'Oak Hill', 'Oak Hill,Oak Hills', 36.0878400, -86.7830500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136108, 'Oak Ridge', 'Oak Ridge', 'Elza,Oak Ridge,Ok-Ridzh,Ouk Ridz,awk rydj,awk ryj  tnsy,okeuliji,xiang shu ling,ʼwq rydg,Ок-Ридж,Ок-Рідж,Оук Риџ,אוק רידג,أوك ريدج,اوک ریج، تنسی,オーク・リッジ,橡树岭,오크리지', 36.0103600, -84.2696400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136109, 'Oakland', 'Oakland', 'Oklend,Окленд', 35.2289800, -89.5150800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136110, 'Obion', 'Obion', '', 36.2589600, -89.1917400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136111, 'Olivet', 'Olivet', '', 35.2142500, -88.2003100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136112, 'Oliver Springs', 'Oliver Springs', 'Oliver Springs,Olivers,Winters,Winters Gap,awlyfr sbrynghz,awlywr aspryngz  tnsy,Оливер Спрингс,أوليفر سبرينغز,اولیور اسپرینگز، تنسی', 36.0445200, -84.3443700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136113, 'Oneida', 'Oneida', '', 36.4981300, -84.5127200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136114, 'Paris', 'Paris', 'PHT,Paris,Parizh,barys,parys  tnsy,Париж,Парис,باريس,پاریس، تنسی,پیرس، ٹینیسی', 36.3020000, -88.3267100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136115, 'Park City', 'Park City', 'Park City,Parks City', 35.0820300, -86.5711100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136116, 'Parsons', 'Parsons', 'Parsons,Parsons Flats', 35.6497900, -88.1267000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136117, 'Pegram', 'Pegram', 'Pegram,Pegrams,Pegrams Station', 36.1006100, -87.0511200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136118, 'Pigeon Forge', 'Pigeon Forge', 'Pidzin Fordz,pyjn frj  tnsy,Пиџин Форџ,پیجن فرج، تنسی', 35.7884200, -83.5543300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136119, 'Pikeville', 'Pikeville', 'Pakjvil,baykfyl,pykwyl  tnsy,Пакјвил,بايكفيل,پیکویل، تنسی', 35.6056200, -85.1888500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136120, 'Pine Crest', 'Pine Crest', '', 36.2761900, -84.1288100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136121, 'Pine Crest', 'Pine Crest', '', 36.2992700, -82.3179200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136122, 'Piperton', 'Piperton', '', 35.0450900, -89.6217500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136123, 'Pleasant View', 'Pleasant View', 'Pleasant View,Pleasantview', 36.3942200, -87.0366700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136124, 'Portland', 'Portland', 'Portland,Portlend,Richland,Richland Station,Портленд', 36.5817100, -86.5163800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136125, 'Powells Crossroads', 'Powells Crossroads', 'Crossroads,Powells Crossroads', 35.1895200, -85.4858000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136126, 'Pulaski', 'Pulaski', 'Pulaski,Tuluski,bwlasky,pu wa si ji,pwlsky  tnsy,Пуласки,بولاسكي,پولسکی، تنسی,普瓦斯基', 35.1998000, -87.0308400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136127, 'Red Bank', 'Red Bank', 'Dry Valley,Hamilton,Pleasant Hill,Red Bank', 35.1122900, -85.2941300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136128, 'Red Boiling Springs', 'Red Boiling Springs', 'Red Boiling Springs,Redboiling Springs', 36.5333900, -85.8499800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136129, 'Ridgely', 'Ridgely', '', 36.2634000, -89.4878500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136130, 'Ridgetop', 'Ridgetop', 'Nancy,Ridge Top Station,Ridgetop,Ridgetop Station', 36.3950500, -86.7794400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136131, 'Ripley', 'Ripley', '', 35.7453600, -89.5298000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136132, 'Roan Mountain', 'Roan Mountain', '', 36.1962300, -82.0704000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136133, 'Rockwood', 'Rockwood', 'RKW,Rokvud,rwkwwd,rwkwwd  tnsy,Роквуд,روكوود,روکوود، تنسی', 35.8656300, -84.6849400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136134, 'Rogersville', 'Rogersville', 'Hawkins Courthouse,Rodgersville,Rodzersvil,Rogersville,rwgrswyl  tnsy,rwjrzfyl,Роџерсвил,روجرزفيل,روجرزویل، ٹینیسی,روگرسویل، تنسی', 36.4073200, -83.0054400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136135, 'Rural Hill', 'Rural Hill', 'Rural Hill,Ruralhill', 36.1167300, -86.4791600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136136, 'Rutherford', 'Rutherford', 'Rutherford,Rutherford Depot', 36.1275700, -88.9859000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136137, 'Rutledge', 'Rutledge', 'Ratledz,ratlyj  tnsy,rwtlydj,Ратлеџ,راتلیج، تنسی,روتليدج', 36.2809200, -83.5149000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136138, 'Sale Creek', 'Sale Creek', 'Rock Creek,Sale Creek,Salecreek', 35.3822900, -85.1088400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136139, 'Savannah', 'Savannah', 'Savana,Savanna,safana,sawana  tnsy,Савана,Саванна,سافانا,ساوانا، تنسی', 35.2248000, -88.2492000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136140, 'Selmer', 'Selmer', '', 35.1700800, -88.5922700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136141, 'Sevierville', 'Sevierville', 'Forks of Little Pigeon,Severeville,Sevierville,Suviurvil,swyrwyl  tnsy,syfyrfyl,Съвиървил,سویرویل، تنسی,سيفيرفيل', 35.8681500, -83.5618400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136142, 'Sewanee', 'Sewanee', 'Sewanee,UOS,University,University Place,swan  tnsy,سوان، تنسی', 35.2031400, -85.9210900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136143, 'Seymour', 'Seymour', '', 35.8906400, -83.7246200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136144, 'Shackle Island', 'Shackle Island', 'Montgomery,Shackle Island,Worsham', 36.3706000, -86.6166600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136145, 'Shelbyville', 'Shelbyville', 'SYI,Shelbivil,Shelbyville,shlbywyl  tnsy,shylbyfyl,Шелбивил,شلبیویل، تنسی,شيلبيفيل', 35.4834100, -86.4602700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136146, 'Signal Mountain', 'Signal Mountain', '', 35.1225700, -85.3438500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136147, 'Smithville', 'Smithville', '', 35.9606200, -85.8141500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136148, 'Smyrna', 'Smyrna', 'MQY,Smirna,asmrna  tnsy,smyrna,sumana,Смирна,اسمرنا، تنسی,سميرنا,スマーナ', 35.9828400, -86.5186000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136149, 'Sneedville', 'Sneedville', 'Greasy Rock,Sneedsville,Sneedville', 36.5298100, -83.2174000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136150, 'Soddy-Daisy', 'Soddy-Daisy', 'Daisy,Soddy,Soddy-Daisy', 35.2359000, -85.1907900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136151, 'Somerville', 'Somerville', 'Bowersville,Samervil,Somerville,samrwyl  tnsy,swmrfyl,Самервил,سامرویل، تنسی,سومرفيل', 35.2437000, -89.3500700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136152, 'South Carthage', 'South Carthage', '', 36.2420000, -85.9519300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136153, 'South Cleveland', 'South Cleveland', 'Cleveland South,South Cleveland', 35.1411900, -84.8721700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136154, 'South Fulton', 'South Fulton', 'Jacksonville,South Fulton', 36.5008900, -88.8753400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136155, 'South Pittsburg', 'South Pittsburg', 'Battle Creek,South Pittsburg,South Pittsburgh', 35.0123000, -85.7044100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136156, 'Sparta', 'Sparta', '', 35.9259000, -85.4641400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136157, 'Spencer', 'Spencer', '', 35.7472900, -85.4666400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136158, 'Spring City', 'Spring City', 'Rheaville,Rheaville Station,Spring,Spring City,Walnut Grove', 35.6920100, -84.8607800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136159, 'Spring Hill', 'Spring Hill', 'Spring Hill,Spring-Khill,Springhill,Спринг-Хилл', 35.7511800, -86.9300000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136160, 'Springfield', 'Springfield', 'Springfild,aspryngfyld  tnsy,sbrynghfyld,Спрингфилд,Спрінгфілд,اسپرینگفیلد، تنسی,سبرينغفيلد,سپرنگفیلڈ، ٹینیسی', 36.5092100, -86.8850000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136161, 'Spurgeon', 'Spurgeon', '', 36.4395500, -82.4557000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136162, 'Surgoinsville', 'Surgoinsville', 'Surgainesville,Surgoinsville', 36.4709300, -82.8518300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136163, 'Sweetwater', 'Sweetwater', 'Sweet Water,Sweetwater', 35.6014600, -84.4610400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136164, 'Tazewell', 'Tazewell', 'Tazvel,ta ci wei er,tazwl  tnsy,tazwyl,Тазвел,تازول، تنسی,تازويل,塔兹韦尔', 36.4542500, -83.5693500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136165, 'Tennessee Ridge', 'Tennessee Ridge', 'Tennessee Ridge,Tennessee Ridge Station,The Ridge', 36.3120000, -87.7733600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136166, 'Thompson''s Station', 'Thompson''s Station', 'Thompson Station,Thompson''s Station,Thompsons,Thompsons Station', 35.8020100, -86.9113900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136167, 'Three Way', 'Three Way', '', 35.7759000, -88.8595000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136168, 'Tiptonville', 'Tiptonville', '', 36.3784000, -89.4720200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136169, 'Tracy City', 'Tracy City', 'Tracy,Tracy City,Trejsi Siti,trysy syty,trysy syty  tnsy,Трејси Сити,تريسي سيتي,تریسی سیتی، تنسی', 35.2603600, -85.7360800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136170, 'Trenton', 'Trenton', 'Gibsonport,Trenton,Трентон', 35.9806200, -88.9414500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136171, 'Troy', 'Troy', 'Troja,Троя', 36.3386800, -89.1639600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136172, 'Tullahoma', 'Tullahoma', 'THA,Talakhoma,talahwma  tnsy,twlahwma,Талахома,تالاهوما، تنسی,تولاهوما', 35.3620200, -86.2094300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136173, 'Tusculum', 'Tusculum', '', 36.1751000, -82.7587600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136174, 'Unicoi', 'Unicoi', 'Greasy Cove,Head of the Big Lane,Limonite,North Erwin,Swingleville,Unicoi,Unicoi City', 36.1953900, -82.3495800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136175, 'Union City', 'Union City', 'Junion Siti,Junion-Siti,UCY,Union City,ywnywn syty,ywnywn syty  tnsy,Јунион Сити,Юнион-Сити,يونيون سيتي,یونین سٹی، ٹینیسی,یونیون سیتی، تنسی', 36.4242300, -89.0570100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136176, 'Unionville', 'Unionville', '', 35.6217400, -86.5925000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136177, 'Vonore', 'Vonore', 'fwnwr,wwnwr  tnsy,فونور,وونور، تنسی', 35.5900800, -84.2418600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136178, 'Walden', 'Walden', 'Walden,Walton Branch', 35.1647900, -85.3013500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136179, 'Walnut Hill', 'Walnut Hill', '', 36.5698300, -82.2568000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136180, 'Wartburg', 'Wartburg', 'Vortberg,Wartburg,Wartburgh,wartbwrgh,wartbwrk  tnsy,Вортберг,وارتبورغ,وارتبورک، تنسی', 36.1048000, -84.5971600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136181, 'Watertown', 'Watertown', 'Three Forks,Waters Mill,Watertown', 36.1003400, -86.1319300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136182, 'Waverly', 'Waverly', '', 36.0839500, -87.7947500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136183, 'Waynesboro', 'Waynesboro', 'Waynesboro,Waynesborough', 35.3195200, -87.7622500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136184, 'Westmoreland', 'Westmoreland', 'Coatestown,Coatstown,Staleyville,Westmoreland', 36.5619900, -86.2480400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136185, 'White Bluff', 'White Bluff', 'White Bluff,White Bluff Station,White Bluffs', 36.1075600, -87.2208400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136186, 'White House', 'White House', 'White House,Whitehouse', 36.4703200, -86.6513800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136187, 'White Pine', 'White Pine', 'White Pine,White Pines,Whitepine', 36.1075900, -83.2868300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136188, 'Whiteville', 'Whiteville', '', 35.3264700, -89.1495100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136189, 'Whitwell', 'Whitwell', 'Checkville,Cheeksville,Cheekville,Liberty,Whitwell', 35.2014600, -85.5191300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136190, 'Wildwood Lake', 'Wildwood Lake', '', 35.0920200, -84.8543900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136191, 'Wildwood', 'Wildwood', '', 35.8037000, -83.8712900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136192, 'Winchester', 'Winchester', '', 35.1859200, -86.1122100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136193, 'Woodbury', 'Woodbury', 'Danville,Vudbari,Woodbury,Woodville,Вудбари', 35.8275700, -86.0716600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136194, 'Asherton', 'Asherton', '', 28.4419300, -99.7603300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136195, 'Abilene', 'Abilene', 'ABI,Abilenas,Abilene,Abilin,Abilina,Abilīna,Abulijn,Gorad Abilin,a bi lin,abirin,abylyn,abylyn  tgzas,aebillin,Абилин,Абълийн,Абілін,Горад Абілін,אבילין,أبيلين,ابیلین,ابیلین، تگزاس,ابیلین، ٹیکساس,アビリーン,阿比林,애빌린', 32.4487400, -99.7331400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136196, 'Abram', 'Abram', '', 26.1998000, -98.4111300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136197, 'Addison', 'Addison', 'Adison,adyswn,adyswn  tgzas,Адисон,آدیسون، تگزاس,أديسون,ایڈسن، ٹیکساس,ആഡിസൺ', 32.9617900, -96.8291700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136198, 'Alamo Heights', 'Alamo Heights', 'Alamo Khajts,alamw hayts,alamw hayts  tgzas,Аламо Хајтс,آلامو هایتس، تگزاس,ألامو هايتس', 29.4849500, -98.4658500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136199, 'Alamo', 'Alamo', 'Alamo,Ebenezer,Swallow', 26.1836900, -98.1230600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136200, 'Albany', 'Albany', 'Olbani,albany,albany  tgzas,Олбани,آلبانی، تگزاس,ألباني,البانی، ٹیکساس', 32.7234500, -99.2973000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136201, 'Aldine', 'Aldine', '', 29.9324500, -95.3802100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136202, 'Aledo', 'Aledo', 'Aleda,Aledo', 32.6959600, -97.6022500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136203, 'Alice', 'Alice', 'ALI,Alis,alys,alys  tgzas,Алис,آلیس، تگزاس,اليس', 27.7522500, -98.0697200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136204, 'Allen', 'Allen', 'Alen,Allen,aln,alyn,Ален,Аллен,آلن,ألين,ایلن، ٹیکساس,അല്ലെൻ', 33.1031700, -96.6705500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136205, 'Alto', 'Alto', '', 31.6504500, -95.0727200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136206, 'Alton', 'Alton', '', 26.2872900, -98.3133500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136207, 'Alton North (historical)', 'Alton North (historical)', 'Alton North,Alton North (historical)', 26.2953500, -98.3044600, 'US', '2012-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136208, 'Alvarado', 'Alvarado', '', 32.4065300, -97.2116800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136209, 'Alvin', 'Alvin', 'Alvin,Ehlvin,alfyn,alwyn,Алвин,Элвин,آلوین,ألفين', 29.4238500, -95.2441000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136210, 'Alvord', 'Alvord', '', 33.3584500, -97.6947500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136211, 'Ames', 'Ames', '', 31.5209900, -97.7794700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136212, 'Ames', 'Ames', 'Ames,Rachal Station', 30.0538300, -94.7435300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136213, 'Anahuac', 'Anahuac', 'Anahuac,Anauak,Anavak,Anáhuac,Chambersia,Perry''s Point,a na wa ke,anahak  tgzas,anwhak,Анавак,Анауак,آناهاک، تگزاس,أنوهاك,阿納瓦克', 29.7730000, -94.6827000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136214, 'Anderson', 'Anderson', 'Anderson,andrsn  tgzas,andrswn,Андерсон,أندرسون,اندرسن، تگزاس,اینڈرسن، ٹیکساس', 30.4871500, -95.9869000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136215, 'Anderson Mill', 'Anderson Mill', '', 30.4549200, -97.8058400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136216, 'Angleton', 'Angleton', 'Anglton,LJN,anghltwn,angltwn  tgzas,Англтон,Анґлтон,انغلتون,انگلتون، تگزاس', 29.1694100, -95.4318800, 'US', '2017-07-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136217, 'Anna', 'Anna', '', 33.3490000, -96.5486000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136218, 'Annetta', 'Annetta', 'Anneta,Annetta', 32.7093000, -97.6761400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136219, 'Anson', 'Anson', '', 32.7565000, -99.8962100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136220, 'Aransas Pass', 'Aransas Pass', 'Aransas Harbor,Aransas Pass,Aranzas Pas,aranss bas,arnzas ps  tgzas,Аранзас Пас,آرنزاس پس، تگزاس,أرانسس باس', 27.9094700, -97.1499900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136221, 'Archer City', 'Archer City', 'Archer Siti,a che cheng,archr syty  tgzas,arshyr,Арчер Сити,آرچر سیتی، تگزاس,أرشير,阿彻城', 33.5956600, -98.6256100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136222, 'Arcola', 'Arcola', '', 29.4960700, -95.4657800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136223, 'Argyle', 'Argyle', '', 33.1212300, -97.1833500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136224, 'Arlington', 'Arlington', 'Arlin''nkton,Arlingt"n,Arlington,Arlingtona,Arlingtonas,Arlinqton,Gorad Arlingtan,a ling dun,allingteon,arinton,arlingtana,arlintana,arlynghtwn,arlyngtwn  tgzas,arlyngtwn  tygzas,xar ling tan,Ārlingtona,Άρλινγκτον,Арлингтон,Арлингтън,Арлінгтон,Горад Арлінгтан,Արլինգտոն,ארלינגטון,آرلنگٹن,آرلنگٹن، ٹیکساس,آرلینگتون، تئگزاس,آرلینگتون، تگزاس,أرلينغتون,आर्लिंग्टन,আর্লিংটন,ആർലിങ്ടൺ,อาร์ลิงตัน,არლინგტონი,アーリントン,阿灵顿,알링턴', 32.7356900, -97.1080700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136225, 'Asherton', 'Asherton', '', 28.4436000, -99.7589400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136226, 'Atascocita', 'Atascocita', '', 29.9988300, -95.1766000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136227, 'Athens', 'Athens', 'Alvin,Atens,Athens,athyna,atn  tgzas,Атенс,آتن، تگزاس,أثينا,ایتھنز، ٹیکساس', 32.2048700, -95.8555200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136228, 'Atlanta', 'Atlanta', 'Atlanta,atlanta,atlanta  tgzas,Атланта,آتلانتا، تگزاس,أتلانتا,اٹلانٹا، ٹیکساس', 33.1137400, -94.1643500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136229, 'Aubrey', 'Aubrey', 'Aubrey,Omego', 33.3042800, -96.9861200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136230, 'Aurora', 'Aurora', 'Avrora,Аврора', 33.0606800, -97.5033600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136231, 'Austin', 'Austin', 'AUS,Austin,Austino,Austinopolis,Aŭstino,Gorad Oscin,Montopolis,Ostin,Ostina,Ostinas,Ostins,Waterloo,ao si ting,asatina,astin,astina,astyn  tgzas,awstn,ke shi dian,oseutin,ostina,ostʼini,osutin,xxstin,Ώστιν,Горад Осцін,Остин,Остін,Օստին,אוסטין,אסטין,آستین، تگزاس,آسٹن,آسٹن، ٹیکساس,أوستن,अस्टिन,अस्तिन,आस्टिन्,ऑस्टिन,অস্টিন,ਆਸਟਿਨ,ஆஸ்டின்,ഓസ്റ്റിൻ,ออสติน,ოსტინი,ኦስቲን፣ ቴክሳስ,ᎠᏍᏘᏂ,オースティン,奧斯汀,柯士甸,오스틴', 30.2671500, -97.7430600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136232, 'Azle', 'Azle', 'Ejzl,azl,azl  tgzas,Ејзл,أزل,ازل، تگزاس', 32.8951300, -97.5458600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136233, 'Bacliff', 'Bacliff', 'Bakliv,Баклив', 29.5069000, -94.9924300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136234, 'Baird', 'Baird', 'Berd,bei er de,byrd,byrd  tgzas,Берд,بيرد,بیرد، تگزاس,貝爾德', 32.3940200, -99.3942400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136235, 'Balch Springs', 'Balch Springs', '', 32.7287400, -96.6227700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136236, 'Balcones Heights', 'Balcones Heights', '', 29.4880100, -98.5516900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136237, 'Ballinger', 'Ballinger', 'Balindzer,balynjyr,blynjr  tgzas,Балинџер,بالينجير,بلینجر، تگزاس', 31.7382100, -99.9473100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136238, 'Bandera', 'Bandera', 'Bandera,bandyra,bndra  tgzas,Бандера,بانديرا,بندرا، تگزاس', 29.7266100, -99.0736500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136239, 'Bangs', 'Bangs', '', 31.7171000, -99.1325500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136240, 'Barrett', 'Barrett', '', 29.8799500, -95.0629800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136241, 'Bartlett', 'Bartlett', 'Bartlett,Бартлетт', 30.7949100, -97.4255600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136242, 'Barton Creek', 'Barton Creek', '', 30.2852100, -97.8691700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136243, 'Bartonville', 'Bartonville', 'Bartonville,Earthenville', 33.0731800, -97.1316800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136244, 'Bastrop', 'Bastrop', 'Bastrop,bastrwb,bstrap  tgzas,Бастроп,باستروب,بستراپ، تگزاس', 30.1104900, -97.3152700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136245, 'Batesville', 'Batesville', '', 28.9510800, -99.6178300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136246, 'Baytown', 'Baytown', 'Baytown,Bejtaun,Creek,Goose Creek,HPY,bay tawn,bei dui,beitaun,by tawn  tgzas,Бејтаун,باي تاون,بی تاون، تگزاس,بےٹاؤن، ٹیکساس,ベイタウン,貝敦,베이타운', 29.7355000, -94.9774300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136247, 'Beach City', 'Beach City', 'Beach City,Sea Crest Park', 29.6621700, -94.8899200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136248, 'Bayou Vista', 'Bayou Vista', '', 29.3263500, -94.9385300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136249, 'Beaumont', 'Beaumont', 'BPT,Beaumont,Bomont,Bomontas,Cow Bayou,Jefferson City,Neches River Settlement,Tevis Bluff,bo meng te,bomamta,bomonteu,bomonto,bwmant  tgzas,bwmwnt,Бомонт,بومانت، تگزاس,بومونت,بیومونٹ,بیومونٹ، ٹیکساس,बोमाँट,ボーモント,博蒙特,보몬트', 30.0860500, -94.1018500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136250, 'Bedford', 'Bedford', 'Bedford,bdfwrd  tgzas,bydfwrd,Бедфорд,بدفورد، تگزاس,بيدفورد,بیڈفورڈ، ٹیکساس', 32.8440200, -97.1430700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136251, 'Bee Cave', 'Bee Cave', 'Bee Cave,Bee Caves,Beecaves', 30.3085400, -97.9450100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136252, 'Beeville', 'Beeville', 'Beeville,Beeville on the Poesta,Bivil,Maryville,NIR,byfyl,bywyl  tgzas,Бивил,بيفيل,بیویل، تگزاس', 28.4009500, -97.7497400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136253, 'Bellaire', 'Bellaire', 'Beler,belleeo,blyr  tgzas,bylayr,Белер,بلیر، تگزاس,بيلاير,벨레어', 29.7057900, -95.4588300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136254, 'Bellmead', 'Bellmead', '', 31.5940500, -97.1088900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136255, 'Bells', 'Bells', 'Bells,Gospel Ridge', 33.6103800, -96.4108200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136256, 'Bellville', 'Bellville', 'Belvil,bei er wei er,belbil,blwyl  tgzas,bylfyl,Белвил,بلویل، تگزاس,بيلفيل,贝尔维尔,벨빌', 29.9502300, -96.2571900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136257, 'Belton', 'Belton', 'Belton,belteon,bltwn  tgzas,byltwn,Белтон,بلتون، تگزاس,بيلتون,بیلٹن، ٹیکساس,벨턴', 31.0560100, -97.4644500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136258, 'Benavides', 'Benavides', '', 27.5989200, -98.4080700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136259, 'Benbrook', 'Benbrook', 'Benbruk,bnbrwk,bnbrwk  tgzas,Бенбрук,بنبروك,بنبروک، تگزاس', 32.6731900, -97.4605800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136260, 'Benjamin', 'Benjamin', '', 33.5839800, -99.7923100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136261, 'Berryville', 'Berryville', '', 32.0884900, -95.4719000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136262, 'Bertram', 'Bertram', '', 30.7438000, -98.0555800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136263, 'Beverly', 'Beverly', '', 31.5251700, -97.1419500, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136264, 'Beverly Hills', 'Beverly Hills', 'Beverly,Beverly Hills,Bevurli Khils,Бевърли Хилс', 31.5215600, -97.1538900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136265, 'Bevil Oaks', 'Bevil Oaks', 'Bevel Acres,Bevel Oaks,Bevil Oaks', 30.1502100, -94.2696300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136266, 'Big Sandy', 'Big Sandy', '', 32.5837500, -95.1088300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136267, 'Bishop', 'Bishop', 'Bishop,Brookings', 27.5861400, -97.7991600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136268, 'Blanco', 'Blanco', '', 30.0979900, -98.4214100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136269, 'Bloomington', 'Bloomington', 'Blumington,Блумингтон', 28.6477700, -96.8924900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136270, 'Blossom', 'Blossom', '', 33.6615000, -95.3857900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136271, 'Blue Mound', 'Blue Mound', '', 32.8565200, -97.3389100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136272, 'Boerne', 'Boerne', 'Berni,brny  tgzas,bwyrn,Берни,برنی، تگزاس,بويرن', 29.7946600, -98.7319700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136273, 'Bogata', 'Bogata', '', 33.4706700, -95.2138400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136274, 'Boling', 'Boling', '', 29.2644100, -95.9438400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136275, 'Bolivar Peninsula', 'Bolivar Peninsula', '', 29.4782900, -94.5799100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136276, 'Bonham', 'Bonham', 'Bonam,banhm  tgzas,bwnham,Бонам,بانهم، تگزاس,بونهام', 33.5773300, -96.1783100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136277, 'Bowie', 'Bowie', 'Boui,Bui,bawy,bwyy  tgzas,Боуи,Буи,باوي,بویی، تگزاس', 33.5590000, -97.8486500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136278, 'Boyd', 'Boyd', '', 33.0787300, -97.5653000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136279, 'Brady', 'Brady', 'BBD,Bredi,Brejdi,brady,brydy  tgzas,Бреді,Брейди,Брејди,برادي,بریدی، تگزاس', 31.1351700, -99.3350600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136280, 'Brazoria', 'Brazoria', 'BZT', 29.0444100, -95.5691100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136281, 'Breckenridge', 'Breckenridge', 'BKD,Breckenridge,Brekenridz,brknryj  tgzas,bryknrydj,Брекенриџ,بريكنريدج,برکنریج، تگزاس,بریکنریج، ٹیکساس', 32.7556800, -98.9022900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136282, 'Brenham', 'Brenham', 'Brenam,brnham  tgzas,brynham,Бренам,برنهام، تگزاس,برينهام', 30.1668800, -96.3977400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136283, 'Briar', 'Briar', '', 32.9951200, -97.5428000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136284, 'Briarcliff', 'Briarcliff', '', 30.4074200, -98.0444600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136285, 'Bridge City', 'Bridge City', '', 30.0207700, -93.8457300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136286, 'Bridgeport', 'Bridgeport', '', 33.2101200, -97.7547600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136287, 'Brookshire', 'Brookshire', '', 29.7860600, -95.9510700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136288, 'Brookside Village', 'Brookside Village', '', 29.5869000, -95.3252200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136289, 'Brownsboro', 'Brownsboro', '', 32.3023700, -95.6135700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136290, 'Brownsville', 'Brownsville', 'BRO,Braunsvil,Braunsvila,Braunsvilis,Braunsvill,Brownsville,Fort Brown,Fort Taylor,beulaunjeubil,brawnzfyl,brawnzwl,brawnzwyl  tgzas,bu lang si wei er,buraunzubiru,Браунсвил,Браунсвилл,בראונסוויל,براؤنزول,براونزفيل,براونزویل، تگزاس,براونزویل، ٹیکساس,ブラウンズビル,布朗斯維爾,브라운즈빌', 25.9017500, -97.4974800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136291, 'Bruceville-Eddy', 'Bruceville-Eddy', 'Bruceville,Bruceville-Eddy,Eddy', 31.3051700, -97.2516700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136292, 'Brownwood', 'Brownwood', 'BWD,Braunvud,Brownwood,beulaun-udeu,brawnwwd,brawnwwd  tgzas,Браунвуд,براونوود,براونوود، تگزاس,브라운우드', 31.7093200, -98.9911600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136293, 'Brushy Creek', 'Brushy Creek', '', 30.5135300, -97.7397300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136294, 'Bryan', 'Bryan', 'Brajan,Bryan,CFD,beulaieon,brayan  tgzas,bryan,bu lai en,buraian,Брайан,Брајан,برائن، ٹیکساس,برایان، تگزاس,بريان,ブライアン,布賴恩,브라이언', 30.6743600, -96.3699600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136295, 'Buchanan Dam', 'Buchanan Dam', 'Bachanan Dam,Buchanan Dam', 30.7399000, -98.4311400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136296, 'Buffalo', 'Buffalo', 'Buffalo,Буффало', 31.4637900, -96.0580200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136297, 'Bullard', 'Bullard', '', 32.1398800, -95.3202300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136298, 'Bulverde', 'Bulverde', 'Bulverde,Pieper Settlement', 29.7438300, -98.4530700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136299, 'Buna', 'Buna', '', 30.4329800, -93.9624000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136300, 'Bunker Hill Village', 'Bunker Hill Village', '', 29.7674500, -95.5299400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136301, 'Burkburnett', 'Burkburnett', 'Burkburnett,Gilbert', 34.0978700, -98.5706100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136302, 'Burleson', 'Burleson', 'Berleson,Burlesone,brlswn  tgzas,bwrlyswn,Берлесон,Бурлесоне,برلسون، تگزاس,بورليسون', 32.5420800, -97.3208500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136303, 'Burnet', 'Burnet', 'Bernet,brnt  tgzas,byrnt,Бернет,برنت، تگزاس,بيرنت', 30.7582400, -98.2283600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136304, 'Cactus', 'Cactus', '', 27.9069500, -99.3939200, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136305, 'Caddo Mills', 'Caddo Mills', '', 33.0656700, -96.2277600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136306, 'Caldwell', 'Caldwell', 'Kolduehll,Koldvel,kaldwl  tgzas,kaldwyl,Колдвел,Колдуэлл,كالدويل,کالدول، تگزاس', 30.5313200, -96.6930300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136307, 'Calvert', 'Calvert', 'Kalvert,kalfyrt,kalwrt  tgzas,Калверт,كالفيرت,کالورت، تگزاس', 30.9779700, -96.6738600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136308, 'Cameron', 'Cameron', 'Kameron,kamrwn  tgzas,kamyrwn,Камерон,كاميرون,کامرون، تگزاس,کیمرون، ٹیکساس', 30.8532500, -96.9769300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136309, 'Cameron Park', 'Cameron Park', '', 25.9645200, -97.4766500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136310, 'Cameron Park Colonia', 'Cameron Park Colonia', '', 25.9714700, -97.4783200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136311, 'Camp Swift', 'Camp Swift', '', 30.1907700, -97.2922100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136312, 'Canton', 'Canton', '', 32.5565200, -95.8633000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136313, 'Canyon Lake', 'Canyon Lake', '', 29.8752200, -98.2625100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136314, 'Carrizo Springs', 'Carrizo Springs', 'Karizo Springs,ka li suo si pu lin si,karyzw sbrynghz,kryzw aspryngz  tgzas,Каризо Спрингс,كاريزو سبرينغز,کریزو اسپرینگز، تگزاس,卡里索斯普林斯', 28.5219300, -99.8606100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136315, 'Carrollton', 'Carrollton', 'Carrollton,Karolton,Karoltonas,Karrolton,Kerrolton,ka luo er dun,kaeleolteon,karwltwn,krwltwn  tgzas,kyaroruton,Каролтон,Карролтон,Керролтон,كارولتون,کرولتون، تگزاس,کیرولٹن,کیرولٹن، ٹیکساس,കരോൾട്ടൺ,キャロルトン,卡羅爾頓,캐럴턴', 32.9537300, -96.8902800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136316, 'Carthage', 'Carthage', 'Kartidz,kartazh  tgzas,karthagh,kasiji,Картиџ,كارثاغ,کارتاژ، تگزاس,کارتھیج، ٹیکساس,카시지', 32.1573800, -94.3374200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136317, 'Castle Hills', 'Castle Hills', '', 29.5232900, -98.5164100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136318, 'Castroville', 'Castroville', 'Kastrovil,kastrwfyl,kstrwyl  tgzas,Кастровил,كاستروفيل,کسترویل، تگزاس', 29.3557900, -98.8786400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136319, 'Cedar Hill', 'Cedar Hill', 'Cedar Hill,Cedarhill', 32.5884700, -96.9561200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136320, 'Cedar Park', 'Cedar Park', 'Cedar Park,Cedarpark,Sidar Park,sydar bark,sydr park  tgzas,Сидар Парк,سيدار بارك,سیدر پارک، تگزاس,سیڈر پارک، ٹیکساس', 30.5052000, -97.8202900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136321, 'Celina', 'Celina', '', 33.3245600, -96.7844400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136322, 'Center', 'Center', '', 31.5107300, -96.4247000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136323, 'Center', 'Center', 'Senter,sntr,sntr  tgzas,Сентер,سنتر,سنتر، تگزاس,سینٹر، ٹیکساس', 31.7954500, -94.1790900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136324, 'Centerville', 'Centerville', 'Centerville,Centreville', 31.2579600, -95.9782900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136325, 'Central Gardens', 'Central Gardens', '', 29.9954900, -94.0140600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136326, 'César Chávez', 'Cesar Chavez', 'Cesar Chavez,César Chávez', 26.3034000, -98.1152900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136327, 'Chandler', 'Chandler', 'Chandler,Чандлер', 32.3079300, -95.4799600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136328, 'Channelview', 'Channelview', '', 29.7760600, -95.1146500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136329, 'Charlotte', 'Charlotte', 'Sharlott,Шарлотт', 28.8619200, -98.7064100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136330, 'Chico', 'Chico', 'Chiko,Чико', 33.2959500, -97.7989200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136331, 'China', 'China', '', 30.0479900, -94.3357400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136332, 'China Grove', 'China Grove', '', 29.3888500, -98.3489000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136333, 'Cibolo', 'Cibolo', 'Cibolo,Cibolo Valley,Fromme''s Store', 29.5616200, -98.2269600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136334, 'Cinco Ranch', 'Cinco Ranch', '', 29.7388400, -95.7580000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136335, 'Cisco', 'Cisco', '', 32.3881900, -98.9792300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136336, 'Citrus City', 'Citrus City', 'Citrus City,Judd City', 26.3264600, -98.3853000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136337, 'Clarksville', 'Clarksville', '', 33.6106600, -95.0527200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136338, 'Clear Lake Shores', 'Clear Lake Shores', '', 29.5474500, -95.0321500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136339, 'Cleburne', 'Cleburne', 'Klibern,klybrn  tgzas,kylbwrn,Клиберн,كيلبورن,کلیبرن، تگزاس', 32.3476400, -97.3866800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136340, 'Cleveland', 'Cleveland', '', 31.6768200, -99.2536700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136341, 'Cleveland', 'Cleveland', 'Klivlend,klyfland,klywlnd  tgzas,Кливленд,كليفلاند,کلیولند، تگزاس,کلیولینڈ، ٹیکساس', 30.3413200, -95.0854900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136342, 'Clifton', 'Clifton', 'Klifton,klyftwn,klyftwn  tgzas,Клифтон,كليفتون,کلیفتون، تگزاس', 31.7823800, -97.5766900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136343, 'Cloverleaf', 'Cloverleaf', '', 29.7782800, -95.1718800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136344, 'Clute', 'Clute', 'Clute,Clute City,Lake Barbara', 29.0246900, -95.3988300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136345, 'Clyde', 'Clyde', '', 32.4059600, -99.4936900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136346, 'Cockrell Hill', 'Cockrell Hill', '', 32.7362400, -96.8869500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136347, 'Coldspring', 'Coldspring', 'Cold Spring,Coldspring,Coonskin,Firemans Hill,Firemen''s Hill', 30.5924200, -95.1293800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136348, 'Coleman', 'Coleman', 'COM', 31.8273700, -99.4264500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136349, 'College Station', 'College Station', 'CLL,College Station,Koledz Stejshon,Kolledzh-Stejshen,da xue cheng,kalej stesan,kalj astyshn  tgzas,kallijiseuteisyeon,karejjisuteshon,koleja stesana,kwlyj styshn,Колеџ Стејшон,Колледж-Стейшен,كوليج ستيشن,کالج استیشن، تگزاس,کالج سٹیشن، ٹیکساس,कॉलेज स्टेशन,కాలేజ్ స్టేషన్,カレッジステーション,大學城,칼리지스테이션', 30.6279800, -96.3344100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136350, 'Colleyville', 'Colleyville', 'Coleysville,Colleyville,Kolivil,kalywyl  tgzas,kwlyfyl,Коливил,كوليفيل,کالیویل، تگزاس', 32.8809600, -97.1550100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136351, 'Collinsville', 'Collinsville', 'Kollinsvil'',Коллинсвиль', 33.5615000, -96.9111100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136352, 'Columbus', 'Columbus', 'Colombus,Columbus,Kolambus,Kolumbus,ge lun bu,klmbws  tgzas,kwlwmbws,Коламбус,Колумбус,كولومبوس,کلمبوس، تگزاس,کولمبس، ٹیکساس,哥倫布', 29.7066200, -96.5396900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136353, 'Comanche', 'Comanche', 'Komanchi,ke man qi,kwmanchy  tgzas,kwmansh,Команчи,كومانش,کومانچی، تگزاس,科曼奇', 31.8973700, -98.6036600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136354, 'Combes', 'Combes', 'Combes,Combs', 26.2486900, -97.7338800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136355, 'Combine', 'Combine', '', 32.5884700, -96.5086000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136356, 'Comfort', 'Comfort', 'Kamfort,kamfwrt,kamfwrt  tgzas,Камфорт,كامفورت,کامفورت، تگزاس', 29.9677100, -98.9050300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136357, 'Commerce', 'Commerce', '', 33.2470600, -95.8999700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136358, 'Conroe', 'Conroe', 'CXO,Konro,kanrw  tgzas,kwnrwy,Конро,كونروي,کانرو، تگزاس,کونرو، ٹیکساس', 30.3118800, -95.4560500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136359, 'Converse', 'Converse', 'Konvers,kanwrs  tgzas,kwnfyrs,Конверс,كونفيرس,کانورس، تگزاس', 29.5180100, -98.3161200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136360, 'Cooper', 'Cooper', 'Kuper,kwpr  tgzas,Купер,کوپر، تگزاس', 33.3734400, -95.6882900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136361, 'Cooper', 'Cooper', '', 31.2432400, -95.5821700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136362, 'Coppell', 'Coppell', 'Koppell,Коппелл', 32.9545700, -97.0150100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136363, 'Copper Canyon', 'Copper Canyon', '', 33.0959500, -97.0966800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136364, 'Copperas Cove', 'Copperas Cove', 'Coperas Cove,Copperas Cove,Kopras Kouv,kwbyras kwf,kwpras kww  tgzas,Копрас Коув,كوبيراس كوف,کوپراس کوو، تگزاس', 31.1240600, -97.9030800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136365, 'Corinth', 'Corinth', '', 33.1540100, -97.0647300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136366, 'Corpus Christi', 'Corpus Christi', 'CRP,Corpus Christi,Gorad Korpus-Krysty,Korpous Kristi,Korpus Kristi,Korpus-Kristi,Korpuskristi,ke po si ke li si di,khxrpaskh ri sti,kopasukurisuti,kopeoseukeuliseuti,korpasa kristi,kwrbws krysty,kwrps krysty,qwrpws krysty,Κόρπους Κρίστι,Горад Корпус-Крысты,Корпус Кристи,Корпус-Кристи,Корпус-Крісті,Корпъс Кристи,קורפוס כריסטי,كوربوس كريستي,کارپس کرسٹی، ٹیکساس,کورپس کرسٹی,کورپس کریستی,कॉर्पस क्रिस्टी,คอร์ปัสคริสตี,コーパスクリスティ,科珀斯克里斯蒂,코퍼스크리스티', 27.8005800, -97.3963800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136367, 'Corrigan', 'Corrigan', '', 30.9968600, -94.8271500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136368, 'Corsicana', 'Corsicana', 'CRS,Korsikana,kwrsykana,kwrsykana  tgzas,Корсикана,كورسيكانا,کورسیکانا، تگزاس', 32.0954300, -96.4688700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136369, 'Cottonwood Shores', 'Cottonwood Shores', '', 30.5557500, -98.3239100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136370, 'Cotulla', 'Cotulla', 'COT,Kotula,kwtwla,kwtwla  tgzas,Котула,كوتولا,کوتولا، تگزاس', 28.4369300, -99.2350300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136371, 'Crandall', 'Crandall', '', 32.6279100, -96.4558200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136372, 'Crockett', 'Crockett', 'Crocket,Crockett,Kroket,krakt  tgzas,krwkyt,Крокет,كروكيت,کراکت، تگزاس', 31.3182400, -95.4566100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136373, 'Crosby', 'Crosby', '', 29.9118900, -95.0621500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136374, 'Cross Mountain', 'Cross Mountain', '', 29.6455000, -98.6594700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136375, 'Crowell', 'Crowell', '', 33.9839700, -99.7248200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136376, 'Crowley', 'Crowley', '', 32.5790300, -97.3625200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136377, 'Crystal City', 'Crystal City', 'Kristal Siti,krystal syty,krystal syty  tgzas,Кристал Сити,كريستال سيتي,کرسٹل سٹی، ٹیکساس,کریستال سیتی، تگزاس', 28.6774800, -99.8281100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136378, 'Cuero', 'Cuero', 'Cuero,Kvero,Quairo,kwrw,kwrw  tgzas,Кверо,كورو,کورو، تگزاس', 29.0938700, -97.2891600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136379, 'Cut and Shoot', 'Cut and Shoot', 'Cut ''N Shoot,Cut and Shoot', 30.3332700, -95.3579900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136380, 'Cypress', 'Cypress', 'saybrs,sayprs  tgzas,سايبرس,سایپرس، تگزاس', 29.9691100, -95.6971700, 'US', '2011-07-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136381, 'Daingerfield', 'Daingerfield', 'Dejndzerfild,dyngrfyld  tgzas,dynjrfyld,Дејнџерфилд,دينجرفيلد,دینگرفیلد، تگزاس', 33.0317900, -94.7218700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136382, 'Dallas', 'Dallas', 'DFW,Dalas,Dalasa,Dalasas,Dallas,Dallas shaary,Dallasium,Gorad Dalas,Ntalas,da la si,daelleoseu,dailasa,dalas,dalasa,dalasi,dallas,dallasa,dallaseu,darasu,delasa,talas,Ντάλας,Горад Далас,Далас,Даллас,Даллас шаары,Դալաս,דאלאס,دالاس,داللاس,داڵاس,ڈیلاس,डॅलस,डैलस,ডালাস,ਡਾਲਸ,ડલ્લાસ,டாலஸ்,డల్లాస్,ഡാളസ്,แดลลัส,ဒါးလတ်စ်မြို့,დალასი,ዳላስ,ダラス,達拉斯,달라스,댈러스', 32.7830600, -96.8066700, 'US', '2017-06-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136383, 'Dalworthington Gardens', 'Dalworthington Gardens', '', 32.7029100, -97.1552900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136384, 'Danbury', 'Danbury', '', 29.2283000, -95.3449400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136385, 'Dayton', 'Dayton', 'Daystown,Dayton,Dayton Station,Dejton,West Liberty,daytwn,detana,dytwn  tgzas,Дейтон,Дејтон,دايتون,دیتون، تگزاس,ڈیٹن، ٹیکساس,डेटन', 30.0466100, -94.8852000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136386, 'De Kalb', 'De Kalb', 'De Kalb,Dekalb', 33.5087300, -94.6163200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136387, 'De Leon', 'De Leon', 'De Leon,DeLeon,Deleon', 32.1109700, -98.5358800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136388, 'DeCordova', 'DeCordova', '', 32.4298600, -97.6950300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136389, 'DeSoto', 'DeSoto', 'De Soto,DeSoto,Desoto,Opportunity,Soto,Woodland Hills,deseattea,dswtw  tgzas,dy swtw,Десото,Сото,دسوتو، تگزاس,دي سوتو,ڈیسوٹو، ٹیکساس,ഡെസോട്ടൊ', 32.5898600, -96.8569500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136390, 'Decatur', 'Decatur', 'Dekejter,Dekejtur,dikeiteo,diketa,diketara,dkatwr  tgzas,dykatwr,Декейтер,Декејтур,ديكاتور,دکاتور، تگزاس,डिकॅटर,ディケーター,디케이터', 33.2342800, -97.5861400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136391, 'Deer Park', 'Deer Park', 'Deer Park,Deerpark,Dir Park,dyr bark,dyr park  tgzas,Дир Парк,دير بارك,دیر پارک، تگزاس', 29.7052300, -95.1238200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136392, 'Denison', 'Denison', 'Denison,Dennison,dan ni sen,denison,dnyswn,dnyswn  tgzas,Денисон,דניסון,دنيسون,دنیسون، تگزاس,ڈینیسن، ٹیکساس,デニソン,丹尼森', 33.7556600, -96.5366600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136393, 'Denton', 'Denton', 'Denton,Dentonas,Dentono,Dentun,deng dun,dentana,denteon,denton,dntwn  tgzas,dyntwn,Дентон,Дентън,دنتون، تگزاس,دينتون,ڈینٹن,ڈینٹن، ٹیکساس,डेंटन,ডেন্টন,ഡെന്റൺ,デントン,登頓,덴턴', 33.2148400, -97.1330700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136394, 'Deweyville', 'Deweyville', '', 30.2977100, -93.7435000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136395, 'Diboll', 'Diboll', '', 31.1871300, -94.7810400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136396, 'Dickinson', 'Dickinson', 'Dikinson,dikinseun,dykynswn,dykynswn  tgzas,Дикинсон,ديكينسون,دیکینسون، تگزاس,디킨슨', 29.4607900, -95.0513200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136397, 'Doffing', 'Doffing', '', 26.2745200, -98.3858500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136398, 'Donna', 'Donna', '', 26.1703500, -98.0519500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136399, 'Doolittle', 'Doolittle', '', 26.3533700, -98.1166600, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136400, 'Double Oak', 'Double Oak', '', 33.0651200, -97.1105700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136401, 'Dripping Springs', 'Dripping Springs', '', 30.1902100, -98.0866800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136402, 'Dublin', 'Dublin', 'Dablin,Dublin,dbln,deobeullin,dwblyn  tgzas,Даблин,Дублин,دبلن,دوبلین، تگزاس,ڈبلن، ٹیکساس,더블린', 32.0851400, -98.3419900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136403, 'Duncanville', 'Duncanville', 'Dankanvil,danknfyl,danknwyl  tgzas,Данканвил,دانكنفيل,دانکنویل، تگزاس,ഡങ്കൺവിൽ', 32.6518000, -96.9083400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136404, 'Eagle Lake', 'Eagle Lake', 'Eagle Lake,Eaglelake,Igl Lejk,ayghl lyk,aygl lyk  tgzas,Игл Лејк,إيغل ليك,ایگل لیک، تگزاس', 29.5896800, -96.3335800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136405, 'Eagle Mountain', 'Eagle Mountain', '', 32.8934600, -97.4444600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136406, 'Early', 'Early', '', 31.7421000, -98.9456100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136407, 'East Bernard', 'East Bernard', '', 29.5310700, -96.0710700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136408, 'Eastland', 'Eastland', 'Istland,aystland,aystlnd  tgzas,Истланд,إيستلاند,ایستلند، تگزاس', 32.4015200, -98.8175600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136409, 'Edcouch', 'Edcouch', 'Ed Couch,Edcouch', 26.2939600, -97.9605600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136410, 'Eden', 'Eden', '', 31.2162800, -99.8456300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136411, 'Edgecliff Village', 'Edgecliff Village', 'Edgecliff,Edgecliff Village', 32.6576300, -97.3427900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136412, 'Edgewood', 'Edgewood', '', 32.6981800, -95.8852400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136413, 'Edinburg', 'Edinburg', 'Edinburg,Ehdinburg,adynbrg  tgzas,adynbwrgh,edinbagu,Единбург,Эдинбург,إدينبورغ,ادینبرگ، تگزاس,ایڈنبرگ، ٹیکساس,エディンバーグ', 26.3017400, -98.1633400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136414, 'El Campo', 'El Campo', 'El Campo,El Kampo,Elcampo,al kambw,al kampw  tgzas,Ел Кампо,إل كامبو,ال کامپو، تگزاس', 29.1966400, -96.2696900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136415, 'El Cenizo', 'El Cenizo', '', 27.3522400, -99.4925400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136416, 'El Lago', 'El Lago', '', 29.5635600, -95.0452100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136417, 'Electra', 'Electra', 'Beaver,Electra,Elektra,Waggoner Switch,alktra  tgzas,alyktra,Електра,إليكترا,الکترا، تگزاس', 34.0292600, -98.9189600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136418, 'Elgin', 'Elgin', 'Elgin,algyn  tgzas,aljyn,Елгин,إلجين,الگین، تگزاس', 30.3496500, -97.3702700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136419, 'Elkhart', 'Elkhart', 'Ehlkkhart,Elkhart,Elkheart,Элкхарт', 31.6251700, -95.5794000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136420, 'Elmendorf', 'Elmendorf', '', 29.2560700, -98.3327900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136421, 'Elsa', 'Elsa', '', 26.2934000, -97.9930600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136422, 'Emory', 'Emory', '', 32.8745700, -95.7655200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136423, 'Encantada-Ranchito-El Calaboz', 'Encantada-Ranchito-El Calaboz', 'Encantada-Ranchito El Calaboz,Encantada-Ranchito-El Calaboz', 26.0334400, -97.6330700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136424, 'Ennis', 'Ennis', 'Enis,Ennis,Sonoma,anys  tgzas,aynys,Енис,انیس، تگزاس,اينيس', 32.3293100, -96.6252700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136425, 'Escobares', 'Escobares', '', 26.4106200, -98.9625300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136426, 'Euless', 'Euless', 'Jules,ywls,ywls  tgzas,Јулес,يولس,یولس، تگزاس,یولیس، ٹیکساس', 32.8370700, -97.0819500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136427, 'Evadale', 'Evadale', '', 30.3549300, -94.0726800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136428, 'Everman', 'Everman', '', 32.6309700, -97.2891800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136429, 'Fair Oaks Ranch', 'Fair Oaks Ranch', '', 29.7457800, -98.6433600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136430, 'Fairchilds', 'Fairchilds', '', 29.4313500, -95.7802300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136431, 'Fairfield', 'Fairfield', 'Fairfield,Ferfild,Feurfild,Mount Pleasant,Mount Prairie,fyrfyld,fyrfyld  tgzas,Ферфилд,Феърфилд,فيرفيلد,فیئرفیلڈ، ٹیکساس,فیرفیلد، تگزاس', 31.7246100, -96.1652500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136432, 'Fairview', 'Fairview', '', 33.1579000, -96.6316600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136433, 'Fairview', 'Fairview', 'Fairview,New Fairview', 33.0192900, -97.5458600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136434, 'Falcon Lake Estates', 'Falcon Lake Estates', '', 26.8728200, -99.2553100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136435, 'Falfurrias', 'Falfurrias', 'Falfjurijas,falfwryas,falfwryas  tgzas,Фалфјуријас,فالفورياس,فالفوریاس، تگزاس,فالفوریاس، ٹیکساس', 27.2269900, -98.1441700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136436, 'Fannett', 'Fannett', '', 29.9260500, -94.2507400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136437, 'Farmers Branch', 'Farmers Branch', 'Farmers Branch,farmrz bransh,farmrz brnch  tgzas,Фармерс Бранч,فارمرز برانش,فارمرز برنچ، تگزاس,ഫാർമേഴ്സ് ബ്രാഞ്ച്', 32.9265100, -96.8961200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136438, 'Farmersville', 'Farmersville', '', 33.1634500, -96.3599800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136439, 'Fate', 'Fate', '', 32.9415100, -96.3813700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136440, 'Ferris', 'Ferris', '', 32.5340300, -96.6655500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136441, 'Fifth Street', 'Fifth Street', '', 29.5982900, -95.5513300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136442, 'Flatonia', 'Flatonia', '', 29.6877300, -97.1086000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136443, 'Florence', 'Florence', 'Florencija,Флоренция', 30.8413000, -97.7936300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136444, 'Floresville', 'Floresville', 'Floresvil,Florsvil,flwrsfyl,flwrzwyl  tgzas,Флорсвил,Ֆլորեսվիլ,فلورزویل، تگزاس,فلورسفيل', 29.1335800, -98.1561200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136445, 'Flower Mound', 'Flower Mound', 'Flauer Maund,Flower Mound,flawr,flawr mawnd  tgzas,Флауер Маунд,فلاور,فلاور ماؤنڈ، ٹیکساس,فلاور ماوند، تگزاس', 33.0145700, -97.0969600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136446, 'Forest Hill', 'Forest Hill', '', 32.6720800, -97.2691800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136447, 'Forney', 'Forney', '', 32.7481800, -96.4719300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136448, 'Fort Worth', 'Fort Worth', 'Arx Vorthensis,Camp Worth,FTW,Fort Gouorth,Fort Uehrt,Fort Uert,Fort Uurt,Fort Vort,Fort Worth,Fort-Owert,Fort-Uehrt,Fort-Vort,Fortverta,Fortvortas,Fortvērta,Gorad Fort-Uehrt,f xrtweirth,forata varatha,fotowasu,fwrt wwrth,fwrt wwrth  tgzas,phorta oyartha,phorta vartha,portʼ-uerti,poteuwoseu,pwrt wwrt,vort kottai,wo si bao,Φορτ Γουόρθ,Горад Форт-Уэрт,Форт Ворт,Форт Уърт,Форт Уэрт,Форт-Ворт,Форт-Уэрт,Ֆորտ-Ուերտ,פורט וורת,فورت وورث,فورت وورث، تگزاس,فورٹ ورتھ,فورٹ ورتھ، ٹیکساس,फोर्ट वर्थ,ফোর্ট ওয়ার্থ,ਫ਼ੋਰਟ ਵਰਥ,வொர்த் கோட்டை,ഫോർട്ട് വർത്ത്,ฟอร์ตเวิร์ท,ფორტ-უერთი,フォートワース,沃思堡,포트워스', 32.7254100, -97.3208500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136449, 'Four Corners', 'Four Corners', '', 29.6685700, -95.6577200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136450, 'Franklin', 'Franklin', 'Franklin,Frenklin,franklyn,franklyn  tgzas,Франклин,Френклин,فرانكلين,فرانکلین، تگزاس,فرینکلن، ٹیکساس', 31.0260200, -96.4852400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136451, 'Frankston', 'Frankston', '', 32.0526600, -95.5063500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136452, 'Fredericksburg', 'Fredericksburg', 'Fredericksburg,Frederiksberg,Frederiksburg,Friedrichsburg,frdryksbrg  tgzas,frydryksbwrgh,fu lei de li ke si bao,furederikkusubagu,peuledeoligseubeogeu,Фредериксберг,Фредериксбург,Фредериксбърг,Фредеріксбург,فردریکسبرگ، تگزاس,فريدريكسبورغ,フレデリックスバーグ,弗雷德里克斯堡,프레더릭스버그', 30.2752000, -98.8719800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136453, 'Freeport', 'Freeport', 'Friport,frybwrt,frypwrt  tgzas,peulipoteu,Фрипорт,فريبورت,فری پورٹ، ٹیکساس,فریپورت، تگزاس,프리포트', 28.9541400, -95.3596600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136454, 'Freer', 'Freer', '', 27.8828000, -98.6177900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136455, 'Fresno', 'Fresno', 'Fresno,Фресно', 29.5388500, -95.4474400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136456, 'Friendswood', 'Friendswood', 'Frendsvud,frndzwwd  tgzas,fryndzwwd,Френдсвуд,فرندزوود، تگزاس,فريندزوود', 29.5294000, -95.2010400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136457, 'Frisco', 'Frisco', 'Firsco,Frisco,Frisko,fryskw,fryskw  tgzas,furisuko,peuliseuko,phriskea,Фриско,Фріско,فريسكو,فریسکو، تگزاس,فریسکو، ٹیکساس,ഫ്രിസ്കോ,フリスコ,프리스코', 33.1506700, -96.8236100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136458, 'Fulshear', 'Fulshear', '', 29.6899600, -95.8996800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136459, 'Fulton', 'Fulton', '', 28.0614000, -97.0411000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136460, 'Gainesville', 'Gainesville', 'GLE,Gejnsvil,geinjeubil,ghynsfyl,gynzwyl  tgzas,Гејнсвил,غينسفيل,گینزویل، تگزاس,게인즈빌', 33.6259400, -97.1333500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136461, 'Galena Park', 'Galena Park', 'Galina Park,ghalyna bark,glyna park  tgzas,Галина Парк,غالينا بارك,گلینا پارک، تگزاس', 29.7335600, -95.2302100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136462, 'Galveston', 'Galveston', 'GLS,Galveston,Gorad Galvestan,gaelbeoseuteon,galwstwn  tgzas,garubesuton,gelvhastana,ghalfstwn,jia er wei si dui,Галвестон,Горад Галвестан,Ґалвестoн,غالفستون,گالوستون، تگزاس,गॅल्व्हस्टन,ഗാൽ‌വെസ്റ്റൺ,ガルベストン,加爾維斯敦,갤버스턴', 29.3013500, -94.7977000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136463, 'Ganado', 'Ganado', '', 29.0405400, -96.5135800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136464, 'Garden Ridge', 'Garden Ridge', '', 29.6346700, -98.3052900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136465, 'Gardendale', 'Gardendale', '', 28.5169300, -99.2161400, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136466, 'Garfield', 'Garfield', '', 30.1874400, -97.5577800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136467, 'Garland', 'Garland', 'Duck Creek,Embree,Garland,Garlandas,Garlend,Girljanda,gallaendeu,garando,garlnd  tgzas,gharland,jia lan,Гарланд,Гарленд,Гирлянда,Ґарланд,غارلاند,گارلند، تگزاس,گارلینڈ,گارلینڈ، ٹیکساس,ഗാർലന്റ്,ガーランド,加蘭,갈랜드', 32.9126200, -96.6388800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136468, 'Gatesville', 'Gatesville', 'Gejtsvil,gai ci wei er,ghtsfyl,gytswyl  tgzas,Гејтсвил,غتسفيل,گیتسویل، تگزاس,蓋茨維爾', 31.4351600, -97.7439100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136469, 'George West', 'George West', '', 28.3325000, -98.1175100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136470, 'Georgetown', 'Georgetown', 'Dzhordzhtaun,Dzordztaun,Džordžtaun,jrj‌tawn  tgzas,jwrjtawn,Џорџтаун,Джорджтаун,جارج ٹاؤن، ٹیکساس,جرج‌تاون، تگزاس,جورجتاون', 30.6326900, -97.6772300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136471, 'Geronimo', 'Geronimo', '', 29.6630000, -97.9669500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136472, 'Gholson', 'Gholson', '', 31.7010000, -97.2164000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136473, 'Giddings', 'Giddings', 'Gidings,ghydynghz,gydyngz  tgzas,ji ding si,Гидингс,غيدينغز,گیدینگز، تگزاس,吉丁斯', 30.1827200, -96.9363700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136474, 'Gilmer', 'Gilmer', 'Gilmer,ghlmr,gylmr  tgzas,Гилмер,Ґілмер,غلمر,گیلمر، تگزاس', 32.7287500, -94.9424400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136475, 'Gladewater', 'Gladewater', '', 32.5365300, -94.9427200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136476, 'Glen Rose', 'Glen Rose', 'Glen Rose,Glen Rouz,Glenrose,ge lun luo si,ghln rz,gln rz  tgzas,Глен Роуз,غلن رز,گلن رز، تگزاس,格伦罗斯', 32.2345900, -97.7553100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136477, 'Glenn Heights', 'Glenn Heights', '', 32.5487500, -96.8566700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136478, 'Godley', 'Godley', '', 32.4490300, -97.5266900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136479, 'Goldthwaite', 'Goldthwaite', 'Goltvejt,ghwldthwyt,gldtwayt  tgzas,Голтвејт,غولدثويت,گلدتوایت، تگزاس', 31.4498900, -98.5708800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136480, 'Goliad', 'Goliad', 'Goliad,Goliat,Golijad,ge li ya de,ghwlyd,gwlyad  tgzas,Голијад,غوليد,گولیاد، تگزاس,戈利亚德', 28.6683300, -97.3883300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136481, 'Gonzales', 'Gonzales', 'Gonzales,Gonzáles,gang sa lei si,ghwnzalys,gonjalleoseu,gwnzals  tgzas,Гонзалес,Ґонзалес,غونزاليس,گونزالس، تگزاس,冈萨雷斯,곤잘러스', 29.5016300, -97.4524900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136482, 'Gorman', 'Gorman', '', 32.2137500, -98.6706100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136483, 'Graham', 'Graham', 'Grejam,ghraham,graham  tgzas,Грејам,غراهام,گراهام، تگزاس', 33.1070600, -98.5895000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136484, 'Granbury', 'Granbury', 'Granberi,ghranbwry,granbry  tgzas,Гранбери,غرانبوري,گرانبری، تگزاس', 32.4420800, -97.7942000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136485, 'Grand Prairie', 'Grand Prairie', 'Deckman,Grand Prairie,Grand Preri,Grand Preris,Grand-Preri,da cao yuan cheng,geulaendeupeuleli,ghrand brary,grnd pryry  tgzas,gurandopureri,Гранд Прери,Гранд-Прери,Гранд-Прері,غراند براري,گرند پریری، تگزاس,گرینڈ پریری,گرینڈ پریرے,ഗ്രാൻഡ് പ്രയറി,グランドプレーリー,大草原城,그랜드프레리', 32.7459600, -96.9977800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136486, 'Grand Saline', 'Grand Saline', 'Grand Saline,Jordan''s Saline,Jordans Saline', 32.6734600, -95.7094100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136487, 'Grandview', 'Grandview', '', 32.2704200, -97.1791800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136488, 'Granger', 'Granger', '', 30.7176900, -97.4427800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136489, 'Granite Shoals', 'Granite Shoals', '', 30.5890800, -98.3839200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136490, 'Grapeland', 'Grapeland', '', 31.4918500, -95.4785600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136491, 'Grapevine', 'Grapevine', '', 32.9342900, -97.0780700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136492, 'Greatwood', 'Greatwood', '', 29.5541300, -95.6757800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136493, 'Green Valley Farms', 'Green Valley Farms', '', 26.1220200, -97.5605400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136494, 'Greenville', 'Greenville', 'GVT,Grinvil,Grinvill,ghrynfyl,grynwyl  tgzas,Гринвил,Гринвилл,غرينفيل,گرینویل، تگزاس,گرینویل، ٹیکساس', 33.1384500, -96.1108100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136495, 'Gregory', 'Gregory', '', 27.9222400, -97.2899900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136496, 'Groesbeck', 'Groesbeck', 'Groesbeck,Groesbeeck,Groesbuck', 31.5243400, -96.5338700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136497, 'Groves', 'Groves', '', 29.9482700, -93.9171200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136498, 'Groveton', 'Groveton', 'Groverton,Groveton,Grovton,ghrwftwn,grwwtwn  tgzas,Гровтон,غروفتون,گرووتون، تگزاس', 31.0549100, -95.1257700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136499, 'Gun Barrel City', 'Gun Barrel City', '', 32.3345900, -96.1513600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136500, 'Gunter', 'Gunter', '', 33.4478900, -96.7474900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136501, 'Gunter', 'Gunter', '', 32.8687300, -95.6296800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136502, 'Hackberry', 'Hackberry', '', 33.1523400, -96.9177800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136503, 'Hallettsville', 'Hallettsville', 'Halletsville,Hallettsville,Khaletsvil,haltswyl,halytsfyl,Халетсвил,هالتسویل,هاليتسفيل', 29.4438500, -96.9410900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136504, 'Hallsville', 'Hallsville', '', 32.5043200, -94.5740900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136505, 'Haltom City', 'Haltom City', 'Haltom City,Kholtom Siti,Village of Haltom City,haltwm syty,Холтом Сити,هالتوم سيتي,هالتوم سیتی', 32.7995700, -97.2691800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136506, 'Hamilton', 'Hamilton', 'Gamil''ton,Khamilton,hamyltwn,hmyltwn  tgzas,Гамильтон,Хамилтон,هاميلتون,همیلتون، تگزاس,ہیملٹن، ٹیکساس', 31.7037700, -98.1239200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136507, 'Harker Heights', 'Harker Heights', '', 31.0835100, -97.6597400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136508, 'Harlingen', 'Harlingen', 'Garlingen,HRL,Harlingen,Kharlindzen,Kharlingen,ha ling gen,hallingjeon,harinjen,harlynghn,harlynjn,hrlyngn,Гарлінґен,Харлинген,Харлинџен,הרלינגן,هارلينغن,هارلینجن,ہارلنگین، ٹیکساس,ハーリンジェン,哈靈根,할링전', 26.1906300, -97.6961000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136509, 'Harper', 'Harper', '', 30.2999200, -99.2442100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136510, 'Haskell', 'Haskell', '', 33.1576000, -99.7337000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136511, 'Haslet', 'Haslet', '', 32.9748500, -97.3478000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136512, 'Hawkins', 'Hawkins', '', 32.5884700, -95.2041100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136513, 'Hearne', 'Hearne', 'Khern,hrnh  tgzas,hyrn,Херн,هرنه، تگزاس,هيرن', 30.8785200, -96.5930300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136514, 'Heath', 'Heath', '', 32.8365100, -96.4749900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136515, 'Hebbronville', 'Hebbronville', '', 27.3068800, -98.6803200, 'US', '2014-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136516, 'Hedwig Village', 'Hedwig Village', 'Hedwig,Hedwig Village', 29.7774500, -95.5171600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136517, 'Heidelberg', 'Heidelberg', '', 26.1970200, -97.8802800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136518, 'Helotes', 'Helotes', '', 29.5780100, -98.6897500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136519, 'Hemphill', 'Hemphill', '', 31.3407400, -93.8468500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136520, 'Hempstead', 'Hempstead', 'Khempsted,hmpstyd  tgzas,hymbstyd,Хемпстед,همپستید، تگزاس,هيمبستيد', 30.0974400, -96.0782900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136521, 'Henrietta', 'Henrietta', 'Khenrijeta,hnryta,hnryta  tgzas,Хенријета,هنريتا,هنریتا، تگزاس', 33.8173200, -98.1953200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136522, 'Hewitt', 'Hewitt', '', 31.4623900, -97.1958400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136523, 'Hickory Creek', 'Hickory Creek', '', 31.3787900, -95.3213300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136524, 'Hico', 'Hico', '', 31.9829300, -98.0336500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136525, 'Hidalgo', 'Hidalgo', 'Hidalgo,Hildago,Khidalgo,hydalghw,hydalgw  tgzas,Хидалго,هيدالغو,هیدالگو، تگزاس', 26.1003500, -98.2630700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136526, 'Hideaway', 'Hideaway', '', 32.4904200, -95.4574600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136527, 'Highland Park', 'Highland Park', 'Khajlend Park,Хайленд Парк', 32.8334600, -96.7919500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136528, 'Highland Village', 'Highland Village', '', 33.0917900, -97.0466800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136529, 'Highlands', 'Highlands', 'Elena,Highlands', 29.8188400, -95.0560400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136530, 'Hill Country Village', 'Hill Country Village', '', 29.5824500, -98.4908500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136531, 'Hillsboro', 'Hillsboro', 'Khillsboro,Хиллсборо', 32.0109900, -97.1300100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136532, 'Hilltop Lakes', 'Hilltop Lakes', '', 31.0793500, -96.2038500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136533, 'Hitchcock', 'Hitchcock', '', 29.3482900, -95.0160400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136534, 'Holiday Lakes', 'Holiday Lakes', '', 29.2096900, -95.5168900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136535, 'Holland', 'Holland', 'Gollandija,Голландия', 30.8782400, -97.4016700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136536, 'Holliday', 'Holliday', '', 33.8162100, -98.6950600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136537, 'Hollywood Park', 'Hollywood Park', '', 29.6005000, -98.4872400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136538, 'Hondo', 'Hondo', 'Khondo,handw,hwndw,Хондо,هاندو,هوندو', 29.3474600, -99.1414200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136539, 'Honey Grove', 'Honey Grove', 'Honey Grove,Honeygrove', 33.5834400, -95.9099700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136540, 'Hooks', 'Hooks', '', 33.4662300, -94.2885300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136541, 'Hornsby Bend', 'Hornsby Bend', 'Dunlap,Hornsby,Hornsby Bend', 30.2474300, -97.5833300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136542, 'Horseshoe Bay', 'Horseshoe Bay', '', 30.5442900, -98.3739400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136543, 'Houston', 'Houston', 'Chiouston,Gorad Khjustan,HOU,Hiu-su-tun,Hiustonas,Hiû-sṳ̂-tûn,Hjuston,Hjustona,Hjūstona,Houston,Houston City,Hustonia,Hyuston,Kh''juston,Khjust"n,Khjuston,hi''ustana,hiustʼoni,hiws tan,hiyustan,hou si dun,husatana,hyuseuteon,hyustan,hyustana,hyusuton,hywstn,hywstwn,xiu si dun,ywstwn,Χιούστον,Горад Хюстан,Хьюстон,Хюстон,Хюстън,Хјустон,Հյուստոն,היוסטן,יוסטון,هيوستن,هیوستون,ھیووستن,ہywsٹn,ہیوسٹن,ह्युस्टन,হিউস্টন,ਹੂਸਟਨ,હ્યુસ્ટન,ஹியூஸ்டன்,హ్యూస్టన్,ഹ്യൂസ്റ്റൺ,ฮิวสตัน,ဟူစတန်မြို့,ჰიუსტონი,ሂውስተን,ヒューストン,休斯敦,休斯頓,侯斯頓,휴스턴', 29.7632800, -95.3632700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136544, 'Howe', 'Howe', '', 33.5087200, -96.6122100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136545, 'Hubbard', 'Hubbard', '', 31.8484900, -96.7972100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136546, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 31.3226800, -94.7782600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136547, 'Hudson', 'Hudson', '', 29.9024500, -95.5024400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136548, 'Hudson Bend', 'Hudson Bend', '', 30.4171400, -97.9291800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136549, 'Hudson Oaks', 'Hudson Oaks', '', 32.7570700, -97.7067000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136550, 'Hughes Springs', 'Hughes Springs', '', 32.9984600, -94.6307600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136551, 'Humble', 'Humble', 'Ambl,hambl,hambl  tksas,Амбл,هامبل,هامبل، تكساس', 29.9988300, -95.2621600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136552, 'Hunters Creek Village', 'Hunters Creek Village', 'Hunters Creek,Hunters Creek Village', 29.7705100, -95.4955000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136553, 'Huntington', 'Huntington', 'Khantington,Хантингтон', 31.2776900, -94.5765900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136554, 'Huntsville', 'Huntsville', 'Gantsvil'',HTV,Khantsvil,Khantsvill,hantsavhila,hantsfyl,hantswyl,heoncheubil,Гантсвіль,Хантсвил,Хантсвилл,هانتسفيل,هانتسویل,हंट्सव्हिल,헌츠빌', 30.7235300, -95.5507800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136555, 'Hurst', 'Hurst', 'Kherst,hrst  tgzas,hwrst,Херст,هرست، تگزاس,هورست', 32.8234600, -97.1705700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136556, 'Hutchins', 'Hutchins', 'Khachins,hachynz  tgzas,hatshynz,Хачинс,هاتشينز,هاچینز، تگزاس,ഹച്ചിൻസ്', 32.6493000, -96.7130500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136557, 'Hutto', 'Hutto', '', 30.5427000, -97.5466700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136558, 'Indian Hills', 'Indian Hills', '', 26.2128500, -97.9163900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136559, 'Inez', 'Inez', '', 28.9038800, -96.7880400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136560, 'Ingleside', 'Ingleside', 'Inglsajd,anghlsayd,aynglsayd  tgzas,Инглсајд,إنغلسايد,اینگلساید، تگزاس', 27.8778000, -97.2116600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136561, 'Ingram', 'Ingram', '', 30.0774300, -99.2403200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136562, 'Iowa Colony', 'Iowa Colony', '', 29.4824600, -95.4155000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136563, 'Iowa Park', 'Iowa Park', 'Iowa Park,Iowapark', 33.9514800, -98.6686700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136564, 'Irving', 'Irving', '"rving,Erving,Irving,Irvingas,abingu,ayrfyngh,ayrwyng  tgzas,eobing,ou wen,Ірвінг,Ервинг,Ирвинг,Ървинг,ارونگ، ٹیکساس,ايرفينغ,ایروینگ، تگزاس,എർവിങ്,アービング,歐文,어빙', 32.8140200, -96.9488900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136565, 'Italy', 'Italy', 'Houston Creek,Italy', 32.1840400, -96.8847200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136566, 'Itasca', 'Itasca', '', 32.1595900, -97.1500100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136567, 'Jacinto City', 'Jacinto City', '', 29.7674500, -95.2338200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136568, 'Jacksboro', 'Jacksboro', 'Dzeksboro,jaksbwrw,jksbwrw  tgzas,Џексборо,جاكسبورو,جکسبورو، تگزاس,جککسبورو، ٹیکساس', 33.2184500, -98.1586600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136569, 'Jacksonville', 'Jacksonville', 'Dzeksonvil,Dzheksonvill,JKV,jaegseunbil,jakswnfyl,jkswnwyl  tgzas,Џексонвил,Джексонвилл,جاكسونفيل,جکسونویل، تگزاس,جککسونویل، ٹیکساس,잭슨빌', 31.9637800, -95.2705000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136570, 'Jamaica Beach', 'Jamaica Beach', '', 29.1896800, -94.9796500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136571, 'Jarrell', 'Jarrell', '', 30.8249100, -97.6044500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136572, 'Jasper', 'Jasper', 'Dzasper,jasbr,jspr  tgzas,Џаспер,جاسبر,جسپر، تگزاس,جسپر، ٹیکساس', 30.9202000, -93.9965800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136573, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefferson,jfrswn  tgzas,jyfyrswn,Џеферсон,Джефферсон,جفرسون، تگزاس,جيفيرسون', 32.7573600, -94.3451900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136574, 'Jersey Village', 'Jersey Village', '', 29.8877200, -95.5630000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136575, 'Jewett', 'Jewett', '', 31.3615700, -96.1441300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136576, 'Johnson City', 'Johnson City', 'Dzhonson Siti,Dzonson Siti,Kota Johnson,janswn syty  tgzas,jonseunsiti,jwnswn syty,yue han xun cheng,Џонсон Сити,Джонсон Сити,جانسن سٹی، ٹیکساس,جانسون سیتی، تگزاس,جونسون سيتي,约翰逊城,존슨시티', 30.2768700, -98.4119700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136577, 'Jollyville', 'Jollyville', '', 30.4427000, -97.7750100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136578, 'Jones Creek', 'Jones Creek', '', 28.9685800, -95.4552200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136579, 'Jonestown', 'Jonestown', '', 30.4954700, -97.9233500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136580, 'Josephine', 'Josephine', '', 33.0612300, -96.3072000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136581, 'Joshua', 'Joshua', '', 32.4615300, -97.3880700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136582, 'Jourdanton', 'Jourdanton', 'Dzordanton,jwrdantwn,qiao dan dun,Џордантон,جردن‌تاون، تگزاس,جوردانتون,乔丹顿', 28.9180300, -98.5464100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136583, 'Junction', 'Junction', 'Dzankshon,Dzhankshen,jankshn  tgzas,jnkshn,Џанкшон,Джанкшен,جانکشن، تگزاس,جنكشن', 30.4893600, -99.7720100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136584, 'Justin', 'Justin', '', 33.0848400, -97.2961300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136585, 'Karnes City', 'Karnes City', 'Karns Siti,Karns-Siti,karnz syty  tgzas,kyrnz syty,Карнс Сити,Карнс-Сити,Карнс-Сіті,كيرنز سيتي,کارنز سیتی، تگزاس', 28.8849800, -97.9008400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136586, 'Kaufman', 'Kaufman', 'Kaufman,Kings Fort,Kingsboro,Kofman,kafmn  tgzas,kwfman,Кофман,كوفمان,کافمن، تگزاس', 32.5890200, -96.3088700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136587, 'Katy', 'Katy', 'Kejti,katy,kyty  tgzas,Кејти,كاتي,کیتی، تگزاس', 29.7857900, -95.8244000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136588, 'Keene', 'Keene', '', 32.3968100, -97.3239000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136589, 'Keller', 'Keller', 'Keller,Келлер', 32.9345700, -97.2516800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136590, 'Kemah', 'Kemah', 'Evergreen,Kemah,Kima,kyma,kyma  tgzas,Кима,كيما,کیما، تگزاس', 29.5427300, -95.0204800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136591, 'Kemp', 'Kemp', '', 32.4426400, -96.2299800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136592, 'Kenedy', 'Kenedy', '', 28.8191500, -97.8486100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136593, 'Kennedale', 'Kennedale', '', 32.6468000, -97.2258500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136594, 'Kempner', 'Kempner', '', 31.0810100, -98.0025200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136595, 'Kerens', 'Kerens', '', 32.1332100, -96.2277500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136596, 'Kerrville', 'Kerrville', 'ERV,Kervil,krwyl  tgzas,kyrfyl,Кервил,كيرفيل,کرویل، تگزاس', 30.0474300, -99.1403200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136597, 'Kilgore', 'Kilgore', 'Kilgor,kylghwr,kylgwr  tgzas,Килгор,كيلغور,کیلگور، تگزاس', 32.3862600, -94.8757700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136598, 'Killeen', 'Killeen', 'ILE,Kilin,Kilinas,Killean,Killeen,Killin,ji lin,kaylyn  tgzas,killin,kirin,klyn,kylyn,Килин,Киллин,Кіллін,كيلين,کایلین، تگزاس,کلین,کیلین، ٹیکساس,キリーン,基林,킬린', 31.1171200, -97.7278000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136599, 'Kingsland', 'Kingsland', '', 30.6582400, -98.4405800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136600, 'Kingsville', 'Kingsville', 'Kingsvil,NQI,kingseubil,kynghzfyl,kyngzwyl  tgzas,Кингсвил,كينغزفيل,کینگزویل، تگزاس,킹스빌', 27.5158700, -97.8561100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136601, 'Kirby', 'Kirby', '', 29.4632900, -98.3855700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136602, 'Kirbyville', 'Kirbyville', '', 30.6604800, -93.8926800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136603, 'Knox City', 'Knox City', 'Knox City,Orient', 33.4181500, -99.8189800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136604, 'Kountze', 'Kountze', '', 30.3716000, -94.3124100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136605, 'Krugerville', 'Krugerville', '', 33.2815100, -96.9905600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136606, 'Krum', 'Krum', '', 33.2615100, -97.2380700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136607, 'Kyle', 'Kyle', 'Kajl,kayl  tgzas,kyly,Кајл,كيلي,کایل، تگزاس', 29.9891100, -97.8772300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136608, 'La Blanca', 'La Blanca', '', 26.2928500, -98.0377800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136609, 'La Coste', 'La Coste', 'Fernando,La Coste,Lacoste', 29.3107900, -98.8100300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136610, 'La Feria', 'La Feria', 'Arroyo Alto,La Ferija,la fyrya,la fyrya  tgzas,Ла Ферија,لا فيريا,لا فیریا، تگزاس,لا فیریا، ٹیکساس', 26.1589600, -97.8238900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136611, 'La Grange', 'La Grange', 'La Grange,LaGrange,Lagrange', 29.9055000, -96.8766500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136612, 'La Grulla', 'La Grulla', 'Grulla,La Grulla', 26.2695100, -98.6472500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136613, 'La Homa', 'La Homa', '', 26.2500700, -98.3636300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136614, 'La Joya', 'La Joya', 'La Joya,San Pedro de Buena Vista Ranch', 26.2470200, -98.4814100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136615, 'La Marque', 'La Marque', 'Buttermilk Station,Highland,La Marque', 29.3685700, -94.9713100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136616, 'La Paloma', 'La Paloma', '', 26.0459100, -97.6674900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136617, 'La Porte', 'La Porte', 'La Port,la bwrt,la pwrth  tgzas,Ла Порт,لا بورت,لا پورت، ٹیکساس,لا پورته، تگزاس', 29.6657800, -95.0193700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136618, 'La Pryor', 'La Pryor', '', 28.9410800, -99.8497800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136619, 'La Vernia', 'La Vernia', 'La Vernia,Live Oak Grove,Post Oak', 29.3563500, -98.1155600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136620, 'La Villa', 'La Villa', '', 26.2986800, -97.9286100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136621, 'Lacy-Lakeview', 'Lacy-Lakeview', '', 31.6293300, -97.1027800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136622, 'Lago Vista', 'Lago Vista', '', 30.4602000, -97.9883500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136623, 'Laguna Heights', 'Laguna Heights', '', 26.0800800, -97.2538600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136624, 'Laguna Park', 'Laguna Park', '', 31.8593200, -97.3797400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136625, 'Laguna Vista', 'Laguna Vista', '', 26.1009100, -97.2902500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136626, 'Lake Brownwood', 'Lake Brownwood', '', 31.8357000, -99.0078300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136627, 'Lake Dallas', 'Lake Dallas', 'Lejk Dalas,layk dalas,lyk dalas  tgzas,Лејк Далас,لايك دالاس,لیک دالاس، تگزاس,لیک ڈیلاس، ٹیکساس', 33.1192900, -97.0255600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136628, 'Lake Jackson', 'Lake Jackson', 'Lejk DZekson,layk jakswn,lyk jkswn  tgzas,Лејк Џексон,لايك جاكسون,لیک جکسون، تگزاس,لیک جیکسن، ٹیکساس', 29.0338600, -95.4343900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136629, 'Lake Kiowa', 'Lake Kiowa', '', 33.5770500, -97.0130600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136630, 'Lake Dunlap', 'Lake Dunlap', '', 29.6757800, -98.0722300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136631, 'Lake Worth', 'Lake Worth', '', 32.8048500, -97.4450200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136632, 'Lakehills', 'Lakehills', 'Lakehills,Upper Medina Lake', 29.6046700, -98.9430900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136633, 'Lakeside', 'Lakeside', 'LKS', 32.8223500, -97.4933500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136634, 'Lakeway', 'Lakeway', '', 30.3637700, -97.9795900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136635, 'Lampasas', 'Lampasas', 'Lampasas,lambsas,lmpss  tgzas,Лампасас,لامبساس,لمپسس، تگزاس,لیمپاساس، ٹیکساس', 31.0637800, -98.1817000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136636, 'Lancaster', 'Lancaster', 'Lankaster,lankstr,lnkstr  tgzas,Ланкастер,لانكستر,لانکیسٹر، ٹیکساس,لنکستر، تگزاس,ലങ്കാസ്റ്റർ', 32.5920800, -96.7561100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136637, 'Laredo', 'Laredo', 'LRD,Laredo,Laredum,Villa de San Augustine de Laredo,la lei duo,larydw,larydw  tgzas,leoleido,raredo,Ларедо,לארדו,لاريدو,لاریدو، تگزاس,لاریڈو، ٹیکساس,لریڈو,ラレド,拉雷多,러레이도', 27.5064100, -99.5075400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136638, 'Las Lomas', 'Las Lomas', '', 26.3647900, -98.7753000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136639, 'Lasara', 'Lasara', '', 26.4647900, -97.9111100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136640, 'Laureles', 'Laureles', '', 26.1092400, -97.4941500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136641, 'Lavon', 'Lavon', '', 33.0276200, -96.4341500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136642, 'League City', 'League City', 'League City,Lig Siti,lyg syty  tgzas,lygh syty,Лиг Сити,ليغ سيتي,لیگ سٹی، ٹیکساس,لیگ سیتی، تگزاس', 29.5074500, -95.0949300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136643, 'Leakey', 'Leakey', '', 29.7288400, -99.7614500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136644, 'Leander', 'Leander', '', 30.5788100, -97.8530700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136645, 'Leon Valley', 'Leon Valley', '', 29.4952300, -98.6186300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136646, 'Leonard', 'Leonard', '', 33.3795500, -96.2474800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136647, 'Lewisville', 'Lewisville', 'L''juisvill,Lewisville,Luisvil,liu yi si wei er,lu-iseubil,lwysfyl,lwyzwl,ruisubiru,Луисвил,Льюисвилл,لوئیس‌ویل، تگزاس,لويسفيل,لویزول,لیوسویل، ٹیکساس,ലൂയിസ്‌വിൽ,ルイスビル,刘易斯维尔,루이스빌', 33.0462300, -96.9941700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136648, 'Lexington', 'Lexington', 'Leksington,Лексингтон', 30.4191000, -97.0116500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136649, 'Liberty', 'Liberty', 'Atascosito,Liberti,Liberty,Liberty City,Villa De la Sautissima Trinidad de la Libertad,Villa de la Santissima Trinidad de la Libertad,lybrty,lybrty  tgzas,Либерти,ليبرتي,لیبرتی، تگزاس', 30.0579900, -94.7954800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136650, 'Liberty City', 'Liberty City', '', 32.4454300, -94.9485500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136651, 'Liberty Hill', 'Liberty Hill', 'Liberty Hill,Libertyhill', 30.6649100, -97.9225200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136652, 'Lindale', 'Lindale', '', 32.5157000, -95.4094000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136653, 'Linden', 'Linden', 'Linden,lyndn,lyndn  tgzas,Линден,ليندن,لیندن، تگزاس', 33.0123500, -94.3654700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136654, 'Lindsay', 'Lindsay', '', 33.6359400, -97.2227900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136655, 'Little Elm', 'Little Elm', 'Litl Elm,lytl alm,lytl alm  tgzas,Литл Елм,ليتل إلم,لیتل الم، تگزاس,ലിറ്റിൽ എൽമ്', 33.1626200, -96.9375100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136656, 'Little River-Academy', 'Little River-Academy', 'Academy,Little River,Little River-Academy', 30.9862900, -97.3586100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136657, 'Live Oak', 'Live Oak', '', 29.5652300, -98.3364000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136658, 'Livingston', 'Livingston', 'Livingston,lyfynghstn,lywyngstn  tgzas,rivu~ingusuton,Ливингстон,ليفينغستن,لیونگسٹن، ٹیکساس,لیوینگستن، تگزاس,リヴィングストン', 30.7110300, -94.9329900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136659, 'Llano', 'Llano', 'Lano,lanw,lanw  tgzas,Лано,لانو,لانو، تگزاس', 30.7593500, -98.6750400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136660, 'Llano Grande', 'Llano Grande', '', 26.1298000, -97.9680600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136661, 'Lockhart', 'Lockhart', 'Lockhart,Lokkhart,Plum Creek,lakhart  tgzas,lwkhart,Локхарт,لاکهارت، تگزاس,لوكهارت', 29.8849400, -97.6700000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136662, 'Lone Star', 'Lone Star', '', 33.7856600, -95.3877300, 'US', '2012-05-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136663, 'Lone Star', 'Lone Star', 'Iron Bluff,Lone Star', 32.9440200, -94.7071500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136664, 'Longview', 'Longview', 'GGG,Longv''ju,Longview,Longvju,lang wei you,langwyw  tgzas,longbyu,lwnghfyw,lwngwyw,rongubyu,Лонгвью,Лонгвю,Лонгвју,لانگویو، تگزاس,لونغفيو,لونگویئو، ٹیکساس,لونگویو,ロングビュー,朗維尤,롱뷰', 32.5007000, -94.7404900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136665, 'Lopezville', 'Lopezville', '', 26.2381300, -98.1597300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136666, 'Lorena', 'Lorena', '', 31.3865600, -97.2155600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136667, 'Los Fresnos', 'Los Fresnos', '', 26.0717400, -97.4763700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136668, 'Los Indios', 'Los Indios', '', 26.0492400, -97.7449900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136669, 'Lost Creek', 'Lost Creek', '', 30.2954800, -97.8444500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136670, 'Lowry Crossing', 'Lowry Crossing', 'Biggers,Lowry Crossing', 33.1548400, -96.5472100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136671, 'Lucas', 'Lucas', '', 33.0842900, -96.5766600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136672, 'Lufkin', 'Lufkin', 'LFK,Lafkin,la fu jin,lwfkyn,lwfkyn  tgzas,Лафкин,لوفكين,لوفکین، تگزاس,拉夫金', 31.3382400, -94.7291000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136673, 'Luling', 'Luling', 'Luling,lwlyng  tgzas,lwlyngh,Лулинг,لولينغ,لولینگ، تگزاس', 29.6805100, -97.6475000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136674, 'Lumberton', 'Lumberton', 'Ariola,Chance,Fletcher,Hooks Switch,Lumberton,Sharon', 30.2657700, -94.1996300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136675, 'Lyford', 'Lyford', '', 26.4122900, -97.7897200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136676, 'Lytle', 'Lytle', 'Coal Mine,Lytle', 29.2332900, -98.7964100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136677, 'Mabank', 'Mabank', '', 32.3665300, -96.1008100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136678, 'Madisonville', 'Madisonville', '', 30.9499100, -95.9116200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136679, 'Magnolia', 'Magnolia', '', 30.2093800, -95.7507800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136680, 'Malakoff', 'Malakoff', '', 32.1696000, -96.0124700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136681, 'Manchaca', 'Manchaca', '', 30.1407700, -97.8330600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136682, 'Manor', 'Manor', '', 30.3407600, -97.5569500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136683, 'Mansfield', 'Mansfield', 'Mansfeild,Mansfield,Mehnsfild,Mensfild,mansfyld,mnsfyld  tgzas,Менсфилд,Мэнсфилд,مانسفيلد,منسفیلد، تگزاس,مینسفیلڈ، ٹیکساس', 32.5631900, -97.1416800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136684, 'Manvel', 'Manvel', '', 29.4627400, -95.3579900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136685, 'Marble Falls', 'Marble Falls', 'Marbl Fols,marbl fals  tgzas,marbl fwlz,Марбл Фолс,ماربل فالس، تگزاس,ماربل فولز', 30.5784100, -98.2750700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136686, 'Marion', 'Marion', 'Mehrion,Мэрион', 29.5713400, -98.1402900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136687, 'Markham', 'Markham', '', 28.9602600, -96.0652400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136688, 'Marlin', 'Marlin', 'Marlin,marlyn,marlyn  tgzas,Марлин,مارلين,مارلین، تگزاس', 31.3062900, -96.8980400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136689, 'Marshall', 'Marshall', 'ASL,Marshal,Marshall,ma xie er,marshal,marshal  tgzas,masharu,masyeol,Маршал,Маршалл,مارشال,مارشال، تگزاس,مارشل، ٹیکساس,マーシャル,马歇尔,마셜', 32.5448700, -94.3674200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136690, 'Mart', 'Mart', '', 31.5423900, -96.8336000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136691, 'Martindale', 'Martindale', '', 29.8455000, -97.8408400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136692, 'Mason', 'Mason', 'Mejson,maswn,mysn  tgzas,Мейсон,Мејсон,ماسون,میسن، تگزاس,میسن، ٹیکساس', 30.7487900, -99.2306100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136693, 'Mathis', 'Mathis', '', 28.0944600, -97.8280500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136694, 'Maud', 'Maud', '', 33.3329000, -94.3427000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136695, 'Mauriceville', 'Mauriceville', '', 30.2035400, -93.8662800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136696, 'McAllen', 'McAllen', 'MFE,Mak-Allen,Makalen,McAllen,maekaelleon,mai ka lun,makalyn,makkaren,Мак-Аллен,Макален,מקאלן,ماكالين,مک ایلن، ٹیکساس,مک‌آلن,マッカレン,麦卡伦,매캘런', 26.2034100, -98.2300100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136697, 'McGregor', 'McGregor', '', 31.4440600, -97.4091800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136698, 'McKinney', 'McKinney', 'Mak-Kinni,Makini,McKinney,maekini,mai jin ni,makkini,makkinni,makkyny,Мак-Кинни,Мак-Кінні,Макини,ماككيني,مک کینی، ٹیکساس,مک‌کینی، تگزاس,മക്കിന്നി,マッキニー,麥金尼,매키니', 33.1976200, -96.6152700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136699, 'McLendon-Chisholm', 'McLendon-Chisholm', 'Chisholm,McLendon,McLendon-Chisholm', 32.8423500, -96.3805400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136700, 'McQueeney', 'McQueeney', '', 29.5921700, -98.0333400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136701, 'Meadowlakes', 'Meadowlakes', '', 30.5624500, -98.2986700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136702, 'Meadows Place', 'Meadows Place', 'Meadows,Meadows Place', 29.6513400, -95.5880000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136703, 'Medina', 'Medina', 'Medina,Медина', 29.7966100, -99.2464300, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136704, 'Medina', 'Medina', '', 26.9211500, -99.2594800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136705, 'Melissa', 'Melissa', '', 33.2859500, -96.5727700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136706, 'Menard', 'Menard', 'Menard,mo na de,mynard,mynrd  tgzas,Менард,مينارد,مینرد، تگزاس,默纳德', 30.9176700, -99.7864600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136707, 'Mercedes', 'Mercedes', '', 26.1498000, -97.9136100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136708, 'Meridian', 'Meridian', 'Meridian,Меридиан', 31.9232100, -97.6566900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136709, 'Mesquite', 'Mesquite', 'Meskit,Meskvit,Mesquite,mei si ji te,meseukiteu,meskvirr,mesukito,mskyt  tgzas,mwskw,Месквіт,Мескит,مسکیت، تگزاس,مسکیٹ، ٹیکساس,موسكو,میسکوٹ,മെസ്ക്വിറ്റ്,メスキート,梅斯基特,메스키트', 32.7668000, -96.5991600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136710, 'Mexia', 'Mexia', 'Mekheja,mahya,mhya  tgzas,Мехеја,ماهيا,مهیا، تگزاس', 31.6798900, -96.4822000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136711, 'Midlothian', 'Midlothian', 'Midlothian,Midlotijan,mydlwdhyan,mydlwtyn  tgzas,Мидлотијан,ميدلوذيان,میدلوتین، تگزاس', 32.4823600, -96.9944500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136712, 'Midway North', 'Midway North', 'Midway North', 26.1877600, -98.0170800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136713, 'Midway South', 'Midway South', 'Midway South', 26.1569400, -98.0201100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136714, 'Mila Doce', 'Mila Doce', '', 26.2261800, -97.9588900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136715, 'Milam', 'Milam', '', 31.4324000, -93.8457400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136716, 'Mineola', 'Mineola', 'Miniola,mynywla,mynywla  tgzas,Миниола,مينيولا,مینیولا، تگزاس', 32.6631900, -95.4882900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136717, 'Mineral Wells', 'Mineral Wells', 'MWL,Mineral Vels,Mineral Wells,Mineralwells,minelal-welseu,mynral wlz  tgzas,mynyral wylz,Минерал Велс,مينيرال ويلز,مینرال ولز، تگزاس,미네랄웰스', 32.8084600, -98.1128200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136718, 'Mission', 'Mission', 'Mishon,Missija,Mission,mi shen,misshon,myshn  tgzas,Миссия,Мишон,میشن، تگزاس,ミッション,米申', 26.2159100, -98.3252900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136719, 'Mission Bend', 'Mission Bend', '', 29.6938400, -95.6649500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136720, 'Missouri City', 'Missouri City', 'Missouri City,Misuri Siti,mi su li cheng,misari sirri,myswry syty,myzwry‌syty  tgzas,Мисури Сити,مسوری سٹی، ٹیکساس,ميسوري سيتي,میزوری‌سیتی، تگزاس,മിസൗറി സിറ്റി,密蘇里城', 29.6185700, -95.5377200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136721, 'Mont Belvieu', 'Mont Belvieu', '', 29.8477200, -94.8907600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136722, 'Montague', 'Montague', '', 33.6648300, -97.7205900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136723, 'Monte Alto', 'Monte Alto', '', 26.3731200, -97.9716700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136724, 'Moody', 'Moody', '', 31.3082300, -97.3614000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136725, 'Morgans Point Resort', 'Morgans Point Resort', 'Morgan''s Point Resort,Morgans Point Resort', 31.1482300, -97.4633400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136726, 'Mount Pleasant', 'Mount Pleasant', 'Maunt Plezant,mawnt blyzant,mawnt plznt  tgzas,Маунт Плезант,ماونت بليزانت,ماونت پلزنت، تگزاس', 33.1567900, -94.9682700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136727, 'Mount Vernon', 'Mount Vernon', 'Keith''s,Keiths,Lone Star,Maunt Vernon,Mount Vernon,mwnt fyrnwn,mwnt wrnn  tgzas,Маунт Вернон,ماؤنٹ ورنن، ٹیکساس,مونت فيرنون,مونت ورنن، تگزاس', 33.1887300, -95.2213300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136728, 'Muenster', 'Muenster', '', 33.6517700, -97.3764100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136729, 'Munday', 'Munday', '', 33.4492600, -99.6228600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136730, 'Muniz', 'Muniz', '', 26.2564600, -98.0894500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136731, 'Murillo Colonia', 'Murillo Colonia', 'Murillo Colonia,Murillo Subdivision Colonia,Nurillo', 26.2564600, -98.1133400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136732, 'Murphy', 'Murphy', '', 33.0151200, -96.6130500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136733, 'Nacogdoches', 'Nacogdoches', 'Nacodoches,Nacogdoches,Nakodoches,OCH,nakwdwchz  tgzas,nakwghdwshs,Накодочес,ناكوغدوشس,ناکودوچز، تگزاس', 31.6035100, -94.6554900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136734, 'Naples', 'Naples', 'Neapol'',Неаполь', 33.2031800, -94.6802100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136735, 'Nash', 'Nash', '', 33.4423500, -94.1307500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136736, 'Nash', 'Nash', '', 32.2657000, -96.8127700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136737, 'Nassau Bay', 'Nassau Bay', '', 29.5446800, -95.0910400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136738, 'Navasota', 'Navasota', 'Navasota,Nolansville', 30.3879800, -96.0877300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136739, 'Nederland', 'Nederland', 'Niderland,nydrland,nydrlnd  tgzas,Нидерланд,نيدرلاند,نیدرلند، تگزاس', 29.9743800, -93.9924000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136740, 'Needville', 'Needville', 'Needville,Schendelville', 29.3994100, -95.8377300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136741, 'Nevada', 'Nevada', 'Nevada,Невада', 33.0423400, -96.3738700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136742, 'New Boston', 'New Boston', 'Nju Boston,nyw bwstn,nyw bwstwn  tgzas,Њу Бостон,نيو بوسطن,نیو بوستون، تگزاس', 33.4598400, -94.4154800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136743, 'New Braunfels', 'New Braunfels', 'N''ju-Braunfels,Nju Bronfels,nyuburonferuzu,nyw branflz  tgzas,nyw brawnfylz,xin bu lang fei er si,Њу Бронфелс,Нью-Браунфелс,نيو براونفيلز,نیو برانفلز، تگزاس,نیو براونفیلز، ٹیکساس,ニューブローンフェルズ,新布朗費爾斯', 29.7030000, -98.1244500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136744, 'New Summerfield', 'New Summerfield', '', 31.9807200, -95.0938300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136745, 'New Territory', 'New Territory', '', 29.5941200, -95.6807800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136746, 'New Waverly', 'New Waverly', '', 30.5377000, -95.4832800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136747, 'Newark', 'Newark', 'N''juark,Ньюарк', 33.0012400, -97.4844700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136748, 'Newton', 'Newton', 'N''juton,Ньютон', 30.8485300, -93.7574000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136749, 'Nixon', 'Nixon', '', 29.2674600, -97.7644400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136750, 'Nocona', 'Nocona', 'Noccona,Nocona', 33.7867700, -97.7258600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136751, 'Nolanville', 'Nolanville', '', 31.0787900, -97.6055700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136752, 'North Alamo', 'North Alamo', '', 26.2173000, -98.1289000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136753, 'North Richland Hills', 'North Richland Hills', '', 32.8343000, -97.2289000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136754, 'Northcliff', 'Northcliff', '', 29.6210600, -98.2247300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136755, 'Northcrest', 'Northcrest', '', 31.6365500, -97.0997200, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136756, 'Northlake', 'Northlake', '', 33.1273400, -97.2655700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136757, 'Nurillo', 'Nurillo', '', 26.2670200, -98.1214000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136758, 'Oak Leaf', 'Oak Leaf', '', 32.5204200, -96.8547200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136759, 'Oak Point', 'Oak Point', '', 33.1901200, -96.9916700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136760, 'Oak Ridge North', 'Oak Ridge North', '', 30.1602200, -95.4443800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136761, 'Oak Trail Shores', 'Oak Trail Shores', '', 32.4887500, -97.8342000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136762, 'Odem', 'Odem', '', 27.9505700, -97.5822200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136763, 'Old River-Winfree', 'Old River-Winfree', 'Old River Winfree,Old River-Winfree,Oldriver Winfrees,Winfree', 29.8682800, -94.8327000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136764, 'Olivarez', 'Olivarez', '', 26.2284100, -97.9922300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136765, 'Olmito', 'Olmito', '', 26.0217400, -97.5341500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136766, 'Olmos Park', 'Olmos Park', '', 29.4788400, -98.4875200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136767, 'Olney', 'Olney', 'ONY,Olni,Олни', 33.3706600, -98.7528400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136768, 'Onalaska', 'Onalaska', '', 30.8057500, -95.1163300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136769, 'Onion Creek', 'Onion Creek', '', 30.1366000, -97.7841700, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136770, 'Orange', 'Orange', 'Green''s Bluff,Greens Bluff,Huntley,Jefferson,Madison,Orange,Strongs Bluff', 30.0929900, -93.7365500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136771, 'Orange Grove', 'Orange Grove', '', 27.9566800, -97.9369400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136772, 'Ore City', 'Ore City', '', 32.8001400, -94.7207600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136773, 'Overton', 'Overton', 'Overton,awfrtwn,awwrtwn  tgzas,Овертон,اوفرتون,اوورتون، تگزاس,اوورٹن، ٹیکساس', 32.2746000, -94.9785500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136774, 'Ovilla', 'Ovilla', '', 32.5265300, -96.8863900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136775, 'Oyster Creek', 'Oyster Creek', '', 29.0030200, -95.3318800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136776, 'Paint Rock', 'Paint Rock', 'Paint Rock,Paintrock', 31.5084900, -99.9200800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136777, 'Palacios', 'Palacios', 'PSX', 28.7080500, -96.2174700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136778, 'Palestine', 'Palestine', 'Palestin,flstyn,pa lei si tan,palleseutain,plstayn  tgzas,Палестин,Палестін,فلسطين,فلسطین، ٹیکساس,پلستاین، تگزاس,帕勒斯坦,팔레스타인', 31.7621200, -95.6307900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136779, 'Palm Valley', 'Palm Valley', '', 26.2017400, -97.7541600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136780, 'Palmer', 'Palmer', '', 32.4312500, -96.6677700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136781, 'Palmhurst', 'Palmhurst', '', 26.2584100, -98.3180700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136782, 'Palmview', 'Palmview', '', 26.2334100, -98.3708500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136783, 'Palmview South', 'Palmview South', 'Palmview South', 26.2156300, -98.3786300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136784, 'Palo Pinto', 'Palo Pinto', 'Palo Pinto,Palopinto', 32.7673500, -98.2986600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136785, 'Panorama Village', 'Panorama Village', '', 30.3810400, -95.4935500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136786, 'Pantego', 'Pantego', '', 32.7143000, -97.1564000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136787, 'Paris', 'Paris', 'PRX,Paris,Parizh,barys,parys  tgzas,Париж,Парис,Փարիզ,باريس,پاریس، تگزاس,پیرس، ٹیکساس', 33.6609400, -95.5555100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136788, 'Parker', 'Parker', 'Parker,Паркер', 33.0554000, -96.6219400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136789, 'Pasadena', 'Pasadena', 'Pasadena,Pasadina,basadyna,pa sa di na,paeseodina,pasadena,pasadna  tgzas,Пасадена,Пасадина,باسادينا,پاسادنا، تگزاس,パサデナ,帕薩迪納,패서디나', 29.6910600, -95.2091000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136790, 'Patton Village', 'Patton Village', '', 30.1929900, -95.1688200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136791, 'Pearland', 'Pearland', 'Pehrlend,Perland,byrland,pyr lnd  tgzas,Перланд,Пэрленд,بيرلاند,پئیرلینڈ، ٹیکساس,پیر لند، تگزاس', 29.5635700, -95.2860500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136792, 'Pearsall', 'Pearsall', '', 28.8921900, -99.0950300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136793, 'Pecan Acres', 'Pecan Acres', '', 32.9701300, -97.4747400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136794, 'Pecan Grove', 'Pecan Grove', '', 29.6260700, -95.7316200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136795, 'Pecan Plantation', 'Pecan Plantation', '', 32.3604200, -97.6755800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136796, 'Pelican Bay', 'Pelican Bay', '', 32.9209600, -97.5183600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136797, 'Penitas', 'Penitas', '', 26.2306300, -98.4447400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136798, 'Perezville', 'Perezville', '', 26.2245200, -98.4005700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136799, 'Pflugerville', 'Pflugerville', 'Flugervil,bflwghrfyl,flagrwyl  tgzas,Флугервил,بفلوغرفيل,فلاگرویل، تگزاس,فلوگیرویل، ٹیکساس', 30.4393700, -97.6200000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136800, 'Pharr', 'Pharr', 'Far,Farra,far,far  tgzas,Фар,Фарра,فار,فار، تگزاس,فار، ٹیکساس', 26.1948000, -98.1836200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136801, 'Pilot Point', 'Pilot Point', 'Pilot Point,Pilotpoint', 33.3965000, -96.9605600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136802, 'Pine Island', 'Pine Island', '', 30.0580000, -96.0374600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136803, 'Pinehurst', 'Pinehurst', '', 30.1710500, -95.6824500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136804, 'Pinehurst', 'Pinehurst', '', 30.1071500, -93.7746100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136805, 'Pinewood Estates', 'Pinewood Estates', '', 30.1643800, -94.3215800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136806, 'Piney Point Village', 'Piney Point Village', 'Pajni Pojnt Vilidz,Piney Point,Piney Point Village,byny bwynt fylyj,payny pwynt wylyj  tgzas,Пајни Појнт Вилиџ,بيني بوينت فيليج,پاینی پوینت ویلیج، تگزاس', 29.7599500, -95.5171600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136807, 'Pittsburg', 'Pittsburg', 'Pitsburg,bytsbwrgh,pytsbrg  tgzas,Питсбург,بيتسبورغ,پیتسبرگ، تگزاس', 32.9954000, -94.9657700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136808, 'Plano', 'Plano', 'Planas,Planom,Plejno,Plejnou,blanw,peulleino,planw,plenea,pleno,plynw,pu lai nuo,pureino,Планом,Плейно,Плейноу,Плејно,פלאנו,بلانو,پلانو,پلانو، ٹیکساس,پلینو,प्लेनो,പ്ലേനോ,プレイノ,普莱诺,플레이노', 33.0198400, -96.6988900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136809, 'Pleak', 'Pleak', '', 29.4891300, -95.8077300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136810, 'Pleasanton', 'Pleasanton', 'Pleasanton,Pleasantown,Plezantun,Плезантън', 28.9671900, -98.4786300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136811, 'Plum Grove', 'Plum Grove', '', 32.1957000, -96.9894500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136812, 'Ponder', 'Ponder', '', 33.1829000, -97.2872400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136813, 'Port Aransas', 'Port Aransas', 'Port Aranzas,bwrt aransas,pwrt aransas  tgzas,Порт Аранзас,بورت أرانساس,پورت آرانساس، تگزاس', 27.8339200, -97.0611000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136814, 'Port Arthur', 'Port Arthur', 'BPT,Port Arthur,Port Arthur i Texas,Port Artur,Port-Artur,a se gang,bwrt arthr,poteuaseo,potoasa,pwrt artr  tgzas,Порт Артур,Порт-Артур,Պորտ-Արտուր,بورت أرثر,پورت آرتر، تگزاس,پورٹ آرتھر، ٹیکساس,ポートアーサー,阿瑟港,포트아서', 29.8851900, -93.9423300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136815, 'Port Isabel', 'Port Isabel', 'Port Izabel,bwrt ayzabyl,pwrt ayzabl  tgzas,Порт Изабел,بورت إيزابيل,پورت ایزابل، تگزاس', 26.0734100, -97.2085800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136816, 'Port Lavaca', 'Port Lavaca', 'Port Lavaka,bwrt lafaka,la wa ka gang,potorabaka,pwrt lawaka  tgzas,Порт Лавака,بورت لافاكا,پورت لاواکا، تگزاس,ポートラバカ,拉瓦卡港', 28.6150000, -96.6260900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136817, 'Port Neches', 'Port Neches', 'Grigsby Bluff,Grigsby''s Bluff,Port Neches', 29.9913200, -93.9585100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136818, 'Port O''Connor', 'Port O''Connor', 'Port O''Conner,Port O''Connor', 28.4483400, -96.4058100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136819, 'Porter Heights', 'Porter Heights', '', 30.1518800, -95.3218800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136820, 'Portland', 'Portland', 'Portland,Portlend,bwrtland,pwrtlnd  tgzas,Портланд,Портленд,بورتلاند,پورتلند، تگزاس,پورٹلینڈ، ٹیکساس', 27.8772500, -97.3238800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136821, 'Poteet', 'Poteet', '', 29.0405200, -98.5680700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136822, 'Poth', 'Poth', 'Marcelina,Poth', 29.0696900, -98.0819500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136823, 'Potosi', 'Potosi', '', 32.3293000, -99.6564700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136824, 'Pottsboro', 'Pottsboro', '', 33.7592700, -96.6694400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136825, 'Powderly', 'Powderly', '', 33.8112200, -95.5244000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136826, 'Prairie View', 'Prairie View', 'Prairie View,Prairieview', 30.0932700, -95.9877300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136827, 'Premont', 'Premont', '', 27.3605900, -98.1236200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136828, 'Preston', 'Preston', '', 33.8823200, -96.6330500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136829, 'Primera', 'Primera', '', 26.2259100, -97.7580500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136830, 'Princeton', 'Princeton', 'Prinston,brynstwn,prynstwn  tgzas,Принстон,برينستون,پرنسٹن، ٹیکساس,پرینستون، تگزاس,പ്രിൻസ്ടൺ', 33.1801200, -96.4980400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136831, 'Progreso', 'Progreso', '', 26.0923000, -97.9572200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136832, 'Prosper', 'Prosper', '', 33.2362300, -96.8011100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136833, 'Quanah', 'Quanah', 'Kvona,kwana,kwanah  tgzas,Квона,كوانا,کواناه، تگزاس', 34.2978500, -99.7403700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136834, 'Queen City', 'Queen City', '', 33.1487400, -94.1501900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136835, 'Quinlan', 'Quinlan', '', 32.9104000, -96.1355300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136836, 'Quitman', 'Quitman', 'Kvitman,kwiteumeon,kwytman,kwyytmn  tgzas,Квитман,كويتمان,کوئیتمن، تگزاس,퀴트먼', 32.7959600, -95.4510600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136837, 'Rancho Alegre', 'Rancho Alegre', '', 27.7416900, -98.0947300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136838, 'Rancho Viejo', 'Rancho Viejo', '', 26.0395200, -97.5563800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136839, 'Ranger', 'Ranger', 'RGR', 32.4698500, -98.6789500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136840, 'Raymondville', 'Raymondville', 'Rejmondvil,raymwndfyl,rymndwyl  tgzas,Рејмондвил,رايموندفيل,ریمندویل، تگزاس', 26.4814600, -97.7830500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136841, 'Red Lick', 'Red Lick', 'Red Lick,Redlick', 33.4648500, -94.1710300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136842, 'Red Oak', 'Red Oak', 'Red Oak,Redoak', 32.5176400, -96.8044400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136843, 'Redland', 'Redland', '', 31.4043500, -94.7213200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136844, 'Redwater', 'Redwater', 'Ingersoll,Redwater', 33.3581800, -94.2543600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136845, 'Redwood', 'Redwood', '', 29.8102200, -97.9113900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136846, 'Refugio', 'Refugio', 'RFG', 28.3052800, -97.2752700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136847, 'Rendon', 'Rendon', '', 32.5762500, -97.2414000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136848, 'Reno', 'Reno', 'Rino,Рино', 33.6631600, -95.4624500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136849, 'Reno', 'Reno', 'Rino,Рино', 32.9442900, -97.5772500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136850, 'Rhome', 'Rhome', 'Prairie Point,Rhome,Rome', 33.0534600, -97.4719700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136851, 'Ricardo', 'Ricardo', 'Ricardo,Richard', 27.4214300, -97.8511100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136852, 'Richardson', 'Richardson', 'Ricardsonas,Richardson,Ričardsonas,licheodeuseun,richadoson,rychardswn  tgzas,rytshardswn,Ричардсон,Річардсон,ريتشاردسون,رچرڈسن,ریچاردسون، تگزاس,റിച്ചാർഡ്സൺ,リチャードソン,리처드슨', 32.9481800, -96.7297200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136853, 'Richland Hills', 'Richland Hills', '', 32.8159600, -97.2280700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136854, 'Richmond', 'Richmond', 'Richmond,lichimeondeu,rychmand  tgzas,rytshmwnd,Ричмонд,ريتشموند,رچمنڈ، ٹیکساس,ریچماند، تگزاس,리치먼드', 29.5821800, -95.7607800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136855, 'Richwood', 'Richwood', 'Richwood,Richwood Village', 29.0560800, -95.4099400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136856, 'Riesel', 'Riesel', 'Prospect,Riesel', 31.4748900, -96.9233300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136857, 'Rio Bravo', 'Rio Bravo', '', 27.3641900, -99.4800400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136858, 'Rio Grande City', 'Rio Grande City', 'Rio Grande City,Rio Grandi Siti,Riogrande,ryw ghrandy syty,ryw grand syty  tgzas,Рио Гранди Сити,ريو غراندي سيتي,ریو گراند سیتی، تگزاس', 26.3797900, -98.8203000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136859, 'Rio Hondo', 'Rio Hondo', '', 26.2353500, -97.5819300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136860, 'River Oaks', 'River Oaks', '', 32.7770700, -97.3944600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136861, 'Roanoke', 'Roanoke', 'Roanok,lo-eonokeu,rnk  tgzas,rwnwk,Роанок,رنک، تگزاس,رونوك,로어노크', 33.0040100, -97.2258500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136862, 'Robinson', 'Robinson', '', 31.4676700, -97.1147200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136863, 'Robstown', 'Robstown', 'Robstaun,rabztawn  tgzas,rwbstawn,Робстаун,رابزتاون، تگزاس,روبستاون', 27.7903000, -97.6688800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136864, 'Rockdale', 'Rockdale', '', 30.6554800, -97.0013700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136865, 'Rockwall', 'Rockwall', 'Rokvol,rakwal  tgzas,rwkwwl,Роквол,راکوال، تگزاس,روكوول', 32.9312300, -96.4597100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136866, 'Rockport', 'Rockport', 'RKP,Rokport,luo ke bo te,rakprt  tgzas,rwkbwrt,Рокпорт,راکپرت، تگزاس,راکپورٹ، ٹیکساس,روكبورت,罗克波特', 28.0207700, -97.0560100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136867, 'Rogers', 'Rogers', 'Rodzhers,Роджерс', 30.9315700, -97.2266600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136868, 'Rollingwood', 'Rollingwood', '', 30.2768700, -97.7911200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136869, 'Roman Forest', 'Roman Forest', '', 30.1791000, -95.1624300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136870, 'Roma-Los Saenz', 'Roma-Los Saenz', 'Los Saenz,Roma,Roma-Los Saenz', 26.4050600, -99.0158600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136871, 'Rosebud', 'Rosebud', '', 31.0729600, -96.9786000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136872, 'Rosenberg', 'Rosenberg', 'Rozenberg,rwznbrg  tgzas,rwznbrgh,Розенберг,روزنبرغ,روزنبرگ، تگزاس', 29.5571800, -95.8085600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136873, 'Rosharon', 'Rosharon', 'Masterson Switch,Rosharon', 29.3521800, -95.4602200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136874, 'Round Rock', 'Round Rock', 'Raund Rok,Raund Rokas,Raund-Rok,Round Rock,Roundrock,lang de luo ke,laundeu log,rand rak  tgzas,raundorokku,rawnd rwks,Раунд Рок,Раунд-Рок,راؤنڈ راک، ٹیکساس,راند راک، تگزاس,راوند روكس,ラウンドロック,朗德羅克,라운드 록', 30.5082600, -97.6789000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136875, 'Rowlett', 'Rowlett', 'Rowlett,Rowlette', 32.9029000, -96.5638800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136876, 'Royse City', 'Royse City', '', 32.9751200, -96.3324800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136877, 'Runaway Bay', 'Runaway Bay', '', 33.1678900, -97.8783700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136878, 'Runge', 'Runge', '', 28.8833100, -97.7130500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136879, 'Rusk', 'Rusk', 'Rask,rask  tgzas,rwsk,Раск,راسک، تگزاس,روسك', 31.7960100, -95.1502200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136880, 'Sabinal', 'Sabinal', 'Hammer''s Station,Sabinal', 29.3174600, -99.4664400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136881, 'Sachse', 'Sachse', 'Saksi,saks,satshs,sych  tgzas,Сакси,ساتشس,سچسے، ٹیکساس,سیچ، تگزاس,സക്സ്', 32.9762300, -96.5952700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136882, 'Saginaw', 'Saginaw', 'Sagino,sgyna  tgzas,sjynaw,Сагино,سجيناو,سگینؤ، ٹیکساس,سگینا، تگزاس', 32.8601300, -97.3639100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136883, 'Saint Hedwig', 'Saint Hedwig', 'Cottage Hill,Saint Hedwig', 29.4144000, -98.2000100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136884, 'Saint Jo', 'Saint Jo', '', 33.6948300, -97.5225200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136885, 'Saint Paul', 'Saint Paul', '', 33.0412300, -96.5502700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136886, 'Salado', 'Salado', 'Salado,saladw,saladw  tgzas,Саладо,سالادو,سالادو، تگزاس', 30.9471300, -97.5386200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136887, 'Sam Rayburn', 'Sam Rayburn', '', 31.0640800, -94.0357500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136888, 'San Antonio', 'San Antonio', 'Gorad San-Antonia,SAT,San Antonijus,San Antonio,San Antonio de Bejar,San Antoniyo,San Antònio,San-Antonio,Sanantonio,Sanctus Antonius,can antoniyo,saen-antonio,saina entoniyo,san antoniyo,san antwnyw,san''antonio,san-antʼonio,sana antoni''o,sena amtoniyo,sheng an dong ni ao,Σαν Αντόνιο,Горад Сан-Антоніа,Сан Антонио,Сан-Антонио,Сан-Антоніо,Սան Անտոնիո,סאן אנטאניא,סן אנטוניו,سان آنتونیو,سان أنطونيو,سان انٹونیو,सॅन अँटोनियो,सैन एन्टोनियो,স্যান অ্যান্টোনিও,ਸਾਨ ਆਂਤੋਨੀਓ,சான் அந்தோனியோ,శాన్ అంటోనియో,സാൻ അന്റോണിയോ,แซนแอนโทนีโอ,სან-ანტონიო,サンアントニオ,圣安东尼奥,聖安東尼奧,샌안토니오', 29.4241200, -98.4936300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136889, 'San Augustine', 'San Augustine', 'San Ogastin,San-Ogastin,sn agwstyn  tgzas,Сан Огастин,Сан-Огастин,سن آگوستین، تگزاس', 31.5299000, -94.1060300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136890, 'San Benito', 'San Benito', 'San Benito,san bnytw,sn bnytw  tgzas,Сан Бенито,سان بنيتو,سن بنیتو، تگزاس', 26.1325800, -97.6311000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136891, 'San Carlos', 'San Carlos', 'San - Karlos,Сан - Карлос', 26.2956300, -98.0719500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136892, 'San Diego', 'San Diego', 'San-Diego,Сан-Диего', 27.7639100, -98.2389000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136893, 'San Juan', 'San Juan', '', 26.1892400, -98.1552900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136894, 'San Leon', 'San Leon', 'San Leon,San León,San Lion,Сан Лион', 29.4832900, -94.9221500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136895, 'San Marcos', 'San Marcos', 'San Markos,San-Markos,san markws,sanmarukosu,sheng ma ke si,sn markws  tgzas,Сан Маркос,Сан-Маркос,سان ماركوس,سان مارکوس، ٹیکساس,سن مارکوس، تگزاس,サンマルコス,聖馬科斯', 29.8832700, -97.9413900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136896, 'San Saba', 'San Saba', 'San Saba,san saba,san sba  tgzas,sheng sa ba,Сан Саба,سان سابا,سان سبا، تگزاس,圣萨巴', 31.1957200, -98.7181000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136897, 'Sanger', 'Sanger', 'Sanger,sanghr,sngr  tgzas,Сангер,سانغر,سنگر، تگزاس', 33.3631700, -97.1739000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136898, 'Sansom Park', 'Sansom Park', 'Sansom Park,Sansom Park Village', 32.8059600, -97.4030700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136899, 'Santa Anna', 'Santa Anna', '', 31.7420900, -99.3217300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136900, 'Santa Fe', 'Santa Fe', 'Alta Loma,Alto Loma,Arcadia,Santa Fe,Santa-Fe,santa fay,snta fh  tgzas,Санта Фе,Санта-Фе,سانتا فاي,سانتا فے، ٹیکساس,سنتا فه، تگزاس', 29.3780100, -95.1057600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136901, 'Santa Rosa', 'Santa Rosa', 'Santa-Rosa,Санта-Роса', 26.2567400, -97.8250000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136902, 'Sarita', 'Sarita', '', 27.2217100, -97.7891600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136903, 'Scenic Oaks', 'Scenic Oaks', '', 29.7107800, -98.6758600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136904, 'Schertz', 'Schertz', 'Sherc,shrtz  tgzas,shyrtz,Шерц,شرتز، تگزاس,شيرتز', 29.5521700, -98.2697300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136905, 'Schulenburg', 'Schulenburg', '', 29.6819000, -96.9030400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136906, 'Scissors', 'Scissors', '', 26.1398000, -98.0538900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136907, 'Seabrook', 'Seabrook', '', 29.5641200, -95.0254800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136908, 'Seadrift', 'Seadrift', '', 28.4152800, -96.7135900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136909, 'Seagoville', 'Seagoville', 'Sigovil,syghwfyl,sygwyl  tgzas,Сиговил,سيغوفيل,سیگویل، تگزاس,സീഗോവിൽ', 32.6395800, -96.5383200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136910, 'Sealy', 'Sealy', '', 29.7807900, -96.1571800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136911, 'Sebastian', 'Sebastian', '', 26.3428500, -97.7902700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136912, 'Seguin', 'Seguin', 'Segin,Seguin,Walnut Springs,syghwyn,sygwyn  tgzas,Сегин,سيغوين,سیگوین، تگزاس', 29.5688400, -97.9647300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136913, 'Selma', 'Selma', 'Sel''ma,Сельма', 29.5843900, -98.3058500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136914, 'Serenada', 'Serenada', '', 30.6993600, -97.6919500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136915, 'Seven Points', 'Seven Points', '', 32.3204200, -96.2130300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136916, 'Seymour', 'Seymour', 'Simor,symwr,symwr  tgzas,Симор,سيمور,سیمور، تگزاس', 33.5942600, -99.2603500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136917, 'Shady Hollow', 'Shady Hollow', '', 30.1649300, -97.8622300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136918, 'Shady Shores', 'Shady Shores', '', 33.1651200, -97.0294500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136919, 'Shamrock', 'Shamrock', '', 32.5993000, -96.8875000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136920, 'Shavano Park', 'Shavano Park', '', 29.5849500, -98.5525200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136921, 'Sheldon', 'Sheldon', '', 29.8680000, -95.1282600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136922, 'Shenandoah', 'Shenandoah', '', 30.1802200, -95.4557700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136923, 'Shepherd', 'Shepherd', '', 30.4979800, -94.9966000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136924, 'Sherman', 'Sherman', 'PNX,Sherman,shaman,shrmn  tgzas,shyrman,xie er man,Шерман,شرمن، تگزاس,شيرمان,شیرمین، ٹیکساس,シャーマン,谢尔曼', 33.6356600, -96.6088800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136925, 'Sherwood Shores', 'Sherwood Shores', '', 33.8523200, -96.8177800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136926, 'Shiner', 'Shiner', '', 29.4291300, -97.1705400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136927, 'Shoreacres', 'Shoreacres', '', 29.6202300, -95.0099300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136928, 'Sienna Plantation', 'Sienna Plantation', '', 29.4860700, -95.5080000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136929, 'Siesta Shores', 'Siesta Shores', '', 26.8581000, -99.2536500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136930, 'Silsbee', 'Silsbee', '', 30.3491000, -94.1779600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136931, 'Sinton', 'Sinton', '', 28.0366800, -97.5091600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136932, 'Smithville', 'Smithville', '', 30.0085500, -97.1594300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136933, 'Somerset', 'Somerset', 'Somerset,Сомерсет', 29.2263500, -98.6578000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136934, 'Somerville', 'Somerville', '', 30.3460400, -96.5283000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136935, 'Sour Lake', 'Sour Lake', 'Sour Lake,Sourlake', 30.1402100, -94.4110200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136936, 'South Alamo', 'South Alamo', '', 26.1570200, -98.1086200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136937, 'South Houston', 'South Houston', '', 29.6630100, -95.2354900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136938, 'South Padre Island', 'South Padre Island', 'Palm Beach,Saut Padre Ajland,South Padre Island,jzyrh padrh jnwby,sawt badry ayland,Саут Падре Ајланд,جزیره پادره جنوبی,ساوت بادري أيلاند', 26.1036900, -97.1646900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136939, 'South Point', 'South Point', '', 25.8686900, -97.3835900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136940, 'Southlake', 'Southlake', 'Sautlejk,sawthlayk,sawtlyk  tgzas,Саутлејк,ساوتلیک، تگزاس,ساوثلايك', 32.9412400, -97.1341800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136941, 'Southmayd', 'Southmayd', 'Southmayd,Southmayde', 33.6303800, -96.7691600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136942, 'Southside Place', 'Southside Place', 'South Side Place,Southside Place', 29.7060600, -95.4368800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136943, 'Sparks', 'Sparks', '', 30.9285200, -97.3597200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136944, 'Splendora', 'Splendora', '', 30.2329900, -95.1610400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136945, 'Spring', 'Spring', 'Springtaun,aspryng  tgzas,sbryngh,seupeuling,Спрингтаун,اسپرینگ، تگزاس,سبرينغ,سپرنگ، ٹیکساس,스프링', 30.0799400, -95.4171600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136946, 'Spring Valley', 'Spring Valley', 'Spring-Vehlli,Спринг-Вэлли', 29.7896700, -95.5035500, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136947, 'Springtown', 'Springtown', '', 32.9659600, -97.6836400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136948, 'Stafford', 'Stafford', 'Staford,astafwrd  tgzas,stafwrd,Стафорд,استافورد، تگزاس,ستافورد,സ്റ്റാഫൊർഡ്', 29.6160700, -95.5577200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136949, 'Stamford', 'Stamford', 'Stamford,astmfwrd  tgzas,stamfwrd,Стамфорд,استمفورد، تگزاس,ستامفورد', 32.9453900, -99.8028700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136950, 'Stephenville', 'Stephenville', 'SEP,Stivenvil,astfnwyl  tgzas,styfnfyl,Стивенвил,استفنویل، تگزاس,ستيفنفيل', 32.2207000, -98.2022600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136951, 'Stockdale', 'Stockdale', '', 29.2369100, -97.9600000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136952, 'Stowell', 'Stowell', '', 29.7899400, -94.3832400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136953, 'Sugar Land', 'Sugar Land', 'SGR,Shugar Land,Shugar-Lend,Sugar Land,shu ge lan,shugarando,shwgrlnd  tgzas,shwjr land,syugeolaendeu,Шугар Ланд,Шугар-Ленд,Шуґар-Ленд,شوجر لاند,شوگر لینڈ، ٹیکساس,شوگرلند، تگزاس,ഷുഗർലാൻഡ്,シュガーランド,舒格蘭,슈거랜드', 29.6196800, -95.6349500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136954, 'Sullivan City', 'Sullivan City', '', 26.2775700, -98.5636300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136955, 'Sulphur Springs', 'Sulphur Springs', 'SLR,Salfur Springs,swlfr sbrynghz,swlfwr aspryngz  tgzas,Салфур Спрингс,سولفر سبرينغز,سولفور اسپرینگز، تگزاس', 33.1384500, -95.6010700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136956, 'Sunnyvale', 'Sunnyvale', 'Sunivejl,Сънивейл', 32.7965200, -96.5608200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136957, 'Sweeny', 'Sweeny', 'Sweeney,Sweeny', 29.0388600, -95.6985600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136958, 'Taft', 'Taft', 'Mesquital,Taft', 27.9789100, -97.3986000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136959, 'Taft Southwest (historical)', 'Taft Southwest (historical)', 'Taft Southwest,Taft Southwest (historical)', 27.9739100, -97.4030500, 'US', '2012-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136960, 'Talty', 'Talty', 'Irish Ridge,Layden''s Ridge,Talty', 32.6831900, -96.3855400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136961, 'Tatum', 'Tatum', '', 32.3159900, -94.5165900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136962, 'Taylor', 'Taylor', 'Tejlor,Тейлор', 30.5707600, -97.4094400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136963, 'Taylor Lake Village', 'Taylor Lake Village', '', 29.5752300, -95.0502100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136964, 'Teague', 'Teague', '', 31.6271100, -96.2838600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136965, 'Tenaha', 'Tenaha', '', 31.9437800, -94.2440900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136966, 'Temple', 'Temple', 'TPL,Templ,tan pu er,tempeul,tenpuru,tmbl,tmpl  tgzas,Темпл,تمبل,تمپل، تگزاس,ٹیمپل، ٹیکساس,テンプル,坦普爾,템플', 31.0982300, -97.3427800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136967, 'Terrell', 'Terrell', 'TRL,Terel,Terrel,Terrell,teleol,trl  tgzas,tyryl,Терел,ترل، تگزاس,تيريل,테럴', 32.7359600, -96.2752600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136968, 'Terrell Hills', 'Terrell Hills', '', 29.4749500, -98.4508500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136969, 'Texarkana', 'Texarkana', 'TXK,Teksarkana,Texarcana,Texarkana,te ke sa ka na,tegsakaena,tekusakana,tksarkna  tgzas,tyksarkana,Тексаркана,تيكساركانا,تکسارکنا، تگزاس,ٹیکسرکینا، ٹیکساس,テクサーカナ,特克萨卡纳,텍사캐나', 33.4251300, -94.0476900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136970, 'Texas City', 'Texas City', 'Teksas Siti,Teksasurbo,de ke sa si cheng,tekisasushiti,teksasa siti,tgzas syty  tgzas,tksas syty,Тексас Сити,تكساس سيتي,تگزاس سیتی، تگزاس,टेक्सास सिटी,テキサスシティ,德克薩斯城', 29.3838500, -94.9027000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136971, 'The Colony', 'The Colony', 'Koloni,Kolonija,d klny  tgzas,dha kwlwny,di kealani,Колони,Колония,د کلنی، تگزاس,ذا كولوني,ദി കോളനി', 33.0890100, -96.8863900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136972, 'The Hills', 'The Hills', '', 30.3479800, -97.9850100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136973, 'The Woodlands', 'The Woodlands', 'Te-Vudlends,The Woodlands,Vudlands,Ze-Vudlends,dha wwdlandz,wu de lan shi,wwdlndz  tgzas,Вудландс,Зе-Вудлендс,Те-Вудлендс,دی ووڈلینڈز، ٹیکساس,ذا وودلاندز,وودلندز، تگزاس,ザ・ウッドランズ,伍德蘭市', 30.1579900, -95.4893800, 'US', '2014-05-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136974, 'Thorndale', 'Thorndale', '', 30.6138100, -97.2055500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136975, 'Three Rivers', 'Three Rivers', 'Hamiltonburg,Three Rivers', 28.4602700, -98.1825100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136976, 'Throckmorton', 'Throckmorton', '', 33.1787200, -99.1775800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136977, 'Tilden', 'Tilden', 'Colfax,Dog Town,Tilden', 28.4619400, -98.5491800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136978, 'Timberwood Park', 'Timberwood Park', '', 29.7057800, -98.4783500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136979, 'Timpson', 'Timpson', '', 31.9037800, -94.3952000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136980, 'Tom Bean', 'Tom Bean', '', 33.5201100, -96.4838700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136981, 'Tomball', 'Tomball', 'Tom Ball,Tomball,Tombol,tambal  tgzas,twmbwl,Томбол,تامبال، تگزاس,تومبول', 30.0971600, -95.6160500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136982, 'Tool', 'Tool', 'Tool,Toole', 32.2679200, -96.1702500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136983, 'Trinity', 'Trinity', '', 30.9451900, -95.3755000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136984, 'Trophy Club', 'Trophy Club', '', 32.9979000, -97.1836200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136985, 'Troup', 'Troup', 'Troope Station,Troup,Troupe,Zavalla', 32.1446000, -95.1205000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136986, 'Troy', 'Troy', 'Troja,Троя', 31.2068400, -97.3027800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136987, 'Tye', 'Tye', '', 32.4576200, -99.8714800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136988, 'Tyler', 'Tyler', 'TYR,Tajler,Tyler,tai lei,taira,taylr,taylr  tgzas,Тайлер,Тајлер,تايلر,تایلر، تگزاس,ٹائلر,ٹائلر، ٹیکساس,タイラー,泰勒', 32.3512600, -95.3010600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136989, 'Uhland', 'Uhland', '', 29.9577200, -97.7861100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136990, 'Universal City', 'Universal City', '', 29.5480100, -98.2911200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136991, 'University Park', 'University Park', '', 32.8501300, -96.8002800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136992, 'Uvalde', 'Uvalde', 'Juvalde,Juvaldi,UVA,afayld,you wa er di,yubaeldi,ywwald  tgzas,Јувалди,Ювалде,Ювалди,أفايلد,یووالد، تگزاس,尤瓦尔迪,유밸디', 29.2096800, -99.7861700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136993, 'Uvalde Estates', 'Uvalde Estates', '', 29.1652400, -99.8322800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136994, 'Valley Mills', 'Valley Mills', '', 31.6593300, -97.4722400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136995, 'Van', 'Van', '', 32.5248600, -95.6371800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136996, 'Van Alstyne', 'Van Alstyne', '', 33.4215000, -96.5772100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136997, 'Van Vleck', 'Van Vleck', '', 29.0177500, -95.8894000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136998, 'Venus', 'Venus', 'Gossip,Venus', 32.4334700, -97.1025100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(136999, 'Vernon', 'Vernon', 'Eagle Flats,Vernon,WIB,fyrnwn,wrnan  tgzas,Вернон,فيرنون,ورنان، تگزاس', 34.1553600, -99.2662800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137000, 'Victoria', 'Victoria', 'Guadalupe Victoria,VCT,Victoria,Viktorija,bigtolia,bikutoria,fyktwrya,wei duo li ya,wyktwrya  tgzas,Виктория,Викторија,فيكتوريا,وکٹوریہ، ٹیکساس,ویکتوریا، تگزاس,ビクトリア,維多利亞,빅토리아', 28.8052700, -97.0036000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137001, 'Vidor', 'Vidor', '', 30.1316000, -94.0154500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137002, 'Von Ormy', 'Von Ormy', 'Manns Crossing,Medina Crossing,Von Ormy', 29.2891300, -98.6444600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137003, 'Waco', 'Waco', 'ACT,Uehjko,Uejkou,Vako,Vejko,Waco,u~eko,veko,wakw,wei ke,weiko,wykw,wykw  tgzas,wyyqw,Вако,Вейко,Вејко,Уейкоу,Уэйко,וייקו,واكو,ویکو,ویکو، تگزاس,ویکو، ٹیکساس,वेको,ウェーコ,韋科,韦科,웨이코', 31.5493300, -97.1466700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137004, 'Wake Village', 'Wake Village', 'Wake,Wake Village', 33.4267900, -94.1063000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137005, 'Waller', 'Waller', '', 30.0566100, -95.9269000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137006, 'Waskom', 'Waskom', '', 32.4787600, -94.0596300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137007, 'Watauga', 'Watauga', '', 32.8579100, -97.2547400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137008, 'Waxahachie', 'Waxahachie', 'Uaksakhachi,Voksakhachi,wksahachy  tgzas,wksahatshy  tksas,wogseohaechi,Воксахачи,Уаксахачи,وكساهاتشي، تكساس,وکساهاچی، تگزاس,웍서해치', 32.3865300, -96.8483300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137009, 'Weatherford', 'Weatherford', 'Vederford,WEA,wdrfrd  tgzas,wydhrfwrd,Ведерфорд,ودرفرد، تگزاس,ويذرفورد', 32.7593000, -97.7972500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137010, 'Webster', 'Webster', 'Vebster,wbstr  tgzas,wybstr,Вебстер,وبستر، تگزاس,ويبستر,ویبسٹر، ٹیکساس', 29.5377300, -95.1182600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137011, 'Weimar', 'Weimar', '', 29.7030100, -96.7805300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137012, 'Wells Branch', 'Wells Branch', '', 30.4460400, -97.6794500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137013, 'Weslaco', 'Weslaco', 'Veslako,wslakw  tgzas,wyslakw,Веслако,وسلاکو، تگزاس,ويسلاكو', 26.1595200, -97.9908400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137014, 'West', 'West', 'Uehst,Vest,wei si te,weseuteu,wst  tgzas,wyst,Вест,Уэст,وست، تگزاس,ويست,ویسٹ، ٹیکساس,韋斯特,韦斯特,웨스트', 31.8023800, -97.0916700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137015, 'West Columbia', 'West Columbia', '', 29.1438600, -95.6452200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137016, 'West Lake Hills', 'West Lake Hills', '', 30.2979800, -97.8019500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137017, 'West Livingston', 'West Livingston', '', 30.6982500, -95.0018800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137018, 'West Orange', 'West Orange', '', 30.0821500, -93.7582200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137019, 'West Sharyland', 'West Sharyland', '', 26.2725700, -98.3286300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137020, 'West Tawakoni', 'West Tawakoni', '', 32.8937300, -96.0294100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137021, 'West University Place', 'West University Place', 'Vest Juniversiti Plejs,wst ywnywrsyty plys  tgzas,wyst ywnyfrsyty blays,Вест Јуниверсити Плејс,وست یونیورسیتی پلیس، تگزاس,ويست يونيفرسيتي بلايس', 29.7180100, -95.4338300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137022, 'Westlake', 'Westlake', '', 32.9912400, -97.1950100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137023, 'Westworth', 'Westworth', 'Westworth,Westworth Village', 32.7573500, -97.4108500, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137024, 'Wharton', 'Wharton', 'Vorton,WHT,Wharton,wartwn,wartwn  tgzas,Вортон,وارتون,وارتون، تگزاس', 29.3116400, -96.1027400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137025, 'White Oak', 'White Oak', '', 32.5279200, -94.8613300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137026, 'White Settlement', 'White Settlement', '', 32.7595700, -97.4583500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137027, 'Whitehouse', 'Whitehouse', '', 32.2268200, -95.2255000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137028, 'Whitesboro', 'Whitesboro', '', 33.6562200, -96.9069500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137029, 'Whitewright', 'Whitewright', '', 33.5128900, -96.3924800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137030, 'Whitney', 'Whitney', 'Uitni,Уитни', 31.9518200, -97.3214000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137031, 'Wichita Falls', 'Wichita Falls', 'SPS,Uichito Fols,Uichito-Fols,Vichita Fols,Vichita-Fols,Wichita Falls,u~ichitaforuzu,vicita pholsa,wei qi tuo fu er si,wichitopolseu,wychyta falz  tgzas,wytshyta fwlz,Вичита Фолс,Вічита-Фолс,Уичито Фолс,Уичито-Фолс,ويتشيتا فولز,وچیٹا فالز,ویچیتا فالز، تگزاس,ویچیتا فالز، ٹیکساس,विचिटा फॉल्स,ウィチタフォールズ,威奇托福尔斯,위치토폴스', 33.9137100, -98.4933900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137032, 'Wild Peach Village', 'Wild Peach Village', '', 29.0835800, -95.6338400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137033, 'Wildwood', 'Wildwood', '', 30.5240900, -94.4415800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137034, 'Willis', 'Willis', '', 30.4249300, -95.4799400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137035, 'Willow Park', 'Willow Park', '', 32.7626300, -97.6505800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137036, 'Wills Point', 'Wills Point', 'Wills Point,Willspoint', 32.7093000, -96.0083000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137037, 'Wilmer', 'Wilmer', '', 32.5890200, -96.6852700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137038, 'Wimberley', 'Wimberley', '', 29.9974400, -98.0986200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137039, 'Windemere', 'Windemere', '', 30.4590900, -97.6491700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137040, 'Windcrest', 'Windcrest', '', 29.5155100, -98.3802900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137041, 'Winnie', 'Winnie', 'Vini,wyny,wyny  tgzas,Вини,ويني,وینی، تگزاس', 29.8202200, -94.3840800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137042, 'Winnsboro', 'Winnsboro', 'Winnsboro,Winnsborough', 32.9573400, -95.2902200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137043, 'Winters', 'Winters', '', 31.9565300, -99.9623100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137044, 'Wolfe City', 'Wolfe City', '', 33.3706700, -96.0688600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137045, 'Woodbranch', 'Woodbranch', '', 30.1810500, -95.1888200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137046, 'Woodcreek', 'Woodcreek', '', 30.0282700, -98.1111200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137047, 'Woodsboro', 'Woodsboro', '', 28.2383400, -97.3199900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137048, 'Woodville', 'Woodville', 'Vudvil,Vudvill,wu de wei er,wwdfyl,wwdwyl  tgzas,Вудвил,Вудвилл,وودفيل,وودویل، تگزاس,伍德維爾', 30.7752000, -94.4154800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137049, 'Woodway', 'Woodway', '', 31.5060000, -97.2050100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137050, 'Wortham', 'Wortham', '', 31.7879400, -96.4624800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137051, 'Wyldwood', 'Wyldwood', '', 30.1293800, -97.4727700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137052, 'Wylie', 'Wylie', 'Vajli,vaili,wayly  tgzas,wyly,Вајли,وایلی، تگزاس,ويلي,വൈലി', 33.0151200, -96.5388800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137053, 'Yoakum', 'Yoakum', '', 29.2877500, -97.1519300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137054, 'Yorktown', 'Yorktown', 'Lower Town,Yorktown', 28.9810900, -97.5027700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137055, 'Zapata', 'Zapata', 'Carrizo,Zapata', 26.9072600, -99.2714300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137056, 'Abingdon', 'Abingdon', 'Abingdon,Black''s Fort,Blacks Fort,VJI,Wolf Hills,a bin deng,abyngdam  wyrjynya,abynghdwn,aebingdeon,Абингдон,Абінгдон,أبينغدون,ابینگدام، ویرجینیا,阿宾登,애빙던', 36.7098300, -81.9773500, 'US', '2017-04-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137057, 'Accomac', 'Accomac', 'Accomac,Accomac Court House,Accomack Court House,Akomak,Dales Gift,Drummond,Drummondtown,Freemans Plantation,Matomkin,Metomkin,Metompkin,Metompkin Court House,akwmak,akwmak  wyrjynya,Акомак,أكوماك,اکوماک، ویرجینیا', 37.7195700, -75.6654800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137058, 'Adwolf', 'Adwolf', 'Adwolf,Adwolfe', 36.7892800, -81.5820600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137059, 'Alexandria', 'Alexandria', 'Aleksandri,Aleksandrija,Alexandria,Alexandria City,Allexandria,Belhaven,Belle Haven,Bellhaven,Chincoteague Creek,Gincatic Creek,Guicatic Run,alaskndryt,alksandrya  wyrjynya,allegsandeulia,arekusandoria,ya li shan de li ya,Александри,Александрия,Александрија,Александрія,Ալեքսանդրիա,אלכסנדריה,الإسكندرية,الکساندریا، ویرجینیا,الیگزینڈریا، ورجینیا,অ্যালেক্সান্ড্রিয়া,アレクサンドリア,亚历山德里亚,알렉산드리아', 38.8048400, -77.0469200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137060, 'Altavista', 'Altavista', 'Alta Vista,Altavista', 37.1118100, -79.2855800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137061, 'Amelia Court House', 'Amelia Court House', 'Amelia,Amelia Court House', 37.3429300, -77.9805600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137062, 'Amherst', 'Amherst', 'Amherst,Amherst Court House,Amkherst,Seven Oaks,The Oaks,amhrst  wyrjynya,Амхерст,امهرست، ویرجینیا', 37.5851400, -79.0514100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137063, 'Annandale', 'Annandale', 'Anandejl,Анандејл', 38.8303900, -77.1963700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137064, 'Appalachia', 'Appalachia', 'Appalachia,Intermont,Mineralville', 36.9067600, -82.7818300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137065, 'Apple Mountain Lake', 'Apple Mountain Lake', '', 38.9242800, -78.1013900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137066, 'Appomattox', 'Appomattox', 'Apamatuck,Apomatoks,Appomattox,Appomattox Court House,Appomattox Depot,Appomattox Station,Apumetec,Nebraska,West Appomattox,Апоматокс', 37.3570900, -78.8252900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137067, 'Aquia Harbour', 'Aquia Harbour', '', 38.4626200, -77.3888700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137068, 'Arlington', 'Arlington', 'Arlington,Arlingtonas,a ling dun xian,arinton,Арлингтон,アーリントン,阿靈頓縣', 38.8810100, -77.1042800, 'US', '2015-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137069, 'Ashburn', 'Ashburn', 'Ashbern,Ashburn,Farmville,Farmwell,Old Farmwell,aesyubeon,ashbrn  wyrjynya,ashbwrn,Ашберн,Ашбърн,آشبورن,اشبرن، ویرجینیا,애슈번', 39.0437200, -77.4874900, 'US', '2015-03-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137070, 'Ashland', 'Ashland', 'Ashland,Eshland,Slash Cottage,Slashes,Ешланд,ایشلنڈ، ورجینیا', 37.7590300, -77.4799800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137071, 'Atkins', 'Atkins', 'Atkins,Atkins Switch,Atkins Tank', 36.8673400, -81.4234400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137072, 'Baileys Crossroads', 'Baileys Crossroads', 'Bailey Crossroads,Bailey''s Crossroads,Baileys Cross Roads,Baileys Crossroads,Baily''s Cross Roads,Balls X Roads', 38.8503900, -77.1297000, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137073, 'Bassett', 'Bassett', 'Bassett,Bassetts', 36.7593000, -79.9903200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137074, 'Basye', 'Basye', 'Basye,Basye-Bryce Mountain,Bryce Mountain,Powder Springs', 38.8070600, -78.7922400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137075, 'Bealeton', 'Bealeton', 'Beale,Bealeton,Bealton,Germantown', 38.5717900, -77.7638800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137076, 'Bedford', 'Bedford', 'Bedesford,Bedford,Bedford City,Bedford Court House,Bēdesford,Liberty,Liberty Court House,bdfwrd  wyrjynya,beddofodo,bedeupeodeu,bei de fu,Бедфорд,بدفورد، ویرجینیا,بیڈفورڈ، ورجینیا,ベッドフォード,貝德福,베드퍼드', 37.3343100, -79.5230900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137077, 'Belle Haven', 'Belle Haven', '', 38.7853900, -77.0630300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137078, 'Bellwood', 'Bellwood', '', 37.4218100, -77.4374800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137079, 'Belmont', 'Belmont', 'Belmont,Belmont Park', 39.0648300, -77.5099900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137080, 'Bensley', 'Bensley', '', 37.4468100, -77.4433200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137081, 'Berryville', 'Berryville', 'Battletown,Berivil,Berryville,Беривил', 39.1517700, -77.9822200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137082, 'Big Stone Gap', 'Big Stone Gap', 'Big Stone Gap,Big Stoun Gap,Bigstone Gap,Imboden,Mineral City,Three Forks,Wolverhampton,Биг Стоун Гап', 36.8817600, -82.7471000, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137083, 'Blackstone', 'Blackstone', 'BKT,Bellefonte,Black and Whites,Blacks,Blacks and Whites,Blackstone,Blekstoun,Whites,Блекстоун', 37.0804300, -77.9972300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137084, 'Blacksburg', 'Blacksburg', 'BCB,Blacksburg,Blacksburgh,Blaecesburg,Blehksberg,Blehksburg,Bleksburg,Blæcesburg,Draper Meadows,Draper''s Meadow,Draper''s Meadows,Drapers Meadow,beullaegseubeogeu,blaksbrgh,blksbrg,burakkusubagu,hei bao,Блексбург,Блэксберг,Блэксбург,بلاكسبرغ,بلکسبرگ,ブラックスバーグ,黑堡,블랙스버그', 37.2295700, -80.4139400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137085, 'Bland', 'Bland', 'Bland,Bland Court House,Crab Orchard,Crab Orchard Creek,Seddon,Selden,Seldon', 37.1020600, -81.1162000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137086, 'Blue Ridge', 'Blue Ridge', 'Blue Ridge,Blue Ridge Spring,Blueridge Springs,Flukes', 37.3784700, -79.8069800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137087, 'Bluefield', 'Bluefield', 'Bluefield,Blufild,Graham,Harman,Pin Hook,Блуфилд', 37.2526200, -81.2712100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137088, 'Bon Air', 'Bon Air', 'Bon Air,Bonair', 37.5248700, -77.5577700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137089, 'Bowling Green', 'Bowling Green', 'Bouling Grin,Bouling-Grin,Bowling Green,Bowlingfreen,bawlng gryn  wrjynya,Боулинг Грин,Боулинг-Грин,باولنگ گرین، ورجینیا', 38.0495800, -77.3466500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137090, 'Boydton', 'Boydton', 'Bojton,Бојтон', 36.6676400, -78.3875000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137091, 'Bracey', 'Bracey', 'Bracey,Bracy', 36.5995900, -78.1430500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137092, 'Brambleton', 'Brambleton', '', 38.9820500, -77.5386000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137093, 'Brandermill', 'Brandermill', '', 37.4320900, -77.6497100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137094, 'Bridgewater', 'Bridgewater', 'Bridgeport,Bridgewater,Bridzhuoter,Dinkletown,Бриджуотер', 38.3820700, -78.9767000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137095, 'Brightwood', 'Brightwood', 'Brightwood,Dulinsville,Fleshmans Shop', 38.4215200, -78.1936100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137096, 'Bristol', 'Bristol', 'Bristol,Bristol City,Goodson,Sappling Grove,brystwl,brystwl  wyrjynya,bu li si tuo er,burisutoru,Бристол,برسٹل، ورجینیا,بريستول,بریستول، ویرجینیا,ブリストル,布里斯托爾', 36.5964900, -82.1884700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137097, 'Broadlands', 'Broadlands', '', 39.0181600, -77.5202700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137098, 'Broadway', 'Broadway', 'Broadway,Broadway Depot,Brodvej,Бродвеј', 38.6131700, -78.7989100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137099, 'Brookneal', 'Brookneal', 'Brook Neal,Brookneal,Bruknil,Брукнил', 37.0501400, -78.9441800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137100, 'Buchanan', 'Buchanan', 'Buchanan,Bukanan,Crow''s Ferry,Looney''s Ferry,Pattonsburg,bwtshanan,bywkynn  wrjynya,Буканан,بوتشانان,بیوکینن، ورجینیا', 37.5273600, -79.6797600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137101, 'Buckhall', 'Buckhall', '', 38.7317800, -77.4311000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137102, 'Buckingham', 'Buckingham', 'Buckingham,Buckingham Court House,Buckingham Courthouse,Maysville,Mayville', 37.5501500, -78.5555600, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137103, 'Buena Vista', 'Buena Vista', 'B''juna-Vista,Bjuna Vista,Buena Vista,Buena Vista City,Buena Vista konderria,Buenavista,bu you na wei si ta,buenabisuta,bwyna fysta,bwynawysta  wyrjynya,Бьюна-Виста,Бјуна Виста,بوئناویستا، ویرجینیا,بوينا فيستا,بیونا وسٹا، ورجینیا,ブエナビスタ,布尤納維斯塔', 37.7343000, -79.3539200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137104, 'Bull Run', 'Bull Run', '', 38.7837300, -77.5205500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137105, 'Bull Run Mountain Estates', 'Bull Run Mountain Estates', '', 38.9037200, -77.6616600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137106, 'Burke', 'Burke', 'Berk,brk  wyrjynya,Берк,برک، ویرجینیا', 38.7934500, -77.2716500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137107, 'Cana', 'Cana', '', 36.5895800, -80.6717300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137108, 'Cape Charles', 'Cape Charles', 'Accomack,Cape Charles,Kejp Charls,kab tsharlys,Кејп Чарлс,كاب تشارليس', 37.2679200, -76.0174300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137109, 'Carrollton', 'Carrollton', 'Carrollton,Carrolton', 36.9468200, -76.5605100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137110, 'Castlewood', 'Castlewood', 'Cassel''s Wood,Castle''s Woods,Castles Woods,Castlewood', 36.8901000, -82.2795900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137111, 'Cave Spring', 'Cave Spring', 'Cave Spring,Cavespring', 37.2276400, -80.0128200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137112, 'Cedar Bluff', 'Cedar Bluff', '', 37.2640300, -79.9353200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137113, 'Cedar Bluff', 'Cedar Bluff', 'Cedar Bluff,Cedarbluff', 37.0876100, -81.7590000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137114, 'Central Garage', 'Central Garage', '', 37.7440300, -77.1316400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137115, 'Centreville', 'Centreville', 'Centerville,Centreville,New Gate,Newgate,Sentervil,sntrwyl  wyrjynya,Сентервил,سنترویل، ویرجینیا', 38.8403900, -77.4288800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137116, 'Chamberlayne', 'Chamberlayne', '', 37.6265300, -77.4285900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137117, 'Chantilly', 'Chantilly', 'Chantilly,Chantilly Creek,Ox Hill,Shantili,Шантили', 38.8942800, -77.4311000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137118, 'Charles City', 'Charles City', 'Charles City,Charles City Court House,Charls Siti,Чарлс Сити', 37.3434800, -77.0730300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137119, 'Charlotte Court House', 'Charlotte Court House', 'Charlotte,Charlotte Court House,Charlotte Courthouse,Dalstonburgh,Daltonsburgh,Marysville,Maryville,Sharlot Kort Khaus,Smithville,The Magazine,tsharlwt kwrt haws,Шарлот Корт Хаус,تشارلوت كورت هاوس', 37.0565400, -78.6383300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137120, 'Charlottesville', 'Charlottesville', 'CHO,Charlottesville,Sarlotsvilis,Sharlotsvil,Sharlotsvill,Sharlottsvill'',sharlwtsfyl,sharlwtzwyl  wyrjynya,sharottsubiru,syalleocheubil,sʼrlwtswwyl,xia lu di zhen,Šarlotsvilis,Шарлотсвил,Шарлотсвилл,Шарлоттсвилль,שארלוטסוויל,شارلوتزویل، ویرجینیا,شارلوتسفيل,شارلوٹزویل، ورجینیا,シャーロッツビル,夏律第鎮,샬러츠빌', 38.0293100, -78.4766800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137121, 'Chase City', 'Chase City', 'Chase City,Chejs Siti,Christianville,tshas syty,Чејс Сити,تشاس سيتي', 36.7993100, -78.4583300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137122, 'Chatham', 'Chatham', 'Chatam,Chatham,Competition,tshatham,Чатам,تشاتهام', 36.8256900, -79.3980800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137123, 'Chatmoss', 'Chatmoss', '', 36.6568000, -79.8122600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137124, 'Cherry Hill', 'Cherry Hill', '', 38.5698400, -77.2669300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137125, 'Chesapeake', 'Chesapeake', 'Cesapikas,Chesapeack,Chesapeake,Chesapijk,Chesapik,Norfolk County,South Norfolk,cespik,chesapiku,cheseopikeu,chsapyk  wrjynya,chsapyk  wyrjynya,qie sa pi ke,tshysabyk,zspyq,Česapikas,Чесапийк,Чесапик,Чесапік,צספיק,تشيسابيك,چساپیک، ورجینیا,چساپیک، ویرجینیا,ಚೆಸ್ಪೀಕ್,チェサピーク,切萨皮克,체서피크', 36.8190400, -76.2749400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137126, 'Chester', 'Chester', 'Chester,Честер,چیسٹر، ورجینیا', 37.3568200, -77.4416500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137127, 'Chesterfield', 'Chesterfield', 'Chesterfield,Chesterfield Court House', 37.3770900, -77.5058200, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137128, 'Chesterfield Court House', 'Chesterfield Court House', '', 37.3770900, -77.5049900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137129, 'Chilhowie', 'Chilhowie', 'Chilhowie,Greevers Switch,Town House', 36.7984500, -81.6823400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137130, 'Chincoteague', 'Chincoteague', 'Chincoteague,Chincoteague Island,Shinkotig,WAL,tshayntyghw,Шинкотиг,تشاينتيغو', 37.9331800, -75.3788100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137131, 'Christiansburg', 'Christiansburg', 'Bangs,Cambria,Christiansburg,Christiansburgh,Hans Meadow,Krishchansburg,krystyansbwrgh,kurisuchanzubagu,Кришчансбург,كريستيانسبورغ,クリスチャンズバーグ', 37.1298500, -80.4089400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137132, 'Clarksville', 'Clarksville', 'Klarksvil,klarksfyl,klarkswyl  wrjynya,Кларксвил,كلاركسفيل,کلارکسویل، ورجینیا', 36.6240300, -78.5569400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137133, 'Claypool Hill', 'Claypool Hill', '', 37.0626100, -81.7517800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137134, 'Clifton Forge', 'Clifton Forge', 'Clifton Force,Clifton Forge,Cliftonforge,Cliftons Forge,Klifton Fordz,Williamson,Williamson''s Station,klyftwn fwrgh,Клифтон Форџ,كليفتون فورغ', 37.8162400, -79.8244900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137135, 'Clintwood', 'Clintwood', 'Clintwood,Clintwood Court House,Holly Creek,Klintvud,klyntwwd,Клинтвуд,كلينتوود', 37.1501100, -82.4559800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137136, 'Cloverdale', 'Cloverdale', '', 37.3651400, -79.9056000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137137, 'Coeburn', 'Coeburn', 'Coburn,Coeburn,Guest Station,Guest''s Station,Guests Station', 36.9439900, -82.4640400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137138, 'Collinsville', 'Collinsville', 'Kollinsvil'',Коллинсвиль', 36.7151400, -79.9153200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137139, 'Colonial Beach', 'Colonial Beach', 'Classic Shore,Colonial Beach,Irish Neck,Kolonijal Bich,Las Vegas on the Potomac,Millville,White Beach,kwlwnyal,Колонијал Бич,كولونيال', 38.2545700, -76.9635800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137140, 'Colonial Heights', 'Colonial Heights', 'Colonial Heights City,Kolonial-Khajts,Kolonijal Khajts,ke luo ni er hai ci,koroniaruhaitsu,kwlwnyal hayts  wyrjynya,kwlwnyl hayts,Колониал-Хайтс,Колонијал Хајтс,كولونيل هايتس,کولونیال هایتس، ویرجینیا,کولونیل ہائٹس، ورجینیا,コロニアルハイツ,科洛尼爾海茨', 37.2680400, -77.4072600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137141, 'Concord', 'Concord', 'Concord,Concord Depot', 37.3426400, -78.9750200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137142, 'Countryside', 'Countryside', '', 39.0409400, -77.4136000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137143, 'Courtland', 'Courtland', 'Courtland,Jerusalem,Kortland,kwrtland,Кортланд,كورتلاند', 36.7162600, -77.0680200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137144, 'Covington', 'Covington', 'Covington,Kavington,Kovington,Merry''s Store,Merrys Store,ka wen dun,kawyngtwn  wyrjynya,keobingteon,kobinton,kwfynghtwn,Кавингтон,Ковингтон,كوفينغتون,کاوینگتون، ویرجینیا,کوونگٹن، ورجینیا,コビントン,卡溫頓,커빙턴', 37.7934600, -79.9939500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137145, 'Crewe', 'Crewe', 'Krju,Kru,krw  wyrjynya,krywy,Кру,Крю,كريوي,کرو، ویرجینیا', 37.1732100, -78.1233300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137146, 'Crimora', 'Crimora', 'Crimora,Crimora Station', 38.1540200, -78.8503000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137147, 'Crozet', 'Crozet', 'Crozet,Land of Oz,Wayland,Waylands Crossing', 38.0695800, -78.7005800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137148, 'Culpeper', 'Culpeper', 'Culpeper,Fairfax,Kalpeper,kalapepara,karupepa,ku er pei po,kwlbybr,Калпепер,كولبيبر,कलपेपर,カルペパー,库尔佩珀', 38.4731800, -77.9966600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137149, 'Cumberland', 'Cumberland', 'Cumberland,Cumberland Court House', 37.4959800, -78.2452700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137150, 'Dahlgren', 'Dahlgren', 'DGN,Dahlgren,MaCcrady,McCrady,McGready', 38.3312400, -77.0510900, 'US', '2013-04-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137151, 'Dale City', 'Dale City', 'Dale City,Dejl Siti,Дейл Сити,Дејл Сити', 38.6370600, -77.3110900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137152, 'Daleville', 'Daleville', 'Amsterdam,Dalesville,Daleville,New Amsterdam', 37.4098600, -79.9125400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137153, 'Danville', 'Danville', 'DAN,Danvil,Danvill,Danville,Wynne''s Falls,daenbil,dan wei er,danbiru,danfyl,dnwyl  wyrjynya,Данвил,Данвилл,دانفيل,دنویل، ویرجینیا,ڈینویل، ورجینیا,ダンビル,丹維爾,댄빌', 36.5859700, -79.3950200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137154, 'Dayton', 'Dayton', 'Dayton,Deaton,Dejton,Rifetown,Rifeville,daytwn,detana,Дейтон,Дејтон,دايتون,ڈیٹن، ورجینیا,डेटन', 38.4148500, -78.9386400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137155, 'Deltaville', 'Deltaville', 'Deltaville,Sandy Bottom,Unionville', 37.5548600, -76.3368900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137156, 'Dinwiddie', 'Dinwiddie', 'Dinwiddie,Dinwiddie Court House', 37.0779300, -77.5866500, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137157, 'Dooms', 'Dooms', 'Dooms,Dooms Crossing', 38.1090200, -78.8575200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137158, 'Dranesville', 'Dranesville', 'Drane''s Tavern,Dranesville', 39.0006700, -77.3458200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137159, 'Dryden', 'Dryden', '', 36.7775900, -82.9415500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137160, 'Dublin', 'Dublin', 'Dablin,Dublin,PSK,dwblyn,Даблин,Дублин,دوبلين,ڈبلن، ورجینیا', 37.1056800, -80.6853400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137161, 'Dulles Town Center', 'Dulles Town Center', 'Dulles', 39.0376100, -77.4158200, 'US', '2012-05-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137162, 'Dumfries', 'Dumfries', 'Damfriz,Dumfrijs,dwmsfrys,Дамфриз,Дъмфрийс,دومسفريس', 38.5676200, -77.3280400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137163, 'Dumbarton', 'Dumbarton', '', 37.6037600, -77.4913700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137164, 'Dunn Loring', 'Dunn Loring', '', 38.8934400, -77.2216500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137165, 'East Hampton', 'East Hampton', '', 37.0373700, -76.3316100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137166, 'East Lexington', 'East Lexington', '', 37.7929100, -79.4253200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137167, 'East Highland Park', 'East Highland Park', '', 37.5809800, -77.4069300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137168, 'Eastville', 'Eastville', 'Eastville,Forks of Hungars Creek,Hornes of Hungars Creek,Istvil,Peachburg,The Horns,aystfyl,Иствил,إيستفيل', 37.3526400, -75.9457600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137169, 'Edinburg', 'Edinburg', 'Eden,Eden-Burg,Edenburg,Edenburgh,Edinburg,Ehdinburg,Shryock,Stony Creek,adynbwrgh,Единбург,Эдинбург,إدينبورغ', 38.8209500, -78.5658500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137170, 'Elkton', 'Elkton', 'Conrad''s Store,Conrads Store,Elkton,alktwn,Елктон,ألكتون', 38.4079000, -78.6236300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137171, 'Emory', 'Emory', '', 36.7728900, -81.8362300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137172, 'Emporia', 'Emporia', 'Belfield,Emporia,Emporia City,Emporija,Hicks Ford,Hicks'' Ford,Hicksford,Hicksville,ambwrya,ampwrya  wyrjynya,aympwrya  wrjynya,empolia,en bo li ya,enporia,Емпорија,إمبوريا,امپوریا، ویرجینیا,ایمپوریا، ورجینیا,エンポリア,恩波里亞,엠포리아', 36.6859800, -77.5424800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137173, 'Enon', 'Enon', '', 37.3307000, -77.3227600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137174, 'Ettrick', 'Ettrick', 'Ettrick,Ettrick Banks,Ettricks,Ettricks Banks', 37.2401500, -77.4299800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137175, 'Exmore', 'Exmore', '', 37.5318000, -75.8229900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137176, 'Fairfax', 'Fairfax', 'City of Fairfax,Fairfax,Fairfax Court House,Ferfaks,Feurfaks,Providence,feafakkusu,fei er fa ke si,frfks  wyrjynya,fyrfaks,fyyrfyks  wrjynya,peeopaegseu,Ферфакс,Феърфакс,فرفکس، ویرجینیا,فيرفاكس,فیئرفیکس، ورجینیا,フェアファックス,費爾法克斯,페어팩스', 38.8462200, -77.3063700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137177, 'Fairfax Station', 'Fairfax Station', 'Fairfax Station,Swetman,Swetnam', 38.8009500, -77.3255400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137178, 'Fairlawn', 'Fairlawn', '', 37.7762400, -79.9820000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137179, 'Fairlawn', 'Fairlawn', '', 37.1484600, -80.5783900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137180, 'Falls Church', 'Falls Church', 'Falls Church City,Fols Cherch,Fols-Cherch,falz chrch  wyrjynya,foruzuchachi,fu er si che qi,fwlz chrch,fwlz tshyrsh,Фолс Черч,Фолс-Черч,فالز چرچ، ویرجینیا,فولز تشيرش,فولز چرچ,フォールズチャーチ,福爾斯徹奇', 38.8823300, -77.1710900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137181, 'Falmouth', 'Falmouth', 'Falmut,Falmuthum,Фалмут', 38.3240200, -77.4683200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137182, 'Farmville', 'Farmville', 'Farmvil,Farmville,Rutledge Ford,Rutledges Ford,farmfyl,Фармвил,فارمفيل', 37.3021000, -78.3919400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137183, 'Ferrum', 'Ferrum', 'Ferrum,Sophronia', 36.9229200, -80.0133700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137184, 'Fincastle', 'Fincastle', 'Botetourt Court House,Fincastle,Finkasl,Millers Mill,fynkastl,Финкасл,فينكاستل', 37.4993000, -79.8772600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137185, 'Fishersville', 'Fishersville', 'Fishersville,Fisherville', 38.0990200, -78.9691900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137186, 'Floris', 'Floris', 'Floris,Frying Pan', 38.9370600, -77.4127700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137187, 'Floyd', 'Floyd', 'Flojd,Floyd,Floyd Court House,Jacksonville,flwyd,Флојд,فلويد', 36.9112400, -80.3200500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137188, 'Forest', 'Forest', 'Forist,Форист', 37.3637500, -79.2897500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137189, 'Fort Lee', 'Fort Lee', '', 37.4957000, -77.3352600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137190, 'Franconia', 'Franconia', 'Franconia,Franconia Station,Frankonija,ZFO,Франкония', 38.7820600, -77.1463700, 'US', '2013-08-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137191, 'Franklin', 'Franklin', 'FKN,Franklin,Franklin Depot,Frenklin,Southampton,franklyn,franklyn  wyrjynya,frynkln  wrjynya,fu lan ke lin,furankurin,peulaengkeullin,Франклин,Френклин,فرانكلين,فرانکلین، ویرجینیا,فرینکلن، ورجینیا,フランクリン,富蘭克林,프랭클린', 36.6776500, -76.9224600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137192, 'Fredericksburg', 'Fredericksburg', 'Fredericksburg,Fredericksburg City,Fredericksburgh,Frederiksberg,Frederiksburg,Fredricksburg,Lease-Land,Leaselands,frdrykzbrg  wyrjynya,frydryksbywrgh,fu lei de li ke si bao,furederikkusubagu,peuledeoligseubeogeu,Фредериксберг,Фредериксбург,Фредеріксбург,فردریکزبرگ، ویرجینیا,فريدريكسبيورغ,فریڈرکزبرگ، ورجینیا,ფრედერიკსბურგი,フレデリックスバーグ,弗雷德里克斯堡,프레더릭스버그', 38.3031800, -77.4605400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137193, 'Front Royal', 'Front Royal', 'FRR,Front Rojal,Front Royal,Hell Town,Helltown,Lehewtown,frwnt rwyal,fu lan te luo ya er,Фронт Ројал,فرونت رويال,弗兰特罗亚尔', 38.9181700, -78.1944400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137194, 'Gainesville', 'Gainesville', 'Gejnsvil,Гејнсвил', 38.7956700, -77.6138800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137195, 'Galax', 'Galax', 'Bonaparte,Galax,Gejlaks,gai la ke si,galaks  wyrjynya,geirakusu,gylaks  wrjynya,jalaks,Гейлакс,Гејлакс,جالاكس,گالاکس، ویرجینیا,گیلاکس، ورجینیا,ゲイラクス,蓋拉克斯', 36.6612400, -80.9239700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137196, 'Gate City', 'Gate City', 'Estillville,Gate City,Winfield', 36.6378800, -82.5809900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137197, 'Glade Spring', 'Glade Spring', 'Glade Spring,Glejd Spring,Passawatomie,ghlayd sbryngh,glyd aspryng  wyrjynya,Глејд Спринг,غلايد سبرينغ,گلید اسپرینگ، ویرجینیا', 36.7912200, -81.7712300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137198, 'Glasgow', 'Glasgow', 'Glazgou,ghlaskw,Глазгоу,غلاسكو', 37.6340200, -79.4503100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137199, 'Glen Allen', 'Glen Allen', 'Glen Allen,Glenallen', 37.6659800, -77.5063700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137200, 'Gloucester Courthouse', 'Gloucester Courthouse', '', 37.4098600, -76.5266200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137201, 'Gloucester Point', 'Gloucester Point', 'Gloucester Point,Gloucester Town,Tindalls Point,Tyndalls Point', 37.2540300, -76.4968900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137202, 'Goochland', 'Goochland', 'Goochland,Goochland Court House,Guchland,Гучланд', 37.6843100, -77.8852700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137203, 'Gordonsville', 'Gordonsville', 'Beale Tavern,Gordonsvil,Gordonsville,ghwrdwnsfyl,Гордонсвил,غوردونسفيل,گورڈنزویل، ورجینیا', 38.1373600, -78.1877800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137204, 'Great Falls', 'Great Falls', 'Forestville,Great Falls,Grejt Fols,Грејт Фолс', 38.9981700, -77.2883200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137205, 'Greenbriar', 'Greenbriar', '', 38.8734500, -77.4008200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137206, 'Gretna', 'Gretna', 'Elba,Gretna,Sulphur Springs', 36.9537500, -79.3589100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137207, 'Grottoes', 'Grottoes', 'Grottoes,Mount Vernon Forge,Shendun', 38.2673500, -78.8258600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137208, 'Groveton', 'Groveton', '', 38.7673400, -77.0847000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137209, 'Grundy', 'Grundy', 'Grandi,Grundy,Mouth of Slate,ghrandy,Гранди,غراندي', 37.2778900, -82.0990200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137210, 'Halifax', 'Halifax', 'Banister,Halifax,Halifax Court House,Houston,Khalifaks,halfyks,Халифакс,هالفيكس', 36.7659700, -78.9283400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137211, 'Hampden Sydney', 'Hampden Sydney', 'Hampden Sidney,Hampden Sydney', 37.2423700, -78.4597200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137212, 'Hampton', 'Hampton', 'Elizabeth City,Gempton,Hampton,Hampton City,Hampton Town,Hamptonas,Kecoughtan,Khamptun,Khehmpton,Khempton,Kiccowtan,Kichotan,LFI,PHF,Southampton,haempeuteon,hambtwn,han pu dun,hanputon,hmptwn  wyrjynya,Гемптон,Хамптън,Хемптон,Хэмптон,هامبتون,همپتون، ویرجینیا,ہیمپٹن، ورجینیا,ハンプトン,漢普頓,햄프턴', 37.0298700, -76.3452200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137213, 'Hanover', 'Hanover', 'Hanover,Hanover Court House,Hanover Town', 37.7665300, -77.3702600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137214, 'Harrisonburg', 'Harrisonburg', 'Harisonburg,Harrisonburg,Harrisonburg City,Hub of the Valley,Kharisonburg,Rockingham Court House,Rocktown,ha li sen bao,harisonbagu,haryswnbwrgh,hryswnbrg  wyrjynya,Харисонбург,هاريسونبورغ,هریسونبرگ، ویرجینیا,ہیریسنبرگ، ورجینیا,ハリソンバーグ,哈里森堡', 38.4495700, -78.8689200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137215, 'Hayfield', 'Hayfield', '', 38.7517800, -77.1358100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137216, 'Haymarket', 'Haymarket', 'Hay-Market,Haymarket,Khejmarket,Red House,haymarkt,Хејмаркет,هايماركت', 38.8120600, -77.6363800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137217, 'Heathsville', 'Heathsville', 'Heath''s Store,Heathss Store,Heathsville,Heathsville Courthouse,Hughlet''s Tavern,Hughlets Tavern,Hughletts Indian Field,Hughletts Tavern,Khitsvil,Northumberland County Courthouse,Northumberland Courthouse,Rices Inn,Хитсвил', 37.9176300, -76.4721700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137218, 'Henry Fork', 'Henry Fork', '', 36.9662500, -79.8703100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137219, 'Herndon', 'Herndon', 'Kherndon,hrndn  wyrjynya,hyrndwn,Херндон,هرندن، ویرجینیا,هيرندون', 38.9695500, -77.3861000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137220, 'Highland Springs', 'Highland Springs', '', 37.5459800, -77.3277600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137221, 'Hillsville', 'Hillsville', '', 36.7626300, -80.7347900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137222, 'Hollins', 'Hollins', 'Enon,Hollins', 37.3412500, -79.9431000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137223, 'Hollymead', 'Hollymead', '', 38.1170800, -78.4416800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137224, 'Honaker', 'Honaker', 'Honaker,New Garden', 37.0162200, -81.9742900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137225, 'Hopewell', 'Hopewell', 'Khopuehlla,Khoupvel,hopuu~eru,huo pu wei er,hwbwyl,Хопуэлла,Хоупвел,هوبويل,هوپ‌ول، ویرجینیا,ہوپویل، ورجینیا,ホープウェル,霍普維爾', 37.3043200, -77.2872000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137226, 'Horse Pasture', 'Horse Pasture', '', 36.6284700, -79.9508700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137227, 'Huntington', 'Huntington', 'Khantington,Хантингтон', 38.7923400, -77.0708100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137228, 'Hurt', 'Hurt', 'Hurt,Hurt''s Store', 37.0926400, -79.2964100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137229, 'Hybla Valley', 'Hybla Valley', '', 38.7476100, -77.0830300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137230, 'Idylwood', 'Idylwood', 'Idlewood,Idlywood,Idylwood', 38.8951100, -77.2116500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137231, 'Independent Hill', 'Independent Hill', '', 38.6359500, -77.4377600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137232, 'Isle of Wight', 'Isle of Wight', 'Isle of Wight,Isle of Wight Court House', 36.9076500, -76.7077300, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137233, 'Jefferson', 'Jefferson', 'Dzhefferson,Джефферсон', 38.8645600, -77.1877600, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137234, 'Jolivue', 'Jolivue', '', 38.1098500, -79.0730800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137235, 'Jonesville', 'Jonesville', 'Dzounsvil,jwnsfyl,Џоунсвил,جونسفيل', 36.6889800, -83.1110000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137236, 'Kenbridge', 'Kenbridge', 'Browns Store,Kenbridge,Macfarlandss,McFarlands,Tinkling Spring,Tinkling Springs', 36.9620900, -78.1250000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137237, 'Kilmarnock', 'Kilmarnock', 'Crossroads,Kilmarnock,Kilmarnok,Steptoes Ordinary,kylmarnwk,Килмарнок,كيلمارنوك', 37.7104100, -76.3796700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137238, 'King George', 'King George', 'King George,King George Courthouse', 38.2681800, -77.1844200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137239, 'King William', 'King William', 'King William,King William Court House', 37.6873600, -77.0135800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137240, 'King and Queen Court House', 'King and Queen Court House', 'King and Queen,King and Queen Church,King and Queen Court House,King and Quenn', 37.6698600, -76.8774600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137241, 'Kings Park', 'Kings Park', '', 38.8062200, -77.2433200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137242, 'Lake Barcroft', 'Lake Barcroft', '', 38.8478900, -77.1558100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137243, 'Lake Monticello', 'Lake Monticello', '', 37.9232000, -78.3347300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137244, 'Lake Ridge', 'Lake Ridge', '', 38.6878900, -77.2977600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137245, 'Lakeside', 'Lakeside', '', 37.6076500, -77.4769300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137246, 'Lancaster', 'Lancaster', 'Lancaster,Lancaster Court House,Lankaster,Ланкастер', 37.7698600, -76.4663400, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137247, 'Laurel', 'Laurel', 'Hungary Station,Jenningsville School,Laurel', 37.6429200, -77.5088700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137248, 'Lawrenceville', 'Lawrenceville', 'LVL,Lawrenceville,Lorensvil,lawrnsfyl,Лоренсвил,لاورنسفيل', 36.7576500, -77.8469400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137249, 'Laymantown', 'Laymantown', '', 37.3656900, -79.8575400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137250, 'Lebanon', 'Lebanon', 'Lebanon,lbnan,Лебанон,لبنان', 36.9009400, -82.0801300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137251, 'Leesburg', 'Leesburg', 'George Town,Georgetown,Leesburg,Leesburgh,Lizburg,Louisburg,lysbwrgh,lyzbrg  wrjynya,Лизбург,ليسبورغ,لیزبرگ، ورجینیا', 39.1156600, -77.5636000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137252, 'Lexington', 'Lexington', 'Leksington,Lexington,Lexington City,Shrine of the South,ksynghtwn,legsingteon,lei xing dun,lksyngtwn  wyrjynya,rekishinton,Лексингтон,كسينغتون,لکسینگتون، ویرجینیا,لیکسنگٹن، ورجینیا,レキシントン,勒星頓,렉싱턴', 37.7840200, -79.4428200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137253, 'Lincolnia', 'Lincolnia', 'Fairland,Lincolnia,Linconia', 38.8184500, -77.1433100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137254, 'Linton Hall', 'Linton Hall', '', 38.7598400, -77.5749900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137255, 'Loch Lomond', 'Loch Lomond', '', 38.7862300, -77.4780400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137256, 'Lorton', 'Lorton', 'Lorton,loteon,Лортон,로턴', 38.7042800, -77.2277600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137257, 'Louisa', 'Louisa', 'Louisa,Louisa Court House,Luiza,lwyysa,Луиза,لوييسا', 38.0251400, -78.0041600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137258, 'Lovettsville', 'Lovettsville', 'Lavetsvil,Lovettsville,New Town,Thrashers Store,lwfwytsfyl,Лаветсвил,لوفويتسفيل', 39.2726000, -77.6366600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137259, 'Lovingston', 'Lovingston', '', 37.7598600, -78.8708600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137260, 'Lowes Island', 'Lowes Island', '', 39.0598300, -77.3522100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137261, 'Lunenburg', 'Lunenburg', 'Lewistown,Lunenburg,Lunenburg Court House,Lunenburgh Court House', 36.9609800, -78.2655500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137262, 'Luray', 'Luray', 'Lurej,lwray,Луреј,لوراي', 38.6654000, -78.4594500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137263, 'Lynchburg', 'Lynchburg', 'Campbell Court House,LYH,Linchberg,Linchburg,Lynchburg,Lynchs Ferry,Lynchs Warehouse,lin qi bao,linchibeogeu,lynchbrg  wrjynya,lynchbrg  wyrjynya,lynshbrgh,rinchibagu,Линчберг,Линчбург,Линчбърг,لينشبرغ,لینچبرگ، ورجینیا,لینچبرگ، ویرجینیا,リンチバーグ,林奇堡,린치버그', 37.4137500, -79.1422500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137264, 'Lyndhurst', 'Lyndhurst', '', 38.0293000, -78.9450200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137265, 'Madison', 'Madison', 'Madison,Madison Court House,Medison,Mehdison,madyswn,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,میڈیسون، ورجینیا', 38.3804100, -78.2575000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137266, 'Madison Heights', 'Madison Heights', '', 37.4309800, -79.1230800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137267, 'Manassas', 'Manassas', 'MNZ,Manasas,Manassa Junction,Manassas,Manassas City,ma na sa si,manasas,manasas  wrjynya,manasasu,mnass  wyrjynya,Манасас,Манассас,ماناساس,ماناساس، ورجینیا,مناسس، ویرجینیا,マナサス,馬納薩斯', 38.7509500, -77.4752700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137268, 'Manassas Park', 'Manassas Park', 'Manasas Park,Manassas-Park,bark manasas,ma na sa si pa ke,manasas park  wrjynya,manasasupaku,mnass park  wyrjynya,Манасас Парк,Манассас-Парк,بارك ماناساس,ماناساس پارک، ورجینیا,مناسس پارک، ویرجینیا,マナサスパーク,馬納薩斯帕克', 38.7840000, -77.4697100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137269, 'Mantua', 'Mantua', '', 38.8537200, -77.2594300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137270, 'Marion', 'Marion', 'Marion,Mehrion,Royal Oaks,marywn,marywn  wrjynya,Марион,Мэрион,ماريون,ماریون، ورجینیا', 36.8348400, -81.5148400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137271, 'Marshall', 'Marshall', 'Marshall,Salem', 38.8648400, -77.8577700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137272, 'Martinsville', 'Martinsville', 'Martinsvil,Martinsvill,Martinsville City,ma ding si wei er,martynsfyl,martynzwyl  wyrjynya,matinzubiru,Мартинсвил,Мартинсвилл,مارتينسفيل,مارتینزویل، ویرجینیا,مارٹنزویل، ورجینیا,マーティンズビル,馬丁斯維爾', 36.6915300, -79.8725400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137273, 'Massanetta Springs', 'Massanetta Springs', 'Massanetta Springs,Taylor Springs', 38.4004000, -78.8341900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137274, 'Massanutten', 'Massanutten', '', 38.4095700, -78.7378000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137275, 'Mathews', 'Mathews', 'Mathews,Mathews Court House,Matthews,Matthews Court House,Metjuz,Метјуз', 37.4370800, -76.3199400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137276, 'Matoaca', 'Matoaca', '', 37.2304300, -77.4774900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137277, 'McLean', 'McLean', 'Ingleside,Maklejn,Maklin,McLean,Маклејн,Маклин,مک‌لین، ویرجینیا', 38.9342800, -77.1774800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137278, 'Mechanicsville', 'Mechanicsville', 'Mekaniksvil,Меканиксвил', 37.6087600, -77.3733100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137279, 'Merrifield', 'Merrifield', 'Merrifield,Mills Cross Roads,Slabtown', 38.8742800, -77.2269300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137280, 'Merrimac', 'Merrimac', '', 38.4526300, -78.0786100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137281, 'Merrimac', 'Merrimac', 'Merrimac,Merrimac Mines,Merrimoc Mines', 37.1895700, -80.4256100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137282, 'Middletown', 'Middletown', 'Middleton,Middletown,Midltaun,New Middleton,Senseney Town,Senseny Town,mydltawn,Мидлтаун,ميدلتاون,مڈل ٹاؤن، ورجینیا', 39.0276100, -78.2805600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137283, 'Montclair', 'Montclair', '', 38.6109500, -77.3397100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137284, 'Monterey', 'Monterey', 'Bells Place,Highland,Monterej,Monterey,mwntyry,Монтерей,Монтереј,مونتيري', 38.4123400, -79.5806000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137285, 'Montrose', 'Montrose', '', 37.5207000, -77.3783100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137286, 'Montross', 'Montross', 'Mont Ross,Montross,Westmoreland Court House,Westmoreland Courthouse', 38.0951300, -76.8274600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137287, 'Motley', 'Motley', 'Motley,Motley''s Depot', 37.0695900, -79.3411400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137288, 'Mount Hermon', 'Mount Hermon', '', 36.6784700, -79.4222500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137289, 'Mount Jackson', 'Mount Jackson', 'Maunt DZekson,Mount Jackson,Mount Pleasant,mwnt jakswn,Маунт Џексон,مونت جاكسون', 38.7459500, -78.6422400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137290, 'Mountain Road', 'Mountain Road', '', 36.7595800, -78.9869600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137291, 'Narrows', 'Narrows', 'Intermont,Narrows,The Narrows,The Narrows of New River', 37.3315100, -80.8111900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137292, 'Narrows', 'Narrows', '', 37.2054200, -79.9589300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137293, 'Nellysford', 'Nellysford', 'Nellys Ford,Nellysford', 37.8904200, -78.8722400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137294, 'New Baltimore', 'New Baltimore', 'Balls Store,New Baltimore', 38.7673400, -77.7283300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137295, 'New Castle', 'New Castle', 'New Castle,New Fincastle,Newcastle', 37.5001300, -80.1108800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137296, 'New Market', 'New Market', 'Cross Roads,Crossroads,New Market,Newmarket,Nju Market,nyw markt,Њу Маркет,نيو ماركت', 38.6479000, -78.6714100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137297, 'Newington', 'Newington', 'Accotink Station,Newington,Truro Glebe', 38.7384500, -77.1849800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137298, 'Newport News', 'Newport News', 'N''juport-N''jus,New Port Newce,New Porte Newce,Newport Ness,Newport News,Newport Newse,Newport''s News,Newportes Newce,Newportes Newes,Newports News,PHF,Point Hope,Pointe Hope,Porte Newce,The New Port of the Newces,ZWW,Ньюпорт-Ньюс', 37.0833900, -76.4696500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137299, 'Nokesville', 'Nokesville', 'Noksvil,Ноксвил', 38.6987300, -77.5797100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137300, 'Norfolk', 'Norfolk', 'Gorad Norfalk,Norfok,Norfolk,Norfolk City,Norfolka,Norfolkas,Norfolko,ORF,narfwk  wrjynya,nofoku,nopeog,nuo fu ke,nwrfwk  wyrjynya,nwrfwlk,nwrpwq,Горад Норфалк,Норфок,Норфолк,נורפוק,نارفوک، ورجینیا,نورفولك,نورفوک، ویرجینیا,ნორფოლკი,ノーフォーク,諾福克,노퍽', 36.8468100, -76.2852200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137301, 'North Shore', 'North Shore', '', 37.0820900, -79.6583600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137302, 'North Springfield', 'North Springfield', '', 38.8042800, -77.2047000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137303, 'Norton', 'Norton', 'Norton,Norton City,Prince''s Flats,Princes Flats,noton,nuo dun,nwrtwn,nwrtwn  wyrjynya,Нортон,نورتون,نورتون، ویرجینیا,نورٹن، ورجینیا,ノートン,諾頓', 36.9334300, -82.6290500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137304, 'Oak Grove', 'Oak Grove', '', 38.9840000, -77.4038800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137305, 'Oakton', 'Oakton', 'Flint Hill,Oakton', 38.8809500, -77.3008200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137306, 'Occoquan', 'Occoquan', 'Colchester,Occoquan,Occoquon,Okokvon,awkwan,Ококвон,أوكوان', 38.6837300, -77.2602600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137307, 'Onancock', 'Onancock', 'Onancock,Onankok,Port of Entry,awnankwk,Онанкок,أونانكوك', 37.7118000, -75.7491000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137308, 'Orange', 'Orange', 'Orange,Orange Court House', 38.2454100, -78.1108300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137309, 'Palmyra', 'Palmyra', '', 37.8609700, -78.2633400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137310, 'Pannill Fork', 'Pannill Fork', '', 36.7090300, -80.0131000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137311, 'Passapatanzy', 'Passapatanzy', 'Passapatansy,Passapatanzy,Passpatansy', 38.2973500, -77.3141500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137312, 'Patrick Springs', 'Patrick Springs', 'Patrick Springs,Patrick Springs Station', 36.6418000, -80.1950500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137313, 'Pearisburg', 'Pearisburg', 'Pearisburg,Pearisburgh,Pearsburg,Perisburg,byrsbwrgh,Перисбург,بيرسبورغ', 37.3267300, -80.7370200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137314, 'Pembroke', 'Pembroke', 'Lybrooks,Pembroke', 37.3195700, -80.6389500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137315, 'Pennington Gap', 'Pennington Gap', '', 36.7584200, -83.0271100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137316, 'Petersburg', 'Petersburg', 'Appamatuck,Cockade City,Fals,Fort Henry,PTB,Peter''s Point,Peterburg,Peters Point,Petersburg,Petersburg City,Petersburgh,Pitersberg,Pitersburg,The Cockade City,bi de si bao,btrsbrgh,pitazubagu,piteoseubeogeu,pytrzbwrg  wyrjynya,Петербург,Питерсберг,Питерсбург,Пітерсбург,بطرسبرغ,پیترزبورگ، ویرجینیا,پیٹرزبرگ، ورجینیا,ピーターズバーグ,彼得斯堡,피터스버그', 37.2279300, -77.4019300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137317, 'Pimmit Hills', 'Pimmit Hills', 'Pimmit Hills,The Hills', 38.9128900, -77.2008100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137318, 'Poquoson', 'Poquoson', 'Jeffs,Po-co-son,Pokoson,Poquosin,Poquoson,bwkywswn,pakwsn  wyrjynya,pokoson,pu ku sen shi,pwkwyswn  wrjynya,Покосон,بوكيوسون,پاکوسن، ویرجینیا,پوکوئسون، ورجینیا,ポコソン,普庫森市', 37.1223700, -76.3457800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137319, 'Portsmouth', 'Portsmouth', 'Portsmouth,Portsmut,bwrtsmwth,pocheumeoseu,potsumasu,pu ci mao si,pwrtsmwt,pwrtsmwth  wyrjynya,Портсмут,פורטסמות,بورتسموث,پورتسموث، ویرجینیا,پورٹسماؤت، ورجینیا,ポーツマス,朴次茅斯,포츠머스', 36.8354300, -76.2982700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137320, 'Portsmouth Heights', 'Portsmouth Heights', '', 36.8209800, -76.3688300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137321, 'Potomac Mills', 'Potomac Mills', '', 38.6459500, -77.2941500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137322, 'Powhatan', 'Powhatan', 'Powhatan,Powhatan Court House,Powhatan Mennonite Church,Scottsville', 37.5420900, -77.9188900, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137323, 'Prices Fork', 'Prices Fork', 'Price Forks,Prices Fork,Prices Fork Village', 37.2098500, -80.4900500, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137324, 'Prince George', 'Prince George', 'Prince George,Prince George Court House,Prince Georges', 37.2204300, -77.2880300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137325, 'Pulaski', 'Pulaski', 'Martin''s Store,Martin''s Tank,Martins,Martins Station,Martins Tank,Pjulaski,Pulaski,Pulaski City,Pulaski Station,pu wa si ji,Пјуласки,普瓦斯基', 37.0479000, -80.7797900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137326, 'Purcellville', 'Purcellville', 'Perselvil,Purcell''s Store,Purcelli Villa,Purcells Store,Purcellville,Перселвил', 39.1367700, -77.7147200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137327, 'Radford', 'Radford', 'Central,Central Depot,Ingles Ferry,Lovely Mount,Radford,Radford Furnace,la de fu,radfwrd,radofodo,rdfwrd  wyrjynya,Радфорд,رادفورد,راڈفورڈ، ورجینیا,ردفورد، ویرجینیا,ラドフォード,拉德福', 37.1317900, -80.5764500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137328, 'Raven', 'Raven', '', 37.0870600, -81.8551200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137329, 'Ravensworth', 'Ravensworth', 'Ravensworth,Ravensworth Farm', 38.8040000, -77.2205400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137330, 'Reston', 'Reston', 'Reston,Thornton Station,Thornton''s Station,Wiehle,resuton,rstwn  wyrjynya,Рестон,رستون، ویرجینیا,レストン', 38.9687200, -77.3411000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137331, 'Richmond', 'Richmond', 'Gorad Rychmand,Manchester,None Such,RIC,Richmond,Richmond City,Richmund,Ricmonda,Ricmondas,Ricmondia,Ricmonds,Ritsmont,Ričmonda,Ričmondas,Ričmonds,Shoccoe''s,Shockoe,li shi man,lichimeondeu,lie zhi wen,rchmnڈ,ricamanda,ricmand,ricmant,ritchimondo,rychmwnd,rychmwnd  wyrjynya,rytshmwnd,ryzmwnd,Ρίτσμοντ,Горад Рычманд,Ричмонд,Ричмънд,Ռիչմոնդ,ריצמונד,ريتشموند,رچمنڈ,رچمنڈ، ورجینیا,ریچموند,ریچموند، ویرجینیا,रिचमंड,रिचमन्ड,रिच्मन्ड्,ரிச்மண்ட்,リッチモンド,列治文,里士满,리치먼드', 37.5537600, -77.4602600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137332, 'Richlands', 'Richlands', 'Richland,Richlands,Ричландс,رچلینڈs، ورجینیا', 37.0931700, -81.7937300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137333, 'Roanoke', 'Roanoke', 'Big Lick,Old Lick,ROA,Rawrenock,Rhoanoke,Roanok,Roanoke,Roanoke City,Rowrenoc,Rōwrenoc,Star City,Star City of the SouMagic City,The own,lo-eonokeu,luo a nuo ke,ro''anoka,roanoku,rwanwk,rwanwk  wrjynya,rwnwk  wyrjynya,Роанок,רואנוק,روانوك,روانوک، ورجینیا,رونوک، ویرجینیا,रोआनोक,ロアノーク,羅阿諾克,로어노크', 37.2709700, -79.9414300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137334, 'Rocky Mount', 'Rocky Mount', 'Mount Pleasant,Rocky Mount,Rockymount,Roki Maunt,Роки Маунт', 36.9976400, -79.8919800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137335, 'Rose Hill', 'Rose Hill', '', 38.7887200, -77.1127600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137336, 'Ruckersville', 'Ruckersville', 'Roggersville,Ruckersville', 38.2331900, -78.3691700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137337, 'Rural Retreat', 'Rural Retreat', 'Mount Airy,Rural Retreat', 36.8937300, -81.2759300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137338, 'Rushmere', 'Rushmere', 'Fergusons Wharf,Fergusson''s Wharf,Fergussons Wharf,Rushmere', 37.0668100, -76.6763500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137339, 'Rustburg', 'Rustburg', 'Campbell Court House,Rustburg,Rustburgh', 37.2768100, -79.1008500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137340, 'Salem', 'Salem', 'Fauquier,Salem,Salem City,Sejlem,sai lei mu,salm,seiramu,slym  wyrjynya,sylm  wrjynya,Салем,Сейлем,Сејлем,سالم,سلیم، ویرجینیا,سیلم، ورجینیا,セイラム,塞勒姆', 37.2934700, -80.0547600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137341, 'Saluda', 'Saluda', '', 37.6059700, -76.5949500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137342, 'Saltville', 'Saltville', 'Buffalo Lick,Perryville,Prestons Salines,Saltville,Soltvil,Солтвил', 36.8815000, -81.7620600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137343, 'Sandston', 'Sandston', 'Fairfield,Sandston', 37.5234800, -77.3158100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137344, 'Seven Corners', 'Seven Corners', '', 38.8720600, -77.1552600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137345, 'Shawnee Land', 'Shawnee Land', '', 39.1914900, -78.3455600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137346, 'Shawsville', 'Shawsville', 'Fort Vause,Shawsville', 37.1684700, -80.2553200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137347, 'Shenandoah', 'Shenandoah', 'Milnes,SHD,Shenandoa,Shenandoah,Shenandoah Furnace,Шенандоа', 38.4851200, -78.6250200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137348, 'Shenandoah Farms', 'Shenandoah Farms', '', 38.9817800, -78.0755500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137349, 'Short Pump', 'Short Pump', '', 37.6504200, -77.6124900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137350, 'Smithfield', 'Smithfield', 'Smitfild,Smitfildas,shi mi si fei er de,Смитфилд,سمتھفیلڈ، ورجینیا,史密斯菲尔德', 36.9823700, -76.6310700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137351, 'South Boston', 'South Boston', 'Dabbs,Juzhnaja Boston,Saut Boston,South Boston,South Boston Depot,bwstwn jnwby  wyrjynya,Саут Бостон,Южная Бостон,بوستون جنوبی، ویرجینیا', 36.6987500, -78.9014000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137352, 'South Hill', 'South Hill', '', 36.7265300, -78.1288900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137353, 'South Riding', 'South Riding', '', 38.9209400, -77.5038800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137354, 'South Suffolk', 'South Suffolk', '', 36.7170900, -76.5902300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137355, 'Spotsylvania', 'Spotsylvania', 'Spotsylvania,Spotsylvania Court House,Spottsylvania,Spottsylvania Court House', 38.2009600, -77.5891500, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137356, 'Spotsylvania Courthouse', 'Spotsylvania Courthouse', '', 38.1979100, -77.5877700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137357, 'Springfield', 'Springfield', 'Springfild,aspryngfyld  wyrjynya,Спрингфилд,اسپرینگفیلد، ویرجینیا,سپرنگفیلڈ، ورجینیا', 38.7892800, -77.1872000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137358, 'Springville', 'Springville', '', 37.1965100, -81.4028800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137359, 'Stafford', 'Stafford', 'Stafford,Stafford Census Designated Place,Stafford Court House,Stafford Courthouse', 38.4220700, -77.4083200, 'US', '2012-08-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137360, 'Stanardsville', 'Stanardsville', 'Stanardsville,Standardsville', 38.2973500, -78.4400100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137361, 'Stanley', 'Stanley', 'Marksville Station,Sands,Stanley,Stanleyton', 38.5754000, -78.5025100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137362, 'Stanleytown', 'Stanleytown', 'Edgewood,Edgewood Station,Stanleytown', 36.7443000, -79.9628200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137363, 'Staunton', 'Staunton', 'Augusta Court House,Mill Place,Stanton,Staunton,Staunton City,Stonton,astntwn  wyrjynya,si tang dun,stwntwn,sutanton,Стантон,Стонтон,استنتون، ویرجینیا,ستونتون,سٹانٹن، ورجینیا,スタントン,斯湯頓', 38.1499100, -79.0732000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137364, 'Stephens City', 'Stephens City', 'New Town,Newtonfield,Newtown,Newtown Stephensburg,Pantops,Stephens City,Stephensburg,Stevensburg,Stivens Siti,sutibunzushiti,Стивенс Сити,スティーブンズシティ', 39.0834400, -78.2180600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137365, 'Sterling', 'Sterling', 'Guilford,Guilford Station,Loudoun,Old Sterling,Sterling,Sturling,Whaleys Store,Стерлинг,Стърлинг', 39.0062200, -77.4286000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137366, 'Strasburg', 'Strasburg', 'Funk''s Mill,Funks Mills,Funkstown,Funktown,Pot Town,Pottown,Shenandoah River,Staufferstadt,Stovers Town,Stoverstown,Stovertown,Strasburg,Strasburgh,Strazburg,Стразбург', 38.9887200, -78.3586200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137367, 'Stuart', 'Stuart', 'Patrick Court House,Stjuart,Stuart,Taylorsville,Taylorville,Стјуарт', 36.6409700, -80.2656100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137368, 'Stuarts Draft', 'Stuarts Draft', 'Stewarts Draft,Stuart''s Draft,Stuarts Draft', 38.0301400, -79.0336400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137369, 'Sudley', 'Sudley', '', 38.7928900, -77.4974900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137370, 'Suffolk', 'Suffolk', 'Constances Warehouse,Contant''s Wharf,Saffolk,Safok,Sleepy Hole,Suffolk,Suffolk City,sa fu ke,safk  wyrjynya,safoku,seopeog,swfwlk,swfwlk  wrjynya,Сафок,Саффолк,سافک، ویرجینیا,سوفولك,سوفولک، ورجینیا,サフォーク,薩福克,서퍽', 36.7283600, -76.5849600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137371, 'Sugarland Run', 'Sugarland Run', '', 39.0376100, -77.3752600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137372, 'Surry', 'Surry', 'Cross Roads,McIntosh''s Cross Roads,McIntoshs Cross Roads,Sari,Scuffletown,Smithville,Surry,Surry Court House,The Crossroads,Сари', 37.1379300, -76.8352400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137373, 'Sussex', 'Sussex', 'Sussex,Sussex Courthouse', 36.9151500, -77.2791400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137374, 'Tappahannock', 'Tappahannock', 'Hobbes Hole,Hobbs His Hole,Hobbs Hold,Hobbs Hole,Hobs Hole,New Plymouth,Tapakhanok,Tappahannock,Tappanhannocke Towne,Washington,Тапаханок', 37.9254100, -76.8591300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137375, 'Tazewell', 'Tazewell', 'Jeffersonville,Tazewell,Tazewell Courthouse,Tazvel,ta ci wei er,Тазвел,塔兹韦尔', 37.1148400, -81.5195500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137376, 'Timberlake', 'Timberlake', 'Timber Lake,Timberlake', 37.3207000, -79.2575300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137377, 'Timberville', 'Timberville', 'Riddle''s Tavern,Riddles Tavern,Thompson''s Store,Thompsons Store,Timberville,Williamsport', 38.6390100, -78.7739100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137378, 'Triangle', 'Triangle', '', 38.5467900, -77.3366500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137379, 'Tuckahoe', 'Tuckahoe', '', 37.5901500, -77.5563800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137380, 'Tysons Corner', 'Tysons Corner', 'Peach Grove,Peach Grove Crossroads,Tajsons Korner,Tyson''s Corner,Tysons Corner,Tysons Cross Roads,Tysons Crossroads,tayswnz krnr  wyrjynya,Тајсонс Корнер,تایسونز کرنر، ویرجینیا', 38.9187200, -77.2310900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137381, 'Union Hall', 'Union Hall', '', 37.0187500, -79.6864200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137382, 'University Center', 'University Center', '', 39.0570500, -77.4441500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137383, 'Verona', 'Verona', 'Bowlings Mill,Rolla,Vernon,Verona,Verona Station', 38.2020800, -79.0083600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137384, 'Victoria', 'Victoria', 'Viktorija,Виктория,Викторија,وکٹوریہ، ورجینیا', 36.9948700, -78.2272200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137385, 'Vienna', 'Vienna', 'Ayr Hill,Vienna,Vijena,vu~ina,wyana  wrjynya,Вијена,ویانا، ورجینیا,ヴィーナ', 38.9012200, -77.2652600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137386, 'Vinton', 'Vinton', 'Gishs Mill,Vinton', 37.2809700, -79.8969800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137387, 'Virginia Beach', 'Virginia Beach', 'Gorad Virdzhynija-Bich,Litus Virginiae,Verdzhinija-Bich,Vijini Beach,Virciniya Bic,Virciniya Biç,Virdzhini-Bich,Virdzhinija Bijch,Virdzhinija-Bich,Virdzinija Bich,Virdzinija Bycas,Virdzinijabica,Virdžinija Byčas,Virdžīnijabīča,Virginia Beach,Virginia Beach City,Virginija-Bich,Virgìnia Beach,Virtzinia Bits,bajiniabichi,beojiniabichi,bharjiniya bica,frjynya bytsh,vharjiniya bica,virjinia-bichi,wei zhen ni ya hai tan,wexr ci neiy bich,wrjynya bych,wyrgynyh byz,wyrjynya bych  wyrjynya,Βιρτζίνια Μπιτς,Верджиния-Бич,Виргиния-Бич,Вирджини-Бич,Вирджиния Бийч,Вирджиния-Бич,Вирџинија Бич,Вірджинія-Біч,Горад Вірджынія-Біч,Վիրջինիա Բիչ,וירגיניה ביץ,فرجينيا بيتش,ورجینیا بیچ,ویرجینیا بیچ، ویرجینیا,व्हर्जिनिया बीच,ভার্জিনিয়া বিচ,เวอร์จิเนียบีช,ვირჯინია-ბიჩი,バージニアビーチ,維珍尼亞海灘,버지니아비치', 36.8529300, -75.9779900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137388, 'Warm Springs', 'Warm Springs', 'Bath Court House,Warm Springs', 38.0462400, -79.7906100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137389, 'Warrenton', 'Warrenton', 'Fauquier Court House,Red Store,Vorenton,Warrenton,Ворентон,وارنٹن، ورجینیا', 38.7134500, -77.7952700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137390, 'Warsaw', 'Warsaw', 'Richmond County Courthouse,Richmond Court House,Richmond Courthouse,Vorso,Warsaw,warsa  wrjynya,Ворсо,وارسا، ورجینیا', 37.9587400, -76.7580100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137391, 'Washington', 'Washington', 'Vashington,Вашингтон,واشنگٹن، ورجینیا', 38.7134500, -78.1594400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137392, 'Wattsville', 'Wattsville', 'Chincoteague Crossroads,Wattsville', 37.9340100, -75.4996500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137393, 'Waverly', 'Waverly', 'Blackwater Depot,Waverly,Waverly Station', 37.0359800, -77.0952400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137394, 'Waynesboro', 'Waynesboro', 'Teesville,Vejnsboro,Waynesboro,Waynesborough,u~einzuboro,waynysbwrw,wei en si bo lei,wynzbwrw  wyrjynya,wyynzbwrw  wrjynya,Вејнсборо,واينيسبورو,ویئنزبورو، ورجینیا,وینزبورو، ویرجینیا,ウェインズボロ,韋恩斯伯勒', 38.0684700, -78.8894700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137395, 'Weber City', 'Weber City', '', 37.7551400, -78.2838900, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137396, 'Weber City', 'Weber City', 'Moccasin Gap,Weber City', 36.6228800, -82.5621000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137397, 'West Falls Church', 'West Falls Church', '', 38.8909400, -77.1844300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137398, 'West Gate', 'West Gate', '', 38.7828900, -77.4974900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137399, 'West Lynchburg', 'West Lynchburg', '', 37.4032000, -79.1780800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137400, 'West Point', 'West Point', 'Cinquoteck,Delaware,Delaware Town,Deleware Town,King and Queen,Opechancanough,Pamunkee,Pamunkey,Pumunkey Town,The Point,Vest Pojnt,West Point,Westpoint,Wests Point,Вест Појнт,ویسٹ پوائنٹ، ورجینیا', 37.5315300, -76.7963500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137401, 'West Springfield', 'West Springfield', 'Fairfax Park,West Springfield', 38.7726100, -77.2210900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137402, 'Weyers Cave', 'Weyers Cave', 'Weyer Cave Station,Weyers Cave', 38.2884600, -78.9130800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137403, 'Williamsburg', 'Williamsburg', 'Middle Plantation,Uil''jamsberg,Uiljamsburg,Vilijamsburg,Williamsbourg,Williamsburg,Williamsburg City,Williamsburg i Virginia,ZWB,u~iriamuzubagu,wei lian si bao,willieomseubeogeu,wylmzbrg  wrjynya,wylyamzbrg  wyrjynya,wylyamzbrgh,Вилијамсбург,Уильямсберг,Уилямсбърг,ويليامزبرغ,ویلمزبرگ، ورجینیا,ویلیامزبرگ، ویرجینیا,ウィリアムズバーグ,威廉斯堡,윌리엄스버그', 37.2707000, -76.7074600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137404, 'Winchester', 'Winchester', 'Frederick Town,Fredericktown,Old Town,Opequon,Uinchestur,Vinchester,WGO,Winchester,u~inchesuta,wen che si te,wincheseuteo,wynchstr  wyrjynya,wynshstr,Винчестер,Уинчестър,ونچیسٹر، ورجینیا,وينشستر,وینچستر، ویرجینیا,ウィンチェスター,溫徹斯特,윈체스터', 39.1856600, -78.1633300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137405, 'Windsor', 'Windsor', 'Vindzor,Windsor,Windsor Station,Виндзор', 36.8084800, -76.7441200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137406, 'Wolf Trap', 'Wolf Trap', '', 38.9398300, -77.2860900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137407, 'Woodbridge', 'Woodbridge', 'Occoquan Plantation,Occoquon Station,Vudbridz,Woodbridge,Woolbridge,Вудбриџ,وڈبرج، ورجینیا', 38.6581700, -77.2497000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137408, 'Woodlawn', 'Woodlawn', 'Wood Lawn,Woodlawn', 36.7223500, -80.8228500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137409, 'Woodlawn', 'Woodlawn', '', 38.7167800, -77.1327600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137410, 'Woodstock', 'Woodstock', 'Millers Town,Millertown,Mullerstadt,Vudstok,Woodstock,Вудсток', 38.8817800, -78.5058400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137411, 'Wyndham', 'Wyndham', '', 37.6984800, -77.6124900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137412, 'Wytheville', 'Wytheville', 'Abbeville,Evansham,Vidvil,Wytheville,wei si wei er,Видвил,威斯维尔', 36.9484500, -81.0848100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137413, 'Yorkshire', 'Yorkshire', '', 38.7931700, -77.4477700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137414, 'Alderson', 'Alderson', 'Alderson,Aldersons Ferry,aldrswn  wyrjynyay ghrby,Алдерсон,آلدرسون، ویرجینیای غربی', 37.7259500, -80.6420200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137415, 'Alum Creek', 'Alum Creek', 'Alum Creek,Rome', 38.2867600, -81.8051300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137416, 'Ansted', 'Ansted', 'Ansted,New Haven,Woodville', 38.1362200, -81.0995500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137417, 'Barboursville', 'Barboursville', '', 38.4095300, -82.2945900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137418, 'Barrackville', 'Barrackville', 'Barracksville,Barrackville', 39.5037000, -80.1667500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137419, 'Beaver', 'Beaver', 'Beaver,Beever,Glen Hedrick', 37.7478100, -81.1435200, 'US', '2015-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137420, 'Beckley', 'Beckley', 'BKW,Beckley,Beckleyville,Bekli,Raleigh,Raleigh Court House,bekeulli,bkly  wyrjynyay ghrby,Бекли,بکلی، ویرجینیای غربی,베클리', 37.7781700, -81.1881600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137421, 'Belington', 'Belington', 'Barker Settlement,Belington,Laurel Hill', 39.0251000, -79.9356300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137422, 'Belle', 'Belle', '', 38.2320500, -81.5376200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137423, 'Berkeley Springs', 'Berkeley Springs', 'Bath,Berkeley,Berkeley Springs,Warm Springs', 39.6248000, -78.2247200, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137424, 'Bethlehem', 'Bethlehem', 'Bethlehem,Scott', 39.3920300, -80.2806400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137425, 'Blennerhassett', 'Blennerhassett', '', 39.2636900, -81.6292900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137426, 'Bluefield', 'Bluefield', 'BLF,Beaver Pond Spring,Beaver Pond Springs,Bluefield,Blufijld,Blufild,blwfyld,blwfyld  wyrjynyay ghrby,burufirudo,Блуфийлд,Блуфилд,بلوفيلد,بلوفیلد، ویرجینیای غربی,ブルーフィールド', 37.2698400, -81.2223200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137427, 'Bluewell', 'Bluewell', 'Bluewell,Dolph', 37.3126200, -81.2598200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137428, 'Boaz', 'Boaz', '', 39.3614600, -81.5020700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137429, 'Bolivar', 'Bolivar', 'Bolivar,Mudfort', 39.3234300, -77.7527700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137430, 'Bradley', 'Bradley', 'Baileys Farm,Bradley', 37.8653900, -81.1939900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137431, 'Bridgeport', 'Bridgeport', 'Bridgeport,Powers Fort', 39.2864800, -80.2562000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137432, 'Brookhaven', 'Brookhaven', 'Brookhaven,Richard', 39.6117500, -79.9045100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137433, 'Brush Fork', 'Brush Fork', 'Brush Fork,Brushy Fork', 37.2809500, -81.2559300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137434, 'Buckhannon', 'Buckhannon', 'Bakkhannon,Bakkhanon,Buchanon,Buckhannon,Buckhannon Town,Buckwheat,Bush Fort,bwkhanwn  wyrjynyay ghrby,bywkanan,Бакханнон,Бакханон,بوکهانون، ویرجینیای غربی,بيوكانان', 38.9939900, -80.2320300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137435, 'Buffalo', 'Buffalo', 'Buffalo,Буффало', 38.6175900, -81.9818000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137436, 'Ceredo', 'Ceredo', '', 38.3964700, -82.5587700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137437, 'Chapmanville', 'Chapmanville', '', 37.9737100, -82.0173500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137438, 'Charles Town', 'Charles Town', 'Charl''z-Taun,Charles Town,Charlestown,Charls Taun,cha er si zhen,charlz tawn  wyrjynyay ghrby,tsharlz tawn,Чарлс Таун,Чарльз-Таун,تشارلز تاون,چارلز تاون، ویرجینیای غربی,چارلس ٹاؤن، مغربی ورجینیا,查尔斯镇', 39.2889900, -77.8597200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137439, 'Charleston', 'Charleston', 'CRW,Carlstona,Carlstonas,Carlstons,Carolopolis,Charles Town,Charleston,Charleston i Vest-Virginia,Charleston-on-the-Kanawha,Charlestown,Charlston,Charlstun,Clendenin''s Settlement,Clendenins Fort,Clendenins Settlement,Fort Clendennin,Fort Lee,Gorad Charlstan,Kanawha,Kanawha Court House,Mouth of Elk,The Town at the Mouth of Elk,Tsarlston,carlsatan,carlsatana,carlstan,carlstana,cha er si dun,chalseuteon,charlstwn,charusuton,tsharlstwn,zʼrlstwn,Čarlstonas,Čarlstons,Čārlstona,Τσάρλστον,Горад Чарлстан,Чарлстон,Чарлстън,Չարլսթոն,צארלסטון,تشارلستون,چارلستون,چارلسٹن,چارلسٹن، مغربی ورجینیا,चार्ल्सटन,चार्ल्सटन्,चार्ल्स्टन,சார்ல்ஸ்டன்,チャールストン,查尔斯顿,찰스턴', 38.3498200, -81.6326200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137440, 'Cheat Lake', 'Cheat Lake', '', 39.6720200, -79.8533900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137441, 'Chesapeake', 'Chesapeake', 'Chesapeake,Chesapik,Henson,Чесапик', 38.2234400, -81.5362300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137442, 'Clarksburg', 'Clarksburg', 'CKB,Clarkes Town,Clarkesburg,Clarkesburgh,Clarksburg,Klarksberg,Klarksburg,ke la ke si bao,klarksbrg  mghrby wrjynya,klarksbrg  wyrjynyay ghrby,klarksbwrgh,kurakusubagu,Кларксберг,Кларксбург,كلاركسبورغ,کلارکسبرگ، مغربی ورجینیا,کلارکسبرگ، ویرجینیای غربی,クラークスバーグ,克拉克斯堡', 39.2806500, -80.3445300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137443, 'Clay', 'Clay', 'Clay,Clay Court House,Clay Town,Claytown,Henry,Klej,Marshall,klay,kly  wyrjynyay ghrby,Клей,Клеј,كلاي,کلی، ویرجینیای غربی', 38.4603800, -81.0851100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137444, 'Clendenin', 'Clendenin', 'Chilton,Clendenin,Clendennen,Clendennin,Glendenin', 38.4887100, -81.3481700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137445, 'Coal City', 'Coal City', 'Abney,Coal City', 37.6790000, -81.2103800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137446, 'Coal Fork', 'Coal Fork', '', 38.3176000, -81.5209500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137447, 'Crab Orchard', 'Crab Orchard', 'Crab Orchard,Craborchard', 37.7406700, -81.2306600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137448, 'Craigsville', 'Craigsville', 'Craigsville,Craigville,Signboard,Signpost', 38.3306700, -80.6531500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137449, 'Cross Lanes', 'Cross Lanes', 'Cross Lanes,Crosslanes,Fry', 38.4203700, -81.7906800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137450, 'Culloden', 'Culloden', '', 38.4200900, -82.0554200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137451, 'Daniels', 'Daniels', '', 37.7432700, -81.1240800, 'US', '2015-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137452, 'Despard', 'Despard', '', 39.2887000, -80.3059200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137453, 'Dunbar', 'Dunbar', '', 38.3606500, -81.7373500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137454, 'Eleanor', 'Eleanor', 'Eleanor,Red House Farms', 38.5375900, -81.9323600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137455, 'Elizabeth', 'Elizabeth', 'Beauchamps Mills,Ehlizabet,Elizabet,Elizabeth,Jacksonville,Wirt House,alyzabyth,aylyzbt  wyrjynyay ghrby,Елизабет,Элизабет,إليزابيث,الزبتھ، مغربی ورجینیا,ایلیزبت، ویرجینیای غربی', 39.0634100, -81.3951200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137456, 'Elkins', 'Elkins', 'EKN,Ehlkins,Elkins,Joans Friends,Jonas Friends,Leadsville,Leeds Village,Leedsville,alkyns  wyrjynyay ghrby,alkynz,erukinzu,Елкинс,Элкинс,إلكينز,الکینس، ویرجینیای غربی,エルキンズ', 38.9259400, -79.8467300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137457, 'Elkview', 'Elkview', 'Elk View,Elkview', 38.4428800, -81.4804000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137458, 'Fairlea', 'Fairlea', '', 37.7806800, -80.4570200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137459, 'Fairmont', 'Fairmont', 'Fairmont,Fehrmont,Fermont,Middletown,Palatine,Polsley,Polsleys,Polsleys Mill,Polsleys Mills,feamonto,fei er meng te,frmwnt  wyrjynyay ghrby,fyrmwnt,Фермонт,Фэрмонт,فرمونت، ویرجینیای غربی,فيرمونت,فیئرمونٹ، مغربی ورجینیا,フェアモント,费尔蒙特', 39.4850800, -80.1425800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137460, 'Fayetteville', 'Fayetteville', 'Fayetteville,Fejetvil,Fejetvill,Vandalia,faytfyl,fyytwyl  wyrjynyay ghrby,Фейетвилл,Фејетвил,فايتفيل,فییتویل، ویرجینیای غربی', 38.0528900, -81.1039900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137461, 'Fort Ashby', 'Fort Ashby', 'Alaska,Fort Ashby,Frankford,Frankfort,Pattersons Creek', 39.5031500, -78.7686300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137462, 'Franklin', 'Franklin', 'Frankford,Frankfort,Franklin,Frenklin,franklyn,frnklyn  wyrjynyay ghrby,frynkln  mghrby wrjynya,Франклин,Френклин,فرانكلين,فرنکلین، ویرجینیای غربی,فرینکلن، مغربی ورجینیا', 38.6428900, -79.3311500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137463, 'Gilbert Creek', 'Gilbert Creek', '', 37.5759400, -81.8948400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137464, 'Glenville', 'Glenville', 'Glenvil,Glenvill,Glenville,Hartford,Stewarts Creek,The Ford,ge lin wei er,ghlynfyl,glnwyl  wyrjynyay ghrby,Гленвил,Гленвилл,غلينفيل,گلنویل، ویرجینیای غربی,格林维尔', 38.9342600, -80.8376000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137465, 'Glendale', 'Glendale', 'GWV,Glen Dale,Glendale,Gravel Bottom,Hells Half Acre,Upper Flats', 39.9492400, -80.7542500, 'US', '2015-10-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137466, 'Grafton', 'Grafton', 'Gannett,Grafton,Grafton Junction,Three Forks,Three Forks Creek,ghraftwn,grftn  wyrjynyay ghrby,Графтон,غرافتون,گرفتن، ویرجینیای غربی', 39.3409200, -80.0189700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137467, 'Granville', 'Granville', 'Grandville,Granville,Mona', 39.6459100, -79.9872900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137468, 'Grantsville', 'Grantsville', 'Grantsvil,ghrantsfyl,grantswyl  wyrjynyay ghrby,Грантсвил,غرانتسفيل,گرانتسویل، ویرجینیای غربی', 38.9234200, -81.0959500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137469, 'Hamlin', 'Hamlin', 'Hamlin,Hamline Church,Khamlin,hamlyn,hmlyn  wyrjynyay ghrby,Хамлин,هاملين,هملین، ویرجینیای غربی', 38.2787000, -82.1029200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137470, 'Harrisville', 'Harrisville', 'Harrisville,Kharisvil,Kharrisvill,Ritchie Court House,Solus,harysfyl,haryswyl,Харисвил,Харрисвилл,هاريسفيل,هاریسویل', 39.2095200, -81.0517800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137471, 'Hinton', 'Hinton', 'Hinton,Khinton,Upper Hinton,hyntwn,hyntwn  wyrjynyay ghrby,Хинтон,هينتون,هینتون، ویرجینیای غربی,ہنٹن، مغربی ورجینیا', 37.6740100, -80.8892500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137472, 'Huntington', 'Huntington', 'Gantington,Guyandot,Guyandotte,HTS,Holderbys Landing,Huntington,Khantington,Khuntingtun,Maple Grove,hantinton,hantyngtwn  wyrjynyay ghrby,heng ting dun,heontingteon,hnghtynghtwn,Гантінґтон,Хантингтон,Хънтингтън,האנטינגטון,هانتینگتون، ویرجینیای غربی,هنغتينغتون,ہنٹنگٹن، مغربی ورجینیا,ハンティントン,亨廷顿,헌팅턴', 38.4192500, -82.4451500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137473, 'Hurricane', 'Hurricane', '', 38.4325900, -82.0201400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137474, 'Inwood', 'Inwood', '', 39.3578800, -78.0400000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137475, 'Kenova', 'Kenova', 'Kenova,Morganza,Virginia Point', 38.3989700, -82.5782100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137476, 'Keyser', 'Keyser', 'Kajzer,Keyser,Kiser,New Creek,New Creek Station,Paddy Town,Paddys Town,Paddytown,kysr  wyrjynyay ghrby,kysyr,Кайзер,Кисер,كيسير,کیسر، ویرجینیای غربی', 39.4409300, -78.9739200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137477, 'Kingwood', 'Kingwood', 'Kingvud,Kingwood,The Kings Woods,kynghwwd,kyngwwd  wyrjynyay ghrby,Кингвуд,كينغوود,کینگوود، ویرجینیای غربی', 39.4717600, -79.6833900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137478, 'Lavalette', 'Lavalette', 'Lavalette,Lavelette', 38.3228600, -82.4468200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137479, 'Lesage', 'Lesage', 'Carsons Landing,Dickeys Landing,Le Sage,Lesage,Lesages', 38.5064700, -82.2984800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137480, 'Lewisburg', 'Lewisburg', 'Big Levels,Camp Union,Fort Savannah,Fort Union,LWB,Lewisburg,Lewisburgh,Luisburg,Savannah,The Savannah,lwysbrgh,lwysbwrg  wyrjynyay ghrby,lwyysbrg  mghrby wrjynya,Луисбург,لوئیسبرگ، مغربی ورجینیا,لويسبرغ,لویسبورگ، ویرجینیای غربی', 37.8017900, -80.4456300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137481, 'Logan', 'Logan', 'Aracoma,Arracoina,Arracoma,Lawnsville,Logan,Logan Court House,Logan Courthouse,Logantown,lwghan,lwwgn  wyrjynyay ghrby,Логан,لوغان,لووگن، ویرجینیای غربی', 37.8487100, -81.9934600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137482, 'Lubeck', 'Lubeck', '', 39.2353500, -81.6312400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137483, 'Mabscott', 'Mabscott', '', 37.7709500, -81.2084300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137484, 'MacArthur', 'MacArthur', 'Hollywood,MacArthur', 37.7584500, -81.2126000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137485, 'Madison', 'Madison', 'Boone Court House,Madison,Medison,Mehdison,madyswn,mdyswn  wyrjynyay ghrby,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مدیسون، ویرجینیای غربی,میڈیسون، مغربی ورجینیا', 38.0670500, -81.8192900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137486, 'Mallory', 'Mallory', '', 37.7306600, -81.8379000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137487, 'Mannington', 'Mannington', 'Coontown,Koontown,Manington,Mannington,manynghtwn,manyngtwn  wyrjynyay ghrby,Манингтон,مانينغتون,مانینگتون، ویرجینیای غربی', 39.5309200, -80.3434200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137488, 'Marlinton', 'Marlinton', 'Marlin''s Bottom,Marling Bottom,Marlings,Marlington,Marlins,Marlins Bottom,Marlinton,marlyntwn,marlyntwn  wyrjynyay ghrby,Марлинтон,مارلينتون,مارلینتون، ویرجینیای غربی', 38.2234500, -80.0945100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137489, 'Marmet', 'Marmet', 'Brownstown,Brownsville,Lens Creek,Marmet', 38.2453800, -81.5670600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137490, 'Martinsburg', 'Martinsburg', 'MRB,Martinopolis,Martins Town,Martins-Burgh,Martinsberg,Martinsburg,Martinsburgh,Martinsville,ma ding si bao,martynzbrg  wyrjynyay ghrby,matinjeubeogeu,matinzubagu,mrtynsbwrgh,Мартинсберг,Мартинсбург,Мартінсбург,مارتینزبرگ، ویرجینیای غربی,مارٹنسبرگ، مغربی ورجینیا,مرتينسبورغ,マーティンズバーグ,马丁斯堡,마틴즈버그', 39.4562100, -77.9638900, 'US', '2017-07-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137491, 'McMechen', 'McMechen', '', 39.9881300, -80.7314700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137492, 'Middlebourne', 'Middlebourne', 'Middlebourn,Middlebourne,Middleburn,Midlvorn,mydlbwrn,mydlbwrn  wyrjynyay ghrby,Мидлворн,ميدلبورن,میدلبورن، ویرجینیای غربی', 39.4923000, -80.9037200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137493, 'Milton', 'Milton', 'Mil''ton,Milton,Milton-on-the-Mud,Mud River Bridge,Мильтон', 38.4345300, -82.1323600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137494, 'Mineral Wells', 'Mineral Wells', 'Mineral Wells,Mineralwells', 39.1903500, -81.5320700, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137495, 'Monongah', 'Monongah', 'Briar Town,Briartown,Monogah,Monongah', 39.4625800, -80.2181400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137496, 'Montgomery', 'Montgomery', 'Coal Valley,Coal Valley City,Montgomeri,Montgomery,Montgomery''s Ferry,Montgomery''s Landing,Montgomerys Landing,mantgamry  wyrjynyay ghrby,meng ge ma li,mwntghmry,Монтгомери,مانتگامری، ویرجینیای غربی,مونتغمري,مونٹگمری، مغربی ورجینیا,蒙哥馬利', 38.1803800, -81.3284500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137497, 'Moorefield', 'Moorefield', 'Moorefield,Moorefields,Moorfields,Murfild,mwrfyld,mwrfyld  wyrjynyay ghrby,Мурфилд,مورفيلد,مورفیلد، ویرجینیای غربی,مورفیلڈ، مغربی ورجینیا', 39.0623300, -78.9694700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137498, 'Morgantown', 'Morgantown', 'MGW,Monongahela Court House,Morgan Town,Morganopolis,Morgans Town,Morgans-Town,Morganstown,Morgantaun,Morgantown,mo gen dui,mogantaun,mogeontaun,mrgntawn  wyrjynyay ghrby,mwrghantawn,Моргантаун,مرگنتاون، ویرجینیای غربی,مورغانتاون,مورگن ٹاؤن، مغربی ورجینیا,モーガンタウン,摩根敦,모건타운', 39.6295300, -79.9559000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137499, 'Moundsville', 'Moundsville', 'Elizabeth,Elizabeth Town,Elizabethtown,Flats of Grave Creek,Grave Creek,Grave Creek Flats,Maundsvil,Maundsvill,Mound City,Moundsville,Mount Elizabeth,mawndzwyl  wyrjynyay ghrby,mwwndsfyl,Маундсвил,Маундсвилл,ماوندزویل، ویرجینیای غربی,مووندسفيل', 39.9203500, -80.7431400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137500, 'Mount Hope', 'Mount Hope', '', 37.8953900, -81.1642700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137501, 'Mullens', 'Mullens', 'Malins,Millers,Mullens,Mullins,maln  wyrjynyay ghrby,mwlns,Малинс,مالن، ویرجینیای غربی,مولنس', 37.5831700, -81.3803800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137502, 'New Martinsville', 'New Martinsville', 'Fishing Creek,Martinsville,Mouth of Fishing Creek,N''ju-Martinsvill,New Martinsville,Nju Martinsvil,nyw martnzwyl  wyrjynyay ghrby,nyw martynsfyl,Њу Мартинсвил,Нью-Мартинсвилл,نيو مارتينسفيل,نیو مارتنزویل، ویرجینیای غربی', 39.6445200, -80.8576000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137503, 'New Haven', 'New Haven', 'N''ju-Khejven,New Haven,New London,Newhaven,Нью-Хейвен', 38.9864700, -81.9734700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137504, 'Nitro', 'Nitro', 'Crawford City,Nitro', 38.4148100, -81.8440200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137505, 'Nutter Fort', 'Nutter Fort', 'Norwood,Nutter Fort,Stonewall Park', 39.2634200, -80.3198100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137506, 'Oak Hill', 'Oak Hill', 'Oak Hill,Oakhill', 37.9723300, -81.1487100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137507, 'Oceana', 'Oceana', 'Cassville,Cookes,Ginseng,Occana,Oceana,Sumpterville,Wyoming Court House', 37.6920600, -81.6240000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137508, 'Paden City', 'Paden City', 'Paden City,Paden Valley,Paden''s Bottom,Paden''s Valley,Padens Valley,Padensvalley,Padenvalley', 39.6028500, -80.9367700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137509, 'Parkersburg', 'Parkersburg', 'Neals Landing,Neals Station,Newport,PKB,Parkersberg,Parkersburg,Parkersburgh,Parkursburg,Stokelyville,The Point,barkrsbwrgh,pa ke si bao,pakazubagu,pakeojeubeogeu,parkrzbrg  mghrby wrjynya,parkrzbrg  wyrjynyay ghrby,Паркерсберг,Паркерсбург,Паркърсбърг,باركرسبورغ,پارکرزبرگ، مغربی ورجینیا,پارکرزبرگ، ویرجینیای غربی,パーカーズバーグ,帕克斯堡,파커즈버그', 39.2667400, -81.5615100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137510, 'Parsons', 'Parsons', 'Parsons,The River City,barswnz,parswnz  wyrjynyay ghrby,Парсонс,بارسونز,پارسونز، ویرجینیای غربی', 39.0964900, -79.6809000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137511, 'Pea Ridge', 'Pea Ridge', '', 38.4139700, -82.3198700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137512, 'Pennsboro', 'Pennsboro', 'Pennsboro,Pennsborough', 39.2850800, -80.9684400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137513, 'Petersburg', 'Petersburg', 'Grant Court House,Luney''s Creek,Luneys Creek,Lunice Creek,Peterburg,Petersburg,Petersburgh,Petroburgum,Pitersberg,Pitersburg,btrsbwrgh,pytrzbrg  wyrjynyay ghrby,Петербург,Питерсберг,Питерсбург,بطرسبورغ,پیترزبرگ، ویرجینیای غربی,پیٹرزبرگ، مغربی ورجینیا', 38.9926100, -79.1239200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137514, 'Philippi', 'Philippi', 'Anglin''s Ford,Anglins Ford,Booth''s Ferry,Booths Ferry,Booths Ferry of Randolph,Filipi,Filippi,Philippi,Phillippa,Phillippi,fylby,fylypay  wyrjynyay ghrby,Филипи,Филиппи,فيلبي,فیلیپای، ویرجینیای غربی', 39.1523200, -80.0403600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137515, 'Pinch', 'Pinch', 'Dial,Pinch,Pinch Gut,Pinchton', 38.4087100, -81.4817900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137516, 'Pineville', 'Pineville', '', 37.5831700, -81.5370500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137517, 'Pleasant Valley', 'Pleasant Valley', '', 39.4553600, -80.1417500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137518, 'Point Pleasant', 'Point Pleasant', 'Long Point,Point Pleasant,Pojnt Plezant,bwynt blyzant,pointeupeullejeonteu,pwynt plznt,pwynt plznt  wyrjynyay ghrby,Појнт Плезант,פוינט פלזנט,بوينت بليزانت,پوینت پلزنت، ویرجینیای غربی,포인트플레전트', 38.8445300, -82.1370900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137519, 'Princeton', 'Princeton', 'Principitonia,Prinston,brynstwn,prynstn  wyrjynyay ghrby,Принстон,برينستون,پرنسٹن، مغربی ورجینیا,پرینستن، ویرجینیای غربی', 37.3662300, -81.1025900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137520, 'Prosperity', 'Prosperity', '', 37.8365000, -81.2017700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137521, 'Rainelle', 'Rainelle', 'East Rainelle,Rainell,Rainelle,Rainette,Ranell,Sewell Creek,Sewell Valley', 37.9687300, -80.7670300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137522, 'Rand', 'Rand', 'Levi,Plus,Rand', 38.2826000, -81.5623400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137523, 'Ranson', 'Ranson', '', 39.2951000, -77.8605500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137524, 'Ravenswood', 'Ravenswood', 'Ravenswood,Ravensworth,Rejvensvud,rawnswwd  wyrjynyay ghrby,Рејвенсвуд,راونسوود، ویرجینیای غربی', 38.9481400, -81.7609600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137525, 'Richwood', 'Richwood', 'Cherry Bottom,Cherry Tree Bottom,Cherry Tree Bottoms,Richvud,Richwood,rykwwd  wyrjynyay ghrby,rytshwwd,Ричвуд,ريتشوود,ریکوود، ویرجینیای غربی', 38.2248400, -80.5331400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137526, 'Ripley', 'Ripley', 'Jackson,Jackson Court House,Ripley,Ripley Landing,Ripley''s,Ripleys,Ripli,rybly,ryply  wyrjynyay ghrby,Рипли,ريبلي,ریپلی، ویرجینیای غربی', 38.8187000, -81.7106900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137527, 'Romney', 'Romney', 'Pearsall''s,Pearsall''s Flats,Pearsall''s Fort,Pearsall''s Level,Pearsalls Flats,Pearsals,Romney,Romni,Romnia,ramny  wyrjynyay ghrby,rwmny,Ромни,رامنی، ویرجینیای غربی,رومني', 39.3420400, -78.7566800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137528, 'Ronceverte', 'Ronceverte', 'Edgars Mill,Green Briar,Ronceverte,Saint Lawrence Ford,rwnswrt  wyrjynyay ghrby,rwnsyfyrt,رونسورت، ویرجینیای غربی,رونسيفيرت', 37.7498400, -80.4628500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137529, 'Saint Albans', 'Saint Albans', 'Coals Mouth,Coalsmouth,Cole''s Mouth,Kanawha City,Philippi,Saint Albans', 38.3856500, -81.8362400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137530, 'Saint Marys', 'Saint Marys', 'Saint Mary''s,Saint Marys', 39.3917400, -81.2051100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137531, 'Salem', 'Salem', 'New Salem,Salem,Sejlem,salm,sylm  mghrby wrjynya,sylm  wyrjynyay ghrby,Сейлем,Сејлем,سالم,سیلم، مغربی ورجینیا,سیلم، ویرجینیای غربی', 39.2828700, -80.5589900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137532, 'Shady Spring', 'Shady Spring', 'Shady Spring,Shadyspring', 37.7056700, -81.0984300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137533, 'Shannondale', 'Shannondale', '', 39.2170500, -77.8074900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137534, 'Shepherdstown', 'Shepherdstown', 'Macklinboro,Macklinborough Town,Maclinborough,Mecklenburg,Mecklinborg,New Mecklenburg,Pack Horse Ford,Pack Horse Settlement,Potomack,Potomoke,Potowmack,Shepardstaun,Shepherd Town,Shepherd''s Town,Shepherds Town,Shepherdstown,Swearingen''s Ferry,Swearingham''s Ferry,shbrdztawn,shphrdstwwn  wyrjynyay ghrby,Шепардстаун,ועידת שפרדסטאון,شبردزتاون,شپهردستوون، ویرجینیای غربی', 39.4301000, -77.8041600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137535, 'Shinnston', 'Shinnston', 'Shin Town,Shinns Town,Shinnston,Shinnstown', 39.3956400, -80.3000900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137536, 'Sissonville', 'Sissonville', 'Grapevine,Sissianville,Sissonville', 38.5281500, -81.6309600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137537, 'Sistersville', 'Sistersville', 'Sistersvil,Sistersville,Sisterville,Wells Landing,Ziggleton,systrfyl,systrswyl  wyrjynyay ghrby,Систерсвил,سيسترفيل,سیسترسویل، ویرجینیای غربی', 39.5642400, -80.9959400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137538, 'Sophia', 'Sophia', '', 37.7076100, -81.2506600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137539, 'South Charleston', 'South Charleston', 'Saut Charlston,Saut-Charlston,nan cha er si dun,sausucharusuton,sawth tsharlstwn,Саут Чарлстон,Саут-Чарлстон,جنوبی چارلسٹن، مغربی ورجینیا,ساوث تشارلستون,サウスチャールストン,南查爾斯頓', 38.3684300, -81.6995700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137540, 'Spencer', 'Spencer', 'California,California Court House,Cassville,New California,Spencer,Spencer Court House,Spenser,Tanners Cross Roads,Tanners Crossroads,aspnsr  wyrjynyay ghrby,sbnsr,Спенсер,اسپنسر، ویرجینیای غربی,سبنسر', 38.8020300, -81.3509500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137541, 'Stanaford', 'Stanaford', 'Riley,Stanaford', 37.8159500, -81.1523200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137542, 'Star City', 'Star City', '', 39.6584100, -79.9864500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137543, 'Stonewood', 'Stonewood', '', 39.2509200, -80.3123100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137544, 'Summersville', 'Summersville', 'Nicholas Court House,Samervil,Sammersvill,Somerville,Summersville,samrswyl  wyrjynyay ghrby,smrsfyl,Самервил,Саммерсвилл,سامرسویل، ویرجینیای غربی,سمرسفيل', 38.2812200, -80.8526000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137545, 'Sutton', 'Sutton', 'Braxton Court House,Fultonsville,Newville,Saton,Satton,Sutton,Suttonsville,Suttonville,satn  wyrjynyay ghrby,satwn,Сатон,Саттон,ساتن، ویرجینیای غربی,ساتون', 38.6645400, -80.7098200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137546, 'Teays Valley', 'Teays Valley', '', 38.4500900, -81.9293000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137547, 'Terra Alta', 'Terra Alta', 'Cranberry,Cranberry Station,Cranberry Summit,Green Glades,Portland,Salt Lick,Salt Lick Falls,Terra Alta', 39.4456500, -79.5464400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137548, 'Union', 'Union', 'Union,Union Town', 37.5915100, -80.5436800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137549, 'Tornado', 'Tornado', 'Andrews Heights,Big Bend,Tornado,Upper Falls,Upper Falls of Coal River', 38.3428700, -81.8443000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137550, 'Vienna', 'Vienna', 'Vajena,Vienna,biena,fyyna,wei ye na,wyana  mghrby wrjynya,wyna  wyrjynyay ghrby,Вајена,Виенна,فيينا,ویانا، مغربی ورجینیا,وینا، ویرجینیای غربی,ビエナ,维也纳', 39.3270200, -81.5484600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137551, 'Washington', 'Washington', 'Vashington,Вашингтон', 39.2611900, -81.6718000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137552, 'Wayne', 'Wayne', 'Fairview,Trouts Hill,Wayne,Wayne Court House', 38.2214700, -82.4423700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137553, 'Webster Springs', 'Webster Springs', 'Addison,Fork Lick,Forklick,Fort Lick,Salt Springs,Webster Court House,Webster Springs', 38.4792700, -80.4134200, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137554, 'Welch', 'Welch', 'Velch,wlch  wyrjynyay ghrby,wlsh,Велч,ولش,ولچ، ویرجینیای غربی', 37.4328900, -81.5845500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137555, 'West Union', 'West Union', 'Lewisport,Union,Vest Junion,West Union,wst aywnyn  wyrjynyay ghrby,wyst ywnywn,Вест Јунион,وست ایونین، ویرجینیای غربی,ويست يونيون,ویسٹ یونین، مغربی ورجینیا', 39.2964700, -80.7770500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137556, 'Weston', 'Weston', 'Flesher''s Station,Fleshersville,Flesherville,Fletcherville,Preston,Uehston,Veston,Weston,wstwn  wyrjynyay ghrby,wystwn,Вестон,Уэстон,وستون، ویرجینیای غربی,ويستون', 39.0384300, -80.4673100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137557, 'Westover', 'Westover', '', 39.6345300, -79.9697900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137558, 'White Sulphur Springs', 'White Sulphur Springs', 'Dry Creek,Vajt Sulfer Springs,White Sulphur Springs,bai liu huang quan zhen,wayt salfr aspryngz  wyrjynyay ghrby,wayt swlfwr sbrynghz,Вајт Сулфер Спрингс,وايت سولفور سبرينغز,وایت سالفر اسپرینگز، ویرجینیای غربی,白硫磺泉镇', 37.7965100, -80.2975700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137559, 'Wiley Ford', 'Wiley Ford', 'Dixie,South Cumberland,Wiley Ford', 39.6145300, -78.7750200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137560, 'Williamson', 'Williamson', 'Vilijamson,wylymsn  wyrjynyay ghrby,Вилијамсон,ویلیمسن، ویرجینیای غربی', 37.6742700, -82.2773600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137561, 'Williamstown', 'Williamstown', 'Duncan,Vilijamstaun,Williams Town,Williamsport,Williamston,Williamstown,wylyamstwwn  wyrjynyay ghrby,wylyamztawn,Вилијамстаун,ولیمزٹاؤن، مغربی ورجینیا,ويليامزتاون,ویلیامستوون، ویرجینیای غربی', 39.4006300, -81.4481800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137562, 'Winfield', 'Winfield', 'Vinfild,wynfyld,wynfyld  wyrjynyay ghrby,Винфилд,وينفيلد,وینفیلد، ویرجینیای غربی', 38.5331400, -81.8934700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137563, 'Elba', 'Elba', 'Bentonville,Bridgeville,City of Flowing Wells,Elba,alba  alabama,aylba,e er ba,elaba,Елба,إيلبا,ئێلبا، ئەلاباما,البا، آلاباما,एलबा,厄尔巴', 31.4146100, -86.0677200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137564, 'Elmore', 'Elmore', 'Elmor,ai er mo er,almwr,almwr  alabama,elmora,Елмор,إلمور,ئێلمۆر، ئەلاباما,المور، آلاباما,एल्मोर,埃尔莫尔', 32.5387400, -86.3149700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137565, 'Sherwood', 'Sherwood', 'Shervud,seravuda,shrwwd,shyrwwd,Шервуд,شروود,شيروود,شیرووڈ، آرکنساس,शेरवूड', 34.8150900, -92.2243200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137566, 'Franklin', 'Franklin', 'Franklin,franklyn,franklyn  ayndyana,fu lan ke lin,peulaengkeullin,Франклин,فرانكلين,فرانکلین، ایندیانا,فرینکلن، انڈیانا,富蘭克林,프랭클린', 39.4806100, -86.0549900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137567, 'Newton', 'Newton', 'N''juton,Njuton,n''yutana,nywtn,nywtwn  aylynwy,Њутон,Ньютон,نيوتن,نیوتون، ایلینوی,نیوٹن، الینوائے,न्युटन', 38.9908800, -88.1625400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137568, 'Linn', 'Linn', 'Linn,Linnville', 38.4858700, -91.8504500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137569, 'Villa Ridge', 'Villa Ridge', 'Villa Ridge,Villaridge', 38.4725500, -90.8868000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137570, 'Rosedale', 'Rosedale', 'Floreyville,Floryville,Rosedale,Rosedale Plantation,Rouzdejl,Rozdejl,rwsdl,rwzdyl  mysysypy,Роздейл,Роуздејл,روزدیل، میسیسیپی,روزڈیل، مسیسپی,روسدل', 33.8534400, -91.0278900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137571, 'Shaw', 'Shaw', 'Shaw,Shawsburg', 33.6021100, -90.7745800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137572, 'Merchantville', 'Merchantville', 'Mehrkantvill,Merchantvil,mrshantwyl  nywjrsy,Мерчантвил,Мэркантвилл,مرشانتویل، نیوجرسی', 39.9473400, -75.0665600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137573, 'Florence', 'Florence', '', 39.7342800, -74.9182200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137574, 'Oak Valley', 'Oak Valley', '', 39.8012200, -75.1624000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137575, 'Bremen', 'Bremen', '', 39.7017300, -82.4268200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137576, 'Chillicothe', 'Chillicothe', 'Chilcotha,Chilecothe,Chilicotha,Chilicothe,Chillakothe,Chillicothe', 39.3331200, -82.9824000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137577, 'Coalgate', 'Coalgate', 'Coalgate,Koalgehjt,Koulgejt,Liddle,kwalgat  aklahma,kwlghyt,Коалгэйт,Коулгејт,كولغيت,کوالگات، اکلاهما', 34.5381500, -96.2186100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137578, 'Dilley', 'Dilley', 'Darlington,Dilley', 28.6674800, -99.1705900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137579, 'Devine', 'Devine', '', 29.1399600, -98.9053100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137580, 'Hickory Creek', 'Hickory Creek', '', 33.1223400, -97.0430600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137581, 'Wallis', 'Wallis', '', 29.6313500, -96.0652400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137582, 'New Kent', 'New Kent', 'New Kent,New Kent Court House', 37.5176500, -76.9788600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137583, 'Independence', 'Independence', '', 36.6224500, -81.1530900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137584, 'Bay City', 'Bay City', 'Bej Siti,Bej-Siti,bay syty,beishiti,beisiti,by syty  tgzas,Бей-Сити,Беј Сити,باي سيتي,بی سیتی، تگزاس,ベイシティ,베이시티', 28.9827600, -95.9694000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137585, 'Wise', 'Wise', 'Big Glades,Gladesville Court House,Gladeville,LNP,Vajz,Wise,Wise Court House,Вајз', 36.9759300, -82.5757100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137586, 'Abbeville', 'Abbeville', 'Abbeville,Abbieville,Abevil,Ebbivill,a bi wei er,abwyl  alabama,abyfyl,aebibil,ebebhila,Абевил,Еббівілл,أبيفيل,ابویل، آلاباما,एबेभिल,阿比维尔,애비빌', 31.5718400, -85.2504900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137587, 'Adamsville', 'Adamsville', 'Adamsvil,Adamsvill,adamsfyl,adamzwyl,edamsabhila,ya dang si wei er,Адамсвил,Адамсвілл,آدامزویل,أدامسفيل,एडम्सभिल,亚当斯维尔', 33.6009400, -86.9561100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137588, 'Alabaster', 'Alabaster', 'Alabaster,Alebastr,a la ba si te,alabastr  alabama,alabastyr,elbyastara,Алабастер,Алебастр,آلاباستر، آلاباما,ألاباستير,एल्ब्यास्टर,阿拉巴斯特', 33.2442800, -86.8163800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137589, 'Albertville', 'Albertville', 'Al''bertvill,Albertvil,ai bo te wei er,albartabhila,albrt‌wyl,albyrtfyl,Албертвил,Альбертвілл,آلبرت‌ویل,ألبيرتفيل,अल्बर्टभिल,艾伯特维尔', 34.2678300, -86.2087800, 'US', '2017-04-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137590, 'Alexander City', 'Alexander City', 'ALX,Aleksander Siti,Aleksander-Siti,Alexander,Alexander City,Youngsville,alekjendara siti,alksandr syty,alksndr syty,ya li shan da cheng,Александер Сити,Александер-Сіті,آلکساندر سیتی,ألكسندر سيتي,अलेक्जेन्डर सिटी,亚历山大城', 32.9440100, -85.9538500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137591, 'Alexandria', 'Alexandria', 'Aleksandrija,Alexander,Alexandria,Coffeeville,Houstons Store,Александрия', 33.7739900, -85.8855200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137592, 'Aliceville', 'Aliceville', 'AIV,Alisvil,Alisvill,ai li si wei er,alysfyl,alyswyl,elisabhila,Алисвил,Алісвілл,آلیسویل,أليسفيل,एलिसभिल,艾丽斯维尔', 33.1295700, -88.1514200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137593, 'Andalusia', 'Andalusia', 'Andalusia,Andalusija,Andaluzha,New Site,an da lu xi ya,andalwsya,endalusiya,Андалужа,Андалусія,آندالوسیا,أندالوسيا,एन्डालुसिया,安达卢西亚', 31.3080800, -86.4824300, 'US', '2017-03-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137594, 'Anniston', 'Anniston', 'ANB,Aniston,Annies Town,Anniston,Woodstock,aeniseuteon,an ni si dui,anisuton,annistana,annystwn,anystwn,enisatana,Анистон,Аннистон,Анністон,آنیستون,أننيستون,انیسٹن، الاباما,अन्निस्टन,एनिसटन,アニストン,安尼斯敦,애니스턴', 33.6598300, -85.8316300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137595, 'Arab', 'Arab', 'Arab,Arad,Ejrab,a la bo,arab,araba,arabu,arb,Араб,Ејраб,أراب,ارب,अरब,アラブ,阿拉伯', 34.3181500, -86.4958200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137596, 'Argo', 'Argo', 'Argo,a er ge,ago,arghw,argo,argw  alabama,Арго,Арґо,آرگو، آلاباما,أرغو,आर्गो,阿尔戈,아고', 33.6877800, -86.5005100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137597, 'Ardmore', 'Ardmore', 'Ardmore,Austin', 34.9920300, -86.8469500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137598, 'Athens', 'Athens', 'Afini,Atens,Athens,Athenson,a sen si,aeseonseu,athnz,atn  alabama,ethensa,Атенс,Афіни,آتن، آلاباما,آثنز,ایتھنز، الاباما,एथेन्स,阿森斯,애선스', 34.8024300, -86.9721900, 'US', '2017-04-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137599, 'Ashford', 'Ashford', 'Eshford,a shen fu de,ashfwrd,ashfwrd  alabama,espharda,Ешфорд,آشفورد,اشفورد، آلاباما,एश्फर्ड,阿什福德', 31.1829600, -85.2363200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137600, 'Ashland', 'Ashland', 'Eshland,Eshlend,a shen lan,aesyullaendeu,ashland,ashlnd  alabama,eslyanda,Ешланд,Ешленд,آشلاند,اشلند، آلاباما,ایشلنڈ، الاباما,एश्ल्यान्ड,阿什兰,애슐랜드', 33.2737300, -85.8360700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137601, 'Ashville', 'Ashville', 'Ashville,Eshvil,Eshvill,Saint Clairsville,a shen wei er,aesyubil,ashfyl,ashwyl,esbhila,Ешвил,Ешвілл,آشفيل,اشویل,एश्भिल,阿什维尔,애슈빌', 33.8370400, -86.2544200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137602, 'Atmore', 'Atmore', 'Atmor,Atmore,Williams Station,a te mo er,atmwr,etmora,Атмор,آتمور,أتمور,एट्मोर,阿特莫尔', 31.0237900, -87.4938700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137603, 'Attalla', 'Attalla', 'Atala,Atale,Atall,Atalla,Attala,Attalla,Baine,Bainesville,Etolla,New Town,Newton,The Junction,a ta la,atala,atilla,Атала,Етолла,آتالا,أتالا,अटिल्ला,阿塔拉', 34.0217600, -86.0885900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137604, 'Auburn', 'Auburn', 'AUO,Obern,a''ubarna,abarna,abrn  alabama,awbwrn,oban,obeon,ou ben,Оберн,آبرن، آلاباما,آبرن، الاباما,أوبورن,अउबर्न,अबर्न,オーバーン,歐本,오번', 32.6098600, -85.4807800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137605, 'Ballplay', 'Ballplay', '', 34.0587100, -85.8080200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137606, 'South Coventry', 'South Coventry', '', 41.7701000, -72.3050800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137607, 'Tariffville', 'Tariffville', 'Griswoldville,Tariffville,The Falls', 41.9087100, -72.7601000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137608, 'Cos Cob', 'Cos Cob', 'Cos Cob,Cos Cob Village,Lower Landing', 41.0334300, -73.5995700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137609, 'Canton', 'Canton', '', 40.5580900, -90.0351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137610, 'Deer Park', 'Deer Park', '', 41.2950300, -89.0361900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137611, 'Coventry Lake', 'Coventry Lake', '', 41.7723200, -72.3325800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137612, 'Glendale Heights', 'Glendale Heights', '', 41.9146000, -88.0648600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137613, 'Lena', 'Lena', 'Alida,Lena,Lina,Terre Haute,lena,lyna,Лина,لينا,लेना', 42.3794600, -89.8223400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137614, 'Cromwell', 'Cromwell', 'Kromvehll,Kromvel'',Kromvell,krwmwyl,Кромвелл,Кромвель,Кромвэлл,كرومويل,کرامویل، کنیکٹیکٹ', 41.5951000, -72.6453700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137615, 'East Falmouth', 'East Falmouth', 'East Falmouth,Sokones,Succonusset', 41.5784400, -70.5586400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137616, 'Crystal Lake', 'Crystal Lake', 'Crystal Lake,Square Pond', 41.9317600, -72.3784200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137617, 'North Andover', 'North Andover', 'Andover Septentrionalis,Nors Andover,North Andover,North Andover Center,North Andover Depot,andrwr shmaly  masachwst,Норс Андовер,اندرور شمالی، ماساچوست', 42.6987000, -71.1350600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137618, 'Revere', 'Revere', 'North Chelsea,Rehvia,Revere,Revir,Riviur,li wei er,libieo,rfyr,ribia,rwy‌yr  masachwst,Ревир,Ривиър,Рэвиа,راویر، میساچوسٹس,رفير,روی‌یر، ماساچوست,リビア,里维尔,리비어', 42.4084300, -71.0119900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137619, 'West Barnstable', 'West Barnstable', '', 41.7056600, -70.3744700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137620, 'Alfred', 'Alfred', 'Al''frehd,Alfred,Alfred Village,Massabesic,ai er fu lei de,alfrd  mayn,arufureddo,Алфред,Альфрэд,آلفرد، ماین,アルフレッド,艾尔弗雷德', 43.4764700, -70.7183900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137621, 'Danbury', 'Danbury', 'Beantown,DXR,Danberi,Danbjuri,Danburi,Danbury,The Hatchery,daenbeli,dan bo li,danberi,danbry,danbry  kntykt,denabari,dyanabari,Данбери,Данбері,Данбъри,Данбюри,دانبري,دانبری، کنتیکت,ڈینبری، کنیکٹیکٹ,डॅनबरी,ड्यानबरी,แดนเบอรี,ダンベリー,丹伯里,댄베리', 41.3948200, -73.4540100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137622, 'Berwick', 'Berwick', 'Behrvik,Berwick,Newichawannock,Newichawonnak,Vervik,Бэрвик,Вервик', 43.2659200, -70.8645000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137623, 'Hope', 'Hope', 'Hope,Hope Village', 44.2650800, -69.1589300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137624, 'Danielson', 'Danielson', 'Danielson,Danielson''s Village,Danielsonville,Danijelson,West Killingly,dyaniyalasana,Данијелсон,ड्यानियलसन', 41.8026000, -71.8859100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137625, 'Darien', 'Darien', 'Dariehn,Dehrien,Derijen,daelien,daryn,deriyana,Дариэн,Деријен,Дэриен,دارين,ڈیرین، کنیکٹیکٹ,डेरियन,대리엔', 41.0787100, -73.4692900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137626, 'Rockland', 'Rockland', 'RKD,Rockland,Rokland,Roklend,Shore Village,luo ke lan,raklnd  myn,rokkurando,rwkland,Рокланд,Рокленд,راکلند، مین,راکلینڈ، میئن,روكلاند,ロックランド,罗克兰', 44.1036900, -69.1089300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137627, 'Union', 'Union', 'Union,Union Village', 44.2114700, -69.2742100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137628, 'Inkster', 'Inkster', 'Inkster,ankstr,aynkstr  myshygan,Инкстер,إنكستر,اینکستر، میشیگان', 42.2942000, -83.3099300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137629, 'Edina', 'Edina', 'Edin,Един', 40.1675400, -92.1726800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137630, 'Derby', 'Derby', 'Birmingham,Dehrbi,Derbi,Derby,East Huntington,dabi,darbi,de bi,drby,drby  kntykt,Дерби,Дербі,Дэрби,برمنگھم، کنیکٹیکٹ,دربي,دربی، کنتیکت,डर्बी,ダービー,德比', 41.3206500, -73.0890000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137631, 'Yardville', 'Yardville', 'Jardville,Sand Hill,Sand Hills,Sandtown,Yardville', 40.1812200, -74.6643200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137632, 'Camillus', 'Camillus', 'Camillus,Nine Mile Creek,O-ya-ye-han', 43.0392300, -76.3041000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137633, 'Clyde', 'Clyde', 'Block House,Clyde,Lauraville', 43.0842300, -76.8694000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137634, 'Durham', 'Durham', 'Daram,Darem,Durkham,dar''hyama,dwrham,Дарам,Дарем,Дурхам,دورهام,ڈرہم، کنیکٹیکٹ,डर्ह्याम', 41.4817600, -72.6812100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137635, 'Wayland', 'Wayland', 'Begola,Patchinville,Wayland,Wayland Depot', 42.5678400, -77.5897100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137636, 'Watervliet', 'Watervliet', 'Gibbonsville,Port Schuyler,Vatervlejt,Votervlit,Washington,Watervliet,West Troy,watrwyt  nywywrk,wtrflyt,Ватервлейт,Вотервлит,واترویت، نیویورک,وترفليت', 42.7300800, -73.7012300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137637, 'East Brooklyn', 'East Brooklyn', 'Brooklyn Side Village,East Brooklyn,Lockwood Village,Lockwood''s Village,Tiffany,West Side,West Side Village', 41.7967700, -71.8972900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137638, 'Camden', 'Camden', '', 41.2378300, -82.3057200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137639, 'Cleveland Heights', 'Cleveland Heights', 'Klevalehnd Khehjts,Kliveland Khajts,Klivlend-Khajts,ke li fu lan gao de,klyfland hayts,klywlnd hayts  awhayw,Клевалэнд Хэйтс,Кливеланд Хајтс,Кливленд-Хайтс,كليفلاند هايتس,کلیولند هایتس، اوهایو,克利夫兰高地', 41.5200500, -81.5562400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137640, 'Genoa', 'Genoa', '', 41.5181100, -83.3590900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137641, 'East Haddam', 'East Haddam', 'Chapman Ferry,East Haddam,East Haddam Landing,Goodspeeds Landing,Ist Khaddam,ayst hadam,Ист Хаддам,إيست هادام,ایسٹ ہیڈام، کنیکٹیکٹ', 41.4531500, -72.4612000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137642, 'East Hampton', 'East Hampton', 'East Hampton,Ist Khehmpton,Ist Khempton,The Bell Town,ayst hambtwn,ista hyamptana,Ист Хемптон,Ист Хэмптон,إيست هامبتون,ایسٹ ہیمپٹن، کنیکٹیکٹ,इस्ट ह्याम्प्टन', 41.5759300, -72.5025900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137643, 'East Hartford', 'East Hartford', 'EHT,East Hartford,Ist Khartford,ayst hartfwrd,ista hartapharda,isutohatofodo,Ист Хартфорд,إيست هارتفورد,ایسٹ ہارٹفورڈ، کنیکٹیکٹ,इस्ट हार्टफर्ड,イーストハートフォード', 41.7823200, -72.6120300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137644, 'East Haven', 'East Haven', 'East Haven,East Village,Easthaven,Iron Works Village,Ist Khehven,Ist Khejven,Mioonkh-tuk,ayst hyfn,ista hyabhena,Ист Хејвен,Ист Хэвен,إيست هيفن,ایسٹ ہیون، کنیکٹیکٹ,इस्ट ह्याभेन', 41.2762100, -72.8684300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137645, 'Carnegie', 'Carnegie', 'Carnegie,Chartiers,Karnegi,Mansfield,Mansfield Valley,Rich Valley,Карнеги', 40.4086800, -80.0833900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137646, 'East Norwalk', 'East Norwalk', '', 41.1056500, -73.3984500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137647, 'Easton', 'Easton', 'Iston,Istun,aystn  kntykt,aystwn,Истон,Истън,إيستون,ایستن، کنتیکت,ایسٹن، کنیکٹیکٹ', 41.2528700, -73.2973400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137648, 'Hayti', 'Hayti', '', 44.6571900, -97.2050700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137649, 'Brussels', 'Brussels', '', 44.7361100, -87.6209300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137650, 'Ellington', 'Ellington', 'Dexter,Ehllington,Elenton,Ellington,Ellington Center,Great Marsh,Great Swamp,Waazkashuck,Weaxkashuck,Weraxshuck,alynghtwn,Эллингтон,إلينغتون,ایلنگٹن، کنیکٹیکٹ', 41.9039900, -72.4698100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137651, 'Enfield', 'Enfield', 'Ehnfild,Enfield,Freshwater,aynfyld,enfirudo,Энфилд,إينفيلد,اینفیلڈ، کنیکٹیکٹ,エンフィールド', 41.9762100, -72.5917600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137652, 'Fairfield', 'Fairfield', 'Fairfield,Fajrfild,Fehrfild,Fejrfild,Feurfijld,Feurfild,Uncoa,feafirudo,fei er fei er de,fyrfyld,fyrfyld  kntykt,peeopildeu,Файрфилд,Фейрфілд,Феърфийлд,Феърфилд,Фэрфилд,فيرفيلد,فیئرفیلڈ، کونیکٹیکٹ,فیرفیلد، کنتیکت,フェアフィールド,費爾菲爾德,페어필드', 41.1412100, -73.2637300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137653, 'Farmington', 'Farmington', 'Farmington,Farmington Village,farmnghtwn,farmyngtwn  kntykt,Фармингтон,Фармінґтон,فارمنغتون,فارمنگٹن، کنیکٹیکٹ,فارمینگتون، کنتیکت', 41.7198200, -72.8320400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137654, 'Gales Ferry', 'Gales Ferry', 'Gale Ferry,Gale Town,Gale''s Ferry,Gale-town,Gales Ferry', 41.4298200, -72.0820200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137655, 'Georgetown', 'Georgetown', 'Georgetown,Long Hollow', 41.2556500, -73.4348400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137656, 'Glastonbury', 'Glastonbury', 'Glastenbury,Glastonberi,Glastonbjuri,Glastonbury,Naubuc,Watertuyn,ghlastwnbwry,Гластонбери,Гластонбюри,غلاستونبوري,گلیسٹنبری، کنیکٹیکٹ', 41.7123200, -72.6081500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137657, 'Glastonbury Center', 'Glastonbury Center', '', 41.7009300, -72.5995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137658, 'Glenville', 'Glenville', 'Glenville,Sherwood Bridge', 41.0353800, -73.6598500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137659, 'Greenwich', 'Greenwich', 'Greenwich,Grinuich,Grinvich,Horse Neck,ge lin ni zhi,geulinichi,ghrynwytsh,grynwych  kntykt,gurinijji,Гринвич,Гринуич,Ґринвіч,غرينويتش,گرینویچ، کنتیکت,گرینچ، کنیکٹیکٹ,グリニッジ,格林尼治,그리니치', 41.0264900, -73.6284600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137660, 'Groton', 'Groton', 'East Side,GON,Groton,Groton Bank,Groton Ferry,Groton Landing,Grotun,ge luo dun shi,grotana,guroton,Гротон,Гротън,Ґротон,ग्रोटन,グロトン,格罗顿市', 41.3501000, -72.0784100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137661, 'Guilford', 'Guilford', 'Gilford,Gilford Senter,Guilford,Guilford Center,Menunkatucket,ghwylfwrd,gilapharda sentara,Гилфорд,Гилфорд Сентер,غويلفورد,گیلفورڈ، کنیکٹیکٹ,गिलफर्ड सेन्टर', 41.2889900, -72.6817600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137662, 'Hamden', 'Hamden', 'Khamdehn,hamdn,hamuden,Хамдэн,هامدن,ہیمڈن، کنیکٹیکٹ,ハムデン', 41.3959300, -72.8967700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137663, 'Hartford', 'Hartford', 'Chartfornt,Gartford,Gorad Khartfard,HFD,Halakepoka,Hartford,Hartforda,Hartfordas,Hartfordia,Hartfords,Hārtforda,Kharford,Khartford,Newtown,Siti of Khartford,Suckiag,ha te fu,hartafard,hartaforda,hartapharda,hartaphorda,hartfwrd,hartfwrd  kntykt,hartpart,hateupeodeu,hatofodo,hrtpwrd,Χάρτφορντ,Гартфорд,Горад Хартфард,Сити оф Хартфорд,Хартфорд,Харфорд,Ҳартфорд,Հարթֆորդ,הרטפורד,هارتفورد,هارتفورد، کنتیکت,ہارٹفورڈ,ہارٹفورڈ، کنیکٹیکٹ,हार्टफर्ड,हार्टफ़र्ड्,हार्टफ़ोर्ड,हार्टफोर्ड,हार्तफर्द,ஹார்ட்பர்ட்,ハートフォード,哈特福,하트퍼드', 41.7637100, -72.6850900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137664, 'Hazardville', 'Hazardville', '', 41.9873200, -72.5448100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137665, 'Hebron', 'Hebron', 'Hebron,Khehbron,Pumptown,hybrwn,Хэброн,حبرون، کنیکٹیکٹ,هيبرون', 41.6578800, -72.3659200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137666, 'Heritage Village', 'Heritage Village', '', 41.4856500, -73.2378900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137667, 'Higganum', 'Higganum', 'Higganum,Higganum Village,Higganumpus,Hockanum', 41.4970400, -72.5570300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137668, 'Jewett City', 'Jewett City', 'Jewett City,Pachaug City', 41.6067700, -71.9809100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137669, 'Kensington', 'Kensington', 'Farmington Village,Great Swamp,Kensington', 41.6353800, -72.7687100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137670, 'Kent', 'Kent', 'Kent,Kent Plains,Kent Village,knt  kntykt,kynt,Кент,كينت,کنت، کنتیکت,کینٹ، کنیکٹیکٹ', 41.7248200, -73.4770700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137671, 'Killingly Center', 'Killingly Center', 'Aspenock,Killingly Center', 41.8387100, -71.8692400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137672, 'Lake Pocotopaug', 'Lake Pocotopaug', 'Lake Pocotopaug,Pocotopaug Lake', 41.5984300, -72.5103700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137673, 'Ledyard Center', 'Ledyard Center', 'Led Yard,Ledyard,Ledyard Center,Maushantuxet', 41.4398200, -72.0142400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137674, 'Lisbon', 'Lisbon', 'Lisbon,Newent Parish', 41.6039900, -72.0117400, 'US', '2010-03-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137675, 'Litchfield', 'Litchfield', 'Bantam,Lichfijld,Lichfild,Litcfeld,Litchfield,Litchfield Center,Litchfild,Litçfeld,licaphilda,lytshfyld,ritchifirudo,Литчфилд,Личфийлд,Личфилд,ليتشفيلد,لچفیلڈ، کنیکٹیکٹ,लिचफिल्ड,リッチフィールド', 41.7473200, -73.1887200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137676, 'Long Hill', 'Long Hill', 'Long Hill', 41.3539900, -72.0523000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137677, 'Madison', 'Madison', 'East Guilford,MPE,Madison,Madison Center,Medison,Medison Senter,Mehdison,madyswn,myadisana sentara,Мадисон,Медисон Сентер,Медісон,Мэдисон,ماديسون,میڈیسون، کونیکٹیکوٹ,म्याडिसन सेन्टर', 41.2795400, -72.5984300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137678, 'Manchester', 'Manchester', 'Central Manchester,Manchester,Manchester Center,manchesuta,manshstr,mnchstr  kntykt,sentrala myancestara,Манчестер,مانشستر,مانچسٹر، کنیکٹیکٹ,منچستر، کنتیکت,सेन्ट्रल म्यांचेस्टर,マンチェスター', 41.7759300, -72.5214800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137679, 'Mansfield City', 'Mansfield City', '', 41.7659300, -72.2336900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137680, 'Meriden', 'Meriden', 'Meridehn,Meriden,Silver City,mei li deng,meriden,meridena,mrydn  kntykt,myrydyan,Мериден,Меридэн,Меріден,مریدن، کنتیکت,ميريديان,میریڈن، کنیکٹیکٹ,मेरिडेन,メリデン,梅里登', 41.5381500, -72.8070400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137681, 'Middlebury', 'Middlebury', 'Middlbjuri,Middlebury,Middlebury Center,mydlbwry,Миддлбюри,ميدلبوري,مڈلبری، کنیکٹیکٹ', 41.5278700, -73.1276100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137682, 'Middletown', 'Middletown', 'Mattabeseck,Mattabesett,Mattabesset,Middletown,Middltaun,Middltoun,Midltaun,mi de er dui,midalata''una,midorutaun,mydltawn,Миддлтаун,Миддлтоун,Мидлтаун,Міддлтаун,ميدلتاون,مڈل ٹاؤن، کنیکٹیکٹ,میدل‌تاون، کنتیکت,मिडलटाउन,ミドルタウン,米德尔敦', 41.5623200, -72.6506500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137683, 'Milford', 'Milford', 'Four Corners,Milford,Milfordas,Millfort,Wepowaug,mi er fu de,milapharda,milaphorda,milpeodeu,mirufodo,myldfwrd  kntykt,mylfwrd,Милфорд,Мілфорд,ميلفورد,میلدفورد، کنتیکت,میلفورڈ، کنیکٹیکٹ,मिलफर्ड,मिलफोर्ड,ミルフォード,米尔福德,밀퍼드', 41.2223200, -73.0565000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137684, 'Montville Center', 'Montville Center', '', 41.4789900, -72.1511900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137685, 'Moodus', 'Moodus', 'Machimoodus,Mechanicsville,Moodus,Moodus Village', 41.5028800, -72.4500900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137686, 'Moosup', 'Moosup', 'Cranska Village,Cranska Vitto,Gladdings Village,Gladdingville,Gladdinville,Kishwaukee,Moosup,Moosup Village,Uxnionville', 41.7128800, -71.8809100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137687, 'Mystic', 'Mystic', 'Lower Mystic,Mistick,Misticke,Mistik,Mystic,Mystic Bridge,Mystic Village,maystyk,mistika,Мистик,مائی سٹک، کونیکٹیکٹ,مايستيك,मिस्टिक', 41.3542700, -71.9664600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137688, 'Naugatuck', 'Naugatuck', 'Judd''s Meadow,Judds Meadow,Naugatak,Naugatuck,Naugatuck Village,Nawcotuck,Nogatak,Salem Bridge,naugacuka,nawghatwk,Наугатак,Ногатак,ناوغاتوك,یونین سٹی، کنیکٹیکٹ,नौगाचुक', 41.4859300, -73.0506600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137689, 'New Britain', 'New Britain', 'Hardware City,N''ju Britan,N''ju-Briten,New Britain,Nju Briten,Quebec,Quebek,n''yu britana,n''yu britena,nyubeuliteun,nyuburiten,nyw brytn,nyw brytyn  kntykt,xin bu lie dian,Њу Бритен,Нью Британ,Нью-Бритен,Нью-Брітен,نيو بريتن,نیو بریتین، کنتیکت,نیو بریٹن، کنیکٹیکٹ,न्यु ब्रिटेन,न्यू ब्रिटन,ニューブリテン,新不列颠,뉴브리튼', 41.6612100, -72.7795400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137690, 'New Canaan', 'New Canaan', 'N''ju Kanaan,Nju Kanaan,n''yu kanana,nyw kanan,nyw kynn  kntykt,Нью Канаан,Ню Канаан,نيو كانان,نیو کنعان، کنیکٹیکٹ,نیو کینن، کنتیکت,न्यू कनान', 41.1467600, -73.4948400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137691, 'New Fairfield', 'New Fairfield', 'N''ju Fajrfild,nyw fyrfyld,Нью Файрфилд,نيو فيرفيلد,نیو فیئرفیلڈ، کنیکٹیکٹ', 41.4664800, -73.4856800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137692, 'New Haven', 'New Haven', 'Gorad N''ju-Khehjven,HVN,N''ju Khehven,N''ju-Gejven,N''ju-Khejven,New Haven,Nju Khejven,Nju Khejvun,Novus Portus,Nuheivena,Queenapick,Quillipiack,Quinnepyooghq,Quinnipiac,Quinnypiock,Quinopiocke,Rodeberg,Rodenburg,n''yu hevana,n''yu hyabhena,niu ha fen shi,niu hei wen,niu-heiveni,niw he wen,nyuheibeun,nyuheibun,nyw hyfn,nyw hyybn,nywhywn  kntykt,Ņūheivena,Њу Хејвен,Горад Нью-Хэйвен,Нью Хэвен,Нью-Гейвен,Нью-Хейвен,Ню Хейвън,ניו הייבן,نيو هيفن,نیو ہیون، کنیکٹیکٹ,نیوهیون، کنتیکت,न्यु ह्याभेन,न्यू हेवन,นิวเฮเวน,ნიუ-ჰეივენი,ニューヘイブン,纽哈芬市,纽黑文,뉴헤이븐', 41.3081500, -72.9281600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137693, 'New London', 'New London', 'Llundain Newydd,Mameeg,N''ju London,N''ju-London,New London,New-London,Nju London,Nju Lundun,Nova Londres,Pequot Plantation,Pequot Town,n''yu landana,nyuleondeon,nyurondon,xin lun dui,Њу Лондон,Нью Лондон,Нью-Лондон,Ню Лъндън,न्यु लंडन,न्यू लंडन,ニューロンドン,新伦敦,뉴런던', 41.3556500, -72.0995200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137694, 'New Milford', 'New Milford', 'N''ju Milford,Nju Milford,n''yu milapharda,nyw mylfwrd,Њу Милфорд,Нью Милфорд,نيو ميلفورد,نیو میلفورڈ، کنیکٹیکٹ,न्यु मिलफर्ड', 41.5770400, -73.4084500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137695, 'New Preston', 'New Preston', 'New Preston,New Preston Village,North Purchase,Raumaug', 41.6751000, -73.3517900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137696, 'Newington', 'Newington', 'Nevington,Njuington,n''yu''ingatana,nywynghwn,Њуингтон,Невингтон,نيوينغون,نیوانگٹن، کنیکٹیکٹ,न्युइंगटन', 41.6978800, -72.7237100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137697, 'Niantic', 'Niantic', 'Nehantic,Nehantucket,Niantic', 41.3253800, -72.1931300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137698, 'Noank', 'Noank', 'Naiwayhucke,Naiwayonk,Nauyang,Nawyonk,Noank,Noank Village,Nowayunck', 41.3278800, -71.9906300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137699, 'North Branford', 'North Branford', 'Nors Brehnford,North Branford,North Branford Village,North Farms,nwrth branfwrd,Норс Брэнфорд,نارتھ برینفورڈ، کنیکٹیکٹ,نورث برانفورد', 41.3276000, -72.7673200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137700, 'North Granby', 'North Granby', '', 41.9959300, -72.8295400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137701, 'North Grosvenor Dale', 'North Grosvenor Dale', 'Fishersville,Fisherville,Mount Hunger,North Grosvenor Dale,North Grosvenordale', 41.9856500, -71.8986800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137702, 'North Haven', 'North Haven', 'Bricktown,Nors Khehven,Nort Khejven,North Haven,nartha hyabhena,nwrth hyfn,Норс Хэвен,Норт Хејвен,نارتھ ہیون، کنیکٹیکٹ,نورث هيفن,नर्थ ह्याभेन', 41.3909300, -72.8595400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137703, 'North Stamford', 'North Stamford', '', 41.1381500, -73.5434600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137704, 'Norwalk', 'Norwalk', 'Chichester,Naramake,Noruolk,Norvalk,Norvok,Norvolk,Norvolkas,Norwaake,Norwalk,ORQ,The Bridge,The Great Bridge,naravaka,noravoka,nou~oku,nowokeu,nuo wo ke,nwrwak  kntykt,nwrwwlk,Норвалк,Норвок,Норволк,Норуолк,نارواک، کنیکٹیکٹ,نورواک، کنتیکت,نوروولك,नरवाक,नॉरवॉक,ノーウォーク,诺沃克,노워크', 41.1176000, -73.4079000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137705, 'Norwich', 'Norwich', 'Chelsea,Noridzh,Noruich,Norvich,Norwich,Norwich Landing,Norwick,Rose of New England,naravica,nolichi,norvika,nou~itchi,nuo wei qi,nwrwytsh,nwrych  kntykt,Норвич,Норвіч,Норидж,Норуич,نارویچ، کنیکٹیکٹ,نورويتش,نوریچ، کنتیکت,नरविच,नॉर्विक,ノーウィッチ,诺威奇,노리치', 41.5242600, -72.0759100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137706, 'Oakville', 'Oakville', 'Oakville,The City', 41.5934300, -73.0853900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137707, 'Old Greenwich', 'Old Greenwich', 'Greenwich Old Town,Monakeway,Old Greenwich,SoundBeach', 41.0228700, -73.5648500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137708, 'Old Mystic', 'Old Mystic', 'Head of Mistick,Head of Mystic,Head of the River,Mystic,Old Mystic,Pequot,River Head,Upper Mystic', 41.3914900, -71.9617400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137709, 'Old Saybrook', 'Old Saybrook', 'Old Saybrook,Old Sehjbruk,Ould Sehjbruk,Pashbeshauke,Saybrook,Seabrook,Seabrooke,Zeebrugge,awld saybwrwk,Олд Сэйбрук,Оулд Сэйбрук,أولد سايبوروك,اولڈ سیبروک، کنیکٹیکٹ', 41.2917700, -72.3762000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137710, 'Orange', 'Orange', 'Bryan''s Farms,North Milford,Orange,Orange Center', 41.2784300, -73.0256600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137711, 'Oxford', 'Oxford', 'Manchaug,OXC,Oksford,Oxford,Oxford Center,aksfwrd  kntykt,awksfwrd,Оксфорд,آکسفورد، کنتیکت,آکسفورڈ، کنیکٹیکٹ,أوكسفورد', 41.4339900, -73.1167800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137712, 'Pawcatuck', 'Pawcatuck', 'Paquatuck,Paucatuck,Pawcatuck,Pawcatuck Bridge,Pawcatuck Village,Pawcatucket,Pawkeatucket', 41.3773200, -71.8336800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137713, 'Pemberwick', 'Pemberwick', '', 41.0256500, -73.6606800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137714, 'Plainfield', 'Plainfield', 'Plehjnfild,peulleinpildeu,Плэйнфилд,플레인필드', 41.6764900, -71.9150700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137715, 'Plainville', 'Plainville', 'Plainville,Plehjnvill,Plejnvill'',Плейнвилль,Плэйнвилл,پلینویل، کنیکٹیکٹ', 41.6745400, -72.8581600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137716, 'Plymouth', 'Plymouth', 'Northbury,Plajmaus,Plimut,Plymouth,Plymouth Center,Плаймаус,Плимут,پلایماؤت، کنیکٹیکٹ', 41.6720400, -73.0528900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137717, 'Poquonock Bridge', 'Poquonock Bridge', 'Pequonock Bridge,Pequot,Poquonnock,Poquonoc Bridge,Poquonock,Poquonock Bridge,Poquonrock Bridge', 41.3451000, -72.0248000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137718, 'Portland', 'Portland', 'East Middletown,Portland,Portland Center,Portlend,portalyanda,Портланд,Портленд,پورٹلینڈ، کنیکٹیکٹ,पोर्टल्यान्ड', 41.5728800, -72.6406500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137719, 'Prospect', 'Prospect', 'Prospect,Waterbury South Farms', 41.5023200, -72.9787200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137720, 'Preston City', 'Preston City', 'Preston,Preston City,Престон', 41.5289900, -71.9739600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137721, 'Putnam', 'Putnam', 'Cargill Falls,Great Falls,Patnam,Pomfret Street,Pomfretville,Putnam,Putnam District,Putnamas,Quinebaug,Quinebaug Falls,Wilkinson,Wilkinsonville,pattonamu,Патнам,Путнам,پٹنم، کنیکٹیکٹ,パットナム', 41.9151000, -71.9089600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137722, 'Quinebaug', 'Quinebaug', '', 42.0237100, -71.9498000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137723, 'Ridgefield', 'Ridgefield', 'Caudatowa,Ridgefield,Ridzfild,Ridzhfild,rijaphilda,Риджфилд,Риџфилд,ریجفیلڈ، کنیکٹیکٹ,रिजफिल्ड', 41.2814800, -73.4981800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137724, 'Riverside', 'Riverside', '', 41.0337100, -73.5781800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137725, 'Rockville', 'Rockville', 'Rock,Rock Factory,Rock Village,Rockville,Rokvill,The Loom City,Роквилл', 41.8667600, -72.4495300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137726, 'Salem', 'Salem', 'Salem,Salem Center,Sejlem,sylm  kntykt,Салем,Сейлем,سیلم، کنتیکت,سیلم، کنیکٹیکٹ', 41.4903800, -72.2753600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137727, 'Salmon Brook', 'Salmon Brook', '', 41.9564900, -72.7953700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137728, 'Saybrook Manor', 'Saybrook Manor', 'Indian Town,Saybrook Manor', 41.2853800, -72.3989700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137729, 'Seymour', 'Seymour', 'Amaug Suck,Chusetown,Humphreysville,Humphreyville,Naugatuck,Naugetuc,Naukotunk,Sejmur,Seymour,Сеймур,سیمور، کنیکٹیکٹ', 41.3967600, -73.0759400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137730, 'Shelton', 'Shelton', 'Huntington,Huntington Landing,Ripton,Shehlton,Shelton,seltana,sheruton,shltwn  kntykt,shyltwn,xie er dun,Шелтон,Шэлтон,شلتون، کنتیکت,شيلتون,شیلٹن، کنیکٹیکٹ,शेल्टन,シェルトン,谢尔顿', 41.3164900, -73.0931600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137731, 'Sherman', 'Sherman', 'Shehrman,Sherman,Sherman Center,The City,shrmn  kntykt,Шерман,Шэрман,شرمن، کنتیکت,شیرمین، کنیکٹیکٹ', 41.5792600, -73.4956800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137732, 'Sherwood Manor', 'Sherwood Manor', '', 42.0134300, -72.5642500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137733, 'Somers', 'Somers', 'Bittings Mill,Central Somers,Samers,Somehrs,Somer''s Street,Somers,Somers Center,Somers Street,sentrala somarsa,Самерс,Сомерс,Сомэрс,سامرز، کنیکٹیکٹ,सेन्ट्रल सोमर्स', 41.9853700, -72.4462000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137734, 'South Windham', 'South Windham', 'South Windham,Spaffordsville', 41.6795400, -72.1703600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137735, 'South Windsor', 'South Windsor', 'Saus Vindzor,Sous Vindsor,Саус Виндзор,Соус Виндсор,ساوتھ ونڈسر، کنیکٹیکٹ', 41.8237100, -72.6212000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137736, 'South Woodstock', 'South Woodstock', 'Arnold Village,Arnoldtown,Codfish Flat,Codfish Town,Codfishtown,Eastern Vale,South Woodstock,Warnerville', 41.9389900, -71.9595200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137737, 'Southbury', 'Southbury', 'Sausbjuri,Sousbjuri,Саусбюри,Соусбюри,ساوتھبری، کنیکٹیکٹ,ساوت‌بوری، کنتیکت', 41.4814800, -73.2131700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137738, 'Southport', 'Southport', 'Carey Corner,Mill Village,Sasco,Sasqua,Sasqua Fields,Southport', 41.1364900, -73.2834500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137739, 'Southwood Acres', 'Southwood Acres', '', 41.9626000, -72.5714800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137740, 'Stafford', 'Stafford', 'Furnace Hollow,Stafford,Stafford Hollow,Stafford Springs,Stafford Village,Staford Springs,Стафорд Спрингс,Стаффорд,سٹیفورڈ، کنیکٹیکٹ', 41.9848200, -72.2889700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137741, 'Stafford Springs', 'Stafford Springs', '', 41.9542600, -72.3023000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137742, 'Stamford', 'Stamford', 'Rippowams,Stamford,Stamfordas,Stehmford,Stemford,ZTF,astmfwrd  kntykt,seutaempeodeu,si tan fu,stamfwrd,stemapharda,stmpwrd,styamapharda,sutanfodo,Стамфорд,Стемфорд,Стэмфорд,סטמפורד,استمفورد، کنتیکت,ستامفورد,سٹیمفورڈ، کنیکٹیکٹ,स्टॅमफर्ड,स्ट्यामफर्ड,สแตมเฟิร์ด,スタンフォード,斯坦福,스탬퍼드', 41.0534300, -73.5387300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137743, 'Storrs', 'Storrs', 'Storrs,Storrsville,Stors,astwrs,starsa,Сторрс,Сторс,استورس,स्टर्स', 41.8084300, -72.2495200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137744, 'Stratford', 'Stratford', 'Cupheag,Stratford,Strehtford,astratfrd  kntykt,seuteulaespeodeu,stryatapharda,sutoratofodo,Стратфорд,Стрэтфорд,استراتفرد، کنتیکت,سٹریٹفورڈ، کنیکٹیکٹ,स्ट्र्याटफर्ड,ストラトフォード,스트랫퍼드', 41.1845400, -73.1331700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137745, 'Suffield Depot', 'Suffield Depot', '', 41.9812100, -72.6498100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137746, 'Terramuggus', 'Terramuggus', '', 41.6351000, -72.4703600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137747, 'Terryville', 'Terryville', 'Poland,Terrysville,Terryville', 41.6781500, -73.0109400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137748, 'Thomaston', 'Thomaston', 'Church Hollow,Plymouth Hollow,Thomas Town,Thomaston,Tomaston,Tumastun,Томастон,Тъмастън,تھامسٹن، کنیکٹیکٹ', 41.6739900, -73.0731600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137749, 'Thompson', 'Thompson', 'Quinnatisset,Thompson,Thompson Hill,Thompson Village,Tompson,Томпсон,تھامسن، کنیکٹیکٹ', 41.9587100, -71.8625700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137750, 'Thompsonville', 'Thompsonville', 'Freshwater Brook,The City,Thompsonville', 41.9970400, -72.5989800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137751, 'Tolland', 'Tolland', 'Tolland,Толланд,ٹولینڈ، کنیکٹیکٹ', 41.8714900, -72.3686900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137752, 'Torrington', 'Torrington', 'Mast Swamp,New Orleans Village,Spruce Swamp,Torington,Toringtun,Torrington,Wolcottville,taringatana,toringtana,torinton,tuo ling dun,twryngtwn  kntykt,twrynjtwn,Торингтон,Торингтън,Торрингтон,Торрінгтон,تورينجتون,تورینگتون، کنتیکت,ٹورنگٹن، کنیکٹیکٹ,टरिंगटन,टॉरिंग्टन,トリントン,托灵顿', 41.8006500, -73.1212200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137753, 'Trumbull', 'Trumbull', 'Trambal,Trambul,Trumbull,Trumbull Center,White Plains,tramabula,trwmbwl  kntykt,Трамбал,Трамбул,Трумбулл,ترومبول، کنتیکت,ٹرمبل، کنیکٹیکٹ,ट्रमबुल', 41.2428700, -73.2006700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137754, 'Uncasville', 'Uncasville', 'Ankasvill,Bartlett,Uncas Ville,Uncasville,Анкасвилл', 41.4345400, -72.1098000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137755, 'Wallingford', 'Wallingford', 'East River,New Haven Village,Vallingford,Volingford Senter,Wallingford,Wallingford Center,u~oringufodo,valingapharda sentara,wo ling fu de,wollingpeodeu,Валлингфорд,Волингфорд Сентер,والنگفورڈ، کنیکٹیکٹ,वालिंगफर्ड सेन्टर,ウォリングフォード,沃灵福德,월링퍼드', 41.4570400, -72.8231600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137756, 'Washington', 'Washington', 'Vashington,Washington,Washington Center,Washington Green,Вашингтон,واشنگٹن، کنیکٹیکٹ', 41.6314800, -73.3106700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137757, 'Waterbury', 'Waterbury', 'Forest City,The Brass City,Uot"rb"ri,Uoterberi,Vaterbjuri,Voterberi,Waterbury,u~otabari,u~otaberi,vatarabari,votarabari,watrbry  kntykt,watrbwry,wo te bo li,woteobeli,wwtrbry,Ватербюри,Вотербери,Вотербері,Уотербери,Уотърбъри,ווטרברי,واتربری، کنتیکت,واتربوري,واٹربری، کنیکٹیکٹ,वाटरबरी,वॉटरबरी,ウォーターバリー,ウォーターベリー,沃特伯里,워터베리', 41.5581500, -73.0515000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137758, 'Watertown', 'Watertown', 'Vatehrtaun,Votertaun,Watertown,Watertown Center,woteotaun,Ватэртаун,Вотертаун,واٹر ٹاؤن، کنیکٹیکٹ,워터타운', 41.6062100, -73.1181700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137759, 'Wauregan', 'Wauregan', 'Wauregan,Wauregan Village', 41.7442700, -71.9092400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137760, 'Weatogue', 'Weatogue', '', 41.8437100, -72.8284300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137761, 'West Hartford', 'West Hartford', 'Vehst Khartford,Vest Kharford,Vest Khartford,Vest-Gartford,West Division,West Hartford,Zapadnyj Khartford,uesutohatofodo,vesta hartapharda,Вест Хартфорд,Вест Харфорд,Вест-Гартфорд,Вэст Хартфорд,Западный Хартфорд,וועסט הארטפארד,ویسٹ ہارٹفورڈ، کنیکٹیکٹ,वेस्ट हार्टफर्ड,ウエストハートフォード', 41.7620400, -72.7420400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137762, 'West Haven', 'West Haven', 'Uehst-Khejven,Vehst Khehjvn,Vest Khehven,Vest Khejven,Vest-Gejven,u~esutoheibun,vesta hevana,vesta hyabhena,wst hywn  kntykt,wyst hyfn,xi hei wen,Вест Хејвен,Вест Хэвен,Вест-Гейвен,Вэст Хэйвн,Уэст-Хейвен,وست هیون، کنتیکت,ويست هيفن,ویسٹ ہیون، کنیکٹیکٹ,वेस्ट हेवन,वेस्ट ह्याभेन,ウェストヘイブン,西黑文', 41.2706500, -72.9470500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137763, 'West Simsbury', 'West Simsbury', 'Case Farms,Farm Village,Farms,Farms Village,The Farms,West Simsbury', 41.8731500, -72.8581500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137764, 'West Torrington', 'West Torrington', 'Torrington,West Torrington', 41.8184300, -73.1437200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137765, 'Westport', 'Westport', 'Vehstport,Vestport,vestaporta,weseuteupoteu,wstpwrt  kntykt,Вестпорт,Вэстпорт,وستپورت، کنتیکت,ویسٹپورٹ، کنیکٹیکٹ,वेस्टपोर्ट,웨스트포트', 41.1414900, -73.3579000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137766, 'Wethersfield', 'Wethersfield', 'Pyquaq,Vedersfild,Vezersfild,Watertown,Wethersfield,vedarsaphilda,Ведерсфилд,Везерсфилд,ویدرزفیلڈ، کنیکٹیکٹ,वेदर्सफिल्ड', 41.7142700, -72.6525900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137767, 'Willimantic', 'Willimantic', 'Thread City,Vilimantik,Wallamantuck,Walumantticuk,Waramantick,We-am-man-tuck,Wewemantick,Willimantic,u~irimantikku,vilimyantika,wylymantyk,wylymantyk  kntykt,Вилимантик,ويليمانتيك,ویلیمانتیک، کنتیکت,विलिम्यांटिक,ウィリマンティック', 41.7106500, -72.2081300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137768, 'Wilton', 'Wilton', 'Vilton,Wilton,Вилтон,ولٹن، کنیکٹیکٹ', 41.1953700, -73.4379000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137769, 'Winchester Center', 'Winchester Center', 'Old Society,Winchester,Winchester Center', 41.9001000, -73.1348300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137770, 'Windham', 'Windham', 'Hither Place,Hither-Place,South East Quarter,The Center,Vindkham,Windham,Windham Center,wyndham  knktykt,Виндхам,ویندهام، کنکتیکت,وینڈم، کنیکٹیکٹ', 41.6998200, -72.1570200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137771, 'Windsor', 'Windsor', 'Vindzor,Windsor,Виндзор,ونڈسر، کنیکٹیکٹ', 41.8526000, -72.6437000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137772, 'Windsor Locks', 'Windsor Locks', 'BDL,Enfield Falls,Pine Meadow,Vindsor Loks,Vindzor Loks,Windsor Locks,vindara laks,Виндзор Локс,Виндсор Локс,ونڈسر لاکس، کنیکٹیکٹ,विन्डर लक्स्', 41.9292600, -72.6273100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137773, 'Winsted', 'Winsted', 'East Village,Laurel City,Vinsted,Winsted,u~insuteddo,vinsteda,wynstd,wysntd  kntykt,Винстед,Вінстед,ونسٹیڈ، کنیکٹیکٹ,وينستد,ویسنتد، کنتیکت,विन्स्टेड,ウィンステッド', 41.9212100, -73.0601100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137774, 'Wolcott', 'Wolcott', 'Wolcott,Wolcottsville', 41.6023200, -72.9867700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137775, 'Woodbridge', 'Woodbridge', 'Vudbridzh,Вудбридж,ووڈبرج، کنیکٹیکٹ', 41.3526000, -73.0084400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137776, 'Woodbury', 'Woodbury', 'Vudbari,Vudberi Senter,Vudbjuri,Woodberry,Woodbury,Woodbury Center,vudabari sentara,Вудбари,Вудбери Сентер,Вудбюри,ووڈبری، کنیکٹیکٹ,वूडबरी सेन्टर', 41.5445400, -73.2090000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137777, 'Woodmont', 'Woodmont', 'Burwell Farms,Burwell''s Farms,East Farms,Merwin Point,Woodmont,Woodmont-on-the-Sound', 41.2281500, -72.9914900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137778, 'Ackley', 'Ackley', 'Aklehj,Akli,akly,akly  aywwa,Акли,Аклэй,أكلي,اکلی، آیووا,ოკლი', 42.5541500, -93.0532600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137779, 'Adel', 'Adel', 'Adehl,Adel,a dai er,adeli,adl,adl  aywwa,eideru,Адел,Адэл,أدل,ادل، آیووا,ადელი,エイデル,阿戴爾', 41.6144300, -94.0174500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137780, 'Akron', 'Akron', 'Akron,Акрон', 42.8288800, -96.5594800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137781, 'Albia', 'Albia', 'Albia,Albija,albia,albya,albya  aywwa,arubia,Албиа,Албија,آلبیا، آیووا,ألبيا,ალბია,アルビア', 41.0266700, -92.8057500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137782, 'Algona', 'Algona', 'AXG,Algona,Call''s Grove,algona,algwna  aywwa,aljwna,Алгона,آلگونا، آیووا,ألجونا,ཨཱལ་གོ་ན།,ალგონა', 43.0699700, -94.2330200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137783, 'Allison', 'Allison', '', 42.7527500, -92.7951900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137784, 'Alta', 'Alta', '', 42.6735900, -95.2905500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137785, 'Alton', 'Alton', '', 42.9874900, -96.0105700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137786, 'Altoona', 'Altoona', 'Altuna,a er tu na,altwna,altwna  aywwa,Алтуна,آلتونا، آیووا,ألتونا,ალტუნა,阿尔图纳', 41.6441600, -93.4646600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137787, 'Ames', 'Ames', 'AMW,Ames,Ehjmes,Ehjmsa,Ejms,ai mu si,amesi,amys,aymz  aywwa,aymz  ayywwa,eimseu,eimuzu,xem s,Ејмс,Эймес,Эймса,أميس,ایمز، آئیووا,ایمز، آیووا,เอมส์,ამესი,エイムズ,艾姆斯,에임스', 42.0347100, -93.6199400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137788, 'Anamosa', 'Anamosa', 'Anamosa,Lexington,anamosa,anamwsa,anamwsa  aywwa,Анамоса,أناموسا,اناموسا، آیووا,ანამოსა', 42.1083400, -91.2851600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137789, 'Ankeny', 'Ankeny', 'Ankehni,Ankeni,Ankenny,Ankeny,ankny  aywwa,ankyny,ankyny  ayywwa,Анкени,Анкэни,أنكيني,انکنی، آیووا,انکینی، آئیووا,ანკენი', 41.7297100, -93.6057700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137790, 'Aplington', 'Aplington', '', 42.5841500, -92.8843600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137791, 'Arnolds Park', 'Arnolds Park', 'Arnol''ds Park,Arnold Park,Arnolds Park,arnwld bark,arnwlds park  aywwa,Арнолдс Парк,Арнольдс Парк,آرنولدس پارک، آیووا,أرنولد بارك,არნოლდს-პარკი', 43.3727400, -95.1238800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137792, 'Asbury', 'Asbury', 'Asbjuri,Azberi,asbwry,aysbry  ayywwa,azbry  aywwa,osburi,Азбери,Асбюри,أسبوري,ازبری، آیووا,ایسبری، آئیووا,ოსბური', 42.5144500, -90.7515200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137793, 'Atkins', 'Atkins', '', 41.9969400, -91.8621300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137794, 'Atlantic', 'Atlantic', 'AIO,Atlantik,aeteullaentig,atlantyk,atlantyk  aywwa,Атлантик,آتلانتیک، آیووا,أتلانتيك,ატლანტიკი,애틀랜틱', 41.4036000, -95.0138800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137795, 'Audubon', 'Audubon', 'Audubon,Odjubon,Odubon,awdwbwn,awdwbwn  aywwa,odiuboni,Аудубон,Одубон,Одюбон,أودوبون,اودوبون، آیووا,ოდიუბონი', 41.7180400, -94.9324900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137796, 'Avoca', 'Avoca', '', 41.4766600, -95.3380500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137797, 'Baxter', 'Baxter', 'Baxter,Dawson,Independence Center', 41.8261000, -93.1515900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137798, 'Bedford', 'Bedford', 'Bedford,Behdford,bdfwrd  aywwa,bedpordi,bydfwrd,Бедфорд,Бэдфорд,بدفورد، آیووا,بيدفورد,ბედფორდი', 40.6669300, -94.7213600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137799, 'Belle Plaine', 'Belle Plaine', 'Behll Plehjn,Bel Plejn,bl playn  aywwa,byly blyn,Бел Плејн,Бэлл Плэйн,بل پلاین، آیووا,بيلي بلين,ბელ-პლენი', 41.8969400, -92.2782400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137800, 'Bellevue', 'Bellevue', 'Behllevju,Bell View,Bellevue,Belvju,beleviu,blfyw,blwyw  aywwa,Белвју,Бэллевю,بلفيو,بلویو، آیووا,ბელევიუ', 42.2586300, -90.4229100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137801, 'Belmond', 'Belmond', '', 42.8460800, -93.6141000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137802, 'Bettendorf', 'Bettendorf', 'Behttendorf,Betendorf,bei teng duo fu,bettenadorpha,btndrf  aywwa,bytyndwrf,Бетендорф,Бэттендорф,بتندرف، آیووا,بيتيندورف,بیٹنڈورف، آئیووا,बेट्टेनडॉर्फ,ბეტენდორფი,贝滕多夫', 41.5244800, -90.5156900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137803, 'Bloomfield', 'Bloomfield', 'Blumfild,blumpildi,blwmfyld,blwmfyld  aywwa,Блумфилд,بلومفيلد,بلومفیلد، آیووا,ბლუმფილდი', 40.7516900, -92.4149100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137804, 'Blue Grass', 'Blue Grass', '', 41.5089200, -90.7659800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137805, 'Bondurant', 'Bondurant', '', 41.7005400, -93.4621600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137806, 'Boone', 'Boone', 'BNW,Bun,buni,bwn,bwn  aywwa,Бун,بون,بون، آیووا,ბუნი', 42.0597000, -93.8802300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137807, 'Britt', 'Britt', '', 43.0977400, -93.8018900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137808, 'Brooklyn', 'Brooklyn', 'Brooklyn,Bruklin,QFF,Бруклин', 41.7336100, -92.4454600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137809, 'Buffalo (historical)', 'Buffalo (historical)', '', 41.3111000, -94.0035600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137810, 'Buffalo', 'Buffalo', 'Bufalo,Buffalo,bfylw  ayywwa,bupalo,bwfalw,bwfalw  aywwa,Буфало,Буффало,بفیلو، آئیووا,بوفالو,بوفالو، آیووا,ბუფალო', 41.4564200, -90.7234700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137811, 'Burlington', 'Burlington', 'BRL,Berlington,Burlington,Burlingtun,bo ling dun,brlnghtwn,bwrlyngtwn  aywwa,Берлингтон,Берлінгтон,Бурлингтон,Бърлингтън,برلنغتون,برلنگٹن، آئیووا,بورلینگتون، آیووا,ბარლინგტონი,伯灵顿', 40.8075400, -91.1129200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137812, 'Camanche', 'Camanche', 'Kamanch,kamantsh,kmanch  aywwa,Каманч,كامانتش,کمانچ، آیووا', 41.7880900, -90.2562400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137813, 'Carlisle', 'Carlisle', '', 41.5008200, -93.4910500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137814, 'Carroll', 'Carroll', 'CIN,Karol,Karroll,karwl,karwl  aywwa,Карол,Карролл,كارول,کارول، آیووا', 42.0658200, -94.8669300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137815, 'Carter Lake', 'Carter Lake', 'Kartehr Lehjk,Karter Lejk,kartr lyk,kartr lyk  aywwa,Картер Лејк,Картэр Лэйк,كارتر ليك,کارتر لیک، آیووا', 41.2905500, -95.9180700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137816, 'Cascade', 'Cascade', 'Kaskehjd,Kaskejd,kaskad,kaskyd  aywwa,Каскејд,Каскэйд,كاسكاد,کاسکید، آیووا', 42.2986200, -91.0148600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137817, 'Cedar Falls', 'Cedar Falls', 'Sehdar Folls,Sidar Fols,Sidar-Fols,sdar falz  aywwa,sydar fwlz,Сидар Фолс,Сидар-Фолс,Сэдар Фоллс,Сідар-Фолс,سدار فالز، آیووا,سيدار فولز,سیڈر فالز، آئیووا', 42.5277600, -92.4454700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137818, 'Cedar Rapids', 'Cedar Rapids', 'CID,Sehdar Rapids,Sidar Rapids,Sidar-Rapids,Sidur Rapids,sdar rapydz  aywwa,shidarapizzu,sidara repidsa,sideolaepijeu,sydar rabydz,sydr rpyds,xi da la pi zi,Сидар Рапидс,Сидар-Рапидс,Сидър Рапидс,Сэдар Рапидс,Сідар-Рапідс,Սիդար Ռեփիդս,סידר רפידס,سدار راپیدز، آیووا,سيدار رابيدز,سڈار ریپڈس، آئیووا,سیڈار ریپڈز,सीडार रॅपिड्स,シーダーラピッズ,錫達拉皮茲,시더래피즈', 42.0083300, -91.6440700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137819, 'Center Point', 'Center Point', 'Centr Point,Центр Поинт', 42.1908300, -91.7851800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137820, 'Centerville', 'Centerville', 'Sehntrvill,Sentervil,Sentervil'',Sentervill,sntrfyl,sntrwyl  aywwa,Сентервил,Сентервилл,Сентервіль,Сэнтрвилл,سنترفيل,سنترویل، آیووا,سینٹرویل، آئیووا', 40.7341800, -92.8740900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137821, 'Centerville', 'Centerville', '', 42.0927600, -93.9355100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137822, 'Central City', 'Central City', '', 42.2038800, -91.5240600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137823, 'Chariton', 'Chariton', 'Chariton,Shariton,charytwn  aywwa,tsharshn,Чаритон,Шаритон,تشارشن,چاریتون، آیووا', 41.0138900, -93.3066000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137824, 'Charles City', 'Charles City', 'Charl''z Siti,Charls Siti,carlsa siti,charlz syty  aywwa,tsharlz syty,Чарлс Сити,Чарльз Сити,تشارلز سيتي,چارلز سیتی، آیووا,चार्ल्स सिटी', 43.0663600, -92.6724100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137825, 'Cherokee', 'Cherokee', '', 42.7494300, -95.5516700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137826, 'Clarinda', 'Clarinda', 'Clarinda,Guntown,ICL,Klarinda,klarynda,klrynda  aywwa,Кларинда,كلاريندا,کلریندا، آیووا', 40.7398100, -95.0380000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137827, 'Clarion', 'Clarion', 'Klarion,klarywn,klryan  aywwa,Кларион,كلاريون,کلریان، آیووا', 42.7316400, -93.7329900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137828, 'Clarksville', 'Clarksville', '', 42.7847000, -92.6676900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137829, 'Clear Lake', 'Clear Lake', 'Klia Lehjk,Klir Lejk,Kliur Lejk,klyr lyk,klyr lyk  aywwa,Клиа Лэйк,Клир Лејк,Клиър Лейк,كلير ليك,کلیر لیک، آیووا', 43.1380200, -93.3793700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137830, 'Clinton', 'Clinton', 'CWI,Klinton,Klintun,klyntwn,klyntwn  aywwa,Клинтон,Клинтън,كلينتون,کلنٹن، آئیووا,کلینتون، آیووا', 41.8444700, -90.1887400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137831, 'Clive', 'Clive', '', 41.6030400, -93.7241100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137832, 'Clive', 'Clive', '', 41.6083200, -93.7396700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137833, 'Colfax', 'Colfax', '', 41.6777700, -93.2452000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137834, 'Columbus Junction', 'Columbus Junction', '', 41.2800300, -91.3607100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137835, 'Conrad', 'Conrad', '', 42.2247100, -92.8746500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137836, 'Coon Rapids', 'Coon Rapids', 'Kun Rapids,kwn rabydz,kwn rapyds  aywwa,Кун Рапидс,كون رابيدز,کون راپیدس، آیووا', 41.8708200, -94.6774800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137837, 'Coralville', 'Coralville', 'Koralvil,Koralvill,kwralfyl,kwralwyl  aywwa,Коралвил,Коралвилл,كورالفيل,کورالویل، آیووا', 41.6764000, -91.5804500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137838, 'Corning', 'Corning', 'Korning,kwrnyng  aywwa,kwrnynj,Корнинг,Корнінг,كورنينج,کورنینگ، آیووا', 40.9899900, -94.7408100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137839, 'Corydon', 'Corydon', 'Koridon,kwrydwn,kwrydwn  aywwa,Коридон,كوريدون,کوریدون، آیووا', 40.7569500, -93.3188200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137840, 'Council Bluffs', 'Council Bluffs', 'CBF,Council Bluffs,Kanesville,Kaunsil Bafs,Kaunsil-Blafs,Konsil-Blafs,Kounsl Blaffs,Miller''s Hollow,ka''unsila blaphsa,kang se er bu la fu si,kaunshiruburafusu,kwnsl blfs  ayywwa,kwnsyl blwfs,kwnsyl blwfs  aywwa,Каунсил Бафс,Каунсил-Блафс,Консіл-Блафс,Коунсл Блаффс,كونسيل بلوفس,کونسل بلفس، آئیووا,کونسیل بلوفس، آیووا,काउन्सिल ब्लफ्स,カウンシルブラフス,康瑟尔布拉夫斯', 41.2619400, -95.8608300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137841, 'Cresco', 'Cresco', 'Krehsko,Kresko,krskw  aywwa,kryskw,Креско,Крэско,كريسكو,کرسکو، آیووا', 43.3813600, -92.1140500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137842, 'Creston', 'Creston', 'CSQ,Krehston,Kreston,krstwn  aywwa,krystwn,Крестон,Крэстон,كريستون,کرستون، آیووا', 41.0586000, -94.3613500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137843, 'Dakota City', 'Dakota City', 'Dakota,Dakota City,Dakota Siti,Dakotah,Dakotaurbo,dakwta syty,dakwta syty  aywwa,Дакота Сити,داكوتا سيتي,داکوتا سیتی، آیووا', 42.7221900, -94.1971800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137844, 'Dallas Center', 'Dallas Center', '', 41.6844300, -93.9610600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137845, 'Davenport', 'Davenport', 'DVN,Davehnport,Davenport,Dehvenport,da wen bo te,dabenpoto,daebeunpoteu,dafnbwrt,dbnpwrt,devhenaporta,dwnpwrt  aywwa,Давенпорт,Давэнпорт,Дэвенпорт,דבנפורט,دافنبورت,دونپورت، آیووا,ڈیونپورٹ، آئیووا,डॅव्हेनपोर्ट,แดเวนพอร์ต,ダベンポート,達文波特,대븐포트', 41.5236400, -90.5776400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137846, 'De Soto', 'De Soto', '', 41.5316600, -94.0096700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137847, 'De Witt', 'De Witt', 'De Vit,De Witt,DeWitt,DehVitt,Vandenburg,Vanderburg,da wyt  aywwa,dywyt,Де Вит,ДэВитт,دا ویت، آیووا,ديويت', 41.8233600, -90.5381900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137848, 'Decorah', 'Decorah', 'DEH,Dehkorakh,dkwrah  aywwa,dykwrah,Дэкорах,ديكوراه,دکوراه، آیووا', 43.3033100, -91.7857100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137849, 'Denison', 'Denison', 'DNS,Dehnison,Denison,dnyswn  aywwa,dynyswn,Денисон,Дэнисон,دنیسون، آیووا,دينيسون', 42.0177700, -95.3552800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137850, 'Denver', 'Denver', 'Denver,Денвер', 42.6713700, -92.3374000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137851, 'Des Moines', 'Des Moines', 'DSM,De Moinas,De Moins,De Mojn,De Moyn,De-Mojn,Dehs Mojns,Demoina,Des Moines,Gorad Deh-Mojn,Monachopolis,Nte Moin,de mayne,de mei yin,de mo''ina,de-moini,demoin,des mvane,dh mwyn,di mo''ina,di mxyn,dimoin,dmwyn  aywwa,dy mwyn,dy mwyn  ayywwa,ti moyin,Ντε Μόιν,Горад Дэ-Мойн,Де Мойн,Де Мојн,Де-Мойн,Дэс Мойнс,Դե Մոյն,דה מוין,دموین، آیووا,دي موين,دی موین، آئیووا,ڈس موئنس,डे माय्ने,डेस् म्वाने,दि मोइन,दे मॉईन,டி மொயின்,ดิมอยน์,დე-მოინი,デモイン,德梅因,디모인', 41.6005400, -93.6091100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137852, 'Dike', 'Dike', '', 42.4641500, -92.6282500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137853, 'Dubuque', 'Dubuque', 'DBQ,Dub''juk,Дубьюк', 42.5005600, -90.6645700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137854, 'Durant', 'Durant', 'Durant,dwrnt  aywwa,dywrant,Дурант,دورنت، آیووا,ديورانت', 41.5997500, -90.9107000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137855, 'Dyersville', 'Dyersville', 'Dajehrsvill,Dajersvil,Dyersville,Dyerville,daiazubiru,dyrsfyl,dyrswyl  aywwa,Дайэрсвилл,Дајерсвил,ديرسفيل,دیرسویل، آیووا,ダイアーズビル', 42.4844400, -91.1229100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137856, 'Dysart', 'Dysart', '', 42.1716600, -92.3063000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137857, 'Eagle Grove', 'Eagle Grove', 'Eagle Grove,Eagle Grove Junction,Eaglegrove,Igl Grouv,aygl grww  aywwa,ayjl ghrwf,Игл Гроув,إيجل غروف,ایگل گروو، آیووا', 42.6641400, -93.9043900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137858, 'Earlham', 'Earlham', 'Erlam,Irlkham,arlham,ayrlham  aywwa,Ерлам,Ирлхам,إرلهام,ایرلهام، آیووا', 41.4919300, -94.1241200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137859, 'Eddyville', 'Eddyville', 'Edivil,Ehddivill,adyfyl,adywyl  aywwa,Едивил,Эддивилл,إديفيل,ادیویل، آیووا', 41.1565000, -92.6373900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137860, 'Eldora', 'Eldora', 'Ehldora,Eldora,aldwra,aldwra  aywwa,Елдора,Элдора,إلدورا,الدورا، آیووا', 42.3608200, -93.0996500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137861, 'Eldridge', 'Eldridge', 'Ehldridzh,Eldridz,aldrydj,aldryj  aywwa,Елдриџ,Элдридж,إلدريدج,الدریج، آیووا', 41.6580900, -90.5845800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137862, 'Elk Run Heights', 'Elk Run Heights', 'Elk Run,Elk Run Heights', 42.4669300, -92.2565700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137863, 'Elkader', 'Elkader', 'Ehlkadehr,Elkader,ai ka de,alkadr  aywwa,alqadr,Елкадер,Элкадэр,القادر,الکادر، آیووا,艾喀德', 42.8538700, -91.4054200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137864, 'Ely', 'Ely', '', 41.8736200, -91.5851800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137865, 'Emmetsburg', 'Emmetsburg', 'Ehmmertsburg,Emetsberg,amtsbwrg  aywwa,amystsbyrgh,Еметсберг,Эммертсбург,إميستسبيرغ,امتسبورگ، آیووا', 43.1127400, -94.6830400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137866, 'Epworth', 'Epworth', 'Ehpvors,Epvort,abwwrth,apwwrt  aywwa,Епворт,Эпворс,إبوورث,اپوورت، آیووا', 42.4450000, -90.9320800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137867, 'Estherville', 'Estherville', 'EST,Ehstervill,Estervil,asthrfyl,astrwyl  aywwa,Естервил,Эстервилл,إسثرفيل,استرویل، آیووا', 43.4016300, -94.8327600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137868, 'Evansdale', 'Evansdale', 'Ehvansdehjl,Evansdejl,afansdal,awansdal  aywwa,Евансдејл,Эвансдэйл,إفانسدال,اوانسدال، آیووا', 42.4691500, -92.2810200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137869, 'Fairbank', 'Fairbank', '', 42.6391500, -92.0471200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137870, 'Fairfax', 'Fairfax', '', 41.9194500, -91.7810100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137871, 'Fairfield', 'Fairfield', 'FFL,Fajrfild,Ferfild,Feurfild,fyrfyld,fyrfyld  aywwa,Файрфилд,Ферфилд,Феърфилд,فيرفيلد,فیئرفیلڈ، آئیوا,فیرفیلد، آیووا', 41.0086300, -91.9626700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137872, 'Farley', 'Farley', '', 42.4427800, -91.0062500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137873, 'Fayette', 'Fayette', 'Fajehtt,Fejet,fayt,fyt  aywwa,Файэтт,Фејет,فايت,فیت، آیووا', 42.8419300, -91.8021100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137874, 'Forest City', 'Forest City', 'FXY,Forehst Siti,Forist Siti,fwrst syty  aywwa,fwryst syty,Форист Сити,Форэст Сити,فورست سیتی، آیووا,فوريست سيتي', 43.2624600, -93.6371600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137875, 'Fort Dodge', 'Fort Dodge', 'FOD,Fort Dadz,Fort Dodzh,fwrt daj  aywwa,fwrt dwdj,Форт Даџ,Форт Додж,فورت داج، آیووا,فورت دودج,فورٹ ڈاج، آئیووا', 42.4974700, -94.1680200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137876, 'Fort Madison', 'Fort Madison', 'FMS,Fort Madison,Fort Medison,Fort Mehdison,Potowanek,fwrt madyswn,fwrt mdyswn  aywwa,Форт Медисон,Форт Мэдисон,فورت ماديسون,فورت مدیسون، آیووا', 40.6297600, -91.3151500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137877, 'Garner', 'Garner', 'Garner,Гарнер', 43.1024600, -93.6018800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137878, 'George', 'George', '', 43.3438600, -96.0022400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137879, 'Gilbert', 'Gilbert', 'Gilbert,Гилберт', 42.1069300, -93.6496600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137880, 'Glenwood', 'Glenwood', 'Coonville,Glehnvud,Glenvud,Glenwood,ghlynwwd,glnwwd  aywwa,Гленвуд,Глэнвуд,غلينوود,گلنوود، آیووا', 41.0469400, -95.7425100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137881, 'Glidden', 'Glidden', '', 42.0569300, -94.7288700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137882, 'Granger', 'Granger', '', 41.7611000, -93.8243900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137883, 'Greene', 'Greene', '', 42.8958100, -92.8024200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137884, 'Greenfield', 'Greenfield', 'Grinfild,ghrynfyld,grynfyld  aywwa,Гринфилд,Грінфілд,غرينفيلد,گرین فیلڈ، آئیووا,گرینفیلد، آیووا', 41.3052700, -94.4613500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137885, 'Grimes', 'Grimes', 'Grajms,ghraymz,grymz  aywwa,Граймс,Грајмс,غرايمز,گریمز، آیووا', 41.6883200, -93.7910600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137886, 'Grinnell', 'Grinnell', 'Grinel,Grinnehll,grynl  aywwa,Гринел,Гриннэлл,گرینل، آیووا', 41.7430500, -92.7224100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137887, 'Grundy Center', 'Grundy Center', '', 42.3616500, -92.7685300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137888, 'Guthrie Center', 'Guthrie Center', 'Gatri Senter,Gatri-Center,Gatri-Senter,Guzraj Sehntr,gatry sntr  aywwa,jwthry sntr,Гатри Сентер,Гатри-Сентер,Гатрі-Центер,Гузрай Сэнтр,جوثري سنتر,گاتری سنتر، آیووا', 41.6772100, -94.5033000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137889, 'Guttenberg', 'Guttenberg', 'Gatenberg,Guttenberg,Prairie la Porte,ghwtnbrgh,gwtnbrg  aywwa,Гатенберг,Гуттенберг,غوتنبرغ,گوتنبرگ، آیووا', 42.7858200, -91.0995700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137890, 'Hamburg', 'Hamburg', '', 40.6044500, -95.6577700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137891, 'Hampton', 'Hampton', 'Khampton,Khehmpton,Khempton,hambtwn,hamptwn  aywwa,Хамптон,Хемптон,Хэмптон,هامبتون,هامپتون، آیووا', 42.7419200, -93.2024200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137892, 'Harlan', 'Harlan', 'Kharlan,harlan,harln  aywwa,Харлан,هارلان,هارلن، آیووا', 41.6530400, -95.3255500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137893, 'Hartley', 'Hartley', '', 43.1799700, -95.4769500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137894, 'Hawarden', 'Hawarden', 'Khavardehn,hawardn  aywwa,hawardyn,Хавардэн,هاواردن، آیووا,هاواردين', 42.9958200, -96.4853100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137895, 'Hiawatha', 'Hiawatha', '', 42.0358300, -91.6821200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137896, 'Holstein', 'Holstein', '', 42.4891500, -95.5450000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137897, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 42.4066500, -92.4554700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137898, 'Hull', 'Hull', 'Hull,Khal,Khull,Pattersonville,hal  aywwa,hwl,Хал,Хулл,هال، آیووا,هول', 43.1885900, -96.1336300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137899, 'Humboldt', 'Humboldt', 'HUD,Humboldt,Khambolt,Khumboldt,Springvale,hmbwldt,hwmbwlt  aywwa,Хамболт,Хумболдт,همبولدت,هومبولت، آیووا', 42.7208000, -94.2152400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137900, 'Huxley', 'Huxley', '', 41.8952700, -93.6007700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137901, 'Ida Grove', 'Ida Grove', 'Ajda Grouv,IDG,Ida Grouv,ayda ghrwf,ayda grww  aywwa,Ајда Гроув,Ида Гроув,إيدا غروف,ایدا گروو، آیووا', 42.3449900, -95.4716700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137902, 'Independence', 'Independence', 'Indehpendens,Independens,andybyndyns,ayndypndns  aywwa,Индепенденс,Индэпенденс,إنديبيندينس,ایندیپندنس، آیووا', 42.4686000, -91.8893400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137903, 'Indianola', 'Indianola', 'Indianola,Indianolo,Indijanola,andyanwla,ayndyanwla  aywwa,Индианола,Индијанола,إنديانولا,ایندیانولا، آیووا', 41.3580500, -93.5574400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137904, 'Iowa City', 'Iowa City', 'Ajova Siti,Ajova-Siti,IOW,Iowa City,Lova Siti,a''i''ova nagara,ai ao wa cheng,aiowashiti,aiowasiti,ayova siti,aywa syty,aywwa syty  aywwa,Айова Сити,Айова-Сити,Айова-Сіті,Ајова Сити,Лова Сити,Այովա Սիթի,איווה סיטי,آئیووا سٹی، آئیووا,آيوا سيتي,آیووا سیتی، آیووا,आइओवा नगर,आयोवा सिटी,アイオワシティ,艾奥瓦城,아이오와시티', 41.6611300, -91.5301700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137905, 'Iowa Falls', 'Iowa Falls', 'Ajova Fols,IFA,Lova Folls,aywwa falz  aywwa,Ајова Фолс,Лова Фоллс,ایووا فالز، آیووا', 42.5224800, -93.2513100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137906, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefferson,Dzhehfferson,jfrswn  aywwa,jie fu xun,jyfrswn,Џеферсон,Джефферсон,Джэфферсон,جفرسون، آیووا,جيفرسون,傑弗遜', 42.0152600, -94.3774700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137907, 'Jesup', 'Jesup', '', 42.4755400, -92.0637900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137908, 'Jewell', 'Jewell', 'Jewell,Jewell Junction', 42.3069300, -93.6402200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137909, 'Johnston', 'Johnston', '', 41.6730400, -93.6977200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137910, 'Kalona', 'Kalona', '', 41.4830700, -91.7060000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137911, 'Keokuk', 'Keokuk', 'EOK,Keokuk,Keokukas,Kiokak,kykwk  aywwa,kywkwk,Кеокук,Киокак,كيوكوك,کیکوک، آیووا', 40.3972700, -91.3848700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137912, 'Keosauqua', 'Keosauqua', 'Keosaugua,Keosauqua,Keosauque,kywsawkwa  aywwa,kywsawkyw,Кеосаугуа,كيوساوكيو,کئوساوکوا، آیووا', 40.7303100, -91.9623900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137913, 'Kingsley', 'Kingsley', '', 42.5883200, -95.9675200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137914, 'Knoxville', 'Knoxville', 'Noksvil,Noksvill,knwksfyl,nakswyl  aywwa,Ноксвил,Ноксвилл,كنوكسفيل,ناکسویل، آیووا', 41.3208300, -93.1093700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137915, 'La Porte City', 'La Porte City', 'La Port Siti,La Porte,La Porte City,La Porteh Siti,Laporte,Laporte City,la bwrt syty,la pwrt syty  aywwa,Ла Порт Сити,Ла Портэ Сити,لا بورت سيتي,لا پورت سیتی، آیووا', 42.3149900, -92.1921300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137916, 'Lake City', 'Lake City', 'Lehjk Siti,Lejk Siti,lyk syty,lyk syty  aywwa,Лејк Сити,Лэйк Сити,ليك سيتي,لیک سیتی، آیووا', 42.2674800, -94.7338700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137917, 'Lake Mills', 'Lake Mills', 'Lehjk Mills,Lejk Mils,lyk mylz,lyk mylz  aywwa,Лејк Милс,Лэйк Миллс,ليك ميلز,لیک میلز، آیووا', 43.4194000, -93.5332700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137918, 'Lake Park', 'Lake Park', '', 43.4555200, -95.3208300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137919, 'Lake View', 'Lake View', 'Lehjk Vju,Lejk Vju,lyk fyw,lyk wyw  aywwa,Лејк Вју,Лэйк Вю,ليك فيو,لیک ویو، آیووا', 42.3116500, -95.0533200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137920, 'Lamoni', 'Lamoni', 'Lamoni,lai mang ni,lamwny,lamwny  aywwa,lamwny  lwwa,Ламони,لاموني,لامونی، آیووا,لامونی، لووا,莱芒尼', 40.6227800, -93.9341200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137921, 'Laurens', 'Laurens', '', 42.8466400, -94.8519300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137922, 'Le Claire', 'Le Claire', 'Le Claire,LeClaire,LeClare,Leclaire', 41.5986400, -90.3434600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137923, 'Le Mars', 'Le Mars', 'Le Mars,Leh Mars,lh mars  aywwa,ly mars,Ле Марс,Лэ Марс,له مارس، آیووا,لي مارس', 42.7941600, -96.1655800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137924, 'Lenox', 'Lenox', '', 40.8816500, -94.5619100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137925, 'Leon', 'Leon', 'Leon,Lion,lywn,lywn  aywwa,Леон,Лион,لئون، آیووا,ليون', 40.7397200, -93.7477200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137926, 'Lisbon', 'Lisbon', '', 41.9211200, -91.3854500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137927, 'Logan', 'Logan', '', 41.6430500, -95.7889000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137928, 'Lone Tree', 'Lone Tree', '', 41.4880800, -91.4259900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137929, 'Madrid', 'Madrid', 'Madrid,madryd  aywwa,mdryd,Мадрид,مادرید، آیووا,مدريد,میڈرڈ، اایووا', 41.8766500, -93.8232800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137930, 'Maharishi Vedic City', 'Maharishi Vedic City', 'Maharishi Vedic City,Vedic City', 41.0525200, -91.9949000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137931, 'Malvern', 'Malvern', '', 41.0027800, -95.5852800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137932, 'Manchester', 'Manchester', 'Manchehster,Manchester,manshstr,mnchstr  aywwa,Манчестер,Манчэстер,مانشستر,منچستر، آیووا', 42.4841500, -91.4554300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137933, 'Manly', 'Manly', '', 43.2871800, -93.2021500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137934, 'Manning', 'Manning', '', 41.9091500, -95.0649900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137935, 'Manson', 'Manson', '', 42.5291400, -94.5341400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137936, 'Mapleton', 'Mapleton', '', 42.1658200, -95.7930600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137937, 'Maquoketa', 'Maquoketa', 'Makuokehta,makwkyta,makwwkta  aywwa,Макуокэта,ماكوكيتا,ماکووکتا، آیووا', 42.0689100, -90.6656900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137938, 'Marcus', 'Marcus', '', 42.8258200, -95.8075100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137939, 'Marengo', 'Marengo', 'Marengo,marynghw,mrngw  aywwa,Маренго,مارينغو,مرنگو، آیووا', 41.7980600, -92.0707400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137940, 'Marion', 'Marion', 'Mehrion,Мэрион', 42.0341700, -91.5976800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137941, 'Marshalltown', 'Marshalltown', 'MIW,Marshall,Marshall Town,Marshalltown,Marshaltaun,marshaltawn,masharutaun,masyeoltaun,Маршалтаун,مارشالتاون,مارشال‌تاون، آیووا,مارشل ٹاؤن، آئیووا,マーシャルタウン,마셜타운', 42.0494300, -92.9079800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137942, 'Mason City', 'Mason City', 'MCW,Mason Siti,Mejson Siti,Mejson-Siti,Mejsun Siti,maswn syty,maswn syty  aywwa,mesana siti,Масон Сити,Мейсон-Сити,Мейсън Сити,Мејсон Сити,ماسون سيتي,ماسون سیتی، آیووا,میسن شہر، آئیووا,मेसन सिटी', 43.1535700, -93.2010400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137943, 'Mechanicsville', 'Mechanicsville', '', 41.9044600, -91.2546100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137944, 'Mediapolis', 'Mediapolis', 'Mediapolis,Mediopolis', 41.0080900, -91.1640400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137945, 'Melcher-Dallas', 'Melcher-Dallas', 'Dallas,Melcher,Melcher Dallas,Melcher-Dallas', 41.2250000, -93.2413200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137946, 'Milford', 'Milford', 'Milford,mylfrd  aywwa,mylfwrd,Милфорд,ميلفورد,میلفرد، آیووا', 43.3246900, -95.1500000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137947, 'Missouri Valley', 'Missouri Valley', '', 41.5563800, -95.8877900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137948, 'Mitchellville', 'Mitchellville', 'Michelvil,Mitchehlvill,mychlwyl  aywwa,mytshlfyl,Митчэлвилл,Мичелвил,ميتشلفيل,میچلویل، آیووا', 41.6686000, -93.3577100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137949, 'Monona', 'Monona', '', 43.0516500, -91.3893000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137950, 'Monroe', 'Monroe', 'Monro,Монро', 41.5222100, -93.1018700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137951, 'Montezuma', 'Montezuma', 'Montezuma,mantzwma  aywwa,mwntyzwma,Монтезума,مانتزوما، آیووا,مونتيزوما', 41.5858300, -92.5274100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137952, 'Monticello', 'Monticello', 'MXO,Montisehllo,Montiselo,mantyslw  aywwa,mwntayslw,Монтисело,Монтисэлло,مانتیسلو، آیووا,مونتايسلو', 42.2383400, -91.1870900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137953, 'Mount Ayr', 'Mount Ayr', '', 40.7147100, -94.2352300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137954, 'Mount Pleasant', 'Mount Pleasant', 'Maunt Plezant,Maunt Plisant,mawnt blysant,mawnt plyznt  aywwa,Маунт Плезант,Маунт Плисант,ماونت بليسانت,ماونت پلیزنت، آیووا', 40.9636400, -91.5579400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137955, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,mawnt fyrnwn,mawnt wrnwn  aywwa,Маунт Вернон,ماونت فيرنون,ماونت ورنون، آیووا', 41.9219500, -91.4168400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137956, 'Moville', 'Moville', '', 42.4888800, -96.0725200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137957, 'Muscatine', 'Muscatine', 'MUT,Maskatin,Muskatin,ma si ka ting,mwsktyn  aywwa,Маскатин,Мускатин,موسکتین، آیووا,馬斯卡廷', 41.4244700, -91.0432100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137958, 'Nashua', 'Nashua', 'Nashua,nashwa,nshwa  aywwa,Нашуа,ناشوا,نشوا، آیووا', 42.9527500, -92.5363000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137959, 'Nevada', 'Nevada', 'Nevada,Nevejda,nebada,nwada  aywwa,nyfada,Невада,Невејда,نوادا، آیووا,نيفادا,네바다', 42.0227700, -93.4524300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137960, 'New Hampton', 'New Hampton', '', 43.0591400, -92.3176800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137961, 'New London', 'New London', 'N''ju London,N''ju-London,Nju London,nyw landn  aywwa,nyw lndn,nyw lndn  ayywwa,Њу Лондон,Нью Лондон,Нью-Лондон,نيو لندن,نیو لاندن، آیووا,نیو لندن، آئیووا', 40.9269800, -91.3996000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137962, 'New Sharon', 'New Sharon', '', 41.4700000, -92.6513000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137963, 'Newton', 'Newton', 'N''juton,Newton,Newton City,Njuton,TNU,nywtn,nywtwn  aywwa,Њутон,Ньютон,نيوتن,نیوتون، آیووا', 41.6997100, -93.0479800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137964, 'Nora Springs', 'Nora Springs', '', 43.1427500, -93.0043700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137965, 'North English', 'North English', '', 41.5139000, -92.0762900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137966, 'North Liberty', 'North Liberty', 'Nors Liberti,Nort Liberti,nwrth lybrty,nwrth lybrty  aywwa,Норс Либерти,Норт Либерти,نورث ليبرتي,نورث لیبرتی، آیووا', 41.7491800, -91.5979500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137967, 'Northwood', 'Northwood', 'Norsvud,Nortvud,nwrthwwd,Норсвуд,Нортвуд,نورثوود,نورث‌وود، آیووا', 43.4441200, -93.2210400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137968, 'Norwalk', 'Norwalk', '', 41.4755500, -93.6788300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137969, 'Oakland', 'Oakland', '', 42.5810900, -93.4432600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137970, 'Oakland', 'Oakland', 'Oklend,Окленд', 41.3091600, -95.3966700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137971, 'Oelwein', 'Oelwein', 'Oehlvehjn,awlwyn  aywwa,awylwyn,Оэлвэйн,أويلوين,اولوین، آیووا', 42.6733200, -91.9135000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137972, 'Ogden', 'Ogden', 'Ogden,Огден', 42.0391500, -94.0277300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137973, 'Onawa', 'Onawa', 'Onava,awnawa,awnawa  aywwa,Онава,أوناوا,اوناوا، آیووا', 42.0266500, -96.0972400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137974, 'Orange City', 'Orange City', '', 43.0072100, -96.0583500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137975, 'Osage', 'Osage', 'Osehjdzh,Osejdz,awsydj,awsyj  aywwa,ou sai qi,Осејџ,Осэйдж,أوسيدج,اوسیج، آیووا,欧塞奇', 43.2841400, -92.8110300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137976, 'Osceola', 'Osceola', 'Osiola,Oskeola,awskywla  aywwa,awsywla,Осиола,Оскеола,أوسيولا,اوسکئولا، آیووا', 41.0338900, -93.7655000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137977, 'Oskaloosa', 'Oskaloosa', 'OOA,Oskaloosa,Oskalusa,ao si ka lu sa,asklwsa  aywwa,osukarusa,Оскалуса,آسکلوسا، آیووا,オスカルーサ,奥斯卡卢萨', 41.2963900, -92.6443600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137978, 'Ottumwa', 'Ottumwa', 'OTM,Otamva,Ottamua,Ottumva,awtwmwa,awtwmwa  aywwa,oteom-wa,Отамва,Оттамуа,Оттумва,آٹوموا، آئیووا,أوتوموا,اوتوموا، آیووا,오텀와', 41.0200100, -92.4113000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137979, 'Palo', 'Palo', '', 42.0661100, -91.7954600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137980, 'Panora', 'Panora', 'Panora,banwra,panwra  aywwa,Панора,بانورا,پانورا، آیووا', 41.6916500, -94.3630200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137981, 'Park View', 'Park View', 'Park View,Parkview', 41.6942000, -90.5456900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137982, 'Parkersburg', 'Parkersburg', 'Parkersberg,Parkersburg,barkrsbyrgh,parkrzbwrg  aywwa,Паркерсберг,Паркерсбург,باركرسبيرغ,پارکرزبورگ، آیووا', 42.5774800, -92.7868600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137983, 'Paullina', 'Paullina', '', 42.9791500, -95.6880700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137984, 'Pella', 'Pella', 'Pehlla,Pela,byla,pla  aywwa,Пела,Пэлла,بيلا,پلا، آیووا', 41.4080500, -92.9163100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137985, 'Peosta', 'Peosta', '', 42.4505600, -90.8504100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137986, 'Perry', 'Perry', 'PRO,Pehrri,Peri,pry  aywwa,Пери,Пэрри,پری، آیووا', 41.8386000, -94.1071800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137987, 'Pleasant Hill', 'Pleasant Hill', 'Pleasant Hill,Youngstown', 41.5838800, -93.5199400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137988, 'Pleasantville', 'Pleasantville', '', 41.3858300, -93.2693700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137989, 'Pocahontas', 'Pocahontas', 'Pokakhontas,bwkahwntas,pwkhants  aywwa,Покахонтас,بوكاهونتاس,پوکهانتس، آیووا', 42.7355300, -94.6691500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137990, 'Polk City', 'Polk City', 'Polk,Polk City,Polk Siti,bwlk syty,pwlk syty  aywwa,Полк Сити,بولك سيتي,پولک سیتی، آیووا', 41.7713800, -93.7130000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137991, 'Postville', 'Postville', '', 43.0847000, -91.5682000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137992, 'Prairie City', 'Prairie City', '', 41.5994300, -93.2352100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137993, 'Preston', 'Preston', '', 42.0503000, -90.4140200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137994, 'Primghar', 'Primghar', '', 43.0869200, -95.6272300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137995, 'Red Oak', 'Red Oak', 'Red Oak,Red Oak Junction,Red Ouk,Rehd Oak,rd wak  aywwa,ryd wak,Ред Оук,Рэд Оак,رد واک، آیووا,ريد واك', 41.0097200, -95.2255500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137996, 'Reinbeck', 'Reinbeck', '', 42.3236000, -92.5993600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137997, 'Remsen', 'Remsen', '', 42.8147100, -95.9733500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137998, 'Riverside', 'Riverside', 'Rivasajd,Riversajd,ryfrsyd,rywrsayd  aywwa,Ривасайд,Риверсайд,Риверсајд,ريفرسيد,ریورساید، آیووا', 41.4797400, -91.5812800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(137999, 'Robins', 'Robins', '', 42.0711100, -91.6668400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138000, 'Rock Rapids', 'Rock Rapids', 'Rok Rapids,rak rpyd  aywwa,rwk rabydz,Рок Рапидс,راک رپید، آیووا,روك رابيدز', 43.4271900, -96.1758600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138001, 'Rock Valley', 'Rock Valley', '', 43.2052600, -96.2950300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138002, 'Rockwell', 'Rockwell', '', 42.9852400, -93.1918700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138003, 'Rockwell City', 'Rockwell City', 'Rokvehll Siti,Rokvel Siti,rakwl syty  aywwa,rwkwyl syty,Роквел Сити,Роквэлл Сити,راکول سیتی، آیووا,روكويل سيتي', 42.3952600, -94.6338700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138004, 'Roland', 'Roland', '', 42.1663700, -93.5018800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138005, 'Sac City', 'Sac City', 'Sak Siti,sak syty,sk syty  aywwa,Сак Сити,ساك سيتي,سک سٹی، آئیووا,سک سیتی، آیووا', 42.4222000, -94.9897100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138006, 'Saint Ansgar', 'Saint Ansgar', '', 43.3783000, -92.9188100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138007, 'Sanborn', 'Sanborn', '', 43.1816400, -95.6555700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138008, 'Saylorville', 'Saylorville', '', 41.6786000, -93.6296600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138009, 'Sergeant Bluff', 'Sergeant Bluff', 'Sargent Bluff,Seargeante Bluff,Sergeant Bluff,Sergeants Bluff', 42.4038800, -96.3586400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138010, 'Sheffield', 'Sheffield', '', 42.8933000, -93.2152000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138011, 'Sheldon', 'Sheldon', 'Shehldon,Sheldon,shldwn  aywwa,shyldwn,Шелдон,Шэлдон,شلدون، آیووا,شيلدون', 43.1810900, -95.8561300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138012, 'Shell Rock', 'Shell Rock', 'Shell Rock,Shellrock', 42.7102600, -92.5829700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138013, 'Shenandoah', 'Shenandoah', 'Shehnandukh,Shenandoa,shnandwa  aywwa,shynandwah,Шенандоа,Шэнандух,شناندوا، آیووا,شيناندواه', 40.7655500, -95.3722100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138014, 'Sidney', 'Sidney', 'Sidnej,Сидней', 40.7483300, -95.6475000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138015, 'Sibley', 'Sibley', 'Siblehj,Sibli,sybly,sybly  aywwa,Сибли,Сиблэй,سيبلي,سیبلی، آیووا', 43.3991400, -95.7519600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138016, 'Sigourney', 'Sigourney', '', 41.3333400, -92.2046300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138017, 'Sioux Center', 'Sioux Center', 'Siouks Sehntr,Su Senter,sw sntr  aywwa,sywks sntr,Сиоукс Сэнтр,Су Сентер,سو سنتر، آیووا,سيوكس سنتر', 43.0797100, -96.1755800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138018, 'Sioux City', 'Sioux City', 'Kota Sioux,SUX,Siouks Siti,Su Siti,Su-Siti,su cheng,su siti,sushiti,susiti,sw syty,sw syty  aywwa,sywks syty,Сиоукс Сити,Су Сити,Су-Сити,Су-Сіті,סו סיטי,سو سیتی، آیووا,سيوكس سيتي,سیو سٹی، آئیووا,सू सिटी,スーシティ,蘇城,수시티', 42.4999900, -96.4003100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138019, 'Slater', 'Slater', '', 41.8777600, -93.6785500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138020, 'Solon', 'Solon', 'Solon,Солон', 41.8072300, -91.4940600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138021, 'Spencer', 'Spencer', 'SPW,Spensehr,Spenser,aspnsr  aywwa,sbnsr,Спенсер,Спенсэр,اسپنسر، آیووا,سبنسر', 43.1413600, -95.1444400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138022, 'Spirit Lake', 'Spirit Lake', 'RTL,Spirit Lake,Spirit Lehjk,Spirit Lejk,aspyryt lyk  aywwa,sbyryt lyk,Спирит Лејк,Спирит Лэйк,اسپیریت لیک، آیووا,سبيريت ليك', 43.4221800, -95.1022200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138023, 'Springville', 'Springville', '', 42.0594500, -91.4426700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138024, 'State Center', 'State Center', '', 42.0166500, -93.1635400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138025, 'Storm Lake', 'Storm Lake', 'SLB,Storm Lake,Storm Lehjk,Storm Lejk,astwrm lyk  aywwa,si tuo mu lai ke,stwrm lyk,Сторм Лејк,Сторм Лэйк,استورم لیک، آیووا,ستورم ليك,斯托姆莱克', 42.6410900, -95.2097200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138026, 'Story City', 'Story City', 'Stori Siti,astry syty  aywwa,stwry syty,Стори Сити,استری سیتی، آیووا,ستوري سيتي', 42.1872100, -93.5957700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138027, 'Strawberry Point', 'Strawberry Point', '', 42.6836000, -91.5340300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138028, 'Stuart', 'Stuart', 'Stjuart,astwrt  aywwa,stywart,Стюарт,Стјуарт,استورت، آیووا,ستيوارت', 41.5033200, -94.3185700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138029, 'Sumner', 'Sumner', '', 42.8474800, -92.0915600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138030, 'Tama', 'Tama', 'Tama,Tama City', 41.9666600, -92.5768600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138031, 'Tiffin', 'Tiffin', '', 41.7058500, -91.6629500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138032, 'Tipton', 'Tipton', 'Tipton,tybtwn,typtwn  aywwa,Типтон,تيبتون,تیپتون، آیووا', 41.7697400, -91.1279300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138033, 'Toledo', 'Toledo', 'Toledo,Tolehdo,Tolido,twldw  aywwa,twlydw,Толедо,Толидо,Толэдо,تولدو، آیووا,توليدو', 41.9955500, -92.5768600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138034, 'Traer', 'Traer', '', 42.1936000, -92.4654700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138035, 'Tripoli', 'Tripoli', '', 42.8080400, -92.2582300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138036, 'University Heights', 'University Heights', '', 41.6550200, -91.5568400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138037, 'Urbana', 'Urbana', 'Urbana,Урбана', 42.2241600, -91.8743400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138038, 'Urbandale', 'Urbandale', 'Urbandehjl,Urbandejl,awrbandal  aywwa,awrbndyl,Урбандејл,Урбандэйл,أوربنديل,اربنڈیل، آئیووا,اورباندال، آیووا', 41.6266600, -93.7121700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138039, 'Van Meter', 'Van Meter', '', 41.5319300, -93.9541200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138040, 'Villisca', 'Villisca', 'Villisca,Villiska', 40.9297100, -94.9760900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138041, 'Vinton', 'Vinton', 'Vinton,fyntwn,wyntwn  aywwa,Винтон,فينتون,وینتون، آیووا', 42.1686100, -92.0235100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138042, 'Walcott', 'Walcott', '', 41.5847500, -90.7720900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138043, 'Walford', 'Walford', '', 41.8783400, -91.8346200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138044, 'Wapello', 'Wapello', 'Vapehllo,Vopelo,u~oparo,wabylw,waplw  aywwa,Вапэлло,Вопело,وابيلو,واپلو، آیووا,ウォパロ', 41.1814200, -91.1854300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138045, 'Washington', 'Washington', 'Vashington,washntn,washyngtn  aywwa,Вашингтон,واشنطن,واشینگتن، آیووا', 41.2991800, -91.6929400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138046, 'Waterloo', 'Waterloo', 'ALO,Uatehrlu,Vaterlo,Voterlu,Waterloo,u~otaru,votarlu,watrlw,watrlw  aywwa,woteollu,wwtrlw,Ватерло,Вотерлу,Уатэрлу,ווטרלו,واترلو,واترلو، آیووا,واٹرلو، آئیووا,वॉटर्लू,ウォータールー,워털루', 42.4927600, -92.3429600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138047, 'Waukee', 'Waukee', 'Vauki,Voki,Wankes,Waukee,wawky,wawky  aywwa,Вауки,Воки,واوكي,واوکی، آیووا', 41.6116600, -93.8852300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138048, 'Waukon', 'Waukon', 'Uokon,Vaukon,Vokon,wawkwn,wawkwn  aywwa,wo kan,Ваукон,Вокон,Уокон,واوكون,واوکون، آیووا,沃坎', 43.2694200, -91.4757000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138049, 'Waverly', 'Waverly', 'Vejverli,wawrly  aywwa,wyfrly,Вејверли,واورلی، آیووا,ويفرلي', 42.7258100, -92.4754600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138050, 'Webster City', 'Webster City', 'EBS,Vebster Siti,Vehbster Siti,wbstr syty  aywwa,wybstr syty,Вебстер Сити,Вэбстер Сити,وبستر سیتی، آیووا,ويبستر سيتي', 42.4694200, -93.8160500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138051, 'Wellman', 'Wellman', '', 41.4641800, -91.8382300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138052, 'West Branch', 'West Branch', 'Vehst Branch,Vest Branch,wst brnch  aywwa,wyst bransh,xi bu lan qi,Вест Бранч,Вэст Бранч,وست برنچ، آیووا,ويست برانش,西布兰奇', 41.6714100, -91.3465500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138053, 'West Burlington', 'West Burlington', '', 40.8250400, -91.1565400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138054, 'West Des Moines', 'West Des Moines', 'Valley Junction,Vehst Dehs Mojnehs,Vest De Mojn,West Des Moines,wst ds mwyns  aywwa,wyst dy mwynz,Вест Де Мојн,Вэст Дэс Мойнэс,وست دس موینس، آیووا,ويست دي موينز,ویسٹ دی موین، آئیووا', 41.5772100, -93.7113300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138055, 'West Liberty', 'West Liberty', '', 41.5700200, -91.2637700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138056, 'West Union', 'West Union', 'Vehst Junion,Vest Junion,wst ywnywn  aywwa,wyst ywnywn,Вест Јунион,Вэст Юнион,وست یونیون، آیووا,ويست يونيون,ویسٹ یونین، آئیووا', 42.9627600, -91.8082200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138057, 'Williamsburg', 'Williamsburg', '', 41.6611200, -92.0090700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138058, 'Wilton', 'Wilton', 'Glendale,Muscatine Junction,Wilton,Wilton Junction', 41.5889200, -91.0168200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138059, 'Windsor Heights', 'Windsor Heights', '', 41.5977700, -93.7082800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138060, 'Winfield', 'Winfield', '', 41.1230800, -91.4412700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138061, 'Winterset', 'Winterset', 'Uinturset,Vintehrset,Vinterset,u~intasetto,wyntrst,wyntrst  aywwa,Винтерсет,Винтэрсет,Уинтърсет,وينترست,وینترست، آیووا,ウィンターセット', 41.3308200, -94.0138400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138062, 'Woodbine', 'Woodbine', '', 41.7383200, -95.7027800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138063, 'Woodward', 'Woodward', '', 41.8569300, -93.9219000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138064, 'Abingdon', 'Abingdon', 'Abingdon,abyngdwn  aylynwy,abynghdwn,ebingadana,Абингдон,Абінгдон,أبينغدون,ابنگڈن، الینوائے,ابینگدون، ایلینوی,एबिंगडन', 40.8044800, -90.4018000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138065, 'Addison', 'Addison', 'Adison,adyswn,adyswn  aylynwas,edisana,Адисон,إديسون,ادیسون، ایلینواس,ایڈسن، الینوائے,एडिसन', 41.9317000, -87.9889600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138066, 'Aledo', 'Aledo', 'Alido,aldw,alydw  aylynwy,eledo,Алидо,ألدو,الیدو، ایلینوی,الیڈو، الینوائے,एलेदो', 41.1997600, -90.7493100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138067, 'Algonquin', 'Algonquin', 'Algonkvin,algankwyyn  alynwaz,alghankwyyn,elgonkvina,Алгонквин,ألغانكوئين,الگانکوئین، الینواز,الگونکوئن، الینوائے,एल्गोन्क्विन', 42.1655800, -88.2942500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138068, 'Alsip', 'Alsip', 'Olsip,alsyb,alsyp  aylynwaz,elsipa,Олсип,إلسيب,السیپ، ایلینواز,ایلسپ، الینوائے,एल्सिप', 41.6689200, -87.7386600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138069, 'Amboy', 'Amboy', 'Amboy,Ompoge', 41.7142000, -89.3287100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138070, 'Andalusia', 'Andalusia', '', 41.4392000, -90.7176400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138071, 'Antioch', 'Antioch', 'Antiok,antywtsh,entiyaka,Антиок,آنتیوچ، الینوائے,أنتيوتش,एन्टियक', 42.4772400, -88.0956400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138072, 'Arlington Heights', 'Arlington Heights', 'Arlington Heights,Arlington Khajts,Arlington-Khajts,Dunton,JLH,arintonhaitsu,arlingatana ha''itsa,arlynghtwn hayts,Арлингтон Хајтс,Арлингтон-Хайтс,آرلنگٹن ہائٹس، الینوائے,أرلينغتون هايتس,आर्लिङ्गटन हाइट्स,アーリントンハイツ', 42.0883600, -87.9806300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138073, 'Astoria', 'Astoria', '', 40.2275400, -90.3595700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138074, 'Atlanta', 'Atlanta', 'Atlanta,Xenia,Zenia,Атланта', 40.2594800, -89.2334200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138075, 'Aurora', 'Aurora', 'AUZ,Aurora,Avrora,Аврора', 41.7605800, -88.3200700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138076, 'Bannockburn', 'Bannockburn', '', 42.1933600, -87.8664600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138077, 'Barrington', 'Barrington', 'Barington,bararingatana,barynghtwn,Барингтон,بارينغتون,بیرنگٹن، الینوائے,बाररिंगटन', 42.1539100, -88.1361900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138078, 'Barrington Hills', 'Barrington Hills', '', 42.1447500, -88.1556300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138079, 'Bartlett', 'Bartlett', 'Bartlet,Bartlett,bartleta,bartlyt,Бартлет,Бартлетт,بارتليت,بارٹلیٹ، الینوائے,बार्ट्लेट', 41.9950300, -88.1856300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138080, 'Bartonville', 'Bartonville', '', 40.6503200, -89.6520500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138081, 'Batavia', 'Batavia', 'Batavija,Batejvija,batabhiya,batafya,btywya  aylynwy,Батавия,Батејвија,باتافيا,بتیویا، ایلینوی,بٹاویا، الینوائے,बाटाभिया', 41.8500300, -88.3125700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138082, 'Beach Park', 'Beach Park', '', 42.4222400, -87.8573000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138083, 'Beardstown', 'Beardstown', 'Beards Ferry,Beardstown,Birdstaun,Бирдстаун', 40.0175500, -90.4242900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138084, 'Beecher', 'Beecher', '', 41.3405900, -87.6214300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138085, 'Bellevue', 'Bellevue', '', 40.6844800, -89.6801000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138086, 'Bellwood', 'Bellwood', 'Belvud,belavuda,blwwd,Белвуд,بلوود,بیلووڈ، الینوائے,बेलवूड', 41.8814200, -87.8831200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138087, 'Belvidere', 'Belvidere', 'Bel''vedere,Belvider,Belvidir,belbhidera,blwydr  aylynwy,bylfydyr,Белвидир,Белвідер,Бельведере,بلویدر، ایلینوی,بيلفيدير,بیلویڈیر، الینوائے,बेल्भिदेर', 42.2639100, -88.8442700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138088, 'Bensenville', 'Bensenville', 'Bensenvil,benasenabhila,bnsnfyl,Бенсенвил,بنسنفيل,बेनसेनभिल', 41.9550300, -87.9400700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138089, 'Berkeley', 'Berkeley', 'Berkli,Беркли', 41.8889200, -87.9034000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138090, 'Berwyn', 'Berwyn', 'Beruin,Bervin,barvina,beowin,brwyn,brwyn  aylynwy,Бервин,Бервін,Беруин,بروين,بروین، الینوائے,بروین، ایلینوی,बर्विन,버윈', 41.8505900, -87.7936700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138091, 'Big Rock', 'Big Rock', '', 41.7639200, -88.5470200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138092, 'Bloomingdale', 'Bloomingdale', 'Blumingdejl,blumingadela,blwmynghdyl,Блумингдејл,بلومنگڈیل، الینوائے,بلومينغديل,ब्लूमिंगडेल', 41.9575300, -88.0809000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138093, 'Bloomington', 'Bloomington', 'BMI,Blooming Grove,Bloomington,Blumington,Blumingtona,Blumingtun,Blūmingtona,Keg Grove,beullumingteon,blumingatana,blumingtana,blumintana,blwmnjtwn,blwmyngtwn,bu lu ming dun,buruminton,Блумингтон,Блумингтън,Блумінгтон,بلومنجتون,بلومنگٹن,بلومینگتون,ब्लूमिंगटन,ब्लूमिंग्टन,ব্লুমিংটন,ブルーミントン,布卢明顿,블루밍턴', 40.4842000, -88.9936900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138094, 'Blue Island', 'Blue Island', 'Blu Ajland,Blue Island,Portland,beulluaillaendeu,blu a''ilyanda,blw ayland,blw aylnd  aylynwy,Блу Ајланд,بلو آئی لینڈ، الینوائے,بلو آیلند، ایلینوی,بلو أيلاند,ब्लु आइल्यान्ड,블루아일랜드', 41.6572600, -87.6800500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138095, 'Bolingbrook', 'Bolingbrook', 'Bolingbrook,Bolingbruk,bolingabruka,bwlygh brwk,Болингбрук,بولنگبروک، الینوائے,بوليغ بروك,बोलिङ्गब्रूक', 41.6986400, -88.0684000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138096, 'Boulder Hill', 'Boulder Hill', '', 41.7125300, -88.3361800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138097, 'Bourbonnais', 'Bourbonnais', 'Bourbonnais,Bourbonnais Grove,Bulbonas Grove', 41.1537600, -87.8875400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138098, 'Bradley', 'Bradley', 'Bradli,bradly,bryadali,Брадли,برادلي,بریڈلی، الینوائے,ब्र्याडली', 41.1419800, -87.8611500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138099, 'Braidwood', 'Braidwood', '', 41.2650300, -88.2122800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138100, 'Bridgeview', 'Bridgeview', 'Bridzvju,beulijibyu,brijabhyu,bryjfyw,Бриџвју,بريجفيو,بریجویئو، الینوائے,ब्रिजभ्यू,브리지뷰', 41.7500300, -87.8042200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138101, 'Broadview', 'Broadview', '', 41.8639200, -87.8533900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138102, 'Brookfield', 'Brookfield', 'Brookfield,Brukfild,Grossdale,brukaphilda,brwkfyld,Брукфилд,بروكفيلد,بروکفیلڈ، الینوائے,ब्रूकफिल्ड', 41.8239200, -87.8517300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138103, 'Buffalo Grove', 'Buffalo Grove', 'Bafalo Grouv,Bafalo Grouvas,baffarogurobu,baphelo grobha,bwfalw ghrwf,Бафало Гроув,بفیلو گروو، الینوائے,بوفالو غروف,बफेलो ग्रोभ,バッファローグローブ', 42.1514100, -87.9597900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138104, 'Bull Valley', 'Bull Valley', '', 42.3205800, -88.3550900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138105, 'Burbank', 'Burbank', 'Berbank,barbyanka,brbank,bwrbank  aylynwy,Бербанк,بربانك,بربینک، الینوائے,بوربانک، ایلینوی,बर्ब्याङ्क', 41.7339200, -87.7795000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138106, 'Burnham', 'Burnham', '', 41.6389200, -87.5567100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138107, 'Burr Ridge', 'Burr Ridge', 'Bar Ridz,bara rija,bwr rydj,Бар Риџ,بور ريدج,बर रीज', 41.7489200, -87.9183900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138108, 'Bushnell', 'Bushnell', '', 40.5528200, -90.5062400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138109, 'Byron', 'Byron', 'Bajron,Bloomingville,Byron,Fairview,ba''irana,bayrwn,bayrwn  aylynwy,Бајрон,بائرن، الینوائے,بايرون,بایرون، ایلینوی,बाइरन', 42.1269700, -89.2556600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138110, 'Calumet City', 'Calumet City', 'Calumet,Calumet City,Kaljumet Siti,New Hammond,West Hammond,kalwmyt syty,klemeta siti,Калјумет Сити,كالوميت سيتي,کالومی‌سیتی، ایلینوی,کلامے سٹی، الینوائے,क्लेमेट सिटी', 41.6155900, -87.5294900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138111, 'Calumet Park', 'Calumet Park', 'Kalamet Park,kalwmyt bark,klemeta parka,Каламет Парк,كالوميت بارك,क्लेमेट पार्क', 41.6628100, -87.6606000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138112, 'Cambridge', 'Cambridge', 'Kembridz,Kembridzh,kambrydj,kyambrija,Кембридж,Кембриџ,كامبريدج,کیمبرج، الینوائے,क्याम्ब्रिज', 41.3036500, -90.1929000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138113, 'Camp Point', 'Camp Point', 'Camp Point,Camppoint', 40.0392100, -91.0693000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138114, 'Capron', 'Capron', '', 42.3997400, -88.7403800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138115, 'Carbon Cliff', 'Carbon Cliff', '', 41.4947600, -90.3906800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138116, 'Carol Stream', 'Carol Stream', 'Karol Strim,karwl strym,kyarola strima,Карол Стрим,كارول ستريم,کیرول سٹریم، الینوائے,क्यारोल स्ट्रिम', 41.9125300, -88.1347900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138117, 'Carpentersville', 'Carpentersville', 'Karpintersvil,karapenatarasbhila,karbntrfyl,Карпинтерсвил,كاربنترفيل,کارپینٹرزویل، الینوائے,कारपेनटरस्भिल', 42.1211400, -88.2578600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138118, 'Carthage', 'Carthage', 'Carthago,Kartidz,Kartidzh,jia tai ji,kartheja,kartj  aylynwy,kasejji,kasiji,qrtaj,Картидж,Картиџ,قرطاج,کارتج، ایلینوی,کارتھیج، الینوائے,कार्थेज,カーセッジ,迦太基,카시지', 40.4164300, -91.1362500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138119, 'Carthage', 'Carthage', 'Carthage,Taylor', 41.9189200, -89.3137100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138120, 'Cary', 'Cary', 'Carey Station,Cary,Cary Station,Kehri,Keri,kary,kyari,Кери,Кэри,كاري,क्यारि', 42.2119700, -88.2381400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138121, 'Catlin', 'Catlin', '', 40.0650400, -87.7019700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138122, 'Central City', 'Central City', '', 41.2378100, -88.2817300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138123, 'Champaign', 'Champaign', 'CMI,Champaign,Shampejn,West Urbana,cyampena,shang pei en,shanpen,shmpyn  aylynwy,smpyyn,syaempein,syampe''ina,tshambyghn,Шампейн,Шампејн,שמפיין,تشامبيغن,شمپین، ایلینوی,شیمپین، الینوائے,च्याम्पेन,শ্যাম্পেইন,シャンペーン,尚佩恩,섐페인', 40.1164200, -88.2433800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138124, 'Channahon', 'Channahon', '', 41.4294800, -88.2286700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138125, 'Channel Lake', 'Channel Lake', '', 42.4786300, -88.1375900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138126, 'Chatsworth', 'Chatsworth', '', 40.7536500, -88.2919900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138127, 'Chebanse', 'Chebanse', '', 41.0030900, -87.9081000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138128, 'Chenoa', 'Chenoa', 'Shenoa,ceno''a,chnwa  aylynwy,tshynwa,Шеноа,تشينوا,چنوآ، ایلینوی,چینوآ، الینوائے,चेनोआ', 40.7417000, -88.7197900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138129, 'Cherry Valley', 'Cherry Valley', 'Butler,Cheri Vali,Cherry Valley,ceri bhyali,tshry faly,Чери Вали,تشري فالي,चेरी भ्याली', 42.2347400, -88.9489900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138130, 'Chicago', 'Chicago', 'CHI,Cekaga,Chi-ka-ko,Chi-kâ-kô,Chicago,Chicagu,Chikago,Cikaga,Cikago,Cikaqo,E-Chicago,Gorad Chykaga,Kikako,Shikago,Sicagum,Sikago,The Windy City,Tsikago,Windy City,chikhako,cikago,cikako,shikago,shkagw,shykaghw,shykagw,shykajw,shyqgw,sikago,sikkagea,syqgw,zhi jia ge,Çikago,Çikaqo,Ĉikago,Čikaga,Čikago,Čikāga,Čėkaga,Şikago,Σικάγο,Горад Чыкага,Чикаго,Чикаґо,Չիկագո,שיקאגא,שיקגו,شيكاجو,شيكاغو,شکاگو,شیکاگو,شیکاگۆ,ܫܝܩܓܘ,शिकागो,শিকাগো,ਸ਼ਿਕਾਗੋ,சிகாகோ,చికాగో,ಶಿಕಾಗೊ,ഷിക്കാഗോ,ชิคาโก,ရှီကာဂိုမြို့,ჩიკაგო,ሺካጎ,ᓰᖄᑯ,Ṣìkágò,シカゴ,芝加哥,시카고,', 41.8500300, -87.6500500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138131, 'Chicago Heights', 'Chicago Heights', 'Bloom,Chicago Heights,Chikago Khajts,Chikago-Gajts,Thorn Grove,shykaghw hayts,shykagw hayts  aylynwy,Чикаго Хајтс,Чикаго-Гайтс,شيكاغو هايتس,شکاگو ہائٹس، الینوائے,شیکاگو هایتس، ایلینوی', 41.5061500, -87.6356000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138132, 'Chicago Ridge', 'Chicago Ridge', '', 41.7014200, -87.7792200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138133, 'Chillicothe', 'Chillicothe', 'Chillicothe,La Salle Prairie', 40.9222600, -89.4862000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138134, 'Cicero', 'Cicero', 'Cicero,Ciceron,Cícero,Hawthorne,Siseras,Sisero,shisero,siseolo,sisero,sysyrw,Сисеро,Сісеро,Цицерон,سيسيرو,سیسیرو، الینوائے,सिसेरो,シセロ,시서로', 41.8455900, -87.7539400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138135, 'Clarendon Hills', 'Clarendon Hills', 'Clarendon,Clarendon Hills', 41.7975300, -87.9547800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138136, 'Clifton', 'Clifton', 'Klifton,Клифтон', 40.9353100, -87.9344900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138137, 'Clinton', 'Clinton', 'Klinton,klintana,klyntwn,klyntwn  aylynwy,Клинтон,كلينتون,کلنٹن، الینوائے,کلینتون، ایلینوی,क्लिन्टन', 40.1536500, -88.9645300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138138, 'Coal City', 'Coal City', '', 41.2878100, -88.2856200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138139, 'Coal Valley', 'Coal Valley', '', 41.4286500, -90.4609600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138140, 'Colchester', 'Colchester', 'Chester,Colchester', 40.4264300, -90.7926300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138141, 'Colfax', 'Colfax', '', 40.5669800, -88.6164500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138142, 'Colona', 'Colona', 'Colona,Colona Station,Kolona,ke luo na,klwna  aylynwy,kolona,kwlwna,Колона,كولونا,کلونا، ایلینوی,کولونا، الینوائے,कोलोना,科洛纳', 41.4839200, -90.3531800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138143, 'Cortland', 'Cortland', 'Cortland,Courtland,Courtland Station,Lost Grove,Pampas,Richland', 41.9200300, -88.6887000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138144, 'Country Club Hills', 'Country Club Hills', '', 41.5680900, -87.7203300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138145, 'Countryside', 'Countryside', 'Kantrisajd,kantrisa''ida,kawntrysayd,Кантрисајд,كاونتريسايد,کانتری‌ساید، ایلینوی,کنٹری سائڈ، الینوائے,कन्ट्रीसाइड', 41.7828100, -87.8781100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138146, 'Crest Hill', 'Crest Hill', '', 41.5547500, -88.0986700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138147, 'Crestwood', 'Crestwood', 'Krestvud,krestavuda,krstwwd,Крествуд,كرستوود,کریسٹووڈ، الینوائے,क्रेस्टवूड', 41.6611400, -87.7525500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138148, 'Crete', 'Crete', 'Crete,Woods Corners', 41.4444800, -87.6314300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138149, 'Creve Coeur', 'Creve Coeur', 'Creve Coeur,Crevecoeur,Fort Creve Coeur', 40.6472600, -89.5912100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138150, 'Crystal Lake', 'Crystal Lake', 'Brooklyn,Chrystal Lake,Crystal Lake,Crystal Lake Station,Crystallake,Dearborn,Kristal Lejk,North Crystal Lake,Nunda,kristala leka,krystal lyk,Кристал Лејк,كريستال ليك,کرستل لیک، الینوائے,کریستال‌لیک، ایلینوی,क्रिस्टल लेक', 42.2411300, -88.3162000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138151, 'Crystal Lawns', 'Crystal Lawns', '', 41.5703100, -88.1581200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138152, 'Cuba', 'Cuba', 'Centerville,Cuba,Middletown', 40.4928200, -90.1906800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138153, 'Cuba', 'Cuba', '', 42.1839100, -88.1909100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138154, 'Danvers', 'Danvers', 'Denvers,Денверс', 40.5294800, -89.1773100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138155, 'Danville', 'Danville', 'DNV,Danvil,Danvil'',Danvill,Danville,Vermilion Court House,daenbil,dan wei er,danbiru,danfyl,dnwyl  aylynwy,dyanabhila,Данвил,Данвилл,Данвіль,دانفيل,دنویل، ایلینوی,ڈنویل، الینوائے,ड्यानभिल,ড্যানভিল,ダンビル,丹维尔,댄빌', 40.1244800, -87.6300200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138156, 'Darien', 'Darien', 'Derijen,daryn,daryn  aylynwy,deriyana,Деријен,دارين,دارین، ایلینوی,ڈیرین، الینوائے,डेरियन', 41.7519800, -87.9739500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138157, 'Davis Junction', 'Davis Junction', '', 42.1016900, -89.0931600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138158, 'DeKalb', 'DeKalb', 'Buena Vista,De Kalb,De-Kalb,DeKalb,DeKalb Center,Dekab,Huntleys Grove,dekalba,di ka er bu,dikaelbeu,dkalb  aylynwy,dykalb,Де-Калб,Декаб,ديكالب,دکالب، ایلینوی,ڈے کالب، الینوائے,डेकाल्ब,迪卡尔布,디캘브', 41.9294700, -88.7503600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138159, 'Deer Park', 'Deer Park', '', 42.1608600, -88.0814700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138160, 'Deerfield', 'Deerfield', 'Dirfild,di er fei er de,dyaraphilda,dyrfyld,Дирфилд,ديرفيلد,ड्यरफिल्ड,迪爾菲爾德', 42.1711400, -87.8445100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138161, 'Delavan', 'Delavan', '', 40.3725400, -89.5473200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138162, 'Depue', 'Depue', 'De Pue,Depue,Howe,Newport Landing,Selby,Selby Station,Sherman,Trenton', 41.3242000, -89.3067500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138163, 'Des Plaines', 'Des Plaines', 'Des Plaines,Des Pleinsas,Des Plejns,Des-Plejns,Desplaines Station,Maine,Rand,des ple''insa,deseupeulleinseu,dys blyns,Дес Плејнс,Дес-Плейнс,دس‌پلینز، ایلینوی,ديس بلينس,دےپلینے، الینوائے,डेस् प्लेइन्स,데스플레인스', 42.0333600, -87.8834000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138164, 'Diamond', 'Diamond', '', 41.2886400, -88.2517300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138165, 'Dixmoor', 'Dixmoor', '', 41.6317000, -87.6608800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138166, 'Dixon', 'Dixon', 'Dikson,di ke sen,diksana,dykswn,dykswn  aylynwy,Диксон,ديكسون,دیکسون، ایلینوی,ڈکسن، الینوائے,डिक्सन,迪克森', 41.8389200, -89.4795500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138167, 'Dolton', 'Dolton', 'Dalton,Dalton Station,Daltons Station,Dolton,Dolton Station Village,Dolton''s Station,Doltons,Doltons Station', 41.6389200, -87.6072700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138168, 'Downers Grove', 'Downers Grove', 'Downers Grove,East Grove', 41.8089200, -88.0111700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138169, 'Dunlap', 'Dunlap', '', 40.8617000, -89.6787100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138170, 'Durand', 'Durand', 'Durand,Howard', 42.4364000, -89.3320600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138171, 'Dwight', 'Dwight', 'Dvajt,Dwight,Western New York,Двајт', 41.0944800, -88.4250600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138172, 'Earlville', 'Earlville', '', 41.5894800, -88.9220300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138173, 'East Dundee', 'East Dundee', 'Dundee,East Dundee', 42.0989100, -88.2714700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138174, 'East Dubuque', 'East Dubuque', 'Dunleith,Dunlieth,East Dubuque,Ist Dubjuk,ayst dabywk  aylynwy,ayst dwbwk,ista dyubukve,Ист Дубјук,إيست دوبوك,ایست دابیوک، ایلینوی,ایسٹ دوبیوک، الینوائے,इस्ट ड्युबुक्वे', 42.4922300, -90.6429100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138175, 'East Hazel Crest', 'East Hazel Crest', '', 41.5736500, -87.6464300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138176, 'East Moline', 'East Moline', 'Ist Molin,ayst mwlyn,ayst mwlyn  aylynwy,ista mola''ina,Ист Молин,إيست مولين,ایست مولین، ایلینوی,ایسٹ مولین، الینوائے,इस्ट मोलाइन', 41.5008700, -90.4443000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138177, 'East Peoria', 'East Peoria', 'Ist Piorija,ayst bywrya,ayst pywrya  aylynwy,ista pe''oriya,Ист Пиорија,إيست بيوريا,ایست پیوریا، ایلینوی,ایسٹ پیوریا، الینوائے,इस्ट पेओरिया', 40.6661500, -89.5801000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138178, 'El Paso', 'El Paso', 'Ehl''-Paso,El Paso,Elpaso,al basw,ela paso,Ел Пасо,Эль-Пасо,إل باسو,ال‌پاسو، ایلینوی,ایل پاسو، الینوائے,एल पासो', 40.7392000, -89.0164600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138179, 'Elburn', 'Elburn', '', 41.8922500, -88.4723000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138180, 'Elgin', 'Elgin', 'Ehldzhin,Eldzhin,Eldzin,Elgin,ai er jin,algn  aylynwy,aljyn,aylgn,elgin,elgina,erujin,Елджін,Елџин,Элджин,إلجين,الگن، الینوائے,الگن، ایلینوی,ایلگن,एल्गिन,エルジン,埃爾金,엘긴', 42.0372500, -88.2811900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138181, 'Elk Grove Village', 'Elk Grove Village', 'Elk Grouv Vilidz,Elk Grove,Elk Grove Village,elka grobha bhileja,qryt alk ghrwf,Елк Гроув Вилиџ,ایلک گروو گاؤں، الینوائے,قرية إلك غروف,एल्क ग्रोभ भिलेज', 42.0039200, -87.9703500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138182, 'Elmhurst', 'Elmhurst', 'Cottage Hill,Elmhurst,Elmkherst,ai er mu he si te,almhrst  aylynwy,almhwrst,elmaharsta,Елмхерст,إلمهورست,المهرست، ایلینوی,المہرست، الینوائے,एल्महर्स्ट,埃尔姆赫斯特', 41.8994700, -87.9403400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138183, 'Elmwood', 'Elmwood', 'Elmvud,almwwd,almwwd  aylynwy,elmavuda,Елмвуд,إلموود,الموود، ایلینوی,المووڈ، الینوائے,एल्मवूड', 40.7778200, -89.9665000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138184, 'Elmwood Park', 'Elmwood Park', 'Elmvud Park,almwwd bark,elmavuda parka,Елмвуд Парк,إلموود بارك,ایلم ووڈ پارک، الینوائے,एल्मवूड पार्क', 41.9211400, -87.8092300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138185, 'Elwood', 'Elwood', '', 41.4039200, -88.1117200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138186, 'Erie', 'Erie', 'Ehri,Эри', 41.6564200, -90.0792900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138187, 'Eureka', 'Eureka', 'Ehvrika,Jurika,yureka,ywrka,ywryka  aylynwy,Јурика,Эврика,يوركا,یوریکا، الینوائے,یوریکا، ایلینوی,युरेका', 40.7214300, -89.2728600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138188, 'Evanston', 'Evanston', 'Ehvanston,Evanston,Evanstonas,Evanstun,Gorad Ehvanstan,Grosse Pointe,Ridgeville,ai wen si dun,awanstwn  aylynwy,ayfanstwn,ebansuton,ebeonseuteon,ibhansatana,Горад Эванстан,Еванстон,Еванстън,Эванстон,אוונסטון,إيفانستون,اوانستون، ایلینوی,اوانسٹن، الینوائے,इभान्सटन,എവൻസ്റ്റൺ,エバンストン,埃文斯顿,에번스턴', 42.0411400, -87.6900600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138189, 'Evergreen Park', 'Evergreen Park', 'Evergrin Park,afrghryn bark,ebharagrina parka,Евергрин Парк,إفرغرين بارك,एभरग्रीन पार्क', 41.7205900, -87.7017200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138190, 'Fairbury', 'Fairbury', '', 40.7472600, -88.5147800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138191, 'Fairfield', 'Fairfield', '', 42.2191900, -88.0614700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138192, 'Fairmont', 'Fairmont', '', 41.5561400, -88.0592300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138193, 'Farmer City', 'Farmer City', '', 40.2433700, -88.6425700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138194, 'Farmington', 'Farmington', 'Farmington,farmnghtwn,farmyngtwn  aylynwy,pharmingatana,Фармингтон,فارمنغتون,فارمنگٹن، الینوائے,فارمینگتون، ایلینوی,फार्मिंगटन', 40.6980900, -90.0059500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138195, 'Farmington', 'Farmington', '', 41.9447500, -88.3159100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138196, 'Fisher', 'Fisher', '', 40.3147600, -88.3500500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138197, 'Flanagan', 'Flanagan', '', 40.8780900, -88.8611800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138198, 'Flossmoor', 'Flossmoor', '', 41.5428100, -87.6847700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138199, 'Ford Heights', 'Ford Heights', 'East Chicago Heights,Ford Heights', 41.5064200, -87.5917100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138200, 'Forest Lake', 'Forest Lake', '', 42.2075200, -88.0556300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138201, 'Forest Park', 'Forest Park', 'Forest Park,Forest-Park,Forist Park,Harlem,fwrst bark,pharesta parka,Форест-Парк,Форист Парк,فورست بارك,फरेस्ट पार्क', 41.8794800, -87.8136700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138202, 'Forrest', 'Forrest', '', 40.7519800, -88.4111600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138203, 'Forreston', 'Forreston', '', 42.1261400, -89.5792800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138204, 'Fox Lake', 'Fox Lake', 'Foks Lejk,Фокс Лејк', 42.3966900, -88.1837000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138205, 'Fox Lake Hills', 'Fox Lake Hills', '', 42.4080800, -88.1317500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138206, 'Fox River Grove', 'Fox River Grove', '', 42.2008600, -88.2145300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138207, 'Frankfort', 'Frankfort', 'Frankfort,Frankfort Station,Frankfurt,frankfwrt,phryankapharta,Франкфорт,Франкфурт,فرانكفورت,فرینکفرٹ، الینوۓ,फ्र्यांकफर्ट', 41.4958700, -87.8486600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138208, 'Frankfort Square', 'Frankfort Square', '', 41.5189200, -87.8031000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138209, 'Franklin Park', 'Franklin Park', 'Franklin Park,franklyn bark,phryanklina parka,Франклин Парк,فرانكلين بارك,फ्र्याङ्क्लिन पार्क', 41.9353100, -87.8656200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138210, 'Freeport', 'Freeport', 'FEP,Friport,fry bwrt,peulipoteu,phriporta,Фрипорт,Фріпорт,فري بورت,فری پورٹ، الینوائے,فری‌پورت، ایلینوی,फ्रीपोर्ट,프리포트', 42.2966900, -89.6212300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138211, 'Fulton', 'Fulton', 'Fulton,fwltwn,fwltwn  aylynwy,phulatana,Фултон,فولتون,فولتون، ایلینوی,فولٹن، الینوائے,फुलटन', 41.8672500, -90.1595700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138212, 'Gages Lake', 'Gages Lake', '', 42.3516900, -87.9825800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138213, 'Galena', 'Galena', 'Galena,Galina,La Pointe,garina,ghalyna,gyalena,jlyna  aylynwy,Галина,جلینا، ایلینوی,غالينا,گلینا، الینوائے,ग्यालेना,ガリーナ', 42.4166700, -90.4290200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138214, 'Galesburg', 'Galesburg', 'GBG,Galesburg,Galesburgh,Gejlsberg,Gejlsburg,gai er si bao,geiruzubagu,gelsabarga,ghalysbwrgh,gylzbrg  aylynwy,Гейлсберг,Гейлсбург,Гејлсбург,غاليسبورغ,گیلزبرگ، الینوائے,گیلزبرگ، ایلینوی,गेल्सबर्ग,ゲイルズバーグ,盖尔斯堡', 40.9478200, -90.3712400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138215, 'Galva', 'Galva', 'Galva,Gefle', 41.1675400, -90.0426100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138216, 'Gardner', 'Gardner', 'Gardiner,Gardner,Гарднер', 41.1855900, -88.3097800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138217, 'Geneseo', 'Geneseo', '', 41.4480900, -90.1542800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138218, 'Geneva', 'Geneva', 'Dzeniva,Zheneva,jenebha,jnyf,zhnw  aylynwy,Џенива,Женева,جنيف,جنیوا، الینوائے,ژنو، ایلینوی,जेनेभा', 41.8875300, -88.3053500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138219, 'Genoa', 'Genoa', '', 42.0972500, -88.6928700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138220, 'Georgetown', 'Georgetown', '', 42.1397500, -89.8287300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138221, 'Germantown Hills', 'Germantown Hills', '', 40.7664300, -89.4678700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138222, 'Gibson City', 'Gibson City', 'Gibson,Gibson City', 40.4584300, -88.3846000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138223, 'Gifford', 'Gifford', '', 40.3058700, -88.0211500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138224, 'Gilberts', 'Gilberts', '', 42.1033600, -88.3728600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138225, 'Gilman', 'Gilman', '', 40.7667000, -87.9922600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138226, 'Glasford', 'Glasford', '', 40.5725400, -89.8134400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138227, 'Glen Ellyn', 'Glen Ellyn', 'Danby,Glen Elin,Glen Ellyn,Prospect Park,ghln alyn,glena elina,Глен Елин,غلن إلين,ग्लेन एलिन', 41.8775300, -88.0670100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138228, 'Glenview', 'Glenview', 'Glenview,NBU,ZWV', 42.0697500, -87.7878400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138229, 'Glenwood', 'Glenwood', '', 41.5425300, -87.6022700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138230, 'Goodings Grove', 'Goodings Grove', 'Gooding''s Grove,Goodings Grove', 41.6292000, -87.9308900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138231, 'Glencoe', 'Glencoe', 'Glenko,Glenkou,Гленко,Гленкоу', 42.1350300, -87.7581200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138232, 'Grandwood Park', 'Grandwood Park', '', 42.3930800, -87.9867400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138233, 'Grant Park', 'Grant Park', 'Grant,Grant Park,Grantpark', 41.2411400, -87.6461500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138234, 'Granville', 'Granville', '', 41.2611500, -89.2275900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138235, 'Grayslake', 'Grayslake', 'Grays Lake,Grayslake,Greyslake', 42.3444700, -88.0417500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138236, 'Green Oaks', 'Green Oaks', '', 42.2900200, -87.9034100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138237, 'Green Rock', 'Green Rock', '', 41.4730900, -90.3576300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138238, 'Gridley', 'Gridley', '', 40.7433700, -88.8814600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138239, 'Gurnee', 'Gurnee', 'Gerni,Gurnee,Gurnee Station,garni,ghwrny,Герни,غورني,گورنی، الینوائے,गर्नी', 42.3703000, -87.9020200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138240, 'Hainesville', 'Hainesville', 'Hainesville,Hainsville', 42.3450200, -88.0678600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138241, 'Hamilton', 'Hamilton', 'Gamil''ton,Khamilton,hamiruton,hamyltwn,hmyltwn  aylynwy,Гамильтон,Хамилтон,هاميلتون,همیلتون، ایلینوی,ہیملٹن، الینوائے,ハミルトン', 40.3964300, -91.3390400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138242, 'Hampshire', 'Hampshire', '', 42.0978000, -88.5303600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138243, 'Hampton', 'Hampton', 'Khehmpton,Хэмптон', 41.5558700, -90.4093000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138244, 'Hanna City', 'Hanna City', '', 40.6917000, -89.7951100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138245, 'Hanover Park', 'Hanover Park', 'Khanover Park,hanwwr bark,Хановер Парк,هانوور بارك,ہنور پارک، الینوائے', 41.9994700, -88.1450700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138246, 'Harvard', 'Harvard', 'Harvard,Kharvard,Milk Center of the World,harward  aylynwy,Харвард,هاروارد، ایلینوی,ہارورڈ، الینوائے', 42.4222400, -88.6137100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138247, 'Harvey', 'Harvey', 'Kharvi,harbhei,harfy,harwy  aylynwy,Харви,هارفي,هاروی، ایلینوی,ہاروے، الینوائے,हार्भेी', 41.6100300, -87.6467100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138248, 'Harwood Heights', 'Harwood Heights', '', 41.9672500, -87.8075600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138249, 'Havana', 'Havana', 'Khavana,hafana,hawana  aylynwy,Хавана,هافانا,هاوانا، ایلینوی,ہوانا، الینوائے', 40.3000400, -90.0609500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138250, 'Hawthorn Woods', 'Hawthorn Woods', '', 42.2169700, -88.0495200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138251, 'Hazel Crest', 'Hazel Crest', 'Khejzel Krest,hazl krst,hyajela kresta,Хејзел Крест,هازل كرست,ह्याजेल क्रेस्ट', 41.5717000, -87.6944900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138252, 'Hebron', 'Hebron', '', 42.4716900, -88.4323200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138253, 'Hennepin', 'Hennepin', 'Fort Deposit,Fort Wilbourn,Hennepin,Prairie de Prue', 41.2542000, -89.3423100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138254, 'Henry', 'Henry', '', 41.1114200, -89.3564800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138255, 'Herscher', 'Herscher', '', 41.0492000, -88.0978300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138256, 'Heyworth', 'Heyworth', '', 40.3133700, -88.9736900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138257, 'Hickory Hills', 'Hickory Hills', '', 41.7255900, -87.8250600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138258, 'Highland Park', 'Highland Park', 'Gajlend-Park,Highland Park,Khajland Park,Khajlend-Park,Port Clinton,haillaendeupakeu,hayland bark,haylnd park  aylynwy,Гайленд-Парк,Хайленд-Парк,Хајланд Парк,هايلاند بارك,هایلند پارک، ایلینوی,ہائی لینڈ پارک، الینوائے,하일랜드파크', 42.1816900, -87.8003400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138259, 'Highwood', 'Highwood', 'Highwood,Khajvud,Saint John,Хајвуд', 42.1997500, -87.8092300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138260, 'Hillcrest', 'Hillcrest', '', 41.9511400, -89.0645400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138261, 'Hillside', 'Hillside', '', 41.8778100, -87.9028400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138262, 'Hinckley', 'Hinckley', '', 41.7689200, -88.6409100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138263, 'Hinsdale', 'Hinsdale', '', 41.8008600, -87.9370100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138264, 'Hodgkins', 'Hodgkins', 'Khodzkins,hwdjkynz,Хоџкинс,هودجكينز', 41.7689200, -87.8578300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138265, 'Hoffman Estates', 'Hoffman Estates', '', 42.0428100, -88.0798000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138266, 'Homer', 'Homer', '', 40.0347600, -87.9580900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138267, 'Homer Glen', 'Homer Glen', '', 41.6000300, -87.9381100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138268, 'Hometown', 'Hometown', 'Hometown,Pleasant Hill', 41.7344800, -87.7314400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138269, 'Homewood', 'Homewood', 'Khomvud,hwmwwd,Хомвуд,هوموود', 41.5572600, -87.6656000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138270, 'Hoopeston', 'Hoopeston', 'Hoopeston,Hoopestown,Hoopston,Leeds,North Hoopeston', 40.4672600, -87.6683600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138271, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 40.6058700, -88.9873000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138272, 'Huntley', 'Huntley', 'Huntley,Huntley Grove,Khantli,Хантли', 42.1680800, -88.4281400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138273, 'Indian Head Park', 'Indian Head Park', '', 41.7703100, -87.9022800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138274, 'Ingalls Park', 'Ingalls Park', '', 41.5225300, -88.0428300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138275, 'Inverness', 'Inverness', '', 42.1180800, -88.0961900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138276, 'Island Lake', 'Island Lake', '', 42.2761300, -88.1920300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138277, 'Itasca', 'Itasca', '', 41.9750300, -88.0072900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138278, 'Johnsburg', 'Johnsburg', 'Johnsburg,Johnsburgh', 42.3800200, -88.2420300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138279, 'Joliet', 'Joliet', 'JOT,Joliet,Juliet', 41.5251900, -88.0834000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138280, 'Justice', 'Justice', '', 41.7444800, -87.8378300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138281, 'Kankakee', 'Kankakee', 'IKK,Kankaki,kankaki,kankaky,kankaky  aylynwy,kyanakaki,Канкаки,Канкакі,كانكاكي,کانکاکی، ایلینوی,کنکاکی، الینوائے,कान्काकी,ক্যানকাকি', 41.1200300, -87.8611500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138282, 'Kenilworth', 'Kenilworth', 'Kenilvort,ken ni er wo si,kenilavartha,knylwrth,Кенилворт,كنيلورث,केनिलवर्थ,肯尼爾沃斯', 42.0858600, -87.7175600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138283, 'Kewanee', 'Kewanee', 'Kivoni,kivani,kywany,kywny  aylynwy,Кивони,كيواني,کیوانی، الینوائے,کیونی، ایلینوی,कीवानी', 41.2455900, -89.9248300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138284, 'Kildeer', 'Kildeer', '', 42.1705800, -88.0478500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138285, 'Kingston', 'Kingston', 'Kingston,Stuartville,Кингстон', 42.0997500, -88.7589800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138286, 'Kirkland', 'Kirkland', '', 42.0925300, -88.8512100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138287, 'Knollwood', 'Knollwood', '', 42.2861300, -87.8856300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138288, 'Knollwood', 'Knollwood', '', 42.2847900, -87.8834200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138289, 'Knoxville', 'Knoxville', 'Noksvill,Ноксвилл', 40.9083700, -90.2848500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138290, 'La Grange', 'La Grange', 'Hazel Glen,Kensington,Kensington Heights,La Grange,Lagrange,Robbville,West Lyons', 41.8050300, -87.8692300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138291, 'La Grange Park', 'La Grange Park', 'La Grange Park,LaGrange Park', 41.8347500, -87.8617300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138292, 'La Harpe', 'La Harpe', 'Fort La Harpe,Franklin,Hancock Prairie,La Harpe,La Kharp,Laharpe,la harb,laharp  aylynwy,Ла Харп,لا هارب,لا ہارپ، الینوائے,لاهارپ، ایلینوی,ラ・ハープ', 40.5833700, -90.9693100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138293, 'La Salle', 'La Salle', 'La Salle,LaSalle,Lasal,Lasalle,Ласал', 41.3333700, -89.0917500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138294, 'Lacon', 'Lacon', 'Lejkon,lakona,lakwn,lkan  aylynwy,Лејкон,لاكون,لکان، ایلینوی,لیکون، الینوائے,लाकोन', 41.0247600, -89.4112000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138295, 'Ladd', 'Ladd', '', 41.3825300, -89.2189700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138296, 'Lake Barrington', 'Lake Barrington', '', 42.2125200, -88.1525800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138297, 'Lake Bluff', 'Lake Bluff', 'Lejk Blaf,lyk blwf,Лејк Блаф,ليك بلوف', 42.2789100, -87.8342400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138298, 'Lake Catherine', 'Lake Catherine', '', 42.4791900, -88.1334200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138299, 'Lake Forest', 'Lake Forest', 'Lejk Forist,leikeupoliseuteu,leka pharesta,lyk fwrst,lyk fwrst  aylynwy,reikuforesuto,Лејк Форист,ليك فورست,لیک فورست، ایلینوی,لیک فوریسٹ، الینوائے,लेक फरेस्ट,レイクフォレスト,레이크포리스트', 42.2586300, -87.8406300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138300, 'Lake Summerset', 'Lake Summerset', '', 42.4544600, -89.3895600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138301, 'Lake Villa', 'Lake Villa', '', 42.4169700, -88.0739700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138302, 'Lake Zurich', 'Lake Zurich', '', 42.1969700, -88.0934100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138303, 'Lake in the Hills', 'Lake in the Hills', '', 42.1816900, -88.3303600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138304, 'Lake of the Woods', 'Lake of the Woods', '', 40.2064200, -88.3686700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138305, 'Lakemoor', 'Lakemoor', '', 42.3286300, -88.1989700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138306, 'Lakewood', 'Lakewood', 'Lejkvud,Лейквуд', 42.2291900, -88.3550900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138307, 'Lakewood Shores', 'Lakewood Shores', '', 41.2817000, -88.1447800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138308, 'Lanark', 'Lanark', 'Lanark,lanark,lanarka,lanrk  aylynwy,Ланарк,لانارك,لانرک، ایلینوی,لینارک، الینوائے,लान्आर्क', 42.1022500, -89.8334500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138309, 'Lansing', 'Lansing', 'Lansing,lansyngh,lyansinga,ranshingu,Лансинг,لانسينغ,ल्यान्सिंग,ランシング', 41.5647600, -87.5389300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138310, 'Le Roy', 'Le Roy', 'King City,Le Roy,Leroy', 40.3519800, -88.7642400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138311, 'Lemont', 'Lemont', 'Athens,Keepatau,Lemont,Limont,Palmyra,Yankee Settlement,lemonta,lymwnt,Лимонт,ليمونت,लेमोन्ट', 41.6736400, -88.0017300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138312, 'Lewistown', 'Lewistown', 'Luiston,lwyyztawn  aylynwy,lystawn,Луистон,لوییزتاون، ایلینوی,ليستاون,لیوس ٹاؤن، الینوائے', 40.3931000, -90.1548400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138313, 'Lexington', 'Lexington', 'Leksington,lksyngtwn  aylynwy,lyksynghtwn,Лексингтон,ليكسينغتون,لکسینگتون، ایلینوی,لیکسنگٹن، الینوائے', 40.6414200, -88.7834000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138314, 'Libertyville', 'Libertyville', 'Burlington,Independence Grove,Libertivil,Libertyville,li bo di wei er,Либертивил,利伯蒂维尔', 42.2830800, -87.9531300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138315, 'Lily Lake', 'Lily Lake', '', 41.9489200, -88.4778600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138316, 'Lincoln', 'Lincoln', 'Camden,Lincoln,Linkol''n,Linkoln,Postville,linkana,lynkwln,lynkwln  aylynwy,Линколн,Линкольн,لنکن، الینوائے,لينكولن,لینکولن، ایلینوی,लिङ्कन', 40.1483800, -89.3648200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138317, 'Lincolnshire', 'Lincolnshire', 'Linkol''nshir,Linkolnshir,Линколншир,Линкольншир', 42.1900200, -87.9084000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138318, 'Lincolnwood', 'Lincolnwood', 'Lincolnwood,Linkolnvud,Tessville,lynklnwwd,Линколнвуд,لينكلنوود', 42.0044800, -87.7300600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138319, 'Lindenhurst', 'Lindenhurst', '', 42.4105800, -88.0261900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138320, 'Lisle', 'Lisle', 'Lajl,Lilu,Lisle,Lisle Station,lysl,Лајл,Лилу,ليسل', 41.8011400, -88.0747900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138321, 'Lockport', 'Lockport', 'Lockport,Lokport,Runyontown,Yankee Settlement,lakaporta,lwkbwrt,Локпорт,لاک پورٹ، الینوائے,لاک‌پورت، ایلینوی,لوكبورت,लकपोर्ट', 41.5894800, -88.0578400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138322, 'Lombard', 'Lombard', 'Babock''s Grove,Lombard,lombarda,lwmbard,Ломбард,لومبارد,لومبارڈ، الینوائے,लोम्बार्ड', 41.8800300, -88.0078400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138323, 'Long Grove', 'Long Grove', '', 42.1783600, -87.9978500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138324, 'Long Lake', 'Long Lake', '', 42.3708500, -88.1275800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138325, 'Loves Park', 'Loves Park', 'Lavs Park,Love''s Grove,Love''s Park,Loves Park,labhsa parka,lawz park  aylynwy,lwfz bark,Лавс Парк,لاوز پارک، ایلینوی,لوفز بارك,لووز پارک، الینوائے,लभ्स पार्क', 42.3200200, -89.0581600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138326, 'Lynwood', 'Lynwood', 'Linvud,Линвуд', 41.5264200, -87.5386500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138327, 'Lynwood', 'Lynwood', '', 41.6836400, -88.3936800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138328, 'Lyons', 'Lyons', '', 41.8133700, -87.8181100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138329, 'Machesney Park', 'Machesney Park', 'Machesney Park,RMC', 42.3472400, -89.0390000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138330, 'Mackinaw', 'Mackinaw', '', 40.5369800, -89.3575900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138331, 'Macomb', 'Macomb', 'MQB,Macomb,Makom,Washington,ma ke mu,makwm,makwm  aylynwy,meokom,myakamba,Маком,ماكوم,ماکوم، ایلینوی,ماکومب، الینوائے,म्याकम्ब,马克姆,머콤', 40.4592100, -90.6718000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138332, 'Mahomet', 'Mahomet', 'Mahomet,Makhomet,Middletown,mahometa,mahwmt,Махомет,ماهومت,माहोमेट', 40.1953100, -88.4042200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138333, 'Malta', 'Malta', '', 41.9297500, -88.8609200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138334, 'Manhattan', 'Manhattan', 'Mankhehtten,Манхэттен', 41.4225300, -87.9858900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138335, 'Manito', 'Manito', '', 40.4258700, -89.7792800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138336, 'Manteno', 'Manteno', '', 41.2505900, -87.8314300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138337, 'Maple Park', 'Maple Park', 'Lodi,Maple Park', 41.9075300, -88.5992500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138338, 'Marengo', 'Marengo', 'Marengo,Pleasant Grove,marngw  aylynwy,marynghw,myarengo,Маренго,Маренґо,مارنگو، الینوائے,مارنگو، ایلینوی,مارينغو,म्यारेंगो', 42.2486300, -88.6084300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138339, 'Markham', 'Markham', '', 41.5936500, -87.6947700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138340, 'Maroa', 'Maroa', '', 40.0364300, -88.9570300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138341, 'Marquette Heights', 'Marquette Heights', '', 40.6175400, -89.6003800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138342, 'Marseilles', 'Marseilles', 'Marsejls,marselsa,marsyh  aylynwy,mrsylya,Марсејлс,مارسیل، الینوائے,مارسیه، ایلینوی,مرسيليا,मार्सेल्स', 41.3308700, -88.7081300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138343, 'Mason City', 'Mason City', 'Mejson-Siti,Мейсон-Сити', 40.2022700, -89.6981600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138344, 'Matteson', 'Matteson', '', 41.5039200, -87.7131000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138345, 'Maywood', 'Maywood', 'Maywood i Illinois,Mehjvud,Meivuda,Meivudas,Mejud,Mejvud,maywwd,mei wu shi,meiuddo,meiudeu,mevuda,my wwd,myywwd,myywwwd,Мейвуд,Мейуд,Мејвуд,Мэйвуд,מייווד,מייוווד,مايوود,می وود,मेवूड,メイウッド,梅坞市,메이우드', 41.8792000, -87.8431200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138346, 'McCullom Lake', 'McCullom Lake', '', 42.3683500, -88.2925900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138347, 'McHenry', 'McHenry', 'Makkhenri,makhnry,mikahenri,Макхенри,ماكهنري,مک ہنری، الینوائے,مک‌هنری، ایلینوی,मिकहेन्री', 42.3333500, -88.2667500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138348, 'Melrose Park', 'Melrose Park', 'Melrose,Melrose Park,Melroz Park,melroja parka,mlrwz bark,Мелроз Парк,ملروز بارك,मेल्रोज पार्क', 41.9005900, -87.8567300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138349, 'Mendota', 'Mendota', '', 41.5472500, -89.1175900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138350, 'Merrionette Park', 'Merrionette Park', 'Marionette Park,Merrionette Park', 41.6842000, -87.7003300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138351, 'Metamora', 'Metamora', 'Metamora,metamora,mytamwra,Метамора,ميتامورا,मेटामोरा', 40.7905900, -89.3606400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138352, 'Midlothian', 'Midlothian', 'Midlotijan,midlothiyana,mydlwthyan,Мидлотијан,ميدلوثيان,मिड्लोथियन', 41.6253100, -87.7175500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138353, 'Milan', 'Milan', '', 41.4530900, -90.5720800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138354, 'Milford', 'Milford', 'Milford,Милфорд', 40.6283700, -87.6961400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138355, 'Minier', 'Minier', '', 40.4336500, -89.3131500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138356, 'Minonk', 'Minonk', '', 40.9044800, -89.0345200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138357, 'Minooka', 'Minooka', '', 41.4553100, -88.2617300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138358, 'Mokena', 'Mokena', '', 41.5261400, -87.8892200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138359, 'Moline', 'Moline', 'MLI,Molijn,Molin,Moline,Quad Cities,mo lin,mola''ina,mwlyn,mwlyn  aylynwy,Молийн,Молин,Молін,مولن، الینوائے,مولين,مولین، ایلینوی,मोलाइन,莫林', 41.5067000, -90.5151300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138360, 'Momence', 'Momence', 'Lorain,Momence', 41.1667000, -87.6628100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138361, 'Monee', 'Monee', '', 41.4200300, -87.7417100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138362, 'Monmouth', 'Monmouth', 'Monmut,monma''utha,mwnmawth,Монмут,مون ماؤتھ، الینوائے,مونماوث,مون‌موث، ایلینوی,मोन्माउथ', 40.9114300, -90.6473600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138363, 'Montgomery', 'Montgomery', 'Montgomeri,Монтгомери', 41.7305800, -88.3459000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138364, 'Monticello', 'Monticello', 'Montiselo,mantyslw  aylynwy,montiselo,mwntyslw,mwntyzlw,Монтисело,מונטיצלו,مانتیسلو، ایلینوی,مونتيسلو,مونٹی سیلو، الینوائے,मोन्टिसेलो', 40.0278100, -88.5734000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138365, 'Morris', 'Morris', 'Moris,morisa,mwrys,mwrys  aylynwy,Морис,مورس، الینوائے,موريس,موریس، ایلینوی,मोरिस', 41.3572500, -88.4211800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138366, 'Morrison', 'Morrison', 'Morison,morisana,mwryswn,mwryswn  aylynwy,Морисон,موريسون,موریسن، الینوائے,موریسون، ایلینوی,मोरिसन', 41.8097500, -89.9651200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138367, 'Morton', 'Morton', 'Morton,Pumpkin Capital of the World', 40.6128200, -89.4592600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138368, 'Morton Grove', 'Morton Grove', 'Morton Grouv,Morton Grove,Mortongrove,mortana grobha,mwrtwn ghrwf,Мортон Гроув,مورتون غروف,मोर्टन ग्रोभ', 42.0405900, -87.7825600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138369, 'Mount Carroll', 'Mount Carroll', 'Maunt Kerol,ma''unta kyarola,mawnt karwl,Маунт Керол,ماؤنٹ کیرل، الینوائے,ماونت كارول,مونت‌کارول، ایلینوی,माउन्ट क्यारोल', 42.0950200, -89.9781800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138370, 'Mount Morris', 'Mount Morris', '', 42.0503100, -89.4312200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138371, 'Mount Prospect', 'Mount Prospect', 'Maunt Prospekt,ma''unta prospekta,mwnt brwsbkt,Маунт Проспект,ماؤنٹ پراسپیکٹ، الینوائے,مونت بروسبكت,माउन्ट प्रोस्पेक्ट', 42.0664200, -87.9372900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138372, 'Mount Pulaski', 'Mount Pulaski', '', 40.0108800, -89.2823100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138373, 'Mundelein', 'Mundelein', 'Area,Mandlajn,Mundelein,mandelina,mwndlyn,Мандлајн,منڈلائن، الینوائے,موندلين,मंडेलीन', 42.2630800, -88.0039700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138374, 'Naperville', 'Naperville', 'Fort Naper,Naper Settlement,Naperville,Napervillium,Napiersville,Napierville,Nejpervil,Nejpervill,Nepervill,nabrfyl,nei po wei er,neipabiru,neipeobil,neparabhila,Нейпервилл,Непервілл,Нејпервил,نابرفيل,ناپرس‌ویل، ایلینوی,نیپرویل، الینوائے,नेपरभिल,ネイパービル,內珀維爾,네이퍼빌', 41.7858600, -88.1472900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138375, 'Nauvoo', 'Nauvoo', 'Commerce,Commerce City,Nauvoo,Venus', 40.5500400, -91.3848700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138376, 'New Lenox', 'New Lenox', 'Nju Lenoks,n''yu lenaksa,nyw lnwks,Њу Ленокс,نيو لنوكس,न्यु लेनक्स', 41.5119800, -87.9656100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138377, 'Newark', 'Newark', 'N''juark,Ньюарк', 41.5369700, -88.5834100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138378, 'Niles', 'Niles', 'Najls,na''ilsa,naylz,Најлс,نايلز,نایلز,नाइल्स', 42.0189200, -87.8028400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138379, 'Normal', 'Normal', 'Normal,Normal''naja,North Bloomington,nuo mo er,nwrmal  alynwy,Нормал,Нормальная,نورمال، إلينوي,诺默尔', 40.5142000, -88.9906300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138380, 'Norridge', 'Norridge', 'Noridz,nararija,nwrydj,Нориџ,نوريدج,नररिज', 41.9633600, -87.8272800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138381, 'North Aurora', 'North Aurora', '', 41.8061400, -88.3273000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138382, 'North Barrington', 'North Barrington', '', 42.2078000, -88.1406300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138383, 'North Chicago', 'North Chicago', 'Nort Chikago,nartha sikago,nwrth shykaghw,Норт Чикаго,نورتھ شکاگو، الینوائے,نورث شيكاغو,نورث‌شیکاگو، ایلینوی,नर्थ शिकागो', 42.3255800, -87.8411800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138384, 'North Pekin', 'North Pekin', '', 40.6150400, -89.6223200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138385, 'North Peoria', 'North Peoria', '', 40.7175400, -89.5842600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138386, 'North Riverside', 'North Riverside', '', 41.8428100, -87.8231100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138387, 'Northbrook', 'Northbrook', 'Nortbrook,Northbrook,Shermerville,Techny,narthabruka,nwrth brwk,Нортброок,نارتھبروک، الینوائے,نورث بروك,नर्थब्रूक', 42.1275300, -87.8289500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138388, 'Northfield', 'Northfield', 'Nortfild,narthaphilda,nwrthfyld,Нортфилд,نارتھفیلڈ، الینوائے,نورثفيلد,नर्थफिल्ड', 42.0997500, -87.7809000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138389, 'Northlake', 'Northlake', 'North Lake,North Lake Village,Northlake,Nortlejk,narthaleka,nwrthlyk,Нортлејк,نورتھ لیک، الینوائے,نورثليك,نورث‌لیک، ایلینوی,नर्थलेक', 41.9172500, -87.8956200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138390, 'Oak Brook', 'Oak Brook', 'Oak Brook,Oakbrook,Ouk Bruk,QHO,awk brwk,oka bruka,Оук Брук,أوك بروك,ओक ब्रूक', 41.8328100, -87.9289500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138391, 'Oak Forest', 'Oak Forest', 'Ouk Forist,awk fwrst,oka pharesta,Оук Форист,أوك فورست,اوک فاریسٹ، الینوائے,اوک‌فارست، ایلینوی,ओक फरेस्ट', 41.6028100, -87.7439400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138392, 'Oak Lawn', 'Oak Lawn', 'Ouk Lon,awk lawn,oka lana,Оук Лон,أوك لاون,اوک لان، الینوائے,ओक लन', 41.7108700, -87.7581100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138393, 'Oak Park', 'Oak Park', 'Harlem,Noyesville,Oak Park,Oak Ridge,Ouk-Park,Оук-Парк', 41.8850300, -87.7845000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138394, 'Oakbrook Terrace', 'Oakbrook Terrace', 'Oukbruk Teras,awkbrwk tras,okabruka teresa,Оукбрук Терас,أوكبروك تراس,اوک بروک، الینوائے,اوک‌تراس، ایلینوی,ओकब्रूक टेरेस', 41.8500300, -87.9645100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138395, 'Oakwood', 'Oakwood', '', 40.1161500, -87.7783600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138396, 'Oakwood Hills', 'Oakwood Hills', '', 42.2464100, -88.2428600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138397, 'Oglesby', 'Oglesby', '', 41.2953100, -89.0595300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138398, 'Olympia Fields', 'Olympia Fields', 'Olimpija Filds,awlymbya fyldz,Олимпија Филдс,أوليمبيا فيلدز', 41.5133700, -87.6742100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138399, 'Onarga', 'Onarga', '', 40.7150400, -88.0061500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138400, 'Oquawka', 'Oquawka', '', 40.9319800, -90.9470900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138401, 'Oregon', 'Oregon', 'Florence,Oregon,argwn  aylynwy,awryghwn,Орегон,أوريغون,ارگون، ایلینوی,اوریگن، الینوائے', 42.0147500, -89.3323300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138402, 'Orion', 'Orion', '', 41.3547600, -90.3815200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138403, 'Orland Hills', 'Orland Hills', 'Orland Hills,Westhaven', 41.5853100, -87.8431100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138404, 'Orland Park', 'Orland Park', 'Orland,Orland Park,awrland bark,Орланд Парк,اورلاند بارك,اورلینڈ پارک، الینوائے', 41.6303100, -87.8539400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138405, 'Oswego', 'Oswego', 'Lodi,Osvigo,Oswego,Oswego Mills,Освиго,اوسویگو، الینوائے', 41.6828100, -88.3514600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138406, 'Ottawa', 'Ottawa', 'Otava,Ottava,Ottawa,Ottowa,South Ottawa,atawa  aylynwy,awtawa,Отава,Оттава,أوتاوا,اتاوا، ایلینوی,اوٹاوا، الینوائے', 41.3455900, -88.8425800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138407, 'Palatine', 'Palatine', 'Palatajn,Palatin,Palatinas,Palatine,blatyn,Палатајн,Палатин,بلاتين,پالاتائن، الینوائے', 42.1103000, -88.0342400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138408, 'Palos Heights', 'Palos Heights', '', 41.6680900, -87.7964400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138409, 'Palos Hills', 'Palos Hills', '', 41.6967000, -87.8170000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138410, 'Palos Park', 'Palos Park', '', 41.6672500, -87.8303300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138411, 'Park City', 'Park City', '', 42.3483600, -87.8842400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138412, 'Park Forest', 'Park Forest', 'Park Forist,bark fwrst,Парк Форист,بارك فورست,پارک فارسٹ، الینوائے', 41.4914200, -87.6744900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138413, 'Park Ridge', 'Park Ridge', 'Brickton,Park Ridge,Park Ridz,Park Ritz,Park-Ridzh,Parkridge,bark rydj,Παρκ Ριτζ,Парк Риџ,Парк-Ридж,Парк-Рідж,بارك ريدج,پارک رج، الینوائے,پارک‌ریج، ایلینوی', 42.0111400, -87.8406200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138414, 'Paxton', 'Paxton', 'Pakston,Paxton,Prairie City,Prospect City,bakstwn,pakstwn  aylynwy,Пакстон,باكستون,پاکستون، ایلینوی,پاکسٹن، الینوائے', 40.4603100, -88.0953200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138415, 'Pecatonica', 'Pecatonica', 'Lysander,Pecatonica', 42.3139100, -89.3592800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138416, 'Pekin', 'Pekin', 'Pekin,Pikin,bykyn,pkyn  aylynwy,Пекин,Пикин,بيكين,پکین، ایلینوی,پیکن، الینوائے', 40.5675400, -89.6406600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138417, 'Peoria', 'Peoria', 'Au Pay,Au Pe,Le Pe,Opq,PIA,Peoria,Peorija,Pimitoui,Piorias,Piorija,bywrya,pi ao li ya,piolia,pioria,piyoriya,pywrya,pywrya  aylynwy,Пеория,Пиорија,Піорія,פאוריה,بيوريا,پئوریا، ایلینوی,پیوریا,پیوریا، الینوائے,पियोरिया,ピオリア,皮奥里亚,피오리아', 40.6936500, -89.5889900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138418, 'Peoria Heights', 'Peoria Heights', 'Peoria Heights,Prospect Heights', 40.7472600, -89.5739800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138419, 'Peotone', 'Peotone', '', 41.3322600, -87.7853200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138420, 'Peru', 'Peru', 'Peru,VYS,Перу', 41.3275300, -89.1289700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138421, 'Petersburg', 'Petersburg', 'Peterburg,Petersburg,Petersburgh,Pitersburg,btrsbwrgh,ptrzbwrg  aylynwy,Петербург,Питерсбург,بطرسبورغ,پترزبورگ، ایلینوی,پیٹرزبرگ، الینوائے', 40.0117200, -89.8481700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138422, 'Philo', 'Philo', '', 40.0069800, -88.1581000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138423, 'Phoenix', 'Phoenix', 'Finiks,Финикс', 41.6111500, -87.6347700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138424, 'Pingree Grove', 'Pingree Grove', '', 42.0686400, -88.4134200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138425, 'Pistakee Highlands', 'Pistakee Highlands', 'Pistakee,Pistakee Highlands', 42.4086300, -88.2064800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138426, 'Plainfield', 'Plainfield', 'Plainfield,Plejnfild,Walkers Grove,blaynfyld,peulleinpildeu,Плејнфилд,بلاينفيلد,پلینفیلڈ، الینوائے,플레인필드', 41.6269700, -88.2039500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138427, 'Plano', 'Plano', 'Planom,Plejno,blanw,Планом,Плејно,بلانو', 41.6628100, -88.5370200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138428, 'Polo', 'Polo', 'Polo,bwlw,pwlw  aylynwy,Поло,بولو,پولو، الینوائے,پولو، ایلینوی', 41.9861400, -89.5792800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138429, 'Pontiac', 'Pontiac', 'Pontiak,Pontijak,bwntyak,pntyak  aylynwy,Понтиак,Понтијак,بونتياك,پنتیاک، ایلینوی,پونٹیاک، الینوائے', 40.8808700, -88.6297800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138430, 'Poplar Grove', 'Poplar Grove', 'Poplar Grove,Poplargrove', 42.3683500, -88.8220500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138431, 'Port Barrington', 'Port Barrington', 'Fox River Valley Gardens,Port Barrington', 42.2425200, -88.2020300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138432, 'Port Byron', 'Port Byron', '', 41.6064200, -90.3354100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138433, 'Posen', 'Posen', 'Pouzen,bwsyn,Поузен,بوسين', 41.6317000, -87.6814400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138434, 'Prairie Grove', 'Prairie Grove', '', 42.2786300, -88.2609200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138435, 'Preston Heights', 'Preston Heights', '', 41.4917000, -88.0817200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138436, 'Princeton', 'Princeton', 'Prinston,brynstwn,prynstwn  aylynwy,Принстон,برينستون,پرنسٹن، الینوائے,پرینستون، ایلینوی', 41.3680900, -89.4648100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138437, 'Princeville', 'Princeville', '', 40.9297600, -89.7576000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138438, 'Prophetstown', 'Prophetstown', '', 41.6714200, -89.9362200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138439, 'Prospect Heights', 'Prospect Heights', 'Prospekt Khajts,brwsbykt hayts,Проспект Хајтс,بروسبيكت هايتس,پراسپکت‌هایتس، ایلینوی,پراسپکٹ ہائٹس، الینوائے', 42.0953000, -87.9375700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138440, 'Rantoul', 'Rantoul', 'Rantul,rantwl,Рантул,رانتول,র‌্যান্টুল', 40.3083700, -88.1558800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138441, 'Richmond', 'Richmond', 'Richmond,Ричмонд', 42.4758500, -88.3059300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138442, 'Richmond', 'Richmond', '', 40.3608700, -89.3689800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138443, 'Richton Park', 'Richton Park', '', 41.4844800, -87.7033800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138444, 'River Forest', 'River Forest', 'Harlem,River Forest,River Forist,Thatcher,Ривер Форист', 41.8978100, -87.8139500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138445, 'River Grove', 'River Grove', 'River Grove,Rivergrove', 41.9258600, -87.8358900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138446, 'Riverdale', 'Riverdale', 'Riverdale,Riverdejl,South Lawn,ryfrdyl,rywrdyl  aylynwy,Ривердејл,ريفرديل,ریوردیل، ایلینوی', 41.6333700, -87.6331000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138447, 'Riverside', 'Riverside', 'Riversajd,Риверсайд', 41.8350300, -87.8228400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138448, 'Riverwoods', 'Riverwoods', '', 42.1675300, -87.8970100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138449, 'Roanoke', 'Roanoke', '', 40.7961500, -89.1973000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138450, 'Robbins', 'Robbins', '', 41.6439200, -87.7036600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138451, 'Rochelle', 'Rochelle', 'Hickory Grove,Lane,Lane Depot,Loblolly Grove,Rochelle,Roshel,Story,losyel,rosheru,rwshl  aylynwy,rwshyl,Рошел,روشل، ایلینوی,روشيل,روشیل، الینوائے,ロシェル,로셸', 41.9239200, -89.0687100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138452, 'Rock Falls', 'Rock Falls', 'Rock Falls,Rockfalls,Rok Fols,rwk fwlz,Рок Фолс,راک فالز، الینوائے,راک‌فالز، ایلینوی,روك فولز', 41.7797500, -89.6890000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138453, 'Rock Island', 'Rock Island', 'Quad Cities,Rock Island,Rok Ajland,Rok-Ajlend,Stephenson,roka ayalanda,rwk ayland,Рок Ајланд,Рок-Айленд,راک آئی لینڈ، الینوائے,راک‌آیلند، ایلینوی,روك أيلاند,रॉक आयलंड', 41.5094800, -90.5787500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138454, 'Rockdale', 'Rockdale', '', 41.5061400, -88.1145000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138455, 'Rockford', 'Rockford', 'Gorad Rokfard,RFD,RMC,Rockford,Rokford,Rokfordas,The Forest City,ZRK,logpeodeu,luo ke fu de,rakaphorda,rokkufodo,rwkfwrd,rwqpwrd,Горад Рокфард,Рокфорд,רוקפורד,راک فورڈ، الینوائے,راک‌فورد، ایلینوی,روكفورد,روکفورڈ,রকফোর্ড,ロックフォード,罗克福德,록퍼드', 42.2711300, -89.0940000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138456, 'Rockton', 'Rockton', 'Pecatonica,Rockton', 42.4525200, -89.0723300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138457, 'Rolling Meadows', 'Rolling Meadows', 'Roling Medous,rwlynj mydwz,Ролинг Медоус,رولنگ میڈوز، الینوائے,رولينج ميدوز,رولینگ‌مدوز، ایلینوی', 42.0841900, -88.0131300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138458, 'Rome', 'Rome', '', 40.8830900, -89.5025900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138459, 'Romeoville', 'Romeoville', 'LOT,Romeoville,Romiovil,rwmywfyl,Ромиовил,روميوفيل,رومیوویل، الینوائے', 41.6475300, -88.0895100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138460, 'Roscoe', 'Roscoe', '', 42.4133500, -89.0092700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138461, 'Roselle', 'Roselle', '', 41.9847500, -88.0797900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138462, 'Rosemont', 'Rosemont', 'Orchard Place,Rosemont,Rouzmont,Rozemont,lojeumeonteu,rwsmwnt,Роземонт,Роузмонт,روسمونت,로즈먼트', 41.9953100, -87.8845100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138463, 'Rossville', 'Rossville', 'Bicknells Point,Henpeck,Liggetts Grove,North Fork,Rossville', 40.3792000, -87.6686300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138464, 'Round Lake', 'Round Lake', '', 42.3533600, -88.0934100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138465, 'Round Lake Beach', 'Round Lake Beach', '', 42.3716900, -88.0900800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138466, 'Round Lake Heights', 'Round Lake Heights', '', 42.3800200, -88.1042500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138467, 'Round Lake Park', 'Round Lake Park', '', 42.3569700, -88.0767500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138468, 'Rushville', 'Rushville', 'Rashvil,Rushton,Rushville,rwshfyl,Рашвил,راش‌ویل، ایلینوی,رشویل، الینوائے,روشفيل', 40.1211600, -90.5631800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138469, 'Saint Anne', 'Saint Anne', 'Saint Anne,Sainte Anne', 41.0250300, -87.7139200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138470, 'Saint Charles', 'Saint Charles', 'Charleston,Saint Charles,Sent-Charl''z,St. Charles,Waterville,Сент-Чарльз', 41.9141900, -88.3086900, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138471, 'Saint Joseph', 'Saint Joseph', 'Sent-Dzhozef,Сент-Джозеф', 40.1117000, -88.0417000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138472, 'Sandwich', 'Sandwich', 'Sehndvich,Sendvich,sandwych  aylynwy,sandwytsh,Сендвич,Сэндвич,ساندويتش,ساندویچ، ایلینوی,سینڈوچ، الینوائے', 41.6458600, -88.6217400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138473, 'Sauk Village', 'Sauk Village', 'Sok Vilidz,swak fylyj,Сок Вилиџ,سواك فيليج', 41.4883700, -87.5675400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138474, 'Savanna', 'Savanna', 'Savana,Savanna,safana,sawana  aylynwy,Савана,Саванна,سافانا,ساوانا، ایلینوی,سوانا، الینوائے', 42.0944700, -90.1567900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138475, 'Savoy', 'Savoy', 'Savoy,Savoy Station', 40.0547500, -88.2517200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138476, 'Schaumburg', 'Schaumburg', 'JMH,Schaumberg,Schaumburg,Schaumburg Center,Shaumburg,Shomberg,shambwrgh,shanbagu,shao mu bao,syambeogeu,Шаумбург,Шомберг,شامبرگ، الینوائے,شامبورغ,シャンバーグ,绍姆堡,샴버그', 42.0333600, -88.0834100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138477, 'Schiller Park', 'Schiller Park', 'Schiller Park,Shiller Park', 41.9558600, -87.8709000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138478, 'Seneca', 'Seneca', 'Crotty,Seneca', 41.3111400, -88.6097900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138479, 'Sheldon', 'Sheldon', 'Haxby,Sheldon', 40.7692000, -87.5639200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138480, 'Sheridan', 'Sheridan', '', 41.5300300, -88.6798000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138481, 'Shorewood', 'Shorewood', 'Grinton,Shorewood,Troy', 41.5200300, -88.2017300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138482, 'Sidney', 'Sidney', 'Sidnej,Сидней', 40.0250300, -88.0733700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138483, 'Silvis', 'Silvis', '', 41.5122600, -90.4151300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138484, 'Skokie', 'Skokie', 'Niles Center,Niles Centre,Skoki,Skokie,seukoki,skwky,sqwqy,Скоки,Скокі,סקוקי,سكوكي,سکوکی، الینوائے,스코키', 42.0333600, -87.7333900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138485, 'Sleepy Hollow', 'Sleepy Hollow', '', 42.0941900, -88.3025800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138486, 'Somonauk', 'Somonauk', '', 41.6336400, -88.6811900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138487, 'South Barrington', 'South Barrington', '', 42.0914200, -88.1217400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138488, 'South Beloit', 'South Beloit', '', 42.4930700, -89.0367800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138489, 'South Chicago Heights', 'South Chicago Heights', '', 41.4808700, -87.6378200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138490, 'South Elgin', 'South Elgin', 'Clintonville,South Elgin', 41.9941900, -88.2923000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138491, 'South Holland', 'South Holland', 'Saut Kholand,sawth hwland,Саут Холанд,جنوبی ہالینڈ، الینوائے,ساوث هولاند', 41.6008700, -87.6069900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138492, 'South Pekin', 'South Pekin', '', 40.4944800, -89.6517700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138493, 'Spring Grove', 'Spring Grove', 'Bivins Mills,Spring Grove,Springgrove', 42.4436300, -88.2364800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138494, 'Spring Valley', 'Spring Valley', 'Spring Valley,Spring-Vehlli,Springvalley,Спринг-Вэлли', 41.3275400, -89.1998100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138495, 'Steger', 'Steger', '', 41.4700300, -87.6364300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138496, 'Sterling', 'Sterling', 'SQI,Sterling,Sturling,astrlyng  aylynwy,strlyngh,Стерлинг,Стърлинг,استرلینگ، ایلینوی,سترلينغ,سٹرلنگ، الینوائے', 41.7886400, -89.6962200, 'US', '2017-07-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138497, 'Stickney', 'Stickney', '', 41.8214200, -87.7828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138498, 'Stillman Valley', 'Stillman Valley', '', 42.1072500, -89.1792700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138499, 'Stockton', 'Stockton', 'Stoktun,Стоктън', 42.3497400, -90.0067900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138500, 'Stone Park', 'Stone Park', '', 41.9055900, -87.8836700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138501, 'Streamwood', 'Streamwood', '', 42.0255800, -88.1784100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138502, 'Streator', 'Streator', 'Glass Container Capital of the World,Streator,Stritor,astrytwr  aylynwy,strtwr,Стритор,استریتور، ایلینوی,سترتور,سٹریٹو، الینوائے', 41.1208700, -88.8353500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138503, 'Sugar Grove', 'Sugar Grove', 'Shugar Grouv,shwghr ghrwf,Шугар Гроув,شوغر غروف', 41.7614200, -88.4436900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138504, 'Summit', 'Summit', '', 41.7880900, -87.8103300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138505, 'Sycamore', 'Sycamore', 'Sikamor,sykamwr,sykamwr  aylynwy,Сикамор,سيكامور,سیکامور، الینوائے,سیکامور، ایلینوی', 41.9889200, -88.6867500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138506, 'Third Lake', 'Third Lake', '', 42.3739100, -88.0109100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138507, 'Thomasboro', 'Thomasboro', 'Thomasboro,Thomasborough', 40.2417000, -88.1842100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138508, 'Thornton', 'Thornton', 'Tornton,Торнтон', 41.5680900, -87.6081000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138509, 'Tilton', 'Tilton', 'Bryant,Tilton,Vandercook', 40.0953100, -87.6475200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138510, 'Tinley Park', 'Tinley Park', 'Tinley Park,Tinleypark,Tinli Park,tynly bark,Тинли Парк,تينلي بارك,ٹنلی پارک، الینوائے', 41.5733700, -87.7844900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138511, 'Toluca', 'Toluca', '', 41.0022600, -89.1334200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138512, 'Toulon', 'Toulon', 'Millers Point,Toulon', 41.0936500, -89.8648300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138513, 'Tower Lake', 'Tower Lake', 'Tower Lake,Tower Lakes', 42.2319700, -88.1520200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138514, 'Tremont', 'Tremont', '', 40.5275400, -89.4926000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138515, 'Twin Grove', 'Twin Grove', '', 40.4933700, -89.0798000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138516, 'Urbana', 'Urbana', 'Ehrbana,Urbana,abana,arbana,awrbana,awrbana  aylynwy,e ba na,eobaeneo,Урбана,Эрбана,אורבנה,أوربانا,اربانا، الینوائے,اوربانا، ایلینوی,আর্বানা,アーバナ,厄巴纳,어배너', 40.1105900, -88.2072700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138517, 'Venetian Village', 'Venetian Village', '', 42.3986300, -88.0525800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138518, 'Vernon Hills', 'Vernon Hills', '', 42.2194700, -87.9795200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138519, 'Villa Park', 'Villa Park', 'Vila Park,fyla bark,Вила Парк,فيلا بارك', 41.8897500, -87.9889500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138520, 'Volo', 'Volo', '', 42.3261300, -88.1678600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138521, 'Wadsworth', 'Wadsworth', 'Wadsworth,Wadsworth Station', 42.4286300, -87.9239700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138522, 'Walnut', 'Walnut', 'Brewersville,Walnut', 41.5567000, -89.5934300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138523, 'Warren', 'Warren', 'Courtland,Uorren,Warren,Уоррен', 42.4964000, -89.9895700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138524, 'Warrenville', 'Warrenville', '', 41.8178100, -88.1734000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138525, 'Warsaw', 'Warsaw', '', 40.3592100, -91.4346000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138526, 'Wasco', 'Wasco', '', 41.9380800, -88.4045200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138527, 'Washburn', 'Washburn', '', 40.9192000, -89.2912000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138528, 'Washington', 'Washington', 'Vashington,washntn,washyngtwn  aylynwy,Вашингтон,واشنطن,واشنگٹن، الینوائے,واشینگتون، ایلینوی', 40.7036500, -89.4073100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138529, 'Waterman', 'Waterman', '', 41.7717000, -88.7736900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138530, 'Watseka', 'Watseka', 'South Middleport,Votsika,Watseka,watska,Вотсика,واتسكا,واتسه‌کا، ایلینوی,واٹسکا، الینوائے', 40.7761500, -87.7364200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138531, 'Wauconda', 'Wauconda', '', 42.2589100, -88.1392500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138532, 'Waukegan', 'Waukegan', 'Little Fort,Uokigan,Vokigan,Waukegan,u~okigan,waywkgan  aylynwy,wkghn,wo ji gen,wokigeon,wwqygn,wx khi kan,Вокиган,Вокіган,Уокиган,ווקיגן,وائوکگان، ایلینوی,واکیگن، الینوائے,وكغن,วอคีกัน,ウォキーガン,沃基根,워키건', 42.3636300, -87.8447900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138533, 'Wayne', 'Wayne', '', 41.9508600, -88.2423000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138534, 'West Chicago', 'West Chicago', 'Junction,Turner,Vest Chikago,West Chicago,wst shykagw  aylynwy,wyst shykaghw,Вест Чикаго,وست شیکاگو، ایلینوی,ويست شيكاغو,ویسٹ شکاگو، الینوائے', 41.8847500, -88.2039600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138535, 'West Dundee', 'West Dundee', 'Dundee,West Dundee', 42.0980800, -88.2828600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138536, 'West Peoria', 'West Peoria', '', 40.6925400, -89.6278800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138537, 'Westchester', 'Westchester', 'Vestchester,wst tshtr,Вестчестер,وست تشتر', 41.8505900, -87.8820000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138538, 'Western Springs', 'Western Springs', 'Vestern Springs,wstrn sbryngh,Вестерн Спрингс,وسترن سبرينغ,ویسٹرن سپرنگز، الینوائے', 41.8097500, -87.9006200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138539, 'Westmont', 'Westmont', 'Gregg,Uestmont,Vestmont,Westmont,wst mwnt,Вестмонт,Уестмонт,وست مونت', 41.7958600, -87.9756200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138540, 'Westville', 'Westville', '', 40.0422600, -87.6386300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138541, 'Wheaton', 'Wheaton', 'Uiton,Viton,hui dun,hwiteon,wyatwn  aylynwy,wytwn,Витон,Уитон,وئاتون، ایلینوی,ويتون,ویٹن، الینوائے,惠顿,휘턴', 41.8661400, -88.1070100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138542, 'Wheeling', 'Wheeling', 'Viling,wylyngh,Вилинг,ويلينغ,ویلینگ، الینوائے', 42.1391900, -87.9289600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138543, 'Willow Springs', 'Willow Springs', 'Mount Forest,Mountforest,Willow Springs', 41.7408700, -87.8603300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138544, 'Willowbrook', 'Willowbrook', '', 41.7697500, -87.9358900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138545, 'Willowbrook', 'Willowbrook', '', 41.4578100, -87.5364300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138546, 'Wilmette', 'Wilmette', 'Ouilmette Reservation,Vilmet,Vilmett,Wilmette,wilmes,wylmt,wylmyt,Вилмет,Вілметт,וילמט,ويلميت,윌멧', 42.0722500, -87.7228400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138547, 'Wilmington', 'Wilmington', 'Uilmington,Vilmington,Wilmington,Winchester,wylmynghtwn,wylmyngtwn  shhrstan wyl  aylynwy,Вилмингтон,Уилмингтон,ولمنگٹن، ویل کاؤنٹی، الینوائے,ويلمينغتون,ویلمینگتون، شهرستان ویل، ایلینوی', 41.3078100, -88.1467200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138548, 'Winfield', 'Winfield', '', 41.8617000, -88.1609000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138549, 'Winnebago', 'Winnebago', 'Elyda,La Prairie,Winnebago', 42.2661300, -89.2412200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138550, 'Winnetka', 'Winnetka', 'Uinnetka,Vinetka,Winetka,Winnetka,Wynetka,wyntka,Винетка,Уиннетка,وينتكا', 42.1080800, -87.7359000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138551, 'Winthrop Harbor', 'Winthrop Harbor', 'Spring Bluff,Winthrop Harbor', 42.4789100, -87.8236800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138552, 'Wonder Lake', 'Wonder Lake', 'Sunrise Ridge,Wonder Lake', 42.3853000, -88.3473100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138553, 'Wood Dale', 'Wood Dale', '', 41.9633600, -87.9789600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138554, 'Woodridge', 'Woodridge', '', 41.7469700, -88.0503400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138555, 'Woodstock', 'Woodstock', 'Centerville,Vudstok,Woodstock,udeuseutog,wwdstwk,wwdstwk  aylynwy,Вудсток,وودستوك,وودستوک، ایلینوی,ووڈسٹاک، الینوائے,우드스톡', 42.3147400, -88.4487000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138556, 'Worth', 'Worth', '', 41.6897500, -87.7972800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138557, 'Wyoming', 'Wyoming', 'Vajoming,Вайоминг', 41.0617000, -89.7731600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138558, 'Yorkville', 'Yorkville', 'Bristol,Jorkvil,Yorkville,ywrkfyl,Јорквил,يوركفيل,یارک ویل، الینوائے,یورک‌ویل، ایلینوی', 41.6411400, -88.4472900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138559, 'Zion', 'Zion', 'Sion,Zajon,Zion,Zion City,jaieon,zai en,zywn,zywn  aylynwy,Зајон,Сион,زائن، الینوائے,زيون,زیون، ایلینوی,宰恩,자이언', 42.4461300, -87.8328500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138560, 'Aberdeen', 'Aberdeen', '', 41.4389300, -87.1114200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138561, 'Akron', 'Akron', 'Akron,Newark,Акрон', 41.0383800, -86.0280500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138562, 'Albany', 'Albany', 'Olbani,Олбани', 40.3008800, -85.2419100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138563, 'Albion', 'Albion', 'Albion,The Center', 41.3956000, -85.4244200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138564, 'Alexandria', 'Alexandria', 'Aleksandrija,alaskndryt,alksandrya  ayndyana,Александрия,Александрија,الإسكندرية,الکساندریا، ایندیانا,الیگزینڈریا، انڈیانا', 40.2628200, -85.6758100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138565, 'Anderson', 'Anderson', 'AID,Anderson,Andersonton,Andersontown,Wa-piminskink,aendeoseun,andrswn  ayndyana,mdynt andrswn,Андерсон,اندرسون، ایندیانا,اینڈرسن، انڈیانا,مدينة اندرسون,앤더슨', 40.1053200, -85.6802500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138566, 'Andrews', 'Andrews', 'Andrews,Andrewsia,Antioch', 40.8625400, -85.6016500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138567, 'Angola', 'Angola', 'ANQ,Angola,anghwla,angola,angwla  ayndyana,Ангола,آنگولا، ایندیانا,أنغولا,انگولا، انڈیانا,अंगोला', 41.6347700, -84.9994100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138568, 'Arcadia', 'Arcadia', 'Arkadija,Аркадия', 40.1758700, -86.0216500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138569, 'Argos', 'Argos', 'Argos,Sidney', 41.2378000, -86.2146500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138570, 'Attica', 'Attica', '', 40.2942000, -87.2489000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138571, 'Auburn', 'Auburn', 'Obern,abrn  ayndyana,obeon,Оберн,آبرن، ایندیانا,오번', 41.3669900, -85.0588600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138572, 'Avilla', 'Avilla', '', 41.3658800, -85.2388600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138573, 'Bass Lake', 'Bass Lake', '', 41.2072600, -86.6019600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138574, 'Battle Ground', 'Battle Ground', 'Battle Ground,Battleground,Betl Graund,Prophets Town,Бетл Граунд', 40.5083700, -86.8416800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138575, 'Berne', 'Berne', 'Bern,Berne,brn,brnh  ayndyana,Берн,برن,برنه، ایندیانا,برنے، انڈیانا', 40.6578200, -84.9519100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138576, 'Bluffton', 'Bluffton', 'Blafton,blaftwn  ayndyana,bu la fu dun,bwfalw,Блафтон,بلافتون، ایندیانا,بلفٹن، انڈیانا,بوفالو,布拉夫顿', 40.7386600, -85.1716400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138577, 'Bourbon', 'Bourbon', '', 41.2956000, -86.1163900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138578, 'Bremen', 'Bremen', 'Bremen,New Bremen', 41.4464400, -86.1480600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138579, 'Bristol', 'Bristol', '', 41.7214400, -85.8174900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138580, 'Brookston', 'Brookston', 'Brookston,Brookstown', 40.6028100, -86.8672300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138581, 'Burns Harbor', 'Burns Harbor', '', 41.6258700, -87.1333700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138582, 'Butler', 'Butler', 'Butler,Jarvis,Norristown', 41.4297700, -84.8713500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138583, 'Cedar Lake', 'Cedar Lake', '', 41.3647600, -87.4411500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138584, 'Chesterfield', 'Chesterfield', 'Chesterfield,West Union', 40.1125400, -85.5969200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138585, 'Chesterton', 'Chesterton', 'Calumet,Chesterton,Coffee Creek,Честертон', 41.6105900, -87.0642000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138586, 'Churubusco', 'Churubusco', 'Cherubusco,Churubusco,Franklin,Union', 41.2306000, -85.3194200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138587, 'Cicero', 'Cicero', 'Ciceron,Цицерон', 40.1239300, -86.0133200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138588, 'Columbia City', 'Columbia City', 'Columbia,Columbia City', 41.1572700, -85.4883100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138589, 'Converse', 'Converse', 'Converse,Xenia', 40.5775400, -85.8733200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138590, 'Covington', 'Covington', 'Kavington,kawyngtwn  ayndyana,kwfynghtwn,Кавингтон,كوفينغتون,کاوینگتون، ایندیانا,کوونگٹن، انڈیانا', 40.1417000, -87.3947400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138591, 'Crawfordsville', 'Crawfordsville', 'Krofordsvil,ke lao fu ci wei er,krafwrdzwyl  ayndyana,krwfwrdsfyl,Крофордсвил,كروفوردسفيل,کرافوردزویل، ایندیانا,کرافورڈزویل، انڈیانا,克劳福兹维尔', 40.0411500, -86.8744500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138592, 'Crown Point', 'Crown Point', 'Crown Point,Crownpoint,Kraun Pojnt,Robinsons Prairie,kra''una po''inta,krawn bwynt,Краун Појнт,كراون بوينت,کراؤن پوائنٹ، انڈیانا,کرون‌پوینت، ایندیانا,क्राउन पॉइंट', 41.4169800, -87.3653100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138593, 'Culver', 'Culver', 'Culver,Marmount,Union Town', 41.2189300, -86.4230600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138594, 'Dale', 'Dale', '', 40.0167100, -86.4000000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138595, 'Daleville', 'Daleville', 'Dalesville,Daleville', 40.1211500, -85.5580300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138596, 'Dayton', 'Dayton', 'Dayton,Dejton,Fairfield,Дейтон', 40.3742000, -86.7689000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138597, 'DeMotte', 'DeMotte', 'De Motte,DeMotte,Demotte', 41.1950400, -87.1986400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138598, 'Decatur', 'Decatur', 'Dekejter,Декейтер', 40.8306000, -84.9291300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138599, 'Delphi', 'Delphi', 'Carrollton,Delphi', 40.5875400, -86.6750100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138600, 'Dunkirk', 'Dunkirk', '', 40.7564300, -86.3936100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138601, 'Dunkirk', 'Dunkirk', 'Dunkirk,Quincy', 40.3753200, -85.2094100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138602, 'Dyer', 'Dyer', 'Dajer,dayr,Дајер,داير', 41.4942000, -87.5217100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138603, 'Dunlap', 'Dunlap', 'Dunlap,Dunlaps', 41.6378300, -85.9216600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138604, 'East Chicago', 'East Chicago', 'Ist Chikago,ayst shykaghw,shykagwy shrqy  ayndyana,Ист Чикаго,إيست شيكاغو,شیکاگوی شرقی، ایندیانا,مشرقی شکاگو، انڈیانا', 41.6392000, -87.4547600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138605, 'Eaton', 'Eaton', '', 40.3403200, -85.3508000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138606, 'Edgewood', 'Edgewood', '', 40.1033700, -85.7341400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138607, 'Elkhart', 'Elkhart', 'EKI,Ehlkkhart,Elkkhart,ai er ke ha te,alkart  ayndyana,alkhart,Елкхарт,Элкхарт,إلخارت,الکارت، انڈیانا,الکارت، ایندیانا,埃尔克哈特', 41.6819900, -85.9766700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138608, 'Elwood', 'Elwood', 'Duck Creek,Elwood,Quincy', 40.2769800, -85.8419200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138609, 'Fairmount', 'Fairmount', 'Fairmont,Fairmount', 40.4153200, -85.6505300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138610, 'Farmland', 'Farmland', '', 40.1878200, -85.1274700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138611, 'Fish Lake', 'Fish Lake', '', 41.5667100, -86.5519600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138612, 'Flora', 'Flora', '', 40.5472600, -86.5244400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138613, 'Fort Wayne', 'Fort Wayne', 'Arx Vainensis,FWA,Fort Gouein,Fort Miami,Fort Uejn,Fort Veinas,Fort Vejn,Fort Veyn,Fort Wayne,Fort-Uehjn,Fort-Vejn,Fortveina,Frenchtown,Kekionga,Kiskakon,Miami Town,Omee Town,Post Miami,Twightwee Village,fotou~ein,fwrt wayn,fwrt‌wyn  ayndyana,phorta vena,poteuwein,pwrt wyyn,wei en bao,Φορτ Γουέιν,Форт Вејн,Форт Уейн,Форт-Вейн,Форт-Уэйн,פורט ויין,فورت واين,فورت‌وین، ایندیانا,فورٹ وین، انڈیانا,फोर्ट वेन,フォートウェイン,韋恩堡,포트웨인', 41.1306000, -85.1288600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138614, 'Fowler', 'Fowler', '', 40.6167000, -87.3208500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138615, 'Frankfort', 'Frankfort', 'Frankfort,Frankfurt,fa lan ke fu,frankfwrt,frankfwrt  ayndyana,Франкфорт,Франкфурт,فرانكفورت,فرانکفورت، ایندیانا,فرنکفرٹ، انڈیانا,法兰克福', 40.2794800, -86.5108400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138616, 'Fremont', 'Fremont', 'Brockville,Fremont,Fremount,Frimont,Willow Prairie,Фримонт', 41.7308800, -84.9327400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138617, 'Frankton', 'Frankton', '', 40.2228200, -85.7788700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138618, 'Galveston', 'Galveston', 'Galveston,Галвестон', 40.5789300, -86.1902700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138619, 'Garrett', 'Garrett', '', 41.3494900, -85.1355300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138620, 'Gary', 'Gary', 'GYY,Gary,Gehri,Geri,Gorad Gehry,Qari,gairi,geli,geri,ghary,gry  ayndyana,jia li,Гери,Гері,Горад Гэры,Гэри,Գերի,غاري,گری، انڈیانا,گری، ایندیانا,गैरी,แกรี,გერი,ゲーリー,加里,게리', 41.5933700, -87.3464300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138621, 'Gas City', 'Gas City', 'Gas City,Gas Siti,Harrisburg,ghaz syty,gs syty  ayndyana,Гас Сити,غاز سيتي,گس سیتی، ایندیانا,گیس سٹی، انڈیانا', 40.4872600, -85.6130300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138622, 'Geneva', 'Geneva', 'Buffalo,Geneva,Zheneva,Женева', 40.5919900, -84.9571900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138623, 'Georgetown', 'Georgetown', '', 40.7406000, -86.5047300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138624, 'Georgetown', 'Georgetown', '', 41.7294900, -86.2283400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138625, 'Goodland', 'Goodland', '', 40.7633700, -87.2936300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138626, 'Goshen', 'Goshen', 'GSH,Goshen,Гошен', 41.5822700, -85.8344400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138627, 'Grabill', 'Grabill', '', 41.2108800, -84.9669100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138628, 'Granger', 'Granger', '', 41.7533800, -86.1108400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138629, 'Greentown', 'Greentown', 'Greens Village,Greentown', 40.4780900, -85.9666500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138630, 'Griffith', 'Griffith', '', 41.5283700, -87.4236500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138631, 'Gulivoire Park', 'Gulivoire Park', '', 41.6133800, -86.2452800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138632, 'Hamilton', 'Hamilton', 'Enterprise,Gamil''ton,Hamilton,Гамильтон', 41.5336600, -84.9127400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138633, 'Hammond', 'Hammond', 'Hammond,Hohman,Khammond,Khamond,State Line,ha meng de,haemeondeu,hamondo,hamwnd,hmwnd  ayndyana,Хаммонд,Хамонд,هاموند,هموند، ایندیانا,ہیمونڈ، انڈیانا,ハモンド,哈蒙德,해먼드', 41.5833700, -87.5000400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138634, 'Harlan', 'Harlan', 'Harlan,Maysville', 41.1961600, -84.9196900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138635, 'Hartford City', 'Hartford City', 'Hartford,Hartford City,Khartford Siti,hartfwrd syty,hartfwrd syty  ayndyana,Хартфорд Сити,هارتفورد سيتي,هارتفورد سیتی، ایندیانا,ہارٹ فورڈ سٹی، انڈیانا', 40.4511500, -85.3699700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138636, 'Hebron', 'Hebron', 'Hebron,The Corners', 41.3186500, -87.2003100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138637, 'Highland', 'Highland', '', 41.5536500, -87.4519800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138638, 'Hobart', 'Hobart', 'Khobart,hwbart,hwbart  ayndyana,Хобарт,هوبارت,هوبارت، ایندیانا,ہوبرٹ، انڈیانا', 41.5322600, -87.2550400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138639, 'Hudson Lake', 'Hudson Lake', '', 41.7103200, -86.5341900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138640, 'Huntertown', 'Huntertown', '', 41.2283800, -85.1724700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138641, 'Huntington', 'Huntington', 'Khantington,hantyngtwn  ayndyana,heng ting dun,heontingteon,hntnghtwn,Хантингтон,هانتینگتون، ایندیانا,هنتنغتون,ہنٹنگٹن، انڈیانا,亨廷顿,헌팅턴', 40.8831000, -85.4974800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138642, 'Indian Heights', 'Indian Heights', '', 40.4272600, -86.1255500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138643, 'Jonesboro', 'Jonesboro', 'Dzhonsboro,Jonesboro,Jonesborough,Джонсборо', 40.4797600, -85.6277500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138644, 'Kendallville', 'Kendallville', 'Kendalvil,ken de er wei er,kndalwyl  ayndyana,kyndalfyl,Кендалвил,كيندالفيل,کندالویل، ایندیانا,کینڈال ویل، انڈیانا,肯德尔维尔', 41.4414400, -85.2649800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138645, 'Kentland', 'Kentland', 'KKT,Kent,Kentland', 40.7703200, -87.4453000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138646, 'Kingsford Heights', 'Kingsford Heights', '', 41.4806000, -86.6916900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138647, 'Kokomo', 'Kokomo', 'OKK,ke ke mo,kokomo,kwkwmw,kwkwmw  ayndyana,كوكومو,کوکومو، انڈیانا,کوکومو، ایندیانا,コーコモー,科科莫', 40.4864300, -86.1336000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138648, 'Koontz Lake', 'Koontz Lake', '', 41.4181000, -86.4858500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138649, 'Kouts', 'Kouts', 'Kautz,Kout Station,Kouts,Kouts Station', 41.3167100, -87.0258600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138650, 'Knox', 'Knox', '', 41.2958800, -86.6250100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138651, 'LaPorte', 'LaPorte', 'LPO,La Porte,LaPorte,Laporte', 41.6106000, -86.7225200, 'US', '2017-07-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138652, 'Lafayette', 'Lafayette', 'LAF,La Fayette,LaFayette,Lafajet,Lafayette,Lafejet,la fei te,lafayyt,lafyt  ayndyana,lapies,rafaietto,Лафайет,Лафејет,لا فائت، انڈیانا,لافاييت,لافیت، ایندیانا,ラファイエット,拉斐特,라피엣', 40.4167000, -86.8752900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138653, 'Lagrange', 'Lagrange', 'La Grange,LaGrange,Lagrange', 41.6417200, -85.4166500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138654, 'Lake Dalecarlia', 'Lake Dalecarlia', '', 41.3308700, -87.3947600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138655, 'Lake Station', 'Lake Station', 'East Gary,Lake Station', 41.5750400, -87.2389200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138656, 'Lakes of the Four Seasons', 'Lakes of the Four Seasons', '', 41.4103200, -87.2130900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138657, 'Lapel', 'Lapel', 'Lapel,Lapell', 40.0683700, -85.8483100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138658, 'Lebanon', 'Lebanon', '', 40.0483700, -86.4691700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138659, 'Leo-Cedarville', 'Leo-Cedarville', 'Cedarville,Leo,Leo-Cedarville', 41.2125500, -85.0166400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138660, 'Ligonier', 'Ligonier', '', 41.4658800, -85.5874800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138661, 'Logansport', 'Logansport', 'Loganport,Logansport,logeonjeupoteu,Логанспорт,로건즈포트', 40.7544800, -86.3566700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138662, 'Long Beach', 'Long Beach', 'Long-Bich,Лонг-Бич', 41.7389300, -86.8569700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138663, 'Lowell', 'Lowell', 'Louel,Лоуел', 41.2914200, -87.4205900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138664, 'Lynn', 'Lynn', '', 40.0497700, -84.9396900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138665, 'Marion', 'Marion', 'Marion,Mehrion,marywn,mrywn  ayndyana,Марион,Мэрион,ماريون,مریون، ایندیانا,میرین، انڈیانا', 40.5583700, -85.6591400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138666, 'Markle', 'Markle', 'Markle,Tracy', 40.8246200, -85.3388400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138667, 'Merrillville', 'Merrillville', 'Centreville,Merrillville', 41.4828100, -87.3328100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138668, 'Michigan City', 'Michigan City', 'MGC,Michigan-Siti,Michigen Siti,mishiganshiti,misigana sahara,myshygan syty  ayndyana,myshyghan syty,Мичиган-Сити,Мичиген Сити,مشی گن سٹی، انڈیانا,ميشيغان سيتي,میشیگان سیتی، ایندیانا,मिशिगन शहर,ミシガンシティ', 41.7075400, -86.8950300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138669, 'Middlebury', 'Middlebury', '', 41.6753300, -85.7061000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138670, 'Middletown', 'Middletown', 'Middleton,Middletown', 40.0572700, -85.5372000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138671, 'Milford', 'Milford', 'Milford,Милфорд', 41.4097700, -85.8455500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138672, 'Mishawaka', 'Mishawaka', 'Mishavoka,Mishawaka,Mishewaka,misyeowaka,myshawaka,myshwaka  ayndyana,Мишавока,مشاواکا، انڈیانا,ميشاواكا,میشواکا، ایندیانا,미셔와카', 41.6619900, -86.1586200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138673, 'Monon', 'Monon', '', 40.8678200, -86.8789000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138674, 'Monroeville', 'Monroeville', '', 40.9747700, -84.8683000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138675, 'Monticello', 'Monticello', 'Montiselo,mantyslw  ayndyana,mwntyslw,Монтисело,مانتیسلو، ایندیانا,مونتيسلو,مونٹیسیلو، انڈیانا', 40.7453200, -86.7647300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138676, 'Montpelier', 'Montpelier', 'Montpilijer,Монтпилијер', 40.5539300, -85.2774700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138677, 'Morocco', 'Morocco', '', 40.9461500, -87.4533600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138678, 'Mount Vernon', 'Mount Vernon', '', 40.6694900, -85.8241500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138679, 'Mulberry', 'Mulberry', '', 40.3444800, -86.6652800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138680, 'Muncie', 'Muncie', 'MIE,Mansi,Muncey Town,Muncie,Munseetown,Munsey,man si,manshi,mwnsy,mwnsy  ayndyana,Манси,منسی، انڈیانا,مونسي,مونسی، ایندیانا,มันซี,མཱུན་སི།,マンシー', 40.1933800, -85.3863600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138681, 'Munster', 'Munster', 'Mjunster,Мюнстер', 41.5644800, -87.5125400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138682, 'Nappanee', 'Nappanee', 'Napani,nabany,napany  ayndyana,Напани,ناباني,ناپانی، ایندیانا,نپانی، انڈیانا', 41.4428300, -86.0013900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138683, 'New Carlisle', 'New Carlisle', '', 41.7003200, -86.5094600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138684, 'New Chicago', 'New Chicago', '', 41.5583700, -87.2744800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138685, 'New Haven', 'New Haven', 'N''ju-Khejven,New Haven,Newhaven,Нью-Хейвен', 41.0706000, -85.0144100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138686, 'New Paris', 'New Paris', '', 41.5003300, -85.8280500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138687, 'Noblesville', 'Noblesville', 'Noblsvil,Nobulsvil,noburuzubiru,Ноблсвил,Нобълсвил,ノーブルズビル', 40.0455900, -86.0086000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138688, 'North Judson', 'North Judson', '', 41.2150400, -86.7758500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138689, 'North Liberty', 'North Liberty', '', 41.5342100, -86.4272300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138690, 'North Manchester', 'North Manchester', 'Manchester,North Manchester', 41.0006000, -85.7686000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138691, 'North Webster', 'North Webster', '', 41.3256000, -85.6977600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138692, 'Ogden Dunes', 'Ogden Dunes', '', 41.6228100, -87.1917000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138693, 'Osceola', 'Osceola', 'Bancroft''s Mill,Osceola', 41.6650500, -86.0758400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138694, 'Ossian', 'Ossian', '', 40.8806000, -85.1663600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138695, 'Otterbein', 'Otterbein', '', 40.4905900, -87.0964000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138696, 'Oxford', 'Oxford', 'Hartford,Milroy,Oksford,Oxford,Оксфорд', 40.5197600, -87.2477900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138697, 'Parker City', 'Parker City', 'Morristown,Parker,Parker City', 40.1889300, -85.2041300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138698, 'Peru', 'Peru', 'Miamisport,Peru,byrw,prw  ayndyana,Перу,بيرو,پرو، ایندیانا,پیرو، انڈیانا', 40.7536500, -86.0688800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138699, 'Pierceton', 'Pierceton', 'Deed''s Creek,Pierceton,Pierceton Junction,Princeton', 41.2003200, -85.7055400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138700, 'Plymouth', 'Plymouth', 'PLY,Plimut,blymwth,plymwth  ayndyana,Плимут,بليموث,پلائی موتھ، انڈیانا,پلیموث، ایندیانا', 41.3436600, -86.3097300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138701, 'Portage', 'Portage', 'Portidz,bwrtagh,pwrtyj  ayndyana,Портиџ,بورتاغ,پورتیج، ایندیانا,پورٹیج، انڈیانا', 41.5758700, -87.1761500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138702, 'Porter', 'Porter', '', 41.6155900, -87.0742000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138703, 'Portland', 'Portland', 'Portland,Portlend,bwrtland,pwrtlnd  ayndyana,Портланд,Портленд,بورتلاند,پورتلند، ایندیانا,پورٹ لینڈ، انڈیانا', 40.4344900, -84.9777500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138704, 'Redkey', 'Redkey', 'Buzzard''s Roost,Grab All,Half Way,Lick Skillet,Red Key,Red Key Town,Redkey', 40.3489300, -85.1499700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138705, 'Remington', 'Remington', 'Carpenter''s Creek,Carpenter''s Station,Remington', 40.7608700, -87.1508500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138706, 'Rensselaer', 'Rensselaer', 'RNZ,Rensler,Ренслер', 40.9367000, -87.1508600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138707, 'Roanoke', 'Roanoke', '', 40.9625500, -85.3733100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138708, 'Rochester', 'Rochester', 'RCR,Rochester,locheseuteo,luo qie si te,rocestara,rwchstr  ayndyana,rwtshstr,Рочестер,روتشستر,روچستر، ایندیانا,روچسٹر، انڈیانا,रोचेस्टर,罗切斯特,로체스터', 41.0647600, -86.2158300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138709, 'Rome City', 'Rome City', '', 41.4961600, -85.3766500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138710, 'Roselawn', 'Roselawn', 'Rose Lawn,Roselawn', 41.1417000, -87.3147500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138711, 'Rossville', 'Rossville', '', 40.4169800, -86.5947200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138712, 'Russiaville', 'Russiaville', '', 40.4175400, -86.2713800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138713, 'Saint John', 'Saint John', 'Prairie West,Saint John,Western Prairie', 41.4500400, -87.4700400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138714, 'Schererville', 'Schererville', 'Shervil,Шервил,شیئرویل، انڈیانا', 41.4789200, -87.4547600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138715, 'Shadeland', 'Shadeland', '', 40.3736500, -86.9489000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138716, 'Sheridan', 'Sheridan', 'Millwood,Sheridan', 40.1350400, -86.2205500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138717, 'Simonton Lake', 'Simonton Lake', '', 41.7542200, -85.9750000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138718, 'South Bend', 'South Bend', 'Big Saint Joseph Station,Flexuvium Australe,Gorad Saut-Bend,SBN,Saint Joseph''s,Saut Bend,Saut Bendas,Saut-Bend,South Bend,Southold,The Bend,nan ben de,sauseubendeu,sausubendo,sawth bnd,sawth bnd  ayndyana,Горад Саўт-Бенд,Саут Бенд,Саут-Бенд,סאות בנד,ساؤتھ بینڈ، انڈیانا,ساوث بند,ساوث بند، ایندیانا,サウスベンド,南本德,사우스벤드', 41.6833800, -86.2500100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138719, 'South Haven', 'South Haven', '', 41.5419800, -87.1372600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138720, 'South Whitley', 'South Whitley', 'South Whitley,Springfield,Whitley', 41.0847700, -85.6280400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138721, 'Sweetser', 'Sweetser', 'Sweetser,Sweetsers', 40.5719800, -85.7691500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138722, 'Syracuse', 'Syracuse', '', 41.4278300, -85.7524900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138723, 'Thorntown', 'Thorntown', '', 40.1294800, -86.6066700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138724, 'Tipton', 'Tipton', 'Canton,Kingston,Tipton,tybtwn,typtwn  ayndyana,Типтон,تيبتون,تیپتون، ایندیانا,ٹپٹن، انڈیانا', 40.2822600, -86.0411000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138725, 'Topeka', 'Topeka', 'Topika,Топика', 41.5392200, -85.5397100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138726, 'Trail Creek', 'Trail Creek', '', 41.6983700, -86.8592000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138727, 'Tri-Lakes', 'Tri-Lakes', 'Tri Lakes,Tri-Lakes', 41.2458800, -85.4419200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138728, 'Union City', 'Union City', 'Junion-Siti,Юнион-Сити', 40.2019900, -84.8091300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138729, 'Upland', 'Upland', 'Apland,Апланд', 40.4756000, -85.4944200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138730, 'Valparaiso', 'Valparaiso', 'Portersville,VPZ,Val''paraiso,Valparaiso,Valparaíso,Valparejso,baelpeoleijo,falbaraysw,vu~aruparezo,wa er pa lai suo,walprayzw  ayndyana,Валпарејсо,Вальпараисо,فالبارايسو,والپرایزو، ایندیانا,ولپراسیو، انڈیانا,ヴァルパレーゾ,瓦尔帕莱索,밸퍼레이조', 41.4730900, -87.0611400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138731, 'Veedersburg', 'Veedersburg', 'Veedersburg,Veedersburgh', 40.1130900, -87.2625100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138732, 'Wabash', 'Wabash', 'Vobash,Wabash,Wabash Town,Wabashtown,vabasa,wabash,wabash  ayndyana,Вобаш,واباش,واباش، انڈیانا,واباش، ایندیانا,वाबाश', 40.7978200, -85.8205400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138733, 'Wakarusa', 'Wakarusa', 'Salem,Wakarusa', 41.5361600, -86.0208300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138734, 'Walkerton', 'Walkerton', '', 41.4667100, -86.4830700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138735, 'Walton', 'Walton', '', 40.6608700, -86.2419400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138736, 'Wanatah', 'Wanatah', '', 41.4306000, -86.8983600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138737, 'Warren', 'Warren', 'Jonesboro,Uorren,Warren,Уоррен', 40.6828200, -85.4272000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138738, 'Warsaw', 'Warsaw', 'Vorso,warsaw  ayndyana,warsw,Ворсо,وارسا، انڈیانا,وارساو، ایندیانا,وارسو', 41.2381000, -85.8530500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138739, 'Waterloo', 'Waterloo', 'Vaterlo,Waterloo,Waterloo City,Ватерло', 41.4319900, -85.0199700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138740, 'West Lafayette', 'West Lafayette', 'Chauncey,Kingston,Lafayette Occidentalis,Uehst-Lafejett,Vest Lafajet,Vest-Lafajett,West Lafayette,lafayt ghrby  ayndyana,u~esutorafaietto,weseuteulapies,wyst lafayyt,xi la fa ye,Вест Лафајет,Вест-Лафайетт,Уэст-Лафейетт,لافایت غربی، ایندیانا,مغربی لافائت، انڈیانا,ويست لافاييت,ウェストラファイエット,西拉法葉,웨스트라피엣', 40.4258700, -86.9080700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138741, 'Westfield', 'Westfield', 'Uehstfild,Vestfild,Westfield,Westville,weseuteupildeu,wstfyld  ayndyana,wystfyld,Вестфилд,Вестфілд,Уэстфилд,وستفیلد، ایندیانا,ويستفيلد,ویسٹ فیلڈ، انڈیانا,웨스트필드', 40.0428200, -86.1274900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138742, 'Westville', 'Westville', 'New Durham,Westville', 41.5414300, -86.9005800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138743, 'Whiting', 'Whiting', 'Whiting,Whiting''s,Whiting''s Crossing,Whiting''s Station', 41.6797600, -87.4944900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138744, 'Williamsport', 'Williamsport', 'Vilijamsport,Вилијамспорт,ولیمزپورٹ، انڈیانا', 40.2883700, -87.2939000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138745, 'Winamac', 'Winamac', 'Winamac,Winamack', 41.0514300, -86.6030600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138746, 'Winchester', 'Winchester', '', 40.1719900, -84.9813500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138747, 'Winona Lake', 'Winona Lake', 'Eagle Lake,Winona Lake', 41.2272700, -85.8219300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138748, 'Winfield', 'Winfield', 'Bibler,Winfield', 41.4053100, -87.2753100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138749, 'Wolcottville', 'Wolcottville', '', 41.5258800, -85.3666500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138750, 'Woodburn', 'Woodburn', 'Shirley City,Woodburn,Woodburn City', 41.1253300, -84.8533000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138751, 'Yorktown', 'Yorktown', '', 40.1736500, -85.4941400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138752, 'Abington', 'Abington', 'Abington,Abington Centre,Manamooskeagin,abynghtwn,abyngtn  masachwst,Абингтон,Абінгтон,أبينغتون,ابینگتن، ماساچوست,ایبنگٹن، میساچوسٹس', 42.1048200, -70.9453200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138753, 'Acton', 'Acton', 'Actonia,Akshn,Ehkton,aktn  masachwst,aktwn,Акшн,Эктон,أكتون,اکتن، ماساچوست,ایکٹن، میساچوسٹس', 42.4850900, -71.4328400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138754, 'Acushnet', 'Acushnet', 'Achushnet,Achushnet Village,Acushena,Acushnet,Akjushnet,akshnt  masachwst,akwshynt,Акюшнет,أكوشينت,اکشنت، ماساچوست', 41.6806600, -70.9078200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138755, 'Adams', 'Adams', 'Adams,East Hoosic,adamz,admz  masachwst,Адамс,آدامز,آدمز، ماساچوست', 42.6242500, -73.1176000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138756, 'Agawam', 'Agawam', 'Agavam,Agavom,Agawaam,Agawam,Agawam Town,Agawam Village,Agawom,Agawome,Agawomes,Aggawam,Aggawom,Aggawom *,Agissawamg,Agowaun,Agowaymam,Aguwom,Angawom,Angoum,Anguum,Augawam,Augawoam,Augoam,Auguan,a jia wan,agawamu,aghawam,ayjwam  masachwst,Агавам,Агавом,أغاوام,ایجوام، ماساچوست,ایگاوام، میساچوسٹس,アガワム,阿加萬', 42.0695400, -72.6148100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138757, 'Amesbury', 'Amesbury', 'Almsbury,Amehsbjuri,Amesbury,Ejmsberi,Salisbury,amsbry  masachwst,amysbwry,eimjeubeli,eimuzuberi,Амэсбюри,Ејмсбери,آمسبری، ماساچوست,أميسبوري,ایمزبیری، میساچوسٹس,エイムズベリー,에임즈베리', 42.8584200, -70.9300500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138758, 'Amherst', 'Amherst', 'Amerst,Amherst,Amherst Village,Amherst i Massachusetts,Amkhehrst,Amkherst,Amkhurst,Hadley East,Hadley East Precinct,Hadley Third Precinct,Third Precinct,amasuto,amhrst  masachwst,amyrst,Άμερστ,Амхерст,Амхърст,Амхэрст,אמהערסט,أميرست,امهرست، ماساچوست,ამჰერსტი,アマースト', 42.3672300, -72.5185200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138759, 'Amherst Center', 'Amherst Center', '', 42.3753700, -72.5192500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138760, 'Andover', 'Andover', 'Andouvehr,Andover,Andover Centre,Andover Village,Cochichawick,Cochichewick,aendobeo,an duo fu,andoba,andwwr,Андовер,Андоувэр,اندوور,アンドーバー,安多佛,앤도버', 42.6584300, -71.1370000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138761, 'Arlington', 'Arlington', 'Arlington,Menotomy,a ling dun,arinton,arlyngtwn  masachwst,Арлингтон,آرلنگٹن، میساچوسٹس,آرلینگتون، ماساچوست,アーリントン,阿灵顿', 42.4153700, -71.1564400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138762, 'Ashburnham', 'Ashburnham', 'Ashburnham,Ashburnham Centre,Ashburnkham,ashbrnham  masachwst,Ашбурнхам,اشبرنهام، ماساچوست', 42.6362000, -71.9078500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138763, 'Ashby', 'Ashby', 'Ashbi,Ashby,Ashby Centre,ashbay  masachwst,Ашби,اشبای، ماساچوست', 42.6778700, -71.8203500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138764, 'Ashfield', 'Ashfield', 'Ashfield,Ashfield Plain,Ashfild,Huntstown,ashfyld  masachwst,Ашфилд,اشفیلد، ماساچوست', 42.5264700, -72.7884300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138765, 'Ashland', 'Ashland', 'Ashland,Ashland Coutre,Ashlehnd,Magunkaquog,Unionville,aesyullaendeu,ashlnd  masachwst,Ашлэнд,اشلند، ماساچوست,ایشلنڈ، میساچوسٹس,애슐랜드', 42.2612100, -71.4634000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138766, 'Assonet', 'Assonet', 'Assonet,Assonet Village,Assonett,Freetown,aswnyt,أسونيت', 41.7959400, -71.0678200, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138767, 'Athol', 'Athol', 'Asol,Athol,Athol Centre,Athol Depot,Atol,Paquoig,atwl  masachwst,Асол,Атол,اتول، ماساچوست', 42.5959200, -72.2267500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138768, 'Attleboro', 'Attleboro', 'Atlboro,Attlboro,Attleboro,Attleborough,East Attleborough,atlbarw  masachwst,atlbwrw,atoruboro,Атлборо,Аттлборо,أتلبورو,اتلبارو، ماساچوست,ایٹلبرو، میساچوسٹس,アトルボロ', 41.9445400, -71.2856100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138769, 'Auburn', 'Auburn', 'Auburn,Auburn Centre,awbrn  masachwst,obeon,Аубурн,آبرن، میساچوسٹس,اوبرن، ماساچوست,오번', 42.1945400, -71.8356300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138770, 'Avon', 'Avon', '', 42.1306600, -71.0411600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138771, 'Ayer', 'Ayer', 'Ajehr,Ayer,Ayer Groton Junction,Ayer Junction,ayr  masachwst,Айэр,آیر، ماساچوست', 42.5612000, -71.5897900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138772, 'Baldwinville', 'Baldwinville', 'Baldwinsville,Baldwinville', 42.6084200, -72.0759100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138773, 'Barnstable', 'Barnstable', 'Barnstabl,Barnstable,Barnstable Town,Barnstable Village,Barnstabul,Barnstaple,Barnstehjbl,ba en si te bu er,banseuteobeul,bansutaburu,bar ns ta beil,barnstabl,brnstbl  masachwst,Барнстабл,Барнстабъл,Барнстэйбл,بارنستابل,بارنسٹیبل، میساچوسٹس,برنستبل، ماساچوست,บาร์นสตาเบิล,バーンスタブル,巴恩斯特布尔,반스터블', 41.7001100, -70.2994700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138774, 'Barre', 'Barre', 'Bar,Barre,Barre Centre,Barreh,Hutchinson,barh  masachwst,Бар,Баррэ,باره، ماساچوست', 42.4228700, -72.1050800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138775, 'Becket', 'Becket', 'Becket,Behkeht,North Becket,bkt  masachwst,Бэкэт,بکت، ماساچوست', 42.3320300, -73.0828800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138776, 'Bedford', 'Bedford', 'BED,Bedford,Bedford Centre,Behdford,bdfwrd  masachwst,Бедфорд,Бэдфорд,بدفورد، ماساچوست,بیڈفورڈ، میساچوسٹس', 42.4906500, -71.2761700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138777, 'Belchertown', 'Belchertown', 'Behlchertaun,Belchers Town,Belcherstown,Belchertown,Belchertown Village,Belchtaun,Cold Spring,Equivalent Lands,blkrtn  masachwst,Белчтаун,Бэлчертаун,بلکرتن، ماساچوست', 42.2770400, -72.4009200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138778, 'Bellingham', 'Bellingham', 'Behllinkhehm,Belingkham,blyngham  masachwst,Белингхам,Бэллинхэм,بلینگهام، ماساچوست', 42.0867600, -71.4745100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138779, 'Belmont', 'Belmont', 'Behlmont,Bellus Mons,Belmont,blmwnt  masachwst,Белмонт,Бэлмонт,بلمونت، ماساچوست', 42.3959300, -71.1786700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138780, 'Berkley', 'Berkley', 'Behrklej,brkly  masachwst,Бэрклей,برکلی، ماساچوست,برکلے، میساچوسٹس', 41.8459300, -71.0828200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138781, 'Berlin', 'Berlin', 'Berlin,Berlin Centre,brlyn  masachwst,Берлин,برلن، میساچوسٹس,برلین، ماساچوست', 42.3812000, -71.6370100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138782, 'Bernardston', 'Bernardston', 'Bernardston,Bernardston Village,Bernardstoun,brnardastwn  masachwst,Бернардстоун,برنارداستون، ماساچوست', 42.6709200, -72.5495300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138783, 'Beverly', 'Beverly', 'BVY,Bass River,Behverli,Beverli,Beverly,bebeolli,bibari,bwrly  masachwst,byfrly,Беверли,Бэверли,بورلی، ماساچوست,بيفرلي,بیورلی، میساچوسٹس,ビバリー,베벌리', 42.5584300, -70.8800500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138784, 'Beverly Cove', 'Beverly Cove', 'Beverly Cove,Cove Village', 42.5534300, -70.8536600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138785, 'Billerica', 'Billerica', 'Billerica,Billerica Centre,Billerica Village,Billerika,Billirrikey,Shawshine,birerika,bylryka  masachwst,Биллерика,بیلریکا، ماساچوست,ビレリカ', 42.5584300, -71.2689500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138786, 'Blackstone', 'Blackstone', 'Blackstone,Blackstone Village,Blehkstoun,blk astwn  masachwst,Блэкстоун,بلک استون، ماساچوست', 42.0178800, -71.5411700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138787, 'Bliss Corner', 'Bliss Corner', '', 41.6117700, -70.9383700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138788, 'Bolton', 'Bolton', 'Bolton,bwltwn  masachwst,Болтон,بولتون، ماساچوست', 42.4334300, -71.6078400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138789, 'Bondsville', 'Bondsville', 'Bond,Bondeville,Bonds Village,Bondsville,Duckville', 42.2125900, -72.3453600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138790, 'Boston', 'Boston', 'BOS,Baston,Boston,Bostona,Bostonas,Bostone,Bostonia,Bostono,Bostons,Bostun,Bostún,Gorad Bostan,Mushauwomuk,Old Boston,Po-su-tun,Pokekona,Pô-sṳ-tun,Shawmut,Shawmutt,Shawnnut,Totant,Tramount,Tremont,Trimountain,Trimountaine,Vostoni,Wahstoronon:ke,Wahstoronòn:ke,Wastok,bastan,bastana,bausatana,beasrraൺ,bo shi dun,boseuteon,bostan,bostana,bostʼoni,bosuton,bwstn,bwstwn,bxstan,pastan,Βοστωνη,Βοστώνη,Бостон,Бостън,Горад Бостан,Բոստոն,באסטאן,בוסטון,بوستون,بوسطن,بوسٹن,بۆستن,ܒܘܣܛܘܢ,बस्तन,बास्टन्,बॉस्टन,बोस्टन,বস্টন,ਬੌਸਟਨ,பாஸ்டன்,బోస్టన్,ಬಾಸ್ಟನ್,ബോസ്റ്റൺ,บอสตัน,བོ་སེ་ཊོན།,ဘော့စတွန်မြို့,ბოსტონი,ቦስቶን,ボストン,波士頓,波士顿,보스턴', 42.3584300, -71.0597700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138791, 'Bourne', 'Bourne', 'Born,Bourn,Bourne,Mananiet,bwrn  masachwst,Борн,Боурн,بورن، ماساچوست', 41.7412200, -70.5989200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138792, 'Boxborough', 'Boxborough', 'Boxboro,Boxborough', 42.4917600, -71.5272900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138793, 'Boxford', 'Boxford', 'Boksford,baksfwrd  masachwst,Боксфорд,باکسفورد، ماساچوست', 42.6612000, -70.9967200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138794, 'Boylston', 'Boylston', 'Bojlston,bwylstwn  masachwst,Бойлстон,بویلستون، ماساچوست', 42.3917600, -71.7036800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138795, 'Braintree', 'Braintree', 'Braintree,Passonagessit', 42.2223200, -70.9994900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138796, 'Brewster', 'Brewster', 'Brjuster,Bruster,brwstr  masachwst,Брустер,Брюстер,بروستر، ماساچوست', 41.7601100, -70.0828000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138797, 'Bridgewater', 'Bridgewater', 'Bridgewater,Bridgewater Centre,Bridzhuateh,Bridzhuoter,bryjwatr  masachwst,burijjiu~ota,Бриджуатэ,Бриджуотер,برج واٹر، میساچوسٹس,بریجواتر، ماساچوست,ブリッジウォーター', 41.9903800, -70.9750400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138798, 'Brimfield', 'Brimfield', 'Ashquoach,Blimfild,Brimfield,Brimfield Centre,brymfyld  masachwst,Блимфилд,بریمفیلد، ماساچوست', 42.1228700, -72.2009100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138799, 'Brockton', 'Brockton', 'Brockton,Brokton,Broktun,North Bridgewater,braktwn  masachwst,brwktwn,bu luo ke dun,burokkuton,Броктон,Броктън,براکتون، ماساچوست,بروكتون,بروکٹن، میساچوسٹس,ブロックトン,布罗克顿', 42.0834300, -71.0183800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138800, 'Brookline', 'Brookline', 'Brookline,Brouklain,Bruklajn,Bruklin,beulukeullain,brwklayn  masachwst,brwqlyyn,bu lu ke lai en,burukkurain,Μπρούκλαϊν,Бруклайн,Бруклајн,Бруклин,ברוקליין,بروکلاین، ماساچوست,ブルックライン,布鲁克莱恩,브루클라인', 42.3317600, -71.1211600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138801, 'Buckland', 'Buckland', 'Baklehnd,Buckland,Buckland Centre,baklnd  masachwst,bwkland,Баклэнд,باکلند، ماساچوست,بوكلاند', 42.5923100, -72.7917600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138802, 'Burlington', 'Burlington', 'BBF,Berlington,Bjurlington,Burlington,Burlington Centre,Burlingtun,bo ling dun,brlyngtwn  masachwst,bwrlynghtwn,Берлингтон,Бърлингтън,Бюрлингтон,برلنگٹن، میساچوسٹس,برلینگتون، ماساچوست,بورلينغتون,伯灵顿', 42.5048200, -71.1956100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138803, 'Buzzards Bay', 'Buzzards Bay', '', 41.7453800, -70.6180900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138804, 'Cambridge', 'Cambridge', 'Cambridge,Cambridge i Massachusetts,Cantabrigia,Gorad Kembrydzh,Kehmbridzh,Keimbridza,Keimbridža,Keimpritz,Kejmbridzh,Kembridz,Kembridzas,Kembridzh,Kembridžas,Kembrigo,Kembrizh,Kembriĝo,Mishawum,New Town,New Towne,Newtown,Newtowne,Old Cambridge,jian qiao,kambrydj,keimbeuliji,kembrija,kempirij,kenburijji,khem bridc,kmbryj  masachwst,qyymbrydg,Κέιμπριτζ,Горад Кембрыдж,Кеймбридж,Кембридж,Кембриж,Кембриџ,Кембриҷ,Кэмбридж,Քեմբրիջ,קיימברידג,קעמברידזש,كامبريدج,کمبریج، ماساچوست,کیمبرج، میساچوسٹس,केंब्रिज,கேம்பிரிஜ்,เคมบริดจ์,ケンブリッジ,剑桥,케임브리지', 42.3751000, -71.1056100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138805, 'Canton', 'Canton', 'Canton,Dorchester Village,Punkapoag,South Canton', 42.1584300, -71.1447700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138806, 'Carlisle', 'Carlisle', 'Carlisle,Carlisle Centre,Karlisl,karlayl  masachwst,karlyls,Карлисл,كارليلس,کارلائل، میساچوسٹس,کارلایل، ماساچوست', 42.5292600, -71.3495000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138807, 'Carver', 'Carver', 'Carver,Carver Centre,Garvehr,Mohootset,karfyr,karwr  masachwst,Гарвэр,كارفير,کارور، ماساچوست', 41.8834400, -70.7625400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138808, 'Centerville', 'Centerville', 'Centerville,Centreville,Chequaquet', 41.6487200, -70.3480800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138809, 'Charlemont', 'Charlemont', 'Charlmount,karlmwnt  masachwst,tsharlmwnt,Чарлмоунт,تشارلمونت,کارلمونت، ماساچوست', 42.6278600, -72.8698200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138810, 'Charlton', 'Charlton', 'Charleston,Charlton,Charlton Centre,charltwn  masachwst,tsharltwn,Чарлтон,تشارلتون,چارلتون، ماساچوست', 42.1356500, -71.9700700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138811, 'Chatham', 'Chatham', 'Chatam,Chatham,Chatham Village,Chatkham,Manamoyik,Monimoy,Monomoyick,Port Fortune,chatamu,chtm  masachwst,tshatham,Чатам,Чатхам,تشاتهام,چتم، ماساچوست,チャタム', 41.6820600, -69.9597400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138812, 'Chelmsford', 'Chelmsford', 'Chelmsford,shlmzfwrd  masachwst,tshylmsfwrd,Челмсфорд,تشيلمسفورد,شلمزفورد، ماساچوست', 42.5998100, -71.3672800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138813, 'Chelsea', 'Chelsea', 'Chehlsi,Chelsea,Chelsi,Romney Marsh,Rumney Marsh,Winisemit,Winne-ashim-ut,Winnet Semet,Winnisemit,Winnisimmet,Winnissimmet,chelsi,cherushi,chlsy  masachwst,qie er xi,tshylsy,Челси,Чэлси,تشيلسي,چلسی، ماساچوست,چیلسی، میساچوسٹس,チェルシー,切尔西,첼시', 42.3917600, -71.0328300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138814, 'Chesterfield', 'Chesterfield', 'Chehsterfild,Chesterfield,Chesterfield Centre,chstrfyld  masachwst,tshystrfyld,Чэстерфилд,تشيسترفيلد,چسترفیلد، ماساچوست,چیسٹرفیلڈ، میساچوسٹس', 42.3917500, -72.8398200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138815, 'Chicopee', 'Chicopee', 'CEF,Chicopee,Chikopi,chikopi,qi ke pi,shykwby,shykwpy  masachwst,Чикопи,Чікопі,شيكوبي,شیکوپی، ماساچوست,چیکوپی، میساچوسٹس,チコピー,奇科皮', 42.1487000, -72.6078700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138816, 'Clinton', 'Clinton', 'Clinton,Clinton Village,Klinton,klyntwn,klyntwn  masachwst,Клинтон,كلينتون,کلنٹن، میساچوسٹس,کلینتون، ماساچوست', 42.4167600, -71.6828500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138817, 'Cochituate', 'Cochituate', 'Cochituate,Cohituate Village', 42.3209300, -71.3642300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138818, 'Cohasset', 'Cohasset', 'Cohasset,Cohasset Village,Conihasset,Connohasset,Kokhasseht,Quonahassit,kwhasyt,kwhst  masachwst,Кохассэт,كوهاسيت,کوهست، ماساچوست', 42.2417700, -70.8036500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138819, 'Colrain', 'Colrain', 'Boston Township,Colerain,Coleraine,Colrain,Colrain Center,Colrain Centre,Kolrehjn,kwlryan,kwlryn  masachwst,Колрэйн,كولريان,کولرین، ماساچوست', 42.6731400, -72.6967600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138820, 'Concord', 'Concord', 'Concord,Concord Centre,Concord i Massachusetts,Concordia,Konkord,Musketequid,kang ke te,knkwrd  masachwst,kongkodeu,konkodo,kwnkwrd,Конкорд,كونكورد,کنکورد، ماساچوست,کونکورڈ، میساچوسٹس,コンコード,康科特,콩코드', 42.4603700, -71.3489500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138821, 'Conway', 'Conway', 'Konvej,Конвей', 42.5098100, -72.6995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138822, 'Cordaville', 'Cordaville', '', 42.2689800, -71.5239500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138823, 'Cotuit', 'Cotuit', 'Cetuet,Coatuit,Cotuit,Cotuit Port,Cotuitport', 41.6167800, -70.4369700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138824, 'Dalton', 'Dalton', 'Dalton,daltwn,daltwn  masachwst,Далтон,دالتون,دالتون، ماساچوست,ڈالٹن، میساچوسٹس', 42.4737000, -73.1662100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138825, 'Danvers', 'Danvers', 'Danvehrs,Danvers,Danvers Plains,Denvers,New Mills,Salem Village,The Plains,daenbeoseu,danbasu,danfrz,dnwrs  masachwst,Данверс,Данвэрс,Денверс,دانفرز,دنورس، ماساچوست,ダンバース,댄버스', 42.5750900, -70.9300500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138826, 'Dedham', 'Dedham', 'Dedam,Dedham,Dedham Village,Dehdkham,dai de mu,ddham  masachwst,dedamu,dedeom,dydam,Дедам,Дэдхам,ددهام، ماساچوست,ديدام,デダム,戴德姆,데덤', 42.2417700, -71.1661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138827, 'Dennis', 'Dennis', 'Denis,Dennis,Nobsquassitt,Sawkattuckett,deniseu,dnys,dnys  masachwst,Денис,Деннис,دنيس,دنیس، ماساچوست,데니스', 41.7353900, -70.1939100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138828, 'Dennis Port', 'Dennis Port', 'Dennis Port,Dennisport', 41.6584500, -70.1286300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138829, 'Dighton', 'Dighton', 'Dajton,daytwn,dygtwn  masachwst,Дайтон,دايتون,دیگتون، ماساچوست', 41.8139900, -71.1203200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138830, 'Douglas', 'Douglas', 'Douglas,Douglass,Duglas,daglas  masachwst,dwghlas,Дуглас,داگلاس، ماساچوست,دوغلاس', 42.0542600, -71.7395100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138831, 'Dover', 'Dover', 'Dover,Dover Centre,Duvehr,dwfr,dwwr  masachwst,Довер,Дувэр,دوفر,دوور، ماساچوست,ڈوور، میساچوسٹس', 42.2459300, -71.2828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138832, 'Dracut', 'Dracut', 'Dracut,Dracut Centre,Drakat,Drakut,drakat  masachwst,drakwt,Дракат,دراكوت,دراکات، ماساچوست', 42.6703700, -71.3020100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138833, 'Dudley', 'Dudley', 'Chabanakongkomom,Dadlehj,Dudley,Dudley Centre,dadly  masachwst,dwdly,Дадлэй,دادلی، ماساچوست,دودلي', 42.0451000, -71.9300700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138834, 'Dunstable', 'Dunstable', 'Danstehjbl,Dunstable,Dunstable Centre,danstbl  masachwst,dwnstybl,Данстэйбл,دانستبل، ماساچوست,دونستيبل', 42.6750900, -71.4828400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138835, 'Duxbury', 'Duxbury', 'Daksburu,Djuksbjuri,Duxbury,Mattakesett,daksbry  masachwst,dwksbwry,Даксбуру,Дюксбюри,داکسبری، ماساچوست,دوكسبوري', 42.0417700, -70.6722600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138836, 'East Bridgewater', 'East Bridgewater', 'Ist Bridzhuateh,bryjwatr shrqy  masachwst,Ист Бриджуатэ,بریجواتر شرقی، ماساچوست', 42.0334300, -70.9592100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138837, 'East Brookfield', 'East Brookfield', 'Ist Brukfild,ayst brwkfyld,brwkfyld shrqy  masachwst,Ист Брукфилд,إيست بروكفيلد,بروکفیلد شرقی، ماساچوست', 42.2278700, -72.0467400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138838, 'East Dennis', 'East Dennis', '', 41.7426100, -70.1619600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138839, 'East Douglas', 'East Douglas', 'East Douglas,East Douglas Village,East Douglass', 42.0723200, -71.7134000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138840, 'East Harwich', 'East Harwich', '', 41.7001100, -70.0272400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138841, 'East Longmeadow', 'East Longmeadow', 'East Long Meadow,East Longmeadow,Ist Longmidou,ayst lwnghmydw,langmydw shrqy  masachwst,Ист Лонгмидоу,إيست لونغميدو,لانگمیدو شرقی، ماساچوست', 42.0645400, -72.5125900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138842, 'East Pepperell', 'East Pepperell', 'East Pepperell,North Groton', 42.6653700, -71.5731200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138843, 'East Sandwich', 'East Sandwich', 'East Sandwich,Spring Hill', 41.7417700, -70.4516900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138844, 'Eastham', 'Eastham', 'Eastham,Istkhehm,Malle Barre,Nauset,Nawsett,astham  masachwst,aystham,Истхэм,إيستهام,استهام، ماساچوست', 41.8301100, -69.9739100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138845, 'Easthampton', 'Easthampton', 'East Hampton,Easthampton,Istgempton,Istkhampton,Istkhehmpton,Istkhempton,asthamptwn  masachwst,aysthambtwn,isutohanputon,yi si te han pu dun,Істгемптон,Истхамптон,Истхемптон,Истхэмптон,إيستهامبتون,استهامپتون، ماساچوست,ایسٹ ہیمپٹن، میساچوسٹس,イーストハンプトン,伊斯特漢普頓', 42.2667600, -72.6689800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138846, 'Easton', 'Easton', 'Easton,Easton Furnace,Furnace,Furnace Village,Iston,Pequimmit,astwn  masachwst,aystwn,Истон,إيستون,استون، ماساچوست', 42.0245400, -71.1286600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138847, 'Edgartown', 'Edgartown', 'Edgartaun,Edgarton,Edgartown,Edgartown Village,Ehdgartaun,Great Harbor,Great Harbour,Nunne-poag,Nunnepog,Oldtown,adgartwn  masachwst,adghartawn,ai de jia dui,edeugeotaun,edogataun,Едгартаун,Эдгартаун,إدغارتاون,ادگارتون، ماساچوست,エドガータウン,埃德加敦,에드거타운', 41.3890100, -70.5133600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138848, 'Erving', 'Erving', 'Erving,arwyng  masachwst,ayrfyngh,Ервинг,إيرفينغ,اروینگ، ماساچوست', 42.6000900, -72.3981400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138849, 'Essex', 'Essex', 'Chebacco,Ehsseks,Eseks,Essex,asks  masachwst,Есекс,Эссекс,اسکس، ماساچوست', 42.6320400, -70.7828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138850, 'Everett', 'Everett', 'Ehverett,Everet,ai fu li te,awryt  masachwst,ayfrt,ebaretto,Еверет,Эверетт,إيفرت,اوریت، ماساچوست,ایوریٹ، میساچوسٹس,エバレット,埃弗里特', 42.4084300, -71.0536600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138851, 'Fairhaven', 'Fairhaven', 'Fajehkhaven,fyrhawn  masachwst,fyrhyfn,Файэхавен,فيرهيفن,فیئرہون، میساچوسیٹس,فیرهاون، ماساچوست', 41.6376000, -70.9036500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138852, 'Fall River', 'Fall River', 'Border City Village,Fall River,Fall River Village,Fol Riveh,Fol River,Foll-River,Pocasset,The Border City,fal rywr  masachwst,foruriba,fu er li fu,fwl ryfr,Фол Ривер,Фол Ривэ,Фолл-Ривер,Фолл-Рівер,فال ریور، ماساچوست,فال ریور، میساچوسیٹس,فول ريفر,フォールリバー,福尔里弗', 41.7014900, -71.1550500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138853, 'Falmouth', 'Falmouth', 'FMH,Falmous,Falmouth,Falmut,Falmuthum,Sacconesset,Succonessitt,Succonnessitt,falmwt  masachwst,falmwth,farumasu,Фалмоус,Фалмут,فالموت، ماساچوست,فالموث,ファルマス', 41.5515000, -70.6147500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138854, 'Fiskdale', 'Fiskdale', '', 42.1162100, -72.1134100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138855, 'Fitchburg', 'Fitchburg', 'Fichburg,Fitchburg,Fitchburg Centre,fei qi bao,fitchibagu,fychbrg  masachwst,fytshbwrgh,Фитчбург,Фичбург,فيتشبورغ,فیچبرگ، ماساچوست,فیچبرگ، میساچوسٹس,フィッチバーグ,菲奇堡', 42.5834200, -71.8023000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138856, 'Forestdale', 'Forestdale', '', 41.6917700, -70.4994700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138857, 'Foxborough', 'Foxborough', 'Foksboro,Foxboro,Foxborough,Foxmporo,faksbrw  masachwst,fokkusuboro,fu ke si bao,fwksbwrwh,pogseubeoleo,Φόξμπορο,Фоксборо,فاکسبرو، ماساچوست,فوكسبوروه,フォックスボロ,福克斯堡,폭스버러', 42.0653800, -71.2478300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138858, 'Framingham', 'Framingham', 'Framingham,Framingkham,Frejmingkham,South Framingham,framyngham  masachwst,framynghham,fureiminguhamu,peuleiminghaem,Фрамингхам,Фрејмингхам,فرامينغهام,فرامینگهام، ماساچوست,フレイミングハム,프레이밍햄', 42.2792600, -71.4161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138859, 'Framingham Center', 'Framingham Center', 'Framingham Center,Framingham Centre', 42.2973200, -71.4370100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138860, 'Franklin', 'Franklin', 'Franklin,Franklin Centre,Franklin Village,Frenklin,franklyn,frankyn  masachwst,fu lan ke lin,furankurin,peulaengkeullin,Франклин,Френклин,فرانكلين,فرانکین، ماساچوست,فرینکلن، میساچوسٹس,フランクリン,富兰克林,프랭클린', 42.0834300, -71.3967300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138861, 'Freetown', 'Freetown', 'Assonet,Freemans Land,Freemens Land,Freetown,Fritaun,Tiverton,Town of Assonet,Town of Freemans Land,Wattuppa,fry twn  masachwst,frytawn,Фритаун,فريتاون,فری تون، ماساچوست,فری ٹاؤن، میساچوسٹس', 41.7667700, -71.0328200, 'US', '2010-04-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138862, 'Gardner', 'Gardner', 'GDM,Gardnehr,Gardner,Gardner Centre,West Gardner,gardnr  masachwst,Гарднер,Гарднэр,گاردنر، ماساچوست', 42.5750900, -71.9981300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138863, 'Gill', 'Gill', 'Gill,ghyl,gyl  masachwst,Гилл,غيل,گیل، ماساچوست', 42.6403600, -72.4995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138864, 'Gloucester', 'Gloucester', 'Glocester,Gloster,Gloucester,Gloucester Harbor,Glousehstehr,The Harbor,Wingaersheek,Wonasquam,ge luo si te,ghlwstr,glwkstr  masachwst,gurosuta,Глостер,Глоусэстэр,غلوستر,گلوسٹر، میساچوسٹس,گلوکستر، ماساچوست,グロスター,格洛斯特', 42.6159300, -70.6619900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138865, 'Grafton', 'Grafton', 'Grafton,Grafton Center,Grafton Centre,Grehfton,ghraftwn,grftwn  masachwst,Грэфтон,غرافتون,گرفتون، ماساچوست', 42.2070400, -71.6856200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138866, 'Granby', 'Granby', 'Granbi,Grehnbi,ghranby,grnbay  masachwst,Гранби,Грэнби,غرانبي,گرنبای، ماساچوست', 42.2564800, -72.5162000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138867, 'Granville', 'Granville', 'Granvill,Granville,Granville Four Corners,ghranfyl,grnwyl  masachwst,Гранвилл,غرانفيل,گرنویل، ماساچوست', 42.0667600, -72.8614900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138868, 'Great Barrington', 'Great Barrington', 'GBR,Great Barrington,Grejt Barington,Grit Barrington,Kenuckpacook,Westenhuck,bryngtwn bzrg  masachwst,geuleiteubaelingteon,ghryt barynghtwn,Грејт Барингтон,Грит Баррингтон,برینگتون بزرگ، ماساچوست,غريت بارينغتون,گریٹ بیرنگٹن، میساچوسٹس,그레이트배링턴', 42.1959200, -73.3620600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138869, 'Greenfield', 'Greenfield', 'Grinfild,Гринфилд', 42.5875900, -72.5995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138870, 'Groveland', 'Groveland', 'Gruvlehnd,grwlnd  masachwst,Грувлэнд,گرولند، ماساچوست', 42.7603700, -71.0314500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138871, 'Hadley', 'Hadley', 'Hadley,Khadlehj,Nalwottoge,Newtown,Nolwottoge,Nonotuck,Norwottocke,ha de li,hadly,hdly  masachwst,Хадлэй,هادلي,هدلی، ماساچوست,哈德利', 42.3417600, -72.5884200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138872, 'Halifax', 'Halifax', 'Khalifaks,halfyks,hlyfks  masachwst,Халифакс,هالفيكس,هلیفکس، ماساچوست', 41.9912100, -70.8619900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138873, 'Hamilton', 'Hamilton', 'Hamilton,Ipswich Hamlet', 42.2562000, -71.7675700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138874, 'Hampden', 'Hampden', 'Hampden,Khampdehn,South Wilbraham,hambdyn,hmpdn  masachwst,Хампдэн,هامبدين,همپدن، ماساچوست', 42.0639800, -72.4134200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138875, 'Hanson', 'Hanson', 'Hanson,Khanson,Khehnson,North Hanson,hansn,hanswn,Хансон,Хэнсон,هانسن,هانسون', 42.0751000, -70.8800400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138876, 'Hanover', 'Hanover', 'Four Corners,Hanover,Hanover Four Corners,Khanouveh,hanwfr,hanwwr,Ханоувэ,هانوفر,هانوور', 42.1131600, -70.8119900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138877, 'Hardwick', 'Hardwick', 'Hardwick,Hardwick Centre,Kharduik,hardwyk,Хардуик,هاردویک', 42.3500900, -72.1995200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138878, 'Harvard', 'Harvard', 'Harvard,Harvard Centre,Kharvard,harward,Харвард,هاروارد', 42.5000900, -71.5828400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138879, 'Harwich', 'Harwich', 'Harwich,Harwich Center,Harwich Centre,Kharvich,Satucket,Satuckett,harwyk,harwytsh,Харвич,هارويتش,هارویک', 41.6862200, -70.0758500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138880, 'Harwich Port', 'Harwich Port', 'Harwich Port,Harwichport', 41.6667800, -70.0786300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138881, 'Hatfield', 'Hatfield', 'Capawonk,Hatfield,Khatfild,Newtown,hatfyld,hytfyld  masachwst,Хатфилд,هاتفيلد,هیتفیلد، ماساچوست', 42.3709200, -72.5981400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138882, 'Haverhill', 'Haverhill', 'Haverhill,Khaverkhill,Pentucket,Pentuckett,Хаверхилл', 42.7762000, -71.0772800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138883, 'Head of Westport', 'Head of Westport', 'Head of Westport,Head of the River,Westport,Westport Village', 41.6209400, -71.0619900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138884, 'Hingham', 'Hingham', 'Bear Cove,Conihasset,Hingham,Khingam,Khinkham,hyngham  masachwst,hynghham,Хингам,Хинхам,هينغهام,هینگهام، ماساچوست', 42.2417700, -70.8897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138885, 'Hinsdale', 'Hinsdale', '', 42.4387000, -73.1253800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138886, 'Holbrook', 'Holbrook', 'Kholbruk,halbrwk,hwlbrwk,Холбрук,هالبروک,هولبروك', 42.1551000, -71.0086600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138887, 'Holden', 'Holden', 'Eagleville,Holden,Khouldehn,hwldn  masachwst,hwldyn,Хоулдэн,هولدن، ماساچوست,هولدين', 42.3517600, -71.8634100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138888, 'Holland', 'Holland', 'Gollandija,Kholand,Kholland,hlnd  masachwst,hwland,Голландия,Холанд,Холланд,هلند، ماساچوست,هولاند,ہالینڈ، میساچوسٹس', 42.0639800, -72.1573000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138889, 'Holliston', 'Holliston', 'Holliston,Holliston Centre,Kholliston,hlystwn  masachwst,hwlystwn,Холлистон,هلیستون، ماساچوست,هوليستون', 42.2001000, -71.4245000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138890, 'Holyoke', 'Holyoke', 'Goliok,Kholiok,Kholiouk,Kholjok,horuyoku,huo li ao ke,hwlywk,hwlywk  masachwst,Голіок,Холиок,Холиоук,Холјок,هوليوك,هولیوک، ماساچوست,ہولیوک، میساچوسٹس,ホルヨーク,霍利奥克', 42.2042600, -72.6162000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138891, 'Hopedale', 'Hopedale', '', 42.1306500, -71.5411700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138892, 'Hopkinton', 'Hopkinton', 'Gopkinton,Hopkinton,Hopkinton Centre,Khopkinton,hobkinteon,hwbkyntwn,hwpkyntwn  masachwst,Гопкінтон,Хопкинтон,هوبكينتون,هوپکینتون، ماساچوست,홉킨턴', 42.2287100, -71.5225600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138893, 'Housatonic', 'Housatonic', '', 42.2542500, -73.3662200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138894, 'Hubbardston', 'Hubbardston', 'Hubbardston,Hubbardston Centre,Khabbardstoun,habrdztwn  masachwst,hwbardstwn,Хаббардстоун,هابردزتون، ماساچوست,هوباردستون', 42.4737000, -72.0061900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138895, 'Hudson', 'Hudson', 'Feltonville,Gudzon,Hudson,Khadson,hwdstwn  masachwst,hwdswn,Гудзон,Хадсон,هودستون، ماساچوست,هودسون,ہڈسن، میساچوسٹس', 42.3917600, -71.5661800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138896, 'Hull', 'Hull', 'Hull,Khal,Khall,Nantascot,hal,hwl,Хал,Халл,هال,هول', 42.3020400, -70.9078200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138897, 'Hyannis', 'Hyannis', 'HYA,Hyannis,Hyannis Port,Iyanoughs Land,Khajanis,Yannos,haiaeniseu,haianisu,haynys,Хаянис,هاينيس,ハイアニス,하이애니스', 41.6528900, -70.2828000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138898, 'Ipswich', 'Ipswich', 'Agawam,Gippevicum,Ipsvich,Ipswich,aypswych  masachwst,Ипсвич,ایپسویچ، ماساچوست', 42.6792600, -70.8411600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138899, 'Jamaica Plain', 'Jamaica Plain', 'Jamaica Plain,Jamaica Plains,جمیکا پلائیں', 42.3098200, -71.1203300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138900, 'Kingston', 'Kingston', 'Kingston,gyngstwn  masachwst,kynghstwn,Кингстон,كينغستون,کنگسٹن، میسا چوسٹس,گینگستون، ماساچوست', 41.9945500, -70.7244800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138901, 'Lancaster', 'Lancaster', 'Lancaster,Lancaster Center,Lancaster Centre,Lankastehr,Lankaster,Nashaway,lankastr,lnkstr  masachwst,Ланкастер,Ланкастэр,لانكاستر,لانکیسٹر، مساچوسٹس,لنکستر، ماساچوست', 42.4556500, -71.6731200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138902, 'Lanesborough', 'Lanesborough', 'Lanesboro,Lanesborough,Lanesborough Village,Lehjnsborou,Lejnsboro,lnsbrw  masachwst,lynsbwrwgh,Лејнсборо,Лэйнсбороу,لانیسبروگ، مساچوسٹس,لنسبرو، ماساچوست,لينسبوروغ', 42.5173100, -73.2281600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138903, 'Lawrence', 'Lawrence', 'LWM,Lawrence,Lorehns,Lorens,Lourens,lao lun si,larns  masachwst,lolenseu,lwrans,lwrns,rorensu,Лоренс,Лорэнс,Лоуренс,לורנס,لارنس، ماساچوست,لارنس، میساچوسٹس,لورانس,ローレンス,劳伦斯,로렌스', 42.7070400, -71.1631100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138904, 'Lee', 'Lee', 'Li,ly,ly  masachwst,Ли,لي,لی، ماساچوست', 42.3042500, -73.2481600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138905, 'Leicester', 'Leicester', 'Lehjsehstehr,Leicester,Leicester Center,lykstr  masachwst,Лэйсэстэр,لیکستر، ماساچوست', 42.2459300, -71.9086800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138906, 'Lenox', 'Lenox', 'Lenoks,Lenox,Lenuks,Linoks,Yokun,lnaks  masachwst,lynwks,Ленокс,Ленъкс,Линокс,لناکس، ماساچوست,لينوكس', 42.3564800, -73.2848300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138907, 'Leominster', 'Leominster', 'Leminster,Leominster,Leominster Centre,Leominstere,Liominstur,lywmynstr  masachwst,reminsuta,ywmnstr,Леминстер,Леоминстер,Леоминстере,Лиоминстър,لئومینستر، ماساچوست,لیومینسٹر، میساچوسٹس,يومنستر,レミンスター', 42.5250900, -71.7597900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138908, 'Leverett', 'Leverett', 'Levehrehtt,Leverett,Leverett Center,Leverett Centre,South Leverett,lwrt  masachwst,lyfyryt,Левэрэтт,لورت، ماساچوست,ليفيريت', 42.4520300, -72.5014800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138909, 'Lexington', 'Lexington', 'Cambridge Farms,Leksington,Lexington,Lexington Centre,Lexington Village,Lexingtonia,legsingteon,lie ke xing dui,lksyngtwn  masachwst,lyksynghtwn,rekishinton,Лексингтон,ليكسينغتون,لکسینگتون، ماساچوست,لیکسنگٹن، میساچوسٹس,レキシントン,列克星敦,렉싱턴', 42.4473200, -71.2245000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138910, 'Lincoln', 'Lincoln', 'Lincoln,Lincoln Center,Lincoln Centre,Linkol''n,lynkln  masachwst,lynkwln,Линкольн,لنکن، میساچوسٹس,لينكولن,لینکلن، ماساچوست', 42.4259300, -71.3039500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138911, 'Littleton Common', 'Littleton Common', 'Littleton,Littleton Village', 42.5459300, -71.4745100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138912, 'Longmeadow', 'Longmeadow', 'Long Meadow,Longmeadow,Longmedou,Longmidou,Masacksick,langmydw  masachwst,lwnghmydw,Лонгмедоу,Лонгмидоу,لانگمیدو، ماساچوست,لونغميدو', 42.0501000, -72.5828700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138913, 'Lowell', 'Lowell', 'Lauehll,Loouel,Louehll,Louel,Louell,Louul,Lowell,lovela,lowel,luo e er,lwwl,lwwl  masachwst,lwwyl,rou~eru,Λόουελ,Лауэлл,Лоуел,Лоуелл,Лоуъл,Лоуэлл,לוול,لوول، ماساچوست,لوويل,لوویل، میساچوسٹس,लॉवेल,ក្រុងឡូវែល រដ្ឋម៉ាស្សាឈូស៊ែត,ローウェル,洛厄尔,로웰', 42.6334200, -71.3161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138914, 'Ludlow', 'Ludlow', 'Jenckesville,Jenksville,Ladlou,Ludlow,Stony Hill,lwdlaw  masachwst,lwdlw,Ладлоу,لودلاو، ماساچوست,لودلو', 42.1600900, -72.4759200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138915, 'Lunenburg', 'Lunenburg', 'Lunenburg,lanynbwrgh,lwlnbrg  masachwst,Луненбург,لانينبورغ,لولنبرگ، ماساچوست', 42.5945300, -71.7245200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138916, 'Lynn', 'Lynn', 'Lin,Linn,Lyn,Lynn,Saugus,lin,lin en,lyn,lynn  masachwst,rin,Лин,Линн,Лінн,لين,لین، میساچوسٹس,لینن، ماساچوست,リン,林恩,린', 42.4667600, -70.9494900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138917, 'Lynnfield', 'Lynnfield', 'Linfild,Linnfild,Lynn End,Lynnfield,Lynnfield Center,Lynnfield Centre,laynnfyld,lynnfyld  masachwst,Линнфилд,Линфилд,لايننفيلد,لینفیلڈ، میساچوسٹس,لیننفیلد، ماساچوست', 42.5389800, -71.0481100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138918, 'Malden', 'Malden', 'Maldehn,Maldeno,Molden,maldn,mldn  masachwst,moldeun,moruden,Малдэн,Молден,مالدن,مالڈن، میساچوسٹس,ملدن، ماساچوست,モールデン,몰든', 42.4251000, -71.0661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138919, 'Manchester-by-the-Sea', 'Manchester-by-the-Sea', 'Jeffreys Creek,Manchehster-baj-zeh-Si,Manchester,Manchester Village,Manchester-by-the-Sea,maencheseuteobaideosi,manshstr bay dh sy,mnchstr sahl drya  masachwst,Манчестер,Манчэстер-бай-зэ-Си,مانشستر باي ذ سي,مانچسٹر، میساچوسٹس,منچستر ساحل دریا، ماساچوست,맨체스터바이더시', 42.5778700, -70.7689400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138920, 'Mansfield', 'Mansfield', 'Mansfild,Mehnsfild,maenseupildeu,mansfyld,mnsfyld  masachwst,Мансфилд,Мэнсфилд,مانسفيلد,منسفیلد، ماساچوست,맨스필드', 42.0334300, -71.2189400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138921, 'Marblehead', 'Marblehead', 'Marble Harbor,Marblehead,Marblkhed,Marblkhid,marblhd  masachwst,marblhyd,Марблхед,Марблхид,ماربلهد، ماساچوست,ماربلهيد', 42.5001000, -70.8578300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138922, 'Marion', 'Marion', 'Marion,Marion MA,Mehrion,Rochester,Sippican,Sippican Village,marywn,marywn  masachwst,Марион,Мэрион,ماريون,ماریون، ماساچوست,ماریون، میساچوسٹس', 41.7001000, -70.7628100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138923, 'Marlborough', 'Marlborough', 'MXG,Marlboro,malbeoleo,marlbrw  masachwst,marlbwrw,maruboro,Марлборо,مارلبرو، ماساچوست,مارلبورو,مارلبورو، میساچوسٹس,マールボロ,말버러', 42.3459300, -71.5522900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138924, 'Marshfield', 'Marshfield', 'Conohasset,Greens Harbour,Marshfield,Marshfild,Rexhame,South Marshfield,Wrexham,marshfyld,marshfyld  masachwst,Маршфилд,مارشفيلد,مارشفیلد، ماساچوست', 42.0917700, -70.7055900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138925, 'Marshfield Hills', 'Marshfield Hills', 'East Marshfield,Marshfield Hills', 42.1459400, -70.7397600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138926, 'Marstons Mills', 'Marstons Mills', 'Marston Mills,Marston''s Mills,Marstons Mills,Morstons Mills', 41.6562200, -70.4161400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138927, 'Mashpee', 'Mashpee', 'Cadtanmut,Marshpee,Mashpee,Pawpoesit,mashby,mashpy  masachwst,ماشبي,ماشپی، ماساچوست', 41.6484400, -70.4811400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138928, 'Mattapoisett', 'Mattapoisett', 'Mattapoisett,Mattapoissett,Mattapojseht,Mattapuyst,Mattpoiset,Mettapaset,Mettasaset,matabwysyt,matapwyst  masachwst,Маттапойсэт,ماتابويسيت,ماتاپویست، ماساچوست', 41.6584400, -70.8161500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138929, 'Maynard', 'Maynard', 'Assabet,Maynard,Mehjnard,Mejnard,mynrad  masachwst,Мејнард,Мэйнард,مینراد، ماساچوست', 42.4334300, -71.4495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138930, 'Medfield', 'Medfield', 'Medfield,Medfield Centre,Medfild,Mehdfild,mdfyld  masachwst,mydfyld,Медфилд,Мэдфилд,مدفیلد، ماساچوست,ميدفيلد', 42.1876000, -71.3064500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138931, 'Medford', 'Medford', 'Medford,Mehdford,Mistic,Mystic,mdfwrd  masachwst,medeupeodeu,medofodo,mydfwrd,Медфорд,Мэдфорд,مدفورد، ماساچوست,ميدفورد,میڈفورڈ، میساچوسٹس,メドフォード,메드퍼드', 42.4184300, -71.1061600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138932, 'Medway', 'Medway', 'Factory Village,Medway,Medway Village,Mehdvehj,mdwy  masachwst,mydway,Мэдвэй,مدوی، ماساچوست,ميدواي', 42.1417600, -71.3967300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138933, 'Melrose', 'Melrose', 'Mehlrous,Melrose,Melrouz,Mystic Side,Ponde Fielde,mlrwz  masachwst,Мелроуз,Мэлроус,ملروز، ماساچوست', 42.4584300, -71.0661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138934, 'Mendon', 'Mendon', 'Mehndon,Mendon,Mendon Village,Tatumasket,mndwn  masachwst,myndwn,Мэндон,مندون، ماساچوست,ميندون', 42.1056500, -71.5522900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138935, 'Merrimac', 'Merrimac', 'Mehrrimak,Merrimac,Merrimack,West Amesbury,mrymk  masachwst,myrymak,Мэрримак,مریمک، ماساچوست,ميريماك', 42.8306500, -71.0022800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138936, 'Methuen', 'Methuen', 'Mehsjuehn,Methuen,Methuen Falls,Methuen Town,Metuen,masuan,mthwyn  masachwst,mythywn,Метуен,Мэсюэн,مثوئن، ماساچوست,ميثيون,میتھوئن، میساچوسٹس,マスーアン', 42.7262000, -71.1908900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138937, 'Middleborough', 'Middleborough', 'Four Corners,Middleboro,Middleborough,Namasket', 41.8931600, -70.9111500, 'US', '2017-05-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138938, 'Middleton', 'Middleton', 'Middltaun,Middlton,mydltwn,mydltwn  masachwst,Миддлтаун,Миддлтон,Міддлтон,ميدلتون,میدلتون، ماساچوست', 42.5950900, -71.0161600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138939, 'Milford', 'Milford', 'Milford,Milford Centre,mylfwrd,mylfwrd  masachwst,Милфорд,ميلفورد,میلفورد، ماساچوست,میلفورڈ، میساچوسٹس', 42.1398200, -71.5161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138940, 'Millbury', 'Millbury', 'Armory village,Millburi,Millbury,Millbury Centre,mylbry  masachwst,mylbwry,Миллбури,ميلبوري,میلبری، ماساچوست', 42.1939800, -71.7600700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138941, 'Millers Falls', 'Millers Falls', '', 42.5820300, -72.4925900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138942, 'Millis', 'Millis', 'East Medway,Millis,mylys,mylys  masachwst,Миллис,ميليس,میلیس، ماساچوست', 42.1676000, -71.3578400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138943, 'Millville', 'Millville', 'Millvill,mylfyl,mylwyl  masachwst,Миллвилл,ميلفيل,میلویل، ماساچوست', 42.0278800, -71.5809000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138944, 'Milton', 'Milton', 'Massachusett,Mil''ton,Milton,Miltun,Uncataquisset,Uncataquissett,Unquety,mi er dun,myltwn,myltwn  masachwst,Милтон,Милтън,Мильтон,ملٹن، میساچوسٹس,ميلتون,میلتون، ماساچوست,米尔顿', 42.2495400, -71.0661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138945, 'Monson', 'Monson', 'Monson,Monson Center,mwnswn,mwnswn  masachwst,Монсон,مونسون,مونسون، ماساچوست', 42.1042600, -72.3189700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138946, 'Monument Beach', 'Monument Beach', 'Monument Beach,Monumet Beach', 41.7195500, -70.6119800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138947, 'Montague', 'Montague', 'Montag,Montague,Montague Centre,mwntag  masachwst,mwntaghw,Монтаг,مونتاغو,مونتاگ، ماساچوست', 42.5356400, -72.5350900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138948, 'Nahant', 'Nahant', 'Nakhant,nahant  masachwst,Нахант,ناهانت، ماساچوست', 42.4264900, -70.9189400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138949, 'Nantucket', 'Nantucket', 'ACK,Mantukett,Nantucket,Nantucket Village,Nantuckett,Nantuckkit,Nantucquet,Nantukes,Nantukett,Sharborn,Shelburne,Sherborn,Sherbourne,Sherburn,Sherburne,Wesco,Wesko', 41.2834600, -70.0994600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138950, 'Natick', 'Natick', 'Locus Collium,Natick,Natick Centre,Natick Village,Natik,Nejtik,natyk,natyk  masachwst,neitikku,Натик,Нейтик,ناتيك,ناتیک، ماساچوست,ネイティック', 42.2834300, -71.3495000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138951, 'Needham', 'Needham', 'Nidam,Nidkham,nydham,nydham  masachwst,Нидам,Нидхам,نيدهام,نیدهام، ماساچوست', 42.2834300, -71.2328300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138952, 'New Bedford', 'New Bedford', 'Achushena,Acushnet Village,EWB,N''ju Behdford,N''ju-Bedford,New Bedford,Nju Bedford,bdfwrd jdyd  masachwst,niwbedf xrd,nyubeddofodo,nyubedeupeodeu,nyw bdfwrd,xin bei de fu de,Њу Бедфорд,Нью Бэдфорд,Нью-Бедфорд,بدفورد جدید، ماساچوست,نيو بدفورد,نیو بیڈفورڈ، میساچوسٹس,นิวเบดฟอร์ด,ニューベッドフォード,新贝德福德,뉴베드퍼드', 41.6362200, -70.9342100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138953, 'New Marlborough', 'New Marlborough', 'N''ju Marlborou,New Marlboro,New Marlborough,New Marlborough Village,marlbrw jdyd  masachwst,nyw marlbwrw,Нью Марлбороу,مارلبرو جدید، ماساچوست,نيو مارلبورو', 42.1228700, -73.2287200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138954, 'Newburyport', 'Newburyport', 'Clipper City,N''jubjuriport,Newburyport,Njuberiport,niu bo li bo te,nyubeolipoteu,nyuberipoto,nywbwrypwrt  masachwst,Њуберипорт,Ньюбюрипорт,نیوبریپورٹ، میساچوسٹس,نیوبوریپورت، ماساچوست,ニューベリーポート,纽伯里波特,뉴버리포트', 42.8125900, -70.8772800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138955, 'Newton', 'Newton', 'Cambridge,N''juton,New Towne,Newton,Njuton,Njutun,Nonantum,niu dun,nyuteon,nyuton,nywtn,nywtwn  masachwst,Њутон,Ньютон,Нютън,نيوتن,نیوتون، ماساچوست,نیوٹن، میساچوسٹس,ニュートン,牛顿,뉴턴', 42.3370400, -71.2092200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138956, 'Norfolk', 'Norfolk', 'Norfolk,North Wrentham,nwrfalk  masachwst,nwrfwlk,Норфолк,نورفالک، ماساچوست,نورفولك', 42.1195400, -71.3250600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138957, 'North Adams', 'North Adams', 'Nors Adams,Nort Adams,admz shmaly  masachwst,bei ya dang si,noseuaedeomseu,nosuadamuzu,nwrth admz,Норс Адамс,Норт Адамс,آدمز شمالی، ماساچوست,نارتھ ایڈمز، میساچوسٹس,نورث آدمز,ノースアダムズ,北亚当斯,노스애덤스', 42.7009200, -73.1087100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138958, 'North Amherst', 'North Amherst', '', 42.4103700, -72.5309200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138959, 'North Brookfield', 'North Brookfield', 'Nors Brukfild,Nort Brukfild,North Brookfield,North Brookfield Centre,brwkfyld shmaly  masachwst,nwrth brwkfyld,Норс Брукфилд,Норт Брукфилд,بروکفیلد شمالی، ماساچوست,نورث بروكفيلد', 42.2667600, -72.0828500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138960, 'North Chicopee', 'North Chicopee', '', 42.1834300, -72.5995300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138961, 'North Eastham', 'North Eastham', '', 41.8651100, -69.9911300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138962, 'North Falmouth', 'North Falmouth', 'North Falmouth,North Falmouth Village', 41.6459400, -70.6183600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138963, 'North Lakeville', 'North Lakeville', '', 41.8576000, -70.9422600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138964, 'North Pembroke', 'North Pembroke', '', 42.0931600, -70.7925400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138965, 'North Plymouth', 'North Plymouth', '', 41.9709400, -70.6828100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138966, 'North Reading', 'North Reading', 'Nors Riding,North Parish Village,North Reading,nwrth rydyngh,rydyng shmaly  masachwst,Норс Ридинг,ریدینگ شمالی، ماساچوست,شمالی ریڈنگ، میساچوسٹس,نورث ريدينغ', 42.5750900, -71.0786700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138967, 'North Scituate', 'North Scituate', '', 42.2189900, -70.7856000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138968, 'North Seekonk', 'North Seekonk', '', 41.8892700, -71.3300500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138969, 'North Westport', 'North Westport', '', 41.6603800, -71.0883800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138970, 'Northampton', 'Northampton', 'Nalwottoge,Nolwottoge,Nonatuck,Nonotuck,Nonotuck City of Northampton,Norsehmpton,Nortgempton,Northampton,Nortkhamptun,Nortkhempton,Norwottocke,Paradise City,bei an pu dui,nosanputon,nwrthamptwn  masachwst,nwrthhambtwn,Норсэмптон,Нортгемптон,Нортхамптън,Нортхемптон,نارتھیمپٹن، میساچوسٹس,نورتهامپتون، ماساچوست,نورثهامبتون,ノーサンプトン,北安普敦', 42.3250900, -72.6412000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138971, 'Northborough', 'Northborough', 'Norsborou,Nortboro,Northboro,Northborough,nwrthbwrw,nwztbrw  masachwst,Норсбороу,Нортборо,نورثبورو,نوزتبرو، ماساچوست', 42.3195400, -71.6411800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138972, 'Northbridge', 'Northbridge', 'Norsbridzh,Northbridge,Rochdale,Rockdale,nwrtbryj  masachwst,nwrthbrydj,Норсбридж,نورتبریج، ماساچوست,نورثبريدج', 42.1514800, -71.6495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138973, 'Northfield', 'Northfield', 'Norsfild,Nortfild,Northfield,Northfield Village,Squakheag,Squawkeag,nwrtfyld  masachwst,nwrthfyld,Норсфилд,Нортфилд,نارتھفیلڈ، میساچوسٹس,نورتفیلد، ماساچوست,نورثفيلد', 42.6959200, -72.4528700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138974, 'Norton', 'Norton', 'Norton,Norton Centre,nwrtwn,nwrtwn  masachwst,Нортон,نورتون,نورتون، ماساچوست', 41.9667700, -71.1869900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138975, 'Norwell', 'Norwell', 'Norvehll,Norwell,South Scituate,nwrwl  masachwst,nwrwyl,Норвэлл,نورول، ماساچوست,نورويل', 42.1617700, -70.7939300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138976, 'Norwood', 'Norwood', 'Norvud,OWD,nwrwwd,nwrwwd  masachwst,Норвуд,نوروود,نوروود، ماساچوست', 42.1945400, -71.1995000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138977, 'Oak Bluffs', 'Oak Bluffs', 'Cottage City,Easternmost Chop of Holmes Hole,Oak Blaffs,Oak Bluffs,Vineyard Grove,awk blwfs,awk blwfz  masachwst,Оак Блаффс,أوك بلوفس,اوک بلوفز، ماساچوست', 41.4542800, -70.5619700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138978, 'Oakham', 'Oakham', 'Oakham,Oakham Centre,Oakkham,awkham,awkham  masachwst,Оакхам,أوكهام,اوکهام، ماساچوست', 42.3528700, -72.0453500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138979, 'Ocean Grove', 'Ocean Grove', '', 41.7292700, -71.2092100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138980, 'Onset', 'Onset', '', 41.7417700, -70.6578100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138981, 'Orange', 'Orange', 'Orange,Orange Centre', 42.5903600, -72.3098100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138982, 'Orleans', 'Orleans', 'Eastham,Nawsett,Orlean,Orleans,Orleans Village,Orlins,awrlyns,awrlynz  masachwst,Орлеан,Орлеанс,Орлинс,أورلينس,اورلینز، ماساچوست', 41.7898300, -69.9897400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138983, 'Osterville', 'Osterville', 'Cotocheeset,Osterville', 41.6284400, -70.3869700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138984, 'Otis', 'Otis', '', 42.1931500, -73.0917700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138985, 'Oxford', 'Oxford', 'Oksford,Oxford,Oxford Centre,aksfwrd  masachwst,awksfwrd,Оксфорд,آکسفورد، ماساچوست,آکسفورڈ، میساچوسٹس,أوكسفورد', 42.1167600, -71.8647900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138986, 'Palmer', 'Palmer', 'PMX,Palmehr,Palmer,Palmer Depot,balmr,palmr  masachwst,pama,Палмер,Палмэр,بالمر,پالمر، ماساچوست,پامر، میساچوسٹس,パーマー', 42.1584300, -72.3286900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138987, 'Paxton', 'Paxton', 'Pakston,Paxton,Paxton Centre,bakstwn,pakstwn  masachwst,Пакстон,باكستون,پاکستون، ماساچوست', 42.3112000, -71.9281300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138988, 'Peabody', 'Peabody', 'Peabody,Pibodi,South Danvers,bybwdy,pibodi,pybwy  masachwst,Пибоди,بيبودي,پیباڈی، میساچوسٹس,پیبوی، ماساچوست,ピーボディ', 42.5278700, -70.9286600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138989, 'Pelham', 'Pelham', 'Equivalent Lands,Pehlkham,Pelham,Pelham Heights,Stoddards Town,bylham,plham  masachwst,Пэлхам,بيلهام,پلهام، ماساچوست', 42.3931500, -72.4037000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138990, 'Pepperell', 'Pepperell', 'Pehppehrel,Peperel,Pepperell,Pepperell Centre,bybryl,ppyrl  masachwst,Пеперел,Пэппэрел,بيبريل,پپیرل، ماساچوست', 42.6659200, -71.5884000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138991, 'Phillipston', 'Phillipston', 'Phillipston,Phillipston Centre', 42.5487000, -72.1328600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138992, 'Pinehurst', 'Pinehurst', '', 42.5292600, -71.2281100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138993, 'Pittsfield', 'Pittsfield', 'Boston Plantation,PSF,Pitsfijld,Pitsfild,Pittsfield,Pontoosuc,Pontoosuck,Poontoosuck,Wendells Town,bytsfyld,pi ci fei er de,picheupildeu,pittsufirudo,pytzfyld  masachwst,Питсфийлд,Питсфилд,بيتسفيلد,پٹسفیلڈ، میساچوسٹس,پیتزفیلد، ماساچوست,ピッツフィールド,皮茨菲尔德,피츠필드', 42.4500800, -73.2453800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138994, 'Plainville', 'Plainville', 'Plehjnvilli,Plejnvill'',plynwyl  masachwst,Плейнвилль,Плэйнвилли,پلینویل، ماساچوست', 42.0042700, -71.3328300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138995, 'Plymouth', 'Plymouth', 'Accomack,New Plimouth,PYM,Patuxit,Plimaus,Plimoth Plantation,Plimouth,Plimut,Plimutas,Plymouth,Port Saint-Louis,peullimeoseu,plymwth  masachwst,pu li mao si,purimasu,Плимаус,Плимут,Плимът,Плімут,پلایماؤت، میساچوسٹس,پلیموث، ماساچوست,プリマス,普利茅斯,플리머스', 41.9584400, -70.6672600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138996, 'Plympton', 'Plympton', 'Plimpton,plymptwn  masachwst,Плимптон,پلیمپتون، ماساچوست', 41.9528800, -70.8144800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138997, 'Pocasset', 'Pocasset', 'Pocasset,Pocasset Village', 41.6862200, -70.6161400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138998, 'Princeton', 'Princeton', 'Princeton,Princeton Centre,Prinston,prynstwn  masachwst,Принстон,پرنسٹن، میساچوسٹس,پرینستون، ماساچوست', 42.4487000, -71.8773000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(138999, 'Provincetown', 'Provincetown', 'Cap Blanc,PVC,Provincetown,Village of Provincetown', 42.0584400, -70.1786400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139000, 'Quincy', 'Quincy', 'Braintree,Brantree,City Presidents,Kuajnsi,Kuinsi,Kvinsi,MQI,Quincy,kuinshi,kun shi,kun xi,kwinsi,kwynsy,kwynsy  masachwst,Квинси,Квінсі,Куайнси,Куинси,كوينسي,کوئنسی، ماساچوست,کوئنسی، میساچوسٹس,クインシー,昆市,昆西,퀸시', 42.2528800, -71.0022700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139001, 'Randolph', 'Randolph', 'Randol''f,Randolf,Randolph,Randolph Centre,randorufu,randwlf,rndwlf  masachwst,Рандолф,Рандольф,راندولف,رندولف، ماساچوست,رینڈولف، میساچوسٹس,ランドルフ', 42.1626000, -71.0411600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139002, 'Raynham', 'Raynham', 'Hockamock,North Raynham,Rayham,Raynham,Rehjnkham,rayham  masachwst,Рэйнхам,رایهام، ماساچوست', 41.9487100, -71.0731000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139003, 'Raynham Center', 'Raynham Center', 'Raynham,Raynham Center,Raynham Centre', 41.9237100, -71.0522700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139004, 'Reading', 'Reading', 'Lynn Village,Reading,Reding,Riding,rydyng  masachwst,Рединг,Ридинг,ریدینگ، ماساچوست,ریڈنگ، میساچوسٹس', 42.5256500, -71.0953300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139005, 'Rehoboth', 'Rehoboth', 'Palmers River,Rehkhobos,Rehoboth,Rehoboth Village,Saconet,Seakonk,ryhwbw  masachwst,Рэхобос,ریهوبو، ماساچوست', 41.8403800, -71.2494900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139006, 'Richmond', 'Richmond', 'Mount Ephraim,Richmond,Richmont,Yokun Town,rychmwnd  masachwst,Ричмонд,رچمنڈ، میساچوسٹس,ریچموند، ماساچوست', 42.3731400, -73.3676100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139007, 'Rochester', 'Rochester', 'Rochehster,Rochester,Rochester Centre,rwchstr  masachwst,Рочестер,Рочэстер,روچستر، ماساچوست,روچیسٹر، میساچوسٹس', 41.7317700, -70.8200400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139008, 'Rockland', 'Rockland', 'East Abington,Rockland,Roklehnd,raklnd  masachwst,Роклэнд,راکلند، ماساچوست', 42.1306600, -70.9161600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139009, 'Rockport', 'Rockport', 'Rockport,Rockport Village,Rokport,Sandy Bay,rakpwrt  masachwst,Рокпорт,راکپورت، ماساچوست,راکپورٹ، میساچوسٹس', 42.6556500, -70.6203200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139010, 'Rowley', 'Rowley', 'Roulej,Rouli,rwly  masachwst,Роулей,Роули,رولی، ماساچوست', 42.7167600, -70.8786600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139011, 'Royalston', 'Royalston', 'Rojalstoun,Royalston,Royalston Centre,rwyalstwn  masachwst,Роялстоун,رویالستون، ماساچوست', 42.6775900, -72.1878600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139012, 'Rutland', 'Rutland', 'Ratland,Ratlend,Rutland,Rutland Center,Rutland Centre,rwtlnd  masachwst,Ратланд,Ратленд,روتلند، ماساچوست', 42.3695400, -71.9481300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139013, 'Sagamore', 'Sagamore', 'Sagamore,West Sandwich', 41.7701100, -70.5283600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139014, 'Salem', 'Salem', 'Naamkeek,Naumkeag,Nehumkeke,Salem,Sejlem,Sejlum,sai lei mu,seilleom,seiramu,selama,sylm  masachwst,Салем,Сейлем,Сейлъм,Сејлем,سیلم، ماساچوست,सेलम,セイラム,塞勒姆,세일럼', 42.5195400, -70.8967200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139015, 'Salisbury', 'Salisbury', 'East Salisbury,Salisbjuri,Salisbury,Solsberi,salzbry  masachwst,Салисбюри,Солсбери,سالزبری، ماساچوست', 42.8417600, -70.8606100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139016, 'Sandwich', 'Sandwich', 'Aquetnet,Sandwich,Sandwich Village,Sehndvich,Sendvich,sandou~itchi,sandwytsh,sndwych  masachwst,Сендвич,Сэндвич,ساندويتش,سندویچ، ماساچوست,サンドウィッチ', 41.7590000, -70.4939200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139017, 'Saugus', 'Saugus', 'Hammersmith,Saugas,Saugus,Saugus Centre,Sogas,sagws  masachwst,Саугас,Согас,ساگوس، ماساچوست', 42.4648200, -71.0100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139018, 'Scituate', 'Scituate', 'Assanippi,East Scituate,Satuit,Scituate,Scituate Harbor,Scituate Harbour,Sityate', 42.1959300, -70.7258700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139019, 'Seekonk', 'Seekonk', 'Seacunk,Seconet,Seconnet,Secunke,Seekonk,Wauchimoquit,sykank  masachwst,سیکانک، ماساچوست', 41.8084300, -71.3370000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139020, 'Sharon', 'Sharon', 'Sharon,Shehron,Sheron,sharn  masachwst,Шарон,Шерон,Шэрон,شارن، ماساچوست', 42.1237100, -71.1786600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139021, 'Shelburne', 'Shelburne', 'Deerfield Northwest,Deerfield Pasture,Schelburne Centre,Shehlburn,Shelburne,Shelburne Center,shlbrn  masachwst,Шэлбурн,شلبرن، ماساچوست', 42.5898100, -72.6884200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139022, 'Shelburne Falls', 'Shelburne Falls', '', 42.6042500, -72.7392600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139023, 'Sherborn', 'Sherborn', 'Shehrbon,Sherborn,Sherborn Centre,shrbwrn  masachwst,Шэрбон,شربورن، ماساچوست', 42.2389900, -71.3697800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139024, 'Shirley', 'Shirley', 'Shirlehj,Shirley,Shirley Village,Shirli,shrly  masachwst,Ширли,Ширлэй,شرلی، ماساچوست', 42.5437000, -71.6495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139025, 'Shrewsbury', 'Shrewsbury', 'Shrewsbury,Shrewsbury Centre,Shrjusbjuri,Shrusberi,shrwzbry  masachwst,shuruzuberi,Шрусбери,Шрюсбюри,شروزبری، ماساچوست,シュルーズベリー', 42.2959300, -71.7128500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139026, 'Shutesbury', 'Shutesbury', 'Road Town,Shatehsbjuri,Shutesbury,Shutesbury centre,shatzbry  masachwst,Шатэсбюри,شاتزبری، ماساچوست', 42.4564800, -72.4098100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139027, 'Smith Mills', 'Smith Mills', 'Smith Mills,Smiths Mills', 41.6389900, -70.9911500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139028, 'Somerset', 'Somerset', 'Samerset,Somerset,Somerset Village,samrst  masachwst,Самерсет,Сомерсет,سامرست، ماساچوست', 41.7695500, -71.1286600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139029, 'Somerville', 'Somerville', 'Samervil,Somehrvill,Somervill,Somerville,Sumurvil,sa mo wei er,samabiru,samrwyl  masachwst,Самервил,Сомервилл,Сомэрвилл,Съмървил,سامرویل، ماساچوست,サマービル,萨默维尔', 42.3876000, -71.0995000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139030, 'South Amherst', 'South Amherst', '', 42.3403700, -72.5050900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139031, 'South Ashburnham', 'South Ashburnham', 'Ashburnham Junction,South Ashburnham', 42.6103700, -71.9389700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139032, 'South Boston', 'South Boston', 'Dorchester Heights,South Boston', 42.3334300, -71.0494900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139033, 'South Deerfield', 'South Deerfield', '', 42.4773100, -72.6078700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139034, 'South Dennis', 'South Dennis', '', 41.6895600, -70.1564100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139035, 'South Hadley', 'South Hadley', 'Saut Khadli,Sous Khadlehj,hdly jnwby  masachwst,Саут Хадли,Соус Хадлэй,هدلی جنوبی، ماساچوست', 42.2584200, -72.5745300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139036, 'South Lancaster', 'South Lancaster', '', 42.4445400, -71.6870100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139037, 'South Peabody', 'South Peabody', '', 42.5098200, -70.9494900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139038, 'South Yarmouth', 'South Yarmouth', '', 41.6667800, -70.1847400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139039, 'Southampton', 'Southampton', '', 42.2292600, -72.7300900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139040, 'Southborough', 'Southborough', 'Sousborou,Southboro,Southborough,satbrw  masachwst,Соусбороу,ساتبرو، ماساچوست', 42.3056500, -71.5245100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139041, 'Southbridge', 'Southbridge', 'Sautbridz,Sousbridzh,Southbridge,Southbridge Centre,satbryj  masachwst,sauseubeuliji,sausuburijji,sawthbrydj,Саутбриџ,Соусбридж,ساتبریج، ماساچوست,ساوتھبریج، میساچوسٹس,ساوثبريدج,サウスブリッジ,사우스브리지', 42.0751000, -72.0334100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139042, 'Southwick', 'Southwick', 'Sousvik,satwyk  masachwst,Соусвик,ساتویک، ماساچوست', 42.0548200, -72.7703700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139043, 'Spencer', 'Spencer', 'Spencer,Spencer Centre,Spenser,Spensur,aspnsr  masachwst,sbnsr,Спенсер,Спенсър,اسپنسر، ماساچوست,سبنسر', 42.2439800, -71.9923000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139044, 'Springfield', 'Springfield', 'Agawam,Agawome,Campifons,Nayasset,SFY,Springfield,Springfield City,Springfijld,Springfild,Springfilda,Springfildas,Springfīlda,Spryngfild,aspryngfyld  masachwst,sbrynghfyld,seupeulingpildeu,si pu lin fei er de,spryngpyld,supuringufirudo,Спрингфийлд,Спрингфилд,Спрингфілд,Спрынгфілд,ספרינגפילד,اسپرینگفیلد، ماساچوست,سبرينغفيلد,سپرنگفیلڈ، میساچوسٹس,スプリングフィールド,斯普林菲尔德,스프링필드', 42.1014800, -72.5898100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139045, 'Sterling', 'Sterling', 'Sterling,Sterling Centre,astrlyng  masachwst,Стерлинг,استرلینگ، ماساچوست', 42.4375900, -71.7606300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139046, 'Stockbridge', 'Stockbridge', 'Indian Town,Kaunameek,Stockbridge,Stokbridzh,Wnogquetookoke,astwkbryj  masachwst,Стокбридж,استوکبریج، ماساچوست', 42.2875900, -73.3203900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139047, 'Stoneham', 'Stoneham', 'Stonkham,Stounkhem,astwnham  masachwst,Стонхам,Стоунхем,استونهام، ماساچوست', 42.4801000, -71.0995000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139048, 'Stoughton', 'Stoughton', 'Stoughton,Stoughton Centre,Stouton,astwtwn  masachwst,Стоутон,استوتون، ماساچوست', 42.1251000, -71.1022700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139049, 'Stow', 'Stow', 'MMN,Stou,Stounkham,Stow,Stowe,Stowe Centre,astw  masachwst,Стоу,Стоунхам,استو، ماساچوست', 42.4370400, -71.5056200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139050, 'Sturbridge', 'Sturbridge', 'Sterbridz,Stjurbridzh,astwrbryj  masachwst,Стербриџ,Стюрбридж,استوربریج، ماساچوست', 42.1084300, -72.0786900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139051, 'Sudbury', 'Sudbury', 'New Plantation by Concord,Sadbjuri,Sudbury,Sudbury Centre,sdbry  masachwst,Садбюри,سدبری، ماساچوست', 42.3834300, -71.4161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139052, 'Sunderland', 'Sunderland', '', 42.2445400, -71.7717400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139053, 'Sutton', 'Sutton', 'Sattan,Sutton,Sutton Centre,satwn  masachwst,Саттан,ساتون، ماساچوست', 42.1501000, -71.7628500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139054, 'Swampscott', 'Swampscott', 'Svampskott,Svompskot,Swampscot,Swampscott,swamskat  masachwst,Свампскотт,Свомпскот,سوامسکات، ماساچوست', 42.4709300, -70.9175500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139055, 'Swansea', 'Swansea', 'Swansea,Swansey,Swansey Village,Swanzea,swansy  masachwst,سوانسی، ماساچوست', 41.7481600, -71.1897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139056, 'Taunton', 'Taunton', 'Taunton,Taunton Green,Tonten,Tonton,Tontun,tang dun,tantwn  masachwst,tonteon,tonton,twntwn,Тонтен,Тонтон,Тонтън,تانتون، ماساچوست,تونتون,ٹاؤنٹن، میساچوسٹس,トーントン,汤顿,톤턴', 41.9001000, -71.0897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139057, 'Teaticket', 'Teaticket', '', 41.5645500, -70.5958600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139058, 'Templeton', 'Templeton', 'Tehmplton,Templeton,Templeton Centre,tmpltwn  masachwst,Тэмплтон,تمپلتون، ماساچوست', 42.5556400, -72.0675800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139059, 'Tewksbury', 'Tewksbury', 'T''juksberi,T''juksbjuri,Tewksbury,Tewksbury Center,Tewksbury Centre,Tewksbury Village,Wamesit,twksbry  masachwst,twqsbry,Тьюксбери,Тьюксбюри,טוקסברי,توکسبری، ماساچوست', 42.6106500, -71.2342200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139060, 'Topsfield', 'Topsfield', 'New Meadows,New Meadows Village,Shenewemedy,The New Meadow,Topsfield,Topsfild,tapsfyld  masachwst,Топсфилд,تاپسفیلد، ماساچوست', 42.6375900, -70.9495000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139061, 'Townsend', 'Townsend', 'Centre Village,Centreville,Taunsehnd,Taunsend,Townsend,Townsend Center,tawnznd  masachwst,Таунсенд,Таунсэнд,تاونزند، ماساچوست', 42.6667600, -71.7050700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139062, 'Truro', 'Truro', 'Dangerfield,Pamet,Trjuro,Truro,Truro Village,trwrw  masachwst,Трюро,ترورو، ماساچوست', 41.9934400, -70.0497500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139063, 'Turners Falls', 'Turners Falls', 'Peskeompskut,Turners Falls', 42.6042500, -72.5564800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139064, 'Tyngsboro', 'Tyngsboro', 'Tyngsboro,Tyngsborough,Tyngsborough Centre', 42.6767600, -71.4245100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139065, 'Upton', 'Upton', 'Apton,Upton,Upton Centre,Upton-West Upton,aptwn  masachwst,Аптон,آپتون، ماساچوست', 42.1745400, -71.6022900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139066, 'Uxbridge', 'Uxbridge', '"ksbridzh,Aksbridz,Aksbridzas,Aksbridzh,Aksbridžas,Uxbridge,Uxbridge Village,Wacuntug,Waeuntug,a ke si bu li qi,aksabrija,akusuburijji,awksbrydj,eogseubeuliji,uksbridge,Аксбридж,Аксбриџ,Ъксбридж,آکس‌بریج، ماساچوست,أوكسبريدج,अक्सब्रिज,ऊक्ष्ब्रिद्गे,アクスブリッジ,阿克斯布里奇,억스브리지', 42.0773200, -71.6295100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139067, 'Vineyard Haven', 'Vineyard Haven', 'Holmes Hole,Holmes Hole Neck,Homes Hole,Nobnocket,Tisbury,Vineyard Haven', 41.4542800, -70.6036400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139068, 'Wakefield', 'Wakefield', 'Lynn Village,Reading,South Reading,The Common,Vejkfild,Wakefield,Wakefield Center,wykfyld  masachwst,Вејкфилд,ویکفیلد، ماساچوست', 42.5064800, -71.0728300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139069, 'Wales', 'Wales', 'Wales,Wales Village', 42.0695400, -72.2223000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139070, 'Walpole', 'Walpole', 'Uolpol,Valpoul,Volpul,Walpole,Walpole Junction,walpwl  masachwst,Валпоул,Волпул,Уолпол,والپول، ماساچوست', 42.1417700, -71.2495000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139071, 'Waltham', 'Waltham', 'Uoltem,Voltam,Voltgem,WLM,u~orusamu,waltham,waltham  masachwst,wo er se mu,wwltm,Волтам,Волтгем,Уолтем,וולתם,والتهام، ماساچوست,والتھم، میساچوسٹس,والثام,ウォルサム,沃尔瑟姆', 42.3764900, -71.2356100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139072, 'Ware', 'Ware', 'Equivalent Lands,Ware,Ware Village', 42.2598100, -72.2398000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139073, 'Wareham Center', 'Wareham Center', '', 41.7667700, -70.7261500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139074, 'Warren', 'Warren', 'Uarren,Uorren,Voren,Warren,Warren Centre,warn  masachwst,Ворен,Уаррен,Уоррен,وارن، ماساچوست', 42.2125900, -72.1911900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139075, 'Watertown', 'Watertown', 'Saltonstall Plantation,Votertaun,Watertown,u~otataun,watrtawn  masachwst,wo te dui,woteotaun,wtrtawn,Вотертаун,واترتاون، ماساچوست,واٹر ٹاؤن، میساچوسٹس,وترتاون,ウォータータウン,沃特敦,워터타운', 42.3709300, -71.1828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139076, 'Wayland', 'Wayland', 'East Sudbury,Wayland,Wayland Centre,wylnd  masachwst,ویلند، ماساچوست', 42.3626000, -71.3614500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139077, 'Webster', 'Webster', 'Chabanakongkomum,Uehbster,Vebster,Webster,wbstr  masachwst,Вебстер,Уэбстер,وبستر، ماساچوست,ویبسٹر، میساچوسٹس', 42.0501000, -71.8800700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139078, 'Wellesley', 'Wellesley', 'Uehlsli,Vehlslehj,Velesli,Wellesley,West Needham,wei er si li,wlzly  masachwst,Велесли,Вэлслэй,Уэлсли,ولزلی، ماساچوست,韋爾斯利', 42.2964900, -71.2925600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139079, 'Wellfleet', 'Wellfleet', 'Belinsgate,Billingsgate,North Wellfleet,Pamet,Pononakanet,Poole,Port aux Huitres,Saint Suzanne de Cap Blanc,Skeekeet,Uehllflit,Wellfleet,Willfleet,wlflyt  masachwst,Уэллфлит,ولفلیت، ماساچوست', 41.9376100, -70.0328000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139080, 'Wendell', 'Wendell', 'Wendell,Wendell Center', 42.5481400, -72.3967500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139081, 'Wenham', 'Wenham', 'Aenon,Enon,Salem Village,Vehnkham,Wenham,Wenham Centre,wnham  masachwst,Вэнхам,ونهام، ماساچوست', 42.6042600, -70.8911600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139082, 'West Boylston', 'West Boylston', 'Vehst Boulston,bwylstwn ghrby  masachwst,Вэст Боулстон,بویلستون غربی، ماساچوست', 42.3667600, -71.7856300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139083, 'West Bridgewater', 'West Bridgewater', 'Centre Village,Nunketest,Nunketetest,Vehst Bridzhuateh,West Bridgewater,West Bridgewater Centre,bryjwatr ghrby  masachwst,Вэст Бриджуатэ,بریجواتر غربی، ماساچوست', 42.0189900, -71.0078200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139084, 'West Chatham', 'West Chatham', '', 41.6812200, -69.9911300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139085, 'West Concord', 'West Concord', 'Concord Junction,Damon Dale,West Concord', 42.4584300, -71.3953400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139086, 'West Brookfield', 'West Brookfield', 'Vehst Brukfild,Vest Brukfild,Wekabaug,West Brookfield,brwkfyld ghrby  masachwst,Вест Брукфилд,Вэст Брукфилд,بروکفیلد غربی، ماساچوست', 42.2353700, -72.1411900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139087, 'West Dennis', 'West Dennis', '', 41.6645600, -70.1728000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139088, 'West Falmouth', 'West Falmouth', '', 41.6042700, -70.6344700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139089, 'West Newbury', 'West Newbury', 'Vehst N''jubari,nywbary ghrby  masachwst,Вэст Ньюбари,نیوباری غربی، ماساچوست', 42.8014800, -70.9897800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139090, 'West Springfield', 'West Springfield', 'Ireland,Vehst Springfild,Vest Springfild,West Springfield,aspryngfyld ghrby  masachwst,u~esutosupuringufirudo,wyst sbrynghfyld,xi si pu lin fei er de,Вест Спрингфилд,Вэст Спрингфилд,اسپرینگفیلد غربی، ماساچوست,ويست سبرينغفيلد,ویسٹ سپرنگفیلڈ، میساچوسٹس,ウェストスプリングフィールド,西斯普林菲尔德', 42.1070400, -72.6203700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139091, 'West Stockbridge', 'West Stockbridge', 'Indian Town,Queensborough,Vest Stokbridzh,West Stockbridge,astwkbryj ghrby  masachwst,Вест Стокбридж,استوکبریج غربی، ماساچوست', 42.3459200, -73.3662200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139092, 'West Tisbury', 'West Tisbury', 'MVY,Takemmy,Vest Tisburi,West Tisbury,tysbry ghrby  masachwst,Вест Тисбури,تیسبری غربی، ماساچوست', 41.3812200, -70.6744700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139093, 'West Wareham', 'West Wareham', 'Tremont,West Wareham', 41.7898300, -70.7603100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139094, 'West Yarmouth', 'West Yarmouth', 'West Yarmouth,West Yarmouth Village', 41.6501100, -70.2411300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139095, 'Westborough', 'Westborough', 'Vehst Borrou,Vestboro,Westboro,Westborough,Westborough Centre,wstbrw  masachwst,Вестборо,Вэст Борроу,وستبرو، ماساچوست', 42.2695400, -71.6161800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139096, 'Westfield', 'Westfield', 'Kee,Vehstfild,Vestfild,Warronoco,Westfield,Westfield Centre,u~esutofirudo,wei si te fei er de,weseuteupildeu,wstfyld  masachwst,Вестфилд,Вэстфилд,وستفیلد، ماساچوست,ウェストフィールド,韦斯特菲尔德,웨스트필드', 42.1250900, -72.7495400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139097, 'Westford', 'Westford', 'Westford,Westford Centre,weseuteupeodeu,wstfwrd  masachwst,وستفورد، ماساچوست,웨스트퍼드', 42.5792600, -71.4378400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139098, 'Westhampton', 'Westhampton', '', 42.3028700, -72.7745400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139099, 'Westminster', 'Westminster', 'Vehstminster,Westminster,Westminster Centre,wstmaynstr  masachwst,Вэстминстер,وستماینستر، ماساچوست', 42.5459200, -71.9106300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139100, 'Weston', 'Weston', 'The Farmers,Uehston,Weston,Weston Centre,wstwn  masachwst,Уэстон,وستون، ماساچوست', 42.3667600, -71.3031100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139101, 'Westwood', 'Westwood', 'Vehstvud,West Dedham,Westwood,wstwwd  masachwst,wystwwd,Вэствуд,وستوود، ماساچوست,ويستوود,ویسٹووڈ، میساچوسٹس', 42.2139900, -71.2245000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139102, 'Weweantic', 'Weweantic', '', 41.7353800, -70.7319800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139103, 'Weymouth', 'Weymouth', 'Uejmut,Vehjmaus,Vejmut,Wessagusset,Wessagussett,Weymouth,Weymouth Centre,u~eimasu,weimeoseu,wymawth,wymwt  masachwst,Вејмут,Вэймаус,Уеймът,ويماوث,ویماوتھ، میساچوسٹس,ویموت، ماساچوست,ウェイマス,웨이머스', 42.2209300, -70.9397700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139104, 'Whately', 'Whately', 'Whately,Whately Centre', 42.4398100, -72.6348100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139105, 'White Island Shores', 'White Island Shores', '', 41.8001000, -70.6347500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139106, 'Whitinsville', 'Whitinsville', 'Whitinsville,Whitinville', 42.1112100, -71.6661800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139107, 'Whitman', 'Whitman', 'Little Comfort,South Abington,South Abington Village,Vitman,Whitman,wytmn  masachwst,Витман,ویتمن، ماساچوست', 42.0806600, -70.9356000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139108, 'Wilbraham', 'Wilbraham', 'Springfield Mountains,Vilbrakham,Wilbraham,Wilbraham Centre,wylbrham  masachwst,Вилбрахам,ویلبرهام، ماساچوست', 42.1237100, -72.4314700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139109, 'Williamsburg', 'Williamsburg', 'Villiamsburg,wei lian si bao,wylyamzbrg  masachwst,Виллиамсбург,ویلمزبرگ، میساچوسٹس,ویلیامزبرگ، ماساچوست,威廉斯堡', 42.3931400, -72.7300900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139110, 'Williamstown', 'Williamstown', 'Uiljamstaun,Vilijamstaun,Villiamstaun,Williamstown,Willimston,wei lian si dui,willieomseutaun,wylyamztawn,wylyamztawn  masachwst,Вилијамстаун,Виллиамстаун,Уилямстаун,ولیمزٹاؤن، میساچوسٹس,ويليامزتاون,ویلیامزتاون، ماساچوست,威廉斯敦,윌리엄스타운', 42.7120200, -73.2037200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139111, 'Wilmington', 'Wilmington', 'Uilmington,Vilmington,Wilmington,Wilmington Center,u~iruminton,wylmyngtwn  masachwst,Вилмингтон,Уилмингтон,ویلمینگتون، ماساچوست,ویلمینگٹن، میساچوسٹس,ウィルミントン', 42.5464800, -71.1736700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139112, 'Winchendon', 'Winchendon', 'North Village,Vinchendon,Winchendon,wynchndwn  masachwst,Винчендон,وینچندون، ماساچوست', 42.6862000, -72.0439700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139113, 'Winchester', 'Winchester', 'Uinchester,Vinchester,wincheseuteo,wynchstr  masachwst,Винчестер,Уинчестер,ونچیسٹر، میساچوسٹس,وینچستر، ماساچوست,윈체스터', 42.4523200, -71.1370000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139114, 'Winthrop', 'Winthrop', 'Vinsrop,Vintrop,u~insuroppu,vinthropa,winseuleob,wyntrwp  masachwst,Винсроп,Винтроп,ونتھروپ، میساچوسٹس,وینتروپ، ماساچوست,विन्थ्रोप,ウィンスロップ,윈스럽', 42.3751000, -70.9828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139115, 'Woburn', 'Woburn', 'Central Village,Vubern,Woburn,Woburn Centre,Woburn Highland,Wooborne,uban,wobeon,wwbrn,wwbwrn  masachwst,Вуберн,ووبرن,ووبرن، میساچوسٹس,ووبورن، ماساچوست,ウーバン,워번', 42.4792600, -71.1522800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139116, 'Worcester', 'Worcester', 'Gorad Vustehr,Grafton Gore,ORH,Ouorster,Pakachoog,Uorsestehr,Ustur,Vigornia,Vuster,Vusteris,Worcester,Worcester i USA,useuteo,usuta,wrsstr,wu si te,wwstr,wwstr  masachwst,Ουόρστερ,Вустер,Горад Вустэр,Уорсестэр,Устър,ווסטר,ورسستر,ووستر، ماساچوست,ووسٹر، میساچوسٹس,ウースター,伍斯特,우스터', 42.2625900, -71.8022900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139117, 'Wrentham', 'Wrentham', 'Vrehnsam,Wrentham,Wrentham Centre,wrntham  masachwst,Врэнсам,ورنتهام، ماساچوست', 42.0667700, -71.3281100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139118, 'Yarmouth', 'Yarmouth', 'Jarmaus,Mattacheeset,Yarmouth,Yarmouth Village,yarmwt  masachwst,Ярмаус,یارموت، ماساچوست,یارموتھ، میسا چوسٹس', 41.7056700, -70.2286300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139119, 'Yarmouth Port', 'Yarmouth Port', 'Yarmouth Port,Yarmouthport', 41.7020500, -70.2494700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139120, 'Acton', 'Acton', 'Ehkshn,Ehkton,aktwn,aktwn  mayn,Эктон,Экшн,أكتون,اکتون، ماین,ایکٹن، مینے', 43.5342500, -70.9097800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139121, 'Addison', 'Addison', 'Ehddison,adyswn,adyswn  mayn,Эддисон,أديسون,ادیسون، ماین,ایڈسن، مینے', 44.6184100, -67.7441600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139122, 'Albion', 'Albion', 'Albion,Albion Corner', 44.5322900, -69.4425400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139123, 'Appleton', 'Appleton', '', 44.2892400, -69.2508800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139124, 'Arundel', 'Arundel', 'Arundel,Kennebunk Port,North Kennebunkport', 43.3825900, -70.4778300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139125, 'Auburn', 'Auburn', 'Auborn,Obern,Oburn,abrn  myn,ao ben,awbwrn,oban,obeon,Ауборн,Оберн,Обърн,آبرن، مینے,أوبورن,ابرن، مین,オーバーン,奧本,오번', 44.0978500, -70.2311700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139126, 'Augusta', 'Augusta', 'AUG,Aounkousta,Augusta,Cushnoc,Cusinock,Gorad Agasta,Harrington,Herringtown,Koussinock,Ogasta,Ogusta,The Fort,agasta,agwsta  myn,akasta,ao gu si ta,awghwsta,ke ge si ta,ogasta,ogasuta,ogeoseuta,Αουγκούστα,Аугуста,Горад Агаста,Огаста,Огъста,Օգաստա,אוגוסטה,آگسٹا، میئن,آگوستا، مین,أوغوستا,अगस्टा,अगस्ता,ऑगस्टा,অগাস্টা,அகஸ்தா,オーガスタ,奥古斯塔,柯格斯塔,오거스타', 44.3106200, -69.7794900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139127, 'Bangor', 'Bangor', 'BGR,Bangor,Bangur,Kenduskeag Plantation,Sunbury,baeng-go-eo,ban ge,bango,bangwr  myyn,banjwr,bngr  myn,Бангор,Бангър,Банґор,באנגאר,بانجور,بانگور، میئن,بنگر، مین,バンゴー,班戈,뱅고어', 44.8011800, -68.7778100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139128, 'Bar Harbor', 'Bar Harbor', 'BHB,Bar Harboras,Bar Kharbor,Bar Kharbur,bar harbr  myn,Бар Харбор,Бар Харбър,بار هاربر، مین', 44.3875800, -68.2039000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139129, 'Bath', 'Bath', 'Bat,Bath,Behz,Long Reach,Reach,Sagadahoc,The City of Ships,ba si,basu,bath,bth  myn,Бат,Бэз,باتھ، مینے,باث,بث، مین,バス,巴斯', 43.9106400, -69.8206000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139130, 'Belfast', 'Belfast', 'Belfast,bei er fa si te,berufasuto,blfast,blfst  myn,Белфаст,بلفاست,بلفست، مین,بیلفاسٹ، مینے,ベルファスト,贝尔法斯特', 44.4259100, -69.0064200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139131, 'Belgrade', 'Belgrade', 'Belgrehjd,Belgrejd,bylghrayd,Белгрејд,Белгрэйд,بيلغرايد', 44.4472900, -69.8325500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139132, 'Benton', 'Benton', 'Benton,Бентон', 44.5861800, -69.5508800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139133, 'Bethel', 'Bethel', 'Bezehl,Безэл', 44.4042300, -70.7906200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139134, 'Biddeford', 'Biddeford', 'Biddeford,Biddford,bi di fu de,bidefodo,bydfwrd,bydfwrd  myn,Биддефорд,Биддфорд,Біддефорд,بيدفورد,بیدفورد، مین,بیڈیفورڈ، میئن,ビデフォード,比迪福德', 43.4925800, -70.4533800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139135, 'Boothbay', 'Boothbay', 'Boothbay,Boothbay Center,Buzbehj,Newagen,North Boothbay,Townshend,Бузбэй', 43.8764700, -69.6336600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139136, 'Boothbay Harbor', 'Boothbay Harbor', '', 43.8523000, -69.6281000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139137, 'Bradford', 'Bradford', '', 45.0667300, -68.9378100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139138, 'Bradley', 'Bradley', '', 44.9209000, -68.6280900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139139, 'Brewer', 'Brewer', 'Brewer,Brewer Village,Brjua,Bru,brw  myn,brwyr  myyn,brywr,bu lu er,buruwa,Бру,Брюа,برو، مین,بروئر، میئن,بريور,ブルワー,布魯爾', 44.7967400, -68.7614200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139140, 'Bridgton', 'Bridgton', 'Bridgton,Bridgton Village,Bridzton,Pendleton Cove,brdgatn,burijjiton,Бриџтон,بردگاتن,بریجٹن، میئن,ブリッジトン', 44.0547900, -70.7128400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139141, 'Bristol', 'Bristol', 'Aldworth Town,Bristol,Bristol Mills,Bristol i Maine,Brsitol,Pemaquid,Брситол,برسٹل، مینے', 43.9575800, -69.5092100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139142, 'Brooks', 'Brooks', '', 44.5503500, -69.1208700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139143, 'Brownfield', 'Brownfield', 'Brownfield,Brownfield Centre', 43.9381300, -70.9086800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139144, 'Brownville', 'Brownville', '', 45.3070000, -69.0333700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139145, 'Brunswick', 'Brunswick', 'Bransuik,Bransvik,Braunshvejg,Brunsuik,Brunswick,NHZ,Pejebscot,Pejepscot,beuleonjeuwig,buranzuu~ikku,Брансвик,Брансвік,Брансуик,Брауншвейг,Брунсуик,برنزوک، مینے,ブランズウィック,브런즈윅', 43.9145200, -69.9653300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139146, 'Buckfield', 'Buckfield', '', 44.2895100, -70.3653400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139147, 'Bucksport', 'Bucksport', 'Baksport,Bucksport,Buckstown,bwksbwrt,bwkspwrt  myn,Бакспорт,بوكسبورت,بوکسپورت، مین', 44.5736900, -68.7955900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139148, 'Burnham', 'Burnham', 'Burnham,Burnham Junction', 44.6928400, -69.4275500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139149, 'Buxton', 'Buxton', 'Bakston,Buxton,Buxton United Methodist Church,Бакстон', 43.6378600, -70.5189400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139150, 'Calais', 'Calais', 'Calais,Kala,Kalais,Kallus,ka li si,kalys,karesu,kly  myn,Кала,Калаис,كاليس,کلی، مین,کیلئے، میئن,カレス,卡利斯', 45.1889600, -67.2786000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139151, 'Camden', 'Camden', 'Camden,Kamdehn,Kamden,Kehmden,Mada-Kamigosek,kamdn,Камден,Камдэн,Кэмден,كامدن,کیمڈن، مینے', 44.2098000, -69.0647600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139152, 'Canaan', 'Canaan', '', 44.7617300, -69.5614400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139153, 'Canton', 'Canton', '', 44.4408000, -70.3164900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139154, 'Cape Neddick', 'Cape Neddick', 'Cape Neddick,Cape Nuddike,Neddock Cape,Nedick Cape', 43.1937000, -70.6208900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139155, 'Caribou', 'Caribou', 'CAR,Caribou,Caribou Village,Karibou,Karibu,ka li bu,karibu,karybw,karybw  myyn,krbw  myn,Карибоу,Карибу,كاريبو,کاریبو، میئن,کربو، مین,カリブー,卡里布', 46.8606000, -68.0119700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139156, 'Castine', 'Castine', 'Biguyduce,Castine,Kadeskik*,Kastin,Machabitticus,Mesemadega,Mosemadage,Penobscot,Pentagoet,kastyn,kstyn  myn,Кастин,كاستين,کستین، مین', 44.3878500, -68.7997500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139157, 'Charleston', 'Charleston', 'Charlston,Чарлстон', 45.0850600, -69.0405900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139158, 'Chelsea', 'Chelsea', 'Chelsea,Winnisimet', 44.2503500, -69.7172700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139159, 'Cherryfield', 'Cherryfield', 'Cherryfield,Cherryfield Village', 44.6073000, -67.9258400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139160, 'Chesterville', 'Chesterville', '', 44.5511700, -70.0861700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139161, 'China', 'China', 'Chajna,China,China Village,tshayna,Чайна,تشاينا,چائنا، مینے', 44.4786800, -69.5172600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139162, 'Chisholm', 'Chisholm', 'Chisholm,Chisholm''s Mills', 44.4814500, -70.1995000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139163, 'Clinton', 'Clinton', 'Klinton,Клинтон', 44.6378400, -69.5031000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139164, 'Corinna', 'Corinna', '', 44.9211700, -69.2617100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139165, 'Cornish', 'Cornish', 'Cornish,Cornish Village,Kornish,kwrnysh,Корниш,كورنيش', 43.8048000, -70.8011700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139166, 'Cornville', 'Cornville', '', 44.8367300, -69.6731100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139167, 'Cumberland Center', 'Cumberland Center', 'Cumberland,Cumberland Center,Cumberland Centre', 43.7964700, -70.2589400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139168, 'Cushing', 'Cushing', '', 44.0192500, -69.2397700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139169, 'Damariscotta', 'Damariscotta', 'Damariscotta,Madamascontee', 44.0328600, -69.5186600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139170, 'Dedham', 'Dedham', '', 44.6917400, -68.6619800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139171, 'Deer Isle', 'Deer Isle', 'Deer Isle,Deer Isle Village,Dia Ajsl,dyr aysl,Диа Айсл,دير أيسل', 44.2239700, -68.6775300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139172, 'Denmark', 'Denmark', '', 43.9703500, -70.8034000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139173, 'Dexter', 'Dexter', 'Dekstehr,Dekster,dkstr  myn,dykstr,Декстер,Декстэр,ديكستر,دکستر، مین,ڈیکسٹر، مینے', 45.0239500, -69.2897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139174, 'Dixfield', 'Dixfield', '', 44.5339500, -70.4559000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139175, 'Dixmont', 'Dixmont', '', 44.6803500, -69.1628200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139176, 'Dover-Foxcroft', 'Dover-Foxcroft', 'Dover-Fokskroft,Dovur-Fokskroft,Duvehr-Fokskroft,duo fu-fu ke si ke luo fu te,Довер-Фокскрофт,Довър-Фокскрофт,Дувэр-Фокскрофт,ドーバー・フォックスクロフト,多佛-福克斯克罗夫特', 45.1833900, -69.2269900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139177, 'East Machias', 'East Machias', '', 44.7392400, -67.3899900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139178, 'East Millinocket', 'East Millinocket', '', 45.6275500, -68.5744800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139179, 'Easton', 'Easton', 'Iston,Истон', 46.6411500, -67.9094700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139180, 'Eastport', 'Eastport', 'Eastport,Island City,Istport,aystbwrt,aystpwrt  myn,dong gang,isutopoto,Истпорт,Իսթփորթ,إيستبورت,ایستپورت، مین,ایسٹپورٹ، میئن,イーストポート,東港', 44.9061900, -66.9899800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139181, 'Eddington', 'Eddington', '', 44.8261800, -68.6933700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139182, 'Edgecomb', 'Edgecomb', '', 43.9584100, -69.6306000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139183, 'Eliot', 'Eliot', 'Eliot,Eliot Depot', 43.1531400, -70.8000600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139184, 'Ellsworth', 'Ellsworth', 'Ehllsvors,Elsuurt,Elsvort,ai er si wo si,alswrth,alzwrth  myn,erusuwasu,Елсворт,Елсуърт,Эллсворс,إلسورث,الزورث، مین,ایلسورتھ، میئن,エルスワース,埃爾斯沃思', 44.5434100, -68.4194600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139185, 'Enfield', 'Enfield', '', 45.2489400, -68.5683600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139186, 'Etna', 'Etna', '', 44.8209000, -69.1111500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139187, 'Fairfield', 'Fairfield', 'Fairfield,Fajpfild,Ferfild,Feurfild,Kendall''s Mills,Файпфилд,Ферфилд,Феърфилд,فیئرفیلڈ، مین', 44.5884000, -69.5986600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139188, 'Falmouth', 'Falmouth', 'Falmaus,Falmouth,Falmut,Presumpscot Falls,Stogummor,farumasu,flmt  myn,Фалмаус,Фалмут,فالماوتھ، میئن,فلمت، مین,ファルマス', 43.7295300, -70.2419900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139189, 'Falmouth Foreside', 'Falmouth Foreside', '', 43.7348000, -70.2078300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139190, 'Farmingdale', 'Farmingdale', '', 44.2445100, -69.7714300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139191, 'Farmington', 'Farmington', 'Farmington,Фармингтон', 44.6706200, -70.1511700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139192, 'Fayette', 'Fayette', '', 44.4089600, -70.0336700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139193, 'Fort Fairfield', 'Fort Fairfield', 'Fort Ferfild,fwrt fyrfyld,Форт Ферфилд,فورت فيرفيلد', 46.7722700, -67.8339100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139194, 'Fort Kent', 'Fort Kent', 'Fort Kent,Fort-Kent,La Decharge*,fwrt kynt,Форт Кент,Форт-Кент,فورت كينت,فورٹ کینٹ، مینے', 47.2586500, -68.5894900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139195, 'Frankfort', 'Frankfort', 'Frankfurt,Франкфурт', 44.6098000, -68.8767000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139196, 'Franklin', 'Franklin', 'Franklin,Франклин', 44.5870200, -68.2322400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139197, 'Freeport', 'Freeport', 'Freeport,Friport,Harraseeket Settlement,frybwrt,Фрипорт,فريبورت,فری پورٹ، مینے', 43.8570200, -70.1031100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139198, 'Frenchville', 'Frenchville', 'Dickeyville,Frenchville,WFK', 47.2808700, -68.3797600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139199, 'Friendship', 'Friendship', 'Friendship,Meduncook Settlement', 43.9836900, -69.3339400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139200, 'Fryeburg', 'Fryeburg', 'FRY,Frajberg,Frajburg,Fryeburg,Фрайбург,Фрајберг', 44.0164600, -70.9806200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139201, 'Gardiner', 'Gardiner', 'Gardinehr,Gardiner,gadina,gardnr  myn,ghardynr,jia de na,Гардинер,Гардинэр,غاردينر,گاردنر، مین,گارڈنر، میئن,ガーディナー,加德納', 44.2300700, -69.7753200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139202, 'Garland', 'Garland', 'Girljanda,Гирлянда', 45.0384000, -69.1603200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139203, 'Gorham', 'Gorham', 'Goram,Gorem,Gorkham,Gorkhehm,Gorum,ghwrham,goramu,Горам,Горем,Горхам,Горхэм,Горъм,غورهام,گورہم، میئن,ゴーラム', 43.6795200, -70.4442200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139204, 'Gouldsboro', 'Gouldsboro', 'Gouldsboro,Gouldsborough,West Bay', 44.4784100, -68.0383400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139205, 'Greenbush', 'Greenbush', '', 45.0803400, -68.6508600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139206, 'Greene', 'Greene', 'Greene,Greene Village', 44.1897900, -70.1403300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139207, 'Greenville', 'Greenville', 'Grinvil,Grinvill,ghrynfyl,Гринвил,Гринвилл,غرينفيل,گرینویل، مینے', 45.4594900, -69.5906100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139208, 'Hallowell', 'Hallowell', 'Hallowell,Hallowell Hook,Khallouvehll,Khalovel,The Hook,ha luo wei er,halwwl,harou~eru,hlwwyl,Халлоувэлл,Халовел,هالوول,هلوويل,ہالوویل، میئن,ハロウェル,哈洛韋爾', 44.2859000, -69.7908800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139209, 'Hampden', 'Hampden', 'Hampden,Hampden Village,Khampden,hambdyn,hmpdn  myn,Хампден,هامبدين,همپدن، مین', 44.7445200, -68.8369800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139210, 'Hancock', 'Hancock', '', 44.5292400, -68.2536300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139211, 'Harpswell Center', 'Harpswell Center', 'Harpswell Center,Harpswell Centre', 43.8017500, -69.9842100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139212, 'Harrison', 'Harrison', 'Harrison,Harrison Village,Kharrison,haryswn,Харрисон,هاريسون', 44.1103500, -70.6792300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139213, 'Hartford', 'Hartford', 'Khartford,Хартфорд', 44.3728400, -70.3467300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139214, 'Hebron', 'Hebron', '', 44.1981300, -70.4064500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139215, 'Hermon', 'Hermon', 'Hermon,Hermon Corner,Hermon Village', 44.8100700, -68.9133700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139216, 'Hiram', 'Hiram', 'Hiram,Hiram Bridge,Hiram Village,Khiram,hyram,Хирам,هيرام', 43.8786800, -70.8034000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139217, 'Hodgdon', 'Hodgdon', 'Hodgdon,Hodgdon Village', 46.0539400, -67.8666800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139218, 'Holden', 'Holden', 'Holden,Holden Center,Holden Centre,Holder Center', 44.7528500, -68.6789200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139219, 'Hollis Center', 'Hollis Center', 'Hollis Center,Hollis Centre', 43.6050800, -70.5931100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139220, 'Houlton', 'Houlton', 'Goulton,Houlton,Houlton Village,Khjultun,Khoultan,Khoulton,horuton,huo er dun,Гоултон,Хоултан,Хоултон,Хюлтън,ホールトン,霍尔顿', 46.1261600, -67.8403000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139221, 'Howland', 'Howland', '', 45.2386700, -68.6636400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139222, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 45.0011800, -68.8805900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139223, 'Jay', 'Jay', 'Dzhehj,jay,Джэй,جاي', 44.5039500, -70.2161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139224, 'Jefferson', 'Jefferson', 'Dzhefferson,Джефферсон', 44.2067400, -69.4525400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139225, 'Jonesport', 'Jonesport', '', 44.5328600, -67.5983300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139226, 'Kenduskeag', 'Kenduskeag', 'Condeskeag,Kenduskeag,Kenduskeag Village', 44.9195100, -68.9317000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139227, 'Kennebunk', 'Kennebunk', 'Kenebank,Kennebank,Kennenbunk,kenebanku,kenebeongkeu,kynbwnk,kynybnk  myyn,Кенебанк,Кеннебанк,Кенненбунк,كينبونك,کینیبنک، میئن,ケネバンク,케네벙크', 43.3839700, -70.5447800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139228, 'Kennebunkport', 'Kennebunkport', 'Arundel,Cape Porpoise,Kenebankport,Kennebankport,Kennebunk Port,Kennebunkport,Kennenbunkport,ken na bang ke bo te,kynbwnkbwrt,Кенебанкпорт,Кеннебанкпорт,Кенненбункпорт,كينبونكبورت,肯纳邦克波特', 43.3617500, -70.4767200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139229, 'Kingfield', 'Kingfield', '', 44.9592200, -70.1539500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139230, 'Kittery Point', 'Kittery Point', 'Kittery Point,Kitterypoint,kytry pwynt  myn,کیتری پوینت، مین', 43.0834200, -70.7078300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139231, 'Kittery', 'Kittery', 'Chetere,Kettery,Kittehri,Kitteri,Kittery,kitari,Киттери,Киттэри,کٹیری، میئن,キタリー', 43.0881400, -70.7361600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139232, 'Lake Arrowhead', 'Lake Arrowhead', '', 43.6636900, -70.7347800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139233, 'Lebanon', 'Lebanon', 'Lebanon,Tow-woh,Towwoh', 43.3945300, -70.8508900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139234, 'Leeds', 'Leeds', 'Leeds,Leeds Center,Leeds Centre', 44.3034000, -70.1195000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139235, 'Levant', 'Levant', '', 44.8692400, -68.9347600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139236, 'Lewiston', 'Lewiston', 'L''juiston,Leviston,Luiston,Luistonas,Luistun,liu yi si dun,lwstn  myn,lwystwn,ruisuton,Левистон,Луистон,Луистън,Льюистон,لوستن، مین,لويستون,لیوئسٹں، میئن,ルイストン,刘易斯顿', 44.1003500, -70.2147800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139237, 'Limerick', 'Limerick', 'Lajmrik,lymryk  myn,Лаймрик,لیمریک، مین', 43.6884100, -70.7936700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139238, 'Limestone', 'Limestone', 'LIZ,Lajmstoun,lymstwn,Лајмстоун,ليمستون', 46.9086600, -67.8258500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139239, 'Limington', 'Limington', 'Limington,Лимингтон', 43.7317400, -70.7108900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139240, 'Lincoln', 'Lincoln', 'Linkol''n,Линкольн', 45.3622800, -68.5050200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139241, 'Lincolnville', 'Lincolnville', 'Lincolnville,Lincolnville Beach', 44.2811900, -69.0086500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139242, 'Lisbon', 'Lisbon', '', 44.0314600, -70.1045000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139243, 'Lisbon Falls', 'Lisbon Falls', 'Lisbon Falls,Little River', 43.9961900, -70.0606100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139244, 'Livermore', 'Livermore', 'Brettun''s Mill,Brettuns Mills,Livermore,Livermore Village,Livurmor,Ливърмор', 44.3839600, -70.2492200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139245, 'Livermore Falls', 'Livermore Falls', '', 44.4753400, -70.1881100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139246, 'Lovell', 'Lovell', 'Lovell,Lovell Village', 44.1267400, -70.8917300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139247, 'Machias', 'Machias', 'Machajas,Machias,Muchajus,ma chai e si,machaiasu,machyas  mayyny,matshyas,Мачајас,Мачиас,Мъчайъс,ماتشياس,ماچیاس، مائینی,マチャイアス,马柴厄斯', 44.7150800, -67.4613800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139248, 'Machiasport', 'Machiasport', 'Machasport,matshyasbwrt,Мачаспорт,ماتشياسبورت,ماچیاسپورٹ، مائینی', 44.6986900, -67.3947100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139249, 'Madawaska', 'Madawaska', 'Madavaska,Madavoska,madawaska,Мадаваска,Мадавоска,ماداواسكا,میڈاواسکا، مائینی', 47.3553200, -68.3217100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139250, 'Madawaska', 'Madawaska', '', 46.8842100, -67.9472500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139251, 'Madison', 'Madison', 'Madison,Madison Village,Мадисон', 44.7975600, -69.8797800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139252, 'Manchester', 'Manchester', 'Manchester,The Forks,Манчестер', 44.3245100, -69.8603300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139253, 'Mechanic Falls', 'Mechanic Falls', 'Bog Falls,Mechanic Falls,Mekhanik Fols,mykanyk fals,Механик Фолс,ميكانيك فالس', 44.1117400, -70.3917200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139254, 'Medway', 'Medway', 'Medway,Nicatow', 45.6089400, -68.5308600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139255, 'Mexico', 'Mexico', '', 44.5609000, -70.5453400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139256, 'Milbridge', 'Milbridge', 'Milbridge,Mill Bridge,Millbridge', 44.5353600, -67.8808300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139257, 'Milford', 'Milford', 'Milford,Милфорд', 44.9461800, -68.6439200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139258, 'Millinocket', 'Millinocket', 'MLT,Magic City,Milinoket,Milinokett,Milinokit,Millinocket,Millinockett,Millinoket,Millinokett,Shack Hill,mylynkwt,Милинокит,Миллинокет,ميلينكوت', 45.6572700, -68.7097600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139259, 'Milo', 'Milo', 'Majlo,Milo,Milo Village,mylw,Мајло,Мило,ميلو', 45.2536600, -68.9858700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139260, 'Minot', 'Minot', 'Mina,Мина', 44.0856300, -70.3200600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139261, 'Monmouth', 'Monmouth', 'Monmouth,Monmouth Center,Monmouth Village', 44.2386800, -70.0356100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139262, 'Mount Vernon', 'Mount Vernon', '', 44.5011800, -69.9875600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139263, 'New Gloucester', 'New Gloucester', 'N''ju Glousestehr,New Cloucester,New Gloucester,nyw ghlwysstr,Нью Глоусестэр,نيو غلويسستر', 43.9628500, -70.2825500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139264, 'New Sharon', 'New Sharon', 'New Sharon,Tyngstown,Unity', 44.6389500, -70.0156100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139265, 'Newport', 'Newport', 'N''juport,Ньюпорт', 44.8353400, -69.2739400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139266, 'Newfield', 'Newfield', 'N''jufild,nywfyld,Ньюфилд,نيوفيلد', 43.6481300, -70.8470100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139267, 'Nobleboro', 'Nobleboro', 'Nobleboro,Nobleborough', 44.0795200, -69.4850500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139268, 'Norridgewock', 'Norridgewock', 'Nanrantsouak,Narantsouk,Neriwocke,Noridzvok,Norridgewock,OWK,Нориџвок', 44.7131200, -69.7906100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139269, 'North Bath', 'North Bath', '', 43.9348000, -69.8158800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139270, 'North Berwick', 'North Berwick', 'Nors Bervik,Nort Bervik,Норс Бервик,Норт Бервик', 43.3037000, -70.7333900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139271, 'North Windham', 'North Windham', '', 43.8342400, -70.4383900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139272, 'Northport', 'Northport', '', 44.3378600, -68.9614200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139273, 'Norway', 'Norway', 'Norvehj,Norvej,Норвеј,Норвэй', 44.2139600, -70.5447800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139274, 'Oakland', 'Oakland', 'Oakland,Oklend,West Waterfield,Окленд', 44.5403400, -69.7219900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139275, 'Ogunquit', 'Ogunquit', 'Ogunkuajt,Ogunquit,Oqunquit Village,Огункуайт', 43.2489800, -70.5992200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139276, 'Old Orchard Beach', 'Old Orchard Beach', 'Old Ochard Bich,Old Orchard,Old Orchard Beach,Old-Orchard-Bich,Ould Orkhard Bich,awld archrd bych  myn,awld artshard,orudoochadobichi,Олд Очард Бич,Олд-Орчард-Бич,Оулд Орхард Бич,أولد أرتشارد,اولد ارچرد بیچ، مین,اولڈ آرچرڈ بیچ، میئن,オールドオーチャードビーチ', 43.5173100, -70.3775500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139277, 'Old Town', 'Old Town', 'Alnambi-i-menahan,Indian Oldtown,Negan odanak,Old Taun,Old Town,Oldtown,Ould Taun,Panoumke,ao er de dui,awld tawn,awld twn  myn,orudotaun,Олд Таун,Оулд Таун,أولد تاون,اولد تون، مین,اولڈ ٹاؤن، میئن,オールドタウン,奧爾德敦', 44.9342300, -68.6453100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139278, 'Orland', 'Orland', '', 44.5703500, -68.7358600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139279, 'Orono', 'Orono', 'Orono,awrwnw,awrwnw  myyn,orono,Ороно,أورونو,اورونو، میئن,オロノ', 44.8831200, -68.6719800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139280, 'Orrington', 'Orrington', '', 44.7311800, -68.8264300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139281, 'Owls Head', 'Owls Head', 'Owl''s Head,Owls Head,Owlshead', 44.0823000, -69.0572600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139282, 'Oxford', 'Oxford', 'Oksford,Oxford,Oxford Village,Оксфорд', 44.1317400, -70.4931100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139283, 'Palermo', 'Palermo', 'Branch Mills,Palermo', 44.4078500, -69.4739300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139284, 'Palmyra', 'Palmyra', '', 44.8464500, -69.3586600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139285, 'Paris', 'Paris', 'Paris,Paris Hill,Parizh,Peris,barys,pa li si,parisu,Париж,Парис,Перис,باريس,پیرس، مینے,パリス,帕里斯', 44.2597900, -70.5006200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139286, 'Parsonsfield', 'Parsonsfield', 'Parsonfield,Parsonsfield,Pehrsonsfild,barswnfyld,Пэрсонсфилд,بارسونفيلد', 43.7270200, -70.9286800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139287, 'Patten', 'Patten', '', 45.9964400, -68.4461400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139288, 'Penobscot', 'Penobscot', 'Panaobskak,Pembrocks Bay,Pennobscott,Penobscot,Penobscott,Pentagoet', 44.4645200, -68.7111400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139289, 'Peru', 'Peru', '', 44.5067300, -70.4053400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139290, 'Phippsburg', 'Phippsburg', 'Fippsburg,Phippsburg,Phippsburg Center,Phippsburg Village,Phippsburgh,Phipsburg,fybsbwrgh,Фиппсбург,فيبسبورغ', 43.8206400, -69.8147700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139291, 'Pittsfield', 'Pittsfield', '', 44.7825600, -69.3833800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139292, 'Pittston', 'Pittston', '', 44.2217400, -69.7556000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139293, 'Plymouth', 'Plymouth', 'Plimut,Плимут', 44.7672900, -69.2103300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139294, 'Poland', 'Poland', 'Polehnd,Полэнд', 44.0606300, -70.3936700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139295, 'Porter', 'Porter', '', 43.7959100, -70.9325600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139296, 'Portland', 'Portland', 'Casco,Elbow,Falmouth,Falmouth Neck,Gorad Portlend,Indigreat,Machegony,Machigonne,PWM,Portland,Portland i Maine,Portlandia,Portlant,Portlend,Portlenda,Quack,The Neck,Uh-kos-is-co,bo te lan,bwrtland,portalanda,portalyanda,poteullaendeu,potorando,pwrtlnd,pwrtlnd  myn,Πόρτλαντ,Горад Портленд,Портланд,Портленд,Փորթլենդ,פורטלנד,بورتلاند,ورٹلینڈ، مینے,پورتلند، مین,पोर्टलंड,পোর্টল্যান্ড,ポートランド,波特蘭,포틀랜드', 43.6614700, -70.2553300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139297, 'Presque Isle', 'Presque Isle', 'PQI,Presk Ajl,Presk-Ajl,Preskju Ajsl,bryskyw azly,peuleseukeuail,prsk ayl  myn,prysk ayl  myyn,pu lei si ke ai er,puresukuairu,Преск Ајл,Преск-Айл,Прескю Айсл,بريسكيو إزلي,پرسک آیل، مین,پریسک آئل، میئن,プレスクアイル,普雷斯克艾爾,프레스크아일', 46.6811500, -68.0158600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139298, 'Randolph', 'Randolph', 'Randol''f,Рандольф', 44.2303500, -69.7667100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139299, 'Raymond', 'Raymond', 'Rajmond,Раймонд,ریمنڈ، مینے', 43.9014600, -70.4703300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139300, 'Readfield', 'Readfield', 'Readfield,Readfield Corner', 44.3878500, -69.9667200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139301, 'Richmond', 'Richmond', 'Richmond,Ричмонд', 44.0873000, -69.7989300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139302, 'Rockport', 'Rockport', 'Rokport,Рокпорт,راکپورٹ، مینے', 44.1845200, -69.0761500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139303, 'Rome', 'Rome', 'Hungry Hollow,Rome', 44.5850600, -69.8692200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139304, 'Rumford', 'Rumford', 'Rumford,Rumford Falls', 44.5536700, -70.5509000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139305, 'Sabattus', 'Sabattus', 'Sabattus,Sebattis', 44.1198000, -70.1075500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139306, 'Saco', 'Saco', 'Saco,Sako,Sawaguatock,Sawco,Sawguatock,Shawacotoc,Shawakotock,Shawocotuck,sakw,sakw  myn,soko,suo ke,Сако,ساكو,ساکو، مین,سکو،مائنے,ソコー,索科', 43.5009200, -70.4428300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139307, 'Saint Albans', 'Saint Albans', '', 44.9100600, -69.4100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139308, 'Saint George', 'Saint George', 'Svjatoj Georgij,Святой Георгий', 44.0164700, -69.1989300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139309, 'Sanford', 'Sanford', 'Phillipstown,Sanford,Санфорд', 43.4392500, -70.7742200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139310, 'Sangerville', 'Sangerville', '', 45.1647800, -69.3564400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139311, 'Scarborough', 'Scarborough', 'Black Point,Scarboro,Scarborough,Skarboro,Skarborou,skarbwrw  myyn,sukaboro,Скарборо,Скарбороу,سکاربورو، میئن,スカボロー', 43.5781400, -70.3217200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139312, 'Searsmont', 'Searsmont', 'Fraternity Village,Searsmont', 44.3617400, -69.1950400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139313, 'Sedgwick', 'Sedgwick', '', 44.3036900, -68.6161400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139314, 'Shapleigh', 'Shapleigh', 'Shapleigh,Shapleigh Corner', 43.5406400, -70.8481200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139315, 'Sidney', 'Sidney', 'Sidnej,Сидней', 44.4131200, -69.7289300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139316, 'Skowhegan', 'Skowhegan', 'Milburn,Skaukhigun,Skovkhegan,Skowhegan,si ke xi gan,sukauhigan,Скаухигън,Сковхеган,سکاوہیگن، میئن,スカウヒーガン,斯科希甘', 44.7650600, -69.7192200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139317, 'South Berwick', 'South Berwick', 'Sous Bervik,Соус Бервик', 43.2345300, -70.8095000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139318, 'South Eliot', 'South Eliot', 'Eliot,South Eliot', 43.1081400, -70.7775500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139319, 'South Paris', 'South Paris', '', 44.2236800, -70.5133900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139320, 'South Portland', 'South Portland', 'Saut Portland,Saut-Portlend,Sous Portland,nan bo te lan,pwrtlnd jnwby  myn,sausupotorando,sawth bwrtland,Саут Портланд,Саут-Портленд,Соус Портланд,جنوبی پورٹلینڈ، مینے,ساوث بورتلاند,پورتلند جنوبی، مین,サウスポートランド,南波特兰', 43.6414700, -70.2408800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139321, 'South Portland Gardens', 'South Portland Gardens', 'Redbank,Redbank Village,South Portland Gardens', 43.6389700, -70.3153300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139322, 'South Sanford', 'South Sanford', '', 43.4111900, -70.7425600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139323, 'South Thomaston', 'South Thomaston', '', 44.0514700, -69.1278200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139324, 'South Windham', 'South Windham', 'Little Falls,South Windham', 43.7361900, -70.4236600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139325, 'Springvale', 'Springvale', '', 43.4667500, -70.7936700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139326, 'Steep Falls', 'Steep Falls', '', 43.7939700, -70.6525600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139327, 'Stetson', 'Stetson', '', 44.8917300, -69.1428200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139328, 'Steuben', 'Steuben', '', 44.5109800, -67.9666200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139329, 'Stockton Springs', 'Stockton Springs', 'Essick,Stockton Springs', 44.4895200, -68.8569800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139330, 'Stonington', 'Stonington', '', 44.1561900, -68.6666900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139331, 'Strong', 'Strong', '', 44.8075600, -70.2209000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139332, 'Sullivan', 'Sullivan', 'Sullivan,Sullivan Harbor', 44.5203600, -68.1966800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139333, 'Surry', 'Surry', '', 44.4959100, -68.5016900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139334, 'Swanville', 'Swanville', 'Goose Pond Settlement,Swanville', 44.5211900, -68.9978100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139335, 'Thomaston', 'Thomaston', 'Thomaston,Thomoston,Tomaston,Томастон', 44.0789700, -69.1817100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139336, 'Topsham', 'Topsham', '', 43.9275800, -69.9758800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139337, 'Tremont', 'Tremont', 'Mansel,Tremont', 44.2536900, -68.3514100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139338, 'Trenton', 'Trenton', 'Trenton,Трентон', 44.4389700, -68.3700200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139339, 'Troy', 'Troy', 'Bridgton,Joy,Kingsville,Montgomery,Troja,Troy,Troy Corner,Троя', 44.6647900, -69.2408800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139340, 'Turner', 'Turner', 'Turnehr,Turner,Turner Village,trnr  myn,Турнэр,ترنر، مین,ٹرنر، مین', 44.2564600, -70.2561700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139341, 'Van Buren', 'Van Buren', 'Ruisseau a Violettes,Van Bjurehn,Van Bjuren,Van Buren,fan bwrn,wn bwrn  myn,Ван Бюрен,Ван Бюрэн,Ван Бјурен,فان بورن,ون بورن، مین', 47.1572700, -67.9353000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139342, 'Vassalboro', 'Vassalboro', 'Vassalborou,bassaruboro,wslbrw  mynh,Вассалбороу,وسلبرو، مینه,バッサルボロ', 44.4592300, -69.6775500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139343, 'Veazie', 'Veazie', 'The Plains,Veazie', 44.8386800, -68.7053100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139344, 'Vinalhaven', 'Vinalhaven', 'Vinal Haven,Vinalhaven,Vinalkhavehn,Виналхавэн', 44.0481400, -68.8317000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139345, 'Waldoboro', 'Waldoboro', 'Valdoboro,Voldoboro,Waldoboro,Waldoborough,Валдоборо,Волдоборо', 44.0953600, -69.3756000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139346, 'Warren', 'Warren', 'Uorren,Уоррен', 44.1203600, -69.2400500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139347, 'Washington', 'Washington', 'Putnam,Vashington,Washington,Washington Village,Вашингтон', 44.2736900, -69.3672700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139348, 'Waterboro', 'Waterboro', 'Uatehrborou,Уатэрбороу', 43.5356400, -70.7150600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139349, 'Waterville', 'Waterville', 'Ticonic Falls,Uotervill,Vatehrvill,Votervil,Votervil'',WVL,Waterville,u~otabiru,watrwyl  myn,wo te wei er,woteobil,wwtrfyl,Ватэрвилл,Вотервил,Вотервіль,Уотервилл,واترویل، مین,واٹرویل، میئن,ووترفيل,ウォータービル,沃特维尔,워터빌', 44.5520100, -69.6317100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139350, 'Wayne', 'Wayne', '', 44.3486800, -70.0661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139351, 'Wells Beach Station', 'Wells Beach Station', 'Depot Station,Wells Beach Station', 43.3239700, -70.5914400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139352, 'West Paris', 'West Paris', '', 44.3242300, -70.5739500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139353, 'West Scarborough', 'West Scarborough', 'Alger Settlement,Dunstan,Dunstan Corner,Dunstan Village,Dunstan''s Corner,West Scarboro,West Scarborough', 43.5703600, -70.3878300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139354, 'Westbrook', 'Westbrook', 'Saccarabigg,Saccarrappa,Uehstbruk,Vehstbruk,Vestbruk,Westbrook,u~esutoburukku,wei si te bu lu ke,wstbrwk,wstbrwk  myn,Вестбрук,Вэстбрук,Уэстбрук,وستبروك,وستبروک، مین,ویسٹبروک، میئن,ウェストブルック,韦斯特布鲁克', 43.6770300, -70.3711600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139355, 'Whitefield', 'Whitefield', '', 44.1700700, -69.6253200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139356, 'Wilton', 'Wilton', 'Wilton,Wilton Village', 44.5928400, -70.2281200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139357, 'Windsor', 'Windsor', 'Malta,Vindzor,Windsor,Виндзор', 44.3106300, -69.5806000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139358, 'Winslow', 'Winslow', 'Taconnet,Uinslou,Vinslou,Winslow,u~insuro,wynzlww  myn,Винслоу,Уинслоу,وینزلوو، مین,وینسلو، مینے,ウィンスロー', 44.5470100, -69.6211600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139359, 'Winterport', 'Winterport', 'Winterport,Winterport Village', 44.6378500, -68.8450400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139360, 'Winthrop', 'Winthrop', 'Vintrop,Винтроп', 44.3050700, -69.9770000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139361, 'Wiscasset', 'Wiscasset', 'ISS,Uiskasit,Viskasseht,Wetchi sankasek,Wichigaskitaywick,Wiscasset,Wiscassett,u~isukasetto,wei si ka xi te,Вискассэт,Уискасит,ウィスカセット,威斯卡西特', 44.0028600, -69.6656000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139362, 'Woolwich', 'Woolwich', 'Nauseag,Nequasseag,Nequasseaq,Nequasset,Nequasset-settlement,Vulvich,Woolwich,Woolwich Village,Вулвич', 43.9186900, -69.8011600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139363, 'Yarmouth', 'Yarmouth', 'Jarmaus,Jarmaut,Pumgustuck,Yarmouth,Yarmouth Village,Yarmouthville,Yarmoutville,Јармаут,Ярмаус,یارموتھ، مہینے', 43.8006400, -70.1867200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139364, 'York Beach', 'York Beach', '', 43.1714800, -70.6089400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139365, 'York Harbor', 'York Harbor', '', 43.1367600, -70.6456100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139366, 'Adrian', 'Adrian', 'ADG,Adrian,Ejdrijan,adryan,adryan  myshygan,Адриан,Ејдријан,آدریان، میشیگان,أدريان,ایڈرین، مشی گن', 41.8975500, -84.0371700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139367, 'Albion', 'Albion', 'Albion,Ehlbion,albywn,albywn  mshy gn,albywn  myshygan,Албион,Элбион,آلبیون، مشی گن,آلبیون، میشیگان,ألبيون', 42.2431000, -84.7530300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139368, 'Algonac', 'Algonac', 'Algonac,Algonak,Manchester,Poine du Chene,a er ge na ke,alghwnak,algwnak  mshy gn,algwnak  myshygan,Алгонак,آلگوناک، میشیگان,ألغوناك,الگوناک، مشی گن,阿尔戈纳克', 42.6185800, -82.5323000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139369, 'Allegan', 'Allegan', 'Alegan,algan  myshygan,alghn,alygn  mshy gn,Алеган,آلگان، میشیگان,ألغن,الیگن، مشی گن', 42.5292000, -85.8553000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139370, 'Allen Park', 'Allen Park', 'Alen Park,Olehn Park,ai lun pa ke,alyn bark,alyn park  mshy gn,park aln  myshygan,Ален Парк,Олэн Парк,ألين بارك,الین پارک، مشی گن,پارک آلن، میشیگان,艾伦帕克', 42.2575400, -83.2110400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139371, 'Allendale', 'Allendale', '', 42.9722500, -85.9536500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139372, 'Alma', 'Alma', 'AMN,Alma,Ehlma,alma,alma  mshy gn,alma  myshygan,Алма,Элма,آلما، میشیگان,ألما,الما، مشی گن', 43.3789200, -84.6597300, 'US', '2017-06-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139373, 'Almont', 'Almont', '', 42.9205800, -83.0449300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139374, 'Alpena', 'Alpena', 'APN,Alpena,Alpina,a er pi na,albyna,alpna  mshy gn,alpna  myshygan,Алпена,Алпина,آلپنا، میشیگان,ألبينا,الپنا، مشی گن,ཨཱལ་པེ་ན།,阿尔皮纳', 45.0616800, -83.4327500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139375, 'Ann Arbor', 'Ann Arbor', 'A2,ARB,An Arboras,An Arbur,Ann Arbor,Ann Armpor,Ann-Arbor,Arbaro de Ana,Ehnn-Arbor,En Arbor,Enarbora,Enn Arbor,Enn-Arbor,Enārbora,aen-abeo,aena arbara,aina arbara,an arbr,an arbr  myshygan,an nuo bao,anaba,ayn arbr  mshy gn,en arpar,ena arbar,Ανν Άρμπορ,Ан Арбър,Анн-Арбор,Ен Арбор,Енн-Арбор,Энн-Арбор,אן ארבור,آن آربر,ان آربر، میشیگان,این آربر، مشی گن,अॅन आर्बर,ऍन आर्बर्,ऐन आर्बर,ஏன் ஆர்பர்,アナーバー,安娜堡,앤아버', 42.2775600, -83.7408800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139376, 'Argentine', 'Argentine', '', 42.7914200, -83.8463400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139377, 'Armada', 'Armada', 'Armada,Burk''s Corners,Honeoye', 42.8442000, -82.8843700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139378, 'Athens', 'Athens', '', 42.0886600, -85.2347100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139379, 'Atlanta', 'Atlanta', 'Atlanta,Атланта', 45.0047300, -84.1438900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139380, 'Au Sable', 'Au Sable', '', 44.4108500, -83.3321900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139381, 'Auburn', 'Auburn', '', 43.6033600, -84.0697000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139382, 'Auburn Hills', 'Auburn Hills', 'Auburn Khills,Obern Khils,Obern-Gills,Obern-Khills,Obern-Khils,Ompern Chils,ao ben shan,aparn hils,awbwrn hylz,obanhiruzu,Όμπερν Χιλς,Аубурн Хиллс,Оберн Хилс,Оберн-Гіллс,Оберн-Хиллс,Оберн-Хилс,آبرن ہلز، مشی گن,آوبرن‌هیلز، میشیگان,أوبورن هيلز,ஆபர்ன் ஹில்ஸ்,オーバーンヒルズ,奧本山', 42.6875300, -83.2341000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139383, 'Bad Axe', 'Bad Axe', 'Bed Aks,Behd Aks,bad aks,baddoakkusu,bdaks  myshygan,Бед Акс,Бэд Акс,باد إكس,بداکس، میشیگان,بیڈ ایکس، مشی گن,バッドアックス', 43.8019600, -83.0007800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139384, 'Baldwin', 'Baldwin', 'Bolduin,Болдуин', 43.9011200, -85.8517300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139385, 'Bangor', 'Bangor', 'Bangor,Бангор', 42.3125400, -86.1130800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139386, 'Baraga', 'Baraga', '', 46.7785400, -88.4890200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139387, 'Bath', 'Bath', '', 42.8186400, -84.4485900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139388, 'Battle Creek', 'Battle Creek', 'BTL,Batl Krik,Batul Krijk,Betl Krik,ba te er ke li ke,baeteulkeulikeu,batl kryk,batorukuriku,Батл Крик,Батъл Крийк,Бетл Крик,باتل كريك,بتل‌کریک، میشیگان,بیٹل کریک، مشی گن,バトルクリーク,巴特爾克里克,배틀크리크', 42.3173000, -85.1781600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139389, 'Bay City', 'Bay City', 'Bay City,Behj Siti,Beisitija,Bej Siti,Bej-Siti,Kota Bay,Lower Saginaw,bay syty,bei cheng,beishiti,beisiti,by syty  myshygan,Бей-Сити,Бей-Сіті,Беј Сити,Бэй Сити,Բեյ Սիթի,باي سيتي,بی سیتی، میشیگان,بے سیٹی، مشی گن,ベイシティ,贝城,베이시티', 43.5944700, -83.8888600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139390, 'Beaverton', 'Beaverton', '', 43.8822500, -84.4847300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139391, 'Beecher', 'Beecher', '', 43.0900300, -83.6944000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139392, 'Beechwood', 'Beechwood', '', 42.7969700, -86.1258800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139393, 'Belding', 'Belding', '', 43.0978100, -85.2289100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139394, 'Bellaire', 'Bellaire', 'ACB,Behllajr,Beler,bei lai er,bylayry,Белер,Бэллайр,بيلايري,贝莱尔', 44.9802800, -85.2111700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139395, 'Belleville', 'Belleville', '', 42.2047600, -83.4852100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139396, 'Bellevue', 'Bellevue', '', 42.4433700, -85.0180500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139397, 'Benton Harbor', 'Benton Harbor', 'BEH,Bemon Harbor,Benton Harbor,Benton Kharbor,bndr bntwn  myshygan,byntwn harbwr,Бентон Харбор,بندر بنتون، میشیگان,بينتون هاربور,بینٹن بندرگاہ، مشی گن', 42.1167100, -86.4541900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139398, 'Benton Heights', 'Benton Heights', '', 42.1311500, -86.4072400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139399, 'Berkley', 'Berkley', '', 42.5030900, -83.1835400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139400, 'Berrien Springs', 'Berrien Springs', 'Behrrien Springs,Berijen Springs,Berrien Spring,Berrien Springs,byryn sbrynghz,Беријен Спрингс,Бэрриен Спрингс,بيرين سبرينغز', 41.9464300, -86.3389000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139401, 'Bessemer', 'Bessemer', 'Behssemer,Besemer,bsmr  myshygan,bsymr,bysmr  mshy gn,Бесемер,Бэссемер,بسمر، میشیگان,بسيمر,بیسمر، مشی گن', 46.4813400, -90.0529500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139402, 'Beulah', 'Beulah', 'Beulah,Crystal City', 44.6319400, -86.0909200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139403, 'Beverly Hills', 'Beverly Hills', 'Bevurli Khils,Бевърли Хилс', 42.5239200, -83.2232600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139404, 'Big Rapids', 'Big Rapids', 'Big Rabbits Neck,Big Rapids,WBR,bygh rabydz,Биг Рапидс,بيغ رابيدز,بگ ریپڈز، مشی گن,بیگ‌رپیدز، میشیگان', 43.6980800, -85.4836600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139405, 'Bingham Farms', 'Bingham Farms', '', 42.5158700, -83.2732600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139406, 'Birch Run', 'Birch Run', '', 43.2508600, -83.7941300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139407, 'Birmingham', 'Birmingham', 'Bermingkham,Birmingem,Birmingkham,brmnghham,byrmngam  myshygan,Бермингхам,Бирмингем,Бирмингхам,برمنغهام,برمنگھم، مشی گن,بیرمنگام، میشیگان', 42.5467000, -83.2113200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139408, 'Blissfield', 'Blissfield', 'Blissfield,Blissville', 41.8325500, -83.8624400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139409, 'Bloomfield Hills', 'Bloomfield Hills', '', 42.5836400, -83.2454900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139410, 'Boyne City', 'Boyne City', 'Bojn Siti,Boyne,Boyne City,bwyn syty  myshygan,mdynt bwyn,Бойн Сити,Бојн Сити,بوئن سٹی، مشی گن,بوین سیتی، میشیگان,مدينة بوين', 45.2166800, -85.0139400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139411, 'Breckenridge', 'Breckenridge', '', 43.4080800, -84.4750000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139412, 'Bridgeport', 'Bridgeport', '', 43.3594700, -83.8816400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139413, 'Bridgman', 'Bridgman', 'Bridgeman,Bridgman', 41.9431000, -86.5569700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139414, 'Brighton', 'Brighton', 'Brajton,Брайтон', 42.5294800, -83.7802200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139415, 'Bronson', 'Bronson', '', 41.8722700, -85.1947000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139416, 'Brooklyn', 'Brooklyn', 'Bruklin,Бруклин', 42.1058700, -84.2482800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139417, 'Brown City', 'Brown City', '', 43.2122500, -82.9896600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139418, 'Brownlee Park', 'Brownlee Park', '', 42.3189300, -85.1424900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139419, 'Buchanan', 'Buchanan', 'B''jukenen,Bjukenan,Buchanan,Bukhanan,McCoy''s Creek,bwchanan  myshygan,bwkanan,bywkynn  mshy gn,Буханан,Бьюкенен,Бјукенан,بوكانان,بوچانان، میشیگان,بیوکینن، مشی گن', 41.8272700, -86.3611200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139420, 'Buena Vista', 'Buena Vista', '', 43.4203000, -83.8985800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139421, 'Burt', 'Burt', '', 43.2366900, -83.9063600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139422, 'Burton', 'Burton', 'Berton,bwrtwn  myshygan,byrtwn,Бертон,برٹن، مشی گن,بورتون، میشیگان,بيرتون', 42.9994700, -83.6163400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139423, 'Byron Center', 'Byron Center', '', 42.8122500, -85.7228100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139424, 'Cadillac', 'Cadillac', 'CAD,Cadillac,Kadilak,Kadillak,Little Clam,kadylak,kadylak  myshygan,kai di la ke,Кадилак,Кадиллак,كاديلاك,کادیلاک، میشیگان,کیڈیلاک، مشی گن,凯迪拉克', 44.2519500, -85.4011600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139425, 'Caledonia', 'Caledonia', 'Kaledonija,Каледония', 42.7892000, -85.5166900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139426, 'Canadian Lakes', 'Canadian Lakes', '', 43.5791900, -85.3017000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139427, 'Canton', 'Canton', '', 42.3086500, -83.4821600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139428, 'Capac', 'Capac', '', 43.0125300, -82.9279900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139429, 'Carleton', 'Carleton', '', 42.0592100, -83.3907700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139430, 'Caro', 'Caro', 'Caro,Karo,TZC,karw,karw  mshy gn,karw  myshygan,Каро,كارو,کارو، مشی گن,کارو، میشیگان', 43.4907300, -83.3988500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139431, 'Carrollton', 'Carrollton', '', 43.4586400, -83.9302500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139432, 'Carson City', 'Carson City', 'Karson-Siti,Карсон-Сити', 43.1769800, -84.8463900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139433, 'Cass City', 'Cass City', '', 43.6008500, -83.1746700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139434, 'Cassopolis', 'Cassopolis', 'Kasopolis,Kassopolis,kaswbwlys,Касополис,Кассополис,كاسوبوليس', 41.9117100, -86.0100100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139435, 'Cedar Springs', 'Cedar Springs', '', 43.2233600, -85.5514200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139436, 'Center Line', 'Center Line', 'Center,Center Line', 42.4850400, -83.0277000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139437, 'Centreville', 'Centreville', 'Centerville,Centreville', 41.9233800, -85.5283200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139438, 'Charlevoix', 'Charlevoix', 'Charlvojks,Sharlevoj,sha lei wo yi,sharlwwy  myshygan,tsharlyfwyks,Чарлвойкс,Шарлевој,تشارليفويكس,شارلووی، میشیگان,شارلے ووئی، مشی گن,沙勒沃伊', 45.3180600, -85.2584000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139439, 'Charlotte', 'Charlotte', 'Carmel,Charlotte,Eaton Centre,Sharlot,Sharlott,sharlwt,sharlwt  mshy gn,sharlwt  myshygan,Шарлот,Шарлотт,شارلوت,شارلوت، مشی گن,شارلوت، میشیگان', 42.5636500, -84.8358200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139440, 'Cheboygan', 'Cheboygan', 'Chebojgan,Shebojgan,shbwygan  myshygan,shybwghn,shybwyygn  mshy gn,Чебойган,Шебојган,شبویگان، میشیگان,شيبوغن,شیبوئیگن، مشی گن', 45.6469600, -84.4744800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139441, 'Chelsea', 'Chelsea', 'Chelsea,Chelsia', 42.3180700, -84.0218100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139442, 'Chesaning', 'Chesaning', '', 43.1847500, -84.1149700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139443, 'Clare', 'Clare', '', 43.8194700, -84.7686300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139444, 'Clarkston', 'Clarkston', 'Klarkston,Village of Clarkston,klarkstwn,klarkstwn  myshygan,Кларкстон,كلاركستون,کلارکستون، میشیگان,کلارکسٹن، مشی گن', 42.7358600, -83.4188300, 'US', '2010-02-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139445, 'Clawson', 'Clawson', '', 42.5333700, -83.1463200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139446, 'Clinton', 'Clinton', 'Klinton,Клинтон', 42.0719900, -83.9716100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139447, 'Clinton Township', 'Clinton Township', 'Charter Township of Clinton,Clinton Township', 42.5869800, -82.9199200, 'US', '2017-04-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139448, 'Clio', 'Clio', 'Clio,Varna', 43.1775300, -83.7341300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139449, 'Coldwater', 'Coldwater', 'Koldvoter,Koulduatehr,ke er de wo te,kwldwatr  myshygan,kwldwwtr,Колдвотер,Коулдуатэр,كولدووتر,کولدواتر، میشیگان,کولڈواٹر، مشی گن,科尔德沃特', 41.9403300, -85.0005200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139450, 'Coleman', 'Coleman', '', 43.7566900, -84.5858400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139451, 'Coloma', 'Coloma', '', 42.1861500, -86.3083600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139452, 'Colon', 'Colon', '', 41.9583800, -85.3249800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139453, 'Comstock Park', 'Comstock Park', '', 43.0386400, -85.6700300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139454, 'Concord', 'Concord', 'Concord,Konkord,Vanfossenville,Конкорд', 42.1778200, -84.6430200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139455, 'Constantine', 'Constantine', '', 41.8411600, -85.6686000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139456, 'Coopersville', 'Coopersville', '', 43.0639100, -85.9347700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139457, 'Corunna', 'Corunna', 'Korana,Korunna,kwrwna,kwrwna  mshy gn,kwrwna  myshygan,Корана,Корунна,كورونا,کورونا، مشی گن,کورونا، میشیگان', 42.9819700, -84.1177500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139458, 'Croswell', 'Croswell', '', 43.2755800, -82.6210400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139459, 'Crystal Falls', 'Crystal Falls', 'Kristal Fols,abshar krystal  myshygan,krystal fwlz,Кристал Фолс,آبشار کریستال، میشیگان,كريستال فولز,کرسٹل آبشار، مشی گن', 46.0980100, -88.3340200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139460, 'Cutlerville', 'Cutlerville', '', 42.8408600, -85.6636400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139461, 'Davison', 'Davison', '', 43.0347500, -83.5180100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139462, 'DeWitt', 'DeWitt', 'De Witt,DeWitt', 42.8422600, -84.5691500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139463, 'Dearborn', 'Dearborn', 'Dearborn,Dearbornville,Dirborn,Dirborna,Diurborn,Dīrborna,di er bo en,diabon,dieobon,diyaraborna,dyrbwrn,dyrbwrn  myshygan,Дирборн,Диърборн,Дірборн,דירבורן,ديربورن,دیربورن، میشیگان,ڈئربورن، مشی گن,डीयरबॉर्न,ディアボーン,迪尔伯恩,디어본', 42.3222600, -83.1763100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139464, 'Dearborn Heights', 'Dearborn Heights', 'Dirborn Khajts,Dirborn Khehjts,dyrbwrn hayts,Дирборн Хајтс,Дирборн Хэйтс,ديربورن هايتس,دیربورن‌هایتس، میشیگان,ڈئربورن ہائٹس، مشی گن', 42.3369800, -83.2732600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139465, 'Decatur', 'Decatur', 'Dekejter,Декейтер', 42.1081000, -85.9744600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139466, 'Detroit', 'Detroit', 'D-town,DTT,Detroit,Detroita,Detroitas,Detroitum,Detrojt,Detrojto,Detroyt,Détroit,Détroyt,Gorad Dehtrojt,Mo-Town,Motor City,Motown,Ntitroit,The D,Tiughsaghrondy,Tsi kiohsahron:ta,Tsi kiohsahrón:ta,Wawyachtenok,detoroito,detra''ita,detrayeta,detrayit,detro''ita,detʼroitʼi,di te lu,di thrx yt,ditara''ita,diteuloiteu,dtrwyt,dytrwyt,titrayit,Ντιτρόιτ,Горад Дэтройт,Детроит,Детройт,Դետրոյթ,דטרויט,דעטרויט,ديترويت,دیترویت,ڈیٹرائٹ,डेट्राइट,डेट्रॉईट,ডেট্রয়েট,ਡਿਟਰਾਇਟ,டிட்ராயிட்,డెట్రాయిట్,ดีทรอยต์,დეტროიტი,ዲትሮይት,デトロイト,底特律,디트로이트', 42.3314300, -83.0457500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139467, 'Detroit Beach', 'Detroit Beach', '', 41.9311600, -83.3268800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139468, 'Dexter', 'Dexter', '', 42.3383400, -83.8895400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139469, 'Dimondale', 'Dimondale', 'Diamondale,Dimondale', 42.6455900, -84.6488700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139470, 'Dollar Bay', 'Dollar Bay', '', 47.1196500, -88.5115100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139471, 'Douglas', 'Douglas', 'Daglas,Duglas,daglas  myshygan,dwghlas,Даглас,Дуглас,داگلاس، میشیگان,دوغلاس,ڈگلس، مشی گن', 42.6433600, -86.2005900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139472, 'Dowagiac', 'Dowagiac', '', 41.9842100, -86.1086200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139473, 'Dundee', 'Dundee', '', 41.9572700, -83.6596600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139474, 'Durand', 'Durand', '', 42.9119800, -83.9846800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139475, 'Eagle River', 'Eagle River', '', 47.4138100, -88.2956600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139476, 'East Grand Rapids', 'East Grand Rapids', 'Ist Grand Rapids,ayst ghrand rabydz,grndrpydz shrqy  myshygan,Ист Гранд Рапидс,إيست غراند رابيدز,مشرقی گرینڈ ریپڈ، مشی گن,گرندرپیدز شرقی، میشیگان', 42.9411400, -85.6100300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139477, 'East Jordan', 'East Jordan', '', 45.1580600, -85.1242300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139478, 'East Lansing', 'East Lansing', 'Ist Lansing,Ist-Lansing,ayst lansngh,dong lan xin,iseuteulaensing,isutoranshingu,lnsyng shrqy  myshygan,mshrqy lynsng  mshy gn,Ист Лансинг,Ист-Лансинг,إيست لانسنغ,لنسینگ شرقی، میشیگان,مشرقی لینسنگ، مشی گن,イーストランシング,东兰辛,이스트랜싱', 42.7369800, -84.4838700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139479, 'East Tawas', 'East Tawas', 'ECA', 44.2794600, -83.4902500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139480, 'Eastpointe', 'Eastpointe', 'East Detroit,Eastpointe,Istpojnt,aystbwynt,Истпойнт,Истпојнт,إيستبوينت,ایست‌پوینت، میشیگان,ایسٹ پوائنٹ، مشی گن', 42.4683700, -82.9554700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139481, 'Eastwood', 'Eastwood', '', 42.3031000, -85.5502800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139482, 'Eaton Rapids', 'Eaton Rapids', 'Iton Rapids,aytwn rabydz,yi dun la pi de,Итон Рапидс,إيتون رابيدز,ایتون‌رپیدز، میشیگان,ایٹن ریپڈز، مشی گن,伊頓拉皮德', 42.5092000, -84.6558100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139483, 'Ecorse', 'Ecorse', 'Ecorce,Ecorces,Ecorse,Ehkors,Ikors,River aux Ecorces,ai ke si,akrws,aykrwz  myshygan,aykwrs  mshy gn,Икорс,Экорс,إكروس,ایکروز، میشیگان,ایکورس، مشی گن,埃科斯', 42.2444800, -83.1457600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139484, 'Edgemont Park', 'Edgemont Park', '', 42.7467000, -84.5935900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139485, 'Edmore', 'Edmore', '', 43.4080900, -85.0386300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139486, 'Edwardsburg', 'Edwardsburg', '', 41.7956000, -86.0808400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139487, 'Elk Rapids', 'Elk Rapids', 'Ehlk Rapids,Elk Rapids,Stevens,alk rabyds,Елк Рапидс,Элк Рапидс,إلك رابيدس', 44.8955600, -85.4164600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139488, 'Escanaba', 'Escanaba', 'ESC,Ehskanaba,Escanaba,Esconawba,Eskanaba,askanaba,askanaba  myshygan,skanaba  mshy gn,Есканаба,Эсканаба,إسكانابا,اسکانابا، میشیگان,سکانابا، مشی گن', 45.7452500, -87.0645800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139489, 'Essexville', 'Essexville', '', 43.6153000, -83.8419200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139490, 'Evart', 'Evart', '', 43.9005800, -85.2581000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139491, 'Fair Plain', 'Fair Plain', '', 42.0869900, -86.4558600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139492, 'Farmington', 'Farmington', 'Farmington,farmnghtwn,farmyngtwn  myshygan,Фармингтон,فارمنغتون,فارمنگٹن، مشی گن,فارمینگتون، میشیگان', 42.4644800, -83.3763200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139493, 'Farmington Hills', 'Farmington Hills', '', 42.4853100, -83.3771600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139494, 'Fennville', 'Fennville', '', 42.5939200, -86.1017000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139495, 'Fenton', 'Fenton', 'Fenton,Фентон', 42.7978100, -83.7049500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139496, 'Ferndale', 'Ferndale', 'Ferndejl,frndal  myshygan,fyrndal,Ферндејл,فرندال، میشیگان,فرینڈیل، مشی گن,فيرندال', 42.4605900, -83.1346500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139497, 'Ferrysburg', 'Ferrysburg', '', 43.0844600, -86.2203300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139498, 'Flat Rock', 'Flat Rock', 'Flat Rock,Flat Rok,Smooth Rock,flat rwk,Флат Рок,فلات روك,فلت‌راک، میشیگان,فلیٹ راک، مشی گن', 42.0964300, -83.2918700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139499, 'Flint', 'Flint', 'FNT,Flint,Siti of Flint,flynt,flynt  myshygan,fu lin te,furinto,peullinteu,plynt,Сити оф Флинт,Флинт,Флінт,פלינט,فلنٹ، مشی گن,فلينت,فلینت، میشیگان,フリント,弗林特,플린트', 43.0125300, -83.6874600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139500, 'Flushing', 'Flushing', '', 43.0630800, -83.8510700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139501, 'Forest Hills', 'Forest Hills', '', 42.9594700, -85.4897500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139502, 'Fowler', 'Fowler', '', 43.0017000, -84.7397200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139503, 'Fowlerville', 'Fowlerville', '', 42.6605900, -84.0730100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139504, 'Frankenmuth', 'Frankenmuth', 'Frankenmut,Siti of Frankenmus,frankmwnth  myshygan,frankynmwth,Сити оф Франкенмус,Франкенмут,فرانكينموث,فرانکمونث، میشیگان,فرینکن مٹھ، مشی گن', 43.3316900, -83.7380200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139505, 'Frankfort', 'Frankfort', 'Frankfurt,Франкфурт', 44.6336100, -86.2345400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139506, 'Franklin', 'Franklin', 'Franklin,Franklin Village,Франклин', 42.5222600, -83.3060400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139507, 'Fraser', 'Fraser', '', 42.5392000, -82.9493700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139508, 'Freeland', 'Freeland', '', 43.5250300, -84.1227600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139509, 'Fremont', 'Fremont', 'Frimont,Фримонт', 43.4675200, -85.9420000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139510, 'Fruitport', 'Fruitport', '', 43.1319600, -86.1547800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139511, 'Galesburg', 'Galesburg', '', 42.2886500, -85.4180600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139512, 'Garden City', 'Garden City', 'Garden Siti,gardn syty  myshygan,ghardn syty,Гарден Сити,غاردن سيتي,گاردن سیتی، میشیگان,گارڈن سٹی، مشی گن', 42.3255900, -83.3310400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139513, 'Gaylord', 'Gaylord', 'GLR,Gaylord,Gehjlord,Gejlord,Гејлорд,Гэйлорд', 45.0275100, -84.6747500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139514, 'Gibraltar', 'Gibraltar', 'Dzibroltar,Gibraltar,Gibralter,gybraltar  myshygan,jbl tarq,Џибролтар,Гибралтар,جبرالٹر، مشی گن,جبل طارق,گیبرالتار، میشیگان', 42.0950400, -83.1896500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139515, 'Gladstone', 'Gladstone', 'Gladston,Gladstoun,Gledston,ghladstwn,gladstwn  myshygan,Гладстон,Гладстоун,Гледстон,غلادستون,گلادستون، میشیگان,گلیڈسٹون، مشی گن', 45.8527400, -87.0218000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139516, 'Gladwin', 'Gladwin', 'GDW', 43.9808500, -84.4864000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139517, 'Goodrich', 'Goodrich', '', 42.9169700, -83.5063400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139518, 'Grand Blanc', 'Grand Blanc', 'Grand Blank,ghrand blank,grndblans  myshygan,Гранд Бланк,غراند بلانك,گرندبلانس، میشیگان,گرینڈ بلانک، مشی گن', 42.9275300, -83.6299500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139519, 'Grand Haven', 'Grand Haven', 'Grand Khehjven,Grand Khejven,ge lan de gang,ghrand hyfn,grndhywn  myshygan,Гранд Хејвен,Гранд Хэйвен,غراند هيفن,گرندهیون، میشیگان,گرینڈ ہیون، مشی گن,格蘭德港', 43.0630700, -86.2283900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139520, 'Grand Ledge', 'Grand Ledge', '', 42.7533700, -84.7463800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139521, 'Grand Rapids', 'Grand Rapids', 'GRR,Gorad Grand-Rapids,Grand Rapids,Grand Rapidsas,Grand-Rapids,Grend-Repids,da ji liu cheng,geulaendeulaepijeu,gramda repidsa,grndrpydz  myshygan,gurandorapizzu,Горад Гранд-Рапідс,Гранд Рапидс,Гранд-Рапидс,Гренд-Репідс,גרנד ראפידס,گرندرپیدز، میشیگان,ग्रँड रॅपिड्स,ᒥᓯ ᐹᐗᔅᑎᒃ,グランドラピッズ,大急流城,그랜드래피즈', 42.9633600, -85.6680900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139522, 'Grandville', 'Grandville', '', 42.9097500, -85.7630900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139523, 'Grass Lake', 'Grass Lake', '', 42.2508700, -84.2130100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139524, 'Grayling', 'Grayling', 'Grehjling,Grejling,ghraylyngh,grylyng  myshygan,Грејлинг,Грэйлинг,غرايلينغ,گریلینگ، میشیگان', 44.6614000, -84.7147500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139525, 'Greenville', 'Greenville', 'Grinvill,Гринвилл', 43.1775300, -85.2528000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139526, 'Greilickville', 'Greilickville', 'Greilickville,Rennies Station', 44.7830600, -85.6386900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139527, 'Grosse Ile', 'Grosse Ile', '', 42.1292100, -83.1443700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139528, 'Grosse Pointe', 'Grosse Pointe', 'Grosse Point,Grosse Pointe,Grossepointe,Grosspoint,Grous Pojnt,ghrws bwynt,Гроус Појнт,غروس بوينت', 42.3861500, -82.9118600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139529, 'Grosse Pointe Farms', 'Grosse Pointe Farms', 'Gross Pojnte Farms,Grous Pojnt Farms,ghrws bwynt farmz,Гросс Пойнте Фармс,Гроус Појнт Фармс,غروس بوينت فارمز,گراس‌پوینت‌فارمز، میشیگان', 42.4092000, -82.8918600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139530, 'Grosse Pointe Park', 'Grosse Pointe Park', 'Gross Pojnte Park,Grous Pojnt Park,ghrws bwynt bark,Гросс Пойнте Парк,Гроус Појнт Парк,غروس بوينت بارك,گراس‌پوینت، میشیگان', 42.3758700, -82.9374200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139531, 'Grosse Pointe Shores', 'Grosse Pointe Shores', '', 42.4367000, -82.8768600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139532, 'Grosse Pointe Woods', 'Grosse Pointe Woods', '', 42.4436500, -82.9068600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139533, 'Gwinn', 'Gwinn', '', 46.2810600, -87.4409700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139534, 'Hamtramck', 'Hamtramck', 'Gemtremk,Khamtramik,haimatraimaka,hamtramyk,hematramika,Гемтремк,Хамтрамик,هامتراميك,ہیمٹرامک، مشی گن,হেমট্রামিক,ਹੈਮਟ੍ਰੈਮਕ', 42.3928200, -83.0496400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139535, 'Hancock', 'Hancock', 'CMX,Khankok,Khenkok,hankwk,hnkak  myshygan,Ханкок,Хенкок,هانكوك,هنکاک، میشیگان', 47.1268700, -88.5809600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139536, 'Harbor Beach', 'Harbor Beach', 'Harbor Beach,Harbor of Refuge,Sand Beach', 43.8447400, -82.6513200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139537, 'Harbor Springs', 'Harbor Springs', '', 45.4316800, -84.9920000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139538, 'Harper Woods', 'Harper Woods', 'Kharper Vuds,harbr wwdz,harprwwdz  myshygan,Харпер Вудс,هاربر وودز,هارپروودز، میشیگان', 42.4330900, -82.9240800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139539, 'Harrison', 'Harrison', 'Kharrison,Харрисон', 44.0191900, -84.7994700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139540, 'Harrisville', 'Harrisville', 'Kharisvil,Kharrisvill,harysfyl,hryswyl  myshygan,Харисвил,Харрисвилл,هاريسفيل,هریسویل، میشیگان', 44.6564000, -83.2946900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139541, 'Hart', 'Hart', '', 43.6983400, -86.3639700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139542, 'Hartford', 'Hartford', 'Khartford,Хартфорд', 42.2067100, -86.1666900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139543, 'Harvey', 'Harvey', 'Kharvi,Харви', 46.4946600, -87.3543100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139544, 'Haslett', 'Haslett', '', 42.7469800, -84.4010800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139545, 'Hastings', 'Hastings', 'Hasting,Hastings,Khastings,Khejstings,hastynghz,hstyngz  myshygan,Хастингс,Хейстингс,Хејстингс,هاستينغز,هستینگز، میشیگان', 42.6458700, -85.2908400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139546, 'Hazel Park', 'Hazel Park', '', 42.4625400, -83.1040900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139547, 'Hemlock', 'Hemlock', '', 43.4147500, -84.2305400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139548, 'Highland Park', 'Highland Park', 'Gajlend-Park,Khajland Park,Khajlend Park,Khajlend-Park,haillaendeupakeu,hayland bark,haylndpark  myshygan,Гайленд-Парк,Хайленд Парк,Хайленд-Парк,Хајланд Парк,هايلاند بارك,هایلندپارک، میشیگان,하일랜드파크', 42.4055900, -83.0968700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139549, 'Hillsdale', 'Hillsdale', '', 41.9200500, -84.6305100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139550, 'Holland', 'Holland', 'Gollandija,HLM,Holland,Kholand,Kholland,Misi-pawastik,Misi-páwastik,hlnd  myshygan,hollaendeu,hwland,Голландия,Холанд,Холланд,هلند، میشیگان,هولاند,ہالینڈ، مشی گن,홀랜드', 42.7875200, -86.1089300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139551, 'Holly', 'Holly', '', 42.7919700, -83.6277300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139552, 'Holt', 'Holt', '', 42.6405900, -84.5152500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139553, 'Homer', 'Homer', '', 42.1458800, -84.8088600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139554, 'Houghton', 'Houghton', 'Khauton,Khoton,Khoutun,hatn  myshygan,hwtwn,Хаутон,Хотон,Хоутън,هاتن، میشیگان,هوتون', 47.1218700, -88.5690100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139555, 'Houghton Lake', 'Houghton Lake', 'HTL,Houghton Lake', 44.3147400, -84.7647500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139556, 'Howard City', 'Howard City', '', 43.3955800, -85.4678200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139557, 'Howell', 'Howell', '', 42.6072600, -83.9294000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139558, 'Hubbard Lake', 'Hubbard Lake', '', 44.7597300, -83.5444200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139559, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 41.8550500, -84.3538400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139560, 'Hudsonville', 'Hudsonville', 'Khadsonvil,Khadsonvill,hadswnwyl  myshygan,hdswnfyl,heodeuseunbil,Хадсонвил,Хадсонвилл,هادسونویل، میشیگان,هدسونفيل,허드슨빌', 42.8708600, -85.8650400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139561, 'Huntington Woods', 'Huntington Woods', '', 42.4805900, -83.1668700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139562, 'Imlay City', 'Imlay City', 'Imlehj Siti,Imlej Siti,amly syty,aymaly syty  myshygan,Имлеј Сити,Имлэй Сити,إملي سيتي,ایمالی سیتی، میشیگان', 43.0247500, -83.0777200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139563, 'Indian River', 'Indian River', '', 45.4125100, -84.6125400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139564, 'Ionia', 'Ionia', 'Ajonija,Ionia,Ionia Centre,Lonia,aywnya,aywnya  myshygan,Айония,Ајонија,Лониа,آیونیا، میشیگان,إيونيا', 42.9872500, -85.0711200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139565, 'Iron Mountain', 'Iron Mountain', 'IMT', 45.8202300, -88.0659600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139566, 'Iron River', 'Iron River', 'Ajron Riveh,Ajron River,ayrwn ryfr,Айрон Ривэ,Ајрон Ривер,آیرون‌ریور، میشیگان,أيرون ريفر', 46.0927300, -88.6423500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139567, 'Ironwood', 'Ironwood', 'Ajron Vud,Ajronvud,IWD,Ironwood,Maananoonsing,ayrwnwwd,Айрон Вуд,Ајронвуд,آیرون‌وود، میشیگان,أيرونوود', 46.4546700, -90.1710100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139568, 'Ishpeming', 'Ishpeming', 'Ishpeming,ashbymyngh,ayshpmyng  myshygan,Ишпеминг,إشبيمينغ,ایشپمینگ، میشیگان', 46.4885500, -87.6676400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139569, 'Ithaca', 'Ithaca', 'Itak,Itaka,Izaka,aytaka  myshygan,aythaka,isaka,Изака,Итак,Итака,إيثاكا,ایتاکا، میشیگان,イサカ', 43.2917000, -84.6075000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139570, 'Jackson', 'Jackson', 'Dzekson,Dzhehkson,Dzhekson,JXN,Jackson,Jacksonburg,Jacksonopolis,jakswn,jakuson,jkswn  myshygan,jyksn  mshy gn,Џексон,Джексон,Джэксон,جاكسون,جکسون، میشیگان,جیکسن، مشی گن,ジャクソン', 42.2458700, -84.4013500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139571, 'Jenison', 'Jenison', '', 42.9072500, -85.7919800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139572, 'Jonesville', 'Jonesville', '', 41.9842100, -84.6619000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139573, 'Kalamazoo', 'Kalamazoo', 'AZO,Bronson,Kalamazoo,Kalamazu,Kalamazū,ka la ma zu,kaelleomeoju,kalamazw,kalamazw  mshy gn,kalamzw  myshygan,karamazu,Каламазу,קאלאמאזו,كالامازو,کالامازو، مشی گن,کالامزو، میشیگان,カラマズー,卡拉马祖,캘러머주', 42.2917100, -85.5872300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139574, 'Kalkaska', 'Kalkaska', 'Kalkaska,kalkasa,Калкаска,كالكاسا', 44.7341700, -85.1758900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139575, 'Keego Harbor', 'Keego Harbor', '', 42.6080900, -83.3438200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139576, 'Kent City', 'Kent City', '', 43.2200200, -85.7511500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139577, 'Kentwood', 'Kentwood', 'Kentvud,kenteuudeu,kntwwd  myshygan,kyntwwd,Кентвуд,كينتوود,کنتوود، میشیگان,کینٹووڈ، مشی گن,켄트우드', 42.8694700, -85.6447500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139578, 'Kilmanagh', 'Kilmanagh', '', 43.7561300, -83.3569000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139579, 'Kingsford', 'Kingsford', 'Kingsford,kynghzfwrd,kyngzfwrd  myshygan,Кингсфорд,كينغزفورد,کینگزفورد، میشیگان', 45.7949600, -88.0720700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139580, 'Kingsley', 'Kingsley', '', 44.5847300, -85.5359000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139581, 'L''Anse', 'L''Anse', '', 46.7566000, -88.4529100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139582, 'Laingsburg', 'Laingsburg', '', 42.8903100, -84.3513600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139583, 'Lake City', 'Lake City', '', 44.3352900, -85.2150500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139584, 'Lake Fenton', 'Lake Fenton', '', 42.8461400, -83.7077300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139585, 'Lake Michigan Beach', 'Lake Michigan Beach', 'Hagar Shores,Lake Michigan Beach', 42.2208700, -86.3694700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139586, 'Lake Odessa', 'Lake Odessa', '', 42.7847600, -85.1383400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139587, 'Lake Orion', 'Lake Orion', '', 42.7844800, -83.2396600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139588, 'Lakeview', 'Lakeview', '', 42.2983800, -85.2111000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139589, 'Lakeview', 'Lakeview', '', 43.4464200, -85.2742000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139590, 'Lakewood Club', 'Lakewood Club', '', 43.3711200, -86.2603400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139591, 'Lambertville', 'Lambertville', '', 41.7658800, -83.6279900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139592, 'Lansing', 'Lansing', 'Gorad Lansing,LAN,Lansin''nk,Lansing,Lansinga,Lansingas,Lansings,Lehnsing,Lensing,laensing,lan xin,lancin,lansin,lansina,lansinga,lansng,lansng  mshy gn,lansngh,lnsyng,lnsyng  myshygan,lyansinga,ranshingu,Λάνσινγκ,Горад Лансінг,Лансинг,Ленсинг,Лэнсинг,Լանսինգ,לאנסינג,لانسنغ,لانسنگ,لانسنگ، مشی گن,لنسینگ,لنسینگ، میشیگان,लान्सिंग,लान्सिङ,लान्सिङ्,ल्यान्सिंग,லான்சிங்,ランシング,兰辛,蘭辛,랜싱', 42.7325300, -84.5555300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139593, 'Lapeer', 'Lapeer', 'Lapir,labyr,lapyr  mshy gn,lpyr  myshygan,Лапир,لابير,لاپیر، مشی گن,لپیر، میشیگان', 43.0514200, -83.3188300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139594, 'Lathrup Village', 'Lathrup Village', 'Lathrup,Lathrup Village', 42.4964200, -83.2227100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139595, 'Laurium', 'Laurium', '', 47.2374300, -88.4431700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139596, 'Lawton', 'Lawton', 'Louton,Лоутон', 42.1672600, -85.8469500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139597, 'Leland', 'Leland', 'Liland,Лиланд', 45.0230500, -85.7598100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139598, 'Leslie', 'Leslie', '', 42.4514300, -84.4324700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139599, 'Lewiston', 'Lewiston', 'L''juiston,Льюистон', 44.8839000, -84.3055700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139600, 'Lexington', 'Lexington', 'Leksington,Лексингтон', 43.2680800, -82.5307600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139601, 'Lincoln Park', 'Lincoln Park', 'Linkol''n Park Michigan,Linkoln Park,lnkn park  mshy gn,lynkwln bark,Линколн Парк,Линкольн Парк Мичиган,لنکن پارک، مشی گن,لينكولن بارك,لینکون‌پارک، میشیگان', 42.2505900, -83.1785400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139602, 'Linden', 'Linden', 'Linden,Линден', 42.8144700, -83.7824500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139603, 'Litchfield', 'Litchfield', '', 42.0439300, -84.7574600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139604, 'Livonia', 'Livonia', 'Livonia,Livonija,libonia,lyfwnya,lywwnya  mshy gn,lywwnya  myshygan,Ливониа,Ливония,Ливонија,ليفونيا,لیوونیا، مشی گن,لیوونیا، میشیگان,리보니아', 42.3683700, -83.3527100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139605, 'Lowell', 'Lowell', 'Louel,Лоуел', 42.9336400, -85.3419600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139606, 'Ludington', 'Ludington', 'LDM,Ladington,Ljudington,la ding dun,lwdynghtwn,lwdyngtwn  myshygan,Ладингтон,Людингтон,لودينغتون,لودینگتون، میشیگان,拉丁頓', 43.9552800, -86.4525800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139607, 'Luna Pier', 'Luna Pier', '', 41.8069900, -83.4424300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139608, 'Madison Heights', 'Madison Heights', 'Medison Khajts,Mehdison Khehjts,madyswn hayts,Медисон Хајтс,Мэдисон Хэйтс,ماديسون هايتس,مدیسون‌هایتس، میشیگان,میڈیسون ہائٹس، مشی گن', 42.4858700, -83.1052000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139609, 'Manchester', 'Manchester', 'Manchester,Манчестер', 42.1503200, -84.0377200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139610, 'Manistee', 'Manistee', 'MBL,Manisti,ma ni si di,manysty,mnysty  myshygan,Манисти,مانيستي,منیستی، میشیگان,马尼斯蒂', 44.2444500, -86.3242500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139611, 'Mancelona', 'Mancelona', '', 44.9022300, -85.0608800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139612, 'Manistique', 'Manistique', 'ISQ,Manistique,Monistique', 45.9577500, -86.2462500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139613, 'Manton', 'Manton', '', 44.4108400, -85.3989400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139614, 'Marcellus', 'Marcellus', '', 42.0258800, -85.8155600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139615, 'Marine City', 'Marine City', 'Marin Siti,ma lin cheng,maryn syty,maryn syty  myshygan,Марин Сити,مارين سيتي,مارین سیتی، میشیگان,马林城', 42.7194800, -82.4921300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139616, 'Marlette', 'Marlette', '', 43.3269700, -83.0802200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139617, 'Marquette', 'Marquette', 'MQT,Marguehtt,Market,Markett,Marquette,makes,maketto,markyt,markywt  myshygan,Маргуэтт,Маркет,Маркетт,ماركيت,مارکیوت، میشیگان,マーケット,마켓', 46.5435400, -87.3954200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139618, 'Marshall', 'Marshall', 'Marshal,Marshall,marshal,marshal  myshygan,marshl  mshy gn,Маршал,Маршалл,مارشال,مارشال، میشیگان,مارشل، مشی گن', 42.2722600, -84.9633100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139619, 'Marysville', 'Marysville', 'Mehrisvill,Merizvil,ma li si wei er,marysfyl,melijeubil,mryzwyl  myshygan,myryzwyl  mshy gn,Меризвил,Мэрисвилл,ماريسفيل,مریزویل، میشیگان,میریزویل، مشی گن,马里斯维尔,메리즈빌', 42.9125300, -82.4868600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139620, 'Mason', 'Mason', 'Mejson,Мейсон', 42.5792000, -84.4435800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139621, 'Mattawan', 'Mattawan', '', 42.2094800, -85.7844500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139622, 'Melvindale', 'Melvindale', '', 42.2825400, -83.1752000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139623, 'Memphis', 'Memphis', 'Memfis,Мемфис', 42.8964200, -82.7688100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139624, 'Menominee', 'Menominee', 'MNM,Mehnomini,Menominee,Menomini,Menomonee,mnmwny  myshygan,mynwmyny,Меномини,Мэномини,منمونی، میشیگان,مينوميني', 45.1077600, -87.6142700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139625, 'Michigan Center', 'Michigan Center', '', 42.2330900, -84.3271800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139626, 'Middleville', 'Middleville', '', 42.7130900, -85.4619600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139627, 'Midland', 'Midland', 'Midland,mydland,mydlnd  myshygan,Мидланд,ميدلاند,مڈلینڈ، مشی گن,میدلند، میشیگان', 43.6155800, -84.2472100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139628, 'Milan', 'Milan', 'Farmers,Majlan,Milan,Tolaneville,mylan,mylan  myshygan,Мајлан,Милан,ميلان,میلان، میشیگان', 42.0853200, -83.6824400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139629, 'Milford', 'Milford', 'Milford,Милфорд', 42.5936400, -83.5993900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139630, 'Millington', 'Millington', '', 43.2814100, -83.5296800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139631, 'Mio', 'Mio', 'Majo,Мајо', 44.6522400, -84.1297300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139632, 'Monroe', 'Monroe', 'Monro,Monroe,Monroj,River Raisin Settlement,meonlo,mwnrw,mwnrw  myshygan,Монро,Монрой,مونرو,مونرو، میشیگان,먼로', 41.9164300, -83.3977100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139633, 'Montague', 'Montague', '', 43.4166800, -86.3570100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139634, 'Montrose', 'Montrose', '', 43.1766900, -83.8927400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139635, 'Morenci', 'Morenci', '', 41.7194900, -84.2180000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139636, 'Mount Clemens', 'Mount Clemens', 'MTC,Maunt Klehmens,Maunt Klemens,Mt. Clemens,mawnt klymns,Маунт Клеменс,Маунт Клэменс,ماونت كليمنس,مونت‌کلمنز، میشیگان', 42.5972600, -82.8779800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139637, 'Mount Morris', 'Mount Morris', 'Mt. Morris', 43.1186400, -83.6949600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139638, 'Mount Pleasant', 'Mount Pleasant', 'MOP,Maunt Plezant,Maunt Plisant,Maunt-Plezant,mawnt blyzant,Маунт Плезант,Маунт Плисант,Маунт-Плезант,ماونت بليزانت,مونت‌پلیزانت، میشیگان', 43.5978100, -84.7675100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139639, 'Munising', 'Munising', 'Manising,Mjunising,mwnysyng  myshygan,mwnysyngh,Манисинг,Мјунисинг,مونيسينغ,مونیسینگ، میشیگان', 46.4112000, -86.6492600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139640, 'Muskegon', 'Muskegon', 'MKG,Maskegon,Maskigon,maskgwn  myshygan,meoseukigeon,mskyghwn,mskygn  mshy gn,Маскегон,Маскигон,ماسکگون، میشیگان,مسكيغون,مسکیگن، مشی گن,머스키건', 43.2341800, -86.2483900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139641, 'Muskegon Heights', 'Muskegon Heights', '', 43.2011300, -86.2389500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139642, 'Napoleon', 'Napoleon', '', 42.1605900, -84.2460600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139643, 'Nashville', 'Nashville', 'Nashvill,Нашвилл', 42.6028100, -85.0930500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139644, 'Negaunee', 'Negaunee', 'Negauni,Negoni,ngwnh  myshygan,nyghawny,Негауни,Негони,نيغاوني,نگونه، میشیگان', 46.4991000, -87.6118000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139645, 'New Baltimore', 'New Baltimore', '', 42.6811400, -82.7368600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139646, 'New Buffalo', 'New Buffalo', 'Buffalo,N''ju Buffalo,New Buffalo,Nju Bafalo,nyw bwfalw,nywbafalw  myshygan,Њу Бафало,Нью Буффало,نيو بوفالو,نیوبافالو، میشیگان', 41.7939300, -86.7439200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139647, 'New Haven', 'New Haven', 'N''ju-Khejven,Нью-Хейвен', 42.7294800, -82.8013100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139648, 'New Haven', 'New Haven', '', 43.0936400, -84.1533100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139649, 'Newaygo', 'Newaygo', '', 43.4197400, -85.8000500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139650, 'Newberry', 'Newberry', 'N''jubehrri,Newberry,Newburg,Njuberi,nywbyry,Њубери,Ньюбэрри,نيوبيري', 46.3550000, -85.5095600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139651, 'Niles', 'Niles', 'NLE,Najls,Niles,nylz,nylz  myshygan,Найлс,Најлс,نيلز,نیلز، میشیگان', 41.8297700, -86.2541800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139652, 'North Branch', 'North Branch', '', 43.2294700, -83.1966100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139653, 'North Muskegon', 'North Muskegon', '', 43.2561300, -86.2675600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139654, 'Northview', 'Northview', '', 43.0455800, -85.6005900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139655, 'Northville', 'Northville', 'Nortvil,nwrthfyl,nwrthwyl  myshygan,Нортвил,نارتھویل، مشی گن,نورثفيل,نورثویل، میشیگان', 42.4311500, -83.4832700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139656, 'Norton Shores', 'Norton Shores', 'Norton Shorehs,Norton Shors,Nortun Shors,nwrtwn shwrz,swahl nwrtwn  myshygan,Нортон Шорс,Нортон Шорэс,Нортън Шорс,سواحل نورتون، میشیگان,نورتون شورز', 43.1689000, -86.2639500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139657, 'Norway', 'Norway', '', 45.7869000, -87.9037400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139658, 'Novi', 'Novi', 'Novaj,Novi,Novyj,nobai,nwfy,nwwy  myshygan,nwy  mshy gn,Новај,Нови,Новый,نوفي,نووی، میشیگان,نوی، مشی گن,ノバイ,노바이', 42.4805900, -83.4754900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139659, 'Oak Park', 'Oak Park', 'Oak Park,Ouk Park,Ouk-Park,awk bark,awk park  mshy gn,Оак Парк,Оук Парк,Оук-Парк,أوك بارك,اوک پارک، مشی گن,اوک‌پارک، میشیگان', 42.4594800, -83.1827100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139660, 'Okemos', 'Okemos', '', 42.7222600, -84.4274700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139661, 'Olivet', 'Olivet', '', 42.4414300, -84.9241500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139662, 'Ontonagon', 'Ontonagon', 'Odoonaaganing,Ontonagon,awntwnaghwn,Онтонагон,أونتوناغون', 46.8710500, -89.3140300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139663, 'Orchard Lake', 'Orchard Lake', 'Orchard Lake,Orchard Lake Village', 42.5830900, -83.3593800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139664, 'Ortonville', 'Ortonville', '', 42.8522500, -83.4430000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139665, 'Otsego', 'Otsego', '', 42.4605900, -85.6964100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139666, 'Ovid', 'Ovid', '', 43.0058600, -84.3716400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139667, 'Owosso', 'Owosso', 'Ovoso,Ovosso,awsw,awsw  myshygan,Овосо,Овоссо,أوسو,اوسو، میشیگان', 42.9978000, -84.1766400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139668, 'Oxford', 'Oxford', 'Oksford,awksfwrd,Оксфорд,آکسفورڈ، مشی گن,أوكسفورد', 42.8247500, -83.2646600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139669, 'Parchment', 'Parchment', '', 42.3281000, -85.5697300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139670, 'Paw Paw', 'Paw Paw', 'Lafayette,Paw Paw', 42.2178200, -85.8911200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139671, 'Paw Paw Lake', 'Paw Paw Lake', '', 42.2122600, -86.2719700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139672, 'Pearl Beach', 'Pearl Beach', '', 42.6267000, -82.5976900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139673, 'Perry', 'Perry', '', 42.8264200, -84.2194100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139674, 'Petersburg', 'Petersburg', 'Peterburg,Петербург', 41.9011600, -83.7149400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139675, 'Petoskey', 'Petoskey', 'Gorad Petoski,Pehtoskej,Petoski,bytwsky,pei tuo si ji,ptwsky  myshygan,Горад Петоскі,Петоски,Пэтоскей,بيتوسكي,پتوسکی، میشیگان,佩托斯基', 45.3733400, -84.9553300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139676, 'Pigeon', 'Pigeon', '', 43.8300200, -83.2699600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139677, 'Pinckney', 'Pinckney', '', 42.4570000, -83.9479100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139678, 'Pinconning', 'Pinconning', '', 43.8536300, -83.9649900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139679, 'Plainwell', 'Plainwell', 'Plehjnvehll,Plejnvel,blynwyl,plynwl  myshygan,Плејнвел,Плэйнвэлл,بلينويل,پلینول، میشیگان', 42.4400400, -85.6489000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139680, 'Pleasant Ridge', 'Pleasant Ridge', '', 42.4711500, -83.1421500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139681, 'Plymouth', 'Plymouth', 'Plimut,Plymouth,Plymouth Corners,blaymwth,playmawt  mshy gn,plymwth  myshygan,Плимут,بلايموث,پلایماؤت، مشی گن,پلیموث، میشیگان', 42.3714300, -83.4702100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139682, 'Pontiac', 'Pontiac', 'PTK,Pontiac,Pontiak,Pontijak,bwntyak,pang di ya ke,pontiaeg,pontiakku,pwntyak  myshygan,Понтиак,Понтијак,Понтіак,بونتياك,پونتیاک، میشیگان,پونٹیئک، مشی گن,ポンティアック,庞蒂亚克,폰티액', 42.6389200, -83.2910500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139683, 'Port Huron', 'Port Huron', 'Desmond,PHN,Port Huron,Port Khjuron,Port-Guron,bwrt hwrwn,potohyuron,pwrt harwn  myshygan,Порт Хюрон,Порт Хјурон,Порт-Гурон,بورت هورون,پورت هارون، میشیگان,ポートヒューロン', 42.9708600, -82.4249100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139684, 'Portage', 'Portage', 'Portehjdzh,Portidz,bwrtagh,pwrtyj  myshygan,Портиџ,Портэйдж,بورتاغ,پورتیج، میشیگان,پورٹیج، مشی گن', 42.2011500, -85.5800000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139685, 'Portland', 'Portland', 'Portlend,Портленд', 42.8692000, -84.9030500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139686, 'Potterville', 'Potterville', '', 42.6292000, -84.7388700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139687, 'Prudenville', 'Prudenville', '', 44.2983500, -84.6519700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139688, 'Quincy', 'Quincy', 'Kuinsi,Куинси', 41.9442100, -84.8838500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139689, 'Quinnesec', 'Quinnesec', '', 45.8063500, -87.9884600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139690, 'Rapid City', 'Rapid City', '', 44.8344500, -85.2825600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139691, 'Ravenna', 'Ravenna', 'Ravema,Ravenna', 43.1894700, -85.9369900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139692, 'Reading', 'Reading', 'Reding,Рединг', 41.8394900, -84.7480100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139693, 'Redford', 'Redford', 'Redford,Редфорд', 42.3833700, -83.2966000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139694, 'Reed City', 'Reed City', 'RCT,Rid Siti,ryd syty,ryd syty  myshygan,Рид Сити,ريد سيتي,رید سیتی، میشیگان', 43.8750200, -85.5100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139695, 'Reese', 'Reese', '', 43.4505800, -83.6963500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139696, 'Richmond', 'Richmond', 'Richmond,ryshmwnd  myshygan,rytshmwnd,Ричмонд,ريتشموند,ریشموند، میشیگان', 42.8092000, -82.7557600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139697, 'River Rouge', 'River Rouge', '', 42.2733700, -83.1343700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139698, 'Riverview', 'Riverview', 'Rivehvju,Rivervju,ryfrfyw,rywrwyw  myshygan,Ривервју,Ривэвю,ريفرفيو,ریورویو، میشیگان', 42.1742100, -83.1793700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139699, 'Rochester', 'Rochester', 'Rochester,rochesuta,rwchstr  myshygan,rwtshstr,Рочестер,روتشستر,روچستر، میشیگان,روچیسٹر، مشی گن,ロチェスター', 42.6805900, -83.1338200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139700, 'Rochester Hills', 'Rochester Hills', '', 42.6583700, -83.1499300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139701, 'Rockford', 'Rockford', '', 43.1200300, -85.5600300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139702, 'Rockwood', 'Rockwood', '', 42.0708800, -83.2466000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139703, 'Rogers City', 'Rogers City', 'Rodzers Siti,Rodzhehrs Siti,rwjrz syty,rwjrz syty  myshygan,Роджэрс Сити,Роџерс Сити,روجرز سيتي,روجرز سیتی، میشیگان', 45.4214000, -83.8183300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139704, 'Romeo', 'Romeo', '', 42.8028100, -83.0129900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139705, 'Romulus', 'Romulus', 'Romul,Romulus,rwmalws  myshygan,rwmwlws,Ромул,Ромулус,رومالوس، میشیگان,رومولوس', 42.2222600, -83.3966000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139706, 'Roosevelt Park', 'Roosevelt Park', '', 43.1964000, -86.2722800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139707, 'Roscommon', 'Roscommon', 'Roskommon,Roskomon,rwskwmwn,Роскоммон,Роскомон,روسكومون', 44.4983500, -84.5919700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139708, 'Roseville', 'Roseville', 'Rousvill,Rouzvil,Rozvell,lojeubil,rwzfyl,rwzwyl  mshy gn,rzwyl  myshygan,Розвелл,Роузвил,Роусвилл,رزویل، میشیگان,روزفيل,روزویل، مشی گن,로즈빌', 42.4972600, -82.9371400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139709, 'Royal Oak', 'Royal Oak', 'Rojal Ouk,loyeol-okeu,rayl awk  mshy gn,roiyaruoku,rwyal awk,rwyal awk  myshygan,Ројал Оук,رائل اوک، مشی گن,رويال أوك,رویال اوک، میشیگان,ロイヤルオーク,로열오크', 42.4894800, -83.1446500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139710, 'Saginaw', 'Saginaw', 'Fort Saginaw,MBS,Saginav,Saginava,Saginaw,Sagino,Saguno,saegino,saghynaw,sagino,sgynw  mshy gn,sgynw  myshygan,Сагинав,Сагино,Сагъно,ساغيناو,سگینؤ، مشی گن,سگینو، میشیگان,サギノー,새기노', 43.4194700, -83.9508100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139711, 'Saint Charles', 'Saint Charles', 'Sent-Charl''z,Сент-Чарльз', 43.2969700, -84.1405300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139712, 'Saint Helen', 'Saint Helen', '', 44.3636300, -84.4102900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139713, 'Saint Ignace', 'Saint Ignace', '', 45.8661400, -84.7275100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139714, 'Saint Johns', 'Saint Johns', 'Saint John''s,Saint Johns,Saint Johns Village', 43.0011400, -84.5591500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139715, 'Saint Joseph', 'Saint Joseph', 'Sent-Dzhozef,Сент-Джозеф', 42.1097600, -86.4800200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139716, 'Saint Louis', 'Saint Louis', 'Sent-Luis,Сент-Луис', 43.4083600, -84.6066700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139717, 'Saline', 'Saline', 'Salin,Sehlajn,salyn,salyn  myshygan,Салин,Сэлайн,سالين,سالین، میشیگان', 42.1667100, -83.7816100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139718, 'Sand Lake', 'Sand Lake', '', 44.3191800, -83.6847000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139719, 'Sandusky', 'Sandusky', '', 43.4203000, -82.8296600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139720, 'Saranac', 'Saranac', '', 42.9294800, -85.2130700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139721, 'Sault Ste. Marie', 'Sault Ste. Marie', 'SSM,Saint Marys Falls,Sault Marija,Sault Sainte Marie,Sault Sainte-Marie,Sault Ste. Marie,Sault de Sainte Marie,Su Sent Meri,Su-Sent-Mari,su sheng ma li,suseinteumali,susentomari,swlt sant mary,Саулт Мария,Су Сент Мери,Су-Сент-Мари,سولت سانت ماري,スーセントマリー,蘇聖瑪麗,수세인트마리', 46.4953000, -84.3453200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139722, 'Schoolcraft', 'Schoolcraft', '', 42.1142100, -85.6377800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139723, 'Scottville', 'Scottville', '', 43.9547300, -86.2800800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139724, 'Sebewaing', 'Sebewaing', '', 43.7322400, -83.4510700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139725, 'Shelby', 'Shelby', '', 42.6708700, -83.0329800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139726, 'Shelby', 'Shelby', '', 43.6086200, -86.3639600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139727, 'Shepherd', 'Shepherd', '', 43.5244700, -84.6947300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139728, 'Shields', 'Shields', 'Shields,Shields Corners', 43.4153000, -84.0563700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139729, 'Skidway Lake', 'Skidway Lake', '', 44.1833500, -84.0352700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139730, 'South Gull Lake', 'South Gull Lake', '', 42.3875400, -85.3966700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139731, 'South Haven', 'South Haven', 'Saut Khejven,Sous Khehjvn,hywn jnwby  myshygan,sawth hyfn,Саут Хејвен,Соус Хэйвн,ساوث هيفن,هیون جنوبی، میشیگان', 42.4030900, -86.2736400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139732, 'South Lyon', 'South Lyon', '', 42.4605900, -83.6516100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139733, 'South Monroe', 'South Monroe', '', 41.8958800, -83.4177100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139734, 'South Rockwood', 'South Rockwood', '', 42.0639300, -83.2610400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139735, 'Southfield', 'Southfield', 'Sautfild,Sousfild,Southfield,sauseupildeu,Саутфилд,Соусфилд,사우스필드', 42.4733700, -83.2218700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139736, 'Southgate', 'Southgate', 'Sautgejt,Sousgehjt,sawthghyt,Саутгејт,Соусгэйт,ساؤتھ گیٹ، مشی گن,ساوت‌گیت، میشیگان,ساوثغيت', 42.2139300, -83.1938100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139737, 'Sparta', 'Sparta', '', 43.1608600, -85.7100400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139738, 'Spring Arbor', 'Spring Arbor', 'Spring Arbor,Spring Arbour', 42.2050400, -84.5527400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139739, 'Spring Lake', 'Spring Lake', '', 43.0769600, -86.1970000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139740, 'Springfield', 'Springfield', '', 42.3264300, -85.2391600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139741, 'Saint Clair', 'Saint Clair', '', 42.8208700, -82.4860200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139742, 'Saint Clair Shores', 'Saint Clair Shores', '', 42.4969800, -82.8888100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139743, 'Stambaugh, Iron River', 'Stambaugh, Iron River', 'Stambaugh', 46.0810700, -88.6270800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139744, 'Standish', 'Standish', 'Standish,astndysh  myshygan,standysh,Стандиш,استندیش، میشیگان,ستانديش', 43.9830800, -83.9588800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139745, 'Stanton', 'Stanton', 'Stehnton,Стэнтон', 43.2925300, -85.0814100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139746, 'Sterling Heights', 'Sterling Heights', 'Sterling Khajts,Sterling-Khajts,Sturling Khajts,astrlyng hayts  myshygan,si te ling hai ci,styrlyngh hayts,sutaringuhaitsu,Стерлинг Хајтс,Стерлинг-Хайтс,Стърлинг Хайтс,استرلینگ هایتس، میشیگان,ستيرلينغ هايتس,سٹرلنگ ہائٹس، مشی گن,スターリングハイツ,斯特靈海茨', 42.5803100, -83.0302000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139747, 'Stevensville', 'Stevensville', '', 42.0144900, -86.5194700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139748, 'Stockbridge', 'Stockbridge', '', 42.4511500, -84.1805100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139749, 'Stony Point', 'Stony Point', '', 42.4969800, -85.4266800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139750, 'Stony Point', 'Stony Point', '', 41.9414300, -83.2649300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139751, 'Sturgis', 'Sturgis', 'IRS', 41.7992200, -85.4191500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139752, 'Swartz Creek', 'Swartz Creek', 'Svorc Krik,shwartz kryk,swartz kryk  myshygan,Сворц Крик,سوارتز کریک، میشیگان,شوارتز كريك', 42.9572500, -83.8305100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139753, 'Sylvan Lake', 'Sylvan Lake', '', 42.6114200, -83.3285500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139754, 'Tawas City', 'Tawas City', 'Tavas Siti,tawas syty  myshygan,twas syty,Тавас Сити,تاواس سیتی، میشیگان,تواس سيتي', 44.2694600, -83.5147000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139755, 'Taylor', 'Taylor', 'Tehjlor,Tejlor,taylwr,tylwr  myshygan,Тейлор,Тејлор,Тэйлор,تايلور,تیلور، میشیگان,ٹیلر، مشی گن', 42.2408700, -83.2696500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139756, 'Tecumseh', 'Tecumseh', 'Tehkamsekh,Tekamsi,tykwmsyh,Текамси,Тэкамсех,تيكومسيه', 42.0039300, -83.9449400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139757, 'Temperance', 'Temperance', '', 41.7792100, -83.5688200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139758, 'Three Rivers', 'Three Rivers', 'Brooklyn,Canada,HAI,Lockport,Moab,New Jersey,Saint Joseph,Three Rivers', 41.9439400, -85.6324900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139759, 'Three Oaks', 'Three Oaks', '', 41.7986500, -86.6105800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139760, 'Traverse City', 'Traverse City', 'TVC,Travehrs Siti,Travers Siti,te la fu si cheng,teulaebeoseusiti,torabasushiti,trafyrs syty,traws syty  myshygan,Траверс Сити,Травэрс Сити,ترافيرس سيتي,تراوس سیتی، میشیگان,トラバースシティ,特拉弗斯城,트래버스시티', 44.7630600, -85.6206300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139761, 'Trenton', 'Trenton', 'Sibley,Trenton,te lun dun,teulenteon,trntwn  myshygan,tryntwn,Трентон,ترنتون، میشیگان,ترينتون,ٹرنٹن، مشی گن,特伦顿,트렌턴', 42.1394900, -83.1782600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139762, 'Trowbridge Park', 'Trowbridge Park', '', 46.5566000, -87.4373600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139763, 'Troy', 'Troy', 'Troj,Troja,Troy,Troy Corners,te luo yi,teuloi,toroi,trwy,trwy  myshygan,Трой,Троя,Трој,تروي,تروی، میشیگان,ٹرائے، مشی گن,トロイ,特洛伊,트로이', 42.6055900, -83.1499300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139764, 'Twin Lake', 'Twin Lake', '', 43.3627900, -86.1647800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139765, 'Union City', 'Union City', 'Junion-Siti,Юнион-Сити', 42.0667100, -85.1360900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139766, 'Utica', 'Utica', 'Jutika,UIZ,Utica,Utika,ywtyka,ywtyka  myshygan,Јутика,Утика,يوتيكا,یوتیکا، میشیگان', 42.6261400, -83.0335400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139767, 'Vandercook Lake', 'Vandercook Lake', '', 42.1933700, -84.3910700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139768, 'Vassar', 'Vassar', '', 43.3719700, -83.5832900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139769, 'Vicksburg', 'Vicksburg', '', 42.1200500, -85.5327800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139770, 'Lake Isabella', 'Lake Isabella', 'Lake Isabella,Village of Lake Isabella', 43.6436400, -84.9972500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139771, 'Wacousta', 'Wacousta', '', 42.8278100, -84.7008200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139772, 'Wakefield', 'Wakefield', 'Vehjkfild,Vejkfild,wykfyld,Вејкфилд,Вэйкфилд,ويكفيلد,ویک‌فیلد، میشیگان', 46.4752300, -89.9398900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139773, 'Walker', 'Walker', 'Valkehr,Voker,Walker,Walker Grand Trunk,wakr  myshygan,wwkr,Валкэр,Вокер,واکر، میشیگان,ووكر', 43.0014100, -85.7680900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139774, 'Walled Lake', 'Walled Lake', '', 42.5378100, -83.4810500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139775, 'Warren', 'Warren', 'Gorad Uorehn,Uorren,Uorun,Voren,Vorren,Warren,u~oren,warn  mshy gn,warn  myshygan,waryn,wo lun,woleon,wwrn,Ворен,Воррен,Горад Уорэн,Уоррен,Уорън,וורן,وارن، مشی گن,وارن، میشیگان,وارين,ウォーレン,沃伦,워런', 42.4904400, -83.0130400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139776, 'Waterford', 'Waterford', 'Uoterford,Уотерфорд', 42.6930300, -83.4118100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139777, 'Watervliet', 'Watervliet', '', 42.1867100, -86.2605800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139778, 'Waverly', 'Waverly', '', 42.7392000, -84.6208100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139779, 'Wayland', 'Wayland', '', 42.6739200, -85.6447400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139780, 'Wayne', 'Wayne', 'Uehjn,Vajn,Vejn,wayn,wayn  myshygan,wyn  mshy gn,Вайн,Вејн,Уэйн,واين,واین، میشیگان,وین، مشی گن', 42.2814300, -83.3863200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139781, 'Webberville', 'Webberville', '', 42.6669800, -84.1741300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139782, 'West Branch', 'West Branch', 'Vehst Branch,Vest Branch,branch jnwby  myshygan,wyst bransh,Вест Бранч,Вэст Бранч,برانچ جنوبی، میشیگان,ويست برانش', 44.2764100, -84.2386100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139783, 'West Ishpeming', 'West Ishpeming', '', 46.4835500, -87.7009700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139784, 'West Monroe', 'West Monroe', '', 41.9139300, -83.4316000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139785, 'Westland', 'Westland', 'Vehstland,Vestland,weseuteullaendeu,wstlnd  myshygan,wystland,Вестланд,Вэстланд,وستلند، میشیگان,ويستلاند,ویسٹلینڈ، مشی گن,웨스틀랜드', 42.3242000, -83.4002100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139786, 'Westwood', 'Westwood', '', 42.3028200, -85.6336200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139787, 'White Cloud', 'White Cloud', '', 43.5503000, -85.7720000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139788, 'White Pigeon', 'White Pigeon', '', 41.7981100, -85.6433200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139789, 'Whitehall', 'Whitehall', '', 43.4100100, -86.3486800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139790, 'Whitmore Lake', 'Whitmore Lake', '', 42.4397000, -83.7453000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139791, 'Williamston', 'Williamston', 'Vilijamston,Villiamston,wylyamstwn,wylyamstwn  myshygan,Вилијамстон,Виллиамстон,ويليامستون,ویلیامستون، میشیگان', 42.6889200, -84.2830200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139792, 'Wixom', 'Wixom', 'Viksom,wykswm,wymwks  myshygan,Виксом,ويكسوم,ویموکس، میشیگان', 42.5247600, -83.5363300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139793, 'Wolf Lake', 'Wolf Lake', '', 43.2547400, -86.1097800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139794, 'Wolverine Lake', 'Wolverine Lake', '', 42.5567000, -83.4738300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139795, 'Woodhaven', 'Woodhaven', '', 42.1389300, -83.2416000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139796, 'Woodland Beach', 'Woodland Beach', '', 41.9400500, -83.3132600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139797, 'Wyandotte', 'Wyandotte', 'Vajandot,huai en duo te,wayndwt,wyandwt  myshygan,Вајандот,وايندوت,ویاندوت، میشیگان,怀恩多特', 42.2142100, -83.1499200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139798, 'Wyoming', 'Wyoming', 'Vajoming,waywmngh,wayywmng  mshy gn,wywmyng  myshygan,Вајоминг,وائیومنگ، مشی گن,وايومنغ,ویومینگ، میشیگان', 42.9133600, -85.7053100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139799, 'Yale', 'Yale', '', 43.1300300, -82.7982600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139800, 'Ypsilanti', 'Ypsilanti', 'Ipsilanti,Ypsilanti,aypsylanty  myshygan,ibsillaenti,ipushiranti,ybsylanty,ypslnty  mshy gn,Υψιλάντι,Ипсиланти,ایپسیلانتی، میشیگان,يبسيلانتي,یپسلنتی، مشی گن,イプシランティ,입실랜티', 42.2411500, -83.6129900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139801, 'Zeeland', 'Zeeland', 'Ziland,xi lan,zyland,zylnd  myshygan,Зиланд,زيلاند,زیلند، میشیگان,西蘭', 42.8125200, -86.0186500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139802, 'Zilwaukee', 'Zilwaukee', 'Zilwaukee,Zilwaukie', 43.4764100, -83.9205300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139803, 'Ada', 'Ada', 'Ada,City of Ada,Ehjda,Ejda,ada,ai da,Ада,Ејда,Эйда,آدا، مینه‌سوتا,أدا,ایڈا، مینیسوٹا,埃达', 47.2996900, -96.5153500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139804, 'Adrian', 'Adrian', 'Adrian,City of Adrian,Edrian,Ehdrian,Ehjdrian,Ejdrijan,adryan,Адриан,Едріан,Ејдријан,Эдриан,Эйдриан,آدریان، مینه‌سوتا,آدریان، مینیسوٹا,أدريان', 43.6349700, -95.9328000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139805, 'Afton', 'Afton', 'Afton,City of Afton', 44.9027500, -92.7835400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139806, 'Aitkin', 'Aitkin', 'Aitkin,City of Aitkin,Ehjtkin,Ejtkin,ai te jin,aytkn,Ейткін,Ејткин,Эйткин,أيتكن,ایتکن، مینیسوٹا,ایتکین، مینه‌سوتا,艾特金', 46.5330100, -93.7102500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139807, 'Albany', 'Albany', 'Albany,City of Albany,Ehlbani,Olbani,albany,Олбани,Элбани,آلبانی، مینه‌سوتا,ألباني,البانے، مینیسوٹا', 45.6299600, -94.5700000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139808, 'Albert Lea', 'Albert Lea', 'AEL,Al''bert Li,Al''bert-Li,Albert Lea,Albert Li,City of Albert Lea,albarta li,albrt lya,Алберт Ли,Альберт Ли,Альберт-Ли,Альберт-Лі,آلبرت لی، مینه‌سوتا,ألبرت ليا,البرٹ لی، مینیسوٹا,आल्बर्ट ली', 43.6480100, -93.3682700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139809, 'Albertville', 'Albertville', 'Al''bertvil'',Al''bertvill,Albertvil,Albertville,City of Albertville,albrtfyl,Албертвил,Альбертвилл,Альбертвіль,آلبرتویل، مینه‌سوتا,ألبرتفيل,البرتویل، مینیسوٹا', 45.2377400, -93.6544100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139810, 'Alexandria', 'Alexandria', 'AXN,Alegzandrija,Aleksandria,Aleksandrija,Alexandria,City of Alexandria,alksandrya,allegsandeulia,Алегзандрия,Александриа,Александрия,Александрија,Александрія,ألكساندريا,الکساندریا، مینه‌سوتا,الیگزیندریا، مینیسوٹا,알렉산드리아', 45.8852400, -95.3775400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139811, 'Andover', 'Andover', 'Andovehr,Andover,City of Andover,an duo fu,andwfr,Андовер,Андовэр,آندوور، مینه‌سوتا,أندوفر,اندوویر، مینیسوٹا,安多弗', 45.2333000, -93.2913400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139812, 'Anoka', 'Anoka', 'Anoka,City of Anoka,a nuo ka,anwka,Анока,آنوکا، مینه‌سوتا,أنوكا,انوکا، مینیسوٹا,阿诺卡', 45.1977400, -93.3871800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139813, 'Annandale', 'Annandale', 'Anandejl,Annandale,Annandehjl,Annandejl,City of Annandale,anandal,Анандејл,Аннандейл,Аннандэйл,أناندال,اناندیل، مینه‌سوتا,اناندیل، مینیسوٹا', 45.2627400, -94.1244300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139814, 'Apple Valley', 'Apple Valley', 'Appl Volehj,Apple Valley,City of Apple Valley,Ehpl-Valli,Epl Vali,Epl-Velli,abl faly,aepeulbaelli,Аппл Волэй,Епл Вали,Епл-Веллі,Эпл-Валли,أبل فالي,اپل ولی، مینه‌سوتا,ایپل ویلی، مینیسوٹا,애플밸리', 44.7319100, -93.2177200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139815, 'Appleton', 'Appleton', 'Appleton,City of Appleton', 45.1969100, -96.0197700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139816, 'Arden Hills', 'Arden Hills', 'Arden Hills,City of Arden Hills', 45.0502400, -93.1566100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139817, 'Arlington', 'Arlington', 'Arlington,City of Arlington,Арлингтон', 44.6083000, -94.0805300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139818, 'Arnold', 'Arnold', 'Arnol''d,Арнольд', 46.8802200, -92.0904700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139819, 'Atwater', 'Atwater', 'Atwater,City of Atwater', 45.1388500, -94.7780600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139820, 'Aurora', 'Aurora', 'Avrora,Orora,awrwra,Аврора,Орора,آرورا، مینیسوٹا,أورورا,ائورا، مینه‌سوتا', 47.5299300, -92.2371200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139821, 'Austin', 'Austin', 'AUM,Austin,City of Austin,Ostin,awstyn,osutin,Остин,Остін,آستین، مینه‌سوتا,آسٹن، مینیسوٹا,أوستين,オースティン', 43.6666300, -92.9746400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139822, 'Avon', 'Avon', 'Avon,City of Avon', 45.6091300, -94.4516700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139823, 'Babbitt', 'Babbitt', 'Babbit,Babbitt,City of Babbitt,babyt,Баббит,Баббитт,Баббітт,بابيت,ببیت، مینه‌سوتا,بیبت، مینیسوٹا', 47.7085300, -91.9446000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139824, 'Bagley', 'Bagley', 'Baglehj,Bagley,Bagli,City of Bagley,baghly,Багли,Баглэй,Баґлі,باغلي,بگلی، مینه‌سوتا,بگلے، مینیسوٹا', 47.5216200, -95.3983500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139825, 'Barnesville', 'Barnesville', 'Barnehsvill,Barnesville,Barnsvil,Barnsvil'',Barnsvill,City of Barnesville,barnsfyl,Барнсвил,Барнсвилл,Барнсвіль,Барнэсвилл,بارنزویل، مینه‌سوتا,بارنزویل، مینیسوٹا,بارنسفيل', 46.6521800, -96.4197900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139826, 'Baudette', 'Baudette', 'BDE,Baudehtt,Baudette,Bodett,City of Baudette,bao de te,bawdyt,Баудэтт,Бодетт,باؤدیت، مینیسوٹا,باودت، مینه‌سوتا,باوديت,包地特', 48.7124700, -94.5999300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139827, 'Baxter', 'Baxter', 'Bakstehr,Bakster,Baxter,City of Baxter,bakstr,Бакстер,Бакстэр,باكستر,بکستر، مینه‌سوتا,بکستر، مینیسوٹا', 46.3433000, -94.2866700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139828, 'Bayport', 'Bayport', 'Bayport,Behjport,Bejport,City of Bayport,bybwrt,Бейпорт,Бејпорт,Бэйпорт,بيبورت,بیپورت، مینه‌سوتا,بے پورت، مینیسوٹا', 45.0213600, -92.7810400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139829, 'Becker', 'Becker', 'Becker,Bekehr,Beker,City of Becker,bykr,Бекер,Бекэр,بيكر,بکر، مینه‌سوتا,بیکر، مینیسوٹا', 45.3933000, -93.8769200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139830, 'Belle Plaine', 'Belle Plaine', 'Behll Plehjn,Bel Plejn,Bell-Plejn,Belle Plaine,City of Belle Plaine,byly blyn,Бел Плејн,Белл-Плейн,Бэлл Плэйн,بل پلین، مینه‌سوتا,بيلي بلين,بیل پلین، مینیسوٹا', 44.6227400, -93.7685700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139831, 'Bemidji', 'Bemidji', 'BJI,Behmidzhi,Bemidji,Bemidzhi,Bemidzi,Bemijigamaag,Bermidji,City of Bemidji,bymydjy,Бемиджи,Бемиџи,Беміджи,Бэмиджи,بمیجی، مینه‌سوتا,بيميدجي,بیمیجی، مینیسوٹا', 47.4735600, -94.8802800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139832, 'Benson', 'Benson', 'BBB,Benson,City of Benson', 45.3149600, -95.6000300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139833, 'Big Lake', 'Big Lake', 'Big Lake,Big Lehjk,Big Lejk,Big-Lejk,City of Big Lake,Humboldt,bygh lyk,Биг Лејк,Биг Лэйк,Биг-Лейк,Біґ-Лейк,بيغ ليك,بگ لیک، مینیسوٹا,بیگ لیک، مینه‌سوتا', 45.3324600, -93.7460800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139834, 'Birchwood', 'Birchwood', 'Birchwood,Birchwood Village,City of Birchwood Village', 45.0610800, -92.9760500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139835, 'Blaine', 'Blaine', 'Blaine,City of Blaine', 45.1608000, -93.2349500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139836, 'Blooming Prairie', 'Blooming Prairie', 'Blooming Prairie,City of Blooming Prairie', 43.8666300, -93.0510300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139837, 'Bloomington', 'Bloomington', 'Bloomington,Bloominton,Blumington,City of Bloomington,beullumingteon,blwmnghtwn,blwmyngtn  mynh‌swta,buruminton,Блумингтон,بلومنغتون,بلومنگٹن، مینیسوٹا,بلومینگتن، مینه‌سوتا,ブルーミントン,블루밍턴', 44.8408000, -93.2982800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139838, 'Blue Earth', 'Blue Earth', 'Blu Ert,Blu Irs,Blu-Ehrt,Blu-Ert,Blue Earth,City of Blue Earth,blw ayrth,Блу Ерт,Блу Ирс,Блу-Ерт,Блу-Эрт,بلو إيرث,بلو ارتھ، مینیسوٹا,بلو ارث، مینه‌سوتا', 43.6374600, -94.1021800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139839, 'Braham', 'Braham', 'Bragam,Braham,Brakham,City of Braham,braham,Брагам,Брахам,براهام,براهام، مینه‌سوتا,براہم، مینیسوٹا', 45.7227400, -93.1707800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139840, 'Brainerd', 'Brainerd', 'BRD,Brainerd,Brehjnerd,Brejnerd,Brejnurd,City of Brainerd,Oski-odena,brynrd,Брейнерд,Брейнърд,Брэйнерд,برينرد,برینرد، مینه‌سوتا,برینرڈ، مینیسوٹا', 46.3580200, -94.2008300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139841, 'Branch', 'Branch', 'Branch,City of Branch', 45.4852400, -92.9618800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139842, 'Breckenridge', 'Breckenridge', 'Breckenridge,Brehkenridzh,Brekenridz,Brekenridzh,City of Breckenridge,bryknrydj,Брекенридж,Брекенриџ,Брекенрідж,Брэкенридж,بريكنريدج,برکنریج، مینه‌سوتا,بریکین رج، مینیسوٹا', 46.2635700, -96.5881300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139843, 'Breezy Point', 'Breezy Point', 'Breezy Point,City of Breezy Point,Pelican Lakes', 46.5900100, -94.2198200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139844, 'Brooklyn Center', 'Brooklyn Center', 'Brooklyn Center,Bruklin Sentehr,Bruklin Senter,Bruklin-Senter,City of Brooklyn Center,brwklyn sntr,Бруклин Сентер,Бруклин Сентэр,Бруклин-Сентер,Бруклін-Сентер,بروكلين سنتر,بروکلین سنتر، مینه‌سوتا,بروکلین سینٹر، مینیسوٹا', 45.0760800, -93.3327300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139845, 'Brooklyn Park', 'Brooklyn Park', 'Brooklyn Park,Bruklin Park,Bruklin-Park,City of Brooklyn Park,beulukeullinpakeu,brwklyn bark,Бруклин Парк,Бруклин-Парк,Бруклін-Парк,بروكلين بارك,بروکلین پارک، مینه‌سوتا,بروکلین پارک، مینیسوٹا,브루클린파크', 45.0941300, -93.3563400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139846, 'Buffalo', 'Buffalo', 'Baffalo,Bufalo,Buffalo,baflw,Баффало,Буфало,Буффало,بافلو,بوفالو، مینه‌سوتا,بوفیلو، مینیسوٹا', 45.1719100, -93.8746900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139847, 'Burnsville', 'Burnsville', 'Bernsvil,Bernsvil'',Bernsvill,Burnsvill,Burnsville,City of Burnsville,bwrnsfyl,Бернсвил,Бернсвилл,Бернсвіль,Бурнсвилл,برنزویل، مینه‌سوتا,برنزویل، مینیسوٹا,بورنسفيل', 44.7677400, -93.2777200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139848, 'Byron', 'Byron', 'Bryon,Byron,City of Byron', 44.0327400, -92.6454600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139849, 'Caledonia', 'Caledonia', 'Caledonia,City of Caledonia,Kaledonija,Каледония', 43.6346900, -91.4968100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139850, 'Cambridge', 'Cambridge', 'Cambridge,City of Cambridge,Kehmbridzh,Kejmbridzh,Kembridz,Kembridzh,kambrydj,Кеймбридж,Кеймбрідж,Кембридж,Кембриџ,Кэмбридж,كامبريدج,کمبریج، مینه‌سوتا,کیمبرج، مینیسوٹا', 45.5727400, -93.2243900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139851, 'Canby', 'Canby', 'Canby,City of Canby,Kanbi,Kehnbi,knby,Канби,Канбі,Кэнби,كنبي,کنبی، مینه‌سوتا,کینبی، مینیسوٹا', 44.7088500, -96.2764300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139852, 'Cannon Falls', 'Cannon Falls', 'Cannon Falls,City of Cannon Falls,Kannon Fols,Kannon-Fols,Kanon Fols,Kennon-Fols,kanwn fwlz,Каннон Фолс,Каннон-Фолс,Канон Фолс,Кеннон-Фолс,كانون فولز,کانن فلز، مینه‌سوتا,کینن فالز، مینیسوٹا', 44.5069100, -92.9054800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139853, 'Carlton', 'Carlton', 'Carlton,City of Carlton,Karlton,Northern Pacific Junction,karltwn,Карлтон,كارلتون,کارلتن، مینه‌سوتا,کارلٹن، مینیسوٹا', 46.6638300, -92.4249100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139854, 'Carver', 'Carver', 'Carver,City of Carver,Karvehr,Karver,karfr,Карвер,Карвэр,كارفر,کارور، مینه‌سوتا,کارور، مینیسوٹا', 44.7635700, -93.6257900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139855, 'Center City', 'Center City', '', 45.3938500, -92.8166000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139856, 'Centerville', 'Centerville', 'Centerville,City of Centerville,Sentervil,Sentervil'',Sentervill,sntrfyl,Сентервил,Сентервилл,Сентервіль,سنترفيل,سنترویل، مینه‌سوتا,سینٹرویل، مینیسوٹا', 45.1630200, -93.0557800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139857, 'Champlin', 'Champlin', 'Chamlin,Champlin,City of Champlin,tshamblyn,Чамлин,Чамплин,Чамплін,تشامبلين,چمپلین، مینه‌سوتا,چیمپلن، مینیسوٹا', 45.1888500, -93.3974500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139858, 'Chanhassen', 'Chanhassen', 'Chanhassen,Chankhasen,Chankhassehn,City of Chanhassen,Shangassen,Shankhassen,tshanhasyn,Чанхасен,Чанхассэн,Шангассен,Шанхассен,تشانهاسين,چنهسن، مینه‌سوتا,چین ہاسن، مینیسوٹا', 44.8621900, -93.5307900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139859, 'Chaska', 'Chaska', 'Chaska,City of Chaska,chaska  mynh‌swta,tshska,Часка,تشسكا,چاسکا، مینه‌سوتا,چاسکا، مینیسوٹا', 44.7894100, -93.6021800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139860, 'Chatfield', 'Chatfield', 'Chatfield,Chatfild,City of Chatfield,shatfyld,Чатфилд,Чатфілд,شاتفيلد,چتفیلد، مینه‌سوتا,چیٹفیلڈ، مینیسوٹا', 43.8455200, -92.1890500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139861, 'Chisago City', 'Chisago City', 'Chisago Siti,Chisago-Siti,qi sa ge cheng,tshysaghw syty,Чисаго Сити,Чисаго-Сити,Чісаґо-Сіті,تشيساغو سيتي,چساگو سٹی، مینیسوٹا,چیساگو سیتی، مینه‌سوتا,奇萨戈城', 45.3735800, -92.8899400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139862, 'Chisholm', 'Chisholm', 'Chisholm,Chiskholm,Chizgolm,Chizolm,City of Chisholm,tshyshwlm,Чизолм,Чисхолм,Чишолм,Чізголм,تشيشولم,چیسم، مینه‌سوتا,چیشوم، مینیسوٹا', 47.4891000, -92.8838000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139863, 'Circle Pines', 'Circle Pines', 'Circle Pines,City of Circle Pines,Serkel Pajns,Serkl-Pajns,Sokl Pajns,syrkl byns,Серкел Пајнс,Серкл-Пайнс,Сокл Пайнс,سرکل پائنز، مینیسوٹا,سرکل پاینز، مینه‌سوتا,سيركل بينس', 45.1485800, -93.1516100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139864, 'Clara City', 'Clara City', '', 44.9549600, -95.3664000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139865, 'Clearwater', 'Clearwater', 'City of Clearwater,Clear Water,Clearwater,Clearwater Village', 45.4194100, -94.0488700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139866, 'Cloquet', 'Cloquet', 'City of Cloquet,Cloquet,Klogueht,Klokej,Kloket,ke luo kai,keullokes,klwkt  mynh‌swta,klwkyh,Клогуэт,Клокей,Клокет,Клокеј,كلوكيه,کلوکت، مینه‌سوتا,کلوکیٹ، مینیسوٹا,克洛凯,클로켓', 46.7216100, -92.4593600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139867, 'Cohasset', 'Cohasset', 'Bass Brook,Cohasset', 47.2635600, -93.6202200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139868, 'Cokato', 'Cokato', 'City of Cokato,Cokato,Kokato,Kokejto,kwkatw,Кокато,Кокейто,كوكاتو,کوکاتو، مینه‌سوتا,کوکیٹو، مینیسوٹا', 45.0758000, -94.1899800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139869, 'Coleraine', 'Coleraine', 'City of Coleraine,Coleraine,Kolerajn,Kolrejn,kwlyryn,Колерайн,Колрейн,Колрејн,كوليرين,کولرین، مینه‌سوتا,کولرین، مینیسوٹا', 47.2888300, -93.4277100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139870, 'Collegeville', 'Collegeville', '', 45.5944100, -94.3630500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139871, 'Cold Spring', 'Cold Spring', 'City of Cold Spring,Cold Spring', 45.4558000, -94.4288800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139872, 'Cologne', 'Cologne', 'City of Cologne,Cologne,Kologn,Kolon,kwlwghn,Кологн,Колон,كولوغن,کولون، مینیسوٹا,کولونی، مینه‌سوتا', 44.7716300, -93.7813500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139873, 'Columbia Heights', 'Columbia Heights', 'City of Columbia Heights,Columbia Heights,Kolambija Khajts,Kolambija-Gajts,Kolambija-Khajts,Kolumbia Khehjts,kwlwmbya hayts,Коламбия-Хайтс,Коламбија Хајтс,Коламбія-Гайтс,Колумбиа Хэйтс,كولومبيا هايتس,کلمبیا هایتس، مینه‌سوتا,کولمبیا ہائٹس، مینیسوٹا', 45.0408000, -93.2630000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139874, 'Coon Rapids', 'Coon Rapids', 'City of Coon Rapids,Coon Rapids,Kun Rapids,Kun-Rapids,kwn rabydz,Кун Рапидс,Кун-Рапидс,Кун-Рапідс,كون رابيدز,کون رپیدز، مینه‌سوتا,کون ریپڈز، مینیسوٹا', 45.1199700, -93.2877300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139875, 'Corcoran', 'Corcoran', 'City of Corcoran,Corcoran,Korkoran,Коркоран', 45.0952400, -93.5474600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139876, 'Cottage Grove', 'Cottage Grove', 'City of Cottage Grove,Cottage Grove,Kotidz Grouv,Kottedzh-Grov,Kottehjdzh Grouv,Kottidzh-Grov,kotijigeulobeu,kwtj ghrwf,Котиџ Гроув,Коттедж-Гров,Коттидж-Гров,Коттэйдж Гроув,كوتج غروف,کاتیج گروو، مینه‌سوتا,کوٹیج گروو، مینیسوٹا,코티지그로브', 44.8277400, -92.9438200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139877, 'Cottonwood', 'Cottonwood', 'City of Cottonwood,Cottonwood', 44.6088500, -95.6741900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139878, 'Crookston', 'Crookston', 'CKN,City of Crookston,Crookston,Krukston,ke lu ke si dun,krwkstwn,Крукстон,كروكستون,کروکستون، مینه‌سوتا,کروکسٹن، مینیسوٹا,克魯克斯頓', 47.7741400, -96.6081200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139879, 'Crosby', 'Crosby', 'City of Crosby,Crosby,Krosbi,Krozbi,krwsby,Крозби,Кросби,Кросбі,كروسبي,کرازبی، مینه‌سوتا,کروزبی، مینیسوٹا', 46.4821800, -93.9577600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139880, 'Cross Lake', 'Cross Lake', 'City of Crosslake,Cross Lake,Crosslake', 46.6594100, -94.1138700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139881, 'Crystal', 'Crystal', 'City of Crystal,Crystal,Kristal,krystal,Кристал,كريستال,کرسٹل، مینیسوٹا,کریستال، مینه‌سوتا', 45.0327400, -93.3602300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139882, 'Dassel', 'Dassel', 'City of Dassel,Dassel', 45.0816300, -94.3069300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139883, 'Dawson', 'Dawson', 'City of Dawson,Davson,Dawson,Doson,dawswn,Давсон,Досон,داوسن، مینه‌سوتا,داوسون,ڈاؤسن، مینیسوٹا', 44.9327400, -96.0544800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139884, 'Dayton', 'Dayton', 'City of Dayton,Dayton,Dehjton,Dejton,daytwn,detana,Дейтон,Дејтон,Дэйтон,دايتون,دیتن، مینه‌سوتا,ڈیٹن، مینیسوٹا,डेटन', 45.2438500, -93.5149600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139885, 'Deephaven', 'Deephaven', 'City of Deephaven,Deephaven', 44.9296900, -93.5224600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139886, 'Delano', 'Delano', 'City of Delano,Crow River,Dehlano,Delano,Delejno,dylanw,Делано,Делејно,Дэлано,دلنو، مینه‌سوتا,ديلانو,ڈیلانو، مینیسوٹا', 45.0419100, -93.7891300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139887, 'Dellwood', 'Dellwood', 'City of Dellwood,Dehlvud,Dellvud,Dellwood,Delvud,dylwwd,Делвуд,Деллвуд,Дэлвуд,دلوود، مینه‌سوتا,ديلوود,ڈیلووڈ، مینیسوٹا', 45.0899700, -92.9724400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139888, 'Detroit Lakes', 'Detroit Lakes', 'City of Detroit Lakes,DTL,Detroit Ezera,Detroit Lakes,Detrojt Lehjks,Detrojt-Lejks,Ditrojt Lejks,dytrwyt lyks,dytrwyt lyks  mynh‌swta,Детроит Езера,Детройт Лэйкс,Детройт-Лейкс,Дитројт Лејкс,ديترويت ليكس,دیترویت لیکس، مینه‌سوتا,ڈیٹروئٹ لیکس، مینیسوٹا', 46.8171800, -95.8453300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139889, 'Dilworth', 'Dilworth', 'City of Dilworth,Diluehrt,Dilvors,Dilvort,Dilworth,dylwwrth,Дилворс,Дилворт,Дилуэрт,Ділворт,ديلوورث,دیلوورث، مینه‌سوتا,ڈلورتھ، مینیسوٹا', 46.8766300, -96.7034100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139890, 'Dodge Center', 'Dodge Center', 'City of Dodge Center,Dodge Center,Dodz Senter,Dodzh Sentr,Dodzh-Senter,dwdj sntr,Додж Сентр,Додж-Сентер,Доџ Сентер,دوج اسنتر، مینه‌سوتا,دودج سنتر,ڈوج سینٹر، مینیسوٹا', 44.0280200, -92.8546400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139891, 'Duluth', 'Duluth', 'City of Duluth,DLH,Dalut,Duljut,Dulut,Dulutas,Duluth,Onigamiinsing,darusu,deolluseu,dlwth  mynh‌swta,du lu si,dulutha,dwlwt,dwlwth,Далут,Дулут,Дълют,Դուլութ,דולות,دلوث، مینه‌سوتا,دولوث,ڈولوتھ، مینیسوٹا,डुलुथ,ダルース,杜魯斯,덜루스', 46.7832700, -92.1065800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139892, 'Dundas', 'Dundas', 'City of Dundas,Dundas', 44.4294100, -93.2018800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139893, 'Eagan', 'Eagan', 'City of Eagan,Eagan,Igan,aygan  mynh‌swta,ayjan,igan,igana,Іґан,Иган,إيجان,ایگان، مینه‌سوتا,ایگان، مینیسوٹا,ईगन,イーガン', 44.8041300, -93.1668900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139894, 'Eagle Lake', 'Eagle Lake', 'City of Eagle Lake,Eagle Lake,Igl Lehjk,Igl Lejk,Igl-Lejk,ayghl lyk,Ігл-Лейк,Игл Лејк,Игл Лэйк,Игл-Лейк,إيغل ليك,ایگل لیک، مینه‌سوتا,ایگل لیک، مینیسوٹا', 44.1649700, -93.8813400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139895, 'East Bethel', 'East Bethel', 'City of East Bethel,East Bethel,Ist Betel,Ist Bezehl,Ist-Betel,ayst bythyl,Іст-Бетел,Ист Безэл,Ист Бетел,Ист-Бетел,إيست بيثيل,ایست بتل، مینه‌سوتا,ایسٹ بیتھل، مینیسوٹا', 45.3194100, -93.2024500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139896, 'East Grand Forks', 'East Grand Forks', 'City of East Grand Forks,East Grand Forks,Ist Grand Forks,Ist-Grand-Forks,ayst ghrand fwrks,dong da fu ke si,isutogurandofokusu,Іст-Ґранд-Форкс,Ист Гранд Форкс,Ист-Гранд-Форкс,إيست غراند فوركس,ایست گرند فورکس، مینه‌سوتا,ایسٹ گرینڈ فورکس، مینیسوٹا,イーストグランドフォークス,東大福克斯', 47.9299800, -97.0245200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139897, 'East Gull Lake', 'East Gull Lake', 'City of East Gull Lake,East Gull Lake', 46.4080200, -94.3558400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139898, 'Eden Prairie', 'Eden Prairie', 'City of Eden Prairie,Eden Prairie,Ehden Prehjraj,Iden Preri,Iden-Preri,aydn bryry,aydn pryry  mynh‌swta,Іден-Прері,Иден Прери,Иден-Прери,Эден Прэйрай,إيدن بريري,ایدن پریری، مینه‌سوتا,ایڈن پریری، مینیسوٹا', 44.8546900, -93.4707900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139899, 'Eden Valley', 'Eden Valley', 'City of Eden Valley,Eden Valley', 45.3260700, -94.5461100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139900, 'Edgerton', 'Edgerton', 'City of Edgerton,Edgerton,Edzerton,Edzherton,Ehdzherton,adjyrtwn,Еджертон,Еџертон,Эджертон,إدجيرتون,اجرتن، مینه‌سوتا,ایجرٹن، مینیسوٹا', 43.8724700, -96.1286400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139901, 'Edina', 'Edina', 'City of Edina,Edina,Idajna,adyna,idaina,Идайна,Идајна,إدينا,ادینا، مینه‌سوتا,ایڈینا، مینیسوٹا,イーダイナ', 44.8896900, -93.3499500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139902, 'Elbow Lake', 'Elbow Lake', 'City of Elbow Lake,Elbow Lake', 45.9941300, -95.9767200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139903, 'Elgin', 'Elgin', 'City of Elgin,Elgin', 44.1302400, -92.2515600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139904, 'Elk River', 'Elk River', 'City of Elk River,Ehlk Riveh,Ehlk-River,Elk River,Elk-River,alk ryfr,Елк Ривер,Елк-Рівер,Элк Ривэ,Элк-Ривер,إلك ريفر,الک ریور، مینه‌سوتا,ელკ-რივერი', 45.3038500, -93.5671800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139905, 'Ely', 'Ely', 'City of Ely,Ehlaj,Eli,Ely,Ili,LYU,aly,illi,yi li,Елі,Или,Элай,إلي,الی، مینه‌سوتا,伊利,일리', 47.9032400, -91.8670900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139906, 'Esko', 'Esko', '', 46.7057800, -92.3632500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139907, 'Eveleth', 'Eveleth', 'City of Eveleth,EVM,Ehvelehs,Ehvlet,Evelet,Eveleth,afylyth,Евелет,Эвелэс,Эвлет,إفيليث,ایولت، مینه‌سوتا', 47.4624300, -92.5399100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139908, 'Excelsior', 'Excelsior', 'City of Excelsior,Excelsior,Ikselsir,akslsywr,Икселсир,إكسلسيور,ایکسلسیر، مینه‌سوتا', 44.9033000, -93.5663500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139909, 'Eyota', 'Eyota', 'City of Eyota,Eyota', 43.9883000, -92.2285000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139910, 'Fairfax', 'Fairfax', 'City of Fairfax,Fairfax', 44.5291300, -94.7208200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139911, 'Fairmont', 'Fairmont', 'City of Fairmont,FRM,Fair Mount,Fairmont,Fajrmont,Fehrmont,Fermont,fyrmwnt,Файрмонт,Фермонт,Фэрмонт,فيرمونت,فیئرمونٹ، مینیسوٹا,فیرمانت، مینه‌سوتا', 43.6521800, -94.4610800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139912, 'Falcon Heights', 'Falcon Heights', 'City of Falcon Heights,Falcon Heights,Falkon Khajts,Falkon-Gajts,Fehlkon Khehjts,Folkon-Khajts,falkwn hayts,Фалкон Хајтс,Фалкон-Гайтс,Фолкон-Хайтс,Фэлкон Хэйтс,فالكون هايتس,فالکن‌هایتس، مینه‌سوتا,فالکون ہیغٹس، مینیسوٹا', 44.9916300, -93.1663300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139913, 'Faribault', 'Faribault', 'City of Faribault,FBL,Fairbault,Fajrbault,Faribault,Faribo,Fehribo,Feribolt,fa li bo,fryblt  mynh‌swta,fyrbawlt,pheribau,Файрбаулт,Фарибо,Феріболт,Фэрибо,فریبلت، مینه‌سوتا,فيرباولت,फेरिबौ,法里博', 44.2949600, -93.2688300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139914, 'Farmington', 'Farmington', 'City of Farmington,Farmington,farmynghtwn,Фармингтон,Фармінґтон,فارمنگٹن، مینیسوٹا,فارمينغتون,فارمینگتن، مینه‌سوتا', 44.6402400, -93.1435500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139915, 'Fergus Falls', 'Fergus Falls', 'City of Fergus Falls,FFM,Fergas Folls,Fergas Fols,Fergus Falls,Fergus-Fols,frghws fwlz,frgs falz  mynh‌swta,fu ge si fu er si,Фергас Фоллс,Фергас Фолс,Фергус-Фолс,Ферґус-Фолс,فرغوس فولز,فرگس فالز، مینه‌سوتا,弗格斯福尔斯', 46.2830200, -96.0775600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139916, 'Foley', 'Foley', 'City of Foley,Folehj,Foley,Foli,fwly,Фоли,Фолэй,Фолі,فولي,فولی، مینه‌سوتا', 45.6646900, -93.9097000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139917, 'Forest Lake', 'Forest Lake', 'City of Forest Lake,Forehst Lehjk,Forest Lake,Forest-Lejk,Forist Lejk,fu li si te lai ke,fwrst lyk,Форест-Лейк,Форист Лејк,Форэст Лэйк,فارست لیکس، مینه‌سوتا,فورست ليك,福里斯特莱克', 45.2788600, -92.9852200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139918, 'Fosston', 'Fosston', 'City of Fosston,Fosston,Foston,fwstwn,Фостон,فوستون,فوستون، مینه‌سوتا', 47.5763500, -95.7514100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139919, 'Frazee', 'Frazee', 'City of Frazee,Frazee,Frazi,Frejzi,frazy,Фрази,Фрейзи,Фрейзі,فرازي,فریزی، مینه‌سوتا', 46.7280100, -95.7008800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139920, 'Fridley', 'Fridley', 'City of Fridley,Fridlehj,Fridley,Fridli,frydly,frydly  mynh‌swta,peulideulli,Фридли,Фридлэй,Фрідлі,فريدلي,فریدلی، مینه‌سوتا,فریڈلی، مینیسوٹا,프리들리', 45.0860800, -93.2632800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139921, 'Fulda', 'Fulda', 'City of Fulda,Fulda,fwlda,Фулда,فولدا,فولدا، مینه‌سوتا', 43.8705200, -95.6002900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139922, 'Gaylord', 'Gaylord', 'City of Gaylord,Gaylord', 44.5530200, -94.2205300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139923, 'Gilbert', 'Gilbert', 'City of Gilbert,Gilbehrt,Gilbert,jylbrt,Гилберт,Гилбэрт,Ґілберт,جيلبرت,گلبرٹ، مینیسوٹا,گیلبرت، مینه‌سوتا', 47.4888200, -92.4649100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139924, 'Glencoe', 'Glencoe', 'City of Glencoe,Glencoe', 44.7691300, -94.1516400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139925, 'Glenwood', 'Glenwood', 'City of Glenwood,Glenwood', 45.6502400, -95.3897600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139926, 'Glyndon', 'Glyndon', 'City of Glyndon,Glyndon', 46.8752400, -96.5789600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139927, 'Golden Valley', 'Golden Valley', 'City of Golden Valley,Golden Vali,Golden Valley,Golden-Vehlli,Golden-Velli,Goldun Vali,Gouldehn Vallehj,ghwldn faly,goldeunbaelli,gwldn wly  mynh‌swta,Голден Вали,Голден-Вэлли,Голдън Вали,Гоулдэн Валлэй,Ґолден-Веллі,غولدن فالي,گولدن ولی، مینه‌سوتا,골든밸리', 45.0096900, -93.3491200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139928, 'Goodhue', 'Goodhue', 'City of Goodhue,Goodhue', 44.4005200, -92.6238000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139929, 'Goodview', 'Goodview', 'City of Goodview,Goodview', 44.0624600, -91.6957100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139930, 'Grand Marais', 'Grand Marais', 'City of Grand Marais,GRM,Grand Marais,Grand Marej,Grand-Marej,Grehnd Marais,ghrand marys,Гранд Мареј,Гранд-Марей,Грэнд Мараис,Ґранд-Марей,غراند ماريس,گرند ماری، مینه‌سوتا', 47.7504500, -90.3342700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139931, 'Grand Meadow', 'Grand Meadow', 'City of Grand Meadow,Grand Meadow,Grand Medou,Grand-Medou,Grand-Medov,Grehnd Midou,ghrand mydwn,Гранд Медоу,Гранд-Медоу,Грэнд Мидоу,Ґранд-Медов,غراند ميدون,گرند مدو، مینه‌سوتا', 43.7058000, -92.5721200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139932, 'Grand Rapids', 'Grand Rapids', 'GPZ,Grand Rapids,Grand-Rapids,Grehnd Rapids,ghrand rabydz,granda repidsa,Гранд Рапидс,Гранд-Рапидс,Грэнд Рапидс,Ґранд-Рапідс,غراند رابيدز,گرند رپیدز، مینه‌سوتا,ग्रांड रॅपिड्स', 47.2371700, -93.5302100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139933, 'Granite Falls', 'Granite Falls', 'City of Granite Falls,Granit Fols,Granit-Fols,Granite Falls,Grehnajt Fols,ghranyt fwlz,Гранит Фолс,Гранит-Фолс,Грэнайт Фолс,Ґраніт-Фолс,غرانيت فولز,گرنیت فالز، مینه‌سوتا', 44.8099600, -95.5455800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139934, 'Grant', 'Grant', '', 45.0844100, -92.9104900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139935, 'Greenfield', 'Greenfield', 'City of Greenfield,Greenfield,Grinfild,Гринфилд', 45.1033000, -93.6913500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139936, 'Hallock', 'Hallock', 'City of Hallock,Hallock', 48.7744300, -96.9464500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139937, 'Ham Lake', 'Ham Lake', 'City of Ham Lake,Gam-Lejk,Ham Lake,Kham Lehjk,Kham Lejk,Kham-Lejk,ham lyk,Гам-Лейк,Хам Лејк,Хам Лэйк,Хам-Лейк,هام ليك,هم لیک، مینه‌سوتا', 45.2502400, -93.2499500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139938, 'Hanover', 'Hanover', 'City of Hanover,Ganover,Hanover,Khanovehr,Khanover,hanwfr,Гановер,Хановер,Хановэр,هانوفر,هانوفر، مینه‌سوتا', 45.1558000, -93.6663500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139939, 'Harris', 'Harris', 'City of Harris,Harris', 45.5863500, -92.9746600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139940, 'Hastings', 'Hastings', 'City of Hastings,Gastings,Hastings,Khejstings,hastynghz,Гастінґс,Хейстингс,Хејстингс,هاستينغز,هیستینگز، مینه‌سوتا', 44.7433000, -92.8524300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139941, 'Hawley', 'Hawley', 'City of Hawley,Goli,Hawley,Khavlehj,Kholi,hawly,Голі,Хавлэй,Холи,هاولي,هاولی، مینه‌سوتا', 46.8807900, -96.3167300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139942, 'Hayfield', 'Hayfield', 'City of Hayfield,Hayfield', 43.8905200, -92.8476900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139943, 'Hector', 'Hector', 'City of Hector,Hector', 44.7438500, -94.7155500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139944, 'Hermantown', 'Hermantown', 'City of Hermantown,Germantaun,Hermantown,Khehrmantaun,Khermantaun,hyrmantawn,Германтаун,Хермантаун,Хэрмантаун,هرمانتاوون، مینه‌سوتا,هيرمانتاون', 46.8068900, -92.2382500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139945, 'Hibbing', 'Hibbing', 'City of Hibbing,HIB,Hibbing,Hibbins,Khibbing,Khibing,hibing,hibingu,hybyngh,Хиббинг,Хибинг,Хіббінг,هيبينغ,هیبینگ، مینه‌سوتا,ہیبانگ، مینیسوٹا,ヒビング,히빙', 47.4271500, -92.9376900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139946, 'Hinckley', 'Hinckley', 'City of Hinckley,Ginkli,Hinckley,Khinklehj,Khinkli,hynkly,Гінклі,Хинкли,Хинклэй,هينكلي,هینکلی، مینه‌سوتا', 46.0113400, -92.9443700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139947, 'Hopkins', 'Hopkins', 'Bushnell,City of Hopkins,Gopkins,Hopkins,Khopins,Khopkins,West Minneapolis,hwbknz,Гопкінс,Хопинс,Хопкинс,هاپکینز، مینه‌سوتا,هوبكنز', 44.9249600, -93.4627300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139948, 'Howard Lake', 'Howard Lake', 'City of Howard Lake,Howard,Howard Lake', 45.0608000, -94.0733100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139949, 'Hoyt Lakes', 'Hoyt Lakes', 'City of Hoyt Lakes,Gojt-Lejks,Hoyt Lakes,Khojt Lehjks,Khojt Lejks,Khojt-Lejks,hwyt lyks,Гойт-Лейкс,Хойт Лэйкс,Хойт-Лейкс,Хојт Лејкс,هويت ليكس,هویت لیکس، مینه‌سوتا', 47.5196500, -92.1385100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139950, 'Hugo', 'Hugo', 'City of Hugo,Hugo,Kh''jugo,Khjugo,hwghw,Хьюго,Хюго,Хюґо,Хјуго,هوغو,هیوگو، مینه‌سوتا', 45.1599700, -92.9932700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139951, 'Hutchinson', 'Hutchinson', 'City of Hutchinson,Gatchinson,Hutchinson,Khachinson,Khatchinson,hwtshynswn,Гатчінсон,Хатчинсон,Хачинсон,هاچینسون، مینه‌سوتا,هوتشينسون', 44.8877400, -94.3697100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139952, 'Independence', 'Independence', 'City of Independence,Independence', 45.0252400, -93.7074600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139953, 'International Falls', 'International Falls', 'City of International Falls,INL,Internashenal-Fols,International Falls,Internehshnal Folls,Interneshnl-Folls,Interneshonal Fols,Koochiching,antrnashwnal fwlz,guo ji pu bu cheng,Інтернешнл-Фоллс,Интернашенал-Фолс,Интернешонал Фолс,Интернэшнал Фоллс,إنترناشونال فولز,اینترنشنال فالز، مینه‌سوتا,國際瀑布城', 48.6010500, -93.4109800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139954, 'Inver Grove Heights', 'Inver Grove Heights', 'City of Inver Grove Heights,Invehr Grouv Khehjts,Inver Grouv Khajts,Inver Grove,Inver Grove Heights,Inver-Grov-Gajts,Inver-Grov-Khajts,Invergrove,anfr ghrwf hayts,Інвер-Ґров-Гайтс,Инвер Гроув Хајтс,Инвер-Гров-Хайтс,Инвэр Гроув Хэйтс,إنفر غروف هايتس,اینور گروو هایتس، مینه‌سوتا,اینور گروو ہائٹس، مینیسوٹا', 44.8480200, -93.0427200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139955, 'Isanti', 'Isanti', 'Ajsanti,City of Isanti,Isanti,aysnty,Айсанти,Ајсанти,Исанти,إيسنتي,ایسانتی، مینه‌سوتا', 45.4902400, -93.2477300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139956, 'Ivanhoe', 'Ivanhoe', 'City of Ivanhoe,Ivanhoe', 44.4633000, -96.2472600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139957, 'Jackson', 'Jackson', 'City of Jackson,Dzekson,Dzhekson,Jackson,Springfield,jaegseun,jakswn,jakuson,Џексон,Джексон,جاكسون,جکسون، مینه‌سوتا,جیکسن، منیسوٹا,ジャクソン,잭슨', 43.6207900, -94.9886000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139958, 'Janesville', 'Janesville', 'City of Janesville,East Janesville,Janesville', 44.1160800, -93.7080000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139959, 'Jordan', 'Jordan', 'City of Jordan,Dzhordan,Dzordan,Jordan,jwrdan,Џордан,Джордан,جردن، مینه‌سوتا,جوردان', 44.6669100, -93.6269000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139960, 'Kasson', 'Kasson', 'City of Kasson,Kasson,kaswn,Кассон,كاسون,کاسون، مینه‌سوتا', 44.0299600, -92.7507400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139961, 'Keewatin', 'Keewatin', 'City of Keewatin,Keewatin,Keewating,Kewadin', 47.3996600, -93.0724200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139962, 'Kenyon', 'Kenyon', 'City of Kenyon,Kenyon', 44.2721900, -92.9854800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139963, 'La Crescent', 'La Crescent', 'City of La Crescent,La Crescent,LaCrescent', 43.8280200, -91.3040300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139964, 'Lake City', 'Lake City', 'Lehjk Siti,Lejk Siti,Lejk-Siti,lyk syty,Лейк-Сити,Лейк-Сіті,Лејк Сити,Лэйк Сити,ليك سيتي,لیک سٹی، منیسوٹا,لیک سیتی، مینه‌سوتا', 44.4496800, -92.2682000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139965, 'Lake Crystal', 'Lake Crystal', 'City of Lake Crystal,Lake Crystal,Lehjk Kristal,Lejk Kristal,Lejk-Kristal,lyk krystal,Лейк-Кристал,Лейк-Крістал,Лејк Кристал,Лэйк Кристал,ليك كريستال,لیک کرسٹل، منیسوٹا,لیک کریستال، مینه‌سوتا', 44.1058000, -94.2188500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139966, 'Lake Elmo', 'Lake Elmo', 'City of Lake Elmo,Lake Elmo,Lehjk Ehlmo,Lejk Elmo,Lejk-Ehlmo,Lejk-Elmo,lyk almw,Лейк-Елмо,Лейк-Элмо,Лејк Елмо,Лэйк Элмо,ليك إلمو,لیک المو، مینه‌سوتا,لیک ایلمو، منیسوٹا', 44.9958000, -92.8793800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139967, 'Zimmerman', 'Zimmerman', 'City of Zimmerman,Lake Fremont,Zimmerman', 45.4433000, -93.5899600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139968, 'Lake Saint Croix Beach', 'Lake Saint Croix Beach', 'City of Lake St. Croix Beach,Lake Saint Croix Beach,Saint Croix Beach', 44.9208000, -92.7668700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139969, 'Lake Shore', 'Lake Shore', 'City of Lake Shore,Lake Shore', 46.4855200, -94.3605600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139970, 'Lakefield', 'Lakefield', 'City of Lakefield,Lakefield', 43.6774600, -95.1716600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139971, 'Lakeland', 'Lakeland', 'City of Lakeland,Lakeland', 44.9563600, -92.7657600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139972, 'Lakeville', 'Lakeville', 'City of Lakeville,Fairfield,Lake Ville,Lakeville,Lakeville Village,Lehjkvill,Lejkvil,Lejkvil'',Lejkvill,lykfyl,lykwyl  mynh‌swta,Лейквилл,Лейквіль,Лејквил,Лэйквилл,ليكفيل,لیک ویل، منیسوٹا,لیکویل، مینه‌سوتا', 44.6496900, -93.2427200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139973, 'Lauderdale', 'Lauderdale', 'City of Lauderdale,Lauderdale', 44.9985800, -93.2057800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139974, 'Le Center', 'Le Center', 'City of Le Center,La Sehntr,Le Center,Le Senter,Le Sueur Center,Le-Senter,ly sntr,Ла Сэнтр,Ле Сентер,Ле-Сентер,له سنتر، مینه‌سوتا,لي سنتر', 44.3894100, -93.7302300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139975, 'Le Sueur', 'Le Sueur', 'City of Le Sueur,Le Suer,Le Sueur,Le-Sur,Leh S''juur,ly swywr,Ле Суер,Ле-Сур,Лэ Сьюур,ل سیور، مینه‌سوتا,لي سويور', 44.4613500, -93.9152400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139976, 'Lester Prairie', 'Lester Prairie', 'City of Lester Prairie,Lester Prairie', 44.8838500, -94.0416400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139977, 'Lewiston', 'Lewiston', 'City of Lewiston,L''juiston,Lewiston,Льюистон', 43.9844100, -91.8693200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139978, 'Lexington', 'Lexington', 'City of Lexington,Lexington', 45.1424700, -93.1632800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139979, 'Lindstrom', 'Lindstrom', 'City of Lindstrom,Lindstroem,Lindstrom,Lindström,lyndstrwm,Линдстром,Ліндстром,ليندستروم,لیندستروم، مینه‌سوتا', 45.3894100, -92.8479900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139980, 'Lino Lakes', 'Lino Lakes', 'City of Lino Lakes,Lajno Lejks,Lajno-Lejks,Lino Lakes,Lino Lehjks,Lino-Lejks,lynw lyks,Лайно-Лейкс,Лајно Лејкс,Лино Лэйкс,Ліно-Лейкс,لينو ليكس,لینو لیکس، مینه‌سوتا', 45.1602400, -93.0888300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139981, 'Litchfield', 'Litchfield', 'City of Litchfield,Lichfild,Litchfield,Litchfild,lytshfyld,Литчфилд,Личфилд,Літчфілд,ليتشفيلد,لیچفیلد، مینه‌سوتا', 45.1271800, -94.5280500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139982, 'Little Canada', 'Little Canada', 'City of Little Canada,Litl Kanada,Litl-Kanada,Littl Kanada,Little Canada,lytl knda,Литл Канада,Литл-Канада,Литтл Канада,Літл-Канада,ليتل كندا,لیتل کانادا، مینه‌سوتا', 45.0269100, -93.0877200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139983, 'Little Falls', 'Little Falls', 'City of Little Falls,Gakaabikaansing,Litl Fols,Litl-Fols,Littl Fols,Little Falls,li te er fu er si,lytl fwlz,Литл Фолс,Литл-Фолс,Литтл Фолс,Літл-Фолс,ليتل فولز,لیتل فالز، مینه‌سوتا,利特尔福尔斯', 45.9763500, -94.3625000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139984, 'Little Rock', 'Little Rock', '', 47.8680100, -95.1105500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139985, 'Long Lake', 'Long Lake', 'City of Long Lake,Long Lake', 44.9866300, -93.5716200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139986, 'Long Prairie', 'Long Prairie', 'City of Long Prairie,Long Prairie,Long Preri,Long-Preri,lwngh brayry,Лонг Прери,Лонг-Прери,Лонґ-Прері,لانگ پریری، مینه‌سوتا,لونغ برايري', 45.9746900, -94.8655800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139987, 'Lonsdale', 'Lonsdale', 'City of Lonsdale,Lonsdale,Lonsdejl,lwnsdyl,Лонсдейл,Лонсдејл,لانزدیل، مینه‌سوتا,لونسديل', 44.4802400, -93.4285600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139988, 'Luverne', 'Luverne', 'City of Luverne,Lu Verne,Lu Verne Village,Luvern,Luverne,lwfyrn,Луверн,لوفيرن,لوورن، مینه‌سوتا', 43.6541400, -96.2128100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139989, 'Madelia', 'Madelia', 'City of Madelia,Madelia', 44.0507900, -94.4183000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139990, 'Madison', 'Madison', 'City of Madison,Madison,Мадисон', 45.0096800, -96.1958800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139991, 'Madison Lake', 'Madison Lake', 'City of Madison Lake,Madison Lake', 44.2044100, -93.8155100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139992, 'Mahnomen', 'Mahnomen', 'City of Mahnomen,Mahnomen', 47.3152400, -95.9686500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139993, 'Mahtomedi', 'Mahtomedi', 'City of Mahtomedi,Mahtomedi', 45.0696900, -92.9516000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139994, 'Mankato', 'Mankato', 'City of Mankato,MKT,Mankato,Mankejto,mankatw,menketo,Манкато,Манкейто,Манкејто,مانكاتو,منکیتو، مینه‌سوتا,مینکیٹو، مینیسوٹا,मॅन्कॅटो', 44.1590600, -94.0091500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139995, 'Mantorville', 'Mantorville', 'City of Mantorville,Mantorvil,Mantorvil'',Mantorvill,Mantorville,mantwrfyl,Манторвил,Манторвилл,Манторвіль,مانتورفيل,مانتورویل، مینه‌سوتا', 44.0691300, -92.7557500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139996, 'Maple Grove', 'Maple Grove', 'City of Maple Grove,Maple Grove,Mehjpl Grouv,Mejpl Grouv,Mejpl-Grov,mabl ghrwf,Мейпл-Гров,Мейпл-Ґров,Мејпл Гроув,Мэйпл Гроув,مابل غروف,میپل گروو، مینه‌سوتا,میپل گروو، مینیسوٹا', 45.0724600, -93.4557900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139997, 'Maple Lake', 'Maple Lake', 'City of Maple Lake,Maple Lake', 45.2291300, -94.0019200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139998, 'Maple Plain', 'Maple Plain', 'City of Maple Plain,Maple Plain', 45.0071900, -93.6557900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(139999, 'Mapleton', 'Mapleton', 'City of Mapleton,Mapleton', 43.9288500, -93.9560600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140000, 'Maplewood', 'Maplewood', 'City of Maplewood,Maplewood,Mehjplvud,Mejplvud,mablwwd,Мејплвуд,Мэйплвуд,مابلوود,میپلووڈ، مینیسوٹا,میپل‌وود، مینه‌سوتا', 44.9530200, -92.9952200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140001, 'Marshall', 'Marshall', 'City of Marshall,MML,Marshal,Marshall,marshal,Маршал,Маршалл,مارشال,مارشال، مینه‌سوتا,مارشل، مینیسوٹا', 44.4469000, -95.7883500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140002, 'Mayer', 'Mayer', 'City of Mayer,Mayer', 44.8849600, -93.8877500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140003, 'Medford', 'Medford', 'City of Medford,Medford,Медфорд', 44.1741300, -93.2463200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140004, 'Medina', 'Medina', 'City of Medina,Medina,Медина', 45.0352400, -93.5824600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140005, 'Melrose', 'Melrose', 'City of Melrose,Mehlrous,Melrose,Melrouz,Melroz,mylrwz,Мелроз,Мелроуз,Мэлроус,ملروز، مینه‌سوتا,ميلروز', 45.6746900, -94.8075200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140006, 'Menahga', 'Menahga', 'City of Menahga,Menahga', 46.7538500, -95.0980800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140007, 'Mendota Heights', 'Mendota Heights', 'City of Mendota Heights,Mendota Heights,Mendota Khajts,Mendota Khehjts,Mendota-Gajts,Mendota-Khajts,myndwta hayts,Мендота Хајтс,Мендота Хэйтс,Мендота-Гайтс,Мендота-Хайтс,مندوتا هایتس، مینه‌سوتا,ميندوتا هايتس', 44.8835800, -93.1382700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140008, 'Milaca', 'Milaca', 'City of Milaca,Milaca', 45.7558000, -93.6544100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140009, 'Minneapolis', 'Minneapolis', 'City of Minneapolis,Gakaabikaang,Gorad Mineapalis,MSP,Min-ni-a-po-li-su,Mineapoli,Mineapolis,Mineapolisa,Mineápolis,Minneapolis,Minneapòlis,Minnéapolis,Minyapolis,Mìn-nì-â-pô-li-sṳ̂,mineaporisu,minepolisa,ming ni a bo li si,ming ni ya bo li si,miniaepolliseu,miniyapolisa,miniyappolis,minniyapolis,mnyapwls,mynyabwls,mynyapwlys,Μινεάπολη,Горад Мінеапаліс,Минеаполис,Миннеаполис,Міннеаполіс,Մինեապոլիս,מיניאפוליס,منیاپولس,مينيابولس,مینیاپولیس,मिनियापोलिस,मिनीयापोलिस,মিনিয়াপোলিস,મિનેપોલિસ,மினியாப்பொலிஸ்,మిన్నియాపోలిస్,ಮಿನ್ನಿಯಾಪೋಲಿಸ್,มินนีแอโพลิส,მინეაპოლისი,ミネアポリス,明尼亞波利斯,明尼阿波利斯,미니애폴리스', 44.9799700, -93.2638400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140010, 'Minneota', 'Minneota', 'City of Minneota,Minneota,Minnesota', 44.5588500, -95.9855900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140011, 'Minnetonka', 'Minnetonka', 'City of Minnetonka,Minitonka,Minnetonka,minetongka,minetonka,mynytwnka,Минитонка,Миннетонка,Міннетонка,مينيتونكا,مینه‌تونکا، مینه‌سوتا,مینیٹونکا، مینیسوٹا,ミネトンカ,미네통카', 44.9133000, -93.5032900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140012, 'Minnetonka Mills', 'Minnetonka Mills', 'Minnetonka,Minnetonka Mills', 44.9410700, -93.4419000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140013, 'Minnetrista', 'Minnetrista', 'City of Minnetrista,Minnetrista', 44.9383000, -93.7177400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140014, 'Montevideo', 'Montevideo', 'City of Montevideo,MVE,Montevideo,Montividio,mwnth‌wydyw  mynh‌swta,mwntyfydyw,Монтевидео,Монтевідео,Монтивидио,مونته‌ویدئو، مینه‌سوتا,مونتيفيديو', 44.9480300, -95.7170100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140015, 'Montgomery', 'Montgomery', 'City of Montgomery,Montgomehri,Montgomeri,Montgomery,mwntghmry,Монтгомери,Монтгомэри,مونتغمري,مونتگومری، مینه‌سوتا,مونٹگمری، مینیسوٹا', 44.4388500, -93.5813400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140016, 'Monticello', 'Monticello', 'City of Monticello,Monticello,Montikehllo,Montisello,Montiselo,mwntayslw,Монтикэлло,Монтиселло,Монтисело,Монтіселло,مانتیسلو، مینه‌سوتا,مونتايسلو', 45.3055200, -93.7941400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140017, 'Montrose', 'Montrose', 'City of Montrose,Montrose', 45.0649600, -93.9110800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140018, 'Moorhead', 'Moorhead', 'City of Moorhead,Moorhead,Murkhed,Murkhid,mu er hei de,mwrhyd,Мурхед,Мурхид,مورهد، مینه‌سوتا,مورهيد,مورہیڈ، مینیسوٹا,穆爾黑德', 46.8738600, -96.7695100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140019, 'Moose Lake', 'Moose Lake', 'City of Moose Lake,Moose Lake,Mus Lehjk,Mus Lejk,Mus-Lejk,mws lyk,Мус Лејк,Мус Лэйк,Мус-Лейк,موس ليك,موس لیک، مینه‌سوتا', 46.4541100, -92.7618700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140020, 'Mora', 'Mora', 'City of Mora,Mora,mwra,Мора,مورا,مورا، مینه‌سوتا', 45.8769000, -93.2938400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140021, 'Morris', 'Morris', 'City of Morris,Moris,Morris,mwrys,Морис,Моррис,Морріс,موريس,موریس، مینه‌سوتا', 45.5860700, -95.9139400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140022, 'Mound', 'Mound', 'City of Mound,Maund,Mound,mwnd,Маунд,ماوند، مینه‌سوتا,موند', 44.9366300, -93.6660700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140023, 'Mounds View', 'Mounds View', 'City of Mounds View,Maunds Vju,Maunds-V''ju,Maunds-Vju,Mounds View,mwnd fyw,Маундс Вю,Маундс Вју,Маундс-Вью,Маундс-Вю,ماوندز ویو، مینه‌سوتا,موند فيو', 45.1049700, -93.2085600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140024, 'Mountain Iron', 'Mountain Iron', 'City of Mountain Iron,Mountain Iron', 47.5324300, -92.6235100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140025, 'Mountain Lake', 'Mountain Lake', 'City of Mountain Lake,Mountain Lake', 43.9388500, -94.9297100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140026, 'New Brighton', 'New Brighton', 'City of New Brighton,N''ju Brajton,N''ju-Brajton,New Brighton,Nju Brajton,nyw braytwn,Њу Брајтон,Нью Брайтон,Нью-Брайтон,نيو برايتون,نیو برایتن، مینه‌سوتا', 45.0655200, -93.2018900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140027, 'New Hope', 'New Hope', 'City of New Hope,N''ju Khoup,N''ju-Gop,N''ju-Khop,New Hope,Nju Khoup,nyw hwb,Њу Хоуп,Нью Хоуп,Нью-Гоп,Нью-Хоп,نيو هوب,نیو هوپ، مینه‌سوتا', 45.0380200, -93.3866200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140028, 'New London', 'New London', 'City of New London,N''ju-London,New London,Нью-Лондон', 45.3010800, -94.9441800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140029, 'New Prague', 'New Prague', 'City of New Prague,N''ju Pragju,N''ju-Praga,N''ju-Prejg,New Prague,Nju Prag,Prague,Prague Village,nyw bragh,Њу Праг,Нью Прагю,Нью-Праґа,Нью-Прейг,نيو براغ,نیو پراگ، مینه‌سوتا', 44.5433000, -93.5760700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140030, 'New Richland', 'New Richland', 'City of New Richland,New Richland', 43.8938500, -93.4938300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140031, 'New Ulm', 'New Ulm', 'City of New Ulm,N''ju Ulm,N''ju-Alm,New Ulm,Nju Ulm,Nova Ulma,ULM,nyueolleum,nyw awlm,nyw awlm  mynh‌swta,Њу Улм,Нью Улм,Нью-Алм,نيو أولم,نیو اولم، مینه‌سوتا,뉴얼름', 44.3124600, -94.4605300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140032, 'New York Mills', 'New York Mills', 'City of New York Mills,New York Mills', 46.5180200, -95.3761500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140033, 'Newport', 'Newport', 'City of Newport,N''juport,Newport,Njuport,nywbwrt,Њупорт,Ньюпорт,نوپرت، مینه‌سوتا,نيوبورت,نیوپورٹ، مینیسوٹا', 44.8663600, -93.0004900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140034, 'Nicollet', 'Nicollet', 'City of Nicollet,Nicollet', 44.2760800, -94.1874600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140035, 'Nisswa', 'Nisswa', 'City of Nisswa,Nissua,Nissva,Nisswa,nyswa,Ниссва,Ниссуа,Ніссва,نيسوا,نیسوا، مینه‌سوتا', 46.5205200, -94.2886100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140036, 'North Branch', 'North Branch', 'Branch,City of North Branch,Nors Brehnch,Nort Branch,Nort-Branch,North Branch,nwrth bransh,Норс Брэнч,Норт Бранч,Норт-Бранч,نورث برانش,نورث برنچ، مینه‌سوتا', 45.5113500, -92.9802200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140037, 'North Mankato', 'North Mankato', 'City of North Mankato,Nors Mankato,Nort Mankato,Nort-Mankejto,North Mankato,nwrth mankatw,Норс Манкато,Норт Манкато,Норт-Манкейто,نورث مانكاتو,نورث منکیتو، مینه‌سوتا', 44.1733000, -94.0338500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140038, 'North Oaks', 'North Oaks', 'City of North Oaks,Nors Oaks,Nort Ouks,Nort-Oks,North Oaks,nwrth awks,Норс Оакс,Норт Оукс,Норт-Окс,نورث أوكس,نورث اوکس، مینه‌سوتا', 45.1027400, -93.0791100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140039, 'North Saint Paul', 'North Saint Paul', 'Castle,City of North Saint Paul,North Saint Paul', 45.0124700, -92.9918800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140040, 'Northfield', 'Northfield', 'City of Northfield,Norsfild,Nortfild,Northfield,nosufirudo,nuo si fei er de,nwrthfyld,Норсфилд,Нортфилд,Нортфілд,نارتھفیلڈ، مینیسوٹا,نورثفيلد,نورثفیلد، مینه‌سوتا,ノースフィールド,諾斯菲爾德', 44.4583000, -93.1616000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140041, 'Norwood (historical)', 'Norwood (historical)', '', 44.7680200, -93.9274700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140042, 'Norwood Young America', 'Norwood Young America', 'City of Norwood,City of Norwood Young America,City of Young America,Norsvud Jang Amerika,Norvud Jang Amerika,Norvud-Jang-Amerika,Norwood,Norwood Young America,Young America,nwrwwd ywngh amryka,Норвуд Јанг Америка,Норвуд-Янг-Америка,Норсвуд Янг Америка,نوروود يونغ أمريكا,نوروود یانگ آمریکا، مینه‌سوتا,نورووڈ ینگ امیریکا، مینیسوٹا', 44.7735700, -93.9216300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140043, 'Oak Grove', 'Oak Grove', '', 45.3408000, -93.3269000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140044, 'Oak Park Heights', 'Oak Park Heights', 'City of Oak Park Heights,Oak Park Heights', 45.0313600, -92.7929800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140045, 'Oakdale', 'Oakdale', 'City of Oakdale,Oakdale,Oakdehjl,Okdejl,Oukdejl,awkdl,Оакдэйл,Окдейл,Оукдејл,أوكدل,اوکدیل، مینه‌سوتا,اوکڈیل، مینیسوٹا', 44.9630200, -92.9649400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140046, 'Oakport', 'Oakport', '', 46.9319100, -96.7789700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140047, 'Olivia', 'Olivia', 'City of Olivia,Olivia', 44.7763500, -94.9897200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140048, 'Orono', 'Orono', 'City of Orono,Orono,awrwnw,Ороно,أورونو,ارونو، مینه‌سوتا', 44.9713500, -93.6044000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140049, 'Oronoco', 'Oronoco', 'City of Oronoco,Oronoco,Oronoko,awrwnwkw,Ороноко,أورونوكو,ارونوکو، مینه‌سوتا', 44.1660800, -92.5349100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140050, 'Ortonville', 'Ortonville', 'Ortnvil,Ortonvil'',Ortonvill,awrtwnfyl,Ортнвил,Ортонвилл,Ортонвіль,أورتونفيل,اورتونویل، مینه‌سوتا', 45.3046900, -96.4447800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140051, 'Osakis', 'Osakis', 'City of Osakis,Osakis', 45.8669100, -95.1522500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140052, 'Osseo', 'Osseo', 'City of Osseo,Osseo', 45.1194100, -93.4024500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140053, 'Otsego', 'Otsego', '', 45.2741300, -93.5913500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140054, 'Owatonna', 'Owatonna', 'City of Owatonna,OWA,Ovatona,Ovatonna,Owatonna,awatwna,owatona,Оватона,Оватонна,أواتونا,اواٹانا، مینیسوٹا,اوواتانا، مینه‌سوتا,오와토나', 44.0838500, -93.2260400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140055, 'Park Rapids', 'Park Rapids', 'City of Park Rapids,Park Rapids,Park-Rapids,bark rabydz,Парк Рапидс,Парк-Рапидс,Парк-Рапідс,بارك رابيدز,پارک رپیدز، مینه‌سوتا', 46.9221800, -95.0586300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140056, 'Parkers Prairie', 'Parkers Prairie', 'Parker''s Prairie,Parkers Prairie', 46.1530200, -95.3289200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140057, 'Parkville', 'Parkville', '', 47.5310400, -92.5790700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140058, 'Paynesville', 'Paynesville', 'City of Paynesville,New Paynesville,Paynesville', 45.3805200, -94.7119500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140059, 'Pelican Rapids', 'Pelican Rapids', 'City of Pelican Rapids,Pelican Rapids', 46.5707900, -96.0831100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140060, 'Pequot Lakes', 'Pequot Lakes', 'City of Pequot Lakes,Pequot Lakes', 46.6030200, -94.3094400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140061, 'Perham', 'Perham', 'City of Perham,Pehrkham,Peram,Pergem,Perham,Perkhem,byrham,Перам,Пергем,Перхем,Пэрхам,بيرهام,پرهام، مینه‌سوتا', 46.5944000, -95.5725400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140062, 'Pierz', 'Pierz', 'City of Pierz,Pajrz,Pierz,Pirz,byrz,Пайрз,Пирз,Пірз,بيرز,پیرز، مینه‌سوتا', 45.9816300, -94.1047100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140063, 'Pine City', 'Pine City', 'Pajn Siti,Pajn-Siti,byn syty,Пайн Сити,Пайн-Сити,Пайн-Сіті,Пајн Сити,بين سيتي,پاین سیتی، مینه‌سوتا', 45.8260700, -92.9685400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140064, 'Pine Island', 'Pine Island', 'City of Pine Island,Pine Island', 44.2013500, -92.6463000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140065, 'Pipestone', 'Pipestone', 'City of Pipestone,Pajpston,Pajpstoun,Pipestone,Pipestone City,baybstwn,Пайпстон,Пайпстоун,Пајпстон,بايبستون,پایپستون، مینه‌سوتا', 44.0005300, -96.3175300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140066, 'Plainview', 'Plainview', 'Centerville,City of Plainview,Plainview', 44.1649700, -92.1715600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140067, 'Plymouth', 'Plymouth', 'City of Plymouth,Plajmaus,Plimut,Plymouth,blymwth,Плаймаус,Плимут,Плімут,بليموث,پلایماؤت، مینیسوٹا,پلیموث، مینه‌سوتا', 45.0105200, -93.4555100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140068, 'Preston', 'Preston', 'City of Preston,Preston', 43.6702400, -92.0832200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140069, 'Princeton', 'Princeton', 'City of Princeton,Princeton,Prinston,Принстон', 45.5699700, -93.5816300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140070, 'Prior Lake', 'Prior Lake', 'City of Prior Lake,Prajor Lejk,Prajor-Lejk,Prior Lake,Prior Lehjk,brywr lyk,Прайор-Лейк,Прајор Лејк,Приор Лэйк,بريور ليك,پریر لیک، مینه‌سوتا', 44.7133000, -93.4227300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140071, 'Proctor', 'Proctor', 'City of Proctor,Proctor,Proctor Knott,Proctorknott,Proktor,brwktwr,Проктор,بروكتور,پراکتر، مینه‌سوتا', 46.7471600, -92.2254700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140072, 'Ramsey', 'Ramsey', 'City of Ramsey,Ramsehj,Ramsey,Ramsi,Remzi,ramsy,Рамси,Рамсэй,Рамсі,Ремзи,رامسي,رمزی، مینه‌سوتا,ریمسی، مینیسوٹا', 45.2611000, -93.4500000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140073, 'Red Lake', 'Red Lake', 'Red Lake,Wabacing', 47.8763500, -95.0169400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140074, 'Red Lake Falls', 'Red Lake Falls', 'City of Red Lake Falls,Red Lake Falls', 47.8821900, -96.2742100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140075, 'Red Wing', 'Red Wing', 'City of Red Wing,Red Ving,Red Wing,Red-Uing,Red-Ving,ledeuwing,ryd wyngh,Ред Винг,Ред-Вінґ,Ред-Уинг,رد وینگ، مینه‌سوتا,ريد وينغ,레드윙', 44.5624700, -92.5338000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140076, 'Redby', 'Redby', 'Madaabiimong,Redby', 47.8785700, -94.9130500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140077, 'Redwood Falls', 'Redwood Falls', 'City of North Redwood,City of Redwood Falls,RWF,Redvud Fols,Redvud-Fols,Redwood Falls,Rehdvud Folls,rydwwd fwlz,Редвуд Фолс,Редвуд-Фолс,Рэдвуд Фоллс,ردوود فالز، مینه‌سوتا,ريدوود فولز,ریڈووڈ فالز، مینیسوٹا', 44.5394000, -95.1169400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140078, 'Renville', 'Renville', 'City of Renville,Renville', 44.7891300, -95.2116700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140079, 'Rice', 'Rice', 'City of Rice,Rajs,Rice,rays,Райс,Рајс,رايس,رایس، مینه‌سوتا', 45.7519100, -94.2202700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140080, 'Richfield', 'Richfield', 'City of Richfield,Richfield,Richfild,rytshfyld,Ричфилд,Річфілд,ريتشفيلد,رچفیلڈ، مینیسوٹا,ریچفیلد، مینه‌سوتا', 44.8833000, -93.2830000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140081, 'Richmond', 'Richmond', 'City of Richmond,Richmond,Ричмонд', 45.4541300, -94.5183300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140082, 'Robbinsdale', 'Robbinsdale', 'City of Robbinsdale,Robbinsdale,Robbinsdejl,Robinsdejl,rwbynsdl,Роббинсдейл,Роббінсдейл,Робинсдејл,رابینزدیل، مینه‌سوتا,روبينسدل', 45.0321900, -93.3385600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140083, 'Rochester', 'Rochester', 'City of Rochester,RST,Rochester,Rochestur,locheseuteo,luo che si te,rachstr  mynh‌swta,rochesuta,rwtshystr,rwzstr,Рочестер,Рочестър,רוצסטר,راچستر، مینه‌سوتا,روتشيستر,روچیسٹر، مینیسوٹا,ロチェスター,羅徹斯特,로체스터', 44.0216300, -92.4699000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140084, 'Rock Creek', 'Rock Creek', 'City of Rock Creek,Rock Creek', 45.7574600, -92.9624300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140085, 'Rockford', 'Rockford', 'City of Rockford,Rockford,Rokford,rwkfwrd,Рокфорд,راکفورد، مینه‌سوتا,روكفورد', 45.0883000, -93.7344100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140086, 'Rockville', 'Rockville', 'City of Rockville,Rockville,Rokvil,Rokvil'',Rokvill,rwkfyl,Роквил,Роквилл,Роквіль,راکویل، مینه‌سوتا,روكفيل', 45.4719100, -94.3408300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140087, 'Rogers', 'Rogers', 'City of Rogers,Rodzers,Rodzhehrs,Rodzhers,Rogers,rwjrz,Роджерс,Роджэрс,Роџерс,راجرز، مینه‌سوتا,روجرز', 45.1888500, -93.5530100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140088, 'Roseau', 'Roseau', 'City of Roseau,ROX,Roseau,Rosiu,Roso,Rozo,rwzyw,Розо,Росиу,Росо,روزيو,روسو، مینه‌سوتا', 48.8460900, -95.7627700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140089, 'Rosemount', 'Rosemount', 'City of Rosemount,Rosemount,Rosmaunt,Rousmaunt,Rouzmaunt,rwsymawnt,Росмаунт,Роузмаунт,Роусмаунт,رزماونت، مینه‌سوتا,روسيماونت', 44.7394100, -93.1257700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140090, 'Roseville', 'Roseville', 'City of Roseville,Roseville,Rousvill,Rouzvil,Rozvell,Rozvil'',Rozvill,lojeubil,rwzfyl,rwzwyl  mynh‌swta,Розвелл,Розвилл,Розвіль,Роузвил,Роусвилл,روزفيل,روزویل، مینه‌سوتا,روزویل، مینیسوٹا,로즈빌', 45.0060800, -93.1566100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140091, 'Royalton', 'Royalton', 'City of Royalton,Rojalton,Royalton,rwyaltwn,Ройалтон,Роялтон,Ројалтон,رويالتون,رویالتون، مینه‌سوتا', 45.8299700, -94.2936100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140092, 'Rush City', 'Rush City', 'Rash Siti,Rash-Siti,rwsh syty,Раш Сити,Раш-Сити,Раш-Сіті,راش سیتی، مینه‌سوتا,روش سيتي', 45.6855100, -92.9654900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140093, 'Rushford', 'Rushford', 'City of Rushford,Rashfold,Rashford,Rushford,rwshfwrd,Рашфолд,Рашфорд,راشفورد، مینه‌سوتا,روشفورد', 43.8083000, -91.7529300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140094, 'Saint Anthony', 'Saint Anthony', 'City of Saint Anthony,Saint Anthony', 45.0205200, -93.2180000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140095, 'Saint Augusta', 'Saint Augusta', '', 45.4785800, -94.1541500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140096, 'Saint Bonifacius', 'Saint Bonifacius', 'City of Saint Bonifacius,Saint Bonifacius', 44.9055200, -93.7474600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140097, 'Saint Charles', 'Saint Charles', 'City of Saint Charles,Saint Charles,Sent-Charl''z,Сент-Чарльз', 43.9694100, -92.0643300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140098, 'Saint Cloud', 'Saint Cloud', 'City of Saint Cloud,Ozaagiiziibiing,STC,Saint Cloud,St. Cloud', 45.5608000, -94.1624900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140099, 'Saint Francis', 'Saint Francis', 'City of Saint Francis,Saint Francis', 45.3869100, -93.3594000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140100, 'Saint James', 'Saint James', 'City of Saint James,Saint James,Sent-Dzhejms,Сент-Джеймс', 43.9824600, -94.6269200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140101, 'Saint Joseph', 'Saint Joseph', 'City of Saint Joseph,Saint Joseph,Sent-Dzhozef,Сент-Джозеф', 45.5649600, -94.3183300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140102, 'Saint Louis Park', 'Saint Louis Park', 'City of Saint Louis Park,Saint Louis Park', 44.9483000, -93.3480100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140103, 'Saint Michael', 'Saint Michael', 'City of Saint Michael,Saint Michael', 45.2099600, -93.6649600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140104, 'Saint Paul', 'Saint Paul', 'City of Saint Paul,Gorad Sent-Pol,Imnizha ska,Saint Paul,Saint Pol,San Pablo,Sejnt Pol,Sent Pol,Sent Polas,Sent Pols,Sent-Pol,Sentpola,Sint-Paul,St. Paul,Urbs Sancti Pauli de Minnesota,ceyint pal,saint pal,sant bawl,santa pala,seinteupol,senta pala,senta pola,sentoporu,sentphxl,sheng bao luo,synt pl  mynh‌swta,syynt pwl,Σαιντ Πωλ,Горад Сент-Пол,Сейнт Пол,Сент Пол,Сент-Пол,Սեյնթ Փոլ,סיינט פול,سانت باول,سینت پل، مینه‌سوتا,سینٹ پال,سینٹ پال، مینیسوٹا,सन्त पल,सेंट पॉल,सेन्त पल,सैन्ट् पाल्,செயின்ட் பால்,เซนต์พอล,სენტ-პოლი,セントポール,圣保罗,세인트폴', 44.9444100, -93.0932700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140105, 'Saint Paul Park', 'Saint Paul Park', 'City of Saint Paul Park,Saint Paul Park', 44.8421900, -92.9913200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140106, 'Saint Peter', 'Saint Peter', 'City of Saint Peter,Saint Peter', 44.3235800, -93.9580100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140107, 'Sandstone', 'Sandstone', 'City of Sandstone,Sandston,Sandstone,Sehndstoun,sandstwn,Сандстон,Сэндстоун,ساندستون,سندستوون، مینه‌سوتا', 46.1310600, -92.8674200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140108, 'Sartell', 'Sartell', 'City of Sartell,Sartehll,Sartell,sartyl,srtl  mynh‌swta,Сартелл,Сартэлл,سارتيل,سرتل، مینه‌سوتا', 45.6216300, -94.2069400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140109, 'Sauk Centre', 'Sauk Centre', 'City of Sauk Centre,Sauk Center,Sauk Centre,Sauk Sentr,Sok Senter,Sok Sentur,Sok-Senter,Sok-Sentr,swk sntr,Саук Сентр,Сок Сентер,Сок Сентър,Сок-Сентер,Сок-Сентр,ساوک اسنتر، مینه‌سوتا,سوك سنتر', 45.7374700, -94.9525200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140110, 'Sauk Rapids', 'Sauk Rapids', 'City of Sauk Rapids,Sauk Rapids,Sok Rapids,Sok-Rapids,swk rabydz,Саук Рапидс,Сок Рапидс,Сок-Рапидс,Сок-Рапідс,سوك رابيدز,سوک رپیدز، مینه‌سوتا', 45.5919100, -94.1661000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140111, 'Savage', 'Savage', 'City of Savage,Hamilton,Savage,Savazh,Savidz,Savidzh,safagh,Саваж,Савидж,Савиџ,سافاغ,ساوج، مینه‌سوتا,سیویج، مینیسوٹا', 44.7791300, -93.3363400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140112, 'Scandia', 'Scandia', 'Skandia,Skandija,skandya,Скандиа,Скандия,Скандија,Скандія,اسکندیا، مینه‌سوتا,سكانديا', 45.2535800, -92.8057700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140113, 'Shafer', 'Shafer', 'City of Shafer,Shafer', 45.3869100, -92.7477100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140114, 'Shakopee', 'Shakopee', 'City of Shakopee,Shakopee,Shakopi,Shejkope,shakpy  mynh‌swta,shakwby,Шакопи,Шакопі,Шейкопе,شاكوبي,شاکوپی، مینیسوٹا,شاکپی، مینه‌سوتا', 44.7980200, -93.5269000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140115, 'Sherburn', 'Sherburn', 'City of Sherburn,Sherburn,Sherburne', 43.6521800, -94.7269200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140116, 'Shoreview', 'Shoreview', 'City of Shoreview,Shoreview,Shorv''ju,Shorvju,shwrfyw,Шорвью,Шорвю,Шорвју,شورفيو,شورویئو، مینیسوٹا,شورویو، مینه‌سوتا', 45.0791300, -93.1471700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140117, 'Shorewood', 'Shorewood', 'City of Shorewood,Shorewood', 44.9008000, -93.5891200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140118, 'Silver Bay', 'Silver Bay', 'City of Silver Bay,Silvehr Behj,Silver Bay,Silver Bay Harbor,Silver Bej,Silver-Bej,sylfr bay,Силвер Беј,Силвер-Бей,Силвэр Бэй,Сілвер-Бей,سيلفر باي,سیلور بی، مینه‌سوتا', 47.2943600, -91.2573900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140119, 'Slayton', 'Slayton', 'City of Slayton,NSL,Slayton,Slehjton,Slejton,slaytwn,Слейтон,Слејтон,Слэйтон,اسلی‌تن، مینه‌سوتا,سلايتون', 43.9877400, -95.7558500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140120, 'Sleepy Eye', 'Sleepy Eye', 'City of Sleepy Eye,Loreno,Sleepeye,Sleepy Eye,Sleepyeye,Slipi Aj,Slipi-Aj,Village of Sleepy Eye Lake,slyby ay,Слипи Ай,Слипи Ај,Слипи-Ай,Сліпі-Ай,اسلیپی آی، مینه‌سوتا,سليبي أي', 44.2971800, -94.7241500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140121, 'South Saint Paul', 'South Saint Paul', 'City of South Saint Paul,South Saint Paul', 44.8927400, -93.0349400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140122, 'Spicer', 'Spicer', 'City of Spicer,Spicer', 45.2330200, -94.9400100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140123, 'Spring Grove', 'Spring Grove', 'City of Spring Grove,Spring Grove', 43.5610800, -91.6359800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140124, 'Spring Lake Park', 'Spring Lake Park', 'City of Spring Lake Park,Spring Lake Park,Spring Lehjk Park,Spring Lejk Park,Spring-Lejk-Park,sbryngh lyk bark,Спринг Лејк Парк,Спринг Лэйк Парк,Спринг-Лейк-Парк,Спрінґ-Лейк-Парк,اسپرینگ لیک پارک، مینه‌سوتا,سبرينغ ليك بارك', 45.1077400, -93.2380000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140125, 'Spring Park', 'Spring Park', 'City of Spring Park,Spring Park', 44.9352400, -93.6321800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140126, 'Spring Valley', 'Spring Valley', 'City of Spring Valley,Spring Valley,Spring-Vehlli,Спринг-Вэлли', 43.6869100, -92.3890600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140127, 'Springfield', 'Springfield', 'Burns,City of Springfield,Springfield,Springfild,sbrynghfyld,Спрингфилд,Спрінґфілд,اسپرینگفیلد، مینه‌سوتا,سبرينغفيلد,سپرنگفیلڈ، مینیسوٹا', 44.2388500, -94.9758200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140128, 'Saint Augusta', 'Saint Augusta', '', 45.4583000, -94.1980400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140129, 'Stacy', 'Stacy', 'City of Stacy,Stacy', 45.3980200, -92.9874400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140130, 'Staples', 'Staples', 'City of Staples,Staples,Staples Mill,Stejpls,stablys,Стейплс,Стејплс,استپل، مینه‌سوتا,ستابليس', 46.3555200, -94.7922400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140131, 'Starbuck', 'Starbuck', 'City of Starbuck,Starbak,Starbuck,starbwk,Старбак,استارباک، مینه‌سوتا,ستاربوك', 45.6144000, -95.5311500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140132, 'Stewartville', 'Stewartville', 'City of Stewartville,St''juartvil'',St''juartvill,Stehvartvill,Stewartville,Stewartville/Minnesota,Stjuartvil,stywartfyl,Стьюартвилл,Стьюартвіль,Стэвартвилл,Стјуартвил,استیوارتویل، مینه‌سوتا,ستيوارتفيل', 43.8555200, -92.4885100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140133, 'Stillwater', 'Stillwater', 'City of Stillwater,Stilluatehr,Stilluoter,Stillvoter,Stillwater,Stilvoter,seutil-woteo,stylwwtr,Стилвотер,Стиллуатэр,Стиллуотер,Стіллвотер,استیل‌واتر، مینه‌سوتا,ستيلووتر,스틸워터', 45.0563600, -92.8060400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140134, 'Taylors Falls', 'Taylors Falls', 'City of Taylors Falls,Taylor''s Falls,Taylors Falls,Tehjlors Fols,Tejlors Fols,Tejlors-Fols,taylwr fwlz,Тейлорс-Фолс,Тејлорс Фолс,Тэйлорс Фолс,تايلور فولز,تیلورز فالز، مینه‌سوتا', 45.4019100, -92.6524300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140135, 'Thief River Falls', 'Thief River Falls', 'City of Thief River Falls,Sajf Riveh Fols,TVF,Thief River Falls,Tif River Fols,Tif-River-Fols,thyf ryfr fwlz,Сайф Ривэ Фолс,Тиф Ривер Фолс,Тиф-Ривер-Фолс,Тіф-Рівер-Фолс,تیف ریور فالز، مینه‌سوتا,ثيف ريفر فولز', 48.1191400, -96.1811500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140136, 'Tonka Bay', 'Tonka Bay', 'City of Tonka Bay,Tonka Bay', 44.9085700, -93.5930100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140137, 'Tracy', 'Tracy', 'City of Tracy,Tracy,Trejsi,Трейси', 44.2332900, -95.6191800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140138, 'Truman', 'Truman', 'City of Truman,Truman', 43.8277300, -94.4371900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140139, 'Two Harbors', 'Two Harbors', 'City of Two Harbors,Tu Kharbors,Tu-Kharbors,Two Harbors,to~uhabazu,tw harbwrs,Ту Харборс,Ту-Харборс,تو هاربر، مینه‌سوتا,تو هاربورس,トゥーハーバーズ', 47.0227100, -91.6707300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140140, 'Tyler', 'Tyler', 'City of Tyler,Tajlehr,Tajler,Tyler,taylr,taylr  mynswta,Тайлер,Тайлэр,Тајлер,تايلر,تایلر، مینسوتا', 44.2783000, -96.1347500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140141, 'Vadnais Heights', 'Vadnais Heights', 'City of Vadnais Heights,Vadnais Heights', 45.0574700, -93.0738300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140142, 'Victoria', 'Victoria', 'City of Victoria,Victoria,Viktoria,Viktorija,fyktwrya,Викториа,Виктория,Викторија,Вікторія,فيكتوريا,وکٹوریہ، مینیسوٹا,ویکتوریا، مینه‌سوتا', 44.8585700, -93.6616300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140143, 'Vineland', 'Vineland', '', 46.1635700, -93.7574700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140144, 'Virginia', 'Virginia', 'City of Virginia,Franklin,Verdzhinija,Virdzhinia,Virdzhinija,Virdzinija,Virginia,beojinia,fyrjynya,Верджиния,Вирджиниа,Вирџинија,Вірджинія,فيرجينيا,ویرجینیا، مینه‌سوتا,버지니아', 47.5232600, -92.5365700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140145, 'Wabasha', 'Wabasha', 'City of Wabasha,Cratte''s Landing,Uabasha,Vabasha,Vobasha,Vobasho,Wabasha,wabasha,wobeosyo,Вабаша,Вобаша,Вобашо,Уабаша,واباشا,واباشا، مینه‌سوتا,워버쇼', 44.3838600, -92.0329400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140146, 'Waconia', 'Waconia', 'City of Waconia,Waconia,wakwnya,واكونيا,واکونیا، مینه‌سوتا', 44.8508000, -93.7869100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140147, 'Wadena', 'Wadena', 'City of Wadena,Wadena', 46.4424600, -95.1361400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140148, 'Waite Park', 'Waite Park', 'City of Waite Park,Waite Park', 45.5571900, -94.2241600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140149, 'Walker', 'Walker', 'City of Walker,Uoker,Valkehr,Voker,Walker,wwkr,Валкэр,Вокер,Уокер,واکر، مینه‌سوتا,ووكر', 47.1013500, -94.5872200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140150, 'Wanamingo', 'Wanamingo', 'City of Wanamingo,Wanamingo', 44.3044100, -92.7904700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140151, 'Warren', 'Warren', 'City of Warren,Uorren,Varrehn,Voren,Vorren,Warren,wwryn,Варрэн,Ворен,Воррен,Уоррен,وارن، مینه‌سوتا,وورين', 48.1966400, -96.7728400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140152, 'Warroad', 'Warroad', 'City of Warroad,RRT,Uorrod,Varroad,Varrud,Voroud,Warroad,wwrwd,Варроад,Варруд,Вороуд,Уоррод,وارود، مینه‌سوتا,وورود', 48.9052700, -95.3144000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140153, 'Waseca', 'Waseca', 'City of Waseca,Uosika,Vasehka,Vosika,Waseca,wasyka,wska  mynh‌swta,Васэка,Восика,Восіка,Уосика,واسيكا,وسکا، مینه‌سوتا', 44.0777400, -93.5074400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140154, 'Watertown', 'Watertown', 'City of Watertown,Watertown', 44.9635700, -93.8471900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140155, 'Waterville', 'Waterville', 'City of Waterville,Waterville', 44.2188500, -93.5680000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140156, 'Waverly', 'Waverly', 'City of Waverly,Waverly', 45.0666300, -93.9663600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140157, 'Wayzata', 'Wayzata', 'City of Wayzata,Uajzeta,Vajzata,Vehjzata,Wayzata,wyzata,Вайзата,Вэйзата,Уайзета,وایزتا، مینه‌سوتا,ويزاتا', 44.9741300, -93.5066200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140158, 'Wells', 'Wells', 'City of Wells,Wells', 43.7460700, -93.7288400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140159, 'West Coon Rapids', 'West Coon Rapids', '', 45.1596900, -93.3496700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140160, 'West Saint Paul', 'West Saint Paul', 'City of West Saint Paul,West Saint Paul', 44.9160800, -93.1016100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140161, 'Wheaton', 'Wheaton', 'City of Wheaton,Uiton,Wheaton,Уитон', 45.8044100, -96.4992300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140162, 'White Bear Lake', 'White Bear Lake', 'City of White Bear Lake,Uajt Bia Lehjk,Uajt-Behr-Lejk,Vajt Ber Lejk,Vajt-Ber-Lejk,White Bear,White Bear Lake,wayt byr lyk,Вайт-Бер-Лейк,Вајт Бер Лејк,Уайт Биа Лэйк,Уайт-Бэр-Лейк,وائٹ بئیر لیک، مینیسوٹا,وايت بير ليك,وایت بیر لیک، مینه‌سوتا', 45.0846900, -93.0099400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140163, 'Willmar', 'Willmar', 'City of Willmar,ILL,Uilmar,Villmar,Vilmar,Willmar,wylmr,Виллмар,Вилмар,Вілмар,Уилмар,ويلمر,ویلمار، مینه‌سوتا', 45.1219100, -95.0433400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140164, 'Windom', 'Windom', 'City of Windom,Uindom,Vindom,Windom,wyndwm,Виндом,Віндом,Уиндом,ويندوم,ویندوم، مینه‌سوتا', 43.8663500, -95.1169400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140165, 'Winnebago', 'Winnebago', 'City of Winnebago,Uinnebejgo,Vinebejgo,Vinnebago,Vinnebejgo,Winnebago,wynybaghw,Винебејго,Виннебаго,Віннебейґо,Уиннебейго,وينيباغو,وینبگو، مینه‌سوتا', 43.7677300, -94.1657900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140166, 'Winona', 'Winona', 'City of Winona,Montezuma,ONA,Uinona,Vajnona,Vinona,Winona,u~inona,winona,wynwna,Вайнона,Вајнона,Винона,Вінона,Уинона,وينونا,وینونا، مینه‌سوتا,وینونا، مینیسوٹا,ウィノナ,위노나', 44.0499600, -91.6393200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140167, 'Winsted', 'Winsted', 'City of Winsted,Winsted', 44.9638500, -94.0474700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140168, 'Winthrop', 'Winthrop', 'City of Winthrop,Winthrop', 44.5430200, -94.3663700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140169, 'Woodbury', 'Woodbury', 'City of Woodbury,Vudbari,Vudberi,Vudbjuri,Woodbury,udeubeli,vudabari,wwdbwry,Вудбарі,Вудбери,Вудбюри,وودبری، مینه‌سوتا,وودبوري,ووڈبری، مینیسوٹا,वुडबरी,우드베리', 44.9238600, -92.9593800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140170, 'Worthington', 'Worthington', 'City of Worthington,OTG,Okabena,Uehrtington,Vorsington,Vortington,Worthington,wrthynghtwn,wwrdyngtn  mynh‌swta,Ворсингтон,Вортингтон,Вортінґтон,Уэртингтон,ورثينغتون,ووردینگتن، مینه‌سوتا', 43.6199600, -95.5964000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140171, 'Wyoming', 'Wyoming', 'City of Wyoming,Uajoming,Vajoming,Wyoming,wywmyngh,Вайоминг,Вайомінґ,Вајоминг,Уайоминг,وائیومنگ، مینیسوٹا,وایوومینگ، مینه‌سوتا,ويومينغ', 45.3363600, -92.9971600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140172, 'Young America (historical)', 'Young America (historical)', '', 44.7827400, -93.9135800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140173, 'Zumbrota', 'Zumbrota', 'City of Zumbrota,Zumbrota,zwmbrwta,Зумброта,زامبروتا، مینه‌سوتا,زومبروتا', 44.2941300, -92.6690800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140174, 'Albany', 'Albany', 'Olbani,Олбани', 40.2486100, -94.3310700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140175, 'Bethany', 'Bethany', 'Behsani,Betani,Bethany,Bethpage,Dallas,bythany,Бетани,Бэсани,بيثاني,بیتھانی، مسوری', 40.2683300, -94.0282900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140176, 'Canton', 'Canton', '', 40.1250400, -91.6251600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140177, 'Grant City', 'Grant City', 'Grant,Grant City', 40.4874900, -94.4110700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140178, 'Kahoka', 'Kahoka', 'Cahoka,Cahoke,Kaboka,Kahoka,Kahokie,Round Prairie', 40.4203200, -91.7196100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140179, 'King City', 'King City', '', 40.0513800, -94.5241200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140180, 'Kirksville', 'Kirksville', 'Hopkinsville,IRK,Kirksvil,Kirksvill,Kirksville,Long Point,krkzwyl  myzwry,kyrkfyl,Кирксвил,Кирксвилл,كيركفيل,کرکزویل، میزوری', 40.1947500, -92.5832500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140181, 'La Plata', 'La Plata', 'La Plata,LaPlata,Laplata', 40.0233700, -92.4915800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140182, 'Lancaster', 'Lancaster', 'Lankaster,Ланкастер', 40.5208600, -92.5279700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140183, 'Maryville', 'Maryville', 'Mehrivill,Merivil,meribiru,Меривил,Мэривилл,مری‌ویل، میزوری,メリービル', 40.3461000, -94.8724700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140184, 'Memphis', 'Memphis', 'Memfis,Мемфис', 40.4578100, -92.1712900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140185, 'Milan', 'Milan', '', 40.2022400, -93.1252100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140186, 'Monticello', 'Monticello', '', 40.1183800, -91.7121100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140187, 'Mound City', 'Mound City', 'Jacksons Point,Mound City,North Point,Worth Point', 40.1311100, -95.2316400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140188, 'Princeton', 'Princeton', 'Prinston,Принстон', 40.4008400, -93.5805000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140189, 'Rock Port', 'Rock Port', 'Byron,Meeks Mill,Rock Port,Rockport', 40.4111100, -95.5169300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140190, 'Stanberry', 'Stanberry', '', 40.2177700, -94.5382900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140191, 'Tarkio', 'Tarkio', '', 40.4402800, -95.3777600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140192, 'Terre Haute', 'Terre Haute', '', 40.4394600, -93.2341000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140193, 'Trenton', 'Trenton', 'TRX,Trenton,Трентон', 40.0789000, -93.6166100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140194, 'Unionville', 'Unionville', 'Harmony,Unionville', 40.4769600, -93.0032600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140195, 'Ashley', 'Ashley', 'ASY,Ashley', 46.0341400, -99.3715000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140196, 'Belcourt', 'Belcourt', 'Belcourt,Turtle Mountain', 48.8391700, -99.7448700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140197, 'Cando', 'Cando', '', 48.4866700, -99.2098600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140198, 'Carrington', 'Carrington', 'Karington,ka lin dun,karynghtwn,kryngtwn  dakwtay shmaly,Карингтон,كارينغتون,کرینگتون، داکوتای شمالی,کیرنگٹن، شمالی ڈکوٹا,卡林顿', 47.4497200, -99.1262200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140199, 'Casselton', 'Casselton', 'Cass Town,Casselton,Goose Creek,Kaselton,Swan Creek,ka si er dun,kazltwn,ksltwn  dakwtay shmaly,Каселтон,كازلتون,کسلتون، داکوتای شمالی,کیسلٹن، شمالی ڈکوٹا,卡斯尔顿', 46.9005300, -97.2112000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140200, 'Cavalier', 'Cavalier', 'Kavalir,ka wa lai er,kafalyr,kwlyr  dakwtay shmaly,Кавалир,كافالير,کولیر، داکوتای شمالی,کیویلیئر، شمالی ڈکوٹا,卡瓦莱尔', 48.7938800, -97.6223100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140201, 'Cooperstown', 'Cooperstown', 'Kopertaun,gu bai zhen,kwbrstawn,kwprztawn  dakwtay shmaly,Копертаун,كوبرستاون,کوپرزتاون، داکوتای شمالی,کوہرزٹاؤن، شمالی ڈکوٹا,古柏镇', 47.4444400, -98.1239800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140202, 'Devils Lake', 'Devils Lake', 'City of Devils Lake,Creel City,Creelsburg,DVL,Devils Lake,Devils Lejk,debeulseuleikeu,dwl lyk  dakwtay shmaly,dyfylz lyk,mo gui hu,Девилс Лејк,دول لیک، داکوتای شمالی,ديفيلز ليك,ڈیولز لیک، شمالی ڈکوٹا,魔鬼湖,데블스레이크', 48.1127800, -98.8651200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140203, 'Ellendale', 'Ellendale', '', 46.0027500, -98.5270500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140204, 'Fargo', 'Fargo', 'Centralia,FAR,Fago,Fargas,Fargo,Fàgo,Fārgo,Gorad Farga,fa ge,fago,farghw,fargw,fargw  dakwtay shmaly,pago,pargo,phargo,Горад Фарга,Фарго,Фарґо,פארגא,פארגו,فارغو,فارگو,فارگو، داکوتای شمالی,फार्गो,ფარგო,ファーゴ,法戈,파고', 46.8771900, -96.7898000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140205, 'Fessenden', 'Fessenden', '', 47.6491700, -99.6292900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140206, 'Finley', 'Finley', 'Finley,Gilbert', 47.5141600, -97.8359300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140207, 'Forman', 'Forman', '', 46.1077400, -97.6364900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140208, 'Fort Totten', 'Fort Totten', '', 47.9800000, -98.9929000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140209, 'Grafton', 'Grafton', '', 48.4122100, -97.4106300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140210, 'Grand Forks', 'Grand Forks', 'GFK,Grand Foks,Grand Forks,Grand-Forks,Grandforksa,Grann Foks,Grann Fòks,da fu ke si,geulaendeupokeuseu,ghrand fwrks,grnd frk  dakwtay shmaly,grnd pwrqs,gurandofokusu,Гранд Фокс,Гранд-Форкс,גרנד פורקס,غراند فوركس,گرند فرک، داکوتای شمالی,گرینڈفورکس,グランドフォークス,大福克斯,그랜드포크스', 47.9252600, -97.0328500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140211, 'Harvey', 'Harvey', 'Kharvi,Харви', 47.7697200, -99.9354000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140212, 'Hillsboro', 'Hillsboro', 'Comstock,Hill City,Hillsboro,Khillsboro,Хиллсборо', 47.4038700, -97.0620300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140213, 'Horace', 'Horace', '', 46.7588600, -96.9037000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140214, 'Jamestown', 'Jamestown', 'Camp Sykes,Camp Thomas,Dzejmstaun,Fort Cross,Fort Seward,JMS,Jamestown,jeimseutaun,jymstawn,jymztawn  dakwtay shmaly,zhan mu si dui,Џејмстаун,جيمستاون,جیمز ٹاون، شمالی ڈکوٹا,جیمزتاون، داکوتای شمالی,詹姆斯敦,제임스타운', 46.9105400, -98.7084400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140215, 'Lakota', 'Lakota', '', 48.0427800, -98.3362100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140216, 'Langdon', 'Langdon', 'Langdon,McHugh', 48.7600000, -98.3681700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140217, 'Larimore', 'Larimore', '', 47.9066600, -97.6267500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140218, 'Lisbon', 'Lisbon', 'Lisbon,li si ben,lshbwnt,lysbwn  dakwtay shmaly,Лисбон,لزبن، شمالی ڈکوٹا,لشبونة,لیسبون، داکوتای شمالی,里斯本', 46.4416300, -97.6812100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140219, 'Mayville', 'Mayville', 'Arnolds Post,May,Mayville,Mejvil,mayfyl,maywyl  dakwtay shmaly,mei wei er,Мејвил,مايفيل,مایویل، داکوتای شمالی,میئویل، شمالی ڈکوٹا,梅维尔', 47.4980400, -97.3245400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140220, 'Napoleon', 'Napoleon', 'Napolion,na po lun,nablywn,npwlyan  dakwtay shmaly,Наполион,نابليون,نپولیان، داکوتای شمالی,拿破仑', 46.5083100, -99.7712200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140221, 'Minnewaukan', 'Minnewaukan', 'Minnewakon,Minnewaukan', 48.0713900, -99.2523600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140222, 'New Rockford', 'New Rockford', 'Dunn,Dunns Creek,Garrison,New Rockford,Nju Rokford,Rockford,Rockville,Rocky Ford,nyw rakfrd  dakwtay shmaly,nyw rwkfwrd,xin luo ke fu de,Њу Рокфорд,نيو روكفورد,نیو راک فورڈ، شمالی ڈکوٹا,نیو راکفرد، داکوتای شمالی,新罗克福德', 47.6800000, -99.1379000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140223, 'Oakes', 'Oakes', 'Oakes,Oakes City', 46.1385800, -98.0903800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140224, 'Park River', 'Park River', 'Kensington,Park River', 48.3986000, -97.7412000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140225, 'Rolla', 'Rolla', '', 48.8577800, -99.6179200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140226, 'Rugby', 'Rugby', 'Ragbi,la ge bi,ragby  dakwtay shmaly,rkby,Рагби,راگبی، داکوتای شمالی,ركبي,رگبی، شمالی ڈکوٹا,拉格比', 48.3688900, -99.9962500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140227, 'Sheldon', 'Sheldon', 'Jenksville,Sheldon', 46.5858000, -97.4912000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140228, 'Shell Valley', 'Shell Valley', '', 48.7980600, -99.8648600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140229, 'Steele', 'Steele', 'Fourteenth Siding,Steele', 46.8547100, -99.9159400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140230, 'Thompson', 'Thompson', 'Norton,Thompson', 47.7735900, -97.1098000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140231, 'Valley City', 'Valley City', 'Fifth Siding,Vali Siti,Valley City,Wapheton,Worthington,faly syty,gu shi,wly syty  dakwtay shmaly,Вали Сити,فالي سيتي,ولی سیتی، داکوتای شمالی,ویلی سٹی، شمالی ڈکوٹا,谷市', 46.9233100, -98.0031500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140232, 'Wahpeton', 'Wahpeton', 'Chahinkapa,Richville,Vopitn,Wahpeton,wa pei dun,wahbtwn,wpytwn  dakwtay shmaly,Вопитн,واهبتون,واپیٹں، شمالی ڈکوٹا,وپیتون، داکوتای شمالی,瓦佩顿', 46.2652400, -96.6059100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140233, 'West Fargo', 'West Fargo', 'Haggert,Sheyenne Stockyards,South West Fargo,Vest Fargo,West Fargo,u~esutofago,wst fargw  dakwtay shmaly,wyst farghw,xi fa ge,Вест Фарго,وست فارگو، داکوتای شمالی,ويست فارغو,ویسٹ فارگو، شمالی ڈکوٹا,ウェストファーゴ,西法戈', 46.8749700, -96.9003600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140234, 'Ainsworth', 'Ainsworth', 'ANW,Ehjnsuort,Ehjnsvors,Ejnsvort,aynswrth,aynswwrt  nbraska,Ейнсворт,Ејнсворт,Эйнсворс,Эйнсуорт,أينسورث,اینسوورت، نبراسکا', 42.5500000, -99.8626200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140235, 'Albion', 'Albion', 'Albion,albyan  nbraska,albywn,albywn  nybraska,Албион,آلبیون، نیبراسکا,ألبيون,البیان، نبراسکا', 41.6908400, -98.0036700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140236, 'Alma', 'Alma', '', 40.0975100, -99.3620400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140237, 'Arapahoe', 'Arapahoe', 'AHF,Arapahoe,Arrapahoe', 40.3041700, -99.9004000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140238, 'Arlington', 'Arlington', 'Arlington,Bell Creek,Арлингтон', 41.4525000, -96.3511300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140239, 'Ashland', 'Ashland', 'Ashland,Ehshland,Eshland,Saline Ford,ashland,ashlnd  nbraska,Ешланд,Эшланд,أشلاند,اشلند، نبراسکا,ایشلنڈ، نیبراسکا', 41.0391600, -96.3683500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140240, 'Atkinson', 'Atkinson', '', 42.5313900, -98.9781500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140241, 'Auburn', 'Auburn', 'Auborn,Obern,abrn  nybraska,abwrn  nbraska,awbwrn,Ауборн,Оберн,آبرن، نیبراسکا,آبورن، نبراسکا,أوبورن', 40.3927800, -95.8388900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140242, 'Aurora', 'Aurora', 'Avrora,Orora,arwra  nbraska,arwra  nybraska,awrwra,Аврора,Орора,آرورا، نبراسکا,أورورا,ارورا، نیبراسکا', 40.8672300, -98.0042200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140243, 'Bartlett', 'Bartlett', 'Bartlett,Бартлетт', 41.8852900, -98.5523000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140244, 'Bassett', 'Bassett', 'Baset,Bassehtt,Basset,bast  nbraska,basyt,Басет,Бассет,Бассэтт,باست، نبراسکا,باسيت', 42.5858300, -99.5378900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140245, 'Battle Creek', 'Battle Creek', '', 41.9994500, -97.5983900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140246, 'Beatrice', 'Beatrice', 'BIE,Beatris,Biatris,Bitrajs,byatrys,bytrys  nbraska,Беатрис,Биатрис,Битрайс,بياتريس,بیئڑریس، نیبراسکا,بیتریس، نبراسکا', 40.2680600, -96.7469700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140247, 'Beaver City', 'Beaver City', 'Beaver,Beaver City,Beavercreek', 40.1375100, -99.8295600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140248, 'Bellevue', 'Bellevue', 'Behllevju,Belv''ju,Belvju,bei er wei you,berubyu,blwyw  nbraska,blwyw  nybraska,bylyfyw,Белвью,Белвю,Белвју,Бэллевю,بلویو، نبراسکا,بلویو، نیبراسکا,بيليفيو,ベルビュー,贝尔维尤', 41.1366700, -95.8908400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140249, 'Bennington', 'Bennington', '', 41.3647200, -96.1578000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140250, 'Blair', 'Blair', 'Blehjr,Bler,blyr,blyr  nbraska,Блер,Блэйр,بلير,بلیر، نبراسکا', 41.5444400, -96.1250200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140251, 'Brewster', 'Brewster', 'Brjuster,Брюстер', 41.9388900, -99.8648500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140252, 'Broken Bow', 'Broken Bow', 'BBW,Broken Bou,Broken-Bou,Broken-Bov,Brouken Bou,brwkn baw,brwwkn baw  nbraska,Брокен Боу,Брокен-Бов,Брокен-Боу,Броукен Боу,بروكن باو,برووکن باو، نبراسکا', 41.4019500, -99.6392800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140253, 'Burwell', 'Burwell', 'BUB,Burwell,Webster''s Town', 41.7816700, -99.1331500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140254, 'Butte', 'Butte', '', 42.9113900, -98.8492600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140255, 'Center', 'Center', '', 42.6094500, -97.8767300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140256, 'Central City', 'Central City', 'Sentral Siti,asntrl syty  nbraska,senteuleolsiti,syntrl syty,Сентрал Сити,اسنترل سیتی، نبراسکا,سينترل سيتي,센트럴시티', 41.1158500, -98.0017200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140257, 'Chalco', 'Chalco', '', 41.1838900, -96.1503000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140258, 'Clay Center', 'Clay Center', '', 40.5216800, -98.0553300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140259, 'Columbus', 'Columbus', 'Kolambus,Kolumbus,OLU,klmbws  nbraska,kolleombeoseu,kwlmbs  nybraska,kwlmbws,Коламбус,Колумбус,كولمبوس,کلمبوس، نبراسکا,کولمبس، نیبراسکا,콜럼버스', 41.4297300, -97.3683800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140260, 'Cozad', 'Cozad', '', 40.8597300, -99.9873400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140261, 'Creighton', 'Creighton', '', 42.4666700, -97.9061800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140262, 'Crete', 'Crete', 'Blue River City,Crete,Grit,Krit,kryt,kryt  nbraska,Грит,Крит,كريت,کریت، نبراسکا', 40.6277800, -96.9614200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140263, 'Dakota City', 'Dakota City', '', 42.4155500, -96.4183600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140264, 'David City', 'David City', 'David City,Davids City', 41.2527900, -97.1300400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140265, 'Eagle', 'Eagle', '', 40.8166700, -96.4302900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140266, 'Elkhorn', 'Elkhorn', '', 41.2863900, -96.2344700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140267, 'Elwood', 'Elwood', '', 40.5902800, -99.8609500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140268, 'Fairbury', 'Fairbury', 'Fehjrbjuri,Ferberi,fayrbwry,fayrbwry  nbraska,fyyrbwry  nybraska,Фербери,Фэйрбюри,فايربوري,فایربوری، نبراسکا,فیئربوری، نیبراسکا', 40.1372200, -97.1805900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140269, 'Falls City', 'Falls City', 'Folls Siti,Fols Siti,flz syty  nbraska,fwls syty,pholsa siti,Фоллс Сити,Фолс Сити,فلز سیتی، نبراسکا,فولس سيتي,फॉल्स सिटी', 40.0608400, -95.6019300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140270, 'Franklin', 'Franklin', 'Franklin,franklyn,frnklyn  nbraska,frynkln  nybraska,Франклин,فرانكلين,فرنکلین، نبراسکا,فرینکلن، نیبراسکا', 40.0961200, -98.9525800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140271, 'Fremont', 'Fremont', 'FET,Frehmont,Frimont,frymant  nbraska,frymwnt,fu li meng te,Фримонт,Фрэмонт,Фрімонт,فريمونت,فریمانت، نبراسکا,فریمونٹ، نیبراسکا,弗里蒙特', 41.4333300, -96.4980800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140272, 'Friend', 'Friend', '', 40.6536200, -97.2861600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140273, 'Fullerton', 'Fullerton', 'Fullerton,Фуллертон', 41.3633500, -97.9692300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140274, 'Geneva', 'Geneva', 'Dzeniva,Zheneva,jnyfa,jnywa  nbraska,Џенива,Женева,جنيفا,جنیوا، نبراسکا', 40.5269500, -97.5958800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140275, 'Gibbon', 'Gibbon', '', 40.7483500, -98.8448000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140276, 'Grand Island', 'Grand Island', 'GRI,Grand Ajland,Grand-Ajlend,Grandis Insula,ge lan de ai lan,geulaendeuaillaendeu,ghrand aysland,gramda ayalanda,grnd aylnd  nbraska,gurandoairando,Гранд Айланд,Гранд Ајланд,Гранд-Айленд,Ґранд-Айленд,غراند إيسلاند,گرند آیلند، نبراسکا,گرینڈ آئلینڈ، نیبراسکا,ग्रँड आयलंड,グランドアイランド,格蘭德艾蘭,그랜드아일랜드', 40.9250100, -98.3420100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140277, 'Greeley', 'Greeley', 'Greeley,Greeley Center', 41.5486200, -98.5311800, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140278, 'Gretna', 'Gretna', 'Grehtna,Gretna,ghrytna,grtna  nbraska,Гретна,Грэтна,غريتنا,گرتنا، نبراسکا', 41.1408300, -96.2397400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140279, 'Hartington', 'Hartington', 'Kharington,Khartington,hartynghtwn,hartyngtwn,Харингтон,Хартингтон,هارتينغتون,هارتینگتون', 42.6225000, -97.2645000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140280, 'Hastings', 'Hastings', 'Gastings,HSI,Khastings,Khejstings,hastynghs,hei si ting si,heisutinguzu,hystyngz  nbraska,Гастінгс,Хастингс,Хейстингс,Хејстингс,هاستينغس,هیستینگز، نبراسکا,ہیسٹنگز، نیبراسکا,ヘイスティングズ,黑斯廷斯', 40.5861200, -98.3883900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140281, 'Hebron', 'Hebron', '', 40.1663900, -97.5858800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140282, 'Hickman', 'Hickman', '', 40.6200000, -96.6291800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140283, 'Holdrege', 'Holdrege', 'HDE,Holdredge,Holdrege,Kholdridzh,huo er de li qi,hwldrg  nbraska,hwldryj,Холдридж,هولدريج,هولدرگ، نبراسکا,霍爾德里奇', 40.4402900, -99.3698200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140284, 'Kearney', 'Kearney', 'EAR,Karni,Kerni,Kirnehj,ka ni,kani,karni,karny  nbraska,kyarny,kyryny  nybraska,Карни,Карні,Керни,Кирнэй,كيارني,کارنی، نبراسکا,کیرینی، نیبراسکا,कार्नी,カーニー,卡尼,카니', 40.6994600, -99.0814800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140285, 'La Vista', 'La Vista', 'La Vista,La-Vista,la fysta,la wysta  nbraska,Ла Виста,Ла-Виста,Ла-Віста,لا فيستا,لا ویستا، نبراسکا,لا ویسٹا، نیبراسکا', 41.1838900, -96.0311300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140286, 'Lexington', 'Lexington', 'LXN,Leksington,lksyngtn  nbraska,lyksnghtwn,Лексингтон,Лексінгтон,ليكسنغتون,لکسینگتن، نبراسکا,لیکسنگٹن، نیبراسکا', 40.7808400, -99.7415000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140287, 'Lincoln', 'Lincoln', 'Gorad Linkal''n,LNK,Lin''koln,Lincoln,Lincolnia,Linkol''n,Linkoln,Linkolna,Linkolnas,Linkolns,Linkuln,lin ken,ling khxln,lingkeon,linkan,linkana,lnkn,lnkn  nybraska,lynkln  nbraska,lynqwln,rinkan,Λίνκολν,Горад Лінкальн,Линколн,Линкольн,Линкълн,Лінкольн,Լինքոլն,לינקולן,لنكن,لنکن,لنکن، نیبراسکا,لینکلن، نبراسکا,लिंकन,लिङ्कन,லிங்கன்,ลิงคอล์น,ლინკოლნი,リンカーン,林肯,링컨', 40.8000000, -96.6669600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140288, 'Louisville', 'Louisville', 'Luisvil,Луисвил', 40.9977800, -96.1622400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140289, 'Loup City', 'Loup City', '', 41.2755700, -98.9667500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140290, 'Macy', 'Macy', '', 42.1130500, -96.3564200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140291, 'Madison', 'Madison', 'Madison,Mdison,Medison,Mehdison,madyswn,mdyswn  nbraska,Мадисон,Мдисон,Медисон,Медісон,Мэдисон,ماديسون,مدیسون، نبراسکا,میڈیسون، نیبراسکا', 41.8283400, -97.4550500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140292, 'Milford', 'Milford', 'Milford,Милфорд', 40.7744500, -97.0505900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140293, 'Minden', 'Minden', 'Mindehn,Minden,myndn,myndn  nbraska,Минден,Миндэн,ميندن,میندن، نبراسکا', 40.4986300, -98.9478600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140294, 'Nebraska City', 'Nebraska City', 'Nebraska Siti,Nebraska-Siti,nbraska syty,nbraska syty  nbraska,nebeulaeseukasiti,Небраска Сити,Небраска-Сити,Небраска-Сіті,نبراسكا سيتي,نبراسکا سیتی، نبراسکا,نیبراسکا شہر، نیبراسکا,네브래스카시티', 40.6766700, -95.8591700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140295, 'Neligh', 'Neligh', 'Nehlaj,nlyg  nbraska,nylay,Нэлай,نلیگ، نبراسکا,نيلاي', 42.1286200, -98.0297900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140296, 'Nelson', 'Nelson', '', 40.2016800, -98.0678200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140297, 'Norfolk', 'Norfolk', 'Norfok,Norfolk,OFK,narfwk  nybraska,nwrfwk  nbraska,nwrfwlk,Норфок,Норфолк,نارفوک، نیبراسکا,نورفولك,نورفوک، نبراسکا', 42.0283400, -97.4170000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140298, 'North Bend', 'North Bend', '', 41.4619500, -96.7797500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140299, 'O''Neill', 'O''Neill', '', 42.4577800, -98.6475900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140300, 'Oakland', 'Oakland', 'Oklend,Окленд', 41.8358300, -96.4669700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140301, 'Omaha', 'Omaha', 'OMA,Omacha,Omaha,Omakha,ao ma ha,awmaha,awmaha nbraska,awmaha  nbraska,omaha,xo ma ha,Ομάχα,Омаха,Օմահա,אומהה,أوماها,اوماها نبراسكا,اوماها، نبراسکا,اوماہا، نیبراسکا,ओमाहा,ওমাহা,โอมาฮา,ომაჰა,オマハ,奥马哈,오마하', 41.2562600, -95.9404300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140302, 'Ord', 'Ord', 'Chin City,Ord,awrd,awrd  nbraska,Орд,أورد,اورد، نبراسکا', 41.6033400, -98.9262000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140303, 'Osceola', 'Osceola', '', 41.1797400, -97.5475500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140304, 'Papillion', 'Papillion', 'Papilion,Papillion,babylywn,papylywn  nbraska,pypylyn  nybraska,Папилион,Папиллион,Папіліон,بابيليون,پاپیلیون، نبراسکا,پیپیلین، نیبراسکا', 41.1544400, -96.0422400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140305, 'Pawnee City', 'Pawnee City', 'Pawnee,Pawnee City', 40.1083300, -96.1544500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140306, 'Pender', 'Pender', '', 42.1141600, -96.7072600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140307, 'Pierce', 'Pierce', '', 42.1991700, -97.5267200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140308, 'Plainview', 'Plainview', '', 42.3497300, -97.7920100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140309, 'Plattsmouth', 'Plattsmouth', 'Platsmaus,Platsmaut,blatsmwth,platsmwwth  nbraska,pu la ci mao si,Платсмаус,Платсмаут,بلاتسموث,پلاتسمووته، نبراسکا,普拉茨茅斯', 41.0113900, -95.8822300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140310, 'Ponca', 'Ponca', '', 42.5625000, -96.7055900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140311, 'Ralston', 'Ralston', '', 41.2052800, -96.0425200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140312, 'Ravenna', 'Ravenna', '', 41.0261200, -98.9125800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140313, 'Red Cloud', 'Red Cloud', 'Red Cloud,Red Klaud,Redcloud,Rehd Kloud,rd klawd  nbraska,ryd klawd,Ред Клауд,Рэд Клоуд,رد کلاود، نبراسکا,ريد كلاود', 40.0889000, -98.5195000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140314, 'Saint Paul', 'Saint Paul', '', 41.2147300, -98.4581200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140315, 'Schuyler', 'Schuyler', 'Schujler,Skajler,askaylr  nbraska,sshwylyr,Скајлер,Счуйлер,اسکایلر، نبراسکا,سشويلير', 41.4472300, -97.0594800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140316, 'Seward', 'Seward', 'Sehvard,Sivod,swrd  nbraska,syward,Сивод,Сэвард,سورد، نبراسکا,سيوارد', 40.9069500, -97.0989200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140317, 'Shelton', 'Shelton', 'Shelton,Шелтон', 40.7791800, -98.7309100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140318, 'South Sioux City', 'South Sioux City', 'Saut Su Siti,Saut-Su-Siti,Sous Siouks Siti,sawth sywks syty,sw syty  nbraska,Саут Су Сити,Саут-Су-Сити,Саут-Су-Сіті,Соус Сиоукс Сити,ساوتھ سیو سٹی، نیبراسکا,ساوث سيوكس سيتي,سو سیتی، نبراسکا', 42.4738800, -96.4136400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140319, 'Springfield', 'Springfield', 'Springfild,Спрингфилд', 41.0819400, -96.1344600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140320, 'Stanton', 'Stanton', 'Stehnton,Стэнтон', 41.9502800, -97.2239300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140321, 'Springview', 'Springview', 'Spring Veiw,Springview', 42.8244400, -99.7490100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140322, 'Stromsburg', 'Stromsburg', 'Stromburgh,Stromsburg', 41.1141800, -97.5989400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140323, 'Superior', 'Superior', 'Superior,Supirior,spyryar  nbraska,swbyrywr  nbraska,Супериор,Супириор,سوبيريور، نبراسكا,سپیریار، نبراسکا', 40.0208500, -98.0700400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140324, 'Sutton', 'Sutton', '', 40.6055700, -97.8592100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140325, 'Syracuse', 'Syracuse', '', 40.6572200, -96.1864000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140326, 'Taylor', 'Taylor', 'Tejlor,Тейлор', 41.7702800, -99.3787200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140327, 'Tecumseh', 'Tecumseh', 'Frances,Tecumseh', 40.3666700, -96.1961200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140328, 'Tekamah', 'Tekamah', 'TQE,Tekamah', 41.7783200, -96.2211300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140329, 'Valley', 'Valley', 'Platte Sanders,Platte Valley,Valley', 41.3127800, -96.3461400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140330, 'Wahoo', 'Wahoo', 'Vakhu,wahw,wahw  nbraska,Ваху,واهو,واهو، نبراسکا', 41.2113900, -96.6203000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140331, 'Wakefield', 'Wakefield', '', 42.2691700, -96.8650400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140332, 'Waterloo', 'Waterloo', 'Vaterlo,Ватерло', 41.2869400, -96.2855800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140333, 'Waverly', 'Waverly', '', 40.9175000, -96.5283400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140334, 'Wayne', 'Wayne', 'Brookdale,Vehjn,Vejn,Wayne,wei en,wyn,wyn  nbraska,wyn  nybraska,Вејн,Вэйн,وين,وین، نبراسکا,وین، نیبراسکا,韦恩', 42.2305600, -97.0178200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140335, 'Weeping Water', 'Weeping Water', 'EPG', 40.8700000, -96.1405700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140336, 'West Point', 'West Point', 'Vehst Pojnt,Vest Pojnt,West Point,Westpoint,wst pwynt  nbraska,wyst bwynt,Вест Појнт,Вэст Пойнт,وست پوینت، نبراسکا,ويست بوينت,ویسٹ پوائنٹ، نیبراسکا', 41.8416700, -96.7086400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140337, 'Wilber', 'Wilber', '', 40.4813900, -96.9605800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140338, 'Wisner', 'Wisner', '', 41.9872200, -96.9142100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140339, 'Wood River', 'Wood River', '', 40.8205700, -98.6000700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140340, 'Wymore', 'Wymore', '', 40.1222200, -96.6625200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140341, 'York', 'York', 'Jork,New York,York,yark  nybraska,yue ke,ywrk  nbraska,ywtan  nbraska,Јорк,Йорк,يوتان، نبراسكا,یارک، نیبراسکا,یورک، نبراسکا,约克', 40.8680700, -97.5920000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140342, 'Yutan', 'Yutan', '', 41.2450000, -96.3972500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140343, 'Alexandria', 'Alexandria', '', 43.6114600, -71.7928600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140344, 'Alstead', 'Alstead', 'Alstead,Alstead Village,Alstid,Newtown,alstyd  nywhmpshayr,Алстид,الستید، نیوهمپشایر,السٹیڈ، نیو ہیمپشائر', 43.1489700, -72.3606400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140345, 'Andover', 'Andover', 'Andover,Andover Village,New Breton,Андовер,اینڈوور، نیو ہیمپشائر', 43.4370200, -71.8234100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140346, 'Antrim', 'Antrim', 'Antrim,Society Land', 43.0309100, -71.9389700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140347, 'Ashland', 'Ashland', 'Ehshland,Eshland,ashlnd  nywhmpshayr,Ешланд,Эшланд,اشلند، نیوهمپشایر,ایشلنڈ، نیو ہیمپشائر', 43.6953500, -71.6306300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140348, 'Atkinson', 'Atkinson', '', 42.8384200, -71.1470000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140349, 'Auburn', 'Auburn', 'Aubjorn,Аубёрн,آبرن، نیو ہیمپشائر', 43.0045300, -71.3484000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140350, 'Barnstead', 'Barnstead', '', 43.3339700, -71.2928400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140351, 'Barrington', 'Barrington', 'Barrington,Баррингтон,بیرنگٹن، نیو ہیمپشائر', 43.2228600, -71.0470100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140352, 'Bedford', 'Bedford', 'Bedford,Behdford,Narragansett Number 5,Souhegan East,bdfwrd  nywhmpshayr,bedofodo,Бедфорд,Бэдфорд,بدفورد، نیوهمپشایر,بیڈفورڈ، نیو ہیمپشائر,ベドフォード', 42.9464700, -71.5159000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140353, 'Belmont', 'Belmont', 'Behlmont,Belmont,blmant  nywhmpshayr,Белмонт,Бэлмонт,بلمانت، نیوهمپشایر,بیلمونٹ، نیو ہیمپشائر', 43.4453600, -71.4778500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140354, 'Berlin', 'Berlin', 'BML,Berlin,Maynesboro,Maynesborough,bai lin,barin,beollin,brlyn,brlyn  nywhmpshayr,Берлин,Берлін,برلن، نیو ہیمپشائر,برلين,برلین، نیوهمپشایر,バーリン,柏林,벌린', 44.4686700, -71.1850800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140355, 'Boscawen', 'Boscawen', 'Boscawen,Contoocook', 43.3150800, -71.6209100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140356, 'Bow Bog', 'Bow Bog', '', 43.1206400, -71.5114600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140357, 'Brentwood', 'Brentwood', '', 42.9787000, -71.0728400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140358, 'Bridgewater', 'Bridgewater', '', 43.6384100, -71.7364700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140359, 'Bristol', 'Bristol', 'Bristol,brystwl  nywhmpshayr,Бристол,برسٹل، نیو ہیمپشائر,بریستول، نیوهمپشایر', 43.5911900, -71.7367500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140360, 'Brookline', 'Brookline', 'Brookline,Bruklin,Raby,Бруклин', 42.7348100, -71.6581300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140361, 'Candia', 'Candia', 'Candia,Charmingfare', 43.0778600, -71.2767300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140362, 'Canterbury', 'Canterbury', 'Canterbury,Canterbury Center', 43.3370200, -71.5653500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140363, 'Center Harbor', 'Center Harbor', 'Center Harbor,Center Harbour,Centre Harbor,Centre Harbor Village,Centre-Harbor,Centreharbor,Senter Harbour,Senter Kharbor,sntr harbwr,Сентер Харбор,سنتر هاربور,سینٹر بندرگاہ، نیو ہیمپشائر', 43.7098000, -71.4603500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140364, 'Charlestown', 'Charlestown', 'Charlestown,Fort Number Four,Number 4', 43.2386900, -72.4245300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140365, 'Chester', 'Chester', 'Chehster,Cheshire,Chester,tshystr,Честер,Чэстер,تشيستر,چیسٹر، نیو ہیمپشائر', 42.9567500, -71.2572800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140366, 'Chesterfield', 'Chesterfield', 'Chehsterfild,Chesterfield,Number 1,tshystrfyld,Чэстерфилд,تشيسترفيلد,چیسٹرفیلڈ، نیو ہیمپشائر', 42.8873000, -72.4703700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140367, 'Chichester', 'Chichester', '', 43.2492500, -71.3997900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140368, 'Claremont', 'Claremont', 'Klehjrmont,Klermont,ke lai er meng te,klyrmant  nywhmpshayr,klyrmwnt,kureamonto,Клермонт,Клэйрмонт,كليرمونت,کلیئرمونٹ، نیو ہیمپشائر,کلیرمانت، نیوهمپشایر,クレアモント,克萊爾蒙特', 43.3767400, -72.3467600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140369, 'Colebrook', 'Colebrook', 'Colburne,Colebrook,Kolebruk,Koulbruk,kwlbrwk  nywhmpshayr,kwlybrwk,Колебрук,Коулбрук,كوليبروك,کولبروک، نیو ہیمپشائر,کولبروک، نیوهمپشایر', 44.8944900, -71.4959200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140370, 'Concord', 'Concord', 'CON,Concord,Concord i New Hampshire,Gorad Kankord,Kon''kornt,Konkord,Konkorda,Konkordas,Konkords,Penacook,Pencook,Pennacook,Romford,Rumford,kamkorda,kang ke de,kankard,kankarda,kankart,knkwrd  nywhmpshayr,kongkodeu,konkodo,kwnkwrd,qwnqwrd,Κόνκορντ,Горад Канкорд,Конкорд,Կոնկորդ,קאנקארד,קונקורד,كونكورد,کنکورد، نیوهمپشایر,کنکورڈ,کونکورڈ، نیو ہیمپشائر,कङ्कर्द,कन्कर्ड,कन्कर्ड्,काँकोर्ड,காங்கர்ட்,კონკორდი,コンコード,康科德,콩코드', 43.2081400, -71.5375700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140371, 'Contoocook', 'Contoocook', 'Contoocook,Contoocook Village,Contucook', 43.2220200, -71.7139700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140372, 'Conway', 'Conway', 'Chateaugay,Conway,Conway Corner,Dollof Town,Dolloftown,Konvehj,Konvej,Pegwagget,Pequawket,Pequawkett,Pigwacket,Shagigee,kanwy  nywhmpshayr,kon''u~ei,kwnway,Конвей,Конвеј,Конвэй,كونواي,کانوی، نیوهمپشایر,کونوے، نیو ہیمپشائر,コンウェイ', 43.9792400, -71.1203500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140373, 'Danbury', 'Danbury', '', 43.5256300, -71.8617500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140374, 'Danville', 'Danville', 'Danville,Hawke', 42.9125900, -71.1245000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140375, 'Deering', 'Deering', 'Deering,Deering Center,Society Land', 43.0731400, -71.8445200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140376, 'Deerfield', 'Deerfield', '', 44.2306200, -71.6170300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140377, 'Derry', 'Derry', 'Dehrri,Deri,Derri,Derry,Derry Depot,West Derry,deli,deri,dry  nywhmpshayr,dyry,Дери,Дерри,Дэрри,دری، نیوهمپشایر,ديري,ڈیری، نیو ہیمپشائر,デリー,데리', 42.8806400, -71.3272900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140378, 'Derry Village', 'Derry Village', 'Derry,Derry Village', 42.8917500, -71.3120100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140379, 'Dover', 'Dover', 'Bristol,Cochecho,Cocheco,Douvur,Dovehr,Dover,Dover i New Hampshire,Hilton''s Point,Nachwanach,Newichwannock,Northam,Quochecho,Winichahanat,doba,duo fu,dwfr,dwwr  nywhmpshayr,Довер,Довэр,Доувър,دوفر,دوور، نیوهمپشایر,ڈوور، نیو ہیمپشائر,ドーバー,多佛', 43.1978600, -70.8736700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140380, 'Dublin', 'Dublin', 'Dablin,Dublin,Monadnock Number 2,dablyn  nywhmpshayr,dwblyn,Даблин,Дублин,Дублін,دابلین، نیوهمپشایر,دوبلين,ڈبلن، نیو ہیمپشائر', 42.9075800, -72.0625800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140381, 'Durham', 'Durham', 'Daram,Darem,Djurkham,Durham,Oyster River,daramu,dwram  nywhmpshayr,dwrham,Дарам,Дарем,Дюрхам,دورام، نیوهمپشایر,دورهام,ڈرہم، نیو ہیمپشائر,ダーラム', 43.1339700, -70.9264500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140382, 'East Concord', 'East Concord', '', 43.2420200, -71.5381300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140383, 'East Kingston', 'East Kingston', '', 42.9256400, -71.0167200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140384, 'East Merrimack', 'East Merrimack', '', 42.8681400, -71.4834000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140385, 'Effingham', 'Effingham', 'Effingham,Leavitt''s Town', 43.7611900, -70.9964500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140386, 'Enfield', 'Enfield', 'Enfield,Relhan,Rethan', 43.6406300, -72.1439800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140387, 'Epping', 'Epping', '', 43.0334200, -71.0742300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140388, 'Epsom', 'Epsom', 'Epsom,Epsom Four Corners', 43.2228600, -71.3320100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140389, 'Exeter', 'Exeter', 'Ehkseter,Ekseter,Eksutur,Exeter,Swamscot Falls,Swamscott Falls,ai ke sai te,aksytr  nywhmpshayr,aykstr,ekuseta,Ексетер,Ексътър,Эксетер,إيكستر,اکسیتر، نیوهمپشایر,ایگزیٹر، نیو ہیمپشائر,エクセター,埃克塞特', 42.9814800, -70.9478300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140390, 'Farmington', 'Farmington', 'Dock,Farmington,Фармингтон', 43.3898000, -71.0650600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140391, 'Fitzwilliam', 'Fitzwilliam', 'Fitsvilliam,Fitzwilliam,Monadnock Number 4,fytzwylyam,Фитсвиллиам,فيتزويليام,فٹزویلیم، نیو ہیمپشائر', 42.7806400, -72.1417500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140392, 'Francestown', 'Francestown', 'Franstaun,fransystawn,Франстаун,فرانسيستاون,فرینسسٹاؤن، نیو ہیمپشائر', 42.9875800, -71.8125800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140393, 'Franklin', 'Franklin', 'East Village,Franklin,Franklin Falls,Frenklin,Pemigewasset,Pemigewasset Village,Salisbury,franklyn,franklyn  nywhmpshayr,fu lan ke lin,furankurin,peulaengkeullin,Франклин,Френклин,فرانكلين,فرانکلین، نیوهمپشایر,فرینکلن، نیو ہیمپشائر,フランクリン,富蘭克林,프랭클린', 43.4442400, -71.6473000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140394, 'Freedom', 'Freedom', 'Freedom,Leavitt''s Town,North Effingham', 43.8123000, -71.0356200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140395, 'Fremont', 'Fremont', 'Fremont,Frimont,Poplin,Фримонт', 42.9909200, -71.1425600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140396, 'Gilford', 'Gilford', 'Gilford,ghylfwrd,Гилфорд,غيلفورد,گلفورڈ، نیو ہیمپشائر', 43.5475800, -71.4067400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140397, 'Gilmanton', 'Gilmanton', 'Gilmanton,ghylmantwn,Гилмантон,غيلمانتون,گلمنٹن، نیو ہیمپشائر', 43.4242500, -71.4145200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140398, 'Goffstown', 'Goffstown', 'Goffstaun,Goffstown,Gofstaun,Piscataquog Village,gafstawn  nywhmpshayr,ghwfstawn,gofuzutaun,Гофстаун,Гоффстаун,غوفستاون,گافستاون، نیوهمپشایر,گافسٹاؤن، نیو ہیمپشائر,ゴフズタウン', 43.0203600, -71.6003500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140399, 'Gorham', 'Gorham', 'Goram,Gorkham,Gorkhehm,ghwrham,gwram  nywhmpshayr,Горам,Горхам,Горхэм,غورهام,گورام، نیوهمپشایر,گورہم، نیو ہیمپشائر', 44.3878400, -71.1731300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140400, 'Grafton', 'Grafton', '', 43.5586800, -71.9439700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140401, 'Grantham', 'Grantham', 'Grantham,New Grantham', 43.4895200, -72.1375900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140402, 'Greenfield', 'Greenfield', 'Grinfild,ghrynfyld,Гринфилд,غرينفيلد,گرین فیلڈ، نیو ہیمپشائر', 42.9506400, -71.8723000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140403, 'Greenland', 'Greenland', '', 43.0362000, -70.8328300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140404, 'Greenville', 'Greenville', 'Greenville,Grinvill,Mason Harbor,Mason Village,Slipton,Гринвилл', 42.7673100, -71.8123000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140405, 'Groveton', 'Groveton', 'Grove Town,Groveton', 44.5986700, -71.5112000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140406, 'Hampstead', 'Hampstead', 'Hampstead,Timber Lane', 42.8745300, -71.1811700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140407, 'Hampton', 'Hampton', 'Hampton,Khehmpton,Khehmton,Khempton,Winnecumet,Winnicumet,hambtwn,hanputon,hmptwn  nywhmpshayr,Хемптон,Хэмптон,Хэмтон,هامبتون,همپتون، نیوهمپشایر,ہیمپٹن، نیو ہیمپشائر,ハンプトン', 42.9375900, -70.8389400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140408, 'Hampton Beach', 'Hampton Beach', '', 42.9073100, -70.8120000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140409, 'Hampton Falls', 'Hampton Falls', 'Hampton Falls,Hampton-falls,Khehmton Fols,hambtwn fals,Хэмтон Фолс,هامبتون فالس,ہیمپٹن فالز، نیو ہیمپشائر', 42.9162000, -70.8636600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140410, 'Hanover', 'Hanover', '', 43.7022900, -72.2895400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140411, 'Harrisville', 'Harrisville', 'Harrisville,Kharrisvill,Twitchellville,Twitchellville Village,harysfyl,hryswyl  nywhmpshayr,Харрисвилл,هاريسفيل,هریسویل، نیوهمپشایر,ہیرسویل، نیو ہیمپشائر', 42.9450800, -72.0964700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140412, 'Haverhill', 'Haverhill', 'Haverel,Haverhill,Haverhill Corner,Haveril,Havrell,Khaverkhill,Lower Cohos,Lower Corners,Хаверхилл', 44.0345100, -72.0639800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140413, 'Henniker', 'Henniker', 'Henniker,Henniker Village,Hinnekar,Khehnniker,Kheniker,Number 6,hnykr,hnykr  nywhmpshayr,Хеникер,Хэнникер,هنيكر,هنیکر، نیوهمپشایر,ہینیکر، نیو ہیمپشائر', 43.1798000, -71.8223000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140414, 'Hill', 'Hill', 'Hill,Hill Village,New Chester', 43.5242400, -71.7009100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140415, 'Hinsdale', 'Hinsdale', 'Fort Dummer,Hinsdale', 42.7861900, -72.4864800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140416, 'Holderness', 'Holderness', 'Holdernes,Holderness,Khouldehrness,New Holderness,Хоулдэрнесс', 43.7320200, -71.5884100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140417, 'Hollis', 'Hollis', 'Hollis,Khollis,Nissitissit,hwlys,Холлис,هوليس,ہالس، نیو ہیمپشائر', 42.7431400, -71.5917400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140418, 'Hooksett', 'Hooksett', 'Hanna-Ko-Kees,Hooksett,Isle au Hooksett Falls,Isle of Hooksett,Khuksehtt,Khukset,fukkusetto,hwkst  nywhmpshayr,hwksyt,Хуксет,Хуксэтт,هوكسيت,هوکست، نیوهمپشایر,ہکسیٹ، نیو ہیمپشائر,フックセット', 43.0967500, -71.4650700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140419, 'Hopkinton', 'Hopkinton', 'Hopkinton,Khopkinton,New Hopkinton,hwbkyntwn,Хопкинтон,هوبكينتون,ہوپکنٹن، نیو ہیمپشائر', 43.1914700, -71.6753500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140420, 'Hudson', 'Hudson', 'Gudzon,Hudson,Khadson,Nottingham West,hadoson,hadsn  nywhmpshayr,hwdswn,Гудзон,Хадсон,هادسن، نیوهمپشایر,هودسون,ہڈسن، نیو ہیمپشائر,ハドソン', 42.7648100, -71.4397900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140421, 'Jaffrey', 'Jaffrey', 'AFN,Dzafri,Dzhaffrehj,East Jaffrey,Factory Village,Jaffrey,Monadnock Number 3,jafry,jafry  nywhmpshayr,Џафри,Джаффрэй,جافري,جافری، نیوهمپشایر,جففرے، نیو ہیمپشائر', 42.8139700, -72.0231400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140422, 'Jefferson', 'Jefferson', 'Dartmouth,Dzhefferson,Jefferson,Jefferson Hill,Джефферсон', 44.4189500, -71.4745300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140423, 'Keene', 'Keene', 'EEN,Keen,Keene,Kijn,Kin,Kini,Upper Ashuelot,ji en,kin,kyn,kyn  nywhmpshayr,Кийн,Кин,Кини,Кін,كين,کین، نیو ہیمپشائر,کین، نیوهمپشایر,キーン,基恩', 42.9336900, -72.2781400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140424, 'Kensington', 'Kensington', '', 42.9270300, -70.9439400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140425, 'Kingston', 'Kingston', 'Kingston,kynghstwn,Кингстон,كينغستون,کنگسٹن، نیو ہیمپشائر', 42.9364800, -71.0533900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140426, 'Laconia', 'Laconia', 'City of the Lakes,LCI,Laconia,Lakonia,Lakonija,Meredith Bridge,la ke ni ya,lakwnya,lkwwnya  nywhmpshayr,rakonia,Лакониа,Лакония,Лаконија,لاكونيا,لاکونیا، نیو ہیمپ شائر,لکوونیا، نیوهمپشایر,ラコニア,拉科尼亚', 43.5278500, -71.4703500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140427, 'Lancaster', 'Lancaster', 'Lancaster,Lancaster Village,Lankastehr,Lankaster,Lankastur,Upper Cohos,lan kai si te,lankastr,lnkstr  nywhmpshayr,rankasuta,Ланкастер,Ланкастър,Ланкастэр,لانكاستر,لانکیسٹر، نیو ہیمپ شائر,لنکستر، نیوهمپشایر,ランカスター,兰开斯特', 44.4889500, -71.5692500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140428, 'Lebanon', 'Lebanon', 'LEB,Lebanon,lai ba nen,lbnan,lbnan  nywhmpshayr,lebeoneon,rebanon,Лебанон,لبنان,لبنان، نیوهمپشایر,لیبانن، نیو ہیمپشائر,レバノン,萊巴嫩,레버넌', 43.6422900, -72.2517600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140429, 'Lee', 'Lee', '', 43.1231400, -71.0114500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140430, 'Lempster', 'Lempster', 'Dupplin,Lempster,Town of Lemster', 43.2384100, -72.2106400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140431, 'Litchfield', 'Litchfield', 'Brenton''s Farm,Litchfield,Lytchfield', 42.8442500, -71.4797900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140432, 'Littleton', 'Littleton', 'Chiswick,Litlton,Littleton,Littlton,lytltwn,lytltwn  nywhmpshayr,Литлтон,Литтлтон,ليتلتون,لٹلٹن، نیو ہیمپشائر,لیتلتون، نیوهمپشایر', 44.3061700, -71.7700900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140433, 'Londonderry', 'Londonderry', 'Londondehrri,Londonderi,Londonderri,Londonderry,Nutfield,landndry  nywhmpshayr,lndndry,rondonderi,Лондондери,Лондондерри,Лондондэрри,لاندندری، نیوهمپشایر,لندندري,لنڈنڈیری، نیو ہیمپشائر,ロンドンデリー', 42.8650900, -71.3739500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140434, 'Lyme', 'Lyme', 'Lyme,Lyme Plain', 43.8095100, -72.1559200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140435, 'Lyndeborough', 'Lyndeborough', 'Lyndeborough,Lyndeborough Center,Salem Canada', 42.9075800, -71.7664600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140436, 'Madbury', 'Madbury', '', 43.1692500, -70.9239500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140437, 'Madison', 'Madison', 'Madison,Medison,Mehdison,madyswn,Мадисон,Медісон,Мэдисон,ماديسون,میڈیسون، نیو ہیمپ شائر', 43.8992400, -71.1484000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140438, 'Manchester', 'Manchester', 'Derryfield,Harrytown,MHT,Manchehster,Manchester,Manchestur,Namaskeag,Old Harrytown,Tyng''s Town,Tyngstown,maencheseuteo,man che si te,manchesuta,manshstr,mnchstr  nywhmpshayr,mnzstr,Манчестер,Манчестър,Манчэстер,מנצסטר,مانشستر,مانچسٹر، نیو ہیمپشائر,منچستر، نیوهمپشایر,マンチェスター,曼徹斯特,맨체스터', 42.9956400, -71.4547900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140439, 'Marlborough', 'Marlborough', 'Marlboro,Marlborough,Monadnock Number 5,Марлборо', 42.9042500, -72.2078600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140440, 'Mason', 'Mason', 'Mason,Mason Village,Mehson,Meyson,Number 1,maswn,Мэсон,ماسون,میسن، نیو ہیمپشائر', 42.7437000, -71.7689600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140441, 'Meredith', 'Meredith', 'Mehredis,Meredith,New Salem,Мэредис', 43.6575700, -71.5003500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140442, 'Merrimack', 'Merrimack', 'East Merrimack,Merrimac,Merrimack,Merrimak,Souhegan East,merimakku,myrymak,Мерримак,ميريماك,میریمیک، نیو ہیمپشائر,メリマック', 42.8650900, -71.4934000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140443, 'Milan', 'Milan', 'Milan,Paulsburgh', 44.5733900, -71.1850800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140444, 'Milford', 'Milford', 'Mile Slip,Milford,Mill Ford,The Falls,mirufodo,mylfrd  nywhmpshayr,mylfwrd,Милфорд,ميلفورد,میلفرد، نیوهمپشایر,میلفورڈ، نیو ہیمپشائر,ミルフォード', 42.8353600, -71.6489600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140445, 'Mont Vernon', 'Mont Vernon', 'Mont Vernon,Mount Vernon,Mount-Vernon', 42.8945300, -71.6742400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140446, 'Moultonborough', 'Moultonborough', 'Moultonboro,Moultonborou,Moultonborough,mwltwnbwrw,Моултонбороу,مولتونبورو,مولٹنبرو، نیو ہیمپشائر', 43.7548000, -71.3967400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140447, 'Nashua', 'Nashua', 'ASH,Nashua,Watanic,na shu e,naesyua,nashua,nashwa,nshwa  nywhmpshayr,Нашуа,נשואה,ناشوا,ناشوا، نیو ہیمپشائر,نشوا، نیوهمپشایر,ナシュア,纳舒厄,내슈아', 42.7653700, -71.4675700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140448, 'New Boston', 'New Boston', 'Lane''s New Boston,New Boston', 42.9761900, -71.6939600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140449, 'New Castle', 'New Castle', 'Great Island,Great-Island,New Castle,Newcastle', 43.0723100, -70.7161600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140450, 'New Durham', 'New Durham', '', 43.4367500, -71.1722900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140451, 'New Ipswich', 'New Ipswich', 'Ipswich Canada,N''ju Ipsvich,New Ipswich,nyw aybswytsh,Нью Ипсвич,نيو إيبسويتش,نیو اپسویچ، نیو ہیمپشائر', 42.7481400, -71.8542400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140452, 'New London', 'New London', 'Dantzick,N''ju London,N''ju-London,New London,Nju London,nyw landn  nywhmpshayr,nyw lndn,Њу Лондон,Нью Лондон,Нью-Лондон,نيو لندن,نیو لاندن، نیوهمپشایر,نیو لندن، نیو ہیمپشائر', 43.4139600, -71.9850800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140453, 'Newbury', 'Newbury', 'Dantzick,Fishersfield,N''jubjuri,Newbury,nywbwry,Ньюбюри,نيوبوري,نیوبیری، نیو ہیمپشائر', 43.3214600, -72.0359200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140454, 'Newmarket', 'Newmarket', 'Lampreyville,N''jumarket,New-Market,Newmarket,Newmarkit,Njumarket,nywmarkt,nywmarkt  nywhmpshayr,Њумаркет,Ньюмаркет,نيوماركت,نیومارکت، نیوهمپشایر,نیومارکٹ، نیو ہیمپشائر', 43.0828600, -70.9350600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140455, 'Newport', 'Newport', 'N''juport,Njuport,niu bo te,nyupoto,nywbwrt,nywprt  nywhmpshayr,Њупорт,Ньюпорт,Нюпорт,نيوبورت,نیوپرت، نیوهمپشایر,نیوپورٹ، نیو ہیمپشائر,ニューポート,纽波特', 43.3653500, -72.1734200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140456, 'Newton', 'Newton', 'N''juton,Ньютон', 42.8695300, -71.0345000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140457, 'North Conway', 'North Conway', 'Nors Konvehj,Nort Konvej,nrt kanwy  nywhmpshayr,Норс Конвэй,Норт Конвеј,نرت کانوی، نیوهمپشایر', 44.0536800, -71.1284000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140458, 'North Haverhill', 'North Haverhill', '', 44.0903400, -72.0264800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140459, 'North Hampton', 'North Hampton', '', 42.9725900, -70.8297800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140460, 'Northfield', 'Northfield', 'Norsfild,nwrthfyld,Норсфилд,نارتھفیلڈ، نیو ہیمپشائر,نورثفيلد', 43.4331300, -71.5923000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140461, 'Northumberland', 'Northumberland', 'Northumberland,Northumberland Village', 44.5633900, -71.5587000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140462, 'Northwood', 'Northwood', 'Norsvud,nwrthwwd,Норсвуд,نارتھووڈ، نیو ہیمپشائر,نورثوود', 43.1942500, -71.1509000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140463, 'Nottingham', 'Nottingham', 'Nottingkham,nwtynghham,Ноттингхам,نوتينغهام,نوٹنگھم، نیو ہیمپشائر', 43.1145300, -71.0997800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140464, 'Orford', 'Orford', 'Orford,Orford Village', 43.9053500, -72.1400900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140465, 'Ossipee', 'Ossipee', 'New Garden,New-Garden,Osipij,Ossipee,Ossipi,Wigwam Village,ao xi pi,awsyby,awsypy  nywhmpshayr,oshipi,Осипий,Оссипи,أوسيبي,اوسیپی، نیو ہیمپشائر,اوسیپی، نیوهمپشایر,オシピー,奥西皮', 43.6853600, -71.1167300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140466, 'Pelham', 'Pelham', '', 42.7345300, -71.3245100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140467, 'Pembroke', 'Pembroke', 'Pembroke,Rehmbrouk,Suncook,bymbrwk,Рэмброук,بيمبروك,پیمبروک، نیو ہیمپشائر', 43.1467500, -71.4575700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140468, 'Peterborough', 'Peterborough', 'Peterboro,Peterborou,Peterborough,Piterboro,bytrbwrw,pytrbwrwg  nywhmpshayr,Петербороу,Питерборо,بيتربورو,پیتربوروگ، نیوهمپشایر,پیٹربرو، نیو ہیمپشائر', 42.8706400, -71.9517500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140469, 'Pinardville', 'Pinardville', '', 42.9942500, -71.5072900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140470, 'Pittsfield', 'Pittsfield', '', 43.3059100, -71.3242300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140471, 'Plaistow', 'Plaistow', '', 42.8364800, -71.0947800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140472, 'Plymouth', 'Plymouth', 'Plajmaus,Plimut,Plymouth,Plymouth Compact,plymwth  nywhmpshayr,Плаймаус,Плимут,Плимът,پلیموث، نیوهمپشایر', 43.7570200, -71.6881300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140473, 'Portsmouth', 'Portsmouth', 'PSM,Pascataquack,Piscataqua,Portsmaus,Portsmouth,Portsmut,Rivertown,Strabery Banke,Strawberry Banck,Strawberry Bancke,Strawberry Bank,Strawberry-bank,Strawbery Banke,The Bank,bwrtsmwth,pocheumeoseu,potsumasu,prtsmwth  nywhmpshayr,pu ci mao si,Портсмаус,Портсмут,Портсмът,بورتسموث,پرتسموث، نیوهمپشایر,ポーツマス,朴次茅斯,포츠머스', 43.0717600, -70.7625500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140474, 'Raymond', 'Raymond', 'Freetown,Raymond', 43.0362000, -71.1834000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140475, 'Richmond', 'Richmond', '', 42.7548100, -72.2717500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140476, 'Rindge', 'Rindge', 'Rindge,Rindzh,Rowley Canada,Риндж,رینج، نیو ہیمپشائر', 42.7512000, -72.0098000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140477, 'Rochester', 'Rochester', 'Rochestehr,Rochester,locheseuteo,luo che si te,rachstr  nywhmpshayr,rochesuta,rwtshstr,Рочестер,Рочестэр,راچستر، نیوهمپشایر,روتشستر,ロチェスター,羅徹斯特,로체스터', 43.3045300, -70.9756200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140478, 'Rollinsford', 'Rollinsford', 'Rollinsford,Salmon Falls', 43.2362000, -70.8203400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140479, 'Rumney', 'Rumney', 'Rumney,Rumney Village', 43.8053500, -71.8125800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140480, 'Rye', 'Rye', 'Pannaway,Pascataquack,Raj,Rye,Rye Center,Sandy Beach,Рай,رائی، نیو ہیمپشائر', 43.0134200, -70.7708900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140481, 'Salem', 'Salem', 'Salem,salm  nywhmpshayr,seiramu,Салем,سالم، نیوهمپشایر,سیلم، نیو ہیمپشائر,セイラム', 42.7884200, -71.2008900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140482, 'Salisbury', 'Salisbury', 'Salisbury,South Village,Steven''s Town,Stevenstown', 43.3800800, -71.7170200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140483, 'Sanbornton', 'Sanbornton', 'Sanbornton,Sanbornton Square,Санборнтон,سینبورنٹن، نیو ہیمپشائر', 43.4892400, -71.5823000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140484, 'Sanbornville', 'Sanbornville', '', 43.5542500, -71.0309000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140485, 'Sandown', 'Sandown', '', 42.9287000, -71.1870100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140486, 'Sandwich', 'Sandwich', 'Sehndvich,Сэндвич,سینڈوچ، نیو ہیمپشائر', 43.7903500, -71.4111800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140487, 'Seabrook', 'Seabrook', '', 42.8948100, -70.8711600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140488, 'Somersworth', 'Somersworth', 'Great Falls,Samehrs,Samersvort,Sligo,Somersworth,Sumersworth,Summersworth,sa mo si wo si,samazuwasu,samrzwrt  nywhmpshayr,swmrswwrth,Самерсворт,Самэрс,سامرزورت، نیوهمپشایر,سامرزورتھ، نیو ہیمپشائر,سومرسوورث,サマーズワース,薩默斯沃思', 43.2617500, -70.8653400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140489, 'South Hooksett', 'South Hooksett', '', 43.0264700, -71.4353400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140490, 'Springfield', 'Springfield', 'Protectworth,Springfield,Springfild,Спрингфилд', 43.4950700, -72.0334200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140491, 'Strafford', 'Strafford', '', 43.3270300, -71.1842300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140492, 'Stratford', 'Stratford', 'Stratford,Stratford Hollow', 44.6550500, -71.5556400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140493, 'Stratham Station', 'Stratham Station', '', 43.0528700, -70.8953300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140494, 'Sunapee', 'Sunapee', 'Corey''s Town,Sunapee', 43.3875700, -72.0878600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140495, 'Suncook', 'Suncook', '', 43.1306400, -71.4531200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140496, 'Sutton', 'Sutton', '', 43.3342400, -71.9514700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140497, 'Swanzey', 'Swanzey', 'Svanzehj,Swanzey,Swanzey Center,Сванзэй,سوینزی، نیو ہیمپشائر', 42.8698000, -72.2817500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140498, 'Tamworth', 'Tamworth', 'Tamvors,Тамворс,ٹیمورتھ، نیو ہیمپشائر', 43.8598000, -71.2631300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140499, 'Temple', 'Temple', 'Tehmpl,Тэмпл,ٹیمپل، نیو ہیمپشائر', 42.8181400, -71.8514700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140500, 'Thornton', 'Thornton', '', 43.8928500, -71.6759100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140501, 'Tilton', 'Tilton', 'Bridge Village,Sanbornton Bridge,Tilton,Union Bridge,Тилтон,ٹلٹن، نیو ہیمپشائر', 43.4423000, -71.5889600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140502, 'Troy', 'Troy', 'Troja,Троя', 42.8239700, -72.1811900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140503, 'Tuftonboro', 'Tuftonboro', 'Tuftonborou,Туфтонбороу,ٹوفٹنبرو، نیو ہیمپشائر', 43.6964700, -71.2220100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140504, 'Unity', 'Unity', '', 43.2939600, -72.2603700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140505, 'Wakefield', 'Wakefield', 'Uehjkfild,Wakefield,Wakefield Center,Уэйкфилд,ویکفیلڈ، نیو ہیمپشائر', 43.5681300, -71.0300700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140506, 'Weare', 'Weare', 'Vireh,Вирэ,ویئر، نیو ہیمپشائر', 43.0948000, -71.7306300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140507, 'Webster', 'Webster', '', 43.3289700, -71.7178600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140508, 'West Swanzey', 'West Swanzey', '', 42.8700800, -72.3217500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140509, 'Westmoreland', 'Westmoreland', '', 42.9620300, -72.4423100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140510, 'Whitefield', 'Whitefield', 'HIE,Whitefield,Whitefields', 44.3731200, -71.6100800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140511, 'Wilmot', 'Wilmot', 'Four Corners,Wilmot', 43.4517400, -71.9136900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140512, 'Wilton', 'Wilton', 'Uiltun,Vilton,wyltwn  nywhmpshayr,Вилтон,Уилтън,ویلتون، نیوهمپشایر', 42.8434200, -71.7350700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140513, 'Winchester', 'Winchester', '', 42.7734200, -72.3831400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140514, 'Windham', 'Windham', 'Vindkham,Windham,Wyndham,u~indamu,Виндхам,وینڈم، نیو ہیمپشائر,ウィンダム', 42.8006400, -71.3042300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140515, 'Wolfeboro', 'Wolfeboro', 'Vol''fborou,Vulfboro,Wolfborough,Wolfeboro,wwlfbwrw  nywhmpshayr,Вольфбороу,Вулфборо,وولفبرو، نیو ہیمپشائر,وولفبورو، نیوهمپشایر', 43.5839700, -71.2072900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140516, 'Woodstock', 'Woodstock', 'Fairfield,Peeling,Vudstok,Woodstock,Вудсток', 43.9775700, -71.6850800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140517, 'Woodsville', 'Woodsville', 'Bodsvil,Governor''s Farm,Governor''s Reservation,Governors Farm,Governors Reservation,Vudsvill,Woodsville,wwdswyl  nywhmpshayr,Бодсвил,Вудсвилл,وودسویل، نیوهمپشایر', 44.1522900, -72.0373100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140518, 'Allendale', 'Allendale', 'Alendejl,Olehnzhehjl,alndyl  nywjrsy,Алендејл,Олэнжэйл,آلندیل، نیوجرسی,ایلنڈیل، نیو جرسی', 41.0414900, -74.1290300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140519, 'Allentown', 'Allentown', 'Alentaun,Allen Town,Allens Town,Allenstown,Allentaun,Allentown,Olehntaun,alntawn  nywjrsy,Алентаун,Аллентаун,Олэнтаун,آلنتاون، نیوجرسی,ایلن ٹاؤن، نیو جرسی', 40.1778900, -74.5834900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140520, 'Alpine', 'Alpine', 'Alpajn,Alpin,alpayn  nywjrsy,Алпајн,Алпин,الپاین، نیوجرسی', 40.9559300, -73.9312500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140521, 'Alpha', 'Alpha', 'Al''fa,Alfa,Alpha,Straw,alfa  nywjrsy,Алфа,Альфа,آلفا، نیوجرسی', 40.6670400, -75.1574000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140522, 'Annandale', 'Annandale', 'Anandejl,Annandehjl,Анандејл,Аннандэйл', 40.6409300, -74.8812800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140523, 'Asbury Park', 'Asbury Park', 'ARX,Absjuri Park,Asbury Park,Azberi Park,a si bo li pa ke,aejeubelipakeu,aesbari parka,asbry park  nyw jrsy,asbwry park  nywjrsy,Абсюри Парк,Азбери Парк,اسبری پارک، نیو جرسی,اسبوری پارک، نیوجرسی,अॅस्बरी पार्क,阿斯伯里帕克,애즈베리파크', 40.2203900, -74.0120800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140524, 'Atlantic Highlands', 'Atlantic Highlands', 'Atlantic Highlands,Atlantik Khajlands,Portland Point,Portland Poynt,atlantyk haylndz  nywjrsy,Атлантик Хайландс,Атлантик Хајландс,آتلانتیک هایلندز، نیوجرسی', 40.4078900, -74.0343100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140525, 'Avenel', 'Avenel', '', 40.5803800, -74.2851500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140526, 'Avon-by-the-Sea', 'Avon-by-the-Sea', 'Avon,Avon-by-the-Sea,Ehvan-baj-zeh-Si,Key East,aywn-bay-d-sy  nywjrsy,Эван-бай-зэ-Си,ایون-بای-د-سی، نیوجرسی', 40.1923400, -74.0159700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140527, 'Bayonne', 'Bayonne', 'Bajon,Bajonn,Bayonne,Bejon,Bejonn,Bergen Neck,Constabals Hoek,Pamlicae Farme,Pamrepau,baywn  nywjrsy,bei yong,beion,beiyon,byywnny  nyw jrsy,Байон,Байонн,Бейонн,Бејон,بایون، نیوجرسی,بیئوننی، نیو جرسی,ベイヨン,貝永,베이온', 40.6687100, -74.1143100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140528, 'Beattystown', 'Beattystown', 'Beatty''s Mills,Beattyestown,Beattys Town,Beattystown,Beatyestown,Beatystown', 40.8131500, -74.8429400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140529, 'Bedminster', 'Bedminster', 'Bedminster,Bedminster Township,Lesser Crossroads', 40.6806600, -74.6454400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140530, 'Belleville', 'Belleville', 'Belleville,Second River', 40.7937100, -74.1501400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140531, 'Belford', 'Belford', '', 40.4259400, -74.0868100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140532, 'Belmar', 'Belmar', 'BLM,Behlmar,Belmar,Ocean Beach,blmar  nywjrsy,Белмар,Бэлмар,بلمار، نیوجرسی', 40.1784500, -74.0218000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140533, 'Belvidere', 'Belvidere', 'Behlvider,Bel''vedere,Belvedere,Belvidere,Belvidir,Greenwich-on-the-Delaware,bei er wei di er,blwydr  nywjrsy,Белвидир,Бельведере,Бэлвидер,بلویدر، نیوجرسی,貝爾維迪爾', 40.8298200, -75.0776700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140534, 'Bergenfield', 'Bergenfield', 'Behrgenfild,Bergen Fields,Bergenfield,Bergenfields,Bergenfild,brgnfyld  nywjrsy,Бергенфилд,Бэргенфилд,برگنفیلد، نیوجرسی', 40.9276000, -73.9973600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140535, 'Berkeley Heights', 'Berkeley Heights', 'Berkeley Heights,Berkley Heights', 40.6834300, -74.4426500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140536, 'Bernardsville', 'Bernardsville', 'Behrnardsvill,Bernardsvil,Bernardsville,Logtown,Veal Town,Vealtown,brnardzwyl  nywjrsy,Бернардсвил,Бэрнардсвилл,برناردزویل، نیوجرسی', 40.7187100, -74.5693200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140537, 'Beverly', 'Beverly', 'Behverli,Beverli,Beverly,Beverly City,Bevurli,Churchville,Dunk''s Ferry,Dunks Ferry,bwrly  nywjrsy,Беверли,Бевърли,Бэверли,بورلی، نیوجرسی', 40.0653900, -74.9190600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140538, 'Bloomfield', 'Bloomfield', 'Bloomfield,Wardsesson,Wassessing,Watsaping,Watsessing', 40.8067700, -74.1854200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140539, 'Bloomingdale', 'Bloomingdale', 'Blumigdehjl,Blumingdejl,blwmyngdyl  nywjrsy,Блумигдэйл,Блумингдејл,بلومنگڈیل، نیو جرسی,بلومینگدیل، نیوجرسی', 41.0020400, -74.3265400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140540, 'Bloomingdale', 'Bloomingdale', '', 40.4976000, -74.6473800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140541, 'Bogota', 'Bogota', 'Bogata,Bogota,bwgwta  nywjrsy,Богата,Богота,بوگوتا، نیوجرسی,بوگوٹا، نیو جرسی', 40.8762100, -74.0298600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140542, 'Boonton', 'Boonton', 'Booneton,Boonetown,Boonton,Boun Town,Bunton,Old Forge,bwntwn  nywjrsy,Бунтон,بونتون، نیوجرسی', 40.9026000, -74.4071000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140543, 'Bordentown', 'Bordentown', 'Borden Town,Bordentaun,Bordenton,Bordentown,Bordings Town,Burdenstown,Farnsworth''s Landing,Farnsworths Landing,bwrdntawn  nywjrsy,Бордентаун,بوردنتاون، نیوجرسی', 40.1462200, -74.7118300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140544, 'Bound Brook', 'Bound Brook', 'Baund Bruk,Baund-Bruk,Bound Brook,Boundbreak,Boundbrook,Bridgewater,bwnd brwk  nywjrsy,Баунд Брук,Баунд-Брук,بوند بروک، نیوجرسی', 40.5684400, -74.5384900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140545, 'Bradley Beach', 'Bradley Beach', 'Bradlehj Bich,Bradli Bich,brdly bych  nywjrsy,Брадли Бич,Брадлэй Бич,بردلی بیچ، نیوجرسی', 40.2023400, -74.0120800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140546, 'Bradley Gardens', 'Bradley Gardens', '', 40.5628800, -74.6546000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140547, 'Brass Castle', 'Brass Castle', '', 40.7648200, -75.0110100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140548, 'Brielle', 'Brielle', 'Brajll,Brijel,bryl  nywjrsy,Брайлл,Бријел,بریل، نیوجرسی', 40.1078900, -74.0565300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140549, 'Brownville', 'Brownville', '', 40.4006600, -74.2951500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140550, 'Brookdale', 'Brookdale', '', 40.8337100, -74.1829200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140551, 'Budd Lake', 'Budd Lake', 'Budd Lake,Budd''s Lake,Buddlake,Budds Lake', 40.8712100, -74.7340500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140552, 'Burlington', 'Burlington', 'Berlington,Bjurlington,Borlington,Borlingtowne,Bridlington,Bridlington Towne,Burling Town,Burlington,Burlingtun,Buzlington,New Beverley,New Beverly,barlingtana,Берлингтон,Бърлингтън,Бюрлингтон,बर्लिंग्टन', 40.0712200, -74.8648900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140553, 'Butler', 'Butler', 'Batlehr,Batler,batlr  nywjrsy,Батлер,Батлэр,باتلر، نیوجرسی,بٹلر، نیو جرسی', 41.0037100, -74.3415400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140554, 'Caldwell', 'Caldwell', 'CDW,Kaldvehll,Kolduehll,Koldvel,kaldwl  nywjrsy,kaltvel,Калдвэлл,Колдвел,Колдуэлл,کالدول، نیوجرسی,கால்ட்வெல்', 40.8398200, -74.2765400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140555, 'Califon', 'Califon', 'Califon,California,Kalifon,kalyfwn  nywjrsy,kylyfwn  nyw jrsy,Калифон,کالیفون، نیوجرسی,کیلیفون، نیو جرسی', 40.7195400, -74.8357200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140556, 'Carlstadt', 'Carlstadt', 'Carlstadt,Karlshtad,Karlstadt,Tailor Town,karlastadt  nywjrsy,Карлстадт,Карлштад,کارلاستادت، نیوجرسی', 40.8403800, -74.0907000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140557, 'Carteret', 'Carteret', 'Carteret,Kartereht,Karteret,Roosevelt,kartrt  nywjrsy,Картерет,Картерэт,کارترت، نیوجرسی', 40.5773300, -74.2282000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140558, 'Cedar Glen West', 'Cedar Glen West', '', 40.0420600, -74.2926500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140559, 'Cedar Grove', 'Cedar Grove', 'Cedar Grove,Cedarville', 40.8517700, -74.2290300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140560, 'Chatham', 'Chatham', 'Bonnel,Bonnell Town,Chatham,Chatham Borough,John Days Bridge,shatham brw  nywjrsy,شاتهام برو، نیوجرسی', 40.7409300, -74.3837600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140561, 'Chester', 'Chester', 'Black River,Chehster,Chester,Chester Borough,Честер,Чэстер', 40.7842700, -74.6968300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140562, 'Clark', 'Clark', '', 40.6409400, -74.3107000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140563, 'Clearbrook Park', 'Clearbrook Park', '', 40.3098300, -74.4646000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140564, 'Cliffside Park', 'Cliffside Park', 'Kliffsajd Park,Klifsajd Park,klyfsayd park  nywjrsy,Клифсајд Парк,Клиффсайд Парк,کلف سائیڈ پارک، نیو جرسی,کلیفساید پارک، نیوجرسی', 40.8214900, -73.9876400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140565, 'Cliffwood Beach', 'Cliffwood Beach', '', 40.4420500, -74.2168100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140566, 'Clifton', 'Clifton', 'Clifton,Klifton,Weasel,ke li fu dun,keullipeuteon,klyftwn  nywjrsy,kurifuton,Клифтон,کلفٹن، نیو جرسی,کلیفتون، نیوجرسی,クリフトン,克利夫頓,클리프턴', 40.8584300, -74.1637600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140567, 'Clinton', 'Clinton', 'Clinton,Hunt''s Mills,Hunts Mills,Klinton,Клинтон', 40.6367700, -74.9098900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140568, 'Closter', 'Closter', 'Klostehr,Kloster,klwstr  nywjrsy,Клостер,Клостэр,کلوستر، نیوجرسی', 40.9731500, -73.9615300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140569, 'Colonia', 'Colonia', 'Colonia,Colonia Station,Houtenville', 40.5745500, -74.3020900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140570, 'Concordia', 'Concordia', '', 40.3109400, -74.4482100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140571, 'Cranbury', 'Cranbury', 'Cranberry,Cranbury', 40.3162200, -74.5137600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140572, 'Crandon Lakes', 'Crandon Lakes', '', 41.1242600, -74.8398900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140573, 'Cranford', 'Cranford', 'Krehnford,Крэнфорд', 40.6584400, -74.2995900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140574, 'Cresskill', 'Cresskill', 'Closter,Cresskill,Krehsskil,Kreskil,Schrallenburgh Station,krskyl  nywjrsy,Крескил,Крэсскил,کرسکیل، نیوجرسی', 40.9414900, -73.9593000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140575, 'Dayton', 'Dayton', 'Dejton,Дейтон', 40.3726100, -74.5101500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140576, 'Delanco', 'Delanco', 'Delanco,Delranco,Rancocas Station', 40.0506700, -74.9535000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140577, 'Demarest', 'Demarest', 'Demarehst,Demarest,dmarst  nywjrsy,Демарест,Демарэст,دمارست، نیوجرسی', 40.9573200, -73.9634700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140578, 'Dover', 'Dover', 'Beamans,Dovehr,Dover,Old Tye,dawr  nywjrsy,Довер,Довэр,داور، نیوجرسی', 40.8839900, -74.5621000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140579, 'Dunellen', 'Dunellen', 'Danehllen,Danelen,danln  nywjrsy,Данелен,Данэллен,دانلن، نیوجرسی', 40.5892700, -74.4718200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140580, 'Dumont', 'Dumont', 'Djumont,Dumont,Schraalenburgh,Schralenburg,Strahlenburg,damwnt  nywjrsy,Думонт,Дюмонт,دامونت، نیوجرسی', 40.9406500, -73.9968100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140581, 'East Brunswick', 'East Brunswick', '', 40.4278800, -74.4159800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140582, 'East Freehold', 'East Freehold', '', 40.2809400, -74.2512600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140583, 'East Hanover', 'East Hanover', '', 40.8201000, -74.3648700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140584, 'East Newark', 'East Newark', 'East Newark,Est NJuark,Harrison,Ist Nehvark,mshrqy nywark  nyw jrsy,nywark shrqy  nywjrsy,Ест Њуарк,Ист Нэварк,مشرقی نیوارک، نیو جرسی,نیوآرک شرقی، نیوجرسی', 40.7484300, -74.1618100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140585, 'East Orange', 'East Orange', 'Doddtown,East Orange', 40.7673200, -74.2048700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140586, 'East Rutherford', 'East Rutherford', 'East Rutherford,Ijst Rudurford,Ist Raderford,Ist Raderfornt,Ist Ruzehrford,Ist-Raterford,Ist-Rezerford,dong lu se fu,iseuteuleodeopeodeu,isutorazafodo,kilakku ratarhport,radrfwrd shrqy  nywjrsy,Ιστ Ράδερφορντ,Іст-Резерфорд,Ийст Ръдърфорд,Ист Радерфорд,Ист Рузэрфорд,Ист-Ратерфорд,رادرفورد شرقی، نیوجرسی,கிழக்கு ரதர்ஃபோர்ட்,イーストラザフォード,東盧瑟福,이스트러더퍼드', 40.8339900, -74.0970900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140587, 'Eatontown', 'Eatontown', 'Itontaun,aytwntawn  nywjrsy,Итонтаун,ایتونتاون، نیوجرسی', 40.2962200, -74.0509700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140588, 'Edgewater Park', 'Edgewater Park', 'Edzhuatehr Park Taunship,Municipio de Edgewater Park,ajwatr park  nywjrsy,Еджуатэр Парк Тауншип,اجواتر پارک، نیوجرسی', 40.0681700, -74.9007200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140589, 'Edison', 'Edison', 'Edison,Edisun,Ehdison,Ehdison Taunship,Gmina Edison,Menlo Park,adyswn  nywjrsy,ai di sheng,edisana,ediseun,ejison,etican,Едисон,Едисън,Эдисон,Эдисон Тауншип,ادیسون، نیوجرسی,ایڈیسن، نیو جرسی,एडिसन,எடிசன்,エジソン,爱迪生,에디슨', 40.5187200, -74.4121000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140590, 'Edgewater', 'Edgewater', 'Edgewater,Edzvoter,Ehdzhuateh,Undercliff,ajwatr  nywjrsy,Еџвотер,Эджуатэ,اجواتر، نیوجرسی,ایج واٹر، نیو جرسی', 40.8270400, -73.9756900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140591, 'Elizabeth', 'Elizabeth', 'Ehlizabeht,Ehlizabet,Elizabet,Elizabetas,Elizabeth,Elizabeth Town,Elizabeth Towne,Elizabethtown,Elizabets Towne,alyzabt  nywjrsy,alyzabyth,ellijabeseu,erizabesu,yi li sha bai,Елизабет,Елізабет,Элизабет,Элизабэт,אליזבת,إليزابيث,الزبتھ، نیو جرسی,الیزابت، نیوجرسی,エリザベス,伊麗莎白,엘리자베스', 40.6639900, -74.2107000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140592, 'Elmwood Park', 'Elmwood Park', 'Dundee Lake,East Paterson,Ehlmvud Park,Elmvud Park,Elmwood Park,almwwd park  nywjrsy,Елмвуд Парк,Элмвуд Парк,الموود پارک، نیوجرسی', 40.9039900, -74.1184800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140593, 'Emerson', 'Emerson', 'Ehmerson,Emerson,Etna,amrswn  nywjrsy,Емерсон,Эмерсон,امرسون، نیوجرسی', 40.9762100, -74.0262500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140594, 'Englewood', 'Englewood', 'Ehnglvud,Englewood,Englvud,Engulud,Inglvud,Liberty Pole,anghlwwd,anglwwd  nywjrsy,en ge er wu de,eng-geul-udeu,Енглвуд,Енгълуд,Инглвуд,Энглвуд,إنغلوود,انگلوود، نیوجرسی,恩格尔伍德,엥글우드', 40.8928800, -73.9726400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140595, 'Englewood Cliffs', 'Englewood Cliffs', 'Ehnglvud Kliffs,Englvud Klifs,anglwwd klyfs  nywjrsy,Енглвуд Клифс,Энглвуд Клиффс,انگلوود کلیفس، نیوجرسی', 40.8853800, -73.9523600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140596, 'Englishtown', 'Englishtown', 'English Town,Englishtaun,Englishtown,Inglishtaun,anglyshtawn  nywjrsy,Енглиштаун,Инглиштаун,انگلیشتاون، نیوجرسی', 40.2973300, -74.3582000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140597, 'Essex Fells', 'Essex Fells', 'Ehsseks Fehlls,Eseks Fels,asks flz  nywjrsy,Есекс Фелс,Эссекс Фэллс,اسکس فلز، نیوجرسی', 40.8245400, -74.2845900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140598, 'Ewing', 'Ewing', '', 40.2698300, -74.7998800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140599, 'Fair Haven', 'Fair Haven', 'Fair Haven,Fair Haven Township,Fairhaven,Fajeh Khivehn,Fer Khejven,fayr hywn  nywjrsy,Файэ Хивэн,Фер Хејвен,فایر هیون، نیوجرسی,فیئر ہون، نیو جرسی', 40.3606700, -74.0381900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140600, 'Fair Lawn', 'Fair Lawn', 'Fajeh Lon,Fer Lon,fayr lawn  nywjrsy,fyyr lan  nyw jrsy,Файэ Лон,Фер Лон,فایر لاون، نیوجرسی,فیئر لان، نیو جرسی', 40.9403800, -74.1318100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140601, 'Fairfield', 'Fairfield', 'Feurfild,Феърфилд', 40.8837100, -74.3059800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140602, 'Fairview', 'Fairview', 'Fajehvju,Fervju,fayrwyw  nywjrsy,Файэвю,Фервју,فایرویو، نیوجرسی,فیئرویو، برگن کاؤنٹی، نیو جرسی', 40.8126000, -73.9990300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140603, 'Fairview', 'Fairview', '', 40.3731600, -74.0868100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140604, 'Fanwood', 'Fanwood', 'Fanvud,fanwwd  nywjrsy,Фанвуд,فانوود، نیوجرسی', 40.6409400, -74.3834800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140605, 'Farmingdale', 'Farmingdale', 'BLM,Farmingdale,Farmingdehjl,Farmingdejl,Marsh''s Bog,Upper Squankum,farmyngdyl  nywjrsy,Фармингдејл,Фармингдэйл,فارمینگدیل، نیوجرسی', 40.1965000, -74.1684800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140606, 'Finderne', 'Finderne', 'Findern,Finderne,Manville-Finderne', 40.5631600, -74.5776600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140607, 'Florence', 'Florence', 'Florence,Florence City,Florence Heights,High Bank', 40.1195500, -74.8054400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140608, 'Florham Park', 'Florham Park', 'Afton,Broomtown,Columbia,Floram Park,Florham Park,Florkham Park,flwrham park  nywjrsy,Флорам Парк,Флорхам Парк,فلورهام پارک، نیوجرسی', 40.7878800, -74.3882100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140609, 'Fords', 'Fords', '', 40.5292700, -74.3159800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140610, 'Flemington', 'Flemington', 'Flehmington,Fleming,Flemings,Flemington,Flemingtown,flmyngtwn  nywjrsy,fu lei ming dun,Флемингтон,Флэмингтон,فلمینگتون، نیوجرسی,夫雷明頓', 40.5123300, -74.8593300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140611, 'Fort Dix', 'Fort Dix', 'Fort Didz,WRI,di ke si bao,Форт Диџ,迪克斯堡', 40.0298400, -74.6184900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140612, 'Fort Lee', 'Fort Lee', 'Fort Lee,Fort Li,Pickletown,fotori,fwrt ly  nywjrsy,poteuli,Форт Ли,فورت لی، نیوجرسی,فورٹ لی، نیو جرسی,フォートリー,포트리', 40.8509300, -73.9701400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140613, 'Franklin', 'Franklin', 'Franklin,Franklin Furnace,Frenklin,franklyn  nywjrsy,Франклин,Френклин,فرانکلین، نیوجرسی', 41.1220400, -74.5804400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140614, 'Franklin Lakes', 'Franklin Lakes', 'Campgaw,Franklin Lakes,Franklin Lehjks,Franklin Lejks,franklyn lyks  nywjrsy,Франклин Лејкс,Франклин Лэйкс,فرانکلین لیکس، نیوجرسی', 41.0167600, -74.2057000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140615, 'Franklin Park', 'Franklin Park', '', 40.4389900, -74.5351500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140616, 'Freehold', 'Freehold', 'Borough de Freehold,Freehold,Freehold Borough,Frehold,Monmouth,Monmouth Court House,Monmouth Courthouse,fei li he zi zhi shi,菲力荷自治市', 40.2601100, -74.2737600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140617, 'Frenchtown', 'Frenchtown', 'Alexandria,Frehnchtaun,Frenchtaun,Frenchtown,Sunbeam,frnchtawn  nywjrsy,Френчтаун,Фрэнчтаун,فرنچتاون، نیوجرسی,فرینچ ٹاؤن، نیو جرسی', 40.5262100, -75.0615600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140618, 'Garfield', 'Garfield', 'East Passaic,Garfield,Garfild,gapildeu,garfyld  nywjrsy,Гарфилд,گارفیلد، نیوجرسی,گارفیلڈ، نیو جرسی,가필드', 40.8814900, -74.1132000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140619, 'Garwood', 'Garwood', 'Garvud,garwwd  nywjrsy,Гарвуд,گاروود، نیوجرسی', 40.6517700, -74.3229300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140620, 'Gladstone', 'Gladstone', 'Gladston,Gladstone,Peapack and Gladstone,Гладстон', 40.7226000, -74.6654400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140621, 'Glen Gardner', 'Glen Gardner', 'Clarkesville,Clarksville,Glehn Gardnehr,Glen Gardner,Sodom,Spruce Run,gln gardnr  nywjrsy,Глен Гарднер,Глэн Гарднэр,گلن گاردنر، نیوجرسی', 40.6967700, -74.9407200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140622, 'Glen Ridge', 'Glen Ridge', 'Glehn Ridzh,Glen Ridge Borough,Glen Ridz,Glen Ridzh,gln ryj brw  nywjrsy,kilen ritc,Глен Ридж,Глен Риџ,Глэн Ридж,گلن ریج برو، نیوجرسی,கிளென் ரிட்ச்', 40.8053800, -74.2037600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140623, 'Glen Rock', 'Glen Rock', 'Glehn Rok,Glen Rok,Glen-Rok,gln rak  nywjrsy,Глен Рок,Глен-Рок,Глэн Рок,گلن راک، نیوجرسی', 40.9628800, -74.1329200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140624, 'Green Knoll', 'Green Knoll', '', 40.6001000, -74.6121000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140625, 'Groveville', 'Groveville', '', 40.1698300, -74.6715500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140626, 'Guttenberg', 'Guttenberg', 'Gatenberg,Gattehnberg,gwtnbrg  nywjrsy,Гатенберг,Гаттэнберг,گوتنبرگ، نیوجرسی,گوٹنبرگ، نیو جرسی', 40.7920500, -74.0037500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140627, 'Hackensack', 'Hackensack', 'Hackensac,Hackensack,Hackinsack,Haginsack,Khakensak,Khakkensak,New Barbadoes,ha ken sa ke,haekeonsaeg,hakkensakku,hknsak  nywjrsy,Хакенсак,Хаккенсак,هکنساک، نیوجرسی,ہیکینسیک، نیو جرسی,ハッケンサック,哈肯萨克,해컨색', 40.8859300, -74.0434700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140628, 'Hackettstown', 'Hackettstown', 'Hacket Town,Hacket''s Town,Hacketstown,Hackettstown,Halketstown,Helm''s Mills,Helms Mills,Khakehttstaun,Khaketstaun,Musconetcong,haktstawn,Хакетстаун,Хакэттстаун,هاکتستاون', 40.8539900, -74.8290600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140629, 'Hamburg', 'Hamburg', 'Hamburg,Hamburgh,Khamburg,hambwrg,Хамбург,هامبورگ', 41.1534300, -74.5762700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140630, 'Hamilton Square', 'Hamilton Square', 'Crossroads in Nottingham Township,Hamilton Square,Nottingham Square', 40.2273300, -74.6532100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140631, 'Hampton', 'Hampton', 'Hampton,Khehmpton,Khempton,Musconetcong Village,South Hampton,Хемптон,Хэмптон', 40.7070400, -74.9560000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140632, 'Haledon', 'Haledon', 'Khaledon,Khehjldon,haldwn,Халедон,Хэйлдон,هالدون', 40.9356500, -74.1862600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140633, 'Hanover', 'Hanover', '', 40.8045400, -74.3668200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140634, 'Hardwick', 'Hardwick', '', 41.0545400, -74.9321200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140635, 'Harrington Park', 'Harrington Park', 'Kharington Park,Kharrington Park,hryngtwn park  nywjrsy,Харингтон Парк,Харрингтон Парк,هرینگتون پارک، نیوجرسی', 40.9837100, -73.9798600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140636, 'Harrison', 'Harrison', 'East Neward,Garrison,Harrison,Kharison,Kharrison,haeliseun,hryswn  nywjrsy,Гаррисон,Гаррісон,Харисон,Харрисон,هریسون، نیوجرسی,ہیریسن، نیو جرسی,해리슨', 40.7464900, -74.1562600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140637, 'Hasbrouck Heights', 'Hasbrouck Heights', 'Hasbrouck Hts.,Khasbrouk Khehjts,hsbrak hayts  nywjrsy,Хасброук Хэйтс,هسبراک هایتس، نیوجرسی', 40.8581600, -74.0807000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140638, 'Haworth', 'Haworth', 'Khavors,Khavort,hawwrth  nywjrsy,Хаворс,Хаворт,هاوورث، نیوجرسی', 40.9609300, -73.9901400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140639, 'Hawthorne', 'Hawthorne', 'Goffle,Hawthorne,Hopperstown,Khosorn,Khotorn,North Paterson,Small Lots,hawthwrn,Хосорн,Хоторн,هاوثورن', 40.9492600, -74.1537500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140640, 'Heathcote', 'Heathcote', '', 40.3887200, -74.5757100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140641, 'Helmetta', 'Helmetta', 'Helmetta,Khelmehtta,Khelmeta,Railroad Mills,hlmta  nywjrsy,Хелмета,Хелмэтта,هلمتا، نیوجرسی', 40.3767700, -74.4246000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140642, 'High Bridge', 'High Bridge', 'High Bridge,Highbridge,Khaj Bridz,Khaj Bridzh,Union Forge,hay bryj  nywjrsy,Хай Бридж,Хај Бриџ,های بریج، نیوجرسی', 40.6670500, -74.8957200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140643, 'Highland Lake', 'Highland Lake', '', 41.1767600, -74.4565500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140644, 'Highland Park', 'Highland Park', 'Khajland Park,Khajlend Park,haillaendeupakeu,haylnd park  nywjrsy,Хайленд Парк,Хајланд Парк,هایلند پارک، نیوجرسی,하일랜드파크', 40.4959400, -74.4243200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140645, 'Highlands', 'Highlands', 'Highlands,Khajlands,Parkertown,haylndz  nywjrsy,Хайландс,Хајландс,هایلندز، نیوجرسی', 40.4037200, -73.9915300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140646, 'Hightstown', 'Hightstown', 'Khajtstaun,haytstwn  nywjrsy,Хайтстаун,Хајтстаун,هایتستون، نیوجرسی', 40.2695500, -74.5232100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140647, 'Hillsdale', 'Hillsdale', '', 41.0026000, -74.0404200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140648, 'Hillside', 'Hillside', 'Hillside,Lyons Farms', 40.7012100, -74.2301500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140649, 'Ho-Ho-Kus', 'Ho-Ho-Kus', 'Ho-Ho-Kus,Hohokus,Hoppertown,Kho-Kho-Kus,hw-hw-kws  nywjrsy,Хо-Хо-Кус,هو-هو-کوس، نیوجرسی,ہو ہو کس، نیو جرسی', 40.9964900, -74.1012500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140650, 'Hoboken', 'Hoboken', 'Hobocan,Hoboken,Hobokena,Hoebuck,Khoboken,Khobouken,Khouboukun,habwkn  nywjrsy,hoboken,hobokeon,huo bo ken,hwbwqn,Хобокен,Хобоукен,Хоубоукън,הובוקן,هابوکن، نیوجرسی,ہوبوکین، نیو جرسی,ホーボーケン,霍博肯,호보컨', 40.7439900, -74.0323600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140651, 'Hopatcong', 'Hopatcong', 'Brookland,Brooklyn,Hopatcong,Khopatkong,hapatkwng  nywjrsy,Хопатконг,هاپاتکونگ، نیوجرسی', 40.9328800, -74.6593300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140652, 'Hopatcong Hills', 'Hopatcong Hills', '', 40.9439900, -74.6707200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140653, 'Hopewell', 'Hopewell', 'Columbia,Hopewell,Hoppewell,Khopuehlla,Khoupvehll,Khoupvel,hawwpwl  nywjrsy,Хопуэлла,Хоупвел,Хоупвэлл,هاووپول، نیوجرسی', 40.3892700, -74.7618300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140654, 'Irvington', 'Irvington', 'Camptown,Irvington', 40.7323200, -74.2348700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140655, 'Iselin', 'Iselin', 'EWR,Iselin,ZME', 40.5753800, -74.3223700, 'US', '2017-06-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140656, 'Jamesburg', 'Jamesburg', 'Buckalews Bogs,Dzejmsburg,Dzhehjmsburg,Jamesburg,Jamesburgh,jamsbwrg  nywjrsy,jmsbrg  nyw jrsy,Џејмсбург,Джэймсбург,جامسبورگ، نیوجرسی,جمسبرگ، نیو جرسی', 40.3526100, -74.4401500, 'US', '2017-07-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140657, 'Jersey City', 'Jersey City', 'Arissheck,Dinas Jersey,Dzersi Siti,Dzersi Sitis,Dzersisitija,Dzerzi Siti,Dzhehrsi-Sici,Dzhersej Siti,Dzhersi-Siti,Dzhursi Siti,Džersi Sitis,Džērsisitija,Hudson,JEC,Jersey Ceety,Jersey City,Paulus Hook,Paulus''s Hook,Powles Hook,Thanh pho Jersey,Thành phố Jersey,grzy syty,jajishiti,jarsi siti,jeojisiti,jrzy syty,jyrsy syty,ze xi shi,Џерзи Сити,Џерси Сити,Джерсей Сити,Джерси-Сити,Джерсі-Сіті,Джърси Сити,Джэрсі-Сіці,Ջերսի Սիթի,גרזי סיטי,جرزی سیتی,جرسی شہر، نیو جرسی,جيرسي سيتي,जर्सी सिटी,ジャージーシティ,泽西市,저지시티', 40.7281600, -74.0776400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140658, 'Keansburg', 'Keansburg', 'Keansburg,Keansburgh,Kinsburg,Tanner''s Landing,Waycake,kynzbwrg  nywjrsy,Кинсбург,کینزبورگ، نیوجرسی', 40.4417700, -74.1298600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140659, 'Kearny', 'Kearny', 'Barbadoes Neck,Karni,Kearney,Kearny,Kerni,Kirni,kani,karny  nywjrsy,Карни,Керни,Кирни,کارنی، نیوجرسی,カーニー', 40.7684300, -74.1454200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140660, 'Kendall Park', 'Kendall Park', 'Kendall Park,Tenmile Run', 40.4209400, -74.5607100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140661, 'Kenvil', 'Kenvil', 'Ferro Mont,Kenvil,McCainsville,McCainville,Vannatta', 40.8798200, -74.6184900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140662, 'Kenilworth', 'Kenilworth', 'Kehnilvors,Kenilvort,knylwwrth  nywjrsy,Кенилворт,Кэнилворс,کنیلوورث، نیوجرسی', 40.6764900, -74.2907000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140663, 'Keyport', 'Keyport', 'Chinagora,Kehjport,Key Port,Keyport,Kiport,kypwrt  nywjrsy,Кипорт,Кэйпорт,کیپورت، نیوجرسی', 40.4331600, -74.1995900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140664, 'Kingston', 'Kingston', 'Kings Town,Kingston,Kingstown,Кингстон,کنگسٹن، نیو جرسی', 40.3753800, -74.6134900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140665, 'Kinnelon', 'Kinnelon', 'Kinelon,Kinnehlon,Kinnelon,Smoke Rise,kynlwn  nywjrsy,Кинелон,Киннэлон,کینلون، نیوجرسی', 41.0017600, -74.3671000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140666, 'Lake Como', 'Lake Como', 'Lehjk Komo,Lejk Komo,South Belmar,lyk kwmw  nyw jrsy,lyk kwmw  nywjrsy,Лејк Комо,Лэйк Комо,لیک کومو، نیو جرسی,لیک کومو، نیوجرسی', 40.1598400, -74.0281900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140667, 'Lake Mohawk', 'Lake Mohawk', '', 41.0184300, -74.6601600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140668, 'Lake Telemark', 'Lake Telemark', '', 40.9567700, -74.4979300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140669, 'Lakehurst', 'Lakehurst', 'Lakehurst,Lehjkkhjorst,Lejkkhurst,Manchester Furnace,NEL,lykhwrst  nywjrsy,reikuhasuto,Лејкхурст,Лэйкхёрст,لیک ہورسٹ، نیو جرسی,لیکهورست، نیوجرسی,レイクハースト', 40.0145600, -74.3112600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140670, 'Lakewood', 'Lakewood', 'Bergen Works,Bricksburg,Lakewood,Lakewood Township,Lehjkvud,Lejkvud,Municipio de Lakewood,Washington Furnace,lykwwd  nywjrsy,lyyqwwd,reikuuddo,Лейквуд,Лејквуд,Лэйквуд,לייקוואוד,לייקווד,لیک ووڈ ٹاؤنشپ، نیو جرسی,لیکوود، نیوجرسی,レイクウッド', 40.0978900, -74.2176400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140671, 'Lambertville', 'Lambertville', 'Corrells Ferry,Coryel''s Ferry,Coryells Ferry,Georgetown,Lambehrtvill,Lambertsville,Lambertvil,Lambertville,lmbrtwyl  nywjrsy,Ламбертвил,Ламбэртвилл,لامبیرٹویل، نیو جرسی,لمبرتویل، نیوجرسی', 40.3659400, -74.9429400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140672, 'Laurence Harbor', 'Laurence Harbor', '', 40.4567700, -74.2465300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140673, 'Lawrenceville', 'Lawrenceville', 'Laurehnsvill,Lawrenceville,Lorensvil,Maidenhead,Лаурэнсвилл,Лоренсвил', 40.2973300, -74.7296000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140674, 'Lebanon', 'Lebanon', 'Lebanon,Lehbanon,Лебанон,Лэбанон', 40.6417700, -74.8360000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140675, 'Leisure Knoll', 'Leisure Knoll', '', 40.0190100, -74.2920900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140676, 'Leisure Village', 'Leisure Village', '', 40.0426200, -74.1848600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140677, 'Leisure Village East', 'Leisure Village East', '', 40.0301200, -74.1643100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140678, 'Leonardo', 'Leonardo', '', 40.4173300, -74.0620800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140679, 'Leonia', 'Leonia', 'Leonia,Lionija,le-onia,lywnya  nyw jrsy,lywnya  nywjrsy,Леониа,Лионија,لئونیا، نیوجرسی,لیونیا، نیو جرسی,레오니아', 40.8614900, -73.9881900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140680, 'Lincoln Park', 'Lincoln Park', 'Linkol''n Park,Linkoln Park,lynkln park  nywjrsy,Линколн Парк,Линкольн Парк,لینکلن پارک، نیوجرسی', 40.9242700, -74.3020900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140681, 'Lincroft', 'Lincroft', 'Leedsville,Lincraft,Lincroft,Linkroft,Линкрофт', 40.3306700, -74.1209700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140682, 'Linden', 'Linden', 'LDJ,Linden,Wheatsheaf,lyndn,lyndn  nywjrsy,rinden,Линден,ليندن,لیندن، نیوجرسی,リンデン', 40.6220500, -74.2445900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140683, 'Little Falls', 'Little Falls', 'Little Falls,Littlefalls', 40.8689900, -74.2082000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140684, 'Little Ferry', 'Little Ferry', 'Litl Feri,Littl Ferri,lytl fry  nywjrsy,Литл Фери,Литтл Ферри,لیتل فری، نیوجرسی', 40.8528800, -74.0420800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140685, 'Little Silver', 'Little Silver', 'Litl Silver,Littl Silver,Little Silver,Parkersville,lytl sylwr  nywjrsy,Литл Силвер,Литтл Силвер,لیتل سیلور، نیوجرسی', 40.3367800, -74.0470800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140686, 'Livingston', 'Livingston', 'Centerville,Cheapside,Livingston,Ливингстон', 40.7959300, -74.3148700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140687, 'Lodi', 'Lodi', 'Lodaj,Lodi,lady  nywjrsy,Лодај,Лоди,لادی، نیوجرسی,لوڈی، نیو جرسی', 40.8823200, -74.0832000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140688, 'Long Branch', 'Long Branch', 'Long Branch,Longbranch,lang brnch  nywjrsy,ronguburanchi,Лонг Бранч,لانگ برنچ، نیوجرسی,ロングブランチ', 40.3042800, -73.9923600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140689, 'Long Valley', 'Long Valley', 'German Valley,Long Vali,Long Vallehj,Long Valley,Лонг Вали,Лонг Валлэй', 40.7859300, -74.7801600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140690, 'Lyndhurst', 'Lyndhurst', 'Lyndhurst,New Barbadoes', 40.8120400, -74.1243100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140691, 'Madison', 'Madison', 'Battle Hill,Bottle Hill,Madison,Medison,Mehdison,South Hanover,mdyswn  nywjrsy,Мадисон,Медисон,Медісон,Мэдисон,مدیسون، نیوجرسی,میڈیسون، نیو جرسی', 40.7598200, -74.4171000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140692, 'Madison Park', 'Madison Park', '', 40.4515000, -74.3079200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140693, 'Mahwah', 'Mahwah', 'Mahwah,Makhvakh,Oweno,mava,mawa  nywjrsy,Махвах,مأوا، نیوجرسی,மாவா', 41.0887100, -74.1437600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140694, 'Manasquan', 'Manasquan', 'Manaskuan,Manasquan,Squan,Squan Village,manaskwan  nywjrsy,Манаскуан,ماناسکوان، نیوجرسی', 40.1262300, -74.0493000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140695, 'Manville', 'Manville', 'Hillsboro,Manvil,Manville,Mehnvill,mnwyl  nywjrsy,Манвил,Мэнвилл,منویل، نیوجرسی', 40.5409400, -74.5876600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140696, 'Maplewood', 'Maplewood', 'Jefferson,Maplewood,Middleville', 40.7312100, -74.2734800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140697, 'Marlboro', 'Marlboro', 'Marlboro,Marlborough', 40.3153900, -74.2462600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140698, 'Martinsville', 'Martinsville', 'Martinsville,Martinville', 40.6012100, -74.5590500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140699, 'Matawan', 'Matawan', 'Matavan,Matawan,Matayan,Mattawan,Middletown,Middletown Point,New Aberdeen,matawan  nywjrsy,Матаван,ماتاوان، نیوجرسی', 40.4148300, -74.2295900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140700, 'Maywood', 'Maywood', 'Mejvud,mywwd  nywjrsy,Мејвуд,میوود، نیوجرسی', 40.9026000, -74.0618100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140701, 'Mendham', 'Mendham', 'Mehnkham Boro,Mendam,Mendham,Mendham Borough,Mendom,Mendum,Rocksiticus,Roxiticus,mndham barw  nywjrsy,Мендам,Мэнхам Боро,مندهام بارو، نیوجرسی', 40.7759300, -74.6007100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140702, 'Mercerville', 'Mercerville', 'Five Roads,Mercerville,Sandtown', 40.2370500, -74.6865500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140703, 'Metuchen', 'Metuchen', 'Matochshoning,Matouchin,Metachehn,Metachen,Metuchen,Mitachen,mtwchn  nywjrsy,Метачен,Метачэн,Митачен,متوچن، نیوجرسی', 40.5431600, -74.3632000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140704, 'Middlebush', 'Middlebush', '', 40.4976000, -74.5293200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140705, 'Middlesex', 'Middlesex', 'Lincoln,Middlesex,Midlsehks,Midlseks,mydlsks  nywjrsy,Мидлсекс,Мидлсэкс,میدلسکس، نیوجرسی', 40.5726000, -74.4926500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140706, 'Midland Park', 'Midland Park', 'Midland Park,Midlandpark,mydlnd park  nywjrsy,Мидланд Парк,میدلند پارک، نیوجرسی', 40.9892600, -74.1407000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140707, 'Milford', 'Milford', 'Burnt Mills,Lowreytown,Milford,Sunburn,mylfwrd  nywjrsy,Милфорд,میلفورد، نیوجرسی,میلفورڈ، نیو جرسی', 40.5687100, -75.0946200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140708, 'Milltown', 'Milltown', 'Bergens Mills,Milltaun,Milltown,Miltaun,myltawn  nywjrsy,Миллтаун,Милтаун,میلتاون، نیوجرسی', 40.4562200, -74.4432100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140709, 'Monmouth Beach', 'Monmouth Beach', 'Monmaus Bich,Monmaut Bich,mwnmwwth bych  nywjrsy,Монмаус Бич,Монмаут Бич,مونمووث بیچ، نیوجرسی', 40.3303900, -73.9815300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140710, 'Monmouth Junction', 'Monmouth Junction', '', 40.3790000, -74.5465400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140711, 'Montclair', 'Montclair', 'Cranetown,Mont Clair,Montclair,Speertown,West Bloomfield', 40.8259300, -74.2090300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140712, 'Montvale', 'Montvale', 'Montvale,Montvehjl,Montvejl,QMV,mwntwyl  nywjrsy,Монтвејл,Монтвэйл,مونتویل، نیوجرسی', 41.0467600, -74.0229200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140713, 'Moonachie', 'Moonachie', 'Monachie,Moonachie,Munachi,Peach Island,mwnachy  nywjrsy,Муначи,موناچی، نیوجرسی', 40.8412100, -74.0451400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140714, 'Morganville', 'Morganville', '', 40.3765000, -74.2443100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140715, 'Morris Plains', 'Morris Plains', 'Moris Plejns,Morris Plehjns,mwrys plynz  nywjrsy,Морис Плејнс,Моррис Плэйнс,موریس پلینز، نیوجرسی', 40.8217700, -74.4809900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140716, 'Morristown', 'Morristown', 'MMU,Morris Town,Morristaun,Morristown,Morstaun,New Hanover,West Hanover,mo li si dui,moliseutaun,morisutaun,mwrs ٹawn  nyw jrsy,mwrys‌tawn  nywjrsy,Морристаун,Морстаун,מוריסטאון,مورس ٹاؤن، نیو جرسی,موریس‌تاون، نیوجرسی,モリスタウン,莫里斯敦,모리스타운', 40.7967700, -74.4815400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140717, 'Mount Arlington', 'Mount Arlington', 'Maunt Arlington,mawwnt arlyngtwn  nywjrsy,Маунт Арлингтон,ماوونت ارلینگتون، نیوجرسی', 40.9259300, -74.6348800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140718, 'Mountain Lakes', 'Mountain Lakes', '', 40.8948200, -74.4329300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140719, 'Mountainside', 'Mountainside', '', 40.6723200, -74.3573700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140720, 'Navesink', 'Navesink', 'Navesink,Neve Sincks,Neversunk', 40.3995500, -74.0354200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140721, 'Neptune City', 'Neptune City', 'Nept''jun,Neptjun Siti,Neptun Siti,Neptun-Siti,Neptune,nptwn syty  nywjrsy,Нептун Сити,Нептун-Сіті,Нептьюн,Нептюн Сити,نپتون سیتی، نیوجرسی', 40.2001100, -74.0279200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140722, 'Netcong', 'Netcong', 'Nehtkong,Netkong,nei te kong,ntkwng  nywjrsy,Нетконг,Нэтконг,نتکونگ، نیوجرسی,内特孔', 40.8989900, -74.7065500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140723, 'New Brunswick', 'New Brunswick', 'Brunswick,Inian,Inians Ferry,Middlesex,N''ju Bransvik,N''ju-Bransuik,N''ju-Bransvik,New Brunswick,Nju Bransvik,Nju Brunzuik,Nuevo Brunswick,The River,nyubeuleonjeuwig,nyuburanzuu~ikku,nyw branzwyk  nywjrsy,nyw brnzwk  nyw jrsy,nyw brwnzwyk,xin bu lang si wei ke,Њу Брансвик,Нью Брансвик,Нью-Брансвік,Нью-Брансуик,Ню Брънзуик,نيو برونزويك,نیو برانزویک، نیوجرسی,نیو برنزوک، نیو جرسی,ニューブランズウィック,新布朗斯维克,뉴브런즈윅', 40.4862200, -74.4518200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140724, 'New Egypt', 'New Egypt', 'New Egypt,Timmons Hill', 40.0676100, -74.5307100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140725, 'New Milford', 'New Milford', 'N''ju Milford,Nju Milford,Novye Milford,nyw mylfwrd  nywjrsy,Њу Милфорд,Новые Милфорд,Нью Милфорд,نیو میلفورد، نیوجرسی', 40.9351000, -74.0190300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140726, 'New Providence', 'New Providence', 'N''ju Providens,N''ju-Providens,New Providence,Nju Providens,Turkey,nyw prawydns  nywjrsy,Њу Провиденс,Нью Провиденс,Нью-Провиденс,نیو پراویدنس، نیوجرسی', 40.6984300, -74.4015400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140727, 'Newark', 'Newark', 'EWR,Gorad N''juark,Milford,N''juark,New Worke,Newark,Nieworke,Niouark,Niuarkas,Njuark,Novarcum,Nuarka,Nyuark,Youngs Point,n''yu''arka,n''yurka,nevark,niu hua ke,nuvark,nwrk,nyuaku,nyueokeu,nywark,nywark  nyw jrsy,nywark  nywjrsy,Ņuarka,Νιούαρκ,Њуарк,Горад Ньюарк,Ньюарк,Нюарк,Նյուարկ,נוארק,ניוארק,نيوآرك,نیوآرک، نیو جرسی,نیوآرک، نیوجرسی,न्यूअर्क,न्यूर्क,நுவார்க்,నెవార్క్,นวร์ก,ნიუარკი,ニューアーク,紐華克,뉴어크', 40.7356600, -74.1723700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140728, 'Newton', 'Newton', 'Chinkchewunska,N''juton,New Town,Newton,Newtown,Njuton,Sussex,Sussex Court House,niu dun,nywtwn  nywjrsy,Њутон,Ньютон,نیوتون، نیوجرسی,牛頓', 41.0581500, -74.7526700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140729, 'North Arlington', 'North Arlington', 'Nors Arlington,Nort Arlington,arlyngtwn shmaly  nywjrsy,Норс Арлингтон,Норт Арлингтон,آرلینگتون شمالی، نیوجرسی', 40.7884300, -74.1332000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140730, 'North Bergen', 'North Bergen', 'brgn shmaly  nywjrsy,برگن شمالی، نیوجرسی', 40.8042700, -74.0120800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140731, 'North Caldwell', 'North Caldwell', 'Nors Kaldvehll,Nort Koldvel,kaldwl shmaly  nywjrsy,Норс Калдвэлл,Норт Колдвел,کالدول شمالی، نیوجرسی', 40.8648200, -74.2582000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140732, 'North Haledon', 'North Haledon', 'Nors Khehjldon,Nort Khaledon,haldwn shmaly,Норс Хэйлдон,Норт Халедон,هالدون شمالی', 40.9551000, -74.1859800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140733, 'North Middletown', 'North Middletown', '', 40.4395500, -74.1190300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140734, 'North Plainfield', 'North Plainfield', 'Nors Plehjnfild,Nort Plejnfild,plynfyld shmaly  nywjrsy,Норс Плэйнфилд,Норт Плејнфилд,پلینفیلد شمالی، نیوجرسی', 40.6301000, -74.4273700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140735, 'Northfield', 'Northfield', '', 40.7742700, -74.3245900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140736, 'Northvale', 'Northvale', 'Neuvy,Norsvehjl,Northvale,Northvalle Neuvy,Nortvejl,nwrthwyl  nywjrsy,Норсвэйл,Нортвејл,نورثویل، نیوجرسی', 41.0064900, -73.9490300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140737, 'Norwood', 'Norwood', 'Norvud,narwwd  nywjrsy,Норвуд,ناروود، نیوجرسی', 40.9981500, -73.9618000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140738, 'Nutley', 'Nutley', 'Franklintown,Franklinville,Nutley,Spring Garden', 40.8223200, -74.1598700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140739, 'Oakhurst', 'Oakhurst', '', 40.2709400, -74.0162500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140740, 'Oakland', 'Oakland', 'Oakland,Oklend,Oukland,Yaughpaugh,Yawpaw,awklnd  nywjrsy,Оакланд,Окленд,Оукланд,اوکلند، نیوجرسی', 41.0131500, -74.2643100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140741, 'Ocean Grove', 'Ocean Grove', 'Oushan Grouv,Oushehn Grouv,Оушан Гроув,Оушэн Гроув', 40.2120600, -74.0065300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140742, 'Oceanport', 'Oceanport', 'Oushanport,Oushehn Port,awshnpwrt  nywjrsy,Оушанпорт,Оушэн Порт,اوشنپورت، نیوجرسی', 40.3181700, -74.0151400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140743, 'Ogdensburg', 'Ogdensburg', 'Ogdensburg,Ogdensburgh,Sodom,wjnsbwrg  nywjrsy,Огденсбург,وجنسبورگ، نیوجرسی', 41.0817600, -74.5923800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140744, 'Old Bridge', 'Old Bridge', 'Old Bridge,Oldbridge', 40.4148300, -74.3654300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140745, 'Old Tappan', 'Old Tappan', 'Old Tapan,Old Tappan,Ould Tappan,Taphaune,Tappan,awld tapan  nywjrsy,Олд Тапан,Оулд Таппан,اولد تاپان، نیوجرسی', 41.0106500, -73.9912500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140746, 'Oradell', 'Oradell', 'Delford,Oradehll,Oradel,Oradell,awradl  nywjrsy,Орадел,Ораделл,Орадэлл,اورادل، نیوجرسی', 40.9587100, -74.0368100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140747, 'Orange', 'Orange', '', 40.7706600, -74.2326500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140748, 'Oxford', 'Oxford', 'Axford Furnace,Oksford,Oxford,Oxford Furnace,Оксфорд', 40.8031500, -74.9896200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140749, 'Palisades Park', 'Palisades Park', 'Palisade Park,Palisades Park,Palisehjds Park,Palisejds Park,paelliseijeupakeu,palysadys park  nyw jrsy,palysydz park  nywjrsy,Палисејдс Парк,Палисэйдс Парк,پالیسادیس پارک، نیو جرسی,پالیسیدز پارک، نیوجرسی,팰리세이즈파크', 40.8481600, -73.9976400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140750, 'Palmyra', 'Palmyra', 'Palmajra,Pehlmira,palmyra  nywjrsy,Палмајра,Пэлмира,پالمیرا، نیوجرسی', 40.0070600, -75.0282300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140751, 'Paramus', 'Paramus', 'Parames,Paramus,Pyramus,paramasu,paramws  nywjrsy,prmws,Парамус,פרמוס,پاراموس، نیوجرسی,パラマス', 40.9445400, -74.0754200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140752, 'Park Ridge', 'Park Ridge', 'Park Ridge,Park Ridz,Park Ridzh,Parkridge,Pascack,Paskack,park ritcu,park ryj  nywjrsy,Парк Ридж,Парк Риџ,پارک ریج، نیوجرسی,பார்க் ரிட்சு', 41.0376000, -74.0407000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140753, 'Parsippany', 'Parsippany', 'Parcipany,Parcipponog,Parsippani,Parsippany,Percipany,Percipeny,Парсиппани', 40.8578800, -74.4259900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140754, 'Passaic', 'Passaic', 'Acquackanonk,Acquackanonk Bridge,Acquackanonk Landing,Aqueyquinunke,Haquequenunck,Pasejik Siti,Passaic,Passaik,ba sai ke,pasayyk  nywjrsy,paseiku,peoseiig,pysayk  nyw jrsy,Пасејик Сити,Пассаик,פאסעיק,پاسائیک، نیوجرسی,پیسایک، نیو جرسی,パセーイク,巴賽克,퍼세이익', 40.8567700, -74.1284800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140755, 'Paterson', 'Paterson', 'Great Falls,Manchester,New Manchester,Patehrson,Paterson,Patersun,Totowa,batrswn,pa te sen,paeteoseun,patason,ptrswn,ptrswn  nywjrsy,Патерсон,Патерсън,Патэрсон,פטרסון,باترسون,پترسون، نیوجرسی,پیٹرسن، نیو جرسی,แพเทอร์สัน,パターソン,帕特森,패터슨', 40.9167700, -74.1718100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140756, 'Peapack', 'Peapack', 'Peapack,Peapack and Gladstone,Pepack,Tepack', 40.7167700, -74.6565500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140757, 'Pennington', 'Pennington', 'Hopewell,Pehnnington,Penington,Pennington,Penny Town,Queenstown,pnyngtn  nywjrsy,Пенингтон,Пэннингтон,پنینگتن، نیوجرسی', 40.3284400, -74.7907200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140758, 'Perth Amboy', 'Perth Amboy', 'Ambo Point,Amboy,Amboy Perth,New Perth,New Point,Pehrs Ehmboj,Pert Amboj,Perth,Perth Amboy,Perth Town,Purt Amboj,pasuanboi,peoseuaemboi,prth ambwy  nywjrsy,Перт Амбој,Пърт Амбой,Пэрс Эмбой,پرتھ امبوی، نیو جرسی,پرث امبوی، نیوجرسی,パースアンボイ,퍼스앰보이', 40.5067700, -74.2654200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140759, 'Phillipsburg', 'Phillipsburg', 'Chintewick,Lopatcong Village,Philipsburg,Phillipsburg,Phillipsburgh', 40.6937100, -75.1901800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140760, 'Pine Lake Park', 'Pine Lake Park', '', 40.0031700, -74.2565300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140761, 'Piscataway', 'Piscataway', 'New Market,Piscataway,Piscattaway', 40.4992700, -74.3990400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140762, 'Plainfield', 'Plainfield', 'Plehjnfild,Plejnfild,peulleinpildeu,plynfyld  nywjrsy,pureinfirudo,Плейнфилд,Плейнфілд,Плејнфилд,Плэйнфилд,پلینفیلد، نیوجرسی,プレインフィールド,플레인필드', 40.6337100, -74.4073700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140763, 'Plainsboro Center', 'Plainsboro Center', '', 40.3317700, -74.5946000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140764, 'Point Pleasant', 'Point Pleasant', 'Pojnt Plezant,Pojnt Plezunt,pointeupeullejeonteu,pwynt plznt  nywjrsy,Пойнт Плезънт,Појнт Плезант,پوینت پلزنت، نیوجرسی,포인트플레전트', 40.0831700, -74.0681900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140765, 'Point Pleasant Beach', 'Point Pleasant Beach', 'Pojnt Plezant Bich,Pojnt Plizhant Bich,Pt. Pleasant Beach,pwynt plyznt bych  nywjrsy,Пойнт Плижант Бич,Појнт Плезант Бич,پوینت پلیزنت بیچ، نیوجرسی', 40.0912300, -74.0479100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140766, 'Pompton Lakes', 'Pompton Lakes', 'Pompton Lehjks,Pompton Lejks,pamptwn lyks  nywjrsy,Помптон Лејкс,Помптон Лэйкс,پامپتون لیکس، نیوجرسی', 41.0053800, -74.2907000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140767, 'Port Monmouth', 'Port Monmouth', 'Chanceville,Port Monmouth', 40.4301100, -74.0984700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140768, 'Port Reading', 'Port Reading', '', 40.5653800, -74.2604200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140769, 'Princeton', 'Princeton', 'PCT,Prince Town,Princes Town,Princeton,Princetonia,Princetown,Prinston,Prinstona,Prinstun,Stony Brook,brynstwn,peulinseuteon,prinstana,prynstwn,prynstwn  nywjrsy,pu lin si dun,purinsuton,Принстон,Принстън,Փրինսթոն,פרינסטון,برينستون,پرنسٹن، نیو جرسی,پرینستون، نیوجرسی,प्रिन्स्टन,प्रिन्‍सटन,პრინსტონი,プリンストン,普林斯顿,프린스턴', 40.3487200, -74.6590500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140770, 'Princeton Junction', 'Princeton Junction', 'ZTJ', 40.3173300, -74.6198800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140771, 'Princeton Meadows', 'Princeton Meadows', '', 40.3317700, -74.5637700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140772, 'Prospect Park', 'Prospect Park', '', 40.2403900, -74.7662700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140773, 'Prospect Park', 'Prospect Park', 'Prospekt Park,praspkt park  nywjrsy,Проспект Парк,پراسپکت پارک، نیوجرسی,پراسپیکٹ پارک، نیو جرسی', 40.9370400, -74.1743100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140774, 'Rahway', 'Rahway', 'Bridgetown,Leesville,Nawakwa,Rahwack,Rahway,Rakhvzj,Raway,Rjawau. Spanktown,Rovej,Spanktown,rawy  nywjrsy,Рахвзй,Ровеј,راوی، نیوجرسی', 40.6081600, -74.2776500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140775, 'Ramsey', 'Ramsey', 'Ramsehj,Ramsey,Ramseys,Ramseys Station,Rehmsi,Remzi,ramsy  nywjrsy,Рамсэй,Ремзи,Рэмси,رامسی، نیوجرسی', 41.0573200, -74.1409800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140776, 'Ramtown', 'Ramtown', '', 40.1209500, -74.1437500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140777, 'Raritan', 'Raritan', 'Raritan,Rariton,la li tan,Раритан,拉里坦', 40.5695500, -74.6329400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140778, 'Red Bank', 'Red Bank', 'Red Bank,Redbank,Rehd Bank,rd bnk  nywjrsy,Ред Банк,Рэд Банк,رد بنک، نیوجرسی', 40.3470500, -74.0643100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140779, 'Ridgefield', 'Ridgefield', 'English Neighbourhood,Ridgefield,Ridzfild,Ridzhfild,ryjfyld  nywjrsy,Риджфилд,Риџфилд,ریجفیلد، نیوجرسی', 40.8342700, -74.0087500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140780, 'Ridgefield Park', 'Ridgefield Park', 'Ridzfild Park,Ridzhfild Park,ryjfyld park  nywjrsy,Риджфилд Парк,Риџфилд Парк,ریجفیلد پارک، نیوجرسی', 40.8570400, -74.0215300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140781, 'Ridgewood', 'Ridgewood', 'Ridzhvud,Ridzvud,ryjwwd  nywjrsy,Риджвуд,Риџвуд,ریجوود، نیوجرسی', 40.9792600, -74.1165300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140782, 'Ringwood', 'Ringwood', 'Ringvud,Ringwood,Ringwood Manor,ryngwwd  nywjrsy,Рингвуд,رینگوود، نیوجرسی', 41.1134300, -74.2454300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140783, 'River Edge', 'River Edge', 'Riveh Ehdzh,River Edge,River Edz,Riveredge,Riveredzh,Riverehdzh,Riverside,rywr aj  nywjrsy,Ривер Еџ,Риверэдж,Ривэ Эдж,Рівередж,ریور اج، نیوجرسی', 40.9287100, -74.0398600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140784, 'River Vale', 'River Vale', '', 40.9953800, -74.0120800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140785, 'Riverdale', 'Riverdale', 'Pompton,Rivehdehjl,Riverdale,Riverdejl,rywrdyl  nywjrsy,Ривердејл,Ривэдэйл,ریوردیل، نیوجرسی', 40.9939900, -74.3034800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140786, 'Riverton', 'Riverton', '', 40.0084500, -74.9968400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140787, 'Riverton', 'Riverton', 'Rivehton,Riverton,rywrtwn  nywjrsy,Ривертон,Ривэтон,ریورتون، نیوجرسی,ریورٹن، نیو جرسی', 40.0115000, -75.0148900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140788, 'Robbinsville', 'Robbinsville', 'Hungry Hill,Newtown,Poverty Hill,Robbinsville', 40.2145500, -74.6193200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140789, 'Robertsville', 'Robertsville', '', 40.3462200, -74.2879200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140790, 'Rochelle Park', 'Rochelle Park', '', 40.9073200, -74.0751400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140791, 'Rockaway', 'Rockaway', 'Rokavehj,Rokavej,rakawy  nywjrsy,Рокавеј,Рокавэй,راکاوی، نیوجرسی', 40.9012100, -74.5143200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140792, 'Roebling', 'Roebling', '', 40.1159400, -74.7862700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140793, 'Roseland', 'Roseland', 'Rouslehnd,Rouzland,rwzlnd  nywjrsy,Роузланд,Роуслэнд,روزلند، نیوجرسی', 40.8206600, -74.2937600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140794, 'Roselle', 'Roselle', 'Rosehll,Rozel,rasl  nywjrsy,Розел,Росэлл,راسل، نیوجرسی', 40.6522300, -74.2588200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140795, 'Roselle Park', 'Roselle Park', 'Rosehll Park,Rozel Park,rwzl park  nywjrsy,rwzyl park  nyw jrsy,Розел Парк,Росэлл Парк,روزل پارک، نیوجرسی,روزیل پارک، نیو جرسی', 40.6645500, -74.2643100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140796, 'Rossmoor', 'Rossmoor', '', 40.3365000, -74.4734900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140797, 'Rumson', 'Rumson', 'Oceanic,Ramson,Rumson,ramswn  nywjrsy,Рамсон,رامسون، نیوجرسی', 40.3720500, -73.9990300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140798, 'Rutherford', 'Rutherford', 'Boiling Springs,Raderford,Razehford,Rutherford,radrfwrd  nywjrsy,Радерфорд,Разэфорд,رادرفورد، نیوجرسی', 40.8264900, -74.1068100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140799, 'Saddle River', 'Saddle River', 'Saddl Riveh,Sadl River,Sehddl-River,sydl rywr  nywjrsy,Саддл Ривэ,Садл Ривер,Сэддл-Ривер,سیدل ریور، نیوجرسی,سیڈل ریوڑ، نیو جرسی', 41.0317600, -74.1020900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140800, 'Saddle Brook', 'Saddle Brook', 'Saddle Brook,Saddle River', 40.8989900, -74.0926400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140801, 'Sayreville', 'Sayreville', 'Roundabout,Sayreville,Sehjrvill,Sejrvil,Wood''s Landing,syrwyl  nywjrsy,Сејрвил,Сэйрвилл,سیرویل، نیوجرسی', 40.4592700, -74.3609800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140802, 'Sayreville Junction', 'Sayreville Junction', '', 40.4653800, -74.3304300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140803, 'Scotch Plains', 'Scotch Plains', 'Scotch Plains,Scotchplains,Scotsplain,Wahackick', 40.6553800, -74.3898700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140804, 'Sea Bright', 'Sea Bright', 'New Porland,New Portland,Sea Bright,Seabright,Si Brajt,sy brayt  nywjrsy,Си Брайт,Си Брајт,سی برایت، نیوجرسی', 40.3615000, -73.9740300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140805, 'Sea Girt', 'Sea Girt', 'Sea Girt,Seagirt,Si Girt,sy grt  nywjrsy,Си Гирт,سی گرت، نیوجرسی', 40.1320600, -74.0345800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140806, 'Secaucus', 'Secaucus', 'Secaucus,Sehkaukas,Sikokus,sykwks  nywjrsy,Сикокус,Сэкаукас,سیکوکس، نیوجرسی', 40.7895500, -74.0565300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140807, 'Sewaren', 'Sewaren', 'Sewaren,Sewarren', 40.5520500, -74.2587600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140808, 'Shark River Hills', 'Shark River Hills', '', 40.1940000, -74.0487500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140809, 'Short Hills', 'Short Hills', '', 40.7478800, -74.3254300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140810, 'Shrewsbury', 'Shrewsbury', '', 40.1826100, -74.5293200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140811, 'Shrewsbury', 'Shrewsbury', 'Shrjusbjuri,Shrouzberi,Shrusberi,shrwsbwry  nywjrsy,Шроузбери,Шрусбери,Шрюсбюри,شروسبوری، نیوجرسی', 40.3295500, -74.0615300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140812, 'Singac', 'Singac', '', 40.8867700, -74.2409800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140813, 'Sixmile Run', 'Sixmile Run', 'Six Mile Run Village,Sixmile Run', 40.4576100, -74.5115400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140814, 'Society Hill', 'Society Hill', '', 40.5339900, -74.4579300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140815, 'Somerset', 'Somerset', 'Samerset,Somerseht,Somerset,Самерсет,Сомерсет,Сомерсэт', 40.4976000, -74.4884900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140816, 'Somerville', 'Somerville', 'Raritan,Samervil,Somersvill,Somerville,sang mo wei er,swmrwyl  nywjrsy,Самервил,Сомерсвилл,سومرویل، نیوجرسی,桑莫維爾', 40.5742700, -74.6098800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140817, 'South Amboy', 'South Amboy', 'Saut Emboj,Sous Ehmboj,ambwy jnwby  nywjrsy,sausuanboi,Саут Ембој,Соус Эмбой,آمبوی جنوبی، نیوجرسی,サウスアンボイ', 40.4778800, -74.2907000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140818, 'South Belmar', 'South Belmar', '', 40.1709500, -74.0273600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140819, 'South Bound Brook', 'South Bound Brook', 'Bloomington,Saut Baund Bruk,Saut-Baund-Bruk,Sous Baund Bruk,South Bound Brook,South Boundbrook,bawnd brwk jnwby  nywjrsy,Саут Баунд Брук,Саут-Баунд-Брук,Соус Баунд Брук,باوند بروک جنوبی، نیوجرسی', 40.5534400, -74.5315400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140820, 'South Old Bridge', 'South Old Bridge', '', 40.4081600, -74.3543200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140821, 'South Orange', 'South Orange', 'Orange Dale,South Orange', 40.7489900, -74.2612600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140822, 'South Plainfield', 'South Plainfield', 'New Brooklyn,Samptown,Saut Plejnfild,Sous Plehjnfild,South Plainfield,plynfyld jnwby  nywjrsy,Саут Плејнфилд,Соус Плэйнфилд,پلینفیلد جنوبی، نیوجرسی', 40.5792700, -74.4115400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140823, 'South River', 'South River', 'Saut River,Saut-River,Saut-Ryver,Sous Riveh,South River,Washington,rywr jnwby  nywjrsy,Саут Ривер,Саут-Ривер,Саўт-Рывер,Соус Ривэ,ریور جنوبی، نیوجرسی', 40.4464900, -74.3859800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140824, 'Spotswood', 'Spotswood', 'Spotsvud,aspatswwd  nywjrsy,Спотсвуд,اسپاتسوود، نیوجرسی', 40.3917700, -74.3984800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140825, 'Spring Lake', 'Spring Lake', 'Spring Lake,Spring Lake Beach,Spring Lehjk,Spring Lejk,Springlake Beach,aspryng lyk  nywjrsy,Спринг Лејк,Спринг Лэйк,اسپرینگ لیک، نیوجرسی', 40.1534500, -74.0281900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140826, 'Spring Lake Heights', 'Spring Lake Heights', 'Spring Lehjk Khehjts,Spring Lejk Khajts,aspryng lyk hayts  nywjrsy,Спринг Лејк Хајтс,Спринг Лэйк Хэйтс,اسپرینگ لیک هایتس، نیوجرسی', 40.1503900, -74.0309700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140827, 'Springfield', 'Springfield', 'Springfild,Спрингфилд', 40.7049100, -74.3172300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140828, 'Stanhope', 'Stanhope', 'Stankhop,Stankhoup,astanhwp  nywjrsy,Станхоп,Станхоуп,استانهوپ، نیوجرسی', 40.9028800, -74.7090500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140829, 'Strathmore', 'Strathmore', '', 40.3959400, -74.2134800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140830, 'Succasunna', 'Succasunna', 'Succasunna,Suckasinny,Suckasunny', 40.8684300, -74.6404400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140831, 'Summit', 'Summit', 'Samit,Sammit,samyt  nywjrsy,seomis,Самит,Саммит,سامیت، نیوجرسی,서밋', 40.7156200, -74.3646800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140832, 'Sussex', 'Sussex', 'Decker Town,Deckertown,Saseks,Sassehks,Sussex,sasks  nywjrsy,Сасекс,Сассэкс,ساسکس، نیوجرسی', 41.2098200, -74.6076600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140833, 'Teaneck', 'Teaneck', '', 40.8976000, -74.0159700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140834, 'Ten Mile Run', 'Ten Mile Run', '', 40.4130100, -74.6022300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140835, 'Tenafly', 'Tenafly', 'Tenaflaj,Tenafly,Tienevlie,Tienevly,teneopeullai,tnafly  nywjrsy,Тенафлай,Тенафлај,تنافلی، نیوجرسی,테너플라이', 40.9253800, -73.9629200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140836, 'Tinton Falls', 'Tinton Falls', 'New Shrewsbury,Tintern Falls,Tinton,Tinton Falls,Tinton Fals,Tinton Fols,Tintonfalls,tyntwn falz  nywjrsy,Тинтон Фалс,Тинтон Фолс,تینتون فالز، نیوجرسی', 40.3042800, -74.1004200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140837, 'Totowa', 'Totowa', 'Totawa,Totova,Totowa,twtwwa  nywjrsy,Тотова,توتووا، نیوجرسی', 40.9051000, -74.2098700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140838, 'Trenton', 'Trenton', 'Chambersburg,Gorad Trehntan,Lamberton,Mill Hill,Santhickan,TTN,The Falls,Trehnton,Trent Town,Trent''s Town,Trenton,Trentona,Trentonas,Trentonia,Trents Town,Trentun,itrentan,te lun dun,teulenteon,torenton,trentana,trntwn,Τρέντον,Горад Трэнтан,Трентон,Трентън,Трэнтон,Թրենթոն,טרנטון,ترنتون,ٹرنٹن، نیو جرسی,ٹرینٹن,ट्रेंटन,ट्रेन्टन,त्रेन्तन,இட்ரென்டன்,トレントン,特伦顿,트렌턴', 40.2170500, -74.7429400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140839, 'Twin Rivers', 'Twin Rivers', '', 40.2640000, -74.4912600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140840, 'Union', 'Union', 'Connecticut Farms,Union', 40.6976000, -74.2632000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140841, 'Union Beach', 'Union Beach', 'Junion Bich,anywn bych  nywjrsy,Јунион Бич,Юнион Бич,انیون بیچ، نیوجرسی', 40.4465000, -74.1782000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140842, 'Union City', 'Union City', 'ECC,East Cost Cities,Junion Siti,Junion-Siti,Union City,awnywn syty  nywjrsy,you lian shi,yunieonsiti,yunionshiti,ywnywn syty,Јунион Сити,Юнион Сити,Юнион-Сити,Юніон-Сіті,יוניון סיטי,اونیون سیتی، نیوجرسی,يونيون سيتي,یونین شہر، نیو جرسی,ユニオンシティ,友聯市,유니언시티', 40.7795500, -74.0237500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140843, 'Upper Montclair', 'Upper Montclair', 'Upper Mont Clair,Upper Montclair', 40.8462100, -74.2012600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140844, 'Upper Saddle River', 'Upper Saddle River', 'Aper Sadl River,Appeh Saddl Riveh,apr sydl rywr  nywjrsy,Апер Садл Ривер,Аппэ Саддл Ривэ,آپر سیدل ریور، نیوجرسی', 41.0584300, -74.0984800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140845, 'Verona', 'Verona', 'Buttertown,Vernon,Verona', 40.8298200, -74.2401500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140846, 'Victory Gardens', 'Victory Gardens', 'Viktori Gadehns,Viktori Gardens,wyktwry gardnz  nywjrsy,Виктори Гадэнс,Виктори Гарденс,وکٹری گارڈنز، نیو جرسی,ویکتوری گاردنز، نیوجرسی', 40.8759300, -74.5423800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140847, 'Vista Center', 'Vista Center', '', 40.1592800, -74.3179200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140848, 'Voorhees', 'Voorhees', 'Municipio de Voorhees,Voorhees Township,Vurkhis,Vurkhis Taunship,wwrhyz  nywjrsy,Вурхис,Вурхис Тауншип,وورهیز، نیوجرسی', 40.4812200, -74.4832100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140849, 'Vernon Valley', 'Vernon Valley', 'Vernon', 41.2367600, -74.4871000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140850, 'Waldwick', 'Waldwick', 'New Prospect,Voldvik,Waldwick,waldwyk  nywjrsy,Волдвик,والدویک، نیوجرسی', 41.0106500, -74.1179200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140851, 'Wallington', 'Wallington', 'Vallington,Volington,walyngtwn  nywjrsy,Валлингтон,Волингтон,والینگتون، نیوجرسی,ویلنگٹں، نیو جرسی', 40.8531600, -74.1137500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140852, 'Wanaque', 'Wanaque', 'Vanakju,Vonakju,Wanaque,Whinokie,wanak  nywjrsy,Ванакю,Вонакју,واناک، نیوجرسی', 41.0381500, -74.2940400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140853, 'Wanamassa', 'Wanamassa', '', 40.2317800, -74.0254200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140854, 'Washington', 'Washington', 'Mansfield Woodhouse,Vashington,Washington,washyngtn  nywjrsy,Вашингтон,واشنگٹن، نیو جرسی,واشینگتن، نیوجرسی', 40.7584300, -74.9793400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140855, 'Watchung', 'Watchung', 'Vatchung,Vochang,watchwng  nywjrsy,Ватчунг,Вочанг,واتچونگ، نیوجرسی', 40.6378800, -74.4509900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140856, 'Wayne', 'Wayne', '', 40.9253800, -74.2765400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140857, 'Weehawken', 'Weehawken', 'Vikhoken,Weahawk,Weehawken,Wiehachen,wyhawkn  nyw jrsy,wyhawkn  nywjrsy,Вихокен,ویهاوکن، نیو جرسی,ویهاوکن، نیوجرسی', 40.7695500, -74.0204200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140858, 'West Belmar', 'West Belmar', '', 40.1692800, -74.0354200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140859, 'West Caldwell', 'West Caldwell', 'West Caldwell,Westville', 40.8409300, -74.3018200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140860, 'West Freehold', 'West Freehold', '', 40.2420600, -74.3012600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140861, 'West Long Branch', 'West Long Branch', 'Vehst Long Branch,Vest Long Branch,West Long Branch,West Longbranch,Вест Лонг Бранч,Вэст Лонг Бранч', 40.2903900, -74.0176400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140862, 'West Milford', 'West Milford', '', 41.1312100, -74.3673700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140863, 'West New York', 'West New York', 'Vehst N''ju Jork,Vest NJujork,mghrby nyw yark  nyw jrsy,nyw ywrk ghrby  nywjrsy,weseuteunyuyog,Вест Њујорк,Вэст Нью Йорк,مغربی نیو یارک، نیو جرسی,نیو یورک غربی، نیوجرسی,웨스트뉴욕', 40.7878800, -74.0143100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140864, 'West Orange', 'West Orange', 'Freemantown,McLellan,West Orange,Williamstown', 40.7987100, -74.2390400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140865, 'Woodland Park', 'Woodland Park', 'West Paterson,Woodland Park', 40.8898200, -74.1948700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140866, 'Westfield', 'Westfield', 'Uehstfild,Vehstfild,Vestfild,weseuteupildeu,wstfyld  nywjrsy,Вестфилд,Вэстфилд,Уэстфилд,وستفیلد، نیوجرسی,ویسٹ فیلڈ، نیو جرسی,웨스트필드', 40.6589900, -74.3473700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140867, 'Weston', 'Weston', '', 40.5351000, -74.5907100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140868, 'Westville', 'Westville', '', 40.8445400, -74.2995900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140869, 'Westwood', 'Westwood', 'Vehstvud,Vestvud,wstwwd  nywjrsy,Вествуд,Вэствуд,وستوود، نیوجرسی,ویسٹووڈ، نیو جرسی', 40.9912100, -74.0326400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140870, 'Wharton', 'Wharton', 'Port Oram,Varton,Vorton,Wharton,wartn  nywjrsy,Вартон,Вортон,وارتن، نیوجرسی', 40.8931500, -74.5818300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140871, 'White Horse', 'White Horse', '', 40.1906700, -74.7023800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140872, 'White Meadow Lake', 'White Meadow Lake', '', 40.9237100, -74.5107100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140873, 'Whitehouse Station', 'Whitehouse Station', 'White House Station', 40.6153800, -74.7704400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140874, 'Willingboro', 'Willingboro', 'Levittown,Willingboro', 40.0278900, -74.8690500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140875, 'Winfield', 'Winfield', '', 40.6426000, -74.2854300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140876, 'Wood-Ridge', 'Wood-Ridge', 'Vud-Ridz,Vud-Ridzh,Wood Ridge,Wood-Ridge,Woodridge,wwd-ryj  nywjrsy,Вуд-Ридж,Вуд-Риџ,وود-ریج، نیوجرسی', 40.8456600, -74.0879200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140877, 'Woodbridge', 'Woodbridge', 'Woodbridg,Woodbridge,Woodbrige', 40.5576000, -74.2845900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140878, 'Woodcliff Lake', 'Woodcliff Lake', 'Pascack,Vudklif Lehjk,Vudklif Lejk,Woodcliff,Woodcliff Lake,vutklip lek,wwdklyf lyk  nywjrsy,Вудклиф Лејк,Вудклиф Лэйк,وودکلیف لیک، نیوجرسی,வுட்க்ளிப் லேக்', 41.0234300, -74.0665300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140879, 'Wyckoff', 'Wyckoff', 'Wikoff,Wyckoff', 41.0095400, -74.1729200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140880, 'Yorketown', 'Yorketown', '', 40.3078900, -74.3376500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140881, 'Adams', 'Adams', 'Adams,Smiths Mills', 43.8092300, -76.0240900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140882, 'Adams Center', 'Adams Center', 'Adams Center,Adams Centre,Adams Five Corners', 43.8600600, -76.0054800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140883, 'Addison', 'Addison', '', 42.1028500, -77.2335900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140884, 'Airmont', 'Airmont', '', 41.1009300, -74.1162500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140885, 'Akron', 'Akron', 'Akron,akran  nywywrk,akrwn,akrwn  nyw yark,Акрон,أكرون,اکران، نیویورک,اکرون، نیو یارک', 43.0208900, -78.4953000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140886, 'Albany', 'Albany', 'ALB,Albania,Albanija,Albany,Albany i New York,Albany on Niwum Eoforwice,Albany on Nīwum Eoforwīce,Aurania,Beverswyck,Beverwick,Beverwyck,Ches-co-don-ta,Fort Orange,Fuyck,Ga-isch-ti-nic,Gaasch-tinick,Gaishtinic,Gorad Olbani,Kaishtinic,New Orange,Olbani,Olbanis,Olmpani,Pem-pot-a-wut-hut,Pempotuwuthut,Rensselaerwyck,Scheneghtada,Shaw-na-taw-ty,Ska-neh-ta-de,Skaghnetade,Skaneghtada,Skenectadea,William Stadt,Williamstadt,albani,albany,albany  nyw yark,albany  nywywrk,albny,alpeni,ao er ba ni,elbani,ke ba li,olbeoni,orubani,xxlbani,Όλμπανι,Албания,Горад Олбані,Олбани,Олбані,Օլբանի,אולבני,אלבאני,آلبانی، نیویورک,ألباني,ئالبانی، نیویۆرک,البانی، نیو یارک,البنی,अल्बानी,आल्बनी,एल्बानी,ஆல்பெனி,ออลบานี,ალბანი,オールバニ,奥尔巴尼,柯巴利,올버니', 42.6525800, -73.7562300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140887, 'Albertson', 'Albertson', '', 40.7734300, -73.6431800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140888, 'Albion', 'Albion', 'Albion,De-o-wun-dake-no,Freeport,Newport', 43.2464500, -78.1936300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140889, 'Alabama', 'Alabama', 'Alabama,Alabama Center,Ga-swa-dak,Алабама', 43.0964500, -78.3908600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140890, 'Alden', 'Alden', '', 42.9000600, -78.4919700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140891, 'Alexandria Bay', 'Alexandria Bay', 'AXB,Aleksandrija Bej,alksandrya,alksandrya bay  nywywrk,Александрија Беј,ألكساندريا,الکساندریا بای، نیویورک,الیگزینڈریا بے، نیو یارک', 44.3358800, -75.9177300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140892, 'Alfred', 'Alfred', 'Alfred,Alfred Center,Alfred Centre', 42.2542400, -77.7905500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140893, 'Allegany', 'Allegany', 'Alegeni,Allegany,Burton,Алегени,ئەلیگانی', 42.0900600, -78.4941900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140894, 'Altamont', 'Altamont', 'Altamont,Knowersville,Knowerville', 42.7006300, -74.0337400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140895, 'Amagansett', 'Amagansett', 'Amagansett,Amogonsett,amaganst  nyw ywrk,اماگانست، نیو یورک', 40.9737100, -72.1436900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140896, 'Amherst', 'Amherst', 'Amherst,Amkherst,amhrst  nywywrk,amuhasuto,Амхерст,امهرست، نیویورک,アムハースト', 42.9783900, -78.7997600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140897, 'Amityville', 'Amityville', 'Amitivil,Amityville,Sweet Hollow,West Neck South,amytyfyl,Амитивил,أميتيفيل,امیتی‌ویل، نیویورک', 40.6789900, -73.4170700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140898, 'Amsterdam', 'Amsterdam', 'Amsterdam,Amsterdam (New York  USA),Vedder''s Mills,Veddersburg,Veedersburgh,a mu si te dan,aemseuteodaem,amstrdam,amstrdam  nywywrk,amusuterudamu,Амстердам,אמסטערדאם,آمستردام، نیویورک,أمستردام,ایمسٹرڈیم، نیو یارک,ایمسٹرڈیم،نیویارک,アムステルダム,阿姆斯特丹,앰스터댐', 42.9386900, -74.1881900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140899, 'Andover', 'Andover', 'Andover,Bakertown', 42.1564600, -77.7955500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140900, 'Angola on the Lake', 'Angola on the Lake', '', 42.6547800, -79.0489300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140901, 'Angola', 'Angola', 'Angola,Dyo-a-his-tah,Dyoahista,Evans Station', 42.6383900, -79.0278200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140902, 'Apalachin', 'Apalachin', '', 42.0695200, -76.1546500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140903, 'Aquebogue', 'Aquebogue', '', 40.9445400, -72.6270400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140904, 'Arcade', 'Arcade', 'Arcade,China', 42.5339500, -78.4230700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140905, 'Ardsley', 'Ardsley', 'Ardsley,Ashford', 41.0106500, -73.8437500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140906, 'Arlington', 'Arlington', 'Arlington,Арлингтон', 41.6959300, -73.8968000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140907, 'Armonk', 'Armonk', 'Armank,Armonk,Mile Square,Mill Square,Sands Mill,a meng ke shi,amongkeu,amonku,armwnk  nywywrk,Арманк,آرمونک، نیویورک,アーモンク,阿蒙克市,아몽크', 41.1264800, -73.7140200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140908, 'Arrochar', 'Arrochar', '', 40.5984400, -74.0726400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140909, 'Arverne', 'Arverne', '', 40.5912200, -73.7959700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140910, 'Astoria', 'Astoria', 'Astoria,Astorija,Hallett''s Cove,aeseutolia,astwrya,Αστόρια,Астория,آستوریا,অ্যাস্টোরিয়া,애스토리아', 40.7720500, -73.9301400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140911, 'Athens', 'Athens', 'Athens,Canisikek,Esperanza,Looneberg,Loonenburg,Loonenburgh,Lunenburg', 42.2603600, -73.8095700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140912, 'Atlantic Beach', 'Atlantic Beach', 'Atlantic Beach,Long Beach,Long Beach West', 40.5889900, -73.7290200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140913, 'Attica', 'Attica', 'Attica,Gwehtaanetecarnundodeh,Phelps Settlement', 42.8642300, -78.2802900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140914, 'Auburn', 'Auburn', 'Auburn,Hardenbergh''s Corners,Obern,Oburn,Os-co,Was-co,abrn,abrn  nyw yark,abwrn  nywywrk,ao ben,awbwrn,oban,obeon,Аубурн,Оберн,Обърн,آبرن,آبرن، نیو یارک,آبورن، نیویورک,أوبورن,オーバーン,奧本,오번', 42.9317300, -76.5660500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140915, 'Augusta', 'Augusta', 'Ogasta,Огаста', 42.9747900, -75.5012900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140916, 'Averill Park', 'Averill Park', 'Averill,Averill Park,Averillpark', 42.6339700, -73.5537300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140917, 'Avon', 'Avon', '', 42.9120100, -77.7455600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140918, 'Babylon', 'Babylon', 'Babilon,Babylon,New Babylon,South Huntington,Бабилон', 40.6956600, -73.3256800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140919, 'Bainbridge', 'Bainbridge', 'Bainbridge,Jericho', 42.2934100, -75.4793500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140920, 'Baiting Hollow', 'Baiting Hollow', 'Baiting Hollow,Fresh Pond', 40.9562100, -72.7442700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140921, 'Baldwin', 'Baldwin', 'Baldwin,Baldwins,Baldwinville,Bethel,Bolduin,Fox Borough,Hick''s Neck,Milburn Corners,baldwyn,Болдуин,بالدوين,بالڈون، ناساؤ کاؤنٹی، نیو یارک', 40.6564900, -73.6093000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140922, 'Baldwin Harbor', 'Baldwin Harbor', '', 40.6395500, -73.6084600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140923, 'Baldwinsville', 'Baldwinsville', 'Baldwin''s Bridge,Baldwinsville,Boldvinsvil,Columbia,Ste-ha-hah,bladwynsfyl,Болдвинсвил,بلادوينسفيل', 43.1586800, -76.3327100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140924, 'Ballston Spa', 'Ballston Spa', 'Ballston,Ballston Spa,Ballston Springs,Balltown Springs,Bolston Spa,balstwn,Болстон Спа,بالستون', 43.0009100, -73.8490100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140925, 'Balmville', 'Balmville', 'Balmville,Hampton', 41.5348200, -74.0148600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140926, 'Bardonia', 'Bardonia', '', 41.1095400, -73.9962500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140927, 'Barnum Island', 'Barnum Island', '', 40.6045500, -73.6440200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140928, 'Batavia', 'Batavia', 'Batavia,Batavija,Batejvija,Botovijoo,De-o-on-go-wa,Ge-ne-un-dah-sa-is-ka,Jo-a-i-ka,The Bend,batabia,batafya,batawya  nywywrk,Батавия,Батејвија,Ботовиёо,باتافيا,باتاویا، نیویورک,バタビア', 42.9981200, -78.1875200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140929, 'Bath', 'Bath', 'Bat,Bath,Donatagwenda,Ta-nigh-na-quan-da,Tanighnaguanda,qryw bath,Бат,باتھ,قريو باث', 42.3370200, -77.3177600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140930, 'Bath Beach', 'Bath Beach', '', 40.6045500, -74.0043100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140931, 'Bay Park', 'Bay Park', '', 40.6331600, -73.6704100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140932, 'Bay Shore', 'Bay Shore', 'Bay Shore,Bayshore,Bej Shor,Keith,Mechanicville,Penataquit,bay shwry,Бей Шор,Беј Шор,باي شوري', 40.7251000, -73.2453900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140933, 'Baxter Estates', 'Baxter Estates', '', 40.8348200, -73.6954100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140934, 'Bay Wood', 'Bay Wood', 'Baywood', 40.7501000, -73.2912300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140935, 'Baychester', 'Baychester', 'Bay Chester,Baychester', 40.8692800, -73.8364500, 'US', '2017-04-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140936, 'Bayport', 'Bayport', 'Bayport,Middle Road,Midroadville', 40.7384300, -73.0506700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140937, 'Bayside', 'Bayside', 'Bay Side,Bayside,بے سائڈ، کوئینز', 40.7684400, -73.7770800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140938, 'Bayville', 'Bayville', 'Bayville,Oak Neck,Pine Island', 40.9106500, -73.5620700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140939, 'Beacon', 'Beacon', 'Beacon,Biakun,Bikon,Fishkill,Mattewan,bikon,bykwn,bykwn  nywywrk,Биакун,Бикон,بيكون,بیکون، نیویورک,ビーコン', 41.5048200, -73.9695800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140940, 'Bedford', 'Bedford', 'Bedford,bdfwrd,Бедфорд,بدفورد', 41.2042600, -73.6437400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140941, 'Bedford Hills', 'Bedford Hills', 'Bedford Hills,Bedford Station', 41.2367600, -73.6945800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140942, 'Bellaire', 'Bellaire', '', 40.7139900, -73.7540200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140943, 'Belle Harbor', 'Belle Harbor', '', 40.5759400, -73.8481900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140944, 'Bellerose', 'Bellerose', '', 40.7242700, -73.7151300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140945, 'Bellerose Terrace', 'Bellerose Terrace', 'Bellerose Gardens West,Bellerose Terrace', 40.7206600, -73.7259600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140946, 'Bellmore', 'Bellmore', 'Bellmore,New Bridge', 40.6687100, -73.5270700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140947, 'Bellport', 'Bellport', 'Bellport,Oc-com-bo-mock', 40.7570400, -72.9392700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140948, 'Belmont', 'Belmont', 'Belmont,Philipsburgh,Philipsville,Phillipsburg,blmwnt,Белмонт,بلمونت', 42.2231200, -78.0344500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140949, 'Bensonhurst', 'Bensonhurst', 'Bensonhurst,Bensonhurst-By-The-Sea,Bensonkherst,Bensonkhjorst,Бенсонхерст,Бенсонхёрст', 40.6017700, -73.9940300, 'US', '2010-03-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140950, 'Bergen', 'Bergen', 'Bergen,Bergen Corners', 43.0853400, -77.9422300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140951, 'Bergen Beach', 'Bergen Beach', '', 40.6203800, -73.9068000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140952, 'Bethpage', 'Bethpage', 'BPA,Bethpage,Betpejdz,Central Park,beseupeiji,Бетпејџ,베스페이지', 40.7442700, -73.4820700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140953, 'Big Flats', 'Big Flats', 'Big Flats,Bigflats', 42.1373000, -76.9369100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140954, 'Billington Heights', 'Billington Heights', '', 42.7842300, -78.6264200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140955, 'Binghamton', 'Binghamton', 'BGM,Bingamton,Bingamtonas,Bingemton,Binghamton,Binghamton i New York,Bingkhamtun,Bingnamton,Chenango Point,bin han dun,bing-eomteon,bingamuton,bynghamtwn,bynghmtwn,bynghmtwn  nywywrk,Бингамтон,Бингемтон,Бингхамтън,Бингњамтон,Бінгемтон,בינגהמטון,بينغامتون,بینگهمتون، نیویورک,بینگہمٹن، نیو یارک,ビンガムトン,賓漢頓,賓罕頓,빙엄턴', 42.0986900, -75.9179700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140956, 'Black River', 'Black River', 'Black River,Lockport', 44.0125600, -75.7943700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140957, 'Blasdell', 'Blasdell', 'Blaisdell,Blasdell', 42.7972800, -78.8233700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140958, 'Blauvelt', 'Blauvelt', 'Blauvelt,Blauveltville,Greenbush', 41.0634300, -73.9576400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140959, 'Bloomfield', 'Bloomfield', '', 40.6126000, -74.1782000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140960, 'Blue Point', 'Blue Point', 'Blue Point,Bluepoint', 40.7439900, -73.0345500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140961, 'Bohemia', 'Bohemia', '', 40.7692600, -73.1151100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140962, 'Bolivar', 'Bolivar', '', 42.0667300, -78.1677900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140963, 'Bolivar', 'Bolivar', '', 43.0711800, -75.8888000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140964, 'Boonville', 'Boonville', 'Boon''s Upper Settlement,Boonville,Kortenaer', 43.4836800, -75.3365600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140965, 'Borough Park', 'Borough Park', 'Blythebourne,Boro-Park,Borough Park,Боро-Парк,בארא פארק,בורו פארק', 40.6339900, -73.9968100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140966, 'Boston', 'Boston', 'Boston,Бостон', 42.6289500, -78.7375300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140967, 'Brentwood', 'Brentwood', 'Brentud,Brentvud,Brentwood,Modern Times,bryntwwd,Брентвуд,Брентуд,برينتوود,برینٹووڈ، نیو یارک', 40.7812100, -73.2462300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140968, 'Brewerton', 'Brewerton', 'Brewerton,Ga-do-quat,Ohsahaunytah-Seughkah,Te-was-koo-we-goo-na', 43.2381200, -76.1407600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140969, 'Brewster', 'Brewster', 'Brewster,Brewster''s Station,Brewsters Station,Brjuster,Bruster,brwstr,Брустер,Брюстер,بروستر', 41.3973200, -73.6170700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140970, 'Brewster Hill', 'Brewster Hill', '', 41.4239800, -73.6042900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140971, 'Briarcliff Manor', 'Briarcliff Manor', 'Brajarklif Mejnor,Brajrkliff-Mehnor,Briarcliff Farm,Briarcliff Manor,buraiakurifumana,Брайрклифф-Мэнор,Брајарклиф Мејнор,ブライアクリフマナー', 41.1456500, -73.8237500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140972, 'Bridgehampton', 'Bridgehampton', 'Bridgehampton,Bridzkhapton,Bull''s Head,Bullhead,Бриџхаптон', 40.9378800, -72.3009200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140973, 'Bridgeport', 'Bridgeport', '', 43.1553500, -75.9693600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140974, 'Bridgeport', 'Bridgeport', '', 42.9159000, -76.7524500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140975, 'Brighton', 'Brighton', 'Brajton,Брайтон,برائٹن، مونرو کاؤنٹی، نیو یارک', 43.1475600, -77.5505500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140976, 'Brighton Beach', 'Brighton Beach', 'Brighton Beach,Duck Hill', 40.5778800, -73.9595800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140977, 'Brightwaters', 'Brightwaters', '', 40.7209300, -73.2673400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140978, 'Brinckerhoff', 'Brinckerhoff', 'Brinckerhoff,Brinckerhoff Station,Brinckerhoffville', 41.5439800, -73.8681900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140979, 'Broad Channel', 'Broad Channel', '', 40.6031600, -73.8204100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140980, 'Broadalbin', 'Broadalbin', 'Broadalbin,Fonda''s Bush,Kennyetto,Rawsonville', 43.0586800, -74.1965200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140981, 'Brockport', 'Brockport', 'Brockport,Brokport,Gwehtaanetecarnundoteh,brwkbwrt,Брокпорт,بروكبورت', 43.2136700, -77.9391800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140982, 'Brocton', 'Brocton', 'Brocton,Salem,Salem Cross Roads,Salem-on-Erie', 42.3886700, -79.4411600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140983, 'The Bronx', 'The Bronx', 'Borough of Bronx,Bronks,Bronx,The Bronx,Бронкс', 40.8498500, -73.8664100, 'US', '2014-05-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140984, 'Bronxville', 'Bronxville', 'Bronksvil,Bronxville,Underhill''s Crossing,brwnksfyl,bu long ke wei,Бронксвил,برونكسفيل,布隆克維', 40.9381500, -73.8320800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140985, 'Brookhaven', 'Brookhaven', 'Brookhaven,Brukgeven,Brukkhejven,Fire Place,Брукгевен,Брукхейвен,Брукхејвен', 40.7792700, -72.9153800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140986, 'Brooklyn', 'Brooklyn', 'BK,Bklyn,Borough of Brooklyn,Breuckelen,Breukelen,Broklino,Brooklyn,Brucclinu,Bruklin,Bruklina,Bruklinas,Comitatus Bruclinum,Kings County,Marechkawick,beulukeullin,bru klin,brukalina,brwklyn,brwqlyn,bu lu ke lin qu,burukkurin qu,kinsa ka''unti,Бруклин,Бруклін,ברוקלין,بروكلين,بروکلین,ब्रुकलीन,ब्रूकलिन,কিংস কাউন্টি,ব্রুকলিন,บรุกลิน,ბრუკლინი,ブルックリン区,布鲁克林区,브루클린', 40.6501000, -73.9495800, 'US', '2015-01-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140987, 'Brookville', 'Brookville', 'Brookville,Brukvil,Wolver Hollow,Wolverhampton,brwkfyl,Бруквил,بروكفيل', 40.8131600, -73.5673500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140988, 'Brownsville', 'Brownsville', 'Brown''s Village,Brownsville', 40.6609400, -73.9201400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140989, 'Brownville', 'Brownville', '', 44.0070000, -75.9840900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140990, 'Brownville', 'Brownville', '', 41.7998200, -74.3807100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140991, 'Buchanan', 'Buchanan', '', 41.2620400, -73.9381900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140992, 'Buffalo', 'Buffalo', 'BUF,Bafalas,Bafalo,Baffalo,Bufalo,Bufalum,Buffalo,Buffalo i New York,Bupalo,Búfalo,De-o-tro-weh,De-ose-lole,Gorad Bufala,Ne-o-thro-ra,New Amsterdam,Tick-e-ack-gou-ga,Tsistekeriia''kon:ke,Tsistekeriia''kón:ke,bafelo,baffalo,baffaro,baphalo,baphelo,beopeollo,bfylw  nyw yark,bupalo,bwfalw,bwfalw  nywywrk,bwfylw,pahpalo,shui niu cheng,Μπάφαλο,Бафало,Баффало,Буфало,Буффало,Бъфало,Горад Буфала,Բուֆֆալո,באפאלא,באפלו,بفیلو، نیو یارک,بوفالو,بوفالو، نیویورک,بوفیلو,बफ़ेलो,बफेलो,பஃபலோ,బఫెలో,ಬಫಲೋ,บัฟฟาโล,ბუფალო,バッファロー,水牛城,버펄로', 42.8864500, -78.8783700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140993, 'Bushwick', 'Bushwick', 'Boswijck,Bushuik,Bushwick,Bushwyck,bu xi wei ke,bwswwyq,Бушуик,בושוויק,布希維克', 40.6942700, -73.9187500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140994, 'Cairo', 'Cairo', 'Cairo,Shingle Kill', 42.2989700, -73.9984700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140995, 'Calcium', 'Calcium', 'Calcium,Sandfords Corners,Sanford Corners', 44.0217300, -75.8460400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140996, 'Caledonia', 'Caledonia', 'Caledonia,De-o-na-ga-no,Deonegano,Dynneganooh,Dyu-ne-ga-nooh,Kaledonija,Каледония', 42.9731200, -77.8527800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140997, 'Calverton', 'Calverton', 'Baiting Hollow Station,CTO,Calverton,Conungam,Hulse''s Turnout', 40.9064900, -72.7434300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140998, 'Cambria Heights', 'Cambria Heights', '', 40.6945500, -73.7384700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(140999, 'Cambridge', 'Cambridge', 'Cambridge,Dorr''s Corners,Kembridzh,North White Creek,Кембридж', 43.0281300, -73.3812200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141000, 'Camden', 'Camden', 'Camden,Hestayuntwa,Ho-sta-yun-twa', 43.3345100, -75.7479600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141001, 'Canajoharie', 'Canajoharie', 'Canajoharie,Kana''tsiohare,Kana''tsióhare', 42.9056300, -74.5718100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141002, 'Canandaigua', 'Canandaigua', 'Canandaigua,Ga-noon-daa-gwah,Kanandejgva,Konondiagou,kaeneondaigwa,kanandeigua,kanandy gwa  nywywrk,kanandyajw,Канандејгва,Конондиагоу,كاناندياجو,کاناندی گوا، نیویورک,カナンデイグア,캐넌다이과', 42.8742300, -77.2880400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141003, 'Canarsie', 'Canarsie', '', 40.6437200, -73.9006900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141004, 'Canastota', 'Canastota', 'kanastwta,كاناستوتا', 43.0795100, -75.7507400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141005, 'Canisteo', 'Canisteo', '', 42.2703500, -77.6058200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141006, 'Canton', 'Canton', 'Canton,New Cairo', 44.5956200, -75.1690900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141007, 'Carle Place', 'Carle Place', '', 40.7526000, -73.6104100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141008, 'Carmel', 'Carmel', 'Karmel'',kameru,karml,karml  nyw yark,Кармель,كارمل,کارمل، نیو یارک,カーメル', 41.4300900, -73.6801300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141009, 'Carthage', 'Carthage', 'Carthage,Kartidz,Long Falls,karthagh,Картиџ,كارثاغ,کارتھیج، نیو یارک', 43.9781200, -75.6093600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141010, 'Castleton-on-Hudson', 'Castleton-on-Hudson', 'Castleton,Castleton-on-Hudson,Morriches Hastie', 42.5184100, -73.7512300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141011, 'Catskill', 'Catskill', 'Catskill,Catskill Landing,qryt katskyl,قرية كاتسكيل', 42.2173100, -73.8645700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141012, 'Cayuga Heights', 'Cayuga Heights', '', 42.4601000, -76.4877600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141013, 'Cazenovia', 'Cazenovia', 'Kazenovija,kazynwfya,Казеновија,كازينوفيا', 42.9300700, -75.8526900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141014, 'Cedarhurst', 'Cedarhurst', 'Cedarhurst,Ocean Point,Sidarkherst,sydarhwrst,Сидархерст,سيدارهورست', 40.6228800, -73.7243000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141015, 'Celoron', 'Celoron', '', 42.1095000, -79.2831000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141016, 'Center Moriches', 'Center Moriches', 'Center Moriches,Centre Moriches', 40.8003800, -72.7898200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141017, 'Centereach', 'Centereach', 'Centereach,New Village', 40.8584300, -73.0995500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141018, 'Centerport', 'Centerport', '', 43.0409000, -76.5927200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141019, 'Centerport', 'Centerport', 'Centerport,Centreport,Little Cow Harbor', 40.8853800, -73.3762300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141020, 'Central Islip', 'Central Islip', '', 40.7906500, -73.2017800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141021, 'Central Square', 'Central Square', '', 43.2867400, -76.1460400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141022, 'Central Valley', 'Central Valley', '', 41.3317600, -74.1209800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141023, 'Chadwicks', 'Chadwicks', 'Chadwick''s Mills,Chadwicks,Chadwicks Mills', 43.0278500, -75.2715500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141024, 'Champlain', 'Champlain', '', 44.9864300, -73.4465300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141025, 'Chappaqua', 'Chappaqua', 'Chapakva,Чапаква', 41.1595400, -73.7648500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141026, 'Charleston', 'Charleston', 'Androvetteville,Charleston,Charlestown,Kreischerville', 40.5367700, -74.2373700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141027, 'Chatham', 'Chatham', 'Chatham,Chatham Four Corners,Groat''s Corners,Groats Corners', 42.3642500, -73.5948400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141028, 'Cheektowaga', 'Cheektowaga', 'Cheektowaga,Cheektowaga Station,Cheektowaga Village,Jiik-do-waah-geh', 42.9033900, -78.7547500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141029, 'Chelsea', 'Chelsea', 'Chelsea,Peanutville,Prallstown', 40.6006600, -74.1948700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141030, 'Chenango Bridge', 'Chenango Bridge', '', 42.1667400, -75.8624200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141031, 'Chester', 'Chester', 'Chester,Честер', 41.3625900, -74.2712600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141032, 'Chestnut Ridge', 'Chestnut Ridge', '', 41.0842600, -74.0557000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141033, 'Chittenango', 'Chittenango', 'Chitenango,Chittenango,Chudenaang,tshytynanghw,Читенанго,تشيتينانغو', 43.0450700, -75.8665800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141034, 'Churchville', 'Churchville', '', 43.1042300, -77.8844500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141035, 'City Island', 'City Island', '', 40.8473200, -73.7865200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141036, 'Clarence', 'Clarence', 'Clarence,Clarence Hollow,Klerens,Ransomville,ke la lun si zhen,klarns,klyrns  nyw yark,Клеренс,كلارنس,کلیرنس، نیو یارک,克拉伦斯镇', 42.9767300, -78.5919700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141037, 'Clarence Center', 'Clarence Center', 'Clarence,Clarence Center,Clarence Centre,Van Tine''s Corners', 43.0106100, -78.6375300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141038, 'Clark Mills', 'Clark Mills', 'Clark Mills,Clark''s Mills,Clarks Mills', 43.0922900, -75.3796200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141039, 'Clarkson', 'Clarkson', '', 43.2331200, -77.9275100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141040, 'Clayton', 'Clayton', 'Clayton,Cornelia,French Creek', 44.2394900, -76.0857800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141041, 'Clifton', 'Clifton', '', 40.6201000, -74.0770900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141042, 'Clifton Springs', 'Clifton Springs', 'Clifton Springs,Sulphur Springs', 42.9617300, -77.1399800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141043, 'Clinton', 'Clinton', 'Clinton,Kadawisdag,Klinton,Schooltown,klyntwn,Κλίντον,Клинтон,كلينتون,کلنٹن، اونیڈا کاؤنٹی، نیو یارک', 43.0484000, -75.3785000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141044, 'Clintondale', 'Clintondale', 'Clintondale,Quaker Street', 41.6948200, -74.0512500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141045, 'Clymer', 'Clymer', '', 42.0208900, -79.6300500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141046, 'Cobleskill', 'Cobleskill', 'As-ca-le-ge,Cobleskill,Ots-ga-ra-gee', 42.6778500, -74.4854200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141047, 'Cohoes', 'Cohoes', 'Cohoes,Ga-ha-oos,Kokhos,Kounis,kwhs  nywywrk,kwhws,Коуњис,Кохос,كوهوس,کوهس، نیویورک', 42.7742400, -73.7001200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141048, 'Cold Spring', 'Cold Spring', 'Cold Spring,Cold Spring-on-Hudson,Coldspring,Kould Spring,kwld sbryngh,Коулд Спринг,كولد سبرينغ', 41.4200900, -73.9545800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141049, 'Cold Spring Harbor', 'Cold Spring Harbor', 'Cold Spring,Cold Spring Harbor,Kold Spring Kharbor,Nachaquatuck,leng quan gang,Колд Спринг Харбор,コールド・スプリング・ハーバー,冷泉港', 40.8714900, -73.4567900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141050, 'College Point', 'College Point', 'College Point,Collegepoint,Strattonport Point,Strattonsport', 40.7876000, -73.8459700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141051, 'Colonie', 'Colonie', 'Koloni,kwlwny,Колони,كولوني', 42.7178600, -73.8334600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141052, 'Commack', 'Commack', 'Co-Mac,Comac,Comack,Commac,Commack,Comock,Komak,Wanecommack,Winne - Comack,Winnecomac Win-Ne-Co-Mack,Winnie Comac,kwmak,Комак,كوماك', 40.8428800, -73.2928900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141053, 'Concord', 'Concord', '', 40.6081600, -74.0843100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141054, 'Coney Island', 'Coney Island', 'Coney Adasi,Coney Adası,Coney Island,Conyn Island,Conyne Island,Insulo Coney,Koni-Ajlend,kang ni dao,koni-ailendi,koniaillaendeu,koniairando,kwny ayland,Кони-Айленд,קוני איילנד,كوني آيلاند,კონი-აილენდი,ქონი-აილენდი,コニーアイランド,康尼島,코니아일랜드', 40.5778800, -73.9940300, 'US', '2010-08-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141055, 'Congers', 'Congers', '', 41.1506500, -73.9454200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141056, 'Constantia', 'Constantia', 'Constantia,New Rotterdam,Rotterdam', 43.2478500, -76.0002000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141057, 'Cooperstown', 'Cooperstown', 'COP,Cooperstown,Kopertaun,Kupurstaun,Otsego,kupazutaun,kwbrstawn,Копертаун,Купърстаун,كوبرستاون,クーパーズタウン', 42.7004800, -74.9242600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141058, 'Copiague', 'Copiague', 'Copiague,East Amityville,Great Neck,Huntington South', 40.6814900, -73.3998400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141059, 'Coram', 'Coram', 'Coram,Corum', 40.8687100, -73.0014900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141060, 'Corinth', 'Corinth', 'Corinth,Jessup''s Landing,Jessups Landing', 43.2445200, -73.8323400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141061, 'Corning', 'Corning', 'Korning,Kurning,ke ning,koning,koningu,kwrnng,kwrnyng  nywywrk,kwrnyngh,Корнинг,Курнинг,كورنينغ,کورننگ,کورنینگ، نیویورک,コーニング,科宁,코닝', 42.1428500, -77.0546900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141062, 'Cornwall-on-Hudson', 'Cornwall-on-Hudson', 'Canterbury,Cornwall,Cornwall-on-Hudson,Cornwall-on-the-Hudson', 41.4448200, -74.0157000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141063, 'Corona', 'Corona', 'Corona,West Flushing', 40.7470500, -73.8601400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141064, 'Cortland', 'Cortland', 'CTX,Cortland,Kortland,Kurtlend,kotorando,kwrtland,kwrtlnd  nywywrk,Кортланд,Куртленд,كورتلاند,کورتلند، نیویورک,コートランド', 42.6011800, -76.1804800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141065, 'Country Knolls', 'Country Knolls', '', 42.9150800, -73.8051200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141066, 'Coxsackie', 'Coxsackie', '', 42.3509200, -73.8029000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141067, 'Crompond', 'Crompond', '', 41.2950900, -73.8654100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141068, 'Croton-on-Hudson', 'Croton-on-Hudson', 'Colabaugh Landing,Collabaugh Landing,Cortlandt Town,Croton,Croton Landing,Croton-on-Hudson,Kroton na Khadsonu,krwtwn an hadswn,Кротон на Хадсону,كروتون أن هادسون', 41.2084300, -73.8912500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141069, 'Crown Heights', 'Crown Heights', '', 41.6373200, -73.9379200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141070, 'Crugers', 'Crugers', '', 41.2334300, -73.9226400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141071, 'Cuba', 'Cuba', 'Kjuba,kwba,kywba,Кјуба,كوبا,کیوبا', 42.2175700, -78.2752900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141072, 'Cumberland Head', 'Cumberland Head', 'Cumberland Head,Ohskennon:ton,Ohskennón:ton', 44.7164300, -73.4026300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141073, 'Cutchogue', 'Cutchogue', '', 41.0106600, -72.4850900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141074, 'Cypress Hills', 'Cypress Hills', 'Cypress Hills,Union Place', 40.6770500, -73.8912500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141075, 'Dannemora', 'Dannemora', '', 44.7214300, -73.7237500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141076, 'Dansville', 'Dansville', 'DSV', 42.5609000, -77.6961100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141077, 'Deer Park', 'Deer Park', 'DPK,Deer Park,Deerpark', 40.7617700, -73.3292900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141078, 'Delevan', 'Delevan', 'Delevan,Yorkshire Center', 42.4892300, -78.4808500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141079, 'Delhi', 'Delhi', 'qryt dlhy,قرية دلهي', 42.2781400, -74.9159900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141080, 'Delmar', 'Delmar', 'Adam''s Station,Adams Station,Adamsville,Delmar', 42.6220200, -73.8326200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141081, 'Depew', 'Depew', 'Depju,dybyw,Депју,ديبيو', 42.9039500, -78.6922500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141082, 'Deposit', 'Deposit', 'Cokeose,Cookhouse,Deposit', 42.0600800, -75.4276800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141083, 'Dexter', 'Dexter', 'Dexter,Fish Island', 44.0078400, -76.0443700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141084, 'Dix Hills', 'Dix Hills', '', 40.8048200, -73.3362300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141085, 'Dobbs Ferry', 'Dobbs Ferry', 'Dobb''s Ferry,Dobbs Ferry,Dobs Feri,Greenburgh,New Wales,Weecquaesgunk,Добс Фери,ドブス・フェリー', 41.0145400, -73.8726400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141086, 'Dolgeville', 'Dolgeville', 'Brockett''s Bridge,Brocketts Bridge,Dolgeville,Green''s Bridge,dwlghyfyl,دولغيفيل', 43.1009000, -74.7729300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141087, 'Dongan Hills', 'Dongan Hills', '', 40.5884400, -74.0962500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141088, 'Douglaston', 'Douglaston', '', 40.7687100, -73.7470800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141089, 'Dover Plains', 'Dover Plains', 'Dover Plains,Pawlingstown', 41.7412100, -73.5765200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141090, 'Dryden', 'Dryden', '', 42.4909100, -76.2971600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141091, 'Dundee', 'Dundee', 'Dundee,Harpending''s Corners', 42.5234000, -76.9766300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141092, 'Dunkirk', 'Dunkirk', 'Chadwicks Bay,DKK,Dankerk,Dinkirk,Dunkirk,Ganadawao,dankyrk  nywywrk,dwnkyrk,Данкерк,Динкирк,دانکیرک، نیویورک,دونكيرك', 42.4795000, -79.3339300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141093, 'Durham', 'Durham', 'Darem,Durham,New Durham,dwrham,Дарем,دورهام', 42.3995300, -74.1723600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141094, 'Dyker Heights', 'Dyker Heights', '', 40.6214900, -74.0095800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141095, 'East Atlantic Beach', 'East Atlantic Beach', '', 40.7898200, -73.7470800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141096, 'East Aurora', 'East Aurora', 'East Aurora,Ist Orora,Lower Village,Upper Village,ayst aywrwra,Ист Орора,إيست أئورورا', 42.7678400, -78.6133600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141097, 'East Farmingdale', 'East Farmingdale', '', 40.7292700, -73.4167900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141098, 'East Flatbush', 'East Flatbush', 'East Flatbush,Rugby', 40.6537100, -73.9304200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141099, 'East Garden City', 'East Garden City', '', 40.7308300, -73.5980600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141100, 'East Glenville', 'East Glenville', '', 42.8945200, -73.9279000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141101, 'East Greenbush', 'East Greenbush', 'East Greenbush,Het Groen Bosch,Ist Grinbush,ayst ghrynbwsh,Ист Гринбуш,إيست غرينبوش', 42.5909100, -73.7017900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141102, 'East Hampton', 'East Hampton', 'East Hampton,Easthampton,Est Hampton,HTO,Ist Khempton,Iztochen Khamptun,Maidstone,ayst hambtwn,Източен Хамптън,Ист Хемптон,إيست هامبتون', 40.9634300, -72.1848000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141103, 'East Hills', 'East Hills', '', 40.7937100, -73.6270700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141104, 'East Islip', 'East Islip', '', 40.7320400, -73.1856700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141105, 'East Ithaca', 'East Ithaca', '', 42.4395200, -76.4785500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141106, 'East Meadow', 'East Meadow', 'East Meadow,East Meadows,Ist Medou,ayst mydaw,Ист Медоу,إيست ميداو', 40.7139900, -73.5590200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141107, 'East Massapequa', 'East Massapequa', '', 40.6734300, -73.4365100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141108, 'East Moriches', 'East Moriches', '', 40.8051000, -72.7609300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141109, 'East New York', 'East New York', 'East New York,Oostwoud,Starrett City', 40.6667700, -73.8823600, 'US', '2007-06-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141110, 'East Northport', 'East Northport', 'East Northport,Larkfield', 40.8767600, -73.3245600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141111, 'East Norwich', 'East Norwich', 'East Norwich,Norwich', 40.8467700, -73.5351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141112, 'East Patchogue', 'East Patchogue', '', 40.7670400, -72.9962200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141113, 'East Quogue', 'East Quogue', '', 40.8406600, -72.5814800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141114, 'East Rochester', 'East Rochester', '', 43.1086700, -77.4875000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141115, 'East Rockaway', 'East Rockaway', 'Atlantic,East Rockaway,Near Rockaway', 40.6420500, -73.6695700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141116, 'East Setauket', 'East Setauket', '', 40.9414900, -73.1059400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141117, 'East Shoreham', 'East Shoreham', '', 40.9448200, -72.8795500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141118, 'East Syracuse', 'East Syracuse', '', 43.0653400, -76.0785300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141119, 'East Tremont', 'East Tremont', '', 40.8453800, -73.8909700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141120, 'East Williston', 'East Williston', '', 40.7584300, -73.6348500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141121, 'Eastchester', 'Eastchester', '', 40.9583300, -73.8086100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141122, 'Eastchester', 'Eastchester', 'East Chester,Eastchester,Ost Dorp', 40.8876000, -73.8329100, 'US', '2012-04-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141123, 'Eastport', 'Eastport', 'Eastport,Seacotauk,Seatuck', 40.8259300, -72.7317700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141124, 'Eatons Neck', 'Eatons Neck', '', 40.9306500, -73.4015100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141125, 'Eden', 'Eden', 'Eden,Tubb''s Hollow', 42.6522800, -78.8969800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141126, 'Eden', 'Eden', '', 41.2887100, -74.4943300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141127, 'Edgemere', 'Edgemere', 'Edgemere,New Venice', 40.5962200, -73.7676300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141128, 'Edinburg', 'Edinburg', 'Beecher''s Hollow,Beechers Hollow,Edinburg,Edinburgh', 43.2217400, -74.1040200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141129, 'Eggertsville', 'Eggertsville', '', 42.9633900, -78.8039200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141130, 'Elbridge', 'Elbridge', 'Elbridge,Ka-no-wa-ya', 43.0345100, -76.4479900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141131, 'Elizabethtown', 'Elizabethtown', 'Elizabethtown,Pleasant Valley,The Valley', 44.2161600, -73.5909700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141132, 'Ellenville', 'Ellenville', 'Elenvil,Ellenville,Fairchild City,aylnfyl,Еленвил,إيلنفيل', 41.7170400, -74.3957100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141133, 'Elma Center', 'Elma Center', 'Elma Center,Elma Centre', 42.8297800, -78.6361400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141134, 'Elmhurst', 'Elmhurst', 'Elmhurst,Middeburgh,Middelburg,Middelburgh,Neutuyn,Newtown', 40.7364900, -73.8779100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141135, 'Elmira', 'Elmira', 'ELM,Ehl''mira,Elmajra,Elmira,Ilmiro,New Town,Newtown,Skwedowa,ai er mai la,almyra,almyra  nywywrk,aylmyra  nyw yark,erumaira,Елмайра,Елмајра,Илмиро,Эльмира,إلميرا,المیرا، نیویورک,ایلمیرا، نیو یارک,エルマイラ,埃尔迈拉', 42.0898000, -76.8077300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141136, 'Elmira Heights', 'Elmira Heights', '', 42.1298000, -76.8207900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141137, 'Elmont', 'Elmont', 'Elmont,Foster''s Meadow,almwnt,Елмонт,إلمونت', 40.7009400, -73.7129100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141138, 'Elmsford', 'Elmsford', 'Elmsford,Greenburgh,Hall''s Corners,Storm''s Bridge', 41.0551000, -73.8201300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141139, 'Eltingville', 'Eltingville', 'Eltingville,Sea Side,South Side', 40.5453800, -74.1657000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141140, 'Elwood', 'Elwood', '', 40.8453800, -73.3351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141141, 'Emerson Hill', 'Emerson Hill', '', 40.6087200, -74.0959800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141142, 'Endicott', 'Endicott', 'Endikot,andykwt,endikotto,Ендикот,إنديكوت,エンディコット', 42.0984100, -76.0493700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141143, 'Endwell', 'Endwell', 'Endwell,Hooper', 42.1128500, -76.0210300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141144, 'Fairmount', 'Fairmount', '', 43.0472900, -76.2385400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141145, 'Fairport', 'Fairport', 'Fairport,Fullam Town,Fullam''s', 43.0986700, -77.4419400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141146, 'Fairview', 'Fairview', '', 41.7237000, -73.9198600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141147, 'Fairview', 'Fairview', '', 41.0434300, -73.7973600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141148, 'Falconer', 'Falconer', 'Falconer,Worksburg', 42.1186700, -79.1983800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141149, 'Fallsburg', 'Fallsburg', 'Falls of the Neversink,Fallsburg,Fallsburgh,Lockwood''s Mills,Neversink Falls,falsbwrgh,פאלסבורג,فالسبورغ', 41.7320400, -74.6012700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141150, 'Far Rockaway', 'Far Rockaway', 'פאר ראקעוועי,فار روک اوے، کوئینز', 40.6053800, -73.7551300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141151, 'Farmingdale', 'Farmingdale', 'FRG,Farmingdale,Farmingdejl,Hardscrabble,farmynghdyl,Фармингдејл,فارمينغديل', 40.7326000, -73.4454000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141152, 'Farmingville', 'Farmingville', '', 40.8312100, -73.0295500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141153, 'Fayetteville', 'Fayetteville', 'Fayetteville,Manlius Four Corners,The Corners', 43.0297900, -76.0043600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141154, 'Firthcliffe', 'Firthcliffe', 'Fircloff,Firthcliffe,Montana Woolen Mills', 41.4392600, -74.0451400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141155, 'Fishkill', 'Fishkill', 'Fishkil,Fishkill,Fishkill Village,fisshukiru,fyshkyl,Фишкил,فيشكيل,フィッシュキル', 41.5356500, -73.8990300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141156, 'Flanders', 'Flanders', '', 40.9034300, -72.6175900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141157, 'Flatbush', 'Flatbush', 'Flatbush,Middelwout,Middewout,Vlackebos,פלעטבוש', 40.6520500, -73.9590300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141158, 'Flatlands', 'Flatlands', 'Flatlands,Keskachauge,Neue Amserfoort', 40.6212200, -73.9348600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141159, 'Floral Park', 'Floral Park', 'East Hinsdale,Floral Park,Hinsdale,flwral bark,flwrl park  nyw yark,Флорал Парк,فلورال بارك,فلورل پارک، نیو یارک', 40.7237100, -73.7048500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141160, 'Florida', 'Florida', 'Brookland,Florida,Floridus,Флорида', 41.3317600, -74.3568200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141161, 'Flower Hill', 'Flower Hill', '', 40.8073200, -73.6812400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141162, 'Fonda', 'Fonda', 'Caughnawaga,Fonda,Ga-na-wa-da,Kana''tsiohare:ke,Kana''tsioharè:ke,fang da,fwnda,Фонда,فوندا,方达', 42.9545200, -74.3765200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141163, 'Fordham', 'Fordham', '', 40.8592700, -73.8984700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141164, 'Forest Hills', 'Forest Hills', 'Forest Hill,Forest Hills,Whitepot', 40.7162100, -73.8501400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141165, 'Fort Edward', 'Fort Edward', 'Fort Edward,Wah-co-loo-sen-coo-cha-le-va', 43.2670200, -73.5845600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141166, 'Fort Hamilton', 'Fort Hamilton', '', 40.6187200, -74.0332000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141167, 'Fort Montgomery', 'Fort Montgomery', '', 41.3314800, -73.9868100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141168, 'Fort Plain', 'Fort Plain', 'Fort Plain,Twa-da-a-la-ha-la', 42.9314600, -74.6226400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141169, 'Fort Salonga', 'Fort Salonga', '', 40.9126000, -73.3009500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141170, 'Fort Wadsworth', 'Fort Wadsworth', '', 40.6011300, -74.0573800, 'US', '2017-04-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141171, 'Frankfort', 'Frankfort', 'Frankfurt,Франкфурт', 43.0389600, -75.0704400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141172, 'Franklin Square', 'Franklin Square', 'Franklin Skver,Franklin Square,Trimming Square,Washington Square,franklyn skwary,Франклин Сквер,فرانكلين سكواري', 40.7073200, -73.6759600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141173, 'Franklinville', 'Franklinville', '', 42.3370100, -78.4580800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141174, 'Fredonia', 'Fredonia', 'Canadaway,Fredonia,Fridonija,frdwnya  nywywrk,frydwna,Фридонија,فردونیا، نیویورک,فريدونا', 42.4400600, -79.3317100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141175, 'Freeport', 'Freeport', 'Freeport,Friport,Hempstead South,Raynor South,Raynor''s Neck,Raynortown,Raynorville,Washburn''s Neck,frybwrt,peulipoteu,Фрипорт,فريبورت,فری پورٹ، نیو یارک,프리포트', 40.6576000, -73.5831800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141176, 'Fresh Meadows', 'Fresh Meadows', '', 40.7348200, -73.7934700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141177, 'Frewsburg', 'Frewsburg', 'Frewsburg,Frewsburgh', 42.0545000, -79.1581000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141178, 'Friendship', 'Friendship', 'Fighting Corners,Friendship', 42.2064600, -78.1375100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141179, 'Fulton', 'Fulton', 'Fulton,Oswego Falls,fwltn  nywywrk,fwltwn,Фултон,فولتن، نیویورک,فولتون', 43.3228500, -76.4171600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141180, 'Galeville', 'Galeville', '', 43.0900700, -76.1729800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141181, 'Garden City', 'Garden City', 'Garden City,Garden Siti,JHC,ghardyn syty,Гарден Сити,غاردين سيتي,گارڈن سٹی، نیو یارک', 40.7267700, -73.6343000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141182, 'Garden City Park', 'Garden City Park', '', 40.7409300, -73.6626300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141183, 'Garden City South', 'Garden City South', '', 40.7123200, -73.6609600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141184, 'Gang Mills', 'Gang Mills', '', 42.1461900, -77.1116400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141185, 'Gardnertown', 'Gardnertown', '', 41.5350900, -74.0701400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141186, 'Gasport', 'Gasport', '', 43.1992200, -78.5761400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141187, 'Geneseo', 'Geneseo', 'Big Tree,Dzenesio,Geneseo,jynysyw,Џенесио,جينيسيو', 42.7959000, -77.8169500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141188, 'Geneva', 'Geneva', 'Dzeniva,Ganundasaga,Geneva,Geneve,LjinivoNju-Jork,Zheneva,jnyf,zhnwa  nywywrk,ЉинивоНю-Йорк,Џенива,Женева,جنيف,ژنوا، نیویورک', 42.8689600, -76.9777400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141189, 'Glasco', 'Glasco', '', 42.0437000, -73.9473600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141190, 'Glen Cove', 'Glen Cove', 'Glen Cove,Glen Kouv,Glen-Kouv,Glin Kav,Moscheto Cove,Mosquito Cove,Musquito Cove,ghlyn kwf,gln yarw  nywywrk,gurenkobu,Глен Коув,Глен-Коув,Глин Кав,Ґлен-Коув,غلين كوف,گلن یارو، نیویورک,グレンコーブ', 40.8623200, -73.6337400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141191, 'Glen Head', 'Glen Head', 'Glen Head,Glenhead', 40.8353800, -73.6237400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141192, 'Glen Oaks', 'Glen Oaks', '', 40.7470500, -73.7115200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141193, 'Glendale', 'Glendale', '', 40.7014900, -73.8868000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141194, 'Glens Falls', 'Glens Falls', 'Che-pon-tuc,Four Corners,GFL,Glen''s Falls,Glenn''s Falls,Glens Falls,Glens Fols,Glenville,Glins Folz,Ka-yan-do-ros-sa,Wing''s Falls,ghlynz fwlz,glynz falz  nyw yark,glynz falz  nywywrk,gurenzuforuzu,Гленс Фолс,Глинс Фолз,غلينز فولز,گلینز فالز، نیو یارک,گلینز فالز، نیویورک,グレンズフォールズ', 43.3095200, -73.6440100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141195, 'Glenwood Landing', 'Glenwood Landing', 'Glenwood,Glenwood Landing,Littleworth,Newark', 40.8306600, -73.6387400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141196, 'Gloversville', 'Gloversville', 'Glaversvil,Glovursvil,ghlwfrsfyl,glwwrswyl  nywywrk,Главерсвил,Гловурсвил,غلوفرسفيل,گلوورسویل، نیویورک', 43.0528500, -74.3437500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141197, 'Goldens Bridge', 'Goldens Bridge', 'Golden''s Bridge,Goldenbridge,Goldens Bridge,Goldensbridge,Golding''s Bridge', 41.2934300, -73.6768000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141198, 'Gordon Heights', 'Gordon Heights', 'Coram Hill,Gordon Heights,Jordan Heights', 40.8587100, -72.9706600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141199, 'Goshen', 'Goshen', 'Goshen,gwsn,qryt ghwshn,Гошен,גושן,قرية غوشن', 41.4020400, -74.3243200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141200, 'Gouverneur', 'Gouverneur', 'Cambray,Gouverneur', 44.3367300, -75.4629900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141201, 'Gowanda', 'Gowanda', 'Aldrich Mills,Aldrich''s Mills,Govanda,Gowanda,Lodi,Persia,West Lodi,ghwanda,Гованда,غواندا', 42.4631200, -78.9358700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141202, 'Grand Island', 'Grand Island', 'Ga-wah-no-geh,Ga-we-not,Gawanogeh,Gawenodowanneh,Grand Island,ghrand ayland,גרנד איילנד,غراند أيلاند', 43.0331100, -78.9625400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141203, 'Grandyle Village', 'Grandyle Village', 'Grandyle,Grandyle Village', 42.9964500, -78.9550400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141204, 'Graniteville', 'Graniteville', 'Bennett''s Corners,Fayetteville,Graniteville', 40.6248300, -74.1484800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141205, 'Grant City', 'Grant City', '', 40.5820500, -74.1048600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141206, 'Granville', 'Granville', 'Bishops Corners,Granvil,Granville,ghranfyl,Гранвил,غرانفيل', 43.4078500, -73.2595500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141207, 'Gravesend', 'Gravesend', '', 40.5976000, -73.9651400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141208, 'Great Kills', 'Great Kills', 'Clarendon,Gifford''s,Giffords,Great Kills,Greatkills,Newtown', 40.5542700, -74.1515300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141209, 'Great Neck', 'Great Neck', 'Great Neck,Greatneck,Grejt Nek,geuleiteuneg,gryt nk  nywywrk,Грејт Нек,گریت نک، نیویورک,그레이트넥', 40.8006600, -73.7284600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141210, 'Great Neck Gardens', 'Great Neck Gardens', '', 40.7972200, -73.7238900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141211, 'Great Neck Plaza', 'Great Neck Plaza', 'Brookdale,Great Neck,Great Neck Plaza', 40.7867700, -73.7265200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141212, 'Great River', 'Great River', 'Grejt River,Грејт Ривер', 40.7212100, -73.1576100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141213, 'Great Neck Estates', 'Great Neck Estates', '', 40.7870500, -73.7368000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141214, 'Greece', 'Greece', 'Graecia,Grecia,Gris,ghrys,Грис,غريس', 43.2097800, -77.6930600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141215, 'Green Island', 'Green Island', 'Grin Ajland,ghryn ayland,Грин Ајланд,غرين أيلاند', 42.7442400, -73.6915100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141216, 'Greenburgh', 'Greenburgh', 'Grinburg,Гринбург,Ґрінбург', 41.0328700, -73.8429100, 'US', '2010-04-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141217, 'Greene', 'Greene', 'Greene,Hornby', 42.3292400, -75.7699100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141218, 'Greenlawn', 'Greenlawn', '', 40.8689900, -73.3651200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141219, 'Greenport', 'Greenport', 'Green Hill,Greenport,Grinport,Sterling,Stirling,Winter Harbor,Гринпорт', 41.1034300, -72.3592500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141220, 'Greenvale', 'Greenvale', '', 40.8106600, -73.6284600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141221, 'Greenville', 'Greenville', '', 40.9931500, -73.8198600, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141222, 'Greenwich', 'Greenwich', 'Greenwich,Grinvich,Union Village,Whipple City,Whipple''s City,Гринвич', 43.0906300, -73.4987300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141223, 'Greenwood Lake', 'Greenwood Lake', '', 41.2225900, -74.2943200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141224, 'Groton', 'Groton', '', 42.5878500, -76.3668800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141225, 'Grymes Hill', 'Grymes Hill', '', 40.6187200, -74.0934800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141226, 'Hadley', 'Hadley', '', 43.3172900, -73.8481800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141227, 'Hagaman', 'Hagaman', 'Hagaman,Hagaman''s Mills,Hagamans Mills', 42.9745200, -74.1509600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141228, 'Halesite', 'Halesite', '', 40.8884300, -73.4154000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141229, 'Hamburg', 'Hamburg', 'Hamburg,Hamburgh,Smith''s Mills,Smithville,White''s Corners', 42.7158900, -78.8294800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141230, 'Hamilton', 'Hamilton', 'Da-ude-no-sa-gwa-nose,Gamil''ton,Hamilton,Paynesville,Гамильтон', 42.8270100, -75.5446200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141231, 'Hamlin', 'Hamlin', '', 43.3031200, -77.9211200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141232, 'Hampton Bays', 'Hampton Bays', 'Good Ground,Hampton Bays', 40.8689900, -72.5175900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141233, 'Hampton Manor', 'Hampton Manor', '', 42.6209100, -73.7284500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141234, 'Hannawa Falls', 'Hannawa Falls', 'Cox''s Mills,Coxe''s Mills,East Pierrepont,Ellsworth,Hannawa Falls,Hannaway Falls,Nihanawate', 44.6122800, -74.9710300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141235, 'Harbor Isle', 'Harbor Isle', '', 40.6034400, -73.6645700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141236, 'Harlem', 'Harlem', 'Garlem,Harlem,Harlema,Harlemas,Harlemo,Hārlema,Kharlem,New Harlem,Nieu Haarlem,Nieuw Haarlem,Northern Manhattan,ha lai mu qu,hallem,haremu,harlemi,harlm,Гарлем,Харлем,Հառլեմ,הארלם,هارلم,ہارلم,ჰარლემი,ハーレム,哈莱姆区,할렘', 40.8078800, -73.9454200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141237, 'Harriman', 'Harriman', 'Centerville,Harriman,Khariman,Turner,haryman,Хариман,هاريمان', 41.3084300, -74.1445900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141238, 'Harris Hill', 'Harris Hill', '', 42.9647800, -78.6775300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141239, 'Harrison', 'Harrison', 'Kharison,Kharisun,Kharrison,harryswn,Харисон,Харисън,Харрисон,هارريسون', 40.9689900, -73.7126300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141240, 'Hartford', 'Hartford', 'Hartford,Khartford,North Hartford,Хартфорд', 43.3636800, -73.3937200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141241, 'Hartsdale', 'Hartsdale', 'Barne''s Corners,Hart''s Corners,Hartsdale,Moringville', 41.0189900, -73.7981900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141242, 'Hastings-on-Hudson', 'Hastings-on-Hudson', 'Hastings,Hastings On Hudson,Hastings On the Hudson,Hastings Upon Hudson,Hastings-on-Hudson,Hastings-upon-Hudson,Khejstings na Khadsonu,Хејстингс на Хадсону', 40.9945400, -73.8787500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141243, 'Hauppauge', 'Hauppauge', 'Hauppauge,Hauppaugs,Hoppogue,Wheeler Settlement,Wheelers', 40.8256500, -73.2026100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141244, 'Haverstraw', 'Haverstraw', 'Averstroo,Haverstraw,Haverstroo,Khejverstro,Warren,Waynesburgh,habesutoro,hafrstraw,Хејверстро,هافرستراو,ハベストロー', 41.1975900, -73.9645800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141245, 'Haviland', 'Haviland', '', 41.7667600, -73.9015200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141246, 'Hawthorne', 'Hawthorne', 'Hammond''s Mill,Hammonds Mills,Hawthorne,Neperan,Unionville', 41.1073200, -73.7959700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141247, 'Head of the Harbor', 'Head of the Harbor', '', 40.9034300, -73.1578900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141248, 'Hempstead', 'Hempstead', 'Hempstead,Hemsted,Khempsted,Хемпстед', 40.7062100, -73.6187400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141249, 'New Hempstead', 'New Hempstead', 'Hempstead,Kakiat,Keckyate,Kukiat,New Hempstead', 41.1498200, -74.0337500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141250, 'Herkimer', 'Herkimer', 'Herkimer,Kherkimer,Stone Ridge,qryt hrykymr,Херкимер,قرية هريكيمر', 43.0256300, -74.9859900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141251, 'Heritage Hills', 'Heritage Hills', '', 41.3395400, -73.6973500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141252, 'Herricks', 'Herricks', '', 40.7553800, -73.6668000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141253, 'Hewlett', 'Hewlett', 'Cedar Grove,Fenhurst,Hewlett,Hewletts', 40.6431600, -73.6956900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141254, 'Hewlett Harbor', 'Hewlett Harbor', '', 40.6362100, -73.6815200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141255, 'Hicksville', 'Hicksville', 'Khiksvil,Khiksvilla,hyksfyly,Хиксвил,Хиксвилла,هيكسفيلي', 40.7684300, -73.5251300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141256, 'Highland', 'Highland', 'Elting''s Landing,Highland,New Paltz Landing,Philip''s Folly', 41.7209300, -73.9601400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141257, 'Highland Falls', 'Highland Falls', 'Buttermilk Falls,Highland Falls,Khajland Fols,hayland fals,Хајланд Фолс,هايلاند فالس', 41.3692600, -73.9662500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141258, 'Highland Mills', 'Highland Mills', 'Highland Mills,Orange', 41.3470400, -74.1262600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141259, 'Hillcrest', 'Hillcrest', '', 41.1278700, -74.0409700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141260, 'Hillside', 'Hillside', 'East Jamaica,Hillside,Rockaway Junction', 40.7078800, -73.7868000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141261, 'Hillside Lake', 'Hillside Lake', '', 41.6148200, -73.7981900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141262, 'Hilton', 'Hilton', 'Hilton,North Parma,Unionville', 43.2881200, -77.7933400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141263, 'Holbrook', 'Holbrook', 'Kholbruk,Холбрук', 40.8123200, -73.0784400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141264, 'Holcomb', 'Holcomb', 'Bloomfield,Holcomb', 42.9022900, -77.4197100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141265, 'Holland', 'Holland', 'Gollandija,Голландия', 42.6411700, -78.5416900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141266, 'Holley', 'Holley', '', 43.2264500, -78.0266800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141267, 'Holtsville', 'Holtsville', '', 40.8153800, -73.0451100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141268, 'Homer', 'Homer', 'Homer,Te-wis-ta-no-ont-sa-ne-a-ha', 42.6370100, -76.1788200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141269, 'Honeoye Falls', 'Honeoye Falls', 'Honeoye Falls,Norton''s Mills,Nortons Mills,hwnwy fals,هونوي فالس', 42.9522900, -77.5902800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141270, 'Hoosick Falls', 'Hoosick Falls', 'Khusik Fols,hwsyk,Хусик Фолс,هوسيك', 42.9011900, -73.3515000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141271, 'Hornell', 'Hornell', 'Hornell,Hornellsville,Khornel,Njurnel,hwrnl  nywywrk,hwrnyl,Њурнел,Хорнел,هورنل، نیویورک,هورنيل', 42.3278500, -77.6611000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141272, 'Horseheads', 'Horseheads', 'Fairport,Horseheads', 42.1670200, -76.8205100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141273, 'Houghton', 'Houghton', 'Houghton,Jockey Street', 42.4234000, -78.1572300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141274, 'Howard Beach', 'Howard Beach', 'Howard Beach,Rambersville', 40.6578800, -73.8362500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141275, 'Hudson', 'Hudson', 'Claverack Landing,Gudzon,HCC,Hudson,Khadson,hadswn  nywywrk,hdswn,Гудзон,Хадсон,Ҳадсун,هادسون، نیویورک,هدسون,ہڈسن، نیو یارک', 42.2528600, -73.7909600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141276, 'Hudson Falls', 'Hudson Falls', 'Hudson Falls,Khadson Fols,Kingsbury,Sandy Hill,hadswn fals,Хадсон Фолс,هادسون فالس', 43.3006300, -73.5859500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141277, 'Huguenot', 'Huguenot', 'Bloomingview,Huguenot', 40.5373300, -74.1945900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141278, 'Huntington', 'Huntington', 'Gantington,Hontingeton,Hontingtowne,Huntington,Ke-te-wo-moke,Khantington,Khuntingtun,hanthing tan,hantyngtwn  nywywrk,heontingteon,hntnghtwn,Гантінґтон,Хантингтон,Хънтингтън,هانتینگتون، نیویورک,هنتنغتون,ฮันทิงตัน,헌팅턴', 40.8681500, -73.4256800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141279, 'Huntington Bay', 'Huntington Bay', 'Khantington Bej,hantynghtwn bay,Хантингтон Беј,هانتينغتون باي', 40.8998200, -73.4148400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141280, 'Huntington Station', 'Huntington Station', '', 40.8534300, -73.4115100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141281, 'Hurley', 'Hurley', 'Hurley,New Village,Nieuw Dorp', 41.9245400, -74.0612500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141282, 'Hyde Park', 'Hyde Park', 'Hyde Park,Khajd Park,Stoutenburgh,hai de pa ke,haideupakeu,hayd bark,Хајд Парк,هايد بارك,海德帕克,하이드파크', 41.7848200, -73.9331900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141283, 'Ilion', 'Ilion', 'Ilion,Remington,The Corners,aylywn,Илион,إيليون', 43.0150700, -75.0354300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141284, 'Inwood', 'Inwood', 'Inwood,Northwest Point,Westville', 40.6220500, -73.7468000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141285, 'Inwood', 'Inwood', '', 40.8656600, -73.9268000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141286, 'Irondequoit', 'Irondequoit', 'Irondikvojt,arwndykwwyt,Ирондиквојт,إرونديكوويت', 43.2134000, -77.5797200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141287, 'Irvington', 'Irvington', 'Dearman,Dearman''s Landing,Dearmans,Irvington,Irvington-on-Hudson,ayrfynghtwn,Ирвингтон,إيرفينغتون', 41.0392200, -73.8682300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141288, 'Island Park', 'Island Park', 'Ajland Park,ayland bark,Ајланд Парк,آئلینڈ پارک، نیو یارک,أيلاند بارك', 40.6042700, -73.6554100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141289, 'Islandia', 'Islandia', '', 40.8042600, -73.1690000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141290, 'Islip', 'Islip', 'Ajslip,ISP,aslyb,Ајслип,إسليب', 40.7298200, -73.2103900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141291, 'Islip Terrace', 'Islip Terrace', '', 40.7431500, -73.1926200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141292, 'Ithaca', 'Ithaca', 'Cayuga City,ITH,Itak,Itaka,Itako,Ithaca,Markle''s Flats,Sodom,The Flats,athaka,aytaka  nywywrk,isaka,ithaka,yi sa ka,Ітака,Итак,Итака,Итако,איתקה,إثاكا,اتھاکا، نیو یارک,ایتاکا، نیویورک,ইথাকা,イサカ,伊萨卡,이사카', 42.4406300, -76.4966100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141293, 'Jackson Heights', 'Jackson Heights', 'jaegseunhaicheu,جیکسن ہائیٹس، کوئینز,잭슨하이츠', 40.7556600, -73.8854100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141294, 'Jamaica', 'Jamaica', 'Jaimaica,Jamaica,Jamaicah,Jamaick,Jamaico,Jamaika,Jamanica,Jameco,Jemaica,Jemaicae,Jemaico,Jemecah,Rustdorp,gmyyqh,jamaika de qu,jameika,גמייקה,ジャマイカ地区,자메이카', 40.6914900, -73.8056900, 'US', '2012-05-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141295, 'Jamesport', 'Jamesport', 'Jamesport,Lower Aquebogue,Mi-o-mog,Mianrogue,Old Aquebogue', 40.9495400, -72.5814800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141296, 'Jamestown', 'Jamestown', 'Dzejmstaun,JHW,James Town,Jamestown,Limz Taun,jeimseutaun,jemuzutaun,jymz tawn,jymztawn  nywywrk,Џејмстаун,Лимз Таун,جيمز تاون,جیمز ٹاون، نیو یارک,جیمزتاون، نیویورک,ジェームズタウン,제임스타운', 42.0970000, -79.2353300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141297, 'Jefferson Heights', 'Jefferson Heights', 'Jefferson Flats,Jefferson Heights,The Flats', 42.2339800, -73.8823500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141298, 'Jericho', 'Jericho', 'Dzeriko,Jericho,Lusam,Lusum,aryha,Џерико,أريحا', 40.7920400, -73.5398500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141299, 'Johnson City', 'Johnson City', 'Dzhonson Siti,Dzonson Siti,Johnson City,Lestershire,janswn syty,yue han xun cheng,Џонсон Сити,Джонсон Сити,جانسن سٹی، نیو یارک,جانسون سيتي,約翰遜城', 42.1156300, -75.9588100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141300, 'Johnstown', 'Johnstown', 'Dzhonstaun,Dzonstaun,Johnstown,Ko-la-ne-ka,Ljonz Taun,janztawn  nywywrk,jwnstawn,Љонз Таун,Џонстаун,Джонстаун,جانزتاون، نیویورک,جونستاون', 43.0067400, -74.3676400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141301, 'Jordan', 'Jordan', '', 43.0653400, -76.4729900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141302, 'Kaser', 'Kaser', '', 41.1212100, -74.0670900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141303, 'Katonah', 'Katonah', 'Katona,Катона', 41.2589800, -73.6854100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141304, 'Keeseville', 'Keeseville', 'Andersons Falls,Keeseville,Kisvil,Long Chute,kysyfyl,Кисвил,كيسيفيل', 44.5050500, -73.4801300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141305, 'Kenmore', 'Kenmore', '', 42.9658900, -78.8700400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141306, 'Kensington', 'Kensington', '', 40.6462100, -73.9706900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141307, 'Kensington', 'Kensington', '', 40.7934300, -73.7220800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141308, 'Kerhonkson', 'Kerhonkson', 'Kerhonkson,Kerhonkton,Middleport', 41.7748200, -74.2982100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141309, 'Kew Gardens', 'Kew Gardens', '', 40.7142700, -73.8309700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141310, 'Keuka Park', 'Keuka Park', '', 42.6153500, -77.0921900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141311, 'Kiantone', 'Kiantone', '', 42.0220000, -79.1981000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141312, 'Kinderhook', 'Kinderhook', '', 42.3953600, -73.6979000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141313, 'Kings Bridge', 'Kings Bridge', '', 40.8787100, -73.9051400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141314, 'Kings Park', 'Kings Park', '', 40.8862100, -73.2573400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141315, 'Kings Point', 'Kings Point', '', 40.8198200, -73.7351300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141316, 'Kingston', 'Kingston', 'Esopus,Kingston,Kingston L''isle,Kingstun,Swanenburgh,Wildwijk,Wildwyck,Wiltwyck,kingseuteon,kingusuton,kynghstwn,kyngstwn  nywywrk,Кингстон,Кингстън,Кінґстон,كينغستون,کنگسٹن، نیویارک,کینگستون، نیویورک,キングストン,킹스턴', 41.9270400, -73.9973600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141317, 'Kiryas Joel', 'Kiryas Joel', 'Kir''jas-Dzhoehl'',kryas jwyyl  nyw yark,kyryas jwl  nywywrk,kyryas jwyl,Кирьяс-Джоэль,קריית יואל,קרית יואל,كيرياس جويل,کریاس جوئیل، نیو یارک,کیریاس جول، نیویورک', 41.3420400, -74.1679200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141318, 'Lackawanna', 'Lackawanna', 'Lackawanna,Lakavona,Limestone Hill,Lokovono,lakawana,lakawana  nyw yark,lakawana  nywywrk,Лакавона,Локовоно,لاكاوانا,لاکاوانا، نیو یارک,لاکاوانا، نیویورک', 42.8256100, -78.8233700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141319, 'Lake Carmel', 'Lake Carmel', '', 41.4614800, -73.6709600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141320, 'Lake Erie Beach', 'Lake Erie Beach', '', 42.6242300, -79.0669800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141321, 'Lake Grove', 'Lake Grove', 'Lake Grove,Lakegrove,Lakeland,Lakeville', 40.8528800, -73.1151100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141322, 'Lake Katrine', 'Lake Katrine', '', 41.9856500, -73.9881900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141323, 'Lake Luzerne', 'Lake Luzerne', 'Lake Luzerne,Luzerne', 43.3128500, -73.8348400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141324, 'Lake Mohegan', 'Lake Mohegan', '', 41.3178700, -73.8462500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141325, 'Lake Placid', 'Lake Placid', 'LKP,Lake Placid,Leik Plesidas,Leikplesida,Lejk Plesid,Lejk-Plehsid,Lejk-Plesid,Leyk-Plesid,Vjoska Lejk-Plehsid,leikeupeullaesideu,leka plesida,lyk blasyd,lyk plasyd  nywywrk,pu lai xi de hu,rekupurashiddo,Вёска Лейк-Плэсід,Лейк Плесид,Лейк-Плесід,Лейк-Плэсид,Лејк Плесид,ليك بلاسيد,لیک پلاسید، نیویورک,لیک پلاسیڈ، نیو یارک,लेक प्लॅसिड,レークプラシッド,普萊西德湖,레이크플래시드', 44.2796200, -73.9819800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141326, 'Lake Pleasant', 'Lake Pleasant', 'lyk blystant,ليك بليستانت,لیک پلیزینٹ، نیو یارک', 43.4709000, -74.4126500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141327, 'Lake Ronkonkoma', 'Lake Ronkonkoma', '', 40.8351000, -73.1312200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141328, 'Lake Success', 'Lake Success', 'Lejk Sukses,lyk sakss,lyk sksyz  nyw yark,lyyq sqss,Лејк Суксес,לייק סקסס,ليك ساكسس,لیک سکسیز، نیو یارک', 40.7706600, -73.7176300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141329, 'Lakeland', 'Lakeland', '', 43.0903400, -76.2404800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141330, 'Lakeview', 'Lakeview', '', 42.4320200, -75.8654700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141331, 'Lakeview', 'Lakeview', 'Lake View,Lakeview,Woodfield', 40.6853800, -73.6526300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141332, 'Lakewood', 'Lakewood', 'Cowings,Lakewood,Lejkvud,Лейквуд', 42.1042200, -79.3331000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141333, 'Lancaster', 'Lancaster', 'De-as-gwah-da-ga-neh,Ga-squen-da-geh,Lancaster,Lankaster,Ланкастер', 42.9006100, -78.6703100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141334, 'Lansing', 'Lansing', 'Lansing,Лансинг', 42.4842400, -76.4799400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141335, 'Larchmont', 'Larchmont', 'Larchmond,Larchmont,Munro''s Neck,lartshmwnt,Ларчмонт,لارتشمونت', 40.9278800, -73.7518000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141336, 'Lattingtown', 'Lattingtown', '', 40.8953800, -73.6009600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141337, 'Laurel', 'Laurel', 'Franklinville,Laurel', 40.9695400, -72.5620300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141338, 'Laurel Hollow', 'Laurel Hollow', 'Laurel Hollow,Laurelton', 40.8567700, -73.4695700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141339, 'Laurelton', 'Laurelton', '', 40.6701900, -73.7465900, 'US', '2017-04-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141340, 'Lawrence', 'Lawrence', 'Lourens,Лоуренс', 40.6156600, -73.7295800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141341, 'Le Roy', 'Le Roy', 'Le Roy,Leroy,Te-car-no-wun-na-da-ne-o', 42.9783900, -77.9841800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141342, 'Levittown', 'Levittown', 'Island Trees,Levittaun,Levittown,lyfytawn,Левиттаун,ليفيتاون', 40.7259300, -73.5142900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141343, 'Lewiston', 'Lewiston', 'L''juiston,lywstwn,Льюистон,ليوستون', 43.1725600, -79.0358800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141344, 'Liberty', 'Liberty', '', 41.8012000, -74.7465500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141345, 'Lido Beach', 'Lido Beach', '', 40.5889900, -73.6254100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141346, 'Lima', 'Lima', 'Brick School House Corner,Lema,Lima,Ska-hase-ga-o,Лима', 42.9047900, -77.6113900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141347, 'Lincoln Park', 'Lincoln Park', '', 41.9506500, -73.9940300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141348, 'Lincolndale', 'Lincolndale', 'Lincolndale,Somers Center,Teed''s Corner,Teed''s Corners', 41.3228700, -73.7181900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141349, 'Lindenhurst', 'Lindenhurst', 'Breslau,Lindenhurst', 40.6867700, -73.3734500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141350, 'Lindley', 'Lindley', '', 42.0284100, -77.1396900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141351, 'Little Falls', 'Little Falls', 'Litl Fols,Litl Folz,Little Falls,Littlefalls,Rock City,Rockton,Ta-la-que-ga,li te fu si shi,lytl falz  nywywrk,lytl fwlz,Литл Фолз,Литл Фолс,ليتل فولز,لیتل فالز، نیویورک,利特佛斯市', 43.0434000, -74.8596000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141352, 'Little Neck', 'Little Neck', 'Little Neck,Littleneck', 40.7628900, -73.7322500, 'US', '2017-04-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141353, 'Little Valley', 'Little Valley', '', 42.2525600, -78.8055900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141354, 'Liverpool', 'Liverpool', 'Little Ireland,Liverpool,Liverpul,T''kah-skwi-ut-ke,lyfrbwl,Ливерпул,ليفربول', 43.1064600, -76.2177000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141355, 'Livingston Manor', 'Livingston Manor', '', 41.9003700, -74.8282200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141356, 'Livonia', 'Livonia', 'Livonia,Livonia Station,Livonija,Ливония', 42.8214500, -77.6686100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141357, 'Lloyd Harbor', 'Lloyd Harbor', 'Lojd Kharbor,lywd harbwr,Лојд Харбор,ليود هاربور', 40.9034300, -73.4598400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141358, 'Lockport', 'Lockport', 'De-o-do-sote,Lockport,Lokport,Lukport,Ta-ga-ote,lak‌pwrt  nywywrk,logpoteu,luo ke bo te shi,lwkbwrt,rokkupoto,Локпорт,Лукпорт,لاک‌پورت، نیویورک,لوكبورت,ロックポート,洛克波特市,록포트', 43.1706100, -78.6903100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141359, 'Locust Valley', 'Locust Valley', 'Buckram,Locust Valley,Lokast Vali,Old Kaintuck Mill,lwkast wly  nywywrk,Локаст Вали,لوکاست ولی، نیویورک', 40.8759300, -73.5970700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141360, 'Long Beach', 'Long Beach', 'Long Beach,Long Bich,Long Bijch,Long-Bich,Longbeach,lang bych  nyw yark,lang bych  nywywrk,longbichi,lwngh bytsh,rongubichi,Лонг Бийч,Лонг Бич,Лонг-Бич,لانگ بیچ، نیو یارک,لانگ بیچ، نیویورک,لونغ بيتش,ロングビーチ,롱비치', 40.5884400, -73.6579100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141361, 'Long Island City', 'Long Island City', 'Blissville,Dutch Kills,Hunter''s Point,Long Island,Long Island City,Long-Ajlend-Siti,Middletown,long-aillaendeusiti,zhang dao shi,Лонг-Айленд-Сити,לאנג איילענד סיטי,لانگ آئلینڈ سٹی,長島市,롱아일랜드시티', 40.7448200, -73.9487500, 'US', '2016-04-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141362, 'Lorenz Park', 'Lorenz Park', '', 42.2637000, -73.7684600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141363, 'Lowville', 'Lowville', 'qryt lwfyl,قرية لوفيل', 43.7867400, -75.4918500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141364, 'Lynbrook', 'Lynbrook', 'Linbruk,Lynbrook,Pearsall''s,Pearsall''s Corners,Pearsallville,lynbrwk,Линбрук,لينبروك', 40.6548300, -73.6718000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141365, 'Lyncourt', 'Lyncourt', '', 43.0814600, -76.1257600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141366, 'Lyons', 'Lyons', 'Lyons,The Forks', 43.0642300, -76.9902500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141367, 'Macedon', 'Macedon', '', 43.0692300, -77.2988700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141368, 'Mahopac', 'Mahopac', 'Lake Mahopac,Mahopac,Mahopac Station', 41.3723200, -73.7334600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141369, 'Malone', 'Malone', 'Malon,Malone,Te-ka-no-ta-ron-we,Tekanata:ronhwe,Tekanatá:ronhwe,qryt malwn,Малон,قرية مالون', 44.8486600, -74.2949000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141370, 'Malverne', 'Malverne', '', 40.6789900, -73.6740200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141371, 'Mamaroneck', 'Mamaroneck', 'Mamaroneck,Mamaronek,Mamoranick,Mamorineck,Mamoronock,Momaronak,Momomaroneck,Momoronack,Momoroneck,Moraneck,mamarwnyk,Мамаронек,مامارونيك', 40.9487100, -73.7326300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141372, 'Manchester', 'Manchester', 'Manchester,Манчестер', 42.9697900, -77.2302600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141373, 'Manhasset', 'Manhasset', 'Cow Neck,Head of Cow Neck,Manhasset,Robinia,Sint Sink,maenhaeses,맨해셋', 40.7978800, -73.6995700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141374, 'Manhasset Hills', 'Manhasset Hills', '', 40.7592700, -73.6798500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141375, 'Manhattan', 'Manhattan', 'Borough of Manhattan,Manatans,Manathans,Manathas,Manathes,Manatte,Manhattan,Manhattanville,Mankhetten,Mannahattan,Menathans,maenhaeteun,man ha dun,manhatn,mnhtn,mæn hat tan,Манхеттен,מנהטן,مانهاتن,แมนฮัตตัน,曼哈顿,맨해튼', 40.7834300, -73.9662500, 'US', '2014-05-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141376, 'Manlius', 'Manlius', 'Liberty Square,Manlius,Manlius Square,Menlijus,man li wu si,manlyws,Менлијус,مانليوس,曼里烏斯', 43.0020100, -75.9768600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141377, 'Manorhaven', 'Manorhaven', 'Beach Haven,Manhasset Isle,Manorhaven,Orchard Beach,Sunny Side', 40.8431600, -73.7148500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141378, 'Manorville', 'Manorville', '', 40.8737100, -72.8078800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141379, 'Manorville', 'Manorville', '', 42.1423100, -74.0359700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141380, 'Marcellus', 'Marcellus', '', 42.9828400, -76.3404900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141381, 'Marbletown', 'Marbletown', 'Marbleton,Marbletown', 41.8834300, -74.1132000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141382, 'Mariners Harbor', 'Mariners Harbor', 'Mariner''s Harbor,Mariners Harbor', 40.6367700, -74.1587500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141383, 'Marion', 'Marion', '', 43.1434000, -77.1891500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141384, 'Marlboro', 'Marlboro', 'Marlboro,Marlborough', 41.6056500, -73.9715300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141385, 'Maspeth', 'Maspeth', 'English Kills,Maspeth,Mespat,Mispat', 40.7231600, -73.9126400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141386, 'Massapequa', 'Massapequa', 'Masapekua,Masapikva,Massapequa,Oysterbay South,South Oyster Bay,masabykwa,Масапекуа,Масапиква,ماسابيكوا', 40.6806600, -73.4742900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141387, 'Massapequa Park', 'Massapequa Park', 'Massapequa Park,Stadt Wurtemberg,Wurtemberg', 40.6803800, -73.4551200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141388, 'Massena', 'Massena', 'Kentsia:ke,Kentsià:ke,MSS,Massena,Messina,Nikentsiake', 44.9281000, -74.8918600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141389, 'Mastic', 'Mastic', 'Forge,Mastic', 40.8020400, -72.8409400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141390, 'Mastic Beach', 'Mastic Beach', '', 40.7667700, -72.8520500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141391, 'Mattituck', 'Mattituck', '', 40.9912100, -72.5342500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141392, 'Mattydale', 'Mattydale', '', 43.0978400, -76.1452000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141393, 'Maybrook', 'Maybrook', '', 41.4839800, -74.2176500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141394, 'Mayville', 'Mayville', '', 42.2539500, -79.5044900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141395, 'McGraw', 'McGraw', 'Mc Graw,McGraw,McGrawville', 42.5961800, -76.0932600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141396, 'McKownville', 'McKownville', '', 42.6839700, -73.8476200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141397, 'Mechanicstown', 'Mechanicstown', 'Mechanic Town,Mechanicstown', 41.4428700, -74.3884900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141398, 'Mechanicville', 'Mechanicville', 'Burrow,Mechanicsville,Mechanicville,Mechanicville Village,Mechanikvil,Mekanikvil,mchanykwyly  nywywrk,mei ka ni ke wei er,myshnysfyl,Меканиквил,Мечаниквил,ميشنيسفيل,مچانیکویلی، نیویورک,梅卡尼克维尔', 42.9028500, -73.6873400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141399, 'Medford', 'Medford', 'Medford,Medford Station,Медфорд', 40.8176000, -73.0001100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141400, 'Medina', 'Medina', 'Diegeh-hoseh,Medajna,Medina,mdyna,mdyna  nywywrk,Медајна,Медина,مدينا,مدینا، نیویورک,مدینہ، نیو یارک', 43.2200600, -78.3869700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141401, 'Melrose', 'Melrose', '', 40.8245500, -73.9104100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141402, 'Melrose Park', 'Melrose Park', '', 42.9086800, -76.5402200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141403, 'Melville', 'Melville', 'Melvil,Melville,Sun-quams,Sweet Hollow,Мелвил', 40.7934300, -73.4151200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141404, 'Menands', 'Menands', 'Menand''s Station,Menands,mynandz,Менандс,ميناندز', 42.6920200, -73.7245600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141405, 'Merrick', 'Merrick', 'Meric,Merikohe,Merrick,Merrik,Moroke,Меррик', 40.6628800, -73.5515200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141406, 'Mexico', 'Mexico', 'Mexico,Mexicoville', 43.4595100, -76.2288200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141407, 'Middle Island', 'Middle Island', '', 40.8842700, -72.9373300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141408, 'Middle Village', 'Middle Village', '', 40.7164900, -73.8812500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141409, 'Middleburgh', 'Middleburgh', 'Middleburg,Middleburgh,Middletown,Weisers Dorp', 42.5986900, -74.3329200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141410, 'Middleport', 'Middleport', '', 42.7906200, -75.5599000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141411, 'Middleport', 'Middleport', 'Middleport,Te-ka-on-do-duk', 43.2125600, -78.4764100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141412, 'Middletown', 'Middletown', 'Midl Taun,Midltaun,midorutaun,mydl tawn  nywywrk,mydltawn,Мидл Таун,Мидлтаун,ميدلتاون,مڈل ٹاؤن، اورنج کاؤنٹی، نیو یارک,میدل تاون، نیویورک,ミドルタウン', 41.4459300, -74.4229300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141413, 'Midland Beach', 'Midland Beach', '', 40.5731600, -74.0945900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141414, 'Mill Neck', 'Mill Neck', '', 40.8870400, -73.5551200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141415, 'Millbrook', 'Millbrook', 'Milbruk,mylbwrwk,Милбрук,ميلبوروك', 41.7850900, -73.6940200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141416, 'Miller Place', 'Miller Place', 'Miller Place,Miller''s Place,Millerplace', 40.9598200, -72.9962100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141417, 'Milton', 'Milton', 'Mil''ton,Мильтон', 43.0336900, -73.8526200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141418, 'Milton', 'Milton', 'Mil''ton,Мильтон', 41.6598200, -73.9570800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141419, 'Mineola', 'Mineola', 'Haviland,Mineola,Miniola,mineora,miniolla,mynwla  nywywrk,mynywla,mynywla  nyw yark,Миниола,مينيولا,مینولا، نیویورک,مینیولا، نیو یارک,ミネオラ,미니올라', 40.7492700, -73.6406800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141420, 'Minetto', 'Minetto', '', 43.3981200, -76.4774400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141421, 'Mineville', 'Mineville', '', 44.0928300, -73.5181800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141422, 'Minoa', 'Minoa', '', 43.0761800, -76.0007500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141423, 'Mohawk', 'Mohawk', '', 43.0114600, -75.0040400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141424, 'Monroe', 'Monroe', 'Monro,Монро', 41.3306500, -74.1868100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141425, 'Monsey', 'Monsey', 'Kakiat,Monsey,Monsey Depot,Monsi,monzei,mwnsy,Монси,מאנסי,מונסי,モンゼイ', 41.1112100, -74.0684800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141426, 'Montauk', 'Montauk', 'Gorad Montak,MTP,Montok,meng tuo ke,Горад Монтак,Монток,蒙托克', 41.0359400, -71.9545100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141427, 'Montebello', 'Montebello', 'Montebello,Montebelo,mwnybylw,Монтебелло,Монтебело,مونيبيلو', 41.1359300, -74.1184800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141428, 'Montgomery', 'Montgomery', 'MGJ,Montgomeri,Монтгомери', 41.5275900, -74.2368200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141429, 'Monticello', 'Monticello', 'MSV,Montichelo,Montiselo,mwntysylw,Монтисело,Монтичело,מאנטיסעלא,مونتيسيلو', 41.6556500, -74.6893300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141430, 'Montour Falls', 'Montour Falls', 'Catharinetown,Chequegah,Havana,Montour Falls,Montour''s Falls', 42.3473000, -76.8452400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141431, 'Montrose', 'Montrose', 'Centreville,East Haverstraw,Lyell,Montrose', 41.2523200, -73.9315300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141432, 'Moravia', 'Moravia', 'Moravia,Owasco Flats', 42.7125700, -76.4216000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141433, 'Moriches', 'Moriches', '', 40.8073200, -72.8212100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141434, 'Morris Heights', 'Morris Heights', '', 40.8498200, -73.9198600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141435, 'Morrisania', 'Morrisania', '', 40.8292700, -73.9065300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141436, 'Morrisonville', 'Morrisonville', '', 44.6931000, -73.5620800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141437, 'Morrisville', 'Morrisville', 'Morris Flats,Morrisville', 42.8986800, -75.6401800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141438, 'Mott Haven', 'Mott Haven', '', 40.8089900, -73.9229100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141439, 'Mount Ivy', 'Mount Ivy', 'Gurnee''s Corners,Mount Ivy', 41.1867600, -74.0348600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141440, 'Mount Kisco', 'Mount Kisco', 'Maunt Kisko,Mount Kisco,Mount Kisko,New Castle Corner,mawnt kyskw,Маунт Киско,מאונט קיסקא,ماونت كيسكو', 41.2042600, -73.7270800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141441, 'Mount Morris', 'Mount Morris', 'Allen''s Hill,Mount Morris,Richmond Hill,Sanungewage,Sho-no-jo-waah-geh', 42.7256200, -77.8741700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141442, 'Mount Sinai', 'Mount Sinai', 'Mount Sinai,Mount Vernon,Non-o-wan-tuck,Old Man''s Harbor,Old Mans,Ould Mans', 40.9470400, -73.0295500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141443, 'Mount Vernon', 'Mount Vernon', 'Hutchinson''s,Maunt Vernon,Maunt-Vernon,Mount Vernon,fu nong shan,mant wrnwn  nywywrk,maunteubeoneon,mauntobanon,mwnt fyrnwn,Маунт Вернон,Маунт-Вернон,מאונט ורנון,ماؤنٹ ورنن، نیو یارک,مانت ورنون، نیویورک,مونت فيرنون,マウントバーノン,弗農山,마운트버넌', 40.9126000, -73.8370800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141444, 'Mountain Lodge Park', 'Mountain Lodge Park', 'Mountain Lodge,Mountain Lodge Park', 41.3884300, -74.1418100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141445, 'Munsey Park', 'Munsey Park', '', 40.7987100, -73.6798500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141446, 'Munsons Corners', 'Munsons Corners', '', 42.5822900, -76.2091000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141447, 'Myers Corner', 'Myers Corner', 'Myers Corner,Myers Corners', 41.6062000, -73.8729100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141448, 'Muttontown', 'Muttontown', '', 40.8239900, -73.5476300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141449, 'Nanuet', 'Nanuet', 'Clarkstown,Clarkstown Station,Nanuet,Нанует', 41.0887100, -74.0134700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141450, 'Napanoch', 'Napanoch', 'Napanoch,Napanock,Napenagh', 41.7439800, -74.3715400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141451, 'Naples', 'Naples', 'Naples,Neapol'',Nundawao,Watkinstown,Неаполь', 42.6153500, -77.4024900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141452, 'Nassau', 'Nassau', 'Nassau,Union Village', 42.5159100, -73.6101200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141453, 'Nedrow', 'Nedrow', '', 42.9750700, -76.1413100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141454, 'Neponsit', 'Neponsit', '', 40.5717700, -73.8615200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141455, 'Nesconset', 'Nesconset', '', 40.8520400, -73.1540000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141456, 'New Cassel', 'New Cassel', '', 40.7589900, -73.5695700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141457, 'New City', 'New City', 'Clarkstown,New City,New Hempstead,Nju Siti,nyw syty,Њу Сити,نيو سيتي,ニュー・シティ', 41.1476000, -73.9893100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141458, 'New Dorp', 'New Dorp', 'New Dorp,Newdorp,Niew Dorp', 40.5739900, -74.1159800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141459, 'New Dorp Beach', 'New Dorp Beach', '', 40.5653800, -74.1029200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141460, 'New Hartford', 'New Hartford', 'Chegaquatka,New Hartford', 43.0734000, -75.2876700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141461, 'New Hyde Park', 'New Hyde Park', 'New Hyde Park,Nju Khajd Park,Plainville,nyw hayd bark,Њу Хајд Парк,نيو هايد بارك,نیو ہائڈ پارک، نیو یارک', 40.7351000, -73.6879100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141462, 'New Brighton', 'New Brighton', '', 40.6423300, -74.0929200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141463, 'New Paltz', 'New Paltz', 'New Paltz,Newpaltz,Nouveau Palatinat', 41.7475900, -74.0868100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141464, 'New Rochelle', 'New Rochelle', 'N''ju-Roshel'',N''ju-Roshell,New Rochelle,Nju Roshel,Njuroshel,Nouvelle-Rochelle,Nueva Rochelle,nyulosyel,nyurosheru,nyw rashl  nywywrk,nyw rwchyl  nywyark,nyw rwsl,nyw rwtshyl,xin luo xie er,Њу Рошел,Нью-Рошелл,Нью-Рошель,Нюрошел,ניו רושל,نيو روتشيل,نیو راشل، نیویورک,نیو روچیل، نیویارک,ニューロシェル,新羅謝爾,뉴로셸', 40.9114900, -73.7823500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141465, 'New Springville', 'New Springville', 'Carle''s Neck,New Springville,Springville', 40.5934400, -74.1632000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141466, 'New Square', 'New Square', 'Nju Skver,nyw skwyr,nyw skwyyr  nyw yark,nyw sqwwr,Њу Сквер,ניו סקוור,שיכון סקווירא,نيو سكوير,نیو سکوئیر، نیو یارک', 41.1395600, -74.0294200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141467, 'New Windsor', 'New Windsor', 'New Windsor,New Windsor Center,Nju Vinsor,nyw wyndswr,Њу Винсор,نيو ويندسور', 41.4767600, -74.0237500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141468, 'New York City', 'New York City', 'Aebura,Bandar Raya New York,Big Apple,Cathair Nua Eabhraic,City of New York,Eabhraig Nuadh,Efrog Newydd,Evrek Nowydh,Ga-no-no,Kanon:no,Kanono,Kanón:no,Kota New York,Lungsod ng New York,N''ju-Jork,NY,NYC,Nea Yorke,Nei Yarrick Schtadt,Neu Amsterdam,Neu Jorck,New Amsterdam,New Orange,New Yorc,New York,New York City,New York Stad,New York borg,New York kenti,New York-borg,New Yorke,New Yorku,Niujorkas,Nju Jork,Njujork,Nouvelle Yorck,Nouvieau York,Nov-Jorko,Nova Amsterda,Nova Iorque,Nova York,Nova-York,Novjorko,Novum Eboracum,Nowy Jork,Nua-Eabhrac,Nueva York,Nujorka,Nyja Jorvik,Nyu York Shehiri,Nòva York,Nýja Jórvík,Thanh pho New York,The Big Apple,Thành phố New York,York Berri,manhattan,n''yuyorka,ni''u iyarka siti,niu yue,niu yue shi,niyuyark nakaram,nkhr niwyxrk,nyuyog,nyuyog si,nyuyoku,nyw ywrq,nywywrk,Ņujorka,Νέα Υόρκη,Њу Јорк,Њујорк,Нью-Ёрк,Нью-Йорк,Ню Йорк,ניו יארק,ניו יורק,ניו־יאָרק,نيويورك,نیویارک شہر,نیویورک,न्यूयॉर्क,নিউ ইয়র্ক সিটি,நியூயார்க் நகரம்,นครนิวยอร์ก,ნიუ-იორკი,ニューヨーク,マンハッタン,紐約市,纽约,뉴욕,뉴욕 시', 40.7142700, -74.0059700, 'US', '2015-02-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141469, 'New York Mills', 'New York Mills', 'New York Mills,New York Upper Mills', 43.1053500, -75.2912800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141470, 'Newark', 'Newark', 'Arcadia,East Newark,Lockville,Miller''s Basin,N''juark,Newark,Newark - Arcadia,Njuark,nywark,nywark  nyw yark,Њуарк,Ньюарк,نيوارك,نیوآرک، نیو یارک', 43.0467300, -77.0952500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141471, 'Newburgh', 'Newburgh', 'N''juberg,N''juburg,Njuburg,SWF,nyubagu,nyubeogeu,nywbwrg  nywywrk,nywbwrgh,Њубург,Ньюберг,Ньюбург,Нюбург,Нюбърг,نيوبورغ,نیوبورگ، نیویورک,ニューバーグ,뉴버그', 41.5034300, -74.0104200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141472, 'Newfane', 'Newfane', 'Charlotte,Charlottesville,New Fane,Newfane,Njufejn,nywfan,Њуфејн,نيوفان', 43.2867200, -78.7103100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141473, 'Niagara Falls', 'Niagara Falls', 'IAG,Manchester,Najagara Fols,Niagara Falls,Niagara-Folls,Niagara-Fols,Niagaro Folz,Ohnia:kara,Ohnià:kara,naiagalapolseu,naiagaraforuzu,ni ya jia la pu bu cheng,nyagara falz  nywywrk,nyagra falz  nyw yark,nyajara fwlz,Најагара Фолс,Ниагара-Фолс,Ниагаро Фолз,Ніагара-Фоллс,نياجارا فولز,نیاگارا فالز، نیویورک,نیاگرا فالز، نیو یارک,ナイアガラフォールズ,尼亞加拉瀑布城,나이아가라폴스', 43.0945000, -79.0567100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141474, 'Niskayuna', 'Niskayuna', 'Co-nes-ta-gi-o-ne,Connestigune,Niskayuna,naynyka,ناينيكا', 42.7798000, -73.8456800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141475, 'Nissequogue', 'Nissequogue', 'Nissequogne,Nissequogue,Nissequoque,nyskwghw,نيسكوغو', 40.9039900, -73.1978900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141476, 'Niverville', 'Niverville', 'Kinderhook Station,Niverville', 42.4409200, -73.6609500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141477, 'Norfolk', 'Norfolk', 'Ka-na-ta-se-ke,Kanatase:ke,Kanatasè:ke,Norfolk,Норфолк', 44.8008900, -74.9910300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141478, 'North Amityville', 'North Amityville', '', 40.6976000, -73.4251200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141479, 'North Babylon', 'North Babylon', '', 40.7164900, -73.3217900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141480, 'North Bay Shore', 'North Bay Shore', '', 40.7362100, -73.2626200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141481, 'North Bellmore', 'North Bellmore', '', 40.6914900, -73.5334600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141482, 'North Bellport', 'North Bellport', '', 40.7742700, -72.9428800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141483, 'North Boston', 'North Boston', '', 42.6856200, -78.7767000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141484, 'North Collins', 'North Collins', 'Kerr''s Corners,North Collins,Rose''s Corner', 42.5953400, -78.9411500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141485, 'North Elba', 'North Elba', 'North Elba,Plains of Abraham,nwrth alba,نورث إلبا', 44.2433800, -73.9543100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141486, 'North Gates', 'North Gates', '', 43.1764500, -77.7013900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141487, 'North Great River', 'North Great River', '', 40.7473200, -73.1698400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141488, 'North Hills', 'North Hills', '', 40.7809300, -73.6765200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141489, 'North Lindenhurst', 'North Lindenhurst', '', 40.7142700, -73.3815100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141490, 'North Massapequa', 'North Massapequa', '', 40.7009300, -73.4620700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141491, 'North Merrick', 'North Merrick', '', 40.6912100, -73.5631800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141492, 'North New Hyde Park', 'North New Hyde Park', 'North New Hyde Park,Plattsville', 40.7431600, -73.6931900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141493, 'North Patchogue', 'North Patchogue', '', 40.7870400, -73.0090000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141494, 'North Sea', 'North Sea', '', 40.9328800, -72.4142500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141495, 'North Syracuse', 'North Syracuse', '', 43.1347900, -76.1299200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141496, 'North Tonawanda', 'North Tonawanda', 'Kiohnawen:''en,Kiohnawén:''en,N. Tonawanda,Nort Taunovondo,Nort Tonavonda,North Tonawanda,nosutonawanda,nwrt twnawanda  nywywrk,nwrth twnawanda,Норт Тауновондо,Норт Тонавонда,نورت توناواندا، نیویورک,نورث توناواندا,ノーストナワンダ', 43.0386700, -78.8642000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141497, 'North Valley Stream', 'North Valley Stream', '', 40.6851000, -73.7018000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141498, 'North Wantagh', 'North Wantagh', '', 40.6934300, -73.5076300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141499, 'Northport', 'Northport', 'Cowharbor,Great Cow Harbor,Northport,Nortport,nwrthbwrt,Нортпорт,نورثبورت', 40.9009300, -73.3431700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141500, 'Northumberland', 'Northumberland', 'Nortumberlend,Нортумберленд', 43.1273000, -73.5881700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141501, 'Northville', 'Northville', '', 43.2256300, -74.1720800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141502, 'Northville', 'Northville', 'Northville,Success', 40.9701000, -72.6189800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141503, 'Northwest Harbor', 'Northwest Harbor', '', 41.0098200, -72.2211900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141504, 'Norwich', 'Norwich', 'Ganasowadi,Noridzh,Norvich,Norwich,OIC,narwych,nwrwytsh,nwrych  nywywrk,Норвич,Норидж,نارویچ,نورويتش,نوریچ، نیویورک', 42.5311800, -75.5235100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141505, 'Norwood', 'Norwood', 'North Potsdam,Norwood,Potsdam Junction,Potsdam Station,Racquetteville,Raquetteville', 44.7514500, -74.9943600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141506, 'Noyack', 'Noyack', '', 40.9956600, -72.3411900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141507, 'Nunda', 'Nunda', '', 42.5795100, -77.9425000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141508, 'Nyack', 'Nyack', 'Najak,naiakku,nayak,Најак,ناياك,ナイアック', 41.0906500, -73.9179100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141509, 'Oakdale', 'Oakdale', '', 42.2512000, -73.7801300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141510, 'Oakdale', 'Oakdale', 'Oakdale,Oakdale Station,Oukdejl,Оукдејл', 40.7439900, -73.1387200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141511, 'Oakfield', 'Oakfield', 'Caryville,Gau-dak,Oakfield,Plain Brook,Te-car-da-na-duk', 43.0658900, -78.2697400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141512, 'Oakwood', 'Oakwood', '', 40.5639900, -74.1159800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141513, 'Oceanside', 'Oceanside', 'Christian Hook,Ocean Side,Oceanside,Oceanville', 40.6387100, -73.6401300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141514, 'Ogdensburg', 'Ogdensburg', 'Maple City,O-swa-gatch,O-swe-gatch-ie,OGS,Ogdenburg Village,Ogdensberg,Ogdensburg,Ogdensburgh,Sewe:katsi,Sewé:katsi,Soegasti,Sweegassie,Swegaachey,Swegage,Swegatchie,Swegatsky,agdns bwrg  nywywrk,awghdynsbwrgh,Огденсберг,Огденсбург,Оґденсбург,أوغدينسبورغ,اگدنس بورگ، نیویورک', 44.6942300, -75.4863400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141515, 'Olcott', 'Olcott', 'Kempville,Olcott', 43.3378300, -78.7147600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141516, 'Old Bethpage', 'Old Bethpage', '', 40.7626000, -73.4531800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141517, 'Old Brookville', 'Old Brookville', '', 40.8320400, -73.6048500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141518, 'Old Westbury', 'Old Westbury', 'Old Vestberi,Old Westbury,Westbury,awld wstbary,jiu wei si te bo li,Олд Вестбери,أولد وستباري,舊韋斯特伯里', 40.7887100, -73.5995700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141519, 'Olean', 'Olean', 'Hamilton,Hesoh,OLE,Olean,Olean Point,Olijan,Oulon,awlan  nywywrk,awlyn,Олијан,Оулон,أولين,اولان، نیویورک', 42.0775600, -78.4297400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141520, 'Oneida', 'Oneida', 'De-ose-la-ta-gaat,Onajda,Oneida,Ounido,awnyda,awnyda  nywywrk,Онајда,Оунидо,أونيدا,اونیدا، نیویورک', 43.0925700, -75.6512900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141521, 'Oneonta', 'Oneonta', 'Klipnockie,ONH,Oneonta,Onionta,Otego,Ouninto,awnynta  nywywrk,awnywnta,Онеонта,Онионта,Оунинто,أونيونتا,اونینتا، نیویورک', 42.4528600, -75.0637700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141522, 'Ontario', 'Ontario', 'Ontario,Ontário,awntaryw,Онтарио,أونتاريو', 43.2209000, -77.2830400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141523, 'Orange Lake', 'Orange Lake', 'New Grange,Orange Lake', 41.5398200, -74.0982000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141524, 'Orangeburg', 'Orangeburg', 'Orangburgh,Orangeburg', 41.0464900, -73.9495800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141525, 'Orchard Park', 'Orchard Park', 'East Hamburg,Orchard Park,awrtshard bark,Орчард Парк,أورتشارد بارك', 42.7675600, -78.7439200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141526, 'Oriskany', 'Oriskany', '', 43.1572900, -75.3326700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141527, 'Ossining', 'Ossining', 'Hunters Landing,Mount Pleasant,Ossining,Sing Sing', 41.1628700, -73.8615200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141528, 'Oswego', 'Oswego', 'Chonaquen,Choneguen,Choueguen,Osuigo,Osvigo,Oswego,Ousvego,Sowego,awswyghw,azwygw  nywywrk,osuu~ego,Освиго,Освіґо,Осуиго,Оусвего,أوسويغو,ازویگو، نیویورک,オスウェゴ', 43.4553500, -76.5105000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141529, 'Otisville', 'Otisville', '', 41.4734300, -74.5384900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141530, 'Owego', 'Owego', 'Ah-wa-ga,Owego,qryt awyghw,قرية أويغو', 42.1034100, -76.2621500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141531, 'Oxford', 'Oxford', 'Oksford,Oxford,Sodeahlowanake,Оксфорд', 42.4420200, -75.5976900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141532, 'Oyster Bay', 'Oyster Bay', '', 40.8656500, -73.5320700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141533, 'Oyster Bay Cove', 'Oyster Bay Cove', '', 40.8709300, -73.5109600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141534, 'Ozone Park', 'Ozone Park', 'awzwn park  kwyynz,اوزون پارک، کوئینز', 40.6767700, -73.8437500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141535, 'Painted Post', 'Painted Post', 'Painted Post,Tecarnaseteoah', 42.1620200, -77.0941400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141536, 'Palenville', 'Palenville', '', 42.1745300, -74.0201400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141537, 'Palmyra', 'Palmyra', 'Ganagweh,Ganargwa,Palmyra,balmyra,بالميرا', 43.0639500, -77.2333200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141538, 'Parkchester', 'Parkchester', '', 40.8389900, -73.8604100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141539, 'Patchogue', 'Patchogue', 'Milltown,Pachog,Patchogue,batshwghw,Пачог,باتشوغو', 40.7656500, -73.0151100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141540, 'Pawling', 'Pawling', 'Centerville,Gorsetown,Kingston,Pawling,Pawling Center,Pawling Station,Pawling Station P O', 41.5620400, -73.6026300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141541, 'Peach Lake', 'Peach Lake', '', 41.3675900, -73.5779000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141542, 'Pearl River', 'Pearl River', 'Middletown,Muddy Creek,Pearl River,Perl River,Перл Ривер,パール・リバー', 41.0589900, -74.0218100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141543, 'Peekskill', 'Peekskill', 'Peekskill,Peekskill Landing,Pijkskil,Pikskil,Pikskill,bykskyl,pigseukil,pykskyl  nywywrk,Пийкскил,Пикскил,Пикскилл,بيكسكيل,پیکسکیل، نیویورک,픽스킬', 41.2900900, -73.9204200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141544, 'Pelham', 'Pelham', 'North Pelham,Pelham', 40.9098200, -73.8079100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141545, 'Pelham Manor', 'Pelham Manor', '', 40.8953800, -73.8070800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141546, 'Penn Yan', 'Penn Yan', 'Pen Jan,bn yan,Пен Јан,بن يان', 42.6609000, -77.0538600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141547, 'Perry', 'Perry', 'Columbia,Nineveh,Perry,Shacksburg', 42.7156200, -78.0055600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141548, 'Perth', 'Perth', '', 43.0175700, -74.1940200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141549, 'Peru', 'Peru', 'Peru,byrw,Перу,بيرو', 44.5783800, -73.5268000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141550, 'Peru', 'Peru', '', 43.0822900, -76.4079900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141551, 'Phelps', 'Phelps', 'Phelps,Sullivan,Vienna', 42.9575600, -77.0574700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141552, 'Philadelphia', 'Philadelphia', 'Filadel''fija,Philadelphia,Quaker Settlement,Филадельфия', 44.1545000, -75.7088200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141553, 'Philmont', 'Philmont', 'Factory Hill,Philmont', 42.2484200, -73.6531800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141554, 'Phoenix', 'Phoenix', 'Finiks,Kuh-na-ta-ha,Phoenix,Three River Rifts,Финикс', 43.2311800, -76.3007600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141555, 'Piermont', 'Piermont', 'Bogerttown,Piermont,Pirmont,Tapan Landing,Tappan Landing,Tappan Slote,Taulman Landing,Taulman''s Landing,byrmwnt,Пирмонт,بيرمونت', 41.0420400, -73.9181900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141556, 'Pine Bush', 'Pine Bush', 'Crawford,Pine Bush,Pinebush', 41.6081500, -74.2990400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141557, 'Pine Plains', 'Pine Plains', '', 41.9798100, -73.6559600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141558, 'Pittsford', 'Pittsford', 'Pitsford,Питсфорд', 43.0906200, -77.5150000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141559, 'Plainedge', 'Plainedge', '', 40.7173200, -73.4837400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141560, 'Plainview', 'Plainview', 'Manetto Hill,Plainview,Plejnvju,blynfyw,Плејнвју,بلينفيو', 40.7764900, -73.4673500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141561, 'Plandome', 'Plandome', 'Plandome,Planus Domus', 40.8067700, -73.7034600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141562, 'Plandome Heights', 'Plandome Heights', '', 40.8026000, -73.7043000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141563, 'Plattekill', 'Plattekill', 'Plattekil,Plattekill,Platterkill,Pleasant Valley,The Valley', 41.6175900, -74.0759800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141564, 'Plattsburgh', 'Plattsburgh', 'Etsienhne,Etsiénhne,PBG,PLB,Platsbourg,Platsburg,Plattsburg,Plattsburgh,Sen-hah-lo-ne,Son-Halonek,blatsbwrgh,plats bwrg  nywywrk,pu la ci bao,purattsubagu,Платсбург,Платтсбург,بلاتسبورغ,پلاتس بورگ، نیویورک,プラッツバーグ,普拉茨堡', 44.6994900, -73.4529100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141565, 'Pleasant Valley', 'Pleasant Valley', '', 41.7445400, -73.8212400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141566, 'Pleasantville', 'Pleasantville', 'Clark''s Corner,Clark''s Corners,Mechanicsville,Pleasantville,Plezantvil,Plezuntvil,blysantfyl,Плезантвил,Плезънтвил,بليسانتفيل', 41.1328700, -73.7926300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141567, 'Poestenkill', 'Poestenkill', '', 42.6903600, -73.5645600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141568, 'Point Lookout', 'Point Lookout', '', 40.5923300, -73.5806800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141569, 'Pomona', 'Pomona', 'Pomona,Помона', 41.1670400, -74.0432000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141570, 'Port Byron', 'Port Byron', 'Bucksville,Port Byron', 43.0345100, -76.6238300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141571, 'Port Chester', 'Port Chester', 'Port Chester,Portchester,Saw Log Swamp,Saw Pit,Saw Pitts,Sawpits,bwrt tshystyr,Порт Честер,بورت تشيستير,پورٹ چیسٹر، نیو یارک', 41.0017600, -73.6656800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141572, 'Port Dickinson', 'Port Dickinson', 'Carmansville,Port Dickinson', 42.1334100, -75.8963100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141573, 'Port Ewen', 'Port Ewen', '', 41.9053700, -73.9762500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141574, 'Port Henry', 'Port Henry', 'Port Khenri,bwrt hnry,Порт Хенри,بورت هنري', 44.0483900, -73.4598500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141575, 'Port Jefferson', 'Port Jefferson', 'Drowned Meadow,Drowned Meadows,Port DZeferson,Port Jefferson,So-was-sett,Sowassett,bwrt jfrswn,jie fei xun gang,Порт Џеферсон,بورت جفرسون,杰斐遜港', 40.9464900, -73.0692700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141576, 'Port Jefferson Station', 'Port Jefferson Station', 'Echo,Port Jefferson,Port Jefferson Station', 40.9253800, -73.0473300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141577, 'Port Jervis', 'Port Jervis', 'Carpenter''s Point,Mahackamack,Mahackemeck,Port DZervis,Port Jervis,bwrt jyrfys,pwrt jrwys  nywywrk,Порт Џервис,Порт Ҷервис,פארט דזשערוויס,بورت جيرفيس,پورت جرویس، نیویورک', 41.3750900, -74.6926600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141578, 'Port Morris', 'Port Morris', '', 40.8014900, -73.9095800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141579, 'Port Richmond', 'Port Richmond', '', 40.6331600, -74.1365300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141580, 'Port Washington', 'Port Washington', 'Cow Bay,Port Voshington,Port Washington,Sinsinck,pwrt washyngtwn  nywywrk,Порт Вошингтон,پورت واشینگتون، نیویورک', 40.8256600, -73.6981900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141581, 'Port Washington North', 'Port Washington North', '', 40.8448200, -73.7018000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141582, 'Portland', 'Portland', 'Centerville,Chatacouit,Portland,Portlend,Портленд', 42.3797800, -79.4675500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141583, 'Potsdam', 'Potsdam', 'Potsdam,Potsdam  New York,Te-wa-ten-e-ta-ren-ies,Tsi Tewate''nehtararenie''s,Tsi Tewate''nehtararénie''s,pwtsdam,qryt bwtsdam,قرية بوتسدام,پوتسدام', 44.6697800, -74.9813100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141584, 'Poughkeepsie', 'Poughkeepsie', 'POU,Pochkeepsie,Pokipsi,Poughkeepsie,Pougkipsi,Poukipzi,Pukipsij,bkbsy,bo qi pu xi,pokibsi,pokipushi,pwgkypsy  nywywrk,Покипси,Поугкипси,Поукипзи,Поукіпзі,Пъкипсий,بكبسي,پوگکیپسی، نیویورک,ポキプシー,波啟浦夕,포킵시', 41.7003700, -73.9209700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141585, 'Pound Ridge', 'Pound Ridge', 'Pound Ridge,Poundridge', 41.2087100, -73.5748500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141586, 'Pulaski', 'Pulaski', 'Pulaski,Richland', 43.5670100, -76.1277000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141587, 'Purchase', 'Purchase', 'Harrison''s Purchase,Harrisons Purchase,Purchase,The Purchase,Thomasville', 41.0409300, -73.7145700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141588, 'Putnam Lake', 'Putnam Lake', '', 41.4620400, -73.5462400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141589, 'Queens Village', 'Queens Village', 'Brushville,Queens,Queens Village', 40.7267700, -73.7415200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141590, 'Queens', 'Queens', 'Borough of Queens,Queens', 40.6814900, -73.8365200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141591, 'Queensbury', 'Queensbury', 'kuinzuberi,クイーンズベリー', 43.3772900, -73.6131700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141592, 'Randolph', 'Randolph', 'Randol''f,Рандольф', 42.1620100, -78.9753200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141593, 'Ransomville', 'Ransomville', 'Quade''s Corners,Ransomville', 43.2386700, -78.9097600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141594, 'Rapids', 'Rapids', '', 43.0983900, -78.6408600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141595, 'Ravena', 'Ravena', 'Coeymans Junction,Ravena', 42.4684100, -73.8162400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141596, 'Red Hook', 'Red Hook', 'Lower Red Hook,Red Hook,Red Khuk,Redhook,Ред Хук', 41.9950900, -73.8754100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141597, 'Red Oaks Mill', 'Red Oaks Mill', '', 41.6556500, -73.8748600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141598, 'Rego Park', 'Rego Park', 'Rigo-Park,lei ge gong yuan,rygw park,rygw park  kwyynz,Риго-Парк,ریگو پارک,ریگو پارک، کوئینز,レゴ・パーク地区,雷哥公園', 40.7264900, -73.8526400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141599, 'Rensselaer', 'Rensselaer', 'Bath-on-the-Hudson,East Albany,Greenbusch,Greenbush,Renselaer,Rensler,Rensselaer,rnslyr  nywywrk,rynsylar,Ренселаер,Ренслер,رنسلیر، نیویورک,رينسيلار', 42.6425800, -73.7429000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141600, 'Rhinebeck', 'Rhinebeck', '', 41.9267600, -73.9126400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141601, 'Richfield Springs', 'Richfield Springs', 'Richfild Springs,rytshfyld sbrynghz,Ричфилд Спрингс,ريتشفيلد سبرينغز', 42.8534100, -74.9854300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141602, 'Richland', 'Richland', 'Richland,Richland Station', 43.5695100, -76.0477000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141603, 'Richmond Hill', 'Richmond Hill', '', 40.6998300, -73.8312500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141604, 'Ridge', 'Ridge', 'Randallville,Ridge,Ridgeville', 40.8939900, -72.8959400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141605, 'Riverdale', 'Riverdale', 'Riverdale,Riverdale-On-Hudson', 40.9005600, -73.9063900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141606, 'Riverhead', 'Riverhead', 'A-que-bogue,Occapogue,Riverhead,ribaheddo,リバーヘッド', 40.9170400, -72.6620400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141607, 'Riverside', 'Riverside', 'Riversajd,Риверсайд', 40.8812100, -72.6778700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141608, 'Rochester', 'Rochester', 'Ga-sko-sa-ga,Gaskosago,ROC,Rocestera,Rocesteris,Rocestro,Rochester,Rochesterville,Rochestur,Roffa,Rotsester,Roĉestro,Ročestera,Ročesteris,locheseuteo,luo che si te,racestara,rocestar,rocestara,rochesuta,rwchstr  nywywrk,rwtshstr,rwzstr,rx ches texr,Ρότσεστερ,Рочестер,Рочестър,רוצסטר,روتشستر,روچستر، نیویورک,روچسٹر,روچیسٹر، نیو یارک,रॉचेस्टर,रोचेस्टर,রচেস্টার,రోచెస్టర్,รอเชสเตอร์,ロチェスター,羅徹斯特,로체스터', 43.1547800, -77.6155600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141609, 'Rock Hill', 'Rock Hill', 'Rock Hill,Rockhill', 41.6259300, -74.5976600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141610, 'Rockaway Point', 'Rockaway Point', '', 40.5606600, -73.9151400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141611, 'Rockville Centre', 'Rockville Centre', 'Rockville,Rockville Center,Rockville Centre,Rokvil Center,rwkfyl syntr,rwkwyl sntr  nywywrk,Роквил Центер,روكفيل سينتر,روکویل سنتر، نیویورک', 40.6587100, -73.6412400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141612, 'Rocky Point', 'Rocky Point', 'Rocky Point,Rockypoint', 40.9526000, -72.9253800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141613, 'Roessleville', 'Roessleville', '', 42.6950800, -73.8070700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141614, 'Rome', 'Rome', 'Lynchville,Rim,Roma,Rome,Roum,lom,luo ma,rm  nywywrk,romu,rwm  nyw yark,rwmy,Рим,Роум,رم، نیویورک,روم، نیو یارک,رومي,ローム,羅馬,롬', 43.2128500, -75.4557300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141615, 'Ronkonkoma', 'Ronkonkoma', 'Ronkonkoma,rwnkwnkwma,Ронконкома,رونكونكوما', 40.8153800, -73.1123300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141616, 'Roosevelt', 'Roosevelt', '', 40.6787100, -73.5890200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141617, 'Rosebank', 'Rosebank', '', 40.6139900, -74.0662500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141618, 'Rosedale', 'Rosedale', 'Foster''s Meadow,Rosedale', 40.6620500, -73.7354100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141619, 'Roslyn', 'Roslyn', 'Hempstead Harbor,Roslyn,Rozlin,rwslyn,Розлин,روسلين', 40.7998200, -73.6509600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141620, 'Roslyn Estates', 'Roslyn Estates', '', 40.7942700, -73.6604100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141621, 'Roslyn Harbor', 'Roslyn Harbor', 'Rozlin Kharbor,rwslyn harbwr,Розлин Харбор,روسلين هاربور', 40.8164900, -73.6370700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141622, 'Roslyn Heights', 'Roslyn Heights', '', 40.7887100, -73.6473500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141623, 'Rossville', 'Rossville', 'Blazing Star,Rossville', 40.5556600, -74.2134800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141624, 'Rotterdam', 'Rotterdam', '', 42.7870200, -73.9709600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141625, 'Rouses Point', 'Rouses Point', 'RSX,Rauzes Pojnt,Rouse Point,Rouse''s Point,Rouses Point,rwss bwynt,Раузес Појнт,روسس بوينت', 44.9939300, -73.3648600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141626, 'Rye', 'Rye', 'Hastings,Raj,Roj,Rye,ry,way  nywywrk,Рај,Рой,ري,وای، نیویورک', 40.9806500, -73.6837400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141627, 'Rye Brook', 'Rye Brook', 'Raj Bruk,ray brwk,Рај Брук,راي بروك', 41.0192600, -73.6834600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141628, 'Sackets Harbor', 'Sackets Harbor', 'Gahuagojetwadaalote,Sacket Harbor,Sacket''s Harbor,Sackets Harbor,Sackets Harbour,Sackett''s Harbor,Sacketts Harbor,Sakits Kharbor,Сакитс Харбор', 43.9461700, -76.1190900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141629, 'Sag Harbor', 'Sag Harbor', 'Harbor of Sagg,Sag Harbor,Sag Kharbor,Sagaponack Harbor,Sagg Harbor,sa ge gang,sagh harbwr,Саг Харбор,ساغ هاربور,سگ ہاربر، نیو یارک,薩格港', 40.9978800, -72.2925800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141630, 'Saint James', 'Saint James', 'Saint James,Saint Jamesville,Sent-Dzhejms,Sher-a-wog,St. James,Сент-Джеймс', 40.8789900, -73.1567800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141631, 'Saint Johnsville', 'Saint Johnsville', '', 42.9981300, -74.6829200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141632, 'Salamanca', 'Salamanca', 'Salamanka,Salamanko,salamanka,salamanka  nywywrk,Саламанка,Саламанко,سالامانكا,سالامانکا، نیویورک', 42.1578400, -78.7150300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141633, 'Salisbury', 'Salisbury', '', 40.7456600, -73.5601300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141634, 'Sanborn', 'Sanborn', '', 43.1367200, -78.8847600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141635, 'Sands Point', 'Sands Point', 'Sands Pojnt,sandz bwynt,Сандс Појнт,ساندز بوينت', 40.8517700, -73.7187400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141636, 'Saranac Lake', 'Saranac Lake', 'SLK,sarank lyk,سارانك ليك', 44.3295000, -74.1312700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141637, 'Saratoga Springs', 'Saratoga Springs', 'Chi-co-pee,Salatogi,Saratoga Springs,Saratoga-Springs,Saratogo Springz,saeleotogaseupeulingseu,saratogasupuringu,saratwga aspryngz  nywywrk,saratwgha sbrynghs,Саратога Спрингс,Саратога-Спрингс,Саратого Спрингз,Саратоґа-Спрінгс,ساراتوغا سبرينغس,ساراتوگا اسپرینگز، نیویورک,サラトガスプリング,새러토가스프링스', 43.0831300, -73.7845700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141638, 'Saugerties', 'Saugerties', 'Saugerties,Ulster', 42.0775900, -73.9529100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141639, 'Sayville', 'Sayville', 'Sejvil,Сејвил', 40.7359300, -73.0820600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141640, 'Scarsdale', 'Scarsdale', 'Skarsdejl,si ka si dai er,skyrdyl,Скарсдејл,سكيرديل,斯卡斯代爾', 41.0051000, -73.7845800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141641, 'Schenectady', 'Schenectady', 'SCH,Schenectady,Shinetadi,Skanehtati,Skanéhtati,Skenektadi,Skenektadis,Skunektadi,seukinegteodi,si ke nei ke ta di,sknktdy  nywywrk,sknyktady,sqnqtdy,sukenekutadi,Скенектади,Скенектаді,Скънектади,Шинетади,סקנקטדי,سكنيكتادي,سکنکتدی، نیویورک,سکینکٹڈی ، نیویارک,سکینیکٹیڈی، نیو یارک,スケネクタディ,斯克内克塔迪,스키넥터디', 42.8142400, -73.9395700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141642, 'Schoharie', 'Schoharie', 'Brunnen Dorp,Brunnendorf,Fountain Village,Schoharie,Sommersville', 42.6659100, -74.3095800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141643, 'Schuylerville', 'Schuylerville', 'Old Saratoga,Saratoga,Schuylersville,Schuylerville,Skajlervil,shaylrfyl,Скајлервил,شايلرفيل', 43.1000800, -73.5817800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141644, 'Scotchtown', 'Scotchtown', 'Scotch Town,Scotchtown', 41.4814800, -74.3601500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141645, 'Scotia', 'Scotia', 'Skosha,skwtya,Скоша,سكوتيا', 42.8264700, -73.9642900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141646, 'Scottsville', 'Scottsville', 'Oatka,Scottsville,Skotsvil,skwtfyl,Скотсвил,سكوتفيل,سکاٹسویل، نیو یارک', 43.0259000, -77.7452800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141647, 'Sea Cliff', 'Sea Cliff', 'Carpenterville,Littleworth,Sea Cliff,Sea Cliff Grove,Si Klif,sy klyf,Си Клиф,سي كليف', 40.8489900, -73.6448500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141648, 'Seaford', 'Seaford', 'Jerusalem South,Seaford', 40.6659300, -73.4881800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141649, 'Searingtown', 'Searingtown', '', 40.7748200, -73.6556800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141650, 'Seaside', 'Seaside', '', 40.5831600, -73.8281900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141651, 'Selden', 'Selden', 'Selden,Westfield,Селден', 40.8664900, -73.0356600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141652, 'Seneca Falls', 'Seneca Falls', 'Seneca Falls,Shaseounse', 42.9106200, -76.7966200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141653, 'Seneca Knolls', 'Seneca Knolls', '', 43.1200700, -76.2863200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141654, 'Sheepshead Bay', 'Sheepshead Bay', '', 40.5912200, -73.9445800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141655, 'Shelter Island', 'Shelter Island', '', 41.0681500, -72.3386900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141656, 'Shelter Island Heights', 'Shelter Island Heights', '', 41.0839900, -72.3559200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141657, 'Shenorock', 'Shenorock', 'Lake Shenorock,Lake Shenrock,Shenorock', 41.3317600, -73.7381900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141658, 'Sherburne', 'Sherburne', 'Ganadadele,Sherburne', 42.6781300, -75.4985100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141659, 'Sherrill', 'Sherrill', 'Sherrill,Turikesreet,Turkey Street', 43.0736800, -75.5982400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141660, 'Shinnecock Hills', 'Shinnecock Hills', '', 40.8909300, -72.4637000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141661, 'Shirley', 'Shirley', 'Shirli,WSH,Ширли', 40.8014900, -72.8676000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141662, 'Shokan', 'Shokan', 'Ashocan,Ashokan,Ashokjan,Caseville,Shokaken,Shokan', 41.9734300, -74.2120900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141663, 'Shortsville', 'Shortsville', 'Shorts Mills,Shortsville', 42.9559000, -77.2208100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141664, 'Shrub Oak', 'Shrub Oak', 'Scrub Oak,Shrub Oak', 41.3275900, -73.8195800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141665, 'Sidney', 'Sidney', 'SXY,Sidnej,Sidney,Susquehanna Flats,Сидней', 42.3148000, -75.3915700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141666, 'Silver Creek', 'Silver Creek', '', 42.5442300, -79.1667100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141667, 'Skaneateles', 'Skaneateles', 'Skaneateles,Skania:tares,Skaniá:tares,Skeneatelas', 42.9470100, -76.4291000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141668, 'Sleepy Hollow', 'Sleepy Hollow', 'Beekmantown,North Tarrytown,Sleepy Hollow,Slipi Kholou,Slipi-Khollou,duan tou gu,seullipihollo,slyby halw,Слипи Холоу,Слипи-Холлоу,سليبي هالو,斷頭谷,슬리피홀로', 41.0856500, -73.8584700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141669, 'Sloan', 'Sloan', '', 42.8933900, -78.7939200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141670, 'Sloatsburg', 'Sloatsburg', 'Pothat,Pothod,Sloatsburg,Sloatsburgh,Slotsberg,Sloutsburg,slatsbwrgh,surosubagu,Слотсберг,Слоутсбърг,سلاتسبورغ,スロースバーグ', 41.1545400, -74.1929200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141671, 'Smithtown', 'Smithtown', 'Head of the River,Smithtown,Smitstaun,smythtawn,Смитстаун,سميثتاون', 40.8559300, -73.2006700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141672, 'Sodus', 'Sodus', '', 43.2378400, -77.0613600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141673, 'Solvay', 'Solvay', '', 43.0581200, -76.2074300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141674, 'Sound Beach', 'Sound Beach', '', 40.9562100, -72.9678800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141675, 'South Beach', 'South Beach', 'Oude Dorp,South Beach', 40.5832900, -74.0760900, 'US', '2017-04-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141676, 'South Corning', 'South Corning', 'Mossy Glen,South Corning', 42.1217400, -77.0371900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141677, 'South Fallsburg', 'South Fallsburg', 'South Fallsburg,South Fallsburgh', 41.7206500, -74.6343300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141678, 'South Farmingdale', 'South Farmingdale', '', 40.7206600, -73.4401200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141679, 'South Floral Park', 'South Floral Park', '', 40.7142700, -73.7001300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141680, 'South Glens Falls', 'South Glens Falls', 'Clarks Mills,South Glen''s Falls,South Glens Falls', 43.2992400, -73.6351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141681, 'South Hempstead', 'South Hempstead', '', 40.6809400, -73.6154100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141682, 'South Hill', 'South Hill', '', 42.4292400, -76.4949400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141683, 'South Huntington', 'South Huntington', '', 40.8237100, -73.3987300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141684, 'South Lockport', 'South Lockport', '', 43.1500600, -78.6967000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141685, 'South Nyack', 'South Nyack', 'Saut Najak,sawth nayak,Саут Најак,ساوث ناياك', 41.0831500, -73.9201400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141686, 'South Valley Stream', 'South Valley Stream', '', 40.6559400, -73.7176300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141687, 'Southampton', 'Southampton', 'Agwam,Sautkhamptun,Sautkhempton,Southampton,Sud Hampton,Саутхамптън,Саутхемптон,Սաութհեմփթոն', 40.8842700, -72.3895300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141688, 'Southold', 'Southold', 'Southold,Southoule,Yennecock', 41.0648200, -72.4262000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141689, 'Southport', 'Southport', '', 42.0548000, -76.8191200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141690, 'Spackenkill', 'Spackenkill', '', 41.6559300, -73.9134700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141691, 'Sparkill', 'Sparkill', 'Sparkill,Upper Piermont', 41.0312100, -73.9270800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141692, 'Spencerport', 'Spencerport', 'Spencer''s Basin,Spencerport', 43.1864500, -77.8039000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141693, 'Springfield', 'Springfield', 'Springfild,Спрингфилд', 42.8361800, -74.8534800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141694, 'Springfield Gardens', 'Springfield Gardens', 'Springfield,Springfield Gardens', 40.6631200, -73.7622100, 'US', '2017-04-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141695, 'Springs', 'Springs', 'Springs,The Springs', 41.0162100, -72.1592400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141696, 'Springville', 'Springville', 'Fiddler''s Green,Springvil,Springville,sbrynghfyl,Спрингвил,سبرينغفيل', 42.5084000, -78.6672500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141697, 'Spring Valley', 'Spring Valley', 'Pascack,Pot Cheese Hollow,Spring Vali,Spring Valley,Spring-Vehlli,sbryngh faly,sprng wyly  nyw yark,Спринг Вали,Спринг-Вэлли,ספרינג וועלי,سبرينغ فالي,سپرنگ ویلی، نیو یارک,スプリング・バレー', 41.1131500, -74.0437500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141698, 'Spuyten Duyvil', 'Spuyten Duyvil', '', 40.8812100, -73.9173600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141699, 'Saint Bonaventure', 'Saint Bonaventure', 'St. Bonaventure', 42.0803400, -78.4750200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141700, 'Stamford', 'Stamford', 'Devil''s Halfacre,Stamford,Стамфорд', 42.4073000, -74.6143200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141701, 'Stapleton', 'Stapleton', '', 40.6264900, -74.0776400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141702, 'Staten Island', 'Staten Island', 'Borough of Staten Island,Staten Island', 40.5623300, -74.1398600, 'US', '2012-07-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141703, 'Steinway', 'Steinway', 'Ditmars,Steinway', 40.7745500, -73.9037500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141704, 'Stewart Manor', 'Stewart Manor', '', 40.7192700, -73.6884600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141705, 'Stillwater', 'Stillwater', '', 42.9384100, -73.6531700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141706, 'Stone Ridge', 'Stone Ridge', 'Stone Ridge,Stoneridge', 41.8531500, -74.1390300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141707, 'Stony Brook', 'Stony Brook', 'Stoni Bruk,Stony Brook,Stonybrook,Stouni-Bruk,Wopowag,astwny brwk  nywywrk,seutonibeulug,Стони Брук,Стоуни-Брук,استونی بروک، نیویورک,스토니브룩', 40.9256500, -73.1409400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141708, 'Stony Point', 'Stony Point', 'Flora Falls,Florus Falls,North Haverstraw,Stoni Pojnt,Stony Point,Stonypoint,Стони Појнт', 41.2295400, -73.9870800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141709, 'Stottville', 'Stottville', 'Springville,Stottsville,Stottville', 42.2862000, -73.7387300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141710, 'Suffern', 'Suffern', 'New Antrim,Point of the Mountains,Safern,Suffern,Suffrens,safan,swfrn,Саферн,سوفرن,サファーン', 41.1148200, -74.1495900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141711, 'Sunnyside', 'Sunnyside', '', 40.7398200, -73.9354200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141712, 'Sylvan Beach', 'Sylvan Beach', '', 42.4647900, -77.1083000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141713, 'Syosset', 'Syosset', 'Little East Woods,Syosset', 40.8262100, -73.5020700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141714, 'Syracuse', 'Syracuse', 'Bogardus Corners,Cossitts Corners,Gorad Sirakjus,Kah-ya-hoo-neh,Ken-tue-ho-ne,Milan,Na-ta-dunk,SYR,Siracusa,Sirak''jus,Sirakjus,Sirakjuz,Sirakuso,Sirakuz,South Salina,Sy-kuse,Syracusae,Syracuse,Syracuse i New York,Tu-na-ten-tonk,sayrakywz,shirakyusu,shirakyuzu,sileokyuseu,sirekyuja,syrakywz,syrakywz  nyw yark,syrakywz  nywywrk,syrqywz,xi la qiu ci,Горад Сіракюс,Сиракуз,Сиракьюс,Сиракюз,Сиракјус,Сіракюс,סירקיוז,سائراکیوز,سيراكيوز,سیراکیوز، نیو یارک,سیراکیوز، نیویورک,सिरॅक्युज,სირაკიუსი,シラキュース,シラキューズ,锡拉丘兹,시러큐스', 43.0481200, -76.1474200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141715, 'Tappan', 'Tappan', 'Tapan,tappan,Тапан,タッパン', 41.0220400, -73.9473600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141716, 'Tarrytown', 'Tarrytown', 'Alipkonk,Taritaun,Tarritaun,Tarry Town,Tarrytown,Tarwe Dorp,bai you cun,taelitaun,tarytawn,Таритаун,Тарритаун,تاريتاون,柏油村,태리타운', 41.0762100, -73.8587500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141717, 'Terrace Heights', 'Terrace Heights', '', 40.7214900, -73.7693000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141718, 'Terryville', 'Terryville', '', 40.9089900, -73.0651100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141719, 'Thiells', 'Thiells', 'Thiell''s Corners,Thiells,Thiells Corners', 41.2106500, -74.0176400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141720, 'Thomaston', 'Thomaston', '', 40.7862100, -73.7137400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141721, 'Thornwood', 'Thornwood', 'Hillside,Nanahagen,Sherman Park,Thornwood', 41.1234300, -73.7790200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141722, 'Throgs Neck', 'Throgs Neck', 'Throg''s Neck,Throgs Neck', 40.8226000, -73.8195800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141723, 'Ticonderoga', 'Ticonderoga', 'Cheonderoga,Lower Falls,Tajkonderoga,Teken''taro:ken,Teken''taró:ken,Ticonderoga,thi khxn de ro ka,Тајкондерога,ทิคอนเดโรกา', 43.8486700, -73.4234500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141724, 'Tillson', 'Tillson', '', 41.8289800, -74.0684800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141725, 'Tivoli', 'Tivoli', 'Madalin,Tivoli,Upper Red Hook Landing', 42.0584200, -73.9093000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141726, 'Tompkinsville', 'Tompkinsville', 'Tompkinsville,Watering Place', 40.6364900, -74.0854200, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141727, 'Tonawanda', 'Tonawanda', 'Tonavonda,Tonawanda,Tonewanta,Tonovindo,tanawnda  nywywrk,twnawanda,Тонавонда,Тоновиндо,تاناوندا، نیویورک,توناواندا', 43.0203300, -78.8803100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141728, 'Town Line', 'Town Line', '', 42.8906100, -78.5778000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141729, 'Tremont', 'Tremont', 'Adamsville,Mount Hope,South Fordham,Tremont,Upper Morrisania', 40.8495400, -73.9056900, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141730, 'Tribes Hill', 'Tribes Hill', 'Tribes Hill,Tribeshill', 42.9553500, -74.2851300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141731, 'Troy', 'Troy', 'Ashleys Ferry,Ferry Hook,Traj,Troj,Troja,Troy,Van Der Heyden Ferry,Van Der Heyden''s Ferry,Vanderheydens Ferry,te luo yi,teuloi,toroi,trwy,trwy  nywywrk,Трай,Трой,Троя,Трој,Թրոյ,تروي,تروی، نیویورک,ٹرائے، نیو یارک,ٹراۓ، نیویارک,トロイ,特洛伊,트로이', 42.7284100, -73.6917900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141732, 'Trumansburg', 'Trumansburg', 'Tremain Village,Tremans Mill,Tremansburg,Tremansville,Trumansburg,Trumansburgh', 42.5422900, -76.6660600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141733, 'Tuckahoe', 'Tuckahoe', '', 40.8989900, -72.4109200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141734, 'Tuckahoe', 'Tuckahoe', '', 40.9503800, -73.8273600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141735, 'Tupper Lake', 'Tupper Lake', 'Tsi skaniatare''ko:wa,Tsi skaniatare''kó:wa,Tupper Lake,Village of Tupper Lake', 44.2239500, -74.4640600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141736, 'Unadilla', 'Unadilla', 'De-u-na-dil''-lo,Ti-an-der-ra,Tianderah,Unadilla,Unedelly,Unendilla,Unidilly', 42.3253600, -75.3124000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141737, 'Union Springs', 'Union Springs', 'Junion Springs,ywnyn sprngz  nyw yark,ywnywn sbrynghz,Јунион Спрингс,يونيون سبرينغز,یونین سپرنگز، نیو یارک', 42.8397900, -76.6932800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141738, 'Uniondale', 'Uniondale', 'East Meadow,Juniondejl,Turtle Hook,Union Dale,Uniondale,you ning dai er,yunieondeil,ywnywndayl,Јуниондејл,Юниондейл,Юніондейл,يونيوندايل,یونیوندایل,尤寧戴爾,유니언데일', 40.7003800, -73.5929100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141739, 'Unionport', 'Unionport', 'Union Port,Unionport', 40.8273200, -73.8501300, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141740, 'University Gardens', 'University Gardens', '', 40.7773200, -73.7226300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141741, 'University Heights', 'University Heights', 'Fordham Heights,University Heights', 40.8601000, -73.9093000, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141742, 'Upper Brookville', 'Upper Brookville', '', 40.8387100, -73.5651300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141743, 'Upper Nyack', 'Upper Nyack', 'Sarvent''s Landing,Upper Nyack', 41.1070400, -73.9201400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141744, 'Utica', 'Utica', 'Fort Schuyler,Gorad Jutyka,Iotekha,Iotékha,Jutika,Nundadasis,Old Fort Schuyler,Tevadahahtodague,Twa-dah-ah-lo-dah-que,UCA,Unungagages,Utica,Utika,Yanundadasis,ZUA,awtyka,you ti ka,yutika,ywtyka  nywywrk,ywtyqh,Јутика,Горад Ютыка,Утика,Ютика,Ютіка,יוטיקה,أوتيكا,یوتیکا، نیویورک,یوٹیکا، نیو یارک,ユーティカ,由提卡', 43.1009000, -75.2326600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141745, 'Vails Gate', 'Vails Gate', 'Vail Gate,Vail''s Gate,Vailgate,Vails Gate,Vailsgate', 41.4542600, -74.0576400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141746, 'Valatie', 'Valatie', '', 42.4134200, -73.6731700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141747, 'Valhalla', 'Valhalla', 'Davis Brook,Kensico,Robbins Mills,Valhalla,Valkhala,Валхала', 41.0748200, -73.7751300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141748, 'Valley Cottage', 'Valley Cottage', '', 41.1181500, -73.9554200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141749, 'Valley Stream', 'Valley Stream', 'Vali Strijm,Vali Strim,faly strym,wly astrym  nywywrk,Вали Стрийм,Вали Стрим,فالي ستريم,ولی استریم، نیویورک,ویلی سٹریم، نیو یارک', 40.6642700, -73.7084600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141750, 'Van Nest', 'Van Nest', '', 40.8484300, -73.8637500, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141751, 'Vernon', 'Vernon', 'Ska-nu-sunk,Skunaudowa,Vernon', 43.0795100, -75.5393400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141752, 'Verplanck', 'Verplanck', '', 41.2528700, -73.9598600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141753, 'Victor', 'Victor', 'Ga-o''sa-ga-o,Victor', 42.9825600, -77.4088800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141754, 'Village Green', 'Village Green', '', 43.1334000, -76.3129900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141755, 'Village of the Branch', 'Village of the Branch', 'Smithtown Branch,Village of the Branch', 40.8562100, -73.1873300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141756, 'Viola', 'Viola', 'Mechanicsville,Viola', 41.1364800, -74.0823600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141757, 'Volney', 'Volney', 'Volney,Volney Center,Volney Corners', 43.3428500, -76.3577100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141758, 'Voorheesville', 'Voorheesville', 'Farlin,Union Depot,Voorheesville', 42.6539700, -73.9287400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141759, 'Wading River', 'Wading River', '', 40.9503800, -72.8426000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141760, 'Wakefield', 'Wakefield', '', 40.8978800, -73.8523600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141761, 'Walden', 'Walden', 'Volden,waldn,Волден,والدن', 41.5612000, -74.1884800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141762, 'Wallkill', 'Wallkill', 'Reeveton,Shawangunk,The Basin,Wallkill', 41.6056500, -74.1840400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141763, 'Walton', 'Walton', '', 42.1695300, -75.1293400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141764, 'Walton Park', 'Walton Park', '', 41.3098200, -74.2290400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141765, 'Wampsville', 'Wampsville', 'Wampsville,Wempsville', 43.0753500, -75.7068500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141766, 'Wantagh', 'Wantagh', 'Vonto,Вонто', 40.6837100, -73.5101300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141767, 'Wanakah', 'Wanakah', '', 42.7461700, -78.9030900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141768, 'Wappingers Falls', 'Wappingers Falls', 'Wappinger,Wappinger''s Falls,Wappingers Falls,wabynghrz,waping-geoseupolseu,وابينغرز,와핑거스폴스', 41.5964800, -73.9109700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141769, 'Warrensburg', 'Warrensburg', 'Warrensburg,Warrensburgh', 43.4967400, -73.7762300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141770, 'Warsaw', 'Warsaw', 'Chi-nose-heh-geh,Warsaw', 42.7400600, -78.1327900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141771, 'Warwick', 'Warwick', 'Baird''s Tavern,Vorvik,Warwick,warwyk  nywywrk,Ворвик,وارویک، نیویورک', 41.2564800, -74.3598800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141772, 'Washington Heights', 'Washington Heights', 'Harlem Heights,Pen-a-bick,Washington Heights,washintonhaitsu,wosingteonhaicheu,ワシントンハイツ,워싱턴하이츠', 40.8501000, -73.9354100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141773, 'Washington Heights', 'Washington Heights', '', 41.4700900, -74.4157100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141774, 'Washington Mills', 'Washington Mills', 'Checkerville,Washington Mills', 43.0500700, -75.2729400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141775, 'Washingtonville', 'Washingtonville', 'Little York,Matthews Field,Voshingtonvil,Washingtonville,washynghtwnfyl,Вошингтонвил,واشينغتونفيل', 41.4278700, -74.1659800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141776, 'Water Mill', 'Water Mill', 'Mill Neck,Water Mill,Water Mills', 40.9059300, -72.3620300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141777, 'Waterford', 'Waterford', 'Half-Moon Point,Uoterford,Voterford,Waterford,Вотерфорд,Уотерфорд', 42.7925800, -73.6812300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141778, 'Waterloo', 'Waterloo', 'New Hudson,Scauyes,Scauyz,Scawas,Scawyace,Vaterlo,Voterlu,Waterloo,qryt watrlw,Ватерло,Вотерлу,قرية واترلو,واٹرلو', 42.9047900, -76.8627400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141779, 'Water Mill', 'Water Mill', 'Water Mill,Watermill', 40.9195900, -72.3427400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141780, 'Watertown', 'Watertown', 'ART,Uotertaun,Vatertaun,Votertaun,u~otataun,watrtawn  nywywrk,watyrtawn,Ватертаун,Вотертаун,Уотертаун,واترتاون، نیویورک,واتيرتاون,واٹر ٹاؤن,ウォータータウン', 43.9747800, -75.9107600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141781, 'Waterville', 'Waterville', 'Skanawis,The Huddle,Waterville', 42.9311800, -75.3798900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141782, 'Watkins Glen', 'Watkins Glen', 'Jefferson,Salubria,Votkins Glen,Watkins Glen,Watlins,watkyns,Воткинс Глен,واتكينس', 42.3806300, -76.8732900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141783, 'Waverly', 'Waverly', 'Loder,Villemont,Waverley,Waverly', 42.0103500, -76.5271700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141784, 'Wawarsing', 'Wawarsing', 'Warwasing,Wawarsing,Wawasink', 41.7589800, -74.3573800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141785, 'Webster', 'Webster', 'Vebster,Вебстер,ویبسٹر', 43.2122900, -77.4299900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141786, 'Weedsport', 'Weedsport', 'Weed''s Basin,Weed''s Port,Weedsport', 43.0486800, -76.5627200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141787, 'Wellsville', 'Wellsville', 'ELZ,Genesee,Gistaguat,Wellsville', 42.1220100, -77.9480600, 'US', '2017-06-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141788, 'Wellsville', 'Wellsville', '', 42.8759100, -74.2723500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141789, 'Wesley Hills', 'Wesley Hills', '', 41.1592600, -74.0698600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141790, 'West Albany', 'West Albany', 'Spencerville,West Albany', 42.6831300, -73.7784500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141791, 'West Babylon', 'West Babylon', '', 40.7181600, -73.3542900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141792, 'West Bay Shore', 'West Bay Shore', '', 40.7087100, -73.2812300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141793, 'West Carthage', 'West Carthage', '', 43.9742300, -75.6151900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141794, 'West Elmira', 'West Elmira', '', 42.0781300, -76.8452400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141795, 'West End', 'West End', '', 42.4686900, -75.0937800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141796, 'West Glens Falls', 'West Glens Falls', '', 43.3000700, -73.6840100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141797, 'West Haverstraw', 'West Haverstraw', 'Samsondale,West Haverstraw', 41.2095400, -73.9854200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141798, 'West Hempstead', 'West Hempstead', '', 40.7048200, -73.6501300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141799, 'West Hills', 'West Hills', '', 40.8162100, -73.4323400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141800, 'West Hurley', 'West Hurley', '', 41.9973100, -74.1048600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141801, 'West Islip', 'West Islip', '', 40.7062100, -73.3062300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141802, 'West Nyack', 'West Nyack', 'Clarkestown,Clarksville,Mont Moor,Nyack Turnpike,Vest Najak,West Nyack,Вест Најак', 41.0964900, -73.9729200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141803, 'West Point', 'West Point', 'Promontorium Occidentale,Uest Pojnt,Vest Pojnt,West Point,Westpoint,u~esutopointo,weseuteupointeu,xi dian,Вест Појнт,Уест Пойнт,ویسٹ پوائنٹ، نیو یارک,ვესტ-პოინტი,ウェストポイント,西點,웨스트포인트', 41.3914800, -73.9559700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141804, 'West Sand Lake', 'West Sand Lake', 'Ulinesville,West Sand Lake,West Sandlake', 42.6434100, -73.6087300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141805, 'West Sayville', 'West Sayville', '', 40.7278800, -73.0976100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141806, 'West Seneca', 'West Seneca', 'Limestone Hill,Vest Seneka,West Seneca,wyst synyka,Вест Сенека,ويست سينيكا', 42.8500600, -78.7997500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141807, 'Westbury', 'Westbury', 'Vestberi,Westbury,Westbury Station,wstbary,Вестбери,وستباري', 40.7556600, -73.5876300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141808, 'Westerleigh', 'Westerleigh', '', 40.6212100, -74.1318100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141809, 'Westfield', 'Westfield', 'The Crossroads,Uehstfild,Vestfild,Westfield,Вестфилд,Вестфілд,Уэстфилд,ویسٹ فیلڈ', 42.3222800, -79.5781000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141810, 'Westhampton', 'Westhampton', '', 40.8245400, -72.6662100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141811, 'Westhampton Beach', 'Westhampton Beach', 'West Hampton Beach,Westhampton Beach', 40.8031600, -72.6145400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141812, 'Westmere', 'Westmere', '', 42.6911900, -73.8687300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141813, 'Weston Mills', 'Weston Mills', '', 42.0759000, -78.3725200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141814, 'Westons Mills', 'Westons Mills', 'Weston Mills,Weston''s Mills,Westons,Westons Mills,Westonville', 42.0622900, -78.3772400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141815, 'Westvale', 'Westvale', '', 43.0475700, -76.2204800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141816, 'Wheatley Heights', 'Wheatley Heights', '', 40.7637100, -73.3698400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141817, 'White Plains', 'White Plains', 'Quaropas,Uajt Plejns,Uajt-Plejns,Vajt Plajns,Vajt Plejns,Vajt-Plejns,White Plains,Whiteplains,bai yuan shi,hwaiteupeulleinseu,wayt blyns,wayt playnz  nywywrk,wyyt plyyns,Вайт Плайнс,Вайт-Плейнс,Вајт Плејнс,Уайт Плейнс,Уайт-Плейнс,ווייט פלעינס,וייט פליינס,وائٹ پلینس، نیویارک,وايت بلينس,وایت پلاینز، نیویورک,ホワイト・プレインズ,ホワイト・プレインズ_,白原市,화이트플레인스', 41.0339900, -73.7629100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141818, 'Whitehall', 'Whitehall', 'Kah-cha-quah-na,Kahphoquahna,Petit Sault,Skenesboro,Skenesborough,Tekontarakwe:kon,Tekontarakwé:kon,Whitehall', 43.5556200, -73.4037200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141819, 'Whitesboro', 'Whitesboro', 'Whitehall Landing,Whitesboro', 43.1220100, -75.2915600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141820, 'Whitestone', 'Whitestone', 'Clintonville,Cookie Hill,Whitestone', 40.7945500, -73.8184700, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141821, 'Williamson', 'Williamson', '', 43.2239500, -77.1860900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141822, 'Williamsville', 'Williamsville', 'Ga-sko-sa-da-ne-o,Gah-da-ya-deh,Vilijamsvil,Williamsville,wylyamsfyl,Вилијамсвил,ويليامسفيل', 42.9639500, -78.7378100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141823, 'Williston Park', 'Williston Park', '', 40.7564900, -73.6448500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141824, 'Willowbrook', 'Willowbrook', 'Brook Willow,Willowbrook', 40.6031600, -74.1384800, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141825, 'Wilson', 'Wilson', 'Uilson,Уилсон', 43.3097800, -78.8261500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141826, 'Wolcott', 'Wolcott', '', 43.2206200, -76.8149600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141827, 'Woodbury', 'Woodbury', 'East Woods,Vudbari,Woodbury,Вудбари', 40.8256500, -73.4676200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141828, 'Woodbury', 'Woodbury', '', 41.3645400, -74.1059800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141829, 'Woodhaven', 'Woodhaven', 'Woodhaven,Woodville,وڈ ہیون، کوئینز', 40.6892700, -73.8579100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141830, 'Woodlawn', 'Woodlawn', 'Wakefield,Washingtonville,Woodlawn', 40.8981600, -73.8673600, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141831, 'Woodmere', 'Woodmere', 'Woodburg,Woodmere,Woodsburg', 40.6320500, -73.7126300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141832, 'Woodrow', 'Woodrow', 'Bogardus Corners,Wood Row,Woodrow', 40.5434400, -74.1976400, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141833, 'Woodside', 'Woodside', '', 40.7453800, -73.9054100, 'US', '2017-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141834, 'Woodstock', 'Woodstock', 'Vudstok,uddosutokku,udeuseutog,wwdastak  nywywrk,Вудсток,ووداستاک، نیویورک,ウッドストック,우드스톡', 42.0409200, -74.1182000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141835, 'Worcester', 'Worcester', '', 42.5914600, -74.7504300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141836, 'Wurtsboro', 'Wurtsboro', 'Mamakating,Mamakating Hollow,Rome,Vertsboro,Wirtzboro,Wurtsboro,Wurtsborough,wrstbwrw,Вертсборо,ورستبورو', 41.5767600, -74.4871000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141837, 'Wyandanch', 'Wyandanch', 'Half Way Hollow Hills,West Deer Park,Wyandance,Wyandanch,Wylandanch', 40.7539900, -73.3604000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141838, 'Wynantskill', 'Wynantskill', 'Wyantskill,Wynantskill', 42.6967500, -73.6442800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141839, 'Yaphank', 'Yaphank', 'Millville,Yaphank', 40.8367700, -72.9170500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141840, 'Yonkers', 'Yonkers', 'Gorad Ionkers,Jonkers,Jonkersas,Jonkurs,Yonckers,Yonkers,yang ke si,yankrz,yongkeoseu,yonkazu,ywnkrz,ywnkrz  nyw yark,ywnkyrs,ywnqrs,Јонкерс,Горад Іонкерс,Йонкерс,Йонкърс,יאנקערס,יונקרס,يونكيرس,یانکرز,یونکرز,یونکرز، نیو یارک,ヨンカーズ,揚克斯,용커스', 40.9312100, -73.8987500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141841, 'Yorkshire', 'Yorkshire', 'Yorkshire,Yorkshire Corners', 42.5300600, -78.4728000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141842, 'Yorktown Heights', 'Yorktown Heights', 'Underhill,Yorktown Heights', 41.2709300, -73.7776300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141843, 'Yorkville', 'Yorkville', '', 43.1128500, -75.2710000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141844, 'Youngstown', 'Youngstown', 'Jangstaun,ywnghstwn,ywngstwwn  nyw yark,Јангстаун,يونغستون,یونگستوؤن، نیو یارک', 43.2472800, -79.0500500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141845, 'Zena', 'Zena', '', 42.0167600, -74.0762500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141846, 'Ada', 'Ada', 'Ada,Ejda,Johnsons Station,Johnstown,ada,ada  awhayw,Ада,Ејда,آدا,ادا، اوهایو,ایڈا، اوہائیو', 40.7695000, -83.8227100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141847, 'Akron', 'Akron', 'Akron,Akron City,Akrona,Akronas,Akrun,CAK,Ehkron,New Portage,Summitville,a ke lun,aekeuleon,akran  awhayw,akrwn,akuron,ekran,Акрон,Акрън,Экрон,Ակրոն,אקרון,آكرون,اکران، اوهایو,اکرون، اوہائیو,अ‍ॅक्रन,ஏக்ரன்,അക്രോൺ,アクロン,阿克伦,애크런', 41.0814400, -81.5190100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141848, 'Alliance', 'Alliance', 'Al''jans,Alajans,Alliance,Freedom,Liberty,Mahoning,Olians,Williamsport,a lai en si,alayans,alyans  awhayw,eollaieonseu,Алајанс,Альянс,Олианс,ألايانس,الیانس، اوهایو,阿莱恩斯,얼라이언스', 40.9153400, -81.1059300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141849, 'Amherst', 'Amherst', 'Amherst,Amherst Corners,Amherstville,Amhurst,Amkherst,Four Corners,North Amherst,Plato,amhrst,amhrst  awhayw,Амхерст,أمهرست,امهرست، اوهایو', 41.3978200, -82.2223800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141850, 'Andover', 'Andover', 'Andover,Andover Centre', 41.6067200, -80.5723000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141851, 'Anna', 'Anna', 'Anna,Careys Station,Careysville', 40.3944900, -84.1727200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141852, 'Ansonia', 'Ansonia', 'Ansonia,Dallas', 40.2144900, -84.6369000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141853, 'Antwerp', 'Antwerp', '', 41.1814400, -84.7405100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141854, 'Apple Creek', 'Apple Creek', 'Apple Creek,Apple Creek Station,Apple Orchard Town,Applecreek,Applecreek Junction,Applecreek Station,Edenburg,Edinburg,Edinburgh', 40.7517200, -81.8393000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141855, 'Archbold', 'Archbold', 'Archbald,Archbold,Archibald', 41.5214400, -84.3071700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141856, 'Arlington', 'Arlington', 'Arlington,Madison,Арлингтон', 40.8936600, -83.6502100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141857, 'Ashland', 'Ashland', 'Ashland,Ashlend,Ehshlehnd,Eshland,Eshlend,Uniontown,a shen lan,aesyullaendeu,ashland,ayshlnd  awhayw,Ашленд,Ешланд,Ешленд,Эшлэнд,آشلاند,ایشلند، اوهایو,ایشلنڈ، اوہائیو,阿什兰,애슐랜드', 40.8686700, -82.3182200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141858, 'Ashley', 'Ashley', 'Ashley,Ashley Station,Oxford', 40.4089500, -82.9554600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141859, 'Ashtabula', 'Ashtabula', 'Ashtabjula,Ehshtabula,a shen ta bi la,aesyuteobyulla,ashtabwla,ashtabwla  awhayw,ashutabyura,Аштабјула,Эштабула,أشتابولا,اشتابولا، اوهایو,アシュタビューラ,阿什塔比拉,애슈터뷸라', 41.8650500, -80.7898100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141860, 'Aurora', 'Aurora', 'Aurora,Aurora Center,Aurora Centre,Aurora Depot,Aurora Station,Avrora,Howardsville,Howardville,Orora,awrwra,awrwra  awhayw,Аврора,Орора,ارورا، اوہائیو,اورورا,اورورا، اوهایو', 41.3175500, -81.3453900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141861, 'Austintown', 'Austintown', 'Austin,Austin Centre,Austintown,Austintown Centre,Orange', 41.1017200, -80.7645200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141862, 'Avon', 'Avon', 'Avon,Ehvon,Ejvon,French Creek,Troy,Xeuma,afwn,awwn  awhayw,Ејвон,Эвон,أفون,اوون، اوهایو', 41.4517100, -82.0354200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141863, 'Avon Center', 'Avon Center', 'Avon Center,Avon Centre', 41.4597600, -82.0195900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141864, 'Avon Lake', 'Avon Lake', 'Avon Lejk,Ehvon Lehjk,afwn lyk,awwn lyk  awhayw,Авон Лејк,Эвон Лэйк,آفون ليك,اوون لیک، اوهایو', 41.5053200, -82.0282000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141865, 'Bainbridge', 'Bainbridge', 'Bainbridge,Bainbridge Center,Bissell,Bissells,Bissels', 41.3864400, -81.3395500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141866, 'Ballville', 'Ballville', 'Ballsville,Ballville', 41.3278300, -83.1321400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141867, 'Barberton', 'Barberton', 'Barbehrton,Barberton,barbrtwn,barbrtwn  awhayw,Барбертон,Барбэртон,باربرتون,باربرتون، اوهایو', 41.0128300, -81.6051200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141868, 'Bay Village', 'Bay Village', 'Bay,Bay Village,Behj Villadzh,Bej Vilidz,Dover Bay,Dover Bay Park Station,Dover Station,Dover Village,River Bank,bay wylyj  awhayw,byh fylyj,Беј Вилиџ,Бэй Вилладж,بای ویلیج، اوهایو,بيه فيليج', 41.4847700, -81.9220800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141869, 'Beach City', 'Beach City', 'Barrs Mills,Beach City,Beech City,Bells Mills,Willards Mills,Willeard Mills', 40.6531200, -81.5809600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141870, 'Beachwood', 'Beachwood', 'Bichvud,bytshwwd,Бичвуд,بيتشوود,بک‌وود، اوهایو,بیچ ووڈ، اوہائیو', 41.4645000, -81.5087300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141871, 'Bedford', 'Bedford', 'Bedford,Behdford,Pilgerruh,bdfwrd  awhayw,bydfwrd,Бедфорд,Бэдфорд,بدفورد، اوهایو,بيدفورد,بیڈفورڈ، اوہائیو', 41.3931100, -81.5365100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141872, 'Bedford Heights', 'Bedford Heights', '', 41.4170000, -81.5273400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141873, 'Beechwood Trails', 'Beechwood Trails', '', 40.0236700, -82.6507200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141874, 'Bellaire', 'Bellaire', 'Belaire,Beler,Bell Air,Bellair,Bellaire,Georgetown,Klee Post Office,Белер', 40.0161800, -80.7423100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141875, 'Bellefontaine', 'Bellefontaine', 'Behllfontehjn,Belfauntn,Belle Fontaine,Bellefontaine,Bellfontain,Bellfontaine,Blue Jackets Town,bei er fang dan,blfwntayn  awhayw,byl fwntyn,Белфаунтн,Бэллфонтэйн,بلفونتاین، اوهایو,بيل فونتين,贝尔方丹', 40.3611600, -83.7596600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141876, 'Bellevue', 'Bellevue', 'Amsdens Corners,Bellehvju,Bellevue,Bellview,Belvju,Belvue,York,York Cross Roads,Yorks Crossing,blfyw,blww  awhayw,Белвју,Беллэвю,بلفيو,بلوو، اوهایو', 41.2736600, -82.8415800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141877, 'Bellville', 'Bellville', 'Bellerville,Belleville,Bellville,Belvil,McCluers Settlement,McClure,bylfyl,Белвил,بيلفيل', 40.6200600, -82.5107200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141878, 'Berea', 'Berea', 'Behri,Berea,Berija,Lyceum Village,bra  awhayw,byrya,Береа,Берија,Бэри,برا، اوهایو,بيريا', 41.3661600, -81.8543000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141879, 'Bethesda', 'Bethesda', 'Bethesda,Burr,Burrs Kills,Burrs Mill,Fairmont,Fairmount,Fairmount Station', 40.0161800, -81.0726000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141880, 'Bluffton', 'Bluffton', 'Blafton,Bluffton,Croghan,Shannon,blwftn,Блафтон,بلوفتن', 40.8953300, -83.8888300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141881, 'Boardman', 'Boardman', 'Boadman,Boardman,Boardman Center,Boardman Centre,Bordman,Broadman,Боадман,Бордман', 41.0242300, -80.6628500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141882, 'Bolindale', 'Bolindale', '', 41.2072800, -80.7775800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141883, 'Boston Heights', 'Boston Heights', 'Boston,Boston Heights,Boston Ledges', 41.2647800, -81.5131700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141884, 'Botkins', 'Botkins', 'Bodkins,Botkins,Botkins Station,Botkinsville,Dinsmore,bwtkyns,Боткинс,بوتكينس', 40.4678300, -84.1805000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141885, 'Bowling Green', 'Bowling Green', 'Bouling Grin,Bouling-Grin,bao ling ge lin,bolling-geulin,bwlyngh ghryn,bwwlyng gryn  awhayw,Боулинг Грин,Боулинг-Грин,باولنگ گرین، اوہائیو,بولينغ غرين,بوولینگ گرین، اوهایو,鮑靈格林,볼링그린', 41.3747700, -83.6513200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141886, 'Bradford', 'Bradford', 'Bradford,Bradford Junction,Richmond,Union City Junction', 40.1322700, -84.4307800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141887, 'Bradner', 'Bradner', '', 41.3242200, -83.4385400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141888, 'Bratenahl', 'Bratenahl', '', 41.5425500, -81.6262400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141889, 'Brecksville', 'Brecksville', 'Brecksville,Brehksvill,Breksvil,Bricksville,brkswyl  awhayw,byksfyl,Брексвил,Брэксвилл,برکسویل، اوهایو,بيكسفيل', 41.3197800, -81.6267900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141890, 'Brewster', 'Brewster', 'Brewester,Brewster,Brjuster,Брюстер', 40.7070000, -81.5981800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141891, 'Bridgeport', 'Bridgeport', 'Bridgeport,Bridzport,Canton,Kirkwood,North Canton,brydjbwrt,Бриџпорт,برج پورٹ، اوہائیو,بريدجبورت', 40.0697900, -80.7400800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141892, 'Brilliant', 'Brilliant', 'Brilliant,La Grange,LaGrange,Lagrange,Philipsburg,Philipsburgh,Phillipsburg', 40.2647900, -80.6261900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141893, 'Brimfield', 'Brimfield', 'Brimfield,Brimfield Center,Brunsfield,Greenbriar,Thorndike,Wylestown', 41.1000600, -81.3465000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141894, 'Broadview Heights', 'Broadview Heights', 'Broadview Heights,Brodvju Khajts,Brudvju Khehjts,Walling Corners,brwdfyw hayts,brwdwyw hayts  awhayw,Бродвју Хајтс,Брудвю Хэйтс,برودفيو هايتس,برودویو هایتس، اوهایو', 41.3139400, -81.6851300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141895, 'Brook Park', 'Brook Park', 'Bruk Park,brwk bark,brwk park  awhayw,Брук Парк,بروك بارك,بروک پارک، اوهایو', 41.3983800, -81.8045800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141896, 'Brookfield Center', 'Brookfield Center', '', 41.2406100, -80.5578500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141897, 'Brooklyn', 'Brooklyn', 'Brklin,Brooklyn,Brooklyn Village,Bruklin,Ohio City,brwklyn,brwklyn  awhayw,Брклин,Бруклин,بروكلين,بروکلین، اوهایو,بروکلین، اوہائیو', 41.4397700, -81.7354100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141898, 'Brooklyn Heights', 'Brooklyn Heights', '', 41.4253300, -81.6881800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141899, 'Brunswick', 'Brunswick', 'Bransvik,Braunshvejg,Brunswick,Brunswick Center,beuleonjeuwig,branzwyk  awhayw,brwnzwyk,bu lun rui ke,Брансвик,Брауншвейг,برانزویک، اوهایو,برنزوک، اوہائیو,برونزويك,不倫瑞克,브런즈윅', 41.2381100, -81.8418000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141900, 'Bryan', 'Bryan', 'Brajan,beulaieon,brayan,brayan  awhayw,Брайан,Брајан,برايان,برایان، اوهایو,브라이언', 41.4747700, -84.5524500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141901, 'Bucyrus', 'Bucyrus', 'Bakiras,Beadles Settlement,Bjusajrus,Bucyrus,bwsayrws,bwsyrws  awhayw,Бакирас,Бјусајрус,بوسايروس,بوسیروس، اوهایو', 40.8083900, -82.9754600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141902, 'Burlington', 'Burlington', '', 41.5722700, -84.3080000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141903, 'Burton', 'Burton', 'Berton,byrtn,Бертон,بيرتن', 41.4706100, -81.1451000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141904, 'Cadiz', 'Cadiz', 'Cadiz,Cádiz,Kadis,kadyz,kadyz  awhayw,Кадис,كاديز,کادیز، اوهایو', 40.2728500, -80.9967600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141905, 'Calcutta', 'Calcutta', 'Calcutta,Faulkstown,Foulks Town,Foulkstown,Fulkstown,Nineveh,West Union', 40.6734000, -80.5764600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141906, 'Cambridge', 'Cambridge', 'Kehmbridzh,Kejmbridzh,Kembridz,Kembridzh,kambrdj,kmbryj  awhayw,Кеймбридж,Кембридж,Кембриџ,Кэмбридж,كامبردج,کمبریج، اوهایو,کیمبرج، اوہائیو', 40.0311800, -81.5884600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141907, 'Campbell', 'Campbell', 'Campbell,Campbell City,East Youngstown,Kehmpbehll,Kehmpbell,Kembel,kambl,kan bei er,kmpbl  awhayw,Кембел,Кэмпбелл,Кэмпбэлл,كامبل,کمپبل، اوهایو,کیمبل، اوہائیو,坎贝尔', 41.0783900, -80.5992400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141908, 'Canal Fulton', 'Canal Fulton', 'Canal Fulton,Fulton,Midland,Milan,Miland', 40.8897800, -81.5976200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141909, 'Canfield', 'Canfield', '', 41.0250600, -80.7609100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141910, 'Canton', 'Canton', 'Canton', 40.7989500, -81.3784500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141911, 'Cardington', 'Cardington', 'Carding,Cardington', 40.5006200, -82.8935100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141912, 'Carey', 'Carey', 'Carey,Cary', 40.9525600, -83.3824200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141913, 'Carrollton', 'Carrollton', 'Carolton,Carrollton,Carrolton,Centerton,Centerville,Centretown,Centreville,Karolton,kaeleolteon,karwltwn,Каролтон,كارولتون,کیرولٹن، اوہائیو,캐럴턴', 40.5728400, -81.0856500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141914, 'Celina', 'Celina', 'Sehlina,Selajna,Selina,slyna  awhayw,sylyna,Селајна,Селина,Селіна,Сэлина,سلینا، اوهایو,سيلينا,وین ٹاؤن شپ، مرسر کاؤنٹی، اوہائیو', 40.5489400, -84.5702300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141915, 'Centerburg', 'Centerburg', 'Centerburg,Centerburgh,Centreboro,Centreburg,Centreburgh', 40.3045100, -82.6962800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141916, 'Chagrin Falls', 'Chagrin Falls', 'Chagrin,Chagrin Falls,Chagrine,Chagrine Falls,Charlton,Shagrin Fols,shaghrn fwlz,Шагрин Фолс,شاغرن فولز', 41.4361600, -81.3865000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141917, 'Chardon', 'Chardon', 'Chardon,Chardon Center,Chardon Centre,Chardon Village,shardwn  awhayw,tshardn,Чардон,تشاردن,شاردون، اوهایو', 41.6142200, -81.1489900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141918, 'Chesterland', 'Chesterland', 'Chester,Chester Cross Roads,Chester Roads,Chesterland,Cross Roads,Hudsons Corner', 41.5222700, -81.3378900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141919, 'Churchill', 'Churchill', 'Church Hill,Churchill,Liberty', 41.1620000, -80.6648000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141920, 'Cleveland', 'Cleveland', 'CLE,Cleaveland,Cleveland,Forest City,Gorad Kliulend,Klevalehnd,Klevlando,Klivelant,Klivland,Klivlandas,Klivlend,Klivlenda,Klīvlenda,ka fu lan,ke li fu lan,keullibeullaendeu,kilivlant,klebhilyanda,klivhalanda,klyfland,klywlnd,kuriburando,qlyblnd,Κλίβελαντ,Горад Кліўленд,Клевалэнд,Кливланд,Кливленд,Клівленд,Քլիվլենդ,קליבלנד,קליוולאנד,كليفلاند,کلیولند,کلیولینڈ، اوہائیو,क्लीव्हलंड,ক্লেভিল্যান্ড,கிளீவ்லன்ட்,คลีฟแลนด์,კლივლენდი,クリーブランド,克利夫兰,克里夫蘭,卡夫蘭,클리블랜드', 41.4995000, -81.6954100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141921, 'Clinton', 'Clinton', 'Clinton,Klinton,Oradeen,Orradeen,Pumroy,Savanna,Savannah,Клинтон', 40.9267200, -81.6304000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141922, 'Clyde', 'Clyde', 'Bang All,Centreville,Clyde,Hamers Corners,Hamersville,Klajd,klayd,klayd  awhayw,Клайд,Клајд,كلايد,کلاید، اوهایو', 41.3042200, -82.9751900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141923, 'Coldwater', 'Coldwater', 'Buzzards Glory,Cold Water,Coldwater,Franktown', 40.4797700, -84.6282900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141924, 'Columbiana', 'Columbiana', 'Columbiana,Dixonville,Kolambijana,Kolumbiana,klmbyana  awhayw,klwmbyna,Коламбијана,Колумбиана,كلومبينا,کلمبیانا، اوهایو', 40.8883900, -80.6939600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141925, 'Columbus Grove', 'Columbus Grove', 'Columbus Grove,Pleasant', 40.9195000, -84.0568900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141926, 'Conneaut', 'Conneaut', 'Connaut,Conneaught,Conneaut,Koniot,Konniut,Lakeville,Port Independence,Salem,Stow Castle,kwnawt  awhayw,kwnw,Кониот,Конниут,كونو,کوناوت، اوهایو', 41.9475600, -80.5542400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141927, 'Continental', 'Continental', 'Continental,Marice,Marice City', 41.1003300, -84.2663400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141928, 'Convoy', 'Convoy', 'Convoy,East Tully,Tully', 40.9167200, -84.7027400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141929, 'Copley', 'Copley', 'Copely,Copley,Copley Center,Copley Centre,Coply,Greenfield', 41.0989400, -81.6445700, 'US', '2017-07-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141930, 'Cortland', 'Cortland', 'Baconsburg,Baconsburgh,Cortland,Leroy', 41.3303300, -80.7253600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141931, 'Coshocton', 'Coshocton', 'Bullets Town,Coshocton,Delaware Town,Forks of Muskingum,Goschachgunk,Koschachkink,Koshokton,Tuscarawas,Tuscurawa,Tuskarawa,kwshaktn  awhayw,kwshwktwn,Кошоктон,كوشوكتون,کوشاکتن، اوهایو', 40.2720200, -81.8595800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141932, 'Covington', 'Covington', 'Covington,Fort Buchanan,Fort Rowdy,Friendship,New Jefferson,Newberry,Newburg,Newbury,Redman,Stillwater', 40.1172700, -84.3538400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141933, 'Craig Beach', 'Craig Beach', '', 41.1170000, -80.9834200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141934, 'Sheffield', 'Sheffield', '', 41.4622200, -82.0986800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141935, 'Crestline', 'Crestline', 'Crest Line,Crestline,Livingston,Livingstone,North Livingston,Vernon Station', 40.7875600, -82.7365700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141936, 'Creston', 'Creston', 'Creston,Jackson,Old Hickory,Pike Station,Pikes Station,Saville,Seville Station,Sink Hole', 40.9870000, -81.8937500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141937, 'Cridersville', 'Cridersville', 'Cridersville,Criderville', 40.6542200, -84.1507800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141938, 'Curtice', 'Curtice', '', 41.6183800, -83.3677100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141939, 'Cuyahoga Falls', 'Cuyahoga Falls', 'Kajakhoga Fols,Kajakhoga-Fols,Kuakhoga Fols,kaieohogapolseu,kayahogaforuzu,kwyahwga fals  awhayw,kwyahwgha fwlz,Каяхога-Фолс,Кајахога Фолс,Куахога Фолс,كوياهوغا فولز,کواہوگا فالز، اوہائیو,کویاهوگا فالس، اوهایو,カヤホガフォールズ,카이어호가폴스', 41.1339400, -81.4845600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141940, 'Dalton', 'Dalton', 'Dalton,Dover,Middletown,Moscow,Sharon,Далтон', 40.7989400, -81.6954100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141941, 'Danville', 'Danville', 'Buckeye,Danville,Rossville', 40.4475600, -82.2601600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141942, 'De Graff', 'De Graff', 'De Graff,De Graft,DeGraff,Degraff,Degraft', 40.3120000, -83.9157700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141943, 'Defiance', 'Defiance', 'Au Glaize,DFI,Defajans,Defiance,Defians,Ensawacosa,Fort Defiance,Fort Miamis,Fort Winchester,Grand Glaize,Miami Fort,Miamis Fort,Tuendawie,Twendiawie,Winchester,dfyans  awhayw,difaiansu,dyfayns,Дефајанс,Дефианс,دفیانس، اوهایو,ديفاينس,ディファイアンス', 41.2844900, -84.3557800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141944, 'Delaware', 'Delaware', 'Delavarskij,Delaver,Delaware,Millville,derau~ea,dlawar  awhayw,dylawyr,Делаварский,Делавер,دلاوار، اوهایو,ديلاوير,デラウェア', 40.2986700, -83.0679700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141945, 'Delphos', 'Delphos', 'Bredeick,Dehlfos,Delfos,Delphos,East Bredeick,Howard,Howard Town,Section Ten,West Bredeick,dlfws,dlphws  awhayw,Делфос,Дэлфос,دلفوس,دلپهوس، اوهایو', 40.8433800, -84.3416200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141946, 'Delta', 'Delta', 'Delta,Fingerville,Greensprings,Slab Shanty,Tadmore,Tadpole', 41.5736600, -84.0052200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141947, 'Dennison', 'Dennison', 'Denison,Dennison', 40.3934000, -81.3337200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141948, 'Deshler', 'Deshler', '', 41.2075500, -83.8991100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141949, 'Dover', 'Dover', 'Canal Dover,Canal Dover Village,Dovehr,Dover,dwfr,dwwr  awhayw,Довер,Довэр,دوفر,دوور، اوهایو,ڈوور، اوہائیو', 40.5206200, -81.4740100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141950, 'Doylestown', 'Doylestown', 'Chippewa,Chippeway,Chuppewa,Doyleston,Doylestown', 40.9700500, -81.6965200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141951, 'Dresden', 'Dresden', 'Dresden,drysdn,Дресден,دريسدن', 40.1214600, -82.0106900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141952, 'Dublin', 'Dublin', 'Dablin,Dublin,Dublinas,daburin,dbln,deobeullin,dwblyn  awhayw,Даблин,Дублин,دبلن,دوبلین، اوهایو,ڈبلن، اوہائیو,ダブリン,더블린', 40.0992300, -83.1140800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141953, 'East Canton', 'East Canton', 'East Canton,Osnaburg,Osnaburgh', 40.7872800, -81.2826100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141954, 'East Cleveland', 'East Cleveland', 'Colamer,Collamer,Collamer Station,East Cleveland,Euclid,Ist Klivland,Ist Klivlehnd,Nine Mile Creek,ayst klyfland,iseuteukeullibeullaendeu,klywlnd shrqy  awhayw,Ист Кливланд,Ист Кливлэнд,إيست كليفلاند,کلیولند شرقی، اوهایو,이스트클리블랜드', 41.5331100, -81.5790100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141955, 'East Liverpool', 'East Liverpool', 'Crockery City,East Liverpool,Fawcetts Town,Fawcettstown,Ist Liverpul,Ist Liverpul'',Liverpool,Pottery Center of America,Saint Clair,ayst lyfrbwl,lywrpwl shrqy  awhayw,Ист Ливерпул,Ист Ливерпуль,إيست ليفربول,لیورپول شرقی، اوهایو', 40.6186800, -80.5772900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141956, 'East Palestine', 'East Palestine', 'East Palestine,Mechanicsburg,Palestine', 40.8339500, -80.5403500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141957, 'Eastlake', 'Eastlake', 'Eastlake,Eastlake City,Istlehjk,Istlejk,ayst lyk,Истлејк,Истлэйк,ايست ليك,ایست‌لیک، اوهایو', 41.6539400, -81.4503900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141958, 'Eaton Estates', 'Eaton Estates', '', 41.3089400, -82.0057000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141959, 'Edgerton', 'Edgerton', '', 41.4486600, -84.7480100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141960, 'Edgewood', 'Edgewood', 'East Village,Edgewood', 41.8728300, -80.7728600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141961, 'Elida', 'Elida', 'Danberry,Elida', 40.7886600, -84.2038400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141962, 'Elmore', 'Elmore', '', 41.4761600, -83.2957600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141963, 'Elyria', 'Elyria', 'Ehlajria,Ehlirija,Elirija,alyrya,alyrya  awhayw,eriria,yi li li ya,Елирија,Элайриа,Элирия,إليريا,الیریا، اوهایو,ایلیریا، اوہائیو,エリリア,伊利里亞', 41.3683800, -82.1076500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141964, 'Euclid', 'Euclid', 'East Euclid,Ehuklid,Euclid,Euclid Creek,Euclid Station,Euclid Village,Evklid,Juklid,awklyd  awhayw,ywklyd,Јуклид,Евклид,Эуклид,Юклид,اوکلید، اوهایو,ایوکلڈ، اوہائیو,يوكليد', 41.5931000, -81.5267900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141965, 'Fairlawn', 'Fairlawn', '', 41.1278300, -81.6098400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141966, 'Fairport Harbor', 'Fairport Harbor', 'Fairport,Fairport Harbor,Grandon', 41.7500400, -81.2739900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141967, 'Fairview Park', 'Fairview Park', 'Fairview,Fairview Park,Fairview Village,Fajavju Park,Fervju Park,fayrwyw park  awhayw,fyrfyw bark,Файавю Парк,Фервју Парк,فایرویو پارک، اوهایو,فيرفيو بارك,فیئرویو پارک، اوہائیو', 41.4414400, -81.8643000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141968, 'Fayette', 'Fayette', 'Fayette,Forham,Goram,Gorham', 41.6733800, -84.3268900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141969, 'Findlay', 'Findlay', 'FDY,Fajndlehj,Findli,findore,fndly,fyndlay  awhayw,pindeullei,Файндлэй,Финдли,Фіндлі,فندلي,فیندلای، اوهایو,フィンドレー,핀들레이', 41.0442200, -83.6499300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141970, 'Forest', 'Forest', '', 40.8017200, -83.5104800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141971, 'Fort Loramie', 'Fort Loramie', 'Berlin,Fort Loramie,Loramie,Loramies,Loramies Fort,Lorimies,Lormies', 40.3514400, -84.3738400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141972, 'Fort Recovery', 'Fort Recovery', 'Fort Recovery,Recovery', 40.4128200, -84.7763500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141973, 'Fort Shawnee', 'Fort Shawnee', '', 40.6867200, -84.1377300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141974, 'Fostoria', 'Fostoria', 'Fostoria,Fostorija,Risdon,Rome,Stoner,fwstwrya,fwstwrya  awhayw,Фосториа,Фосторија,فوستوريا,فوستوریا، اوهایو', 41.1570000, -83.4168700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141975, 'Frazeysburg', 'Frazeysburg', 'Edmunds,Frazersburg,Frazeyburg,Frazeysburg,Frazeysburgh,Knoxville', 40.1172900, -82.1193100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141976, 'Fredericktown', 'Fredericktown', 'Frederick,Frederick Station,Frederick Town,Frederickstown,Fredericktown,Frederiktaun,Fredricktown,Kerrs Mills,frydryktawn  awhayw,Фредериктаун,فريدريكتاون، أوهايو', 40.4811700, -82.5407200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141977, 'Fremont', 'Fremont', 'Croghanville,Freemont,Frehmont,Fremont,Frimont,Lower Sandusky,frmwnt  awhayw,frymwnt,peulimonteu,Фримонт,Фрэмонт,فرمونت، اوهایو,فريمونت,فریمونٹ، اوہائیو,프리몬트', 41.3503300, -83.1218600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141978, 'Gahanna', 'Gahanna', 'Bridgeport,Gahana,Gahanna,Gahannan,Gakhana,Gakhanna,gahana  awhayw,ghahana,Гахана,Гаханна,غاهانا,گاهانا، اوهایو', 40.0192300, -82.8793400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141979, 'Galion', 'Galion', 'GQQ,Galeon,Galijon,Galion,Goshen,Hardscrabble,Horseshoe,Hosfords,LovericksSettlement,Loverings,New Moccasin,Spangtown,Spongetown,The Corners,galywn  awhayw,ghalywn,Галион,Галијон,غاليون,گالیون، اوهایو', 40.7336700, -82.7899000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141980, 'Gambier', 'Gambier', '', 40.3756200, -82.3971000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141981, 'Garfield Heights', 'Garfield Heights', 'Garfield Heights,Garfild Khajts,Garfild Khehjts,South Newburgh,garfyld hayts  awhayw,gharfyld hayts,Гарфилд Хајтс,Гарфилд Хэйтс,غارفيلد هايتس,گارفیلد هایتس، اوهایو', 41.4170000, -81.6059600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141982, 'Garrettsville', 'Garrettsville', 'Garetsvil,Garretsville,Garrettesville,Garrettsville,Garrettsville Village,Garrits,Garrits Mill,gharytsfyl,Гаретсвил,غاريتسفيل', 41.2842200, -81.0964900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141983, 'Gates Mills', 'Gates Mills', 'Bates,Gates,Gates Mill,Gates Mills', 41.5175500, -81.4034500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141984, 'Geneva', 'Geneva', 'Dzeniva,Zheneva,gnwa  awhayw,jnyf,Џенива,Женева,جنيف,گنوا، اوهایو', 41.8050500, -80.9481500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141985, 'Geneva-on-the-Lake', 'Geneva-on-the-Lake', 'Buckeye Beach,Geneva-on-the-Lake', 41.8595000, -80.9539800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141986, 'Genoa', 'Genoa', '', 40.7828400, -81.4665100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141987, 'Gibsonburg', 'Gibsonburg', 'Gibsonburg,Gibsonburgh', 41.3845000, -83.3204800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141988, 'Girard', 'Girard', '', 41.1539500, -80.7014700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141989, 'Glandorf', 'Glandorf', 'Buck Eye,Buckeye,Glandorf,Glandorff,ghlandwrf,Гландорф,غلاندورف', 41.0289400, -84.0791100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141990, 'Glendale', 'Glendale', 'Glendale,Glendale Station', 41.3970000, -81.5423400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141991, 'Glenmoor', 'Glenmoor', 'Glenmoor,Kenmoor', 40.6661700, -80.6231300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141992, 'Gnadenhutten', 'Gnadenhutten', 'Gnaden''n,Gnadenhuetten,Gnadenhutten', 40.3584000, -81.4342800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141993, 'Grafton', 'Grafton', 'Grafton,Grafton Station,Rawsonville,ghraftwn,Графтон,غرافتون', 41.2725500, -82.0545900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141994, 'Granville', 'Granville', 'Granvil,ghranfyl,Гранвил,غرانفيل', 40.0681200, -82.5196000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141995, 'Green', 'Green', 'Grin,ghryn,gryn  awhayw,Грин,غرين,گرین، اوهایو', 40.9458900, -81.4831700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141996, 'Green Springs', 'Green Springs', 'Green Spring,Green Springs,Greenspring', 41.2561600, -83.0515800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141997, 'Greensburg', 'Greensburg', 'Greenburg,Greensburg,Greensburgh,Inland', 40.9317200, -81.4648400, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141998, 'Greentown', 'Greentown', 'Green,Green Town,Greenstown,Greentown,Greentown Station', 40.9275600, -81.4026100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(141999, 'Greenville', 'Greenville', 'Fort Green Ville,Fort Greenville,Greeneville,Greenville,Grinvil,Grinvill,Miamis Town,Tecumseh Point,Tecumsehs Spring,ghrynfyl,grynwyl  awhayw,Гринвил,Гринвилл,غرينفيل,گرینویل، اوهایو,گرینویل، اوہائیو', 40.1028300, -84.6330100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142000, 'Greenwich', 'Greenwich', 'Greenwich,Greenwich Station,Greenwick,Grinvich,Newtown,West Greenwich,Гринвич', 41.0300500, -82.5157300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142001, 'Hanover', 'Hanover', 'Fleming,Hanover,Licking,Natches,Natchez Under the Hill', 40.0797900, -82.2609800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142002, 'Hartville', 'Hartville', 'Hartsville,Hartville', 40.9636700, -81.3312200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142003, 'Haskins', 'Haskins', '', 41.4647700, -83.7060500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142004, 'Heath', 'Heath', 'Khis,Khit,hys  awhayw,hyth,Хис,Хит,هيث,هیس، اوهایو', 40.0228400, -82.4446000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142005, 'Hicksville', 'Hicksville', 'Hicksville,Hickville,Khiksvilla,Хиксвилла', 41.2931100, -84.7619000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142006, 'Highland Heights', 'Highland Heights', '', 41.5520000, -81.4784500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142007, 'Hilliard', 'Hilliard', 'Hilliard,Hilliard Village,Hilliards,Hilliards Station', 40.0334000, -83.1582500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142008, 'Hiram', 'Hiram', 'Hiram,Hiram Center,Hiram Centre,Hiram Hamlet,Khajram,hyram,Хајрам,هيرام', 41.3125600, -81.1437100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142009, 'Holgate', 'Holgate', 'Holgate,Kaufmanville', 41.2489400, -84.1330000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142010, 'Holland', 'Holland', 'Drakes,Gollandija,Hardy,Holland,Holland Station,Springfield,Голландия', 41.6217200, -83.7116000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142011, 'Howland Center', 'Howland Center', '', 41.2511700, -80.7453600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142012, 'Hubbard', 'Hubbard', 'Khabard,Khabbard,hwbard,Хабард,Хаббард,هوبارد,هیوب‌بارد، اوهایو', 41.1564500, -80.5692400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142013, 'Huber Ridge', 'Huber Ridge', '', 40.0886700, -82.9165700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142014, 'Hudson', 'Hudson', 'Gudzon,Hudson,Hudson Village,Khadson,ha de xun,hadswn  awhayw,hdsn,Гудзон,Хадсон,هادسون، اوهایو,هدسن,ہڈسن، اوہائیو,哈德遜', 41.2400600, -81.4406700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142015, 'Huron', 'Huron', 'Kharon,Khjuron,hwrwn,hwrwn  awhayw,Харон,Хјурон,هورون,هورون، اوهایو', 41.3950500, -82.5551700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142016, 'Independence', 'Independence', 'Center,Independehns,Independence,Independens,Pilgerruh,Pilgrims Rest,Thornburg,Thornburgh,andybndns  awhayw,ayndpndns  awhayw,Индепенденс,Индепендэнс,إنديبندنس، أوهايو,ایندپندنس، اوهایو', 41.3686600, -81.6379000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142017, 'Jackson Center', 'Jackson Center', 'Jackson Center,Jackson Centre', 40.4394900, -84.0402200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142018, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefferson,jfrswn,Џеферсон,Джефферсон,جفرسون', 41.7386700, -80.7698100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142019, 'Johnstown', 'Johnstown', 'Dzhonstaun,Джонстаун', 40.1536700, -82.6851700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142020, 'Kalida', 'Kalida', '', 40.9828300, -84.1993900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142021, 'Kent', 'Kent', 'Carthage,Franklin,Franklin Mills,Kent,Lower Village,ken te,kenta,kenteu,knt  awhayw,kynt,Кент,كينت,کنت، اوهایو,کینٹ، اوہائیو,केंट,肯特,켄트', 41.1536700, -81.3578900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142022, 'Kenton', 'Kenton', 'Fort McArthur,Kenton,McArthur,knt,Кентон,كنت', 40.6470000, -83.6096500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142023, 'Kirtland', 'Kirtland', 'Amenia,Kirkland,Kirtland,Kirtland Mills,Kirtlands Mills,Kirtlehnd,kyrtland,kyrtlnd  awhayw,Киртланд,Киртлэнд,كيرتلاند,کیرتلند، اوهایو', 41.6289400, -81.3615000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142024, 'La Croft', 'La Croft', '', 40.6459000, -80.5978500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142025, 'Lagrange', 'Lagrange', 'La Grange,La Grange Centre,Lagrange,Lagrange Centre', 41.2372800, -82.1198700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142026, 'Lake Mohawk', 'Lake Mohawk', '', 40.6667300, -81.1992700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142027, 'Lakemore', 'Lakemore', '', 41.0208900, -81.4359500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142028, 'Lakeview', 'Lakeview', 'Lake View,Lakeview', 40.4847700, -83.9230000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142029, 'Lakewood', 'Lakewood', 'Arlington,East Rockport,Lakewood,Lehjkvud,Lejkvud,leikeuudeu,lykwwd,lyyqwwd,reikuuddo,Лейквуд,Лејквуд,Лэйквуд,לייקווד,ليكوود,لیک ووڈ، اوہائیو,لیک‌وود، اوهایو,レイクウッド,레이크우드', 41.4819900, -81.7981900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142030, 'Leavittsburg', 'Leavittsburg', 'Leavittsburg,Leavittsburgh,Levitsburg,West Warren,Willow Dale', 41.2478300, -80.8770300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142031, 'Leetonia', 'Leetonia', 'Leetonia,Letonia', 40.8772800, -80.7553600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142032, 'Leipsic', 'Leipsic', 'Creighton,Leipsic,Leipsig,Lipsik,laybsyk,Липсик,لايبسيك', 41.0983800, -83.9846700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142033, 'Lewis Center', 'Lewis Center', 'Lewis Center,Lewis Centre', 40.1984000, -83.0101800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142034, 'Lexington', 'Lexington', 'Leksington,Lexington,New Lexington,lyksnghtn,Лексингтон,ليكسنغتن,لیکسنگٹن، اوہائیو', 40.6786700, -82.5823900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142035, 'Liberty Center', 'Liberty Center', 'Liberty,Liberty Center,Liberty Centre,Liberty Station', 41.4433800, -84.0088300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142036, 'Lima', 'Lima', 'AOH,Lima,laima,lyma,lyma  awhayw,raima,Лима,ليما,لیما، اوهایو,ライマ,라이마', 40.7425500, -84.1052300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142037, 'Lincoln Heights', 'Lincoln Heights', '', 40.7714500, -82.4843300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142038, 'Lisbon', 'Lisbon', 'Lisbon,New Lisbon,lisabana,lyzbwn,Лисбон,ليزبون,ਲਿਸਬਨ', 40.7720000, -80.7681300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142039, 'Lodi', 'Lodi', 'Harrisville,Lodi,Лоди', 41.0333900, -82.0120900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142040, 'Lorain', 'Lorain', 'Black River,Black River Settlement,Blackriver,Charleston,Charlestown,Lorain,Lorehjn,Lorejn,Loren,Mouth of Black River,luo lan,lwryn,lwryn  awhayw,lwryyn,rorein,Лорейн,Лорен,Лорэйн,לוריין,لورين,لورین، اوهایو,لورین، اوہائیو,ロレイン,洛兰', 41.4528200, -82.1823700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142041, 'Lordstown', 'Lordstown', 'Eden,Lordstown,Lordstown Center', 41.1656100, -80.8575800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142042, 'Loudonville', 'Loudonville', 'Londonville,Loudonville,Lowdenville', 40.6353400, -82.2332100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142043, 'Louisville', 'Louisville', 'Beechland,Lewisville,Louisvill,Louisville,Luisvil,Luivil,lwwyswyl  awhayw,lwyfyl,Лоуисвилл,Луивил,Луисвил,لوویسویل، اوهایو,لويفيل', 40.8372800, -81.2595500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142044, 'Lowellville', 'Lowellville', 'Lowell,Lowellville', 41.0353400, -80.5364600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142045, 'Luckey', 'Luckey', '', 41.4506100, -83.4874300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142046, 'Lyndhurst', 'Lyndhurst', 'Euclidville,Lindkherst,Lyndhurst,lyndhrst,lyndhwrst  awhayw,Линдхерст,ليندهرست,لیندهورست، اوهایو', 41.5200500, -81.4887300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142047, 'Macedonia', 'Macedonia', 'Macedonia,Macedonia Depot,Maedonia,Makedonija,Masidonija,masydwnya,mqdwnyh  awhayw,Македония,Македонија,Масидонија,ماسيدونيا,مقدونیه، اوهایو,مقدونیہ، اوہائیو', 41.3136700, -81.5084500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142048, 'Madison', 'Madison', 'Centreville,Chapintown,Madison,Madison Lakelands,Madison on the Lake,Medison,Mehdison,madyswn,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,میڈیسون، اوہائیو', 41.7711600, -81.0498200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142049, 'Malvern', 'Malvern', 'Lodi,Malvern,Troy', 40.6917300, -81.1812100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142050, 'Manchester', 'Manchester', 'Manchester,Nimisilia,Nimisilla,Turkey Foot Mine', 40.9370000, -81.5692900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142051, 'Mansfield', 'Mansfield', 'MFD,Mansfild,Mehnsfild,Mensfild,maenseupildeu,mansqyld,mansufirudo,mnsfyld  awhayw,mnspyld,Мансфилд,Менсфилд,Менсфілд,Мэнсфилд,מנספילד,مانسقيلد,منسفیلد، اوهایو,مینسفیلڈ، اوہائیو,マンスフィールド,맨스필드', 40.7583900, -82.5154500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142052, 'Mantua', 'Mantua', 'Creighton,Mantua', 40.0778500, -81.6790100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142053, 'Mantua', 'Mantua', 'Mantua,Mantua Station', 41.2839400, -81.2239900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142054, 'Maple Heights', 'Maple Heights', 'Mapl Khehjts,Mejpl Khajts,mybl hayts,mypl hayts  awhayw,Мапл Хэйтс,Мејпл Хајтс,ميبل هايتس,میپل هایتس، اوهایو', 41.4153300, -81.5659600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142055, 'Marion', 'Marion', 'Jacobs Well,MNN,Marion,Marion Court House,Mehrion,ma li en,marywn,marywn  awhayw,Марион,Мэрион,ماريون,ماریون، اوهایو,ماریون، اوہائیو,马里恩', 40.5886700, -83.1285200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142056, 'Martins Ferry', 'Martins Ferry', 'Franklin,Jefferson,Martin''s Ferry,Martins Fehrri,Martins Feri,Martins Ferry,Martinsville,Norristown,martynz fry  awhayw,martynz fyry,Мартинс Фери,Мартинс Фэрри,مارتينز فيري,مارتینز فری، اوهایو', 40.0959100, -80.7245300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142057, 'Marysville', 'Marysville', 'Marysville,Mehrisvill,Merisvil,Shaded City,Shady City,maryswyl  awhayw,mearizubiru,melijeubil,myryzfyl,Мерисвил,Мэрисвилл,ماریسویل، اوهایو,ميريزفيل,میریزویل، اوہائیو,メアリーズビル,메리즈빌', 40.2364500, -83.3671400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142058, 'Massillon', 'Massillon', 'Kendal,Kendall,Masillon,Masilon,Massillion,Massillon,Massilon,masillon,masylwn,masylwn  awhayw,Μάσιλον,Масилон,Массиллон,ماسيلون,ماسیلون، اوهایو,마실론', 40.7967200, -81.5215100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142059, 'Masury', 'Masury', '', 41.2111700, -80.5378500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142060, 'Maumee', 'Maumee', 'Fort Miami,Maumee,Maumee City,Maumi,Momi,Waynesville,mawmy,mawmy  awhayw,Мауми,Моми,ماومي,ماومی، اوهایو', 41.5628300, -83.6538200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142061, 'Mayfield', 'Mayfield', 'Mayfield,Mayfield Center,Mayfield Centre', 41.5520000, -81.4392800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142062, 'Mayfield Heights', 'Mayfield Heights', 'Mehjfild Khehjts,Mejfild Khajts,mayfyld hayts,myfyld hayts  awhayw,Мејфилд Хајтс,Мэйфилд Хэйтс,مايفيلد هايتس,میفیلد هایتس، اوهایو', 41.5192200, -81.4579000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142063, 'McComb', 'McComb', 'McComb,Pleasantville', 41.1075500, -83.7927100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142064, 'McDonald', 'McDonald', '', 41.1636700, -80.7242400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142065, 'McKinley Heights', 'McKinley Heights', '', 41.1836700, -80.7173000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142066, 'Mechanicsburg', 'Mechanicsburg', 'Mechanic,Mechanicsburg,Mechanicsburgh,Mekaniksburg,Tan Yard,Меканиксбург', 40.0720000, -83.5563100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142067, 'Medina', 'Medina', 'Mecca,Medajna,Medina,Medina Court House,mdyna,mdyna  awhayw,Медајна,Медина,مدينا,مدینا، اوهایو,مدینہ، اوہائیو', 41.1383900, -81.8637500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142068, 'Mentor', 'Mentor', 'Mehntor,Mentor,Mentor Station,mntwr,mntwr  awhayw,Ментор,Мэнтор,منتور,منتور، اوهایو', 41.6661600, -81.3395500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142069, 'Mentor-on-the-Lake', 'Mentor-on-the-Lake', '', 41.7050400, -81.3603900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142070, 'Middleburg Heights', 'Middleburg Heights', 'Middlburg,Middleburg Heights,Middleburgh Heights,Midlberg Khajts,mydlbrg hayts  awhayw,mydlbyrgh hayts,Миддлбург,Мидлберг Хајтс,ميدلبيرغ هايتس,میدلبرگ هایتس، اوهایو', 41.3614400, -81.8129100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142071, 'Middlefield', 'Middlefield', 'Batavia,Middlefield,Thompsons Corners', 41.4620000, -81.0737100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142072, 'Milan', 'Milan', 'Beatty,Camp Avery,Fort Avery,Majlan,Milan,New Salem,Paynothing,Peaquotting,Petquoting,mi lan,miran,mylan,Мајлан,Милан,ميلان,ミラン,米兰', 41.2975500, -82.6054500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142073, 'Millbury', 'Millbury', 'Clay Junction,Millbury,Millbury Junction', 41.5661600, -83.4246500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142074, 'Millersburg', 'Millersburg', 'Milersburg,Millersburg,Millersburgh,mylzbwrgh,Милерсбург,ميلزبورغ', 40.5545100, -81.9179200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142075, 'Mineral Ridge', 'Mineral Ridge', 'Mineral Ridge,Mineralridge,Weathersfield,Wethersfield', 41.1400600, -80.7689700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142076, 'Minerva', 'Minerva', 'Minerva,mynyrfa,Минерва,مينيرفا', 40.7297800, -81.1053800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142077, 'Minerva Park', 'Minerva Park', 'Minerva Lake,Minerva Park', 40.0764500, -82.9437900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142078, 'Mingo Junction', 'Mingo Junction', 'Mingo,Mingo Junction,Mingo Station,mynghw jankshn,مينغو جانكشن', 40.3217400, -80.6098000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142079, 'Minster', 'Minster', 'Minister,Minster,Muenster,Stallo Town,Stallostown,Stallotown,Stallows Town', 40.3931000, -84.3760600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142080, 'Mogadore', 'Mogadore', 'Bradleyville,Bradyville,Mogadore', 41.0464500, -81.3978900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142081, 'Monroeville', 'Monroeville', 'Monroe,Monroeville', 41.2442200, -82.6962900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142082, 'Montpelier', 'Montpelier', 'Eagle Creek,Egal Creek,Montpelier', 41.5845000, -84.6055100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142083, 'Moreland Hills', 'Moreland Hills', '', 41.4478300, -81.4276200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142084, 'Morgandale', 'Morgandale', '', 41.2656100, -80.7828600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142085, 'Mount Carmel', 'Mount Carmel', '', 41.2711600, -82.9368600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142086, 'Mount Gilead', 'Mount Gilead', 'Gilead,Maunt Gilijad,Mount Gilead,Whetsom,Whetstone,Youngstown,mawnt ghylad,Маунт Гилијад,ماونت غيلاد', 40.5492300, -82.8274000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142087, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,mawnt frnwn,mwwnt wrnwn  awhayw,Маунт Вернон,ماؤنٹ ورنن، اوہائیو,ماونت فرنون,موونت ورنون، اوهایو', 40.3934000, -82.4857200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142088, 'Munroe Falls', 'Munroe Falls', 'Florence,Monroe Falls,Munroe,Munroe Falls', 41.1445000, -81.4398300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142089, 'Napoleon', 'Napoleon', 'Napoleon,Napoleón,Napolion,nabwlywn  awhayw,napwlywn  awhayw,Наполеон,Наполион,نابوليون، أوهايو,ناپولئون، اوهایو', 41.3922700, -84.1252200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142090, 'Navarre', 'Navarre', 'Bethlehem,Nasvarra,Navarra,Navarre,Rochester', 40.7245000, -81.5220700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142091, 'New Albany', 'New Albany', 'Hope,N''ju Albani,N''ju-Albani,New Albany,Nju Olbani,nyw albany,nyw albany  awhayw,Њу Олбани,Нью Албани,Нью-Албани,نيو ألباني,نیو آلبانی، اوهایو', 40.0811700, -82.8087900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142092, 'New Bremen', 'New Bremen', 'Bremen,New Bremen,Nju Bremen,nyw brymyn,Њу Бремен,نيو بريمين', 40.4369900, -84.3796700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142093, 'New California', 'New California', '', 40.1561700, -83.2365800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142094, 'New Franklin', 'New Franklin', '', 40.9417200, -81.5415100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142095, 'New London', 'New London', 'Kings Corners,Kinsleys Corners,Merrifield,Merrifield Settlement,N''ju-London,New London,Nova Londres,Нью-Лондон', 41.0850500, -82.3998900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142096, 'New Middletown', 'New Middletown', '', 40.9611700, -80.5575700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142097, 'New Philadelphia', 'New Philadelphia', 'N''ju Filadel''fija,New Philadelphia,Nju Filadelfija,PHD,Philadelphia,nyw fyladlfya,nyw fyladlfya  awhayw,Њу Филаделфија,Нью Филадельфия,نيو فيلادلفيا,نیو فیلادلفیا، اوهایو', 40.4897900, -81.4456700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142098, 'New Waterford', 'New Waterford', 'Bull Creek,New Waterford', 40.8450600, -80.6145200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142099, 'Newark', 'Newark', 'N''juark,New Ark,Newark,Njuark,nyuaku,nywark,nywark  awhayw,Њуарк,Ньюарк,نيوارك,نیوآرک، اوہائیو,نیوارک، اوهایو,ニューアーク', 40.0581200, -82.4012600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142100, 'Newburgh Heights', 'Newburgh Heights', 'Cleveland Mills,Newburg,Newburg Mills,Newburgh,Newburgh Heights,Newbury,Newsburg', 41.4500500, -81.6634600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142101, 'Newcomerstown', 'Newcomerstown', 'Des Nouveaux Venus,Gekelemukpechunk,Neighbortown,New Camero Town,New Comers Town,New Comerstown,Newcomers,Newcomers Town,Newcomers Village,Newcomerstown,Newcommerstown', 40.2722900, -81.6059500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142102, 'Newton Falls', 'Newton Falls', 'Du Boisville,Duboiseville,Earlesville,Earlville,Lower Village,N''juton Fols,Newton,Newton Falls,Njuton Fols,nywtn fwlz,nywtwn fals  awhayw,Њутон Фолс,Ньютон Фолс,نيوتن فولز,نیوتون فالس، اوهایو', 41.1883900, -80.9781500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142103, 'Niles', 'Niles', 'Heatons Furnace,Mahoning,Mahoning Salt Springs,Mohoning,Najls,Niles,Niles City,Nilestown,naylz,ni er si,nylz  awhayw,Найлс,Најлс,نايلز,نیلز، اوهایو,尼爾斯', 41.1828400, -80.7653600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142104, 'North Baltimore', 'North Baltimore', '', 41.1828300, -83.6782700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142105, 'North Canton', 'North Canton', 'Berlin,Marchant,New Berlin,North Canton', 40.8758900, -81.4023400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142106, 'North Kingsville', 'North Kingsville', 'Kingsville Station,North Kingsville', 41.9058900, -80.6903600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142107, 'North Lewisburg', 'North Lewisburg', 'Lewisburg,North Lewisburg,North Lewisburgh', 40.2231100, -83.5574300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142108, 'North Madison', 'North Madison', '', 41.8020000, -81.0489900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142109, 'North Olmsted', 'North Olmsted', 'Nors Olmstehd,Nort Olmsted,awlmstd shmaly  awhayw,nwrth awlmstyd,Норс Олмстэд,Норт Олмстед,اولمستد شمالی، اوهایو,نورث أولمستيد', 41.4156000, -81.9234700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142110, 'North Randall', 'North Randall', 'North Randal,North Randall,Plank Road,Plank Road Station,Randall,Randall Heights,Randall Station', 41.4347800, -81.5256800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142111, 'North Ridgeville', 'North Ridgeville', 'Nors Ridzhvill,Nort Ridzvil,North Ridgeville,Ridgeville,Ridgeville Centre,nwrth rydjfyl,ryjwyl shmaly  awhayw,Норс Риджвилл,Норт Риџвил,ریجویل شمالی، اوهایو,نورث ريدجفيل', 41.3894900, -82.0190300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142112, 'North Royalton', 'North Royalton', 'Nors Rojalton,Nort,North Royalton,Royalton,Royalton Center,nwrth rwyaltwn,rwyaltwn shmaly  awhayw,Норс Роялтон,Норт,رویالتون شمالی، اوهایو,نورث رويالتون', 41.3136600, -81.7245700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142113, 'Northfield', 'Northfield', '', 41.3450500, -81.5284500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142114, 'Northwood', 'Northwood', '', 40.4728300, -83.7324300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142115, 'Northwood', 'Northwood', '', 41.6072700, -83.4688200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142116, 'Norton', 'Norton', 'Norton,Norton Center,Norton Centre,Norton Corners', 41.0292200, -81.6381800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142117, 'Norwalk', 'Norwalk', 'Norvok,Norvolk,nowokeu,nwrwak  awhayw,Норвок,Норволк,نورواك، أوهايو,نورواک، اوهایو,노워크', 41.2425500, -82.6157300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142118, 'Oak Harbor', 'Oak Harbor', 'Hartford,Oak Harbor,Oakharbor,Port Leron', 41.5067200, -83.1465900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142119, 'Oak Hill', 'Oak Hill', '', 40.4142300, -82.2409900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142120, 'Oakwood', 'Oakwood', '', 41.3653300, -81.5079000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142121, 'Oberlin', 'Oberlin', 'Oberle,Oberlin,awbrlyn,awbrlyn  awhayw,Оберле,Оберлин,Оберлін,أوبرلين,اوبرلین، اوهایو', 41.2939400, -82.2173800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142122, 'Olmsted Falls', 'Olmsted Falls', 'Norris Falls,Olmstead,Olmsted,Olmsted Falls,Olmsted Fols,Olmstehd Folls,awlmstd fals  awhayw,fwls awlmstyd,Олмстед Фолс,Олмстэд Фоллс,اولمستد فالس، اوهایو,فولس أولمستيد', 41.3750500, -81.9081900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142123, 'Ontario', 'Ontario', 'New Castle,Ontario,Онтарио', 40.7595000, -82.5901700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142124, 'Orange', 'Orange', 'Barry,Orange,Orange Center,Orange Centre,Orange Village', 41.4497800, -81.4806700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142125, 'Oregon', 'Oregon', 'Oregon,awrgwn  awhayw,awryghwn,Орегон,أوريغون,اورگون، اوهایو', 41.6436600, -83.4868800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142126, 'Orrville', 'Orrville', 'Orrvill,Orrville,Orvil,Orville,awrfyl,awrwyl  awhayw,Орвил,Оррвилл,أورفيل,اورویل، اوهایو', 40.8436700, -81.7640200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142127, 'Orwell', 'Orwell', 'Leffingwell,Orwell', 41.5350600, -80.8681400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142128, 'Ottawa', 'Ottawa', 'Buckey,Lower Tauwa,Lower Tawa,Ocquanoxa,Ocquenesiestown,Otava,Ottawa,Ottowa,Tauwa Town,Tawa Town,Tawa Village,awtawa,Отава,أوتاوا,اوٹاوا، اوہائیو', 41.0192200, -84.0471700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142129, 'Ottawa Hills', 'Ottawa Hills', 'Ottawa Hill,Ottawa Hills', 41.6642200, -83.6432700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142130, 'Painesville', 'Painesville', 'Champion,Newmarket,PVZ,Painesville,Pehjnsvill,Pejnsvil,baynsfyl,pynswyl  awhayw,Пејнсвил,Пэйнсвилл,باينسفيل,پینسویل، اوهایو', 41.7244900, -81.2456600, 'US', '2017-07-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142131, 'Pandora', 'Pandora', 'Columbia,Pandora,Pendleton', 40.9481100, -83.9610500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142132, 'Parma', 'Parma', 'Parma,barma,pama,parma  awhayw,Парма,פארמה,بارما,پارما، اوهایو,پارما، اوہائیو,パーマ,파마', 41.4047700, -81.7229100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142133, 'Parma Heights', 'Parma Heights', 'Parma,Parma Heights,Parma Khajts,Parma Khehjts,barma hayts,parma hayts  awhayw,Парма Хајтс,Парма Хэйтс,بارما هايتس,پارما هایتس، اوهایو', 41.3900500, -81.7595800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142134, 'Paulding', 'Paulding', 'Polding,bwldyngh,Полдинг,بولدينغ', 41.1381100, -84.5805100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142135, 'Payne', 'Payne', 'Mallotsville,Payne', 41.0775500, -84.7271800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142136, 'Pemberville', 'Pemberville', '', 41.4108900, -83.4610400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142137, 'Peninsula', 'Peninsula', '', 41.2411700, -81.5526200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142138, 'Pepper Pike', 'Pepper Pike', 'Pehpper Pajk,Peper Pajk,bbr bayk,pei po pai ke,ppr pyk  awhayw,Пепер Пајк,Пэппер Пайк,ببر بايك,پپر پیک، اوهایو,佩珀派克', 41.4783900, -81.4637300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142139, 'Perry', 'Perry', '', 41.7603300, -81.1409300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142140, 'Perry Heights', 'Perry Heights', '', 40.7953400, -81.4734500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142141, 'Perrysburg', 'Perrysburg', 'Orleans of the North,Pehrrisburg,Perisburg,Perrysburg,Perrysburgh,byrysbwrgh,prysbwrg  awhayw,Перисбург,Пэррисбург,بيريسبورغ,پریسبورگ، اوهایو', 41.5570000, -83.6271600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142142, 'Pioneer', 'Pioneer', '', 41.6800500, -84.5530100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142143, 'Piqua', 'Piqua', 'Chillicothe,Lower Piqua,Pickawillany,Picks Town,Pikua,Pikvej,Piqua,Piqua Town,Piquatown,Tawixtwi,Washington,bykwa,pykwa  awhayw,Пиквеј,Пикуа,بيكوا,پیکوا، اوهایو', 40.1447700, -84.2424400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142144, 'Plain City', 'Plain City', 'Darby,Darby Creek,Plain City,Pleasant Valley,Plejin Siti,Westminister,blayn syty,Плејин Сити,بلاين سيتي', 40.1075600, -83.2674200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142145, 'Pleasant Hill', 'Pleasant Hill', 'Newton,Pleasant Hill,Pleasanthill', 40.0517200, -84.3443900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142146, 'Plymouth', 'Plymouth', 'Plimut,Плимут', 40.9956100, -82.6671200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142147, 'Poland', 'Poland', 'Fowlers,Poland,Riland', 41.0242300, -80.6148000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142148, 'Port Clinton', 'Port Clinton', 'Port Clinton,Port Klinton,Portage,bwrt klyntwn,pwrt klyntwn  awhayw,Порт Клинтон,بورت كلينتون,پورت کلینتون، اوهایو', 41.5120000, -82.9376900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142149, 'Portage Lakes', 'Portage Lakes', '', 41.0072800, -81.5270600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142150, 'Powell', 'Powell', 'Powell,Powell Station', 40.1578400, -83.0751900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142151, 'Prospect', 'Prospect', 'Middletown,Prospect', 40.4503400, -83.1885300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142152, 'Ravenna', 'Ravenna', 'Ravehnna,Ravena,Ravenna,Revenna,Tinnicum,rafyna,rawna  awhayw,Равена,Равэнна,رافينا,راونا، اوهایو', 41.1575600, -81.2420500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142153, 'Reminderville', 'Reminderville', '', 41.3458900, -81.3951100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142154, 'Richfield', 'Richfield', 'East Center,East Centre,Richfield', 41.2397800, -81.6381800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142155, 'Richmond Heights', 'Richmond Heights', 'Claribel,Richmond Heights', 41.5528300, -81.5101200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142156, 'Richville', 'Richville', 'Pallow,Richville', 40.7511700, -81.4779000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142157, 'Richwood', 'Richwood', 'Rich Wood,Richland,Richmond,Richwood', 40.4264500, -83.2968600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142158, 'Rittman', 'Rittman', 'Milton Station,New Prospect,Ritman,Rittman,Rittman Station,Shinersburg', 40.9781100, -81.7820800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142159, 'Roaming Shores', 'Roaming Shores', '', 41.6431100, -80.8234200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142160, 'Rockford', 'Rockford', 'Old Town,Rockford,Shane Crossing,Shanes Crossing,Shanes Crossings,Shanesville', 40.6878300, -84.6466300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142161, 'Rockford', 'Rockford', 'Rockford,Rocksford', 40.4770100, -81.3084400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142162, 'Rocky River', 'Rocky River', 'Roki River,Rokki Riveh,raky rywr  awhayw,rwky ryfyr,Роки Ривер,Рокки Ривэ,راکی ریور، اوهایو,راکی ریور، اوہائیو,روكي ريفير', 41.4756000, -81.8393000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142163, 'Rossford', 'Rossford', 'Rosford,Rossford,rwsfwrd,rwsfwrd  awhayw,Россфорд,Росфорд,روسفورد,روسفورد، اوهایو', 41.6097700, -83.5643800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142164, 'Russells Point', 'Russells Point', 'Russell Point,Russells Point,Russels Point', 40.4711600, -83.8927200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142165, 'Saint Clairsville', 'Saint Clairsville', 'Newellstown,Saint Clairsville', 40.0806300, -80.9000900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142166, 'Saint Henry', 'Saint Henry', 'Saint Henry,Saint Henrys', 40.4175500, -84.6396800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142167, 'Saint Marys', 'Saint Marys', 'Fort Barbee,Fort Saint Marys,Girtys Town,Girtystown,Kettle Town,Saint Marys', 40.5422700, -84.3894000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142168, 'Saint Paris', 'Saint Paris', 'New Paris,Paris,Saint Paris', 40.1283900, -83.9596600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142169, 'Salem', 'Salem', 'Salem,Sejlem,salm  awhayw,salym,Салем,Сейлем,Сејлем,سالم، اوهایو,ساليم,سیلم، اوہائیو', 40.9008900, -80.8567500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142170, 'Salineville', 'Salineville', 'Salinesville,Salineville', 40.6225600, -80.8378600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142171, 'Sandusky', 'Sandusky', 'Fort Stephenson,Portland,SKY,Sandaski,Sandusky,Sandusky City,sandwsky,sang da si ji,seondeoseuki,sndwsky  awhayw,Сандаски,ساندوسكي,سندوسکی، اوهایو,桑达斯基,선더스키', 41.4489400, -82.7079600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142172, 'Sawyerwood', 'Sawyerwood', '', 41.0378300, -81.4409500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142173, 'Sebring', 'Sebring', '', 40.9228400, -81.0189800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142174, 'Seven Hills', 'Seven Hills', '', 41.3953300, -81.6762400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142175, 'Seville', 'Seville', 'Burgh,Guilford,Guilford Center,Hosmers Opening,Saville,Seville', 41.0100600, -81.8623600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142176, 'Shaker Heights', 'Shaker Heights', 'East View,North Union,Shaker Heights,Shaker Village,Shehjker Khehjts,Shejker Khajts,shakyr hayts,shykr hayts  awhayw,syeikeohaicheu,Шејкер Хајтс,Шэйкер Хэйтс,شاكير هايتس,شیکر هایتس، اوهایو,셰이커하이츠', 41.4739400, -81.5370700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142177, 'Sheffield', 'Sheffield', 'Sheffield,Sheffield Village', 41.4211500, -82.0962600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142178, 'Sheffield Lake', 'Sheffield Lake', 'Randall Grove,Randall''s Grove,Sheffield Lake', 41.4875400, -82.1015400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142179, 'Shelby', 'Shelby', 'Gambles Mills,Sharon,Shehlbi,Shelbi,Shelby,Shelby Junction,shlby  awhayw,shylby,syelbi,Шелби,Шэлби,شلبی، اوهایو,شيلبي,셸비', 40.8814500, -82.6618400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142180, 'Shreve', 'Shreve', '', 40.6814500, -82.0218100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142181, 'Sidney', 'Sidney', 'Sidnehj,Sidnej,Sidney,Sidni,Sydney,sydny,sydny  awhayw,Сидней,Сидни,Сиднэй,سيدني,سیدنی، اوهایو', 40.2842200, -84.1555000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142182, 'Silver Lake', 'Silver Lake', 'Silver Lake,Silver Lake Station', 41.1589500, -81.4542800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142183, 'Smithville', 'Smithville', 'Chatauqua,Chautauqua,Smithville', 40.8622800, -81.8618000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142184, 'Solon', 'Solon', 'Solon,Soulon,swlwn,swlwn  awhayw,Солон,Соулон,سولون,سولون، اوهایو', 41.3897800, -81.4412300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142185, 'South Amherst', 'South Amherst', 'Little Whig Hole,Little Whighole,Podunk,South Amherst,South Ridge', 41.3558800, -82.2537700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142186, 'South Canal', 'South Canal', '', 41.1772800, -80.9867600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142187, 'South Euclid', 'South Euclid', 'Saut Juklid,Sous Euklid,awklyd jnwby  awhayw,sawth awklyd,Саут Јуклид,Соус Еуклид,اوکلید جنوبی، اوهایو,ساوث إوكليد', 41.5231100, -81.5184600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142188, 'South Russell', 'South Russell', '', 41.4314400, -81.3653900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142189, 'Spencerville', 'Spencerville', 'Acadia,Spencer,Spencerville', 40.7089400, -84.3535600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142190, 'Steubenville', 'Steubenville', 'Mingo Town,Steubenville,Stiubenvilis,Stjubehnvill,Stubenvil,Stubenville,astwbnwyl  awhayw,si tuo ben wei er,stwbnfyl,suchubenbiru,Стубенвил,Стюбэнвилл,استوبنویل، اوهایو,ستوبنفيل,スチューベンビル,斯托本维尔', 40.3697900, -80.6339600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142191, 'Stony Prairie', 'Stony Prairie', '', 41.3514400, -83.1552000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142192, 'Stow', 'Stow', 'Stou,Stow,Stow Corners,Stowe,Stows Corners,astww  awhayw,stw,Стоу,استوو، اوهایو,ستو', 41.1595000, -81.4403900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142193, 'Strasburg', 'Strasburg', 'Strasburg,Strasburgh,Strassburgh', 40.5947800, -81.5267900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142194, 'Streetsboro', 'Streetsboro', 'Streetsboro,Streetsboro Center,Streetsborough,Stritborou,Stritsboro,astrytsbwrw  awhayw,strytsbwrw,Стритбороу,Стритсборо,استریتسبورو، اوهایو,ستريتسبورو', 41.2392200, -81.3459400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142195, 'Strongsville', 'Strongsville', 'Strangsville Centre,Strongsvil,Strongsvil'',Strongsvill,Strongsville,Strongville,astrwngswyl  awhayw,strwnghsfyl,Стронгсвил,Стронгсвилл,Стронґсвіль,استرونگسویل، اوهایو,سترونغسفيل', 41.3145000, -81.8356900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142196, 'Struthers', 'Struthers', 'Struther,Struthers', 41.0525600, -80.6078500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142197, 'Stryker', 'Stryker', 'Stryker,Williamsport', 41.5036600, -84.4141200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142198, 'Sugarcreek', 'Sugarcreek', 'Sugar Creek,Sugar Creek Station,Sugarcreek', 40.5031200, -81.6409600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142199, 'Sunbury', 'Sunbury', '', 40.2425600, -82.8590700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142200, 'Swanton', 'Swanton', 'Centreville,Svonton,Swanton,West Swanton,swantwn,Свонтон,سوانتون', 41.5886600, -83.8910500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142201, 'Sylvania', 'Sylvania', 'Silvania,Silvejnija,Sylvania,Whiteford,sylfanya,sylwanya  awhayw,Силваниа,Силвејнија,سيلفانيا,سیلوانیا، اوهایو', 41.7189400, -83.7129900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142202, 'Tallmadge', 'Tallmadge', 'Center,Tallmadge,Tallmadge Center,Tallmadge Centre,Talmadge Center,Talmidz,Tolmehjdzh,talmdj  awhayw,tlmadgh,Талмиџ,Толмэйдж,تالمدج، اوهایو,تلمادغ', 41.1014500, -81.4417800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142203, 'Tiffin', 'Tiffin', 'Fort Ball,Oakley,Tiffin,Tifin,di fen,tyfyn,tyfyn  awhayw,Тифин,Тиффин,تيفين,تیفین، اوهایو,ٹفن، اوہائیو,蒂芬', 41.1145000, -83.1779700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142204, 'Tiltonsville', 'Tiltonsville', 'Grover,Tiltonsville,Tiltonville', 40.1667400, -80.6998000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142205, 'Toledo', 'Toledo', 'Fort Industry,Gorad Talida,Port Lawrence,TOL,Toledo,Tolido,Tolīdo,Upper Toledo,Vistula,teollido,tolido,toredo,tuo lai duo,twldw,twlydw,twlydw  awhayw,Горад Таліда,Толедо,Толидо,Толідо,Թոլեդո,טולדו,توليدو,تولیدو، اوهایو,ٹولیڈو، اوہائیو,टॉलिडो,トレド,托莱多,털리도', 41.6639400, -83.5552100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142206, 'Toronto', 'Toronto', 'Jeddo Station,Newburg,Newburgh,Sloans,Sloans Hollow,Sloans Station,Toronto,twrntw  awhayw,twrwntw,Торонто,تورنتو، اوهایو,تورونتو', 40.4642300, -80.6009100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142207, 'Troy', 'Troy', 'Troj,Troja,teuloi,trwy,trwy  awhayw,Трой,Троя,Трој,تروي,تروی، اوهایو,ٹرائے، اوہائیو,트로이', 40.0395000, -84.2032800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142208, 'Tuscarawas', 'Tuscarawas', 'Trenton,Tuscarawas,Tuscarawastown,Tuscaroraas,Tuscorawies,Tuskarawas,Tuskaroras', 40.3947900, -81.4070600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142209, 'Twinsburg', 'Twinsburg', 'Millsville,Tuinsberg,Tvinsberg,Tvinsburg,Twinsburg,Twinsburg Center,Twinsburgh,Twinsburgh Center,twynsbwrg  awhayw,twynsbwrgh,Твинсберг,Твинсбург,Туинсберг,توينسبورغ,توینسبورگ، اوهایو', 41.3125600, -81.4401100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142210, 'Uhrichsville', 'Uhrichsville', 'Akhrichsvill,Egypt,Uhrichs Mill,Uhrichsville,Uhricksville,Ulricks Mills,Urichsville,Waterford,awhrychswyl  awhayw,ywhrytshsfyl,Ахричсвилл,اوهریچسویل، اوهایو,يوهريتشسفيل', 40.3931200, -81.3465000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142211, 'Union City', 'Union City', 'Junion-Siti,Union,Union City,Юнион-Сити', 40.1994900, -84.8052400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142212, 'Uniontown', 'Uniontown', 'Lake,Myersville,Union,Uniontown', 40.9750600, -81.4081700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142213, 'University Heights', 'University Heights', 'Idlewood,Idlewood Village,Junivehrsiti Khehjts,Juniversiti Khajts,University Heights,da xue gao de,ywnyfyrsyty hayts,ywnywrsyty hayts  awhayw,Јуниверсити Хајтс,Юнивэрсити Хэйтс,يونيفيرسيتي هايتس,یونیورسیتی هایتس، اوهایو,大学高地', 41.4978300, -81.5373500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142214, 'Upper Sandusky', 'Upper Sandusky', 'Aper Sandaski,Appa Sandaski,Fort Feree,Fort Ferree,Upper Sandusky,apr sndwsky  awhayw,awbyr sandwsky,Апер Сандаски,Аппа Сандаски,أوبير ساندوسكي,اپر سندوسکی، اوهایو', 40.8272800, -83.2813100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142215, 'Urbana', 'Urbana', 'Urbana,Urbana City,Urbanna,e ba na,wrbana  awhayw,ywrbana,Урбана,اوربانا، اوہائیو,وربانا، اوهایو,يوربانا,厄巴那', 40.1083900, -83.7524300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142216, 'Utica', 'Utica', 'Robertsons Mills,Utica,Wilmington', 40.2342300, -82.4512700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142217, 'Valley View', 'Valley View', 'Vali Vju,Valley View,Valley View Village,Вали Вју', 41.3878300, -81.6045700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142218, 'Vermilion', 'Vermilion', 'Vehrmilion,Vermilion,Vermillion,wrmylywn  awhayw,Вермилион,Вэрмилион,ورمیلیون، اوهایو', 41.4219900, -82.3646100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142219, 'Van Wert', 'Van Wert', 'Van Vehrt,Van Vert,Van Wert,Vanwert,fan wyrt,wn wrt  awhayw,Ван Верт,Ван Вэрт,فان ويرت,ون ورت، اوهایو', 40.8694900, -84.5841200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142220, 'Vermilion-on-the-Lake', 'Vermilion-on-the-Lake', '', 41.4283800, -82.3237700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142221, 'Versailles', 'Versailles', 'Jacksonville,Versailes,Versailles,Versaj,Verseilles,farsaylys,Версај,فارسايليس', 40.2225500, -84.4844000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142222, 'Wadsworth', 'Wadsworth', 'Vadsvors,Vodsvort,Wadsworth,Wadsworth City,wa si wo si,wadzwrth,wadzwrth  awhayw,Вадсворс,Водсворт,وادزورث,وادزورث، اوهایو,瓦斯沃斯', 41.0256100, -81.7298500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142223, 'Wakeman', 'Wakeman', 'Wakeman,Wakemanville', 41.2545000, -82.3996100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142224, 'Walbridge', 'Walbridge', '', 41.5878300, -83.4932700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142225, 'Walton Hills', 'Walton Hills', '', 41.3656100, -81.5612300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142226, 'Wapakoneta', 'Wapakoneta', 'AXV,Logans Village,Uapakoneta,Vapakoneta,Wapaghkanetta,Wapaghkonetta,Wapaghonetta,Wapahkonetta,Wapakanotta,Wapakonakunge,Wapakonatta,Wapakoneta,Wapakonkunge,Wapakonnetta,Wapauckanata,Wapaughkonetta,Wapaughkonnetta,Wapaukonnetta,Wapoghoognata,Wappakonetta,Wappakonneta,Wappaukenata,Wapucconetta,Warpicanata,Waughpaughkonetta,Wauphauthawonaukee,wabakwnyta,wapakwnta  awhayw,Вапаконета,Уапаконета,واباكونيتا,واپاکونتا، اوهایو', 40.5678300, -84.1935600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142227, 'Warrensville Heights', 'Warrensville Heights', 'Varrehnsvill Khehjts,Vorensvil Khajts,Warrensdale,Warrensville,Warrensville Heights,warnsfyl hayts,warnswyl hayts  awhayw,Варрэнсвилл Хэйтс,Воренсвил Хајтс,وارنسفيل هايتس,وارنسویل هایتس، اوهایو', 41.4350500, -81.5362300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142228, 'Waterville', 'Waterville', '', 41.5008900, -83.7182700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142229, 'Warren', 'Warren', 'Salt Lick Town,Saltlick Town,Uorren,Uorun,Varrehn,Voren,Warren,Warren City,warn  awhayw,woleon,Варрэн,Ворен,Уоррен,Уорън,وارن، اوهایو,워런', 41.2375600, -80.8184200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142230, 'Wauseon', 'Wauseon', '', 41.5492200, -84.1416100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142231, 'Wellington', 'Wellington', 'Velington,Vellington,wylynghtwn,Велингтон,Веллингтон,ويلينغتون,ویلنگٹن، اوہائیو', 41.1689400, -82.2179400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142232, 'Wellsville', 'Wellsville', '', 40.6028400, -80.6489600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142233, 'West Hill', 'West Hill', 'Slope,West Hill', 41.2328300, -80.5192400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142234, 'West Lafayette', 'West Lafayette', 'West LaFayette,West Lafayette,Zapadnyj Lafajet,Западный Лафайет', 40.2753500, -81.7509600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142235, 'West Liberty', 'West Liberty', 'Enochs Mills,Liberty,West Liberty', 40.2522800, -83.7557700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142236, 'West Salem', 'West Salem', '', 40.9714400, -82.1098700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142237, 'West Unity', 'West Unity', '', 41.5861600, -84.4349500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142238, 'Westerville', 'Westerville', 'Vehstervill,Vestvil,Westervelt,Westerville,wstrwyl  awhayw,wystyrfyl,Вествил,Вэстервилл,وسترویل، اوهایو,ويستيرفيل', 40.1261700, -82.9290700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142239, 'Westfield Center', 'Westfield Center', 'Le Roy,LeRoy,Leroy,Westfield Center,Westfield Centre', 41.0264400, -81.9332000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142240, 'Westlake', 'Westlake', 'Dover,Dover Center,Dover Centre,Vehstlehjk,Vestlejk,West Lake,Westlake,wyst lyk,Вестлејк,Вэстлэйк,وست‌لیک، اوهایو,ويست ليك', 41.4553200, -81.9179200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142241, 'Weston', 'Weston', 'Benton,Taylortown,Uehston,Weston,Weston Station,Уэстон', 41.3447700, -83.7971600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142242, 'Whitehouse', 'Whitehouse', 'White House,Whitehouse', 41.5189400, -83.8038300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142243, 'Wickliffe', 'Wickliffe', 'Viklif,Vikliff,Wickliff,Wickliffe,wyklayf,wyklyf  awhayw,Виклиф,Виклифф,ويكلايف,ویکلیف، اوهایو', 41.6053300, -81.4534500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142244, 'Willard', 'Willard', 'Chicago,Chicago Juncion,Willard', 41.0531100, -82.7262900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142245, 'Willoughby', 'Willoughby', 'Chagrin,Chagrin Mills,Uilloubi,Willoughby,Уиллоуби', 41.6397700, -81.4065000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142246, 'Willoughby Hills', 'Willoughby Hills', '', 41.5983800, -81.4184500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142247, 'Willowick', 'Willowick', '', 41.6331000, -81.4687300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142248, 'Windham', 'Windham', 'Strongsburg,Windham,Windham Center,Windham Village', 41.2350600, -81.0492600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142249, 'Wintersville', 'Wintersville', 'Richmond,Wintersville,Winterville', 40.3753500, -80.7036900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142250, 'Wolfhurst', 'Wolfhurst', '', 40.0692400, -80.7837000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142251, 'Woodville', 'Woodville', '', 41.4514400, -83.3657600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142252, 'Wooster', 'Wooster', 'BJJ,Vustehr,Vuster,usuta,wwstr  awhayw,wwstyr,Вустер,Вустэр,ووستر، اوهایو,ووستير,ウースター', 40.8051700, -81.9364600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142253, 'Worthington', 'Worthington', 'Vorsington,Vortington,wajinton,wwrdyngtn  awhayw,wwrthynghtwn,Ворсингтон,Вортингтон,وورثينغتون,ووردینگتن، اوهایو,ワージントン', 40.0931200, -83.0179600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142254, 'Yorkville', 'Yorkville', '', 40.1545200, -80.7103600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142255, 'Youngstown', 'Youngstown', 'Jangstaun,Jangstauna,Jongstaun,Jungstaun,YNG,Youngs Town,Youngstown,yang si dui,yangusutaun,yeongseutaun,yngstʼwn,ywnghztawn,ywngstawn  awhayw,Јангстаун,Йонгстаун,Йънгстаун,Янгстаун,ינגסטאון,يونغزتاون,ینگزٹاؤن، اوہائیو,یونگستاون، اوهایو,ヤングスタウン,扬斯敦,영스타운', 41.0997800, -80.6495200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142256, 'Adamstown', 'Adamstown', '', 40.2412000, -76.0563300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142257, 'Akron', 'Akron', 'Akron,Акрон', 40.1567600, -76.2021700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142258, 'Albion', 'Albion', '', 41.8906100, -80.3664500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142259, 'Albion', 'Albion', '', 40.9589500, -78.9469800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142260, 'Alburtis', 'Alburtis', '', 40.5109300, -75.6029700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142261, 'Aliquippa', 'Aliquippa', 'Alikvipa,alykwyba,alykwyypa  pnsylwanya,Аликвипа,آلیکوئیپا، پنسیلوانیا,أليكويبا', 40.6367300, -80.2400600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142262, 'Alleghenyville', 'Alleghenyville', '', 40.2342600, -75.9885500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142263, 'Allentown', 'Allentown', 'ABE,Alentaun,Alentaunas,Allenschteddel,Allentaun,Allentoun,Allentown,Aluntaun,Northampton,Northamptontown,a lun dui,aelleontaun,alyntawn,arentaun,Алентаун,Аллентаун,Аллентоун,Алънтаун,אלנטאון,آلن‌تاون، پنسیلوانیا,ألينتاون,ایلن ٹاؤن,ایلن ٹاؤن، پنسلوانیا,アレンタウン,阿伦敦,앨런타운', 40.6084300, -75.4901800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142264, 'Allison Park', 'Allison Park', '', 40.5595100, -79.9586700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142265, 'Almedia', 'Almedia', '', 41.0145300, -76.3810500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142266, 'Altoona', 'Altoona', 'Altoona,Altuna,Altūna,POM Wonderful Presents The Greatest Movie Ever Sold,POM Wonderful Presents: The Greatest Movie Ever Sold,a er tu na,altwna,altwna  pnsylwanya,aruto~una,Алтуна,آلتونا، پنسیلوانیا,ألتونا,ایلٹونا، پنسلوانیا,アルトゥーナ,阿尔图纳', 40.5186800, -78.3947400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142267, 'Ambler', 'Ambler', 'Ambler,Амблер', 40.1545500, -75.2215700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142268, 'Ambridge', 'Ambridge', 'Ambridz,ambryj  pnsylwanya,Амбриџ,امبریج، پنسیلوانیا', 40.5892300, -80.2250600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142269, 'Amity Gardens', 'Amity Gardens', '', 40.2742600, -75.7351900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142270, 'Ancient Oaks', 'Ancient Oaks', '', 40.5473200, -75.5893500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142271, 'Annville', 'Annville', 'Annville,Millerstown,Millersville', 40.3295400, -76.5152400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142272, 'Apollo', 'Apollo', 'Apollo,QZP,Warren', 40.5814500, -79.5664300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142273, 'Archbald', 'Archbald', 'Archbald,White Oak Run', 41.4948000, -75.5368500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142274, 'Ardmore', 'Ardmore', 'Ardmor,Ardmore,Athensville,Ардмор', 40.0067800, -75.2854600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142275, 'Arlington Heights', 'Arlington Heights', '', 40.9900900, -75.2162900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142276, 'Arnold', 'Arnold', 'Arnol''d,Arnola,Arnold,Арнольд', 40.5800700, -79.7667200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142277, 'Ashland', 'Ashland', 'Ashland,Eshland,Ашланд,Ешланд,ایشلنڈ، پنسلوانیا', 40.7817500, -76.3457800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142278, 'Ashley', 'Ashley', 'Alberts,Ashley,Coalville,Hendricksburg,Hightown,Nanticoke Junction,Newton,Peestown,Scrabbletown,Skunktown', 41.2103600, -75.8965900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142279, 'Aspinwall', 'Aspinwall', '', 40.4914600, -79.9047700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142280, 'Athens', 'Athens', 'Atens,Athens,Athens Boro,Diahoga,Tioga,Tioga Point,Атенс,ایتھنز، پنسلوانیا، ایک بارو', 41.9573000, -76.5180000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142281, 'Audubon', 'Audubon', '', 40.1278800, -75.4318500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142282, 'Avalon', 'Avalon', 'Avalon,Birmingham,Myler,West Bellevue', 40.5009000, -80.0675600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142283, 'Avis', 'Avis', 'Avis,Oak Grove', 41.1847900, -77.3138600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142284, 'Avoca', 'Avoca', 'Avoca,Pleasant Valley', 41.3398000, -75.7363000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142285, 'Avon', 'Avon', 'Avon,Hebron', 40.3456500, -76.3899600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142286, 'Avonia', 'Avonia', 'Avenia,Avonia', 42.0456100, -80.2697900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142287, 'Back Mountain', 'Back Mountain', '', 41.3359100, -75.9963100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142288, 'Baden', 'Baden', '', 40.6350700, -80.2281200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142289, 'Baidland', 'Baidland', '', 40.1947900, -79.9708800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142290, 'Bainbridge', 'Bainbridge', '', 40.0909300, -76.6674700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142291, 'Bakerstown', 'Bakerstown', '', 40.6509000, -79.9364400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142292, 'Bala-Cynwyd', 'Bala-Cynwyd', 'Bala-Cynwyd,Cynwyd', 40.0076100, -75.2340700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142293, 'Baldwin', 'Baldwin', '', 40.3381300, -79.9789400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142294, 'Bally', 'Bally', '', 40.4023200, -75.5871300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142295, 'Bangor', 'Bangor', 'Bangor,Бангор', 40.8656500, -75.2065700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142296, 'Barnesboro', 'Barnesboro', '', 40.6625700, -78.7800300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142297, 'Bath', 'Bath', 'Bath,Sleepy Hollow', 40.7256500, -75.3940700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142298, 'Bear Rocks', 'Bear Rocks', '', 40.1228500, -79.4617000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142299, 'Beaver', 'Beaver', 'Beaver,Beaver-town,Biver,Fort McIntosh,Бивер', 40.6953400, -80.3047800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142300, 'Beaver Falls', 'Beaver Falls', 'BFP,Beaver Falls,Biver Fols,Brighton,Old Brighton,bawr fals  pnsylwanya,byfyr fwlz,Бивер Фолс,باور فالس، پنسیلوانیا,بيفير فولز', 40.7520100, -80.3192300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142301, 'Beaverdale', 'Beaverdale', 'Beaverdale-Lloydell', 40.3220200, -78.6969600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142302, 'Bedford', 'Bedford', 'Bedford,Camp Raystown,Fort Bedford,Manor of Bedford,Rays-town,Raystown,Бедфорд,بیڈفورڈ، پنسلوانیا', 40.0186900, -78.5039100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142303, 'Bedminster', 'Bedminster', 'Bedminster,Bedminsterville', 40.4259400, -75.1790600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142304, 'Bell Acres', 'Bell Acres', '', 40.5900700, -80.1664500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142305, 'Belfast', 'Belfast', 'Belfast,Belleville,Bellfast,Bellville,Tria,Wards,Wardsburg', 40.7806500, -75.2779600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142306, 'Belle Vernon', 'Belle Vernon', 'Belle Vernon,Belle Vernon Boro,Bellevernon,Nelle Vernon', 40.1250700, -79.8664400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142307, 'Bellefonte', 'Bellefonte', 'Belfont,Bellefonte,PSB,belleponte,Белфонт,벨레폰테', 40.9133900, -77.7783300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142308, 'Belleville', 'Belleville', '', 40.6050700, -77.7255500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142309, 'Bellevue', 'Bellevue', '', 40.4939600, -80.0517200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142310, 'Bellwood', 'Bellwood', 'Bells Mills,Bellwood', 40.6034000, -78.3247400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142311, 'Belmont', 'Belmont', 'Belmont,Белмонт', 40.2873000, -78.8894700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142312, 'Ben Avon', 'Ben Avon', '', 40.5081200, -80.0831100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142313, 'Bentleyville', 'Bentleyville', 'Bentleysville,Bentleyville', 40.1167400, -80.0083900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142314, 'Berwyn', 'Berwyn', '', 40.0448300, -75.4388100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142315, 'Bessemer', 'Bessemer', 'Bessemer,Walford Station', 40.9747800, -80.4936800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142316, 'Berwick', 'Berwick', 'Vervik,Вервик', 41.0545300, -76.2332700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142317, 'Bethel Park', 'Bethel Park', 'Betel Park,Бетел Парк', 40.3275700, -80.0395000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142318, 'Bethlehem', 'Bethlehem', 'Bethlehem,Betlegem,Betlehemas,Betlekhem,Menagachsink,Vifleem,beseullihem,besurehemu,bo li heng,btlhm  pnsylwanya,byt allhm  pnslwanya,byt allhm  pnslwynya,byt lhm,Бетлегем,Бетлехем,Вифлеем,بتلهم، پنسیلوانیا,بيت لحم,بیت اللحم، پنسلوانیا,بیت اللحم، پنسلوینیا,ベスレヘム,伯利恒,베슬리헴', 40.6259300, -75.3704600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142319, 'Big Beaver', 'Big Beaver', '', 40.8245100, -80.3628400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142320, 'Birchwood Lakes', 'Birchwood Lakes', '', 41.2545400, -74.9185000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142321, 'Birdsboro', 'Birdsboro', 'Birdsboro,Birdsborough,Бирдсборо', 40.2645400, -75.8040900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142322, 'Black Lick', 'Black Lick', 'Black Lick,Blacklick', 40.4725000, -79.1868800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142323, 'Blairsville', 'Blairsville', 'BSI,Blairsville,Blairsville Boro', 40.4311800, -79.2608700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142324, 'Blakely', 'Blakely', '', 41.4809100, -75.5946300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142325, 'Blandon', 'Blandon', '', 40.4412000, -75.8868700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142326, 'Blawnox', 'Blawnox', '', 40.4934000, -79.8606100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142327, 'Bloomfield', 'Bloomfield', '', 40.4609000, -79.9508900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142328, 'Bloomsburg', 'Bloomsburg', 'Bloomsburg,Blumsberg,Blumsburg,Eyersburg,Eyertown,blums beirk,blwmsbwrgh,blwmzbrg  pnsylwanya,Блумсберг,Блумсбург,بلومزبرگ، پنسیلوانیا,بلومسبورغ,บลูมส์เบิร์ก', 41.0037000, -76.4549500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142329, 'Blossburg', 'Blossburg', 'Blossburg,Peters Camp', 41.6795200, -77.0638600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142330, 'Blue Ball', 'Blue Ball', '', 40.1187100, -76.0471700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142331, 'Blue Bell', 'Blue Bell', 'BBX,Blue Bell,Pigeontown', 40.1523300, -75.2662900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142332, 'Boalsburg', 'Boalsburg', 'Boalsburg,Boolsburg', 40.7756200, -77.7925000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142333, 'Boiling Springs', 'Boiling Springs', 'Boiling Spring,Boiling Springs', 40.1498100, -77.1283100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142334, 'Boswell', 'Boswell', '', 40.1614700, -79.0289200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142335, 'Bowmansville', 'Bowmansville', '', 40.1967600, -76.0174400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142336, 'Boyertown', 'Boyertown', 'Boertaun,Bojertaun,Боєртаун,Бојертаун', 40.3337100, -75.6374100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142337, 'Brackenridge', 'Brackenridge', '', 40.6081200, -79.7411600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142338, 'Braddock', 'Braddock', 'Bradek,Брадек', 40.4034000, -79.8683800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142339, 'Braddock Hills', 'Braddock Hills', 'Braddock,Braddock Hills,Braddock Hills Boro', 40.4172900, -79.8650500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142340, 'Bradford', 'Bradford', 'BFD,Bradford,Littleton,brdfwrd  pnsylwanya,Брадфорд,بردفورد، پنسیلوانیا', 41.9559000, -78.6439200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142341, 'Bradford Woods', 'Bradford Woods', 'Bradford Woods,Bradfordwoods', 40.6375700, -80.0817200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142342, 'Brentwood', 'Brentwood', 'Brentvud,Брентвуд,برینٹووڈ، پنسلوانیا', 40.3706300, -79.9747700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142343, 'Bressler', 'Bressler', '', 40.2295300, -76.8199700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142344, 'Breinigsville', 'Breinigsville', '', 40.5367600, -75.6313000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142345, 'Brickerville', 'Brickerville', 'Brickersville,Brickerville', 40.2259300, -76.3024600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142346, 'Bridgeport', 'Bridgeport', '', 40.1051100, -75.3451800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142347, 'Bridgeville', 'Bridgeville', 'Bridgeville,Bridgeville Boro,Moorhead', 40.3561800, -80.1100600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142348, 'Bristol', 'Bristol', 'Bristol,Bristul,Buckingham,Bucks,New Bristol,Бристол,Бристъл,برسٹل، پنسلوانیا', 40.1006700, -74.8518300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142349, 'Brockway', 'Brockway', 'Brockway,Brockwayville', 41.2492300, -78.7994700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142350, 'Brodheadsville', 'Brodheadsville', 'Broadheads Ville,Broadheadsville,Brodheadsville', 40.9245400, -75.3937900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142351, 'Brookville', 'Brookville', 'Brukvil,Бруквил', 41.1611700, -79.0830900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142352, 'Brownstown', 'Brownstown', '', 40.1237100, -76.2138400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142353, 'Brownsville', 'Brownsville', 'Braunsvil,Bridgeport-subdivision,Brownsville,Fort Burd,Redstone Old Fort,Браунсвил', 40.0236900, -79.8839400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142354, 'Browntown', 'Browntown', '', 41.3098000, -75.7874200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142355, 'Bryn Athyn', 'Bryn Athyn', 'Bryn Athyn,Byrn Athyn', 40.1315000, -75.0673900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142356, 'Bryn Mawr', 'Bryn Mawr', '', 40.3039600, -80.0867200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142357, 'Bryn Mawr', 'Bryn Mawr', 'bu lin mo er,布林莫爾', 40.0198300, -75.3046300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142358, 'Burgettstown', 'Burgettstown', '', 40.3820100, -80.3928400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142359, 'Burnham', 'Burnham', 'Burnham,Freedom Forge,Logan', 40.6386800, -77.5686100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142360, 'Butler', 'Butler', 'BTP,Batler,Butler,batlr  pnsylwanya,batora,btlr,Батлер,باتلر، پنسیلوانیا,بتلر,بٹلر، پنسلوانیا,バトラー', 40.8611800, -79.8953300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142361, 'California', 'California', 'Kalifornija,kylyfwrnya  pnslwanya,Калифорнија,کیلیفورنیا، پنسلوانیا', 40.0656300, -79.8917100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142362, 'Calumet', 'Calumet', '', 40.2109000, -79.4853200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142363, 'Cambridge Springs', 'Cambridge Springs', 'Cambridge,Cambridge Springs,Cambridgeboro,Cambridgeborough,Kejmbridz Springs,Кејмбриџ Спрингс', 41.8036700, -80.0564400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142364, 'Camp Hill', 'Camp Hill', 'Camp Hill,White Hall', 40.2398100, -76.9199700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142365, 'Campbelltown', 'Campbelltown', '', 40.2775900, -76.5852500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142366, 'Canonsburg', 'Canonsburg', 'Cannonberry,Cannonburg,Cannonsboro,Cannonsburg,Canonsburg,Kanonsberg,Канонсберг', 40.2625700, -80.1872800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142367, 'Canton', 'Canton', '', 41.6564600, -76.8532900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142368, 'Carbondale', 'Carbondale', 'Karbondejl,krbndyl  pnsylwanya,krbwndyl,Карбондејл,كربونديل,کاربنڈیل، پنسلوانیا,کربندیل، پنسیلوانیا', 41.5736900, -75.5018500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142369, 'Carlisle', 'Carlisle', 'Karlajl,Luguvalium,ka lai er,kallail,karairu,karlayl  pnslwanya,Карлајл,کارلائل، پنسلوانیا,カーライル,卡莱尔,칼라일', 40.2014800, -77.1888700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142370, 'Castanea', 'Castanea', '', 41.1247900, -77.4297000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142371, 'Castle Shannon', 'Castle Shannon', 'Kasl Shanon,Касл Шанон', 40.3647900, -80.0222800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142372, 'Catasauqua', 'Catasauqua', 'Bierys Port,Caladaqua,Calesoque,Calisuk,Catasaqua,Catasauqua,Cranesville,Gatasaquo,Sideropolis', 40.6548200, -75.4746300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142373, 'Catawissa', 'Catawissa', '', 40.9520300, -76.4596700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142374, 'Cementon', 'Cementon', 'Cementon,Sidfrieds Ferry,Siegfrieds,Siegfrieds Bridge,Siegfrieds Ferry,White Hall,Whitehall', 40.6892600, -75.5076800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142375, 'Centerville', 'Centerville', 'Brownsville,Centerville,Centreville,East Bethlehem,Frederickstown', 40.0453500, -79.9756100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142376, 'Central City', 'Central City', '', 40.1106300, -78.8019700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142377, 'Centre Hall', 'Centre Hall', 'Center Hall,Centre Hall', 40.8475600, -77.6861100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142378, 'Cetronia', 'Cetronia', 'Cedarville,Cetronia,East Macungie', 40.5867600, -75.5296300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142379, 'Chalfont', 'Chalfont', 'Barndtsville,Butlers Mill,Chalfont,Whitehallville', 40.2884400, -75.2090600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142380, 'Charleroi', 'Charleroi', 'Sharleroj,Шарлерој', 40.1378500, -79.8981000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142381, 'Cherryville', 'Cherryville', '', 40.7539800, -75.5385200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142382, 'Chester Springs', 'Chester Springs', '', 40.0951000, -75.6168700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142383, 'Chesterbrook', 'Chesterbrook', '', 40.0756600, -75.4590800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142384, 'Cheswick', 'Cheswick', 'Chestwick,Cheswick', 40.5417300, -79.7992200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142385, 'Chevy Chase Heights', 'Chevy Chase Heights', '', 40.6367300, -79.1442000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142386, 'Chicora', 'Chicora', 'Chicora,Millerstown', 40.9481200, -79.7428300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142387, 'Chinchilla', 'Chinchilla', '', 41.4750800, -75.6771300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142388, 'Church Hill', 'Church Hill', 'Church Hill,Church Hill Manor', 40.6820100, -77.5986100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142389, 'Churchill', 'Churchill', '', 40.4384000, -79.8431000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142390, 'Churchville', 'Churchville', 'Churchville,Smoketown', 40.1862200, -75.0187800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142391, 'Clairton', 'Clairton', 'Klerton,ke lai dun zhen,klayrtwn  pnsylwanya,klyrtwn,Клертон,كليرتون,کلایرتون، پنسیلوانیا,克莱顿镇', 40.2922900, -79.8817100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142392, 'Clarion', 'Clarion', 'Klarion,Кларион', 41.2147900, -79.3853200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142393, 'Clarks Green', 'Clarks Green', '', 41.4928600, -75.6996400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142394, 'Clarks Summit', 'Clarks Summit', 'Klars Samit,Кларс Самит', 41.4886900, -75.7085200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142395, 'Clay', 'Clay', '', 40.2184300, -76.2555100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142396, 'Claysburg', 'Claysburg', '', 40.2967400, -78.4497400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142397, 'Clearfield', 'Clearfield', 'Chingleclamouchs Old Town,Clearfield,Klirfild,PSB,Клирфилд', 41.0272800, -78.4391900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142398, 'Cleona', 'Cleona', '', 40.3373100, -76.4755200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142399, 'Clymer', 'Clymer', '', 40.6681200, -79.0117000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142400, 'Coaldale', 'Coaldale', 'Bullrun,Coaldale,Gearyville', 40.8228700, -75.9068700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142401, 'Cochranton', 'Cochranton', '', 41.5200500, -80.0483900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142402, 'Collegeville', 'Collegeville', 'Collegeville,Freeland,Koledzvil,Perkiomen Bridge,Колеџвил', 40.1856600, -75.4515700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142403, 'Collinsburg', 'Collinsburg', '', 40.2242400, -79.7683800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142404, 'Colonial Park', 'Colonial Park', '', 40.3006400, -76.8096900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142405, 'Columbia', 'Columbia', 'Columbia,Kolambija,Kolumbija,Wrights Ferry,kwlmbya  pnslwanya,Коламбија,Колумбия,کولمبیا، پنسلوانیا', 40.0337100, -76.5044100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142406, 'Conemaugh', 'Conemaugh', '', 40.3267400, -78.9080800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142407, 'Conashaugh Lakes', 'Conashaugh Lakes', '', 41.3059300, -74.9896200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142408, 'Connellsville', 'Connellsville', 'Connellsville,Dutch Botton,Konelsvil,kwnlswyl  pnsylwanya,kwnylsfyl,Конелсвил,كونيلسفيل,نیو ہیون، پنسلوانیا,کونلسویل، پنسیلوانیا', 40.0178500, -79.5894800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142409, 'Conshohocken', 'Conshohocken', 'کونشوہوکین، پنسلوانیا', 40.0792800, -75.3015700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142410, 'Conway', 'Conway', 'Konvej,Конвей', 40.6597900, -80.2392300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142411, 'Conyngham', 'Conyngham', '', 40.9920300, -76.0565900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142412, 'Coopersburg', 'Coopersburg', 'Coopersburg,Cooperstown,Fryburg,Fryburgh,Frysburg,Kupersberg,Куперсберг', 40.5114900, -75.3904600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142413, 'Coplay', 'Coplay', 'Coplay,Copley,Lehigh Valley,Schrieber,Schriebers', 40.6701000, -75.4954600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142414, 'Coraopolis', 'Coraopolis', 'Carapolis,Coraopolis,Corapolis,Koraopolis,Middletown,Vance Fort,Vancefort,Кораополис', 40.5184000, -80.1667200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142415, 'Cornwall', 'Cornwall', '', 40.2737000, -76.4060700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142416, 'Cornwells Heights', 'Cornwells Heights', 'Cornwell,Cornwells Heights,Maud', 40.0767800, -74.9487800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142417, 'Corry', 'Corry', 'Kori,kary  pnsylwanya,kwry,Кори,كوري,کاری، پنسیلوانیا', 41.9203300, -79.6403300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142418, 'Coudersport', 'Coudersport', 'Kaudersport,Kaudursport,Каудерспорт,Каудърспорт', 41.7747900, -78.0205600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142419, 'Crafton', 'Crafton', 'Brodhead,Crafton,Crafton Heights,Krafton,Крафтон', 40.4350700, -80.0661700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142420, 'Cresson', 'Cresson', 'Kreson,Кресон', 40.4597900, -78.5916800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142421, 'Cressona', 'Cressona', '', 40.6267600, -76.1927200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142422, 'Croydon', 'Croydon', 'Croydon,Schencks Station', 40.0873300, -74.9035000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142423, 'Curtisville', 'Curtisville', '', 40.6422900, -79.8508900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142424, 'Curwensville', 'Curwensville', 'Curwensville,Curwensville Boro', 40.9756100, -78.5250200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142425, 'Dale', 'Dale', '', 40.3128500, -78.9041900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142426, 'Dallas', 'Dallas', 'Dallas,McLellonsville,Даллас', 41.3361900, -75.9632500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142427, 'Dalton', 'Dalton', 'Dalton,Далтон', 41.5342400, -75.7360300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142428, 'Danville', 'Danville', 'Dans-town,Danvil,Danville,Данвил', 40.9634200, -76.6127300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142429, 'Davidsville', 'Davidsville', '', 40.2270200, -78.9364100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142430, 'Delmont', 'Delmont', 'Delmont,New Salem', 40.4131200, -79.5703200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142431, 'Derry', 'Derry', 'Derri,Дерри', 40.3339600, -79.2997600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142432, 'Denver', 'Denver', 'Denver,Денвер', 40.2331500, -76.1371700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142433, 'Devon', 'Devon', '', 40.0492800, -75.4290800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142434, 'Dewart', 'Dewart', '', 41.1092500, -76.8766300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142435, 'Dickson City', 'Dickson City', 'Dickson,Dickson City,Priceburg,Priceville', 41.4714700, -75.6076900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142436, 'Dillsburg', 'Dillsburg', 'Dillsburg,Dillstown', 40.1109300, -77.0349800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142437, 'Donora', 'Donora', 'Donora,Донора', 40.1734000, -79.8575500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142438, 'Dormont', 'Dormont', 'Dormont,Дормонт,ڈورمونٹ، پنسلوانیا', 40.3959000, -80.0331100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142439, 'Dorneyville', 'Dorneyville', 'Dorneysville,Dorneyville', 40.5751000, -75.5196300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142440, 'Dover', 'Dover', 'Dover,Довер', 40.0017600, -76.8502500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142441, 'Downingtown', 'Downingtown', 'Daunington,Downing''s Town,Downingtown,Milltown,Даунингтон', 40.0065000, -75.7032700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142442, 'Doylestown', 'Doylestown', 'DYL,Dojlstaun,Doyle Town,Doylestown,Doyltown,Dyletown,William Doyls Tavern,Дойлстаун,Дојлстаун', 40.3101100, -75.1298900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142443, 'Doylestown', 'Doylestown', '', 40.1975800, -77.7213800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142444, 'Dravosburg', 'Dravosburg', 'Amity,Dravosburg', 40.3506300, -79.8861600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142445, 'Dresher', 'Dresher', 'Dresher,Dreshertown', 40.1409400, -75.1668400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142446, 'DuBois', 'DuBois', 'DUJ,DuBois,Dubois,Rumberger', 41.1192300, -78.7600300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142447, 'Dublin', 'Dublin', 'Double Inn,Dublin,Дублин', 40.3717700, -75.2015600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142448, 'Duboistown', 'Duboistown', 'Dubbistown,Duboistown', 41.2225800, -77.0369100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142449, 'Duncannon', 'Duncannon', '', 40.3981400, -77.0230300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142450, 'Duncansville', 'Duncansville', 'Duncansville,Walterstown', 40.4234100, -78.4339000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142451, 'Dunmore', 'Dunmore', 'Bucktown,Danmor,Dunmore,danmoa,Данмор,ダンモア', 41.4198000, -75.6324100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142452, 'Dunnstown', 'Dunnstown', '', 41.1459000, -77.4213700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142453, 'Dupont', 'Dupont', 'Dupont,Dupont Boro,Smithville', 41.3250800, -75.7454700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142454, 'Duquesne', 'Duquesne', 'Dukejn,Duquesne,Germantown,dwksn  pnsylwanya,dwkywsn,Дукејн,دوكيوسن,دوکسن، پنسیلوانیا', 40.3814600, -79.8597700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142455, 'Duryea', 'Duryea', 'Babylon,Duryea', 41.3439700, -75.7385300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142456, 'Eagleville', 'Eagleville', '', 40.1595500, -75.4082400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142457, 'Earlston', 'Earlston', '', 40.0061900, -78.3700100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142458, 'East Bangor', 'East Bangor', 'Delpsburg,Delpsburgh,East Bangor', 40.8795400, -75.1837900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142459, 'East Berwick', 'East Berwick', '', 41.0620300, -76.2224300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142460, 'East Conemaugh', 'East Conemaugh', '', 40.3486800, -78.8836400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142461, 'East Earl', 'East Earl', '', 40.1101000, -76.0327200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142462, 'East Greenville', 'East Greenville', '', 40.4064900, -75.5018500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142463, 'East McKeesport', 'East McKeesport', '', 40.3831200, -79.8064400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142464, 'East Petersburg', 'East Petersburg', 'East Petersburg,Petersburg', 40.1001000, -76.3541300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142465, 'East Pittsburgh', 'East Pittsburgh', '', 40.3956200, -79.8386600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142466, 'East Stroudsburg', 'East Stroudsburg', 'Branchville,Dansbury,ESP,East Stroudsburg,Ist Straudsberg,Ист Страудсберг', 40.9995400, -75.1812900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142467, 'East Washington', 'East Washington', '', 40.1736800, -80.2375600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142468, 'Eastlawn Gardens', 'Eastlawn Gardens', '', 40.7506500, -75.2957300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142469, 'Easton', 'Easton', 'Dutchtown,Easton,Easton Township,Iston,Lechau-hanne,Lechauwake,Lechauwitank,The Easton Tract,The Forks of the Delaware,Thomas Penns Lottery Lot,aystwn  pnsylwanya,iseuteon,isuton,Истон,ایستون، پنسیلوانیا,ایسٹن، پنسلوانیا,イーストン,이스턴', 40.6884300, -75.2207300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142470, 'Ebensburg', 'Ebensburg', 'Ebensburg,Ebensburgh', 40.4850700, -78.7247400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142471, 'Economy', 'Economy', 'Economy,Economy Station', 40.6000700, -80.2247800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142472, 'Eddington', 'Eddington', 'Dunksville,Eddington,Jugtown,Oakgrove', 40.0845600, -74.9448900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142473, 'Edgewood', 'Edgewood', '', 40.4320100, -79.8814400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142474, 'Edgewood', 'Edgewood', '', 40.7884200, -76.5724600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142475, 'Edgeworth', 'Edgeworth', '', 40.5511800, -80.1928400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142476, 'Edinboro', 'Edinboro', 'Ehdinboro,Эдинборо', 41.8742200, -80.1317200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142477, 'Effort', 'Effort', '', 40.9392600, -75.4349100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142478, 'Edwardsville', 'Edwardsville', 'Edwardsville,Larksville', 41.2695300, -75.9163100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142479, 'Egypt', 'Egypt', '', 40.6801000, -75.5299100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142480, 'Elizabeth', 'Elizabeth', 'Ehlizabet,Elizabeth,Elizabeth Town,Elizabethtown,Элизабет', 40.2692400, -79.8897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142481, 'Elim', 'Elim', '', 40.2978500, -78.9425300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142482, 'Elizabethtown', 'Elizabethtown', 'Betzischteddel,Ehlizabettaun,Elizabettaun,Елизабеттаун,Элизабеттаун', 40.1528700, -76.6027500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142483, 'Elizabethville', 'Elizabethville', '', 40.5489700, -76.8119200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142484, 'Elkland', 'Elkland', 'Elkland,Елкланд', 41.9861800, -77.3108100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142485, 'Ellport', 'Ellport', '', 40.8639500, -80.2589500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142486, 'Ellwood City', 'Ellwood City', 'Ellwood City,Elvud Siti,Hazeldell,ai er wu de shi,Елвуд Сити,אלווד סיטי,埃爾伍德市', 40.8617300, -80.2864500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142487, 'Elverson', 'Elverson', 'Elverson,Springfield', 40.1567600, -75.8327100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142488, 'Elysburg', 'Elysburg', '', 40.8645300, -76.5524600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142489, 'Emerald Lakes', 'Emerald Lakes', '', 41.0884200, -75.4196300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142490, 'Emigsville', 'Emigsville', '', 40.0217600, -76.7280200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142491, 'Emmaus', 'Emmaus', 'Emaus,Emejas,Emmaus,Maguntchi,Salzburg,Емејас', 40.5395400, -75.4968500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142492, 'Emporium', 'Emporium', 'Emporijum,Emporium,Shippen,Емпоријум', 41.5114500, -78.2352900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142493, 'Emsworth', 'Emsworth', 'Courtneyville,Emsworth', 40.5100700, -80.0945000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142494, 'Enhaut', 'Enhaut', '', 40.2317600, -76.8269200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142495, 'Enlow', 'Enlow', 'Enlow,McMinn', 40.4542300, -80.2331100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142496, 'Enola', 'Enola', '', 40.2900900, -76.9338600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142497, 'Ephrata', 'Ephrata', 'Effridaa,Efrata,Ephrata,Ephratah,Ефрата', 40.1798200, -76.1788400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142498, 'Erie', 'Erie', 'City of Erie,ERI,Ehri,Eri,Erie,Iri,ayry,ayry  pnslwanya,ayry  pnsylwanya,eri,ili,yi li,Érié,Ēri,Ери,Ері,Ири,Эри,אירי,إيري,ایری,ایری، پنسلوانیا,ایری، پنسیلوانیا,エリー,伊利,이리', 42.1292200, -80.0850600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142499, 'Espy', 'Espy', '', 41.0062000, -76.4099400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142500, 'Etna', 'Etna', 'Etna,Stewartstown', 40.5042400, -79.9489400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142501, 'Evans City', 'Evans City', 'Evans City,Evansburg', 40.7692300, -80.0628400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142502, 'Evansburg', 'Evansburg', '', 40.1809400, -75.4290700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142503, 'Everett', 'Everett', 'Ehverett,Everet,Evuret,Еверет,Евърет,Эверетт', 40.0114700, -78.3733500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142504, 'Exeter', 'Exeter', '', 41.3206400, -75.8190800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142505, 'Exton', 'Exton', 'Ekston,Екстон', 40.0290000, -75.6207700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142506, 'Factoryville', 'Factoryville', '', 40.8248200, -75.2096200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142507, 'Factoryville', 'Factoryville', '', 41.5631300, -75.7826900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142508, 'Fairhope', 'Fairhope', '', 40.1136800, -79.8397700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142509, 'Fairless Hills', 'Fairless Hills', '', 40.1795500, -74.8551600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142510, 'Fairview', 'Fairview', '', 42.0314500, -80.2553400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142511, 'Falls Creek', 'Falls Creek', '', 41.1450600, -78.8044700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142512, 'Farrell', 'Farrell', 'Farrell,South Sharon', 41.2122800, -80.4967400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142513, 'Faxon', 'Faxon', '', 41.2484100, -76.9771900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142514, 'Feasterville', 'Feasterville', 'Feasterville,Feisterville,The Buck', 40.1440000, -75.0051700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142515, 'Fellsburg', 'Fellsburg', '', 40.1831300, -79.8242100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142516, 'Ferndale', 'Ferndale', '', 40.2889600, -78.9147500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142517, 'Fernway', 'Fernway', '', 40.6947900, -80.1308900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142518, 'Fivepointville', 'Fivepointville', 'Fivepointville,Muddy Creek', 40.1828700, -76.0510600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142519, 'Fleetwood', 'Fleetwood', 'Coxtown,Fleetwood', 40.4539800, -75.8179800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142520, 'Flemington', 'Flemington', '', 41.1264600, -77.4716500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142521, 'Flourtown', 'Flourtown', '', 40.1034400, -75.2124000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142522, 'Flying Hills', 'Flying Hills', '', 40.2767600, -75.9141000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142523, 'Ford City', 'Ford City', 'Ford Siti,Форд Сити', 40.7722900, -79.5297700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142524, 'Forest City', 'Forest City', 'Forest City,Pentecost', 41.6514700, -75.4665700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142525, 'Forest Hills', 'Forest Hills', '', 40.4197900, -79.8500500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142526, 'Fort Washington', 'Fort Washington', 'Fort Vashington,Fort Voshington,Форт Вашингтон,Форт Вошингтон', 40.1417800, -75.2090600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142527, 'Forty Fort', 'Forty Fort', '', 41.2789700, -75.8782500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142528, 'Foster Brook', 'Foster Brook', '', 41.9750600, -78.6172500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142529, 'Fountain Hill', 'Fountain Hill', 'Fountain Hill,Oppeldtsville,Oppeltsville,Wyandotte Hill', 40.6014900, -75.3951800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142530, 'Fox Chapel', 'Fox Chapel', 'Foks Chapel,Фокс Чапел', 40.5134000, -79.8797700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142531, 'Fox Run', 'Fox Run', '', 40.7022900, -80.0828400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142532, 'Frackville', 'Frackville', 'Frackville,Frackville City', 40.7839800, -76.2302200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142533, 'Franklin', 'Franklin', 'FKL,Franklin,Frenklin,franklyn,franklyn  pnsylwanya,Франклин,Френклин,فرانكلين,فرانکلین، پنسیلوانیا,فرینکلن، وینانگو کاؤنٹی، پنسلوانیا', 41.3978400, -79.8314400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142534, 'Franklin Park', 'Franklin Park', 'Franklin,Franklin Park', 40.5834000, -80.0878400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142535, 'Fredericksburg', 'Fredericksburg', 'Frederiksburg,Фредериксбург', 40.4437000, -76.4282900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142536, 'Freedom', 'Freedom', '', 40.6856200, -80.2517300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142537, 'Freeland', 'Freeland', 'Freehold,Freeland,Friland,Фриланд,فری لینڈ، پنسلوانیا', 41.0167500, -75.8971400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142538, 'Freeport', 'Freeport', 'Freeport,Friport,Toddstown,frypwrt  pnsylwanya,Фрипорт,فری پورٹ، پنسلوانیا,فریپورت، پنسیلوانیا', 40.6739500, -79.6847700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142539, 'Freemansburg', 'Freemansburg', 'Freemansburg,Freemansburgh', 40.6264900, -75.3457400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142540, 'Friedens', 'Friedens', '', 40.0500800, -78.9983600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142541, 'Fullerton', 'Fullerton', 'Ferndale,Fullerton,Фуллертон', 40.6317600, -75.4732400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142542, 'Galeton', 'Galeton', 'Galeton,Pike Mills', 41.7331200, -77.6419300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142543, 'Gallitzin', 'Gallitzin', '', 40.4822900, -78.5516800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142544, 'Garden View', 'Garden View', '', 41.2542400, -77.0460800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142545, 'Gastonville', 'Gastonville', 'Curryville,Gastonville', 40.2572900, -79.9958800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142546, 'Geistown', 'Geistown', '', 40.2909100, -78.8689100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142547, 'Georgetown', 'Georgetown', '', 41.2273000, -75.8688100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142548, 'Gibsonia', 'Gibsonia', '', 40.6300700, -79.9695000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142549, 'Gilbertsville', 'Gilbertsville', '', 40.3201000, -75.6101800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142550, 'Girard', 'Girard', 'Girard,Girard Boro', 42.0003300, -80.3181200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142551, 'Girardville', 'Girardville', '', 40.7914800, -76.2835600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142552, 'Glassport', 'Glassport', '', 40.3247900, -79.8922700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142553, 'Glen Lyon', 'Glen Lyon', 'Glen Lyon,Glenlyon', 41.1750800, -76.0746500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142554, 'Glenside', 'Glenside', 'Glensajd,Гленсајд', 40.1023300, -75.1521200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142555, 'Glenshaw', 'Glenshaw', 'Glenshaw,Shaw''s Mills', 40.5328500, -79.9675500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142556, 'Gold Key Lake', 'Gold Key Lake', '', 41.3059300, -74.9385000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142557, 'Green Tree', 'Green Tree', 'Green Tree,Greentree,Grin Tri,Грин Три', 40.4117400, -80.0456100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142558, 'Greenock', 'Greenock', '', 40.3122900, -79.8067100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142559, 'Greenville', 'Greenville', 'Greenville,Grinvil,Grinvill,West Greenville,grynwyl  pnslwanya,Гринвил,Гринвилл,گرینویل، پنسلوانیا', 41.4045000, -80.3911800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142560, 'Greensburg', 'Greensburg', 'Grinsburg,ghrynsbwrj,grynzbrg  pnslwanya,grynzbrg  pnsylwanya,gurinzubagu,Гринсбург,غرينسبورج,گرینزبرگ، پنسلوانیا,گرینزبرگ، پنسیلوانیا,グリーンズバーグ', 40.3014600, -79.5389300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142561, 'Greenwood', 'Greenwood', '', 40.5359000, -78.3575100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142562, 'Grill', 'Grill', '', 40.2987000, -75.9404900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142563, 'Grove City', 'Grove City', 'Grouv Siti,Grove City,Pine Grove,Гроув Сити', 41.1578400, -80.0886700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142564, 'Halfway House', 'Halfway House', '', 40.2820400, -75.6432400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142565, 'Hallam', 'Hallam', 'Hallam,Hellam', 40.0048200, -76.6041300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142566, 'Hallstead', 'Hallstead', 'Great Bend Village,Hallstead', 41.9611900, -75.7432400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142567, 'Hamburg', 'Hamburg', 'Khamburg,Хамбург', 40.5556500, -75.9818800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142568, 'Harleigh', 'Harleigh', '', 40.9806400, -75.9713100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142569, 'Harleysville', 'Harleysville', '', 40.2795500, -75.3871200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142570, 'Harrisburg', 'Harrisburg', 'Charrismpernk,Garrisberg,Gorad Garysberg,HAR,Harisberga,Harisburg,Harisburgas,Harisburgs,Harisbērga,Harrisbarrig,Harrisburg,Harrisburgum,Harrisburq,Kharisburg,Louisbourg,Paxtang,ha li si bao,haeliseubeogeu,harisbarg,harispark,harisubagu,harysbrj,herisabarga,hrysbwrg  pnsylwanya,hyarisabarga,hyarisbarga,Χάρρισμπεργκ,Гаррисберг,Гаррісберг,Горад Гарысберг,Харисбург,Харисбърг,Һаррисбург,Հարիսբուրգ,האריסברג,هاريسبرج,هریسبورگ، پنسیلوانیا,ہیرسبرک، پنسلوانیا,ہیرسبرگ,हारिस्बर्ग्,हॅरिसबर्ग,ह्यारिसबर्ग,ह्यारिस्बर्ग,ஹாரிஸ்பர்க்,แฮร์ริสเบิร์ก,ハリスバーグ,哈里斯堡,해리스버그', 40.2737000, -76.8844200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142571, 'Harveys Lake', 'Harveys Lake', 'Alderson,Harveys Lake', 41.3834100, -76.0246500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142572, 'Hastings', 'Hastings', 'Khejstings,Хейстингс', 40.6650700, -78.7122500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142573, 'Hasson Heights', 'Hasson Heights', '', 41.4489500, -79.6770000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142574, 'Hatboro', 'Hatboro', 'Hatboro,Hatborough,Khatboro,Хатборо', 40.1742800, -75.1068400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142575, 'Hatfield', 'Hatfield', '', 40.2798300, -75.2993400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142576, 'Hawley', 'Hawley', 'Kholi,Холи', 41.4759200, -75.1821200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142577, 'Hazleton', 'Hazleton', 'HZL,Hazelton,Hazleton,Khejzelton,hazltwn,hei ci er dun,heizuruton,hyzltwn  pnsylwanya,Хејзелтон,هازلتون,هیزلتون، پنسیلوانیا,ہیزلٹن، پنسلوانیا,ヘイズルトン,黑兹尔顿', 40.9584200, -75.9746500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142578, 'Hebron', 'Hebron', '', 40.3389800, -76.3994000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142579, 'Heidelberg', 'Heidelberg', '', 40.3922900, -80.0908900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142580, 'Hellertown', 'Hellertown', 'Hellerstown,Hellertown,Stopes', 40.5795400, -75.3407300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142581, 'Hemlock Farms', 'Hemlock Farms', '', 41.3267600, -75.0365600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142582, 'Hermitage', 'Hermitage', 'Khermitidz,hrmytazh  pnsylwanya,hyrmytagh,Хермитиџ,هرمیتاژ، پنسیلوانیا,هيرميتاغ', 41.2333900, -80.4486800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142583, 'Hershey', 'Hershey', 'Gershi,Khershi,he er xi zhen,heosi,hrshy,hrshy  pnsylwanya,Герші,Херши,هرشي,هرشی، پنسیلوانیا,赫爾希鎮,허시', 40.2859200, -76.6502500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142584, 'Highland Park', 'Highland Park', 'Khajlend Park,Хайленд Парк', 40.6209100, -77.5680500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142585, 'Highspire', 'Highspire', 'High Spire,Highspire', 40.2109200, -76.7910800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142586, 'Hilldale', 'Hilldale', '', 41.2892500, -75.8363100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142587, 'Hiller', 'Hiller', 'Hiller,Luzerne Village', 40.0103500, -79.9008800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142588, 'Hokendauqua', 'Hokendauqua', '', 40.6620400, -75.4910200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142589, 'Hollidaysburg', 'Hollidaysburg', 'Holidaysburg,Hollidaysburg,Kholidejsberg,Холидејсберг,ہولیڈیزبرگ، پنسلوانیا', 40.4272900, -78.3889000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142590, 'Homer City', 'Homer City', 'Homer,Homer City,Philips Mills', 40.5434000, -79.1622600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142591, 'Homestead', 'Homestead', 'Goumsted,Khomsted,Гоумстед,Хомстед', 40.4059000, -79.9119900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142592, 'Hometown', 'Hometown', '', 40.8237000, -75.9802000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142593, 'Honesdale', 'Honesdale', 'Dyberry Forks,Honesdale', 41.5767600, -75.2587900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142594, 'Honey Brook', 'Honey Brook', 'Honey Brook,Honeybrook,Waynesburg', 40.0942700, -75.9113300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142595, 'Horsham', 'Horsham', 'Horsham,Horsham Township,Horshamville,Municipio de Horsham,Xa Horsham,Xã Horsham', 40.1784400, -75.1285100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142596, 'Houserville', 'Houserville', 'Houser Mills,Houserville,Plum Grove Ville', 40.8239500, -77.8288900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142597, 'Houston', 'Houston', 'Kh''juston,Хьюстон', 40.2464600, -80.2114500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142598, 'Hudson', 'Hudson', '', 41.2748000, -75.8360300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142599, 'Hughestown', 'Hughestown', '', 41.3270200, -75.7732500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142600, 'Hughesville', 'Hughesville', 'Hughesburg,Hughesville', 41.2411900, -76.7238500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142601, 'Hummels Wharf', 'Hummels Wharf', '', 40.8317500, -76.8358000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142602, 'Hummelstown', 'Hummelstown', 'Frederickstown,Hummelstown', 40.2653700, -76.7083000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142603, 'Huntingdon', 'Huntingdon', 'Huntingdon,Khantingdon,Standing Stone,heng ding dun,Хантингдон,ہنٹنگڈن، پنسلوانیا,亨丁頓', 40.4848000, -78.0102800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142604, 'Hyde', 'Hyde', '', 41.0025600, -78.4625200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142605, 'Hyde Park', 'Hyde Park', '', 40.3773200, -75.9252100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142606, 'Imperial', 'Imperial', 'Imperial,Montour City', 40.4495100, -80.2445000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142607, 'Indian Mountain Lake', 'Indian Mountain Lake', '', 41.0031400, -75.5082400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142608, 'Indian Mountain Lake', 'Indian Mountain Lake', '', 41.0048100, -75.4993500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142609, 'Indiana', 'Indiana', 'IDI,Indiana,Indijana,ayndyana  pnsylwanya,indiana,Индиана,Индијана,ایندیانا، پنسیلوانیا,インディアナ', 40.6214600, -79.1525300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142610, 'Industry', 'Industry', '', 40.6445100, -80.4161800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142611, 'Ingram', 'Ingram', '', 40.4461800, -80.0675500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142612, 'Industry', 'Industry', 'Frank,Industry', 40.2645100, -79.7922700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142613, 'Inkerman', 'Inkerman', '', 41.2989700, -75.8126900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142614, 'Intercourse', 'Intercourse', 'Cross Keys,Intercourse', 40.0376000, -76.1049500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142615, 'Irwin', 'Irwin', '', 40.3245100, -79.7011500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142616, 'Ivyland', 'Ivyland', '', 40.2078900, -75.0726700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142617, 'Jacksonwald', 'Jacksonwald', '', 40.3245400, -75.8496500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142618, 'Jeannette', 'Jeannette', 'Dzanet,janyt,jynt  pnsylwanya,Џанет,جانيت,جینت، پنسیلوانیا', 40.3281200, -79.6153200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142619, 'Jefferson Hills', 'Jefferson Hills', 'Jefferson,Jefferson Hills', 40.2911800, -79.9319900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142620, 'Jenkintown', 'Jenkintown', 'Jenkins-town,Jenkintown', 40.0959400, -75.1251700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142621, 'Jermyn', 'Jermyn', 'Gibsonburg,Jermyn', 41.5309100, -75.5454600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142622, 'Jerome', 'Jerome', 'Dzerom,Џером', 40.2089600, -78.9836400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142623, 'Jersey Shore', 'Jersey Shore', 'Dzerzi Shor,Jersey Shore,Waynesburg,Џерзи Шор', 41.2020200, -77.2644200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142624, 'Jessup', 'Jessup', '', 41.4686900, -75.5621300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142625, 'Jim Thorpe', 'Jim Thorpe', 'Dzhim Torp,Dzim Torp,East Mauch Chunk,Jim Thorpe,Machk Tschunk,Macht Tschunk,Mauch Chunk,Џим Торп,Джим Торп', 40.8759200, -75.7324100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142626, 'Johnsonburg', 'Johnsonburg', 'Johnsonburg,Wilmarth', 41.4906200, -78.6750300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142627, 'Johnsonburg', 'Johnsonburg', '', 40.8861800, -78.8778100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142628, 'Johnstown', 'Johnstown', 'Conemaugh,Conemaugh Town,Dzhonstaun,Dzonstaun,Dzonstauna,Džonstauna,JST,Johnstown,janztawn  pnsylwanya,jonsata''una,jonseutaun,jonzutaun,jwnstawn,yue han si dui,Џонстаун,Джонстаун,جانزتاون، پنسیلوانیا,جونزٹاؤن، پنسلوانیا,جونستاون,जॉन्सटाऊन,ジョンズタウン,约翰斯敦,존스타운', 40.3267400, -78.9219700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142629, 'Jonestown', 'Jonestown', '', 40.4137000, -76.4783000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142630, 'Kane', 'Kane', 'Kejn,Кејн', 41.6628400, -78.8111400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142631, 'Kenhorst', 'Kenhorst', '', 40.3106500, -75.9393800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142632, 'Kenilworth', 'Kenilworth', 'Kenilworth,Madison', 40.2314900, -75.6340800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142633, 'Kenmar', 'Kenmar', '', 41.2534100, -76.9594100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142634, 'King of Prussia', 'King of Prussia', 'Brandywine Village,KPD,King of Prussia,King ov Prasha,Кинг ов Праша', 40.0892700, -75.3960200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142635, 'Kingston', 'Kingston', 'Dorrancetown,Kingston,Kingstonas,kingusuton,kyngztwn  pnsylwanya,Кингстон,کنگسٹن، پنسلوانیا,کینگزتون، پنسیلوانیا,キングストン', 41.2617500, -75.8968600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142636, 'Kittanning', 'Kittanning', 'Cantanyans,Cattanyan,Kittanning', 40.8164500, -79.5219900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142637, 'Knox', 'Knox', 'Edenburg,Knox', 41.2345100, -79.5372700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142638, 'Kulpmont', 'Kulpmont', '', 40.7934200, -76.4724500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142639, 'Kulpsville', 'Kulpsville', 'Kulosville,Kulpsville', 40.2428800, -75.3365600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142640, 'Kutztown', 'Kutztown', 'Kutz Town,Kutzeschtettel,Kutztown,ku ci dui,库茨敦', 40.5173200, -75.7774200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142641, 'Laflin', 'Laflin', '', 41.2889700, -75.8054700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142642, 'Lake City', 'Lake City', 'Lake City,Miles Grove,North Girard', 42.0142200, -80.3453400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142643, 'Lake Wynonah', 'Lake Wynonah', '', 40.5992600, -76.1638300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142644, 'Lakemont', 'Lakemont', '', 40.4728500, -78.3883500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142645, 'Lancaster', 'Lancaster', 'LNS,Lancaster,Lankast"r,Lankaster,Lengeschder,laengkeoseuteo,lainkisatara,lamkestara,lan kai si te,lnkstr  pnsylwanya,rankasuta,Ланкастер,Ланкастър,لنکاسٹر، پنسلوانیا,لنکاسٹر، پنسلوینیا,لنکستر، پنسیلوانیا,लँकेस्टर,ਲੈਂਕਿਸਟਰ,ランカスター,兰开斯特,랭커스터', 40.0378800, -76.3055100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142646, 'Landisville', 'Landisville', '', 40.0953700, -76.4099600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142647, 'Langhorne', 'Langhorne', 'Artleborough,Attleboro,Attleborough,Attlebury,Four Lanes Ends,Langhorne,Langkhorn,Middle Lots,Richardsons Corner,Лангхорн', 40.1745500, -74.9226700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142648, 'Langhorne Manor', 'Langhorne Manor', '', 40.1670500, -74.9176700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142649, 'Lansdale', 'Lansdale', 'Lansdejl,ransuderu,Лансдејл,ランスデール', 40.2415000, -75.2837900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142650, 'Lansford', 'Lansford', 'Ashton,Lansford,Richdale,Storm Hill', 40.8317600, -75.8824200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142651, 'Laporte', 'Laporte', 'LaPorte,Laporte', 41.4239700, -76.4941100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142652, 'Larksville', 'Larksville', 'Blindtown,Larksville', 41.2450800, -75.9307500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142653, 'Latrobe', 'Latrobe', 'LBE,Latrob,latrwb,latrwb  pynslwanya,ltrwb  pnsylwanya,Латроб,لاتروب,لاتروب، پینسلوانیا,لتروب، پنسیلوانیا', 40.3211800, -79.3794800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142654, 'Laureldale', 'Laureldale', 'Laurel Dale,Laureldale', 40.3881500, -75.9179800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142655, 'Laurys Station', 'Laurys Station', 'Laurays Station,Laurys,Laurys Station,Slate Dam', 40.7231500, -75.5301800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142656, 'Lawnton', 'Lawnton', 'Lawnton,Lawton', 40.2584200, -76.8038600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142657, 'Lawrence Park', 'Lawrence Park', '', 40.3456400, -76.8008000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142658, 'Lawrence Park', 'Lawrence Park', '', 42.1522800, -80.0231100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142659, 'Lawson Heights', 'Lawson Heights', '', 40.2917400, -79.3892000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142660, 'Lebanon', 'Lebanon', 'Lebanon,Lebanono,Steitztown,lai ba nen,lbnan,lbnan  pnsylwanya,lebeoneon,lybann  pnslwanya,rebanon,Лебанон,لبنان,لبنان، پنسیلوانیا,لیبانن، پنسلوانیا,レバノン,萊巴嫩,레버넌', 40.3409300, -76.4113500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142661, 'Leechburg', 'Leechburg', '', 40.6270100, -79.6056000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142662, 'Leesport', 'Leesport', '', 40.4470400, -75.9663200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142663, 'Leetsdale', 'Leetsdale', '', 40.5631200, -80.2083900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142664, 'Lehighton', 'Lehighton', 'Likhajton,Лихајтон', 40.8337000, -75.7138000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142665, 'Lemont', 'Lemont', 'Centreville,Dales Mills,Edenville,Elmwood,Lemont', 40.8106200, -77.8183300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142666, 'Lemoyne', 'Lemoyne', 'Bridgeport,Lemoyne', 40.2412000, -76.8941400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142667, 'Lenape Heights', 'Lenape Heights', '', 40.7642300, -79.5206000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142668, 'Leola', 'Leola', '', 40.0878700, -76.1849500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142669, 'Level Green', 'Level Green', '', 40.3934000, -79.7203200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142670, 'Levittown', 'Levittown', 'Levittaun,Левиттаун', 40.1551100, -74.8287700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142671, 'Lewisburg', 'Lewisburg', 'Derrstown,Lewisburg,Luisburg,lwyysbrg  pnslwanya,Луисбург,لوئیسبرگ، پنسلوانیا', 40.9645300, -76.8844100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142672, 'Lewistown', 'Lewistown', 'L''juistaun,Lewistown,Luistaun,Poketytown,Луистаун,Льюистаун', 40.5992400, -77.5713800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142673, 'Liberty', 'Liberty', '', 40.3253500, -79.8561600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142674, 'Light Street', 'Light Street', 'Lightstreet', 41.0362000, -76.4235600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142675, 'Ligonier', 'Ligonier', 'Ligonir,Лигонир', 40.2431300, -79.2375300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142676, 'Limerick', 'Limerick', '', 40.2309300, -75.5221200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142677, 'Lincoln', 'Lincoln', 'Linkol''n,Линкольн', 40.3189600, -79.8547700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142678, 'Lincoln Park', 'Lincoln Park', '', 40.3148100, -75.9854900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142679, 'Linglestown', 'Linglestown', 'Linglestown,Lingletown', 40.3339800, -76.7891400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142680, 'Linntown', 'Linntown', '', 40.9589700, -76.8991300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142681, 'Lionville', 'Lionville', '', 40.0537200, -75.6599300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142682, 'Lititz', 'Lititz', 'Lititz,Warwick', 40.1573200, -76.3069000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142683, 'Lock Haven', 'Lock Haven', 'LHV,Lok Khejven,lak hyfn,lak hywn  pnsylwanya,Лок Хејвен,لاك هيفن,لاک هیون، پنسیلوانیا', 41.1370100, -77.4469300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142684, 'Lorane', 'Lorane', '', 40.2884300, -75.8546500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142685, 'Loretto', 'Loretto', 'Loreto,Лорето', 40.5031300, -78.6303000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142686, 'Lower Allen', 'Lower Allen', '', 40.2264800, -76.9005300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142687, 'Lower Burrell', 'Lower Burrell', 'Louer Berel,lawr barl  pnsylwanya,lwr bwryl,Лоуер Берел,لاور بارل، پنسیلوانیا,لور بوريل', 40.5531200, -79.7572700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142688, 'Loyalhanna', 'Loyalhanna', 'McChesneytown-Loyalhanna', 40.3225700, -79.3622600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142689, 'Luzerne', 'Luzerne', 'Hartseph,Luzerne', 41.2856400, -75.9010300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142690, 'Lykens', 'Lykens', '', 40.5667500, -76.7005200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142691, 'Macungie', 'Macungie', 'Kunshi,Kunski,Maccongy,Machk-unschi,Machts,Machts Kunski,Macongy,Macungie,Macungy,Macunjy,Maguntsche,Makandzi,Mauck-Kuntshy,Millers Town,Millerstown,Millersville,Маканџи', 40.5159300, -75.5551900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142692, 'Mahanoy City', 'Mahanoy City', '', 40.8125900, -76.1416000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142693, 'Malvern', 'Malvern', 'Malvern,Малверн', 40.0362200, -75.5138100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142694, 'Manchester', 'Manchester', 'Manchester,Манчестер', 40.0631500, -76.7183000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142695, 'Manheim', 'Manheim', '', 40.1634300, -76.3949600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142696, 'Manor', 'Manor', '', 40.3339600, -79.6700400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142697, 'Mansfield', 'Mansfield', 'Mehnsfild,Mensfild,Менсфилд,Мэнсфилд', 41.8073000, -77.0774700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142698, 'Maple Glen', 'Maple Glen', '', 40.0156300, -79.9767200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142699, 'Maple Glen', 'Maple Glen', 'Maple Glen,Penneville', 40.1792800, -75.1804500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142700, 'Marianne', 'Marianne', '', 41.2464500, -79.4289300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142701, 'Marienville', 'Marienville', 'Marienville,Marion,Marion Centre,Marionville', 41.4689500, -79.1231000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142702, 'Marietta', 'Marietta', 'Marietta,Marijeta,New Haven,Waterford,Мариетта,Маријета', 40.0570400, -76.5521900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142703, 'Mars', 'Mars', '', 40.6959000, -80.0117300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142704, 'Marshallton', 'Marshallton', '', 40.7867500, -76.5394000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142705, 'Martinsburg', 'Martinsburg', 'AOO', 40.3111900, -78.3241800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142706, 'Marysville', 'Marysville', 'Merisvil,myryzwyl  pnslwanya,Мерисвил,میریزویل، پنسلوانیا', 40.3425900, -76.9299700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142707, 'Matamoras', 'Matamoras', '', 40.4400900, -76.9333100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142708, 'Matamoras', 'Matamoras', '', 41.3687000, -74.7001600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142709, 'Mayfield', 'Mayfield', 'Glenwood,Mayfield', 41.5381400, -75.5360200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142710, 'Mayfield', 'Mayfield', '', 40.1361800, -79.5978200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142711, 'Maytown', 'Maytown', '', 40.0753700, -76.5821900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142712, 'McAdoo', 'McAdoo', 'McAdoo,Pleasant Hill', 40.9012700, -75.9910600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142713, 'McConnellstown', 'McConnellstown', 'M''Connellstown,McConnellstown', 40.4525700, -78.0816700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142714, 'McDonald', 'McDonald', 'Fort McDonald,McDonald', 40.3709000, -80.2347800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142715, 'McGovern', 'McGovern', 'McConnellsville,McGovern', 40.2289600, -80.2164500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142716, 'McKees Rocks', 'McKees Rocks', 'Chartiers,Makis Roks,McKees Rocks,Макис Рокс', 40.4656200, -80.0656100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142717, 'McKeesport', 'McKeesport', 'M''Keesport,Makizport,McKeesport,makkizupoto,makysbwrt,Макизпорт,ماكيسبورت,مککیسپورٹ، پنسلوانیا,مک‌کیسپورت، پنسیلوانیا,マッキーズポート', 40.3478500, -79.8642200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142718, 'McMurray', 'McMurray', 'McMurray,McMurry,Mcmurry', 40.2778500, -80.0839400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142719, 'Meadowood', 'Meadowood', '', 40.8420100, -79.8939400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142720, 'Meadville', 'Meadville', 'Cussewago,MEJ,Meads Settlement,Meadville,Midvil,Mijdvil,madwyl  pnsylwanya,mydfyl,Мидвил,Мийдвил,مادویل، پنسیلوانیا,ميدفيل', 41.6414400, -80.1514500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142721, 'Mechanicsburg', 'Mechanicsburg', 'Drytown,Mechanicsburg,Mekaniksburg,Stoufferstown,Меканиксбург', 40.2142600, -77.0085900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142722, 'Mechanicsville', 'Mechanicsville', 'Frogtown,Mechanicsville', 40.9664800, -76.5866200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142723, 'Mercer', 'Mercer', 'Merser,Мерсер', 41.2270000, -80.2397900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142724, 'Meridian', 'Meridian', 'Meridian,Меридиан', 40.8484000, -79.9620000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142725, 'Middleburg', 'Middleburg', 'Middleburg,Midlburg,Swinefordstown,Мидлбург', 40.7859200, -77.0472000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142726, 'Middletown', 'Middletown', 'Midltaun,Мидлтаун,مڈل ٹاؤن، ڈاوفن کاؤنٹی، پنسلوانیا', 40.1998100, -76.7310800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142727, 'Middletown', 'Middletown', '', 40.6439900, -75.3324000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142728, 'Midland', 'Midland', 'Midland,Midland Borough', 40.6325700, -80.4464500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142729, 'Midland', 'Midland', '', 40.2589600, -80.2181100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142730, 'Mifflinburg', 'Mifflinburg', 'Mifflinburg,Mifflinsburg,Miflinberg,Youngmanstown,Мифлинберг', 40.9175800, -77.0477500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142731, 'Mifflintown', 'Mifflintown', 'Miflintaun,Мифлинтаун', 40.5698000, -77.3969300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142732, 'Mifflinville', 'Mifflinville', 'Creasy Station,Mifflinville', 41.0323100, -76.3079900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142733, 'Milesburg', 'Milesburg', 'Bald Eagle Nest,Bald Eagle''s Nest,Malone,Milesboro,Milesborough,Milesburg,Milesburgh,The Nest', 40.9417300, -77.7850000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142734, 'Milford', 'Milford', 'Milford,Milford Boro,Милфорд', 41.3223200, -74.8023900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142735, 'Mill Hall', 'Mill Hall', 'Mill Hall,Mill Hall Borough', 41.1072900, -77.4844300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142736, 'Millersburg', 'Millersburg', 'Milersburg,Милерсбург', 40.5395300, -76.9608100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142737, 'Millvale', 'Millvale', 'Bennett,Millvale,Milvejl,Милвејл', 40.4800700, -79.9783900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142738, 'Milroy', 'Milroy', 'Milroy,Perryville', 40.7139600, -77.5905500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142739, 'Milton', 'Milton', 'Mil''ton,Mill-town,Milton,miruton,Милтон,Мильтон,ملٹن، پنسلوانیا,ミルトン', 41.0120300, -76.8477400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142740, 'Minersville', 'Minersville', '', 40.6906500, -76.2621700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142741, 'Mohnton', 'Mohnton', 'Mohns Store,Mohnton', 40.2859300, -75.9843800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142742, 'Monaca', 'Monaca', 'Monaka,Монака', 40.6872900, -80.2714500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142743, 'Monessen', 'Monessen', 'Monesen,Monesun,mansn  pnsylwanya,Монесен,Монесън,مانسن، پنسیلوانیا', 40.1484100, -79.8878300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142744, 'Monongahela', 'Monongahela', 'Monongahela,Monongakhila,Mononghela City,Williamsport,mwnangahla  pnsylwanya,mwnwnghahyla,Мононгахила,مونانگاهلا، پنسیلوانیا,مونونغاهيلا', 40.2031300, -79.9261600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142745, 'Monroeville', 'Monroeville', 'Monrovil,Municipality of Monroeville,monrobiru,mwnrwwyl  pnslwanya,Монровил,مونروویل، پنسلوانیا,モンロービル', 40.4211800, -79.7881000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142746, 'Montgomery', 'Montgomery', 'Montgomeri,Montgomery,Montgomery Station,Монтгомери', 41.1703600, -76.8769100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142747, 'Montgomeryville', 'Montgomeryville', '', 40.2473300, -75.2437900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142748, 'Montoursville', 'Montoursville', 'Montoursville,Otstonwackin,Otzinachson', 41.2542500, -76.9205200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142749, 'Montrose', 'Montrose', '', 40.3064800, -75.9877100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142750, 'Montrose', 'Montrose', 'Hinds Settlement,Montrose,Montrouz,Монтроуз', 41.8339700, -75.8771400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142751, 'Moosic', 'Moosic', 'Musik,Мусик', 41.3534100, -75.7382500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142752, 'Morrisville', 'Morrisville', 'Morisvil,Morristown,Morrisville,Морисвил', 40.2115000, -74.7879400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142753, 'Moscow', 'Moscow', 'Dunnings,Gorod Moskva,Moscow,Город Москва', 41.3367500, -75.5185200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142754, 'Mount Carmel', 'Mount Carmel', 'Karmel'',Maunt Karmel,Maunt-Karmel,mawnt karml  pnsylwanya,Кармель,Маунт Кармел,Маунт-Кармел,ماونت کارمل، پنسیلوانیا,マウント・カーメル', 40.7970300, -76.4119000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142755, 'Mount Cobb', 'Mount Cobb', '', 41.4134200, -75.4932400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142756, 'Mount Holly Springs', 'Mount Holly Springs', 'Kidderminster,Mount Holly Spring,Mount Holly Springs,Papertown,South Middleton', 40.1184200, -77.1899800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142757, 'Mount Joy', 'Mount Joy', 'Maunt DZoj,Mount Joy,Mountjoy,Маунт Џој', 40.1098200, -76.5033000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142758, 'Mount Lebanon', 'Mount Lebanon', '', 40.3553500, -80.0495000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142759, 'Mount Oliver', 'Mount Oliver', 'Mount Oliver,Ormsby', 40.4142400, -79.9878300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142760, 'Mount Penn', 'Mount Penn', '', 40.3281500, -75.8907600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142761, 'Mount Pleasant', 'Mount Pleasant', 'Maunt Plezant,Маунт Плезант', 40.1489600, -79.5411500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142762, 'Mount Pocono', 'Mount Pocono', 'MPO,Maunt Pokono,Mt. Pocono,Маунт Поконо', 41.1220300, -75.3646300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142763, 'Mount Union', 'Mount Union', '', 40.3845200, -77.8822200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142764, 'Mount Wolf', 'Mount Wolf', '', 40.0631500, -76.7038600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142765, 'Mountain Top', 'Mountain Top', 'Mountain Top,Mountaintop', 41.1695300, -75.8774200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142766, 'Mountainhome', 'Mountainhome', 'Mountain Home,Mountainhome', 41.1737000, -75.2710200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142767, 'Mountville', 'Mountville', '', 40.0392600, -76.4308000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142768, 'Muhlenberg Park', 'Muhlenberg Park', '', 40.3848200, -75.9413200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142769, 'Muncy', 'Muncy', 'Mansi,Muncy,Pennsborough,Манси', 41.2056400, -76.7855200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142770, 'Munhall', 'Munhall', 'Mankhol,Манхол', 40.3922900, -79.9000500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142771, 'Mundys Corner', 'Mundys Corner', '', 40.4447900, -78.8411300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142772, 'Murrysville', 'Murrysville', '', 40.4284000, -79.6975500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142773, 'Muse', 'Muse', '', 40.2928500, -80.2003400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142774, 'Myerstown', 'Myerstown', 'Majerstaun,Moyerschteddel,Мајерстаун,میئرزٹاؤن، پینسلوانیا', 40.3745400, -76.3027300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142775, 'Nanticoke', 'Nanticoke', 'Mantiock,Nanticoke,Nantikok,nantykwk,nantykwk  pnsylwanya,Нантикок,نانتيكوك,نانتیکوک، پنسیلوانیا', 41.2053600, -76.0049200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142776, 'Nanty Glo', 'Nanty Glo', 'Nanty Glo,Nanty-Glo,Nat-Y-Glo', 40.4722900, -78.8333600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142777, 'Narberth', 'Narberth', 'Libertyville,Narberth', 40.0084500, -75.2604600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142778, 'Nazareth', 'Nazareth', 'Barony of Nazareth,Barony of the Rose,Nazaret,Nazareth,Назарет', 40.7403800, -75.3096200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142779, 'Nescopeck', 'Nescopeck', '', 41.0520300, -76.2207700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142780, 'Nesquehoning', 'Nesquehoning', '', 40.8645300, -75.8110300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142781, 'New Beaver', 'New Beaver', '', 40.8764500, -80.3706200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142782, 'New Berlinville', 'New Berlinville', '', 40.3453700, -75.6329600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142783, 'New Bloomfield', 'New Bloomfield', 'Bloomfield,New Bloomfield', 40.4198100, -77.1863700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142784, 'New Brighton', 'New Brighton', 'Nju Brajton,Novyj Brajton,nyw braytn  pnsylwanya,Њу Брајтон,Новый Брайтон,نیو برایتن، پنسیلوانیا', 40.7303400, -80.3100600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142785, 'New Britain', 'New Britain', '', 40.2990000, -75.1810100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142786, 'New Castle', 'New Castle', 'New Castle,Newcastle,Nju Kasl,niu ka si er,nyukaeseul,nyukyassuru,nyw kasl,nyw kysl  pnslwanya,nywkasl  pnsylwanya,Њу Касл,نيو كاسل,نیو کیسل، پنسلوانیا,نیوکاسل، پنسیلوانیا,ニューキャッスル,紐卡斯爾,뉴캐슬', 41.0036700, -80.3470100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142787, 'New Columbia', 'New Columbia', '', 41.0409200, -76.8669100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142788, 'New Eagle', 'New Eagle', '', 40.2078500, -79.9469900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142789, 'New Cumberland', 'New Cumberland', 'Haldemans-town,New Cumberland', 40.2323100, -76.8847000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142790, 'New Hope', 'New Hope', 'Canbys Ferry,Coryell''s Ferry,Coryells,Coryells Ferry,N''ju-Khoup,New Hope,New Hope Mills,Nju Khoup,Wells Ferry,Њу Хоуп,Нью-Хоуп', 40.3642700, -74.9512800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142791, 'New Kensington', 'New Kensington', 'Kensington,New Kensington,Nju Kensington,nyw knsynghtwn,nyw knsyngtwn  pnsylwanya,Њу Кенсингтон,نيو كنسينغتون,نیو کنسینگتون، پنسیلوانیا', 40.5697900, -79.7647700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142792, 'New Holland', 'New Holland', '', 40.1017600, -76.0852300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142793, 'New Philadelphia', 'New Philadelphia', 'New Philadelphia,Silver Creek', 40.7195300, -76.1157700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142794, 'New Stanton', 'New Stanton', 'New Stanton,Sewickley Mills', 40.2192400, -79.6094800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142795, 'New Wilmington', 'New Wilmington', '', 41.1222800, -80.3328400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142796, 'Newmanstown', 'Newmanstown', 'Newhanstown,Newmanstown', 40.3495400, -76.2132800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142797, 'Newport', 'Newport', 'N''juport,Newport,Njuport,Reidersville,Њупорт,Ньюпорт,نیوپورٹ، پنسلوانیا', 40.4778600, -77.1305400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142798, 'Newtown', 'Newtown', 'Newton,Newtown,Njutaun,Њутаун,نیو ٹاؤن، بکس کاؤنٹی، پنسلوانیا', 40.2292800, -74.9368300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142799, 'Newtown Grant', 'Newtown Grant', '', 40.2601100, -74.9548900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142800, 'Newville', 'Newville', '', 40.1731400, -77.3986000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142801, 'Nixon', 'Nixon', '', 40.7834000, -79.9295000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142802, 'Norristown', 'Norristown', 'Noristaun,Norris,Norristown,Norriton Plantation,noliseutaun,norisutaun,Нористаун,نورس ٹاؤن، پنسلوانیا,ノリスタウン,노리스타운', 40.1215000, -75.3399000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142803, 'North Apollo', 'North Apollo', 'Allison,North Apollo', 40.5961800, -79.5556000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142804, 'North Belle Vernon', 'North Belle Vernon', 'North Belle Vernon,North Bellevernon', 40.1292400, -79.8681000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142805, 'North Braddock', 'North Braddock', '', 40.3989600, -79.8408800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142806, 'North Charleroi', 'North Charleroi', '', 40.1511800, -79.9075500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142807, 'North Catasauqua', 'North Catasauqua', 'North Catasauqua,Upper Catasauqua', 40.6598200, -75.4768500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142808, 'North East', 'North East', 'Nort Ist,North East,Northeast,Норт Ист', 42.2156100, -79.8342200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142809, 'North Versailles', 'North Versailles', '', 40.3797900, -79.8094900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142810, 'North Wales', 'North Wales', '', 40.2109400, -75.2782300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142811, 'North Warren', 'North Warren', 'Berrys Corner,North Warren', 41.8742300, -79.1522700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142812, 'Northampton', 'Northampton', 'Alliance,Figtown,Hockendauqua,Laubach,Laubachsville,Navarro,Newport,Northampton,Nortkhempton,Siegfried,Siegfrieds Bridge,Stemton,Нортхемптон', 40.6862100, -75.4968500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142813, 'Northern Cambria', 'Northern Cambria', 'Barnesboro,Norden Kambrija,Northern Cambria,Spangler,Норден Камбрија', 40.6592300, -78.7816900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142814, 'Northumberland', 'Northumberland', 'Nortamberland,Nortumberlend,nosanbarando,Нортамберланд,Нортумберленд,ノーサンバーランド', 40.8917500, -76.7974700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142815, 'Oak Hills', 'Oak Hills', '', 40.8247900, -79.9131100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142816, 'Oakdale', 'Oakdale', '', 40.3981200, -80.1856100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142817, 'Oakdale', 'Oakdale', '', 40.9920300, -75.9202000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142818, 'Oakland', 'Oakland', '', 40.3064600, -78.8875200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142819, 'Oakland', 'Oakland', 'Oklend,Окленд', 40.9897800, -80.3695100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142820, 'Oakmont', 'Oakmont', 'Oukmont,okeumeonteu,Оукмонт,오크먼트', 40.5217300, -79.8422700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142821, 'Oakwood', 'Oakwood', '', 41.0106200, -80.3795100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142822, 'Ohioville', 'Ohioville', '', 40.6792300, -80.4947900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142823, 'Oil City', 'Oil City', 'Imperial City,Laytonia,Oil City,Ojl Siti,Venango City,awyl syty,awyl syty  pnsylwanya,Ојл Сити,آئل سٹی، پنسلوانیا,أويل سيتي,اویل سیتی، پنسیلوانیا', 41.4339500, -79.7064400, 'US', '2017-06-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142824, 'Old Forge', 'Old Forge', 'Barbertown,Old Forge,Rendham', 41.3711900, -75.7349100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142825, 'Old Orchard', 'Old Orchard', '', 40.6578800, -75.2621200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142826, 'Oley', 'Oley', 'Friedensburg,Oley', 40.3875900, -75.7896400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142827, 'Olyphant', 'Olyphant', '', 41.4684100, -75.6029700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142828, 'Orchard Hills', 'Orchard Hills', '', 40.5861800, -79.5314300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142829, 'Oreland', 'Oreland', '', 40.1184400, -75.1776800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142830, 'Orwigsburg', 'Orwigsburg', '', 40.6548100, -76.1007700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142831, 'Osceola Mills', 'Osceola Mills', 'Osceola,Osceola Mills', 40.8500600, -78.2705700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142832, 'Palmdale', 'Palmdale', '', 40.2978700, -76.6185800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142833, 'Palmer Heights', 'Palmer Heights', '', 40.6873200, -75.2624000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142834, 'Palmerton', 'Palmerton', 'Lehigh,Palmerton,Pamerton,Памертон', 40.8014000, -75.6119000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142835, 'Palmyra', 'Palmyra', 'Palmajra,Palmstown,Palmyra,Палмајра', 40.3089800, -76.5933000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142836, 'Palo Alto', 'Palo Alto', 'Palo Al''to,Пало Альто', 40.6873100, -76.1721600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142837, 'Paoli', 'Paoli', '', 40.0420500, -75.4763100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142838, 'Paradise', 'Paradise', 'Paradise,Paridise', 40.0098200, -76.1285700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142839, 'Park Forest Village', 'Park Forest Village', '', 40.8067300, -77.9169500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142840, 'Parkside', 'Parkside', '', 41.1012000, -75.2504600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142841, 'Patton', 'Patton', 'Marks Mill,Patton', 40.6339600, -78.6503000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142842, 'Paxtang', 'Paxtang', 'Paxtang,Paxtaug,Paxton', 40.2589800, -76.8319200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142843, 'Paxtonia', 'Paxtonia', '', 40.3173100, -76.7944200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142844, 'Pen Argyl', 'Pen Argyl', 'Jory Blocks,Jorytown,Pen Argyl,Penargil,Wind Gap Quarries', 40.8687100, -75.2549000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142845, 'Penbrook', 'Penbrook', '', 40.2753700, -76.8480300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142846, 'Penn Hills', 'Penn Hills', '', 40.5011800, -79.8392200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142847, 'Penndel', 'Penndel', '', 40.1520500, -74.9165600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142848, 'Pennsburg', 'Pennsburg', 'Pensberg,Пенсберг', 40.3909300, -75.4921200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142849, 'Pennside', 'Pennside', '', 40.3373200, -75.8785400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142850, 'Penryn', 'Penryn', 'Penryn,Unionville', 40.2050900, -76.3682900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142851, 'Perkasie', 'Perkasie', 'Comleysville,Comlyville,Perkasey,Perkasie', 40.3720500, -75.2926800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142852, 'Perryopolis', 'Perryopolis', 'Periopolis,Периополис', 40.0870200, -79.7506000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142853, 'Philipsburg', 'Philipsburg', 'Moshannon Town,PSB,Philipsburg,Philipsburgh', 40.8964500, -78.2205700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142854, 'Phoenixville', 'Phoenixville', 'Finiksvil,Finiksvil'',Finiksvill,Phenixville,Phoenixville,fei ni ke si wei er,Финиксвил,Финиксвилл,Фініксвіль,菲尼克斯維爾', 40.1303800, -75.5149100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142855, 'Pine Grove', 'Pine Grove', 'Pine Grove,Pinegrove', 40.5484200, -76.3846800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142856, 'Pine Grove Mills', 'Pine Grove Mills', 'Pattonsville,Pine Grove Mills,Pinegrove,Pinegrove Mills', 40.7336700, -77.8855600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142857, 'Pitcairn', 'Pitcairn', '', 40.4031200, -79.7781000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142858, 'Pittsburgh', 'Pittsburgh', 'Allegheny,Fort Dunmore,Fort Duquesne,Fort Pitt,Fort Trent,Gorad Pitsburg,PIT,Pitsb"rg,Pitsburg,Pitsburga,Pitsburgas,Pitsburgo,Pitsmpernk,Pitts-Bourg,Pittsbarig,Pittsburg,Pittsburgh,Pittsburgum,Pittsburq,The Manor of Pittsburgh,bytsbrgh,phitts beirk,pi ci bao,pi zi bao,picheubeogeu,pitasabaraga,pitsabarga,pitspark,pits‌barg,pittsubagu,pytsbrg  pnsylwanya,pytsbwrg,Πίτσμπεργκ,Горад Пітсбург,Питсбург,Питсбърг,Питтсбург,Піттсбург,פיטסבורג,بيتسبرغ,پٹس برگ,پٹسبرگ,پیتسبرگ، پنسیلوانیا,पिट्सबर्ग,ਪਿਟਸਬਰਗ,பிட்ஸ்பர்க்,పిట్స్‌బర్గ్,ಪಿಟ್ಸ್‌ಬರ್ಗ್,พิตต์สเบิร์ก,ピッツバーグ,匹兹堡,匹茲堡,피츠버그', 40.4406200, -79.9958900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142859, 'Pittston', 'Pittston', 'Fort Pittston,Pitston,Pittston,bytstwn,pytstwn  pnsylwanya,Питстон,بيتستون,پیتستون، پنسیلوانیا', 41.3259100, -75.7893600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142860, 'Plains', 'Plains', '', 41.2753600, -75.8502000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142861, 'Pleasant Gap', 'Pleasant Gap', 'Connelly Gap,Harrisonville,Horntown,Pleasant Gap,Pleasant Gap Station', 40.8681200, -77.7466700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142862, 'Pleasant Hill', 'Pleasant Hill', '', 40.3362000, -76.4416300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142863, 'Pleasant Hills', 'Pleasant Hills', '', 40.3356300, -79.9606100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142864, 'Plum', 'Plum', 'Plam,puramu,Плам,プラム', 40.5003500, -79.7494900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142865, 'Plumsteadville', 'Plumsteadville', 'Harts Tavern,Plumstead,Plumsteadville,Rod Rocks', 40.3873300, -75.1465600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142866, 'Plymouth', 'Plymouth', 'Plimut,Plymouth,Shawneetown,playmawt  pnslwanya,Плимут,پلایماؤت، پنسلوانیا', 41.2403600, -75.9446400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142867, 'Plymouth Meeting', 'Plymouth Meeting', 'Plimat Miting,Plymouth,Plymouth Meeting,Плимат Митинг', 40.1023300, -75.2743500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142868, 'Pocono Pines', 'Pocono Pines', 'Naomi Pines,Pocono Pines', 41.1067500, -75.4543500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142869, 'Port Carbon', 'Port Carbon', '', 40.6964800, -76.1688300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142870, 'Port Allegany', 'Port Allegany', 'Port Allegany,Port Allegheny', 41.8109000, -78.2797400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142871, 'Port Vue', 'Port Vue', 'Port Vue,Portvue', 40.3359000, -79.8697700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142872, 'Portage', 'Portage', '', 40.3886800, -78.6722400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142873, 'Pottsgrove', 'Pottsgrove', '', 40.2648200, -75.6118500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142874, 'Pottstown', 'Pottstown', 'PTW,Potstaun,Pottsgrove,Pottstown,Pottsylvania,pottsutaun,Потстаун,ポッツタウン', 40.2453700, -75.6496300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142875, 'Pottsville', 'Pottsville', 'Potsvil,bwtsfyl,pottsubiru,pwtswyl  pnsylwanya,Потсвил,بوتسفيل,پوتسویل، پنسیلوانیا,پوٹسویل، پنسلوانیا,ポッツビル', 40.6856500, -76.1955000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142876, 'Progress', 'Progress', '', 40.2850900, -76.8313600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142877, 'Prospect', 'Prospect', '', 40.9045100, -80.0464500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142878, 'Punxsutawney', 'Punxsutawney', 'Ash-town,Gnat-town,Panksatoni,Punxsutawney,pang su tuo ni,Панксатони,旁蘇托尼', 40.9436800, -78.9708700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142879, 'Quakertown', 'Quakertown', 'Flatland,Kvejkertaun,Quakertown,Richland,Richland Centre,Swamp,The Quakers Town,UKT,Квејкертаун', 40.4417700, -75.3415700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142880, 'Radnor', 'Radnor', 'Morgans Corner,Radnor', 40.0462200, -75.3599100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142881, 'Pocono Ranch Lands', 'Pocono Ranch Lands', 'Pocono Ranch Lands,Ranch Lands', 41.1645400, -74.9521200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142882, 'Rankin', 'Rankin', 'Rankin,Ранкин', 40.4125700, -79.8792200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142883, 'Raubsville', 'Raubsville', 'Raubs Ferry,Raubsville,Raubville,Uhlersville', 40.6356600, -75.1929500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142884, 'Reading', 'Reading', 'Gorad Rehdyng,RDG,Reading,Reddin,Reding,leding,lei ding,redingu,rydyng  pnsylwanya,rydyngh,Горад Рэдынг,Рединг,Редінг,ريدينغ,ریدینگ، پنسیلوانیا,ریڈنگ، پنسلوانیا,ریڈنگ، پنسلوینیا,レディング,雷丁,레딩', 40.3356500, -75.9268700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142885, 'Reamstown', 'Reamstown', '', 40.2114800, -76.1232800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142886, 'Red Hill', 'Red Hill', '', 40.3728800, -75.4810100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142887, 'Red Lion', 'Red Lion', '', 40.4806500, -75.6160200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142888, 'Reiffton', 'Reiffton', '', 40.3198100, -75.8735400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142889, 'Reinholds', 'Reinholds', 'Reinholds,Reinholdsville', 40.2667600, -76.1155000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142890, 'Rennerdale', 'Rennerdale', '', 40.3984000, -80.1414500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142891, 'Renovo', 'Renovo', '', 41.3264600, -77.7508200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142892, 'Reynolds Heights', 'Reynolds Heights', '', 41.3450600, -80.3942300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142893, 'Reynoldsville', 'Reynoldsville', '', 41.0970100, -78.8886400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142894, 'Rheems', 'Rheems', '', 40.1300900, -76.5705200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142895, 'Richboro', 'Richboro', 'Bennets,Bennetts,Richboro,Richborough', 40.2151100, -75.0107200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142896, 'Richland', 'Richland', 'Richlend,Ричленд', 40.3592600, -76.2582800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142897, 'Richlandtown', 'Richlandtown', 'Ducktown,Flatland,Frogtown,Richlandtown,Three Lanes End', 40.4701000, -75.3204600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142898, 'Ridgway', 'Ridgway', 'Ridzvej,Риџвеј', 41.4203400, -78.7286400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142899, 'River View Park', 'River View Park', '', 40.3925900, -75.9588200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142900, 'Riverside', 'Riverside', 'Riversajd,Риверсайд', 40.9553600, -76.6288500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142901, 'Roaring Spring', 'Roaring Spring', 'Rouring Spring,Роуринг Спринг', 40.3359100, -78.3908500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142902, 'Robesonia', 'Robesonia', '', 40.3517600, -76.1343900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142903, 'Rochester', 'Rochester', 'East Bridgewater,Fairport,Rochester,Рочестер,روچیسٹر، پنسلوانیا', 40.7022900, -80.2864500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142904, 'Rockledge', 'Rockledge', '', 40.0812200, -75.0896200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142905, 'Roseto', 'Roseto', 'New Italy,Rose to Bangor Branch,Roseto', 40.8806500, -75.2146200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142906, 'Rothsville', 'Rothsville', '', 40.1512100, -76.2510700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142907, 'Royalton', 'Royalton', '', 40.1873100, -76.7299700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142908, 'Royersford', 'Royersford', 'Royer''s Ford,Royers Ford,Royersford', 40.1842700, -75.5379600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142909, 'Russell', 'Russell', 'Pine Grove,Russelburg,Russell,Russellburg,Russellsburg,Russellsburgh,RusselsMills,Russelsburg', 41.9414500, -79.1350500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142910, 'Russellton', 'Russellton', '', 40.6114600, -79.8370000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142911, 'Rutherford', 'Rutherford', '', 40.2689800, -76.7680300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142912, 'Saint Clair', 'Saint Clair', '', 40.7206500, -76.1910500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142913, 'Saint Lawrence', 'Saint Lawrence', '', 40.3270400, -75.8718700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142914, 'Saint Marys', 'Saint Marys', '', 41.4278400, -78.5608600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142915, 'Salix', 'Salix', '', 40.3000800, -78.7653000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142916, 'Salunga', 'Salunga', '', 40.1009300, -76.4246900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142917, 'Sanatoga', 'Sanatoga', '', 40.2451000, -75.5951800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142918, 'Sand Hill', 'Sand Hill', '', 40.3595400, -76.4316300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142919, 'Sandy', 'Sandy', '', 41.1078400, -78.7711400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142920, 'Saw Creek', 'Saw Creek', '', 41.1125900, -75.0507300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142921, 'Saxonburg', 'Saxonburg', '', 40.7539500, -79.8100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142922, 'Saylorsburg', 'Saylorsburg', '', 40.8956500, -75.3235200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142923, 'Sayre', 'Sayre', 'Sejri,Сејри', 41.9789600, -76.5155000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142924, 'Schlusser', 'Schlusser', '', 40.2417500, -77.1769300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142925, 'Schnecksville', 'Schnecksville', 'Schnecksville,Schneckville', 40.6751400, -75.6204400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142926, 'Schoeneck', 'Schoeneck', '', 40.2414800, -76.1741100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142927, 'Schuylkill Haven', 'Schuylkill Haven', 'Schuykill Haven,Schuylkill Haven', 40.6306500, -76.1710500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142928, 'Schwenksville', 'Schwenksville', '', 40.2562100, -75.4637900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142929, 'Scottdale', 'Scottdale', 'Fountain Mills,Scottdale,Skotdejl,Скотдејл', 40.1003500, -79.5869800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142930, 'Scranton', 'Scranton', 'AVP,Capouse,Deep Hollow,Gorad Skrantan,Harrison,Scranton,Skranton,Skrantonas,Skrantun,Skrenton,Slocum Hollow,askrantwn  pnsylwanya,seukeulaenteon,si ke lan dun,skrantwn,sqrntwn,sukuranton,Горад Скрантан,Скрантон,Скрантън,Скрентон,סקרנטון,اسکرانتون، پنسیلوانیا,سكرانتون,سکرانٹن,سکرانٹن، پنسلوانیا,スクラントン,斯克蘭頓,스크랜턴', 41.4091600, -75.6649000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142931, 'Selinsgrove', 'Selinsgrove', 'SEG,Selingsgrov,Selins Grove,Selinsgrove,Селингсгров', 40.7989700, -76.8621900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142932, 'Sellersville', 'Sellersville', 'Sellers Tavern,Sellersville', 40.3539900, -75.3049000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142933, 'Seneca', 'Seneca', '', 41.3786700, -79.7039400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142934, 'Seven Fields', 'Seven Fields', '', 40.6917300, -80.0625600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142935, 'Sewickley', 'Sewickley', 'Contention,Devil''s Race Track,Dogtown,Fifetown,Sevikli,Sewickley,Sewickleyville,Севикли', 40.5364600, -80.1845000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142936, 'Shamokin', 'Shamokin', 'Coal,Samokinas,Schahamokink,Shamokin,shamokin,shamwkyn,shamwkyn  pnsylwanya,syamokin,Šamokinas,Шамокин,شاموكين,شاموکین، پنسیلوانیا,シャモキン,샤모킨', 40.7889700, -76.5588500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142937, 'Shamokin Dam', 'Shamokin Dam', 'Shamokin Dam,Shanokin Dam,Шамокин Дам', 40.8487000, -76.8196900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142938, 'Sharon', 'Sharon', 'Sharon,Sheron,sharwn,sharwn  pnsylwanya,Шарон,Шерон,شارون,شارون، پنسیلوانیا', 41.2331100, -80.4934000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142939, 'Sharpsburg', 'Sharpsburg', 'Sharpsburg,Шарпсбург', 40.4945100, -79.9264400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142940, 'Sharpsville', 'Sharpsville', '', 41.2592200, -80.4720100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142941, 'Shavertown', 'Shavertown', '', 41.3198000, -75.9379800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142942, 'Sheffield', 'Sheffield', '', 41.7039500, -79.0356000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142943, 'Shenandoah', 'Shenandoah', '', 40.8203700, -76.2007700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142944, 'Shenandoah Heights', 'Shenandoah Heights', '', 40.8275900, -76.2068800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142945, 'Shillington', 'Shillington', '', 40.3078700, -75.9654900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142946, 'Shiloh', 'Shiloh', '', 41.0417200, -78.2914000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142947, 'Shinglehouse', 'Shinglehouse', 'Shingle House,Shinglehouse', 41.9636800, -78.1908400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142948, 'Shiremanstown', 'Shiremanstown', 'Shiremans,Shiremanstown,Shirmanstown', 40.2234200, -76.9535900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142949, 'Shippensburg', 'Shippensburg', '', 40.0506500, -77.5202600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142950, 'Shoemakersville', 'Shoemakersville', '', 40.5009300, -75.9699300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142951, 'Simpson', 'Simpson', '', 41.5917500, -75.4851800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142952, 'Sinking Spring', 'Sinking Spring', '', 40.3273100, -76.0110500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142953, 'Skippack', 'Skippack', '', 40.2228800, -75.3987900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142954, 'Skyline View', 'Skyline View', '', 40.3392600, -76.7255300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142955, 'Slatington', 'Slatington', 'Slejtington,Слејтингтон', 40.7484300, -75.6118500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142956, 'Slippery Rock', 'Slippery Rock', 'Centerville,Centreville,Giner Hill,Ginger Hill,Slippery Rock,Slipperyrock,Wesch-Ach-Ach-Apochka', 41.0639500, -80.0564500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142957, 'Smethport', 'Smethport', '', 41.8111700, -78.4447400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142958, 'Somerset', 'Somerset', 'Brunerstown,Samerset,Somerset,Summerset,Самерсет,Сомерсет', 40.0084100, -79.0780800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142959, 'Souderton', 'Souderton', '', 40.3117700, -75.3251800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142960, 'South Greensburg', 'South Greensburg', 'Huff,South Greensburg', 40.2784000, -79.5447600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142961, 'South Pottstown', 'South Pottstown', '', 40.2395400, -75.6510200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142962, 'South Temple', 'South Temple', '', 40.4000000, -75.9000000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142963, 'South Waverly', 'South Waverly', '', 41.9975700, -76.5371700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142964, 'South Williamsport', 'South Williamsport', 'Rocktown,Saut Vilijamsport,South Williamsport,Саут Вилијамспорт', 41.2320200, -76.9991300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142965, 'Southmont', 'Southmont', '', 40.3106300, -78.9386400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142966, 'Southwest Greensburg', 'Southwest Greensburg', '', 40.2911800, -79.5469800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142967, 'Spangler', 'Spangler', '', 40.6428500, -78.7728000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142968, 'Speers', 'Speers', '', 40.1245200, -79.8797700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142969, 'Spinnerstown', 'Spinnerstown', 'Spinners Town,Spinnerstown', 40.4389900, -75.4371200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142970, 'Spring City', 'Spring City', 'Spring City,Springville', 40.1767700, -75.5476900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142971, 'Spring House', 'Spring House', '', 40.1853900, -75.2276800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142972, 'Spring Mount', 'Spring Mount', '', 40.2756600, -75.4565700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142973, 'Spring Ridge', 'Spring Ridge', '', 40.3528700, -75.9899400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142974, 'Springdale', 'Springdale', '', 40.5409000, -79.7839400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142975, 'State College', 'State College', 'Agricultural College,Centre Furnace,Farm School,Farmer High School,SCE,State College', 40.7933900, -77.8600000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142976, 'Steelton', 'Steelton', 'Baldwin,Steelton', 40.2353700, -76.8413600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142977, 'Stiles', 'Stiles', 'Stiles,West Coplay', 40.6653700, -75.5082400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142978, 'Stoneboro', 'Stoneboro', '', 41.3392200, -80.1050600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142979, 'Stony Creek Mills', 'Stony Creek Mills', '', 40.3456500, -75.8699300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142980, 'Stormstown', 'Stormstown', 'Stormstown,Walkersville', 40.7933900, -78.0166700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142981, 'Stowe', 'Stowe', '', 40.2526000, -75.6774100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142982, 'Stroudsburg', 'Stroudsburg', 'Fort Penn,Straudsberg,Stroudsburg,Stroudsburgh,Страудсберг', 40.9867600, -75.1946200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142983, 'Sturgeon', 'Sturgeon', '', 40.3847900, -80.2108900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142984, 'Sugarcreek', 'Sugarcreek', 'Sugar Creek,Sugarcreek', 41.4214500, -79.8811700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142985, 'Summit Hill', 'Summit Hill', 'Andrewsville,Jamestown,Summit,Summit Hill', 40.8248100, -75.8710300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142986, 'Sun Valley', 'Sun Valley', '', 40.9820300, -75.4660200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142987, 'Sun Valley', 'Sun Valley', '', 41.0112000, -75.4696300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142988, 'Sunbury', 'Sunbury', 'Sanberi,Shamokin,Simsbury,Sunbury,sanberi,sanbry  pnsylwanya,snbry  pnslwanya,snbwry,Санбери,سانبری، پنسیلوانیا,سنبری، پنسلوانیا,صنبوري,サンベリー', 40.8625900, -76.7944100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142989, 'Sunrise Lake', 'Sunrise Lake', '', 41.3098100, -74.9665600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142990, 'Susquehanna', 'Susquehanna', 'Susquehanna,Susquehanna Depot', 41.9434100, -75.5996300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142991, 'Swartzville', 'Swartzville', 'Schwartville,Swartzville', 40.2331500, -76.0782800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142992, 'Swissvale', 'Swissvale', 'Svisvejl,suisuvu~eru,Свисвејл,スイスヴェール', 40.4236800, -79.8828300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142993, 'Swoyersville', 'Swoyersville', 'Swouerville,Swoyersville,Swoyerville', 41.2917500, -75.8746400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142994, 'Sykesville', 'Sykesville', '', 41.0503400, -78.8222500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142995, 'Tamaqua', 'Tamaqua', '', 40.7973100, -75.9693700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142996, 'Tannersville', 'Tannersville', '', 41.0400900, -75.3057400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142997, 'Tarentum', 'Tarentum', '', 40.6014600, -79.7597700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142998, 'Tatamy', 'Tatamy', 'Lafever,Lefebre,Tatamy', 40.7409300, -75.2571200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(142999, 'Taylor', 'Taylor', 'Taylor,Taylorville,Tejlor,Тейлор', 41.3948000, -75.7065800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143000, 'Telford', 'Telford', '', 40.3220500, -75.3279500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143001, 'Temple', 'Temple', 'Solomons Temple,Temple', 40.4087000, -75.9216000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143002, 'Terre Hill', 'Terre Hill', 'Herrehill,Terre Hill', 40.1573200, -76.0505000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143003, 'Thompsonville', 'Thompsonville', '', 40.2909000, -80.1081100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143004, 'Throop', 'Throop', '', 41.4514700, -75.6118500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143005, 'Tinicum', 'Tinicum', 'Tinicum,Wormansville', 40.4484400, -75.1076700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143006, 'Tionesta', 'Tionesta', 'Goschgoschunk,Tionesta', 41.4953400, -79.4558800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143007, 'Tipton', 'Tipton', '', 40.6359000, -78.2958500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143008, 'Titusville', 'Titusville', 'Tajtusvil,Titusvill'',tytwsfyl,tytwswyl  pnsylwanya,Тајтусвил,Титусвилль,تيتوسفيل,تیتوسویل، پنسیلوانیا,ٹائٹسویل، پنسلوانیا', 41.6270000, -79.6736600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143009, 'Topton', 'Topton', '', 40.5034300, -75.7013000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143010, 'Towamensing Trails', 'Towamensing Trails', '', 41.0078700, -75.5846300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143011, 'Towanda', 'Towanda', 'Meansville,Tovanda,Towanda,Towandee,Williamston,Тованда', 41.7675800, -76.4427200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143012, 'Tower City', 'Tower City', '', 40.5892500, -76.5524600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143013, 'Trafford', 'Trafford', 'Trafford,Trafford City', 40.3856200, -79.7589300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143014, 'Trappe', 'Trappe', 'Trap,Трап', 40.1989900, -75.4762900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143015, 'Treasure Lake', 'Treasure Lake', '', 41.1733900, -78.7158600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143016, 'Tremont', 'Tremont', '', 40.6284200, -76.3871800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143017, 'Trevorton', 'Trevorton', '', 40.7812000, -76.6730200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143018, 'Trevose', 'Trevose', '', 40.1392800, -74.9810000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143019, 'Trexlertown', 'Trexlertown', 'Trexlerstown,Trexlertown', 40.5481500, -75.6057400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143020, 'Trooper', 'Trooper', '', 40.1498300, -75.4018500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143021, 'Troy', 'Troy', 'Troja,Троя', 41.7859100, -76.7880100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143022, 'Troy', 'Troy', '', 40.9150600, -78.2164000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143023, 'Trucksville', 'Trucksville', '', 41.3039700, -75.9321400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143024, 'Tullytown', 'Tullytown', '', 40.1392800, -74.8146100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143025, 'Tunkhannock', 'Tunkhannock', 'Putnam Township,Tunkhannock,Tunkhannock Township', 41.5386900, -75.9465900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143026, 'Turtle Creek', 'Turtle Creek', 'Sulfur Creek,Turtle Creek', 40.4059000, -79.8250500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143027, 'Tyrone', 'Tyrone', 'Tajron,tayrn  pnsylwanya,Тајрон,تایرن، پنسیلوانیا', 40.6706200, -78.2386200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143028, 'Union City', 'Union City', 'Junion-Siti,Юнион-Сити', 41.8995000, -79.8453300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143029, 'Upper Saint Clair', 'Upper Saint Clair', 'Upper Saint Clair,Upper Sainte Clair,Upper St. Clair', 40.3359000, -80.0833900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143030, 'Valley Green', 'Valley Green', '', 40.1573100, -76.7927500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143031, 'Valley View', 'Valley View', '', 40.6459200, -76.5391300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143032, 'Vandergrift', 'Vandergrift', 'Vandergrift,fandrghryft,wndrgryft  pnsylwanya,Вандергрифт,فاندرغريفت,وندرگریفت، پنسیلوانیا', 40.6028400, -79.5647700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143033, 'Verona', 'Verona', '', 40.5064600, -79.8431000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143034, 'Versailles', 'Versailles', '', 40.3156300, -79.8311600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143035, 'Village Shires', 'Village Shires', '', 40.2031600, -74.9704500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143036, 'Vinco', 'Vinco', 'Fairview,Vinco', 40.4050700, -78.8555800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143037, 'Walnutport', 'Walnutport', 'Newhardtport,Newhartport,Walnutport', 40.7542600, -75.5988000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143038, 'Warminster Heights', 'Warminster Heights', '', 40.1870500, -75.0815600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143039, 'Warren', 'Warren', 'Uorren,Voren,warn,warn  pnsylwanya,Ворен,Уоррен,وارن,وارن، پنسیلوانیا', 41.8439500, -79.1450400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143040, 'Washington', 'Washington', 'Basset-town,Catfishs Camp,Vashington,WSG,Washington,Washington-town,washinton,washntn,washyngtn  pnsylwanya,Вашингтон,واشنطن,واشنگٹن، پنسلوانیا,واشینگتن، پنسیلوانیا,ワシントン', 40.1739600, -80.2461700, 'US', '2017-07-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143041, 'Waterford', 'Waterford', 'Fort Le Boeuf,Uoterford,Waterford,Уотерфорд', 41.9428300, -79.9845000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143042, 'Waterford', 'Waterford', '', 40.2545200, -79.1675300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143043, 'Watsontown', 'Watsontown', 'Watsonburg,Watsontown', 41.0845300, -76.8638500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143044, 'Waymart', 'Waymart', '', 41.5803600, -75.4082400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143045, 'Wayne', 'Wayne', 'Louella,Wayne,wyn  pnslwanya,وین، پنسلوانیا', 40.0440000, -75.3876900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143046, 'Weatherly', 'Weatherly', '', 40.9417500, -75.8296400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143047, 'Wellsboro', 'Wellsboro', 'Velsboro,Weilsboro,Wellsboro,Wellsborough,Велсборо', 41.7486800, -77.3005300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143048, 'Wernersville', 'Wernersville', 'Werner,Wernersville', 40.3300900, -76.0805000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143049, 'Wescosville', 'Wescosville', 'Wescoesville,Wescoeville,Wescosville,Westcosville', 40.5667600, -75.5529600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143050, 'Wesleyville', 'Wesleyville', '', 42.1403300, -80.0150600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143051, 'West Conshohocken', 'West Conshohocken', '', 40.0698300, -75.3163000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143052, 'West Easton', 'West Easton', '', 40.6787100, -75.2368400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143053, 'West Fairview', 'West Fairview', 'Fairview,West Fairview', 40.2750900, -76.9155300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143054, 'West Hamburg', 'West Hamburg', 'Berks,West Hamburg', 40.5475900, -76.0021600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143055, 'West Hazleton', 'West Hazleton', 'West Hazelton,West Hazleton', 40.9587000, -75.9960400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143056, 'West Hills', 'West Hills', '', 40.8242300, -79.5431000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143057, 'West Homestead', 'West Homestead', '', 40.3939600, -79.9119900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143058, 'West Kittanning', 'West Kittanning', 'Weskit,West Kittanning', 40.8103400, -79.5294900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143059, 'West Lawn', 'West Lawn', '', 40.3298100, -75.9943800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143060, 'West Leechburg', 'West Leechburg', '', 40.6222900, -79.6128200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143061, 'West Mayfield', 'West Mayfield', '', 40.7800600, -80.3384000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143062, 'West Mifflin', 'West Mifflin', 'Vest Miflin,u~esutomifurin,Вест Мифлин,ウェストミフリン', 40.3634000, -79.8664400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143063, 'West Newton', 'West Newton', 'West Newton,West Side', 40.2097900, -79.7669900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143064, 'West Norriton', 'West Norriton', '', 40.1295500, -75.3785200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143065, 'West Pittston', 'West Pittston', 'Fort Jenkins,West Pittston', 41.3275800, -75.7929700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143066, 'West Reading', 'West Reading', '', 40.3337000, -75.9474300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143067, 'West View', 'West View', '', 40.5222900, -80.0342200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143068, 'West Wyoming', 'West Wyoming', '', 41.3198000, -75.8460300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143069, 'West Wyomissing', 'West Wyomissing', '', 40.3245400, -75.9907700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143070, 'Westfield', 'Westfield', 'Uehstfild,Vestfild,Вестфилд,Вестфілд,Уэстфилд,ویسٹ فیلڈ، پنسلوانیا', 41.9192400, -77.5388700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143071, 'Westmont', 'Westmont', '', 40.3156300, -78.9516900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143072, 'Whitaker', 'Whitaker', 'Whitaker,Whittaker Boro', 40.3984000, -79.8897700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143073, 'White Haven', 'White Haven', '', 41.0606400, -75.7740800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143074, 'White Oak', 'White Oak', '', 40.3375700, -79.8092100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143075, 'Whitehall', 'Whitehall', '', 40.3611800, -79.9908900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143076, 'Whitehall Township', 'Whitehall Township', 'Whitehall Township', 40.6667600, -75.4999100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143077, 'Whitfield', 'Whitfield', '', 40.3359300, -76.0060500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143078, 'Wilkes-Barre', 'Wilkes-Barre', 'AVP,Fort Durkee,Gorad Uilks-Bareh,Uilks-Barre,Vilks-Beri,Wilkes Barre,Wilkes-Barre,Wilkes-Barre City,Wilkesbarre,u~irukusubari,wei er ke si-ba li,wilkeuseubaeli,wylks bar,wylks-bar  pnsylwanya,Вилкс-Бери,Горад Уілкс-Барэ,Уилкс-Барре,ويلكس بار,ویلکس-بار، پنسیلوانیا,ウィルクスバリ,威尔克斯-巴里,윌크스배리', 41.2459100, -75.8813100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143079, 'Wilkinsburg', 'Wilkinsburg', 'McNairsville,Rippeysville,Vilkinsberg,Wilkinsburg,u~irukinsubagu,Вилкинсберг,ویکینس‌بورگ، پنسیلوانیا,ウィルキンスバーグ', 40.4417400, -79.8819900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143080, 'Williamsburg', 'Williamsburg', 'Vilijamsburg,wylmzbrg  pnslwanya,Вилијамсбург,ویلمزبرگ، پنسلوانیا', 40.4620200, -78.1997300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143081, 'Williamsport', 'Williamsport', 'IPT,Vilijamsport,Williams Port,Williamsport,u~iriamuzupoto,wei lian si bo te,wylyamsbwrt,Вилијамспорт,ولیمزپورٹ، پنسلوانیا,ويليامسبورت,ویلیام‌اسپورت، پنسیلوانیا,ウィリアムズポート,威廉斯波特', 41.2411900, -77.0010800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143082, 'Williamstown', 'Williamstown', '', 40.5800900, -76.6177400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143083, 'Willow Grove', 'Willow Grove', 'Vilou Grouv,Вилоу Гроув', 40.1440000, -75.1157300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143084, 'Wilmerding', 'Wilmerding', '', 40.3909000, -79.8100500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143085, 'Wilson', 'Wilson', '', 40.3100700, -79.8914400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143086, 'Wilson', 'Wilson', 'Uilson,Уилсон', 40.6839900, -75.2418400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143087, 'Wind Gap', 'Wind Gap', 'Die Wind Kapf,Gapton,Green Ridge,Hellers,Hellerville,Mutchler,Wind Gap,Windgap,Woodley', 40.8481500, -75.2915700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143088, 'Windber', 'Windber', '', 40.2398000, -78.8350200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143089, 'Wolfdale', 'Wolfdale', 'Wolfdale,Wolftown', 40.1928500, -80.2878400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143090, 'Womelsdorf', 'Womelsdorf', '', 40.3617600, -76.1841100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143091, 'Woodbourne', 'Woodbourne', '', 40.1923300, -74.8887800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143092, 'Woodland Heights', 'Woodland Heights', '', 41.4097800, -79.7117200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143093, 'Woodside', 'Woodside', 'Biles Corner,Edgewood,Woodside', 40.2217800, -74.8754400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143094, 'Wormleysburg', 'Wormleysburg', '', 40.2628700, -76.9138600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143095, 'Woxall', 'Woxall', 'Mechanicsville,Woxall', 40.3106600, -75.4487900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143096, 'Wrightsville', 'Wrightsville', 'Rajtsvil,lai ci wei er,Рајтсвил,赖茨维尔', 40.0256500, -76.5299700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143097, 'Wyncote', 'Wyncote', 'Wyncote,Wyncote Hills', 40.0945500, -75.1487900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143098, 'Wyndmoor', 'Wyndmoor', 'Vindmur,Виндмур', 40.0812200, -75.1893400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143099, 'Wyoming', 'Wyoming', 'Vajoming,wayywmng  pnslwanya,Вайоминг,Вајоминг,وائیومنگ، پنسلوانیا', 41.3117500, -75.8374200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143100, 'Wyomissing', 'Wyomissing', 'Vajomiding,Вајомидинг', 40.3295400, -75.9652100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143101, 'Wyomissing Hills', 'Wyomissing Hills', '', 40.3375900, -75.9796600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143102, 'Yardley', 'Yardley', 'Howells Ferry,Jardli,Johnsons Ferry,The Boatyard,Yardley,Yardley Ferry,Yardleyville,Јардли', 40.2456600, -74.8460000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143103, 'Yeagertown', 'Yeagertown', '', 40.6431300, -77.5805500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143104, 'Youngsville', 'Youngsville', '', 40.7812100, -75.4768500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143105, 'Youngsville', 'Youngsville', '', 41.8522800, -79.3186600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143106, 'Youngwood', 'Youngwood', '', 40.2403500, -79.5767100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143107, 'Zelienople', 'Zelienople', '', 40.7945100, -80.1367300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143108, 'Zion', 'Zion', 'Sion,Сион', 40.9142300, -77.6847200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143109, 'Ashaway', 'Ashaway', 'Ashaway,Crandalls Mills,Cundall''s Mill', 41.4234300, -71.7856200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143110, 'Barrington', 'Barrington', 'Barington,Barrington,Barrington Center,Berrington,Sowams,Swansey,barinton,barynghtwn,bærring tan,Барингтон,Беррінгтон,بارينغتون,بیرنگٹن، روڈ آئلینڈ,แบร์ริงตัน,バーリントン', 41.7406600, -71.3086600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143111, 'Bradford', 'Bradford', 'Bradford,Charlestown,Charlestown-Hopkinton Depot,Dorrville,Niantic,Shaddock''s Weir,Shaddocks Weir,Shattuck''s Weir', 41.3989900, -71.7370100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143112, 'Bristol', 'Bristol', 'Bristol,Bristol'',bris txl,brystwl,bu li si tuo er,burisutoru,Бристол,Бристоль,برسٹل، روڈ آئلینڈ,بريستول,บริสตอล,ブリストル,布里斯托尔', 41.6770500, -71.2661600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143113, 'Central Falls', 'Central Falls', 'Central Falls,Chocolate Mill,Saintrelle,Sentral Fols,Sentral-Folls,se nthralfxll,sen te lei er fu er si,sentoraruforuzu,sntral fwlz,sntrl falz  rwd aylnd,Сентрал Фолс,Сентрал-Фоллс,سنترال فولز,سنترل فالز، رود آیلند,سینٹرل فالز، روڈ آئلینڈ,เซนทรัลฟอลล์,セントラルフォールズ,森特勒尔福尔斯', 41.8906600, -71.3922800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143114, 'Charlestown', 'Charlestown', 'Charlestown,Charlztaun,Cross Mills,Cross''s Mills,charuzutaun,sharlstwn,Чарлзтаун,شارلستون,چارلس ٹاؤن، روڈ آئلینڈ,チャールズタウン', 41.3831600, -71.6417300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143115, 'Chepachet', 'Chepachet', 'Chepachet,Chepachet Village,Chepatchet,Chepatset', 41.9151000, -71.6714600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143116, 'Coventry', 'Coventry', 'Koventri,kao wen chui,kawntry  rwd aylnd,kobentori,kwfntry,Ковентри,Ковентрі,كوفنتري,کاونتری، رود آیلند,کووینٹری، روڈ آئلینڈ,コベントリー,考文垂', 41.7001000, -71.6828400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143117, 'Cranston', 'Cranston', 'Cranston,Kranston,Krehnston,Krenston,Mashapaug,Maushapogue,Maushapoque,ke lan si dun,kranstwn,kranstwn  rwd aylnd,kuransuton,qrnstwn,Кранстон,Кренстон,Крэнстон,קרנסטון,كرانستون,کرانستون، رود آیلند,کرانسٹون، روڈ آئلینڈ,แครนสตัน,クランストン,克兰斯顿', 41.7798200, -71.4372800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143118, 'Cumberland', 'Cumberland', 'Attleboro Gore,Cumberland,Kamberlend,Senechataconet,The Gore,kanbarando,kmbrland,Камберленд,كمبرلاند,کمبرلینڈ، روڈ آئلینڈ,カンバーランド', 41.9667700, -71.4328400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143119, 'Cumberland Hill', 'Cumberland Hill', 'Cumberland,Cumberland Hill,Cumberland Village,Dog Hill', 41.9745400, -71.4670000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143120, 'East Greenwich', 'East Greenwich', 'Dedford,Deptford,East Greenwich,dong ge lin ni zhi,isutogurinijji,ایسٹ گرینچ، روڈ آئلینڈ,イーストグリニッジ,东格林尼治', 41.6603800, -71.4558900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143121, 'East Providence', 'East Providence', 'Ist Providens,Ist-Providens,ayst brwfydans,ayst prawydns  rwd aylnd,dong pu luo wei deng si,isutopurobidensu,xis t phr x wi den s,Іст-Провіденс,Ист Провиденс,إيست بروفيدانس,ایست پراویدنس، رود آیلند,ایسٹ پروویڈنس، روڈ آئلینڈ,อีสต์พรอวิเดนซ์,イーストプロビデンス,东普罗维登斯', 41.8137100, -71.3700500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143122, 'Exeter', 'Exeter', 'Ekseter,Exeter,Exeter Hill,Exeter Hole,Exeter Hollow,akstr,ekuseta,Ексетер,إكستر,ایگزیٹر، روڈ آئلینڈ,エクセター', 41.5776000, -71.5375600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143123, 'Foster', 'Foster', 'Foster,fosuta,fwstr,Фостер,فوستر,فوسٹر، روڈ آئلینڈ,フォスター', 41.8537100, -71.7581200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143124, 'Greenville', 'Greenville', 'Grinvill,Гринвилл', 41.8712100, -71.5520100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143125, 'Harrisville', 'Harrisville', 'Burrillville,Harrisville,Rhodesville', 41.9656500, -71.6745100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143126, 'Hope Valley', 'Hope Valley', '', 41.5076000, -71.7161800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143127, 'Hopkinton', 'Hopkinton', 'Gopkinton,Hopkinton,Hopkinton City,Khopkinton,hopukinton,hwbkyntwn,Гопкінтон,Хопкинтон,هوبكينتون,ہوپکنٹن، روڈ آئلینڈ,ホプキントン', 41.4612100, -71.7775700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143128, 'Jamestown', 'Jamestown', 'Conanicut,Dzhejmstaun,James Towne,Jamestown,West Jamestown,cems thawn,jemuzutaun,jymstawn,Джеймстаун,جيمستاون,جیمز ٹاون، روڈ آئلینڈ,เจมส์ทาวน์,ジェームズタウン', 41.4970500, -71.3672800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143129, 'Kingston', 'Kingston', 'Kings Towne,Kingston,Kingstown,Little Rest,North Kingstown,Rochester,South Kingstown,kynghstwn,kyngztwn  rwd aylnd,Кингстон,كينغستون,کنگسٹن، روڈ آئلینڈ,کینگزتون، رود آیلند', 41.4803800, -71.5225600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143130, 'Melville', 'Melville', '', 41.5870500, -71.2833800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143131, 'Middletown', 'Middletown', 'Middltaun,mid deil thawn,mideultaun,midorutaun,mydltawn,Міддлтаун,ميدلتاون,مڈل ٹاؤن، رہوڈ آئی لینڈ,มิดเดิลทาวน์,ミドルタウン,미들타운', 41.5456600, -71.2914400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143132, 'Narragansett Pier', 'Narragansett Pier', 'Narragansett,Narragansett Pier', 41.4323200, -71.4564400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143133, 'New Shoreham', 'New Shoreham', 'Block Island,Block Island Village,N''ju-Shorem,New Shoreham,Old Harbor,The Harbor,nyushoahamu,nyw shwrham,Нью-Шорем,نيو شورهام,نیو شورہیم، روڈ آئلینڈ,ニューショアハム', 41.1723300, -71.5578300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143134, 'Newport', 'Newport', 'Carolina Hospital,N''juport,NPT,New Port,Newport,Niew-Port,Njuport,niu bo te,niw phxrt,nyupoteu,nyupoto,nywbwrt,nywpwrt,nywpwrt  rwd aylnd,Њупорт,Ньюпорт,Нюпорт,ניופורט,نيوبورت,نیوپورت، رود آیلند,نیوپورٹ، روڈ آئلینڈ,นิวพอร์ต,ニューポート,纽波特,뉴포트', 41.4901000, -71.3128300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143135, 'North Kingstown', 'North Kingstown', 'King''s Towne,NCO,Nort-Kingstaun,North Kingstown,Rochester,nosukingusutaun,nwrth kynghstawn,Норт-Кингстаун,Норт-Кінґстаун,شمالی کنگز ٹاؤن، روڈ آئلینڈ,نورث كينغستاون,ノースキングスタウン', 41.5501000, -71.4661700, 'US', '2017-07-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143136, 'North Providence', 'North Providence', 'Nort Providens,Nort-Providens,North Providence,North-Providence,nosupurobidensu,nwrth brwfydans,nxrth phr x wi den s,Норт Провиденс,Норт-Провіденс,نارتھ پروویڈنس، روڈ آئلینڈ,نورث بروفيدانس,นอร์ทพรอวิเดนซ์,ノースプロビデンス', 41.8501000, -71.4661700, 'US', '2013-08-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143137, 'North Scituate', 'North Scituate', 'North Scituate,Smithville', 41.8317700, -71.5872900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143138, 'North Smithfield', 'North Smithfield', 'Nort-Smitfild,North Smithfield,Slater,nosusumisufirudo,nwrth smythfyld,Норт-Смітфілд,نارتھ سمتھفیلڈ، روڈ آئلینڈ,نورث سميثفيلد,ノーススミスフィールド', 41.9667700, -71.5495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143139, 'Pascoag', 'Pascoag', 'Monkeytown,Pascoag,Pascoage,Paskhoage,Passcogue', 41.9556500, -71.7022900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143140, 'Pawtucket', 'Pawtucket', 'Pawtucket,Potaket,bo ta ji te,bwtkyt,patakyt  rwd aylnd,phxw thak ket,potaketto,Потакет,بوتكيت,پاتاکیت، رود آیلند,پوٹکیٹ، روڈ آئلینڈ,พอว์ทักเก็ต,ポータケット,波塔基特', 41.8787100, -71.3825600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143141, 'Portsmouth', 'Portsmouth', 'Pocasset,Portsmouth,Portsmut,bwrtsmwth,potsumasu,Портсмут,بورتسموث,پورٹسماؤت، روڈ آئلینڈ,ポーツマス', 41.6023200, -71.2503300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143142, 'Providence', 'Providence', 'Gorad Providehns,PVD,Provedensos,Provid"ns,Providence,Providens,Providensa,Providensas,Providentia,Provintens,Provėdensos,brwfydns,peulobideonseu,phr x wi den s,piravitens,prabhidensa,pravidens,prawydns,probhidensa,provhidansa,prwbydns,prwwyڈns  rwڈ aylynڈ,pu luo wei deng si,pu luo wei dun si,purobidensu,purovu~idensu,Πρόβιντενς,Горад Провідэнс,Провиденс,Провидънс,Провіденс,Փրովիդենս,פראווידענס,פרובידנס,بروفيدنس,پراویدنس,پروویڈنس,پروویڈنس، روڈ آئلینڈ,प्रभिदेन्स,प्राविडेन्स्,प्रॉव्हिडन्स,प्रोभिडेन्स,பிராவிடென்ஸ்,พรอวิเดนซ์,プロビデンス,プロヴィデンス,普洛威頓斯,普罗维登斯,프로비던스', 41.8239900, -71.4128300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143143, 'Smithfield', 'Smithfield', 'Smitfild,smythfyld,sumisufirudo,Смітфілд,سمتھفیلڈ، رہوڈ آئی لینڈ,سميثفيلد,スミスフィールド', 41.9220400, -71.5495100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143144, 'Tiverton', 'Tiverton', 'Howland''s Ferry,Howlands Ferry,Pocasset,Tiverton,tibaton,tyfrtwn,Тивертон,Тівертон,تيفرتون,ٹیورٹن، روڈ آئلینڈ,ティバートン', 41.6259400, -71.2133800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143145, 'Valley Falls', 'Valley Falls', '', 41.9067700, -71.3906100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143146, 'Warren', 'Warren', 'Uorren,Vorren,u~oren,waryn,Воррен,Уоррен,وارن، روڈ آئلینڈ,وارين,ウォーレン', 41.7303800, -71.2825500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143147, 'Warwick', 'Warwick', 'Shawomet,Uorik,Vorik,Vorvik,Warwick,u~orikku,war wik,warwyk,waryk  rwd aylnd,wo wei ke,wolig,wwryq,Ворвик,Ворік,Уорик,ווריק,وارويك,واروک، روڈ آئلینڈ,واریک، رود آیلند,วาร์วิก,ウォリック,沃威克,워릭', 41.7001000, -71.4161700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143148, 'West Warwick', 'West Warwick', 'Uehst-Uorik,Vest Vorvik,u~esutou~orikku,wst warwyk,wyst warwyk,Вест Ворвик,Уэст-Уорик,وست وارویک,ويست وارويك,ویسٹ واروک، روڈ آئلینڈ,ウェストウォリック', 41.6968900, -71.5219400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143149, 'Westerly', 'Westerly', 'Feversham,Misquamacuck,Pawcatuck Bridge,Squamicut,Vesterli,WST,Westerly,u~esutari,wystrly,Вестерли,Вестерлі,ويسترلي,ویسٹرلی، روڈ آئلینڈ,ウェスタリー', 41.3776000, -71.8272900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143150, 'Woonsocket', 'Woonsocket', 'CrossRoads,Miswosakit,Niswosaket,Vunsoket,Woonsocket,Woonsocket Falls,unsoketto,wen suo ji te,wnswkt,wun sxk ket,wwnsakyt  rwd aylnd,Вунсокет,ونسوكت,وونساکیت، رود آیلند,وونسوکیٹ، روڈ آئلینڈ,วูนซอกเก็ต,ウーンソケット,文索基特', 42.0028800, -71.5147800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143151, 'Aberdeen', 'Aberdeen', 'ABR,Aberdin,Aburdijn,a bo ding,abadin,abrdyn,abrdyn  dakwtay jnwby,aebeodin,ebaradina,Абердин,Абърдийн,أبردين,ابردین، داکوتای جنوبی,ایبرڈین، جنوبی ڈکوٹا,एबरडीन,アバディーン,阿伯丁,애버딘', 45.4647000, -98.4864800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143152, 'Alexandria', 'Alexandria', 'Aleksandrija,Alexandria,Clarksville,Александрия', 43.6535900, -97.7828500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143153, 'Armour', 'Armour', '', 43.3186000, -98.3467500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143154, 'Baltic', 'Baltic', 'Baltic,Keyes,Saint Olaf', 43.7613600, -96.7403300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143155, 'Beresford', 'Beresford', 'Beresford,Birsford,Paris,bei lei si fu de,brsfwrd  dakwtay jnwby,byrysfwrd,Бирсфорд,برسفورد، داکوتای جنوبی,بيريسفورد,بیرسفورڈ، جنوبی ڈکوٹا,贝雷斯福德', 43.0805400, -96.7736600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143156, 'Brandon', 'Brandon', 'Brandon,Brehndon,braindana,brandwn,brndn  dakwtay jnwby,bu lan deng,Брандон,Брэндон,براندون,برندن، داکوتای جنوبی,برینڈن، جنوبی ڈکوٹا,ब्रैण्डन,布兰登', 43.5947000, -96.5719900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143157, 'Britton', 'Britton', 'Briton,TTO,braytwn,brittana,brytn  dakwtay jnwby,bu li dun,Бритон,برايتون,برٹن، جنوبی ڈکوٹا,بریتن، داکوتای جنوبی,ब्रिट्टन,布里顿', 45.7916200, -97.7509400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143158, 'Brookings', 'Brookings', 'Ada,BKX,Brookings,Brukings,Brukingz,brukingsa,brwkynghz,brwkyngz  dakwtay jnwby,bu lu jin si,burukkinguzu,Брукингз,Брукингс,Брукінгз,بروكينغز,بروکنگز، جنوبی ڈکوٹا,بروکینگز، داکوتای جنوبی,ब्रूकिंग्स,ブルッキングズ,布鲁金斯', 44.3113600, -96.7983900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143159, 'Burke', 'Burke', 'Berk,Берк', 43.1825000, -99.2920500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143160, 'Canton', 'Canton', 'CTK', 43.3008100, -96.5928200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143161, 'Chamberlain', 'Chamberlain', 'Chamberlain,Makah Tepee', 43.8108300, -99.3306600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143162, 'Clark', 'Clark', 'Clark,Clark Center,Klark,ke la ke,klark,klark  dakwtay jnwby,klarka,Кларк,كلارك,کلارک، جنوبی ڈکوٹا,کلارک، داکوتای جنوبی,क्लार्क,克拉克', 44.8777400, -97.7331400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143163, 'Clear Lake', 'Clear Lake', 'Klir Lejk,ke li er lai ke,kliyara leka,klyr lyk,klyr lyk  dakwtay jnwby,Клир Лејк,كلير ليك,کلئیر لیک، جنوبی ڈکوٹا,کلیر لیک، داکوتای جنوبی,क्लियर लेक,克利尔莱克', 44.7458000, -96.6825600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143164, 'Crooks', 'Crooks', 'Crooks,New Hope', 43.6647000, -96.8108900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143165, 'Dakota Dunes', 'Dakota Dunes', '', 42.4874900, -96.4864200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143166, 'De Smet', 'De Smet', 'Cream City,De Smet,De Smit,DeSmet,Desmet,da asmt  dakwtay jnwby,di si mei te,di smaita,dy smyt,Де Смит,دا اسمت، داکوتای جنوبی,دي سميت,ڈی سمیٹ، جنوبی ڈکوٹا,डि स्मैट,迪斯梅特', 44.3874700, -97.5503500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143167, 'Dell Rapids', 'Dell Rapids', 'Del Rapids,Dell City,Dell Rapids,de er la pi ci,dl rpyd  dakwtay jnwby,dyl rabydz,Дел Рапидс,دل رپید، داکوتای جنوبی,ديل رابيدز,ڈیل ریپڈس، جنوبی ڈکوٹا,德尔拉皮兹', 43.8260800, -96.7061600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143168, 'Elk Point', 'Elk Point', 'Elk Point,Elk Pojnt,Elkpoint,ai er ke bo yin te,alk bwynt,alk pwynt  dakwtay jnwby,elka pau''inta,Елк Појнт,إلك بوينت,الک پوینت، داکوتای جنوبی,ایلک پوائنٹ، جنوبی ڈکوٹا,एल्क पौइण्ट,埃尔克波因特', 42.6833300, -96.6836500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143169, 'Faulkton', 'Faulkton', '', 45.0349700, -99.1240000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143170, 'Flandreau', 'Flandreau', 'Flandru,flaindro''u,flandraw  dakwtay jnwby,flandryw,fu lan de li,Фландру,فلاندراو، داکوتای جنوبی,فلاندريو,فلانڈریو، جنوبی ڈکوٹا,फ़्लैण्ड्रोउ,弗兰德利', 44.0494200, -96.5953200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143171, 'Fort Thompson', 'Fort Thompson', '', 44.0686000, -99.4378800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143172, 'Freeman', 'Freeman', '', 43.3524900, -97.4372900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143173, 'Garretson', 'Garretson', 'Garetson,gartswn  dakwtay jnwby,ghartswn,jia lei sen,Гаретсон,غارتسون,گارتسون، داکوتای جنوبی,گیریٹسن، جنوبی ڈکوٹا,加勒森', 43.7174700, -96.5028200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143174, 'Gettysburg', 'Gettysburg', '', 45.0116500, -99.9556700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143175, 'Gregory', 'Gregory', '', 43.2322200, -99.4303800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143176, 'Groton', 'Groton', '', 45.4474600, -98.0987100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143177, 'Harrisburg', 'Harrisburg', 'Garrisberg,Harrisburg,Salina,Selina,Springdale,Гаррисберг', 43.4313700, -96.6972700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143178, 'Hartford', 'Hartford', 'Hartford,Khartford,Oaksville,Хартфорд', 43.6230300, -96.9425500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143179, 'Highmore', 'Highmore', '', 44.5213700, -99.4415000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143180, 'Howard', 'Howard', 'Howard,Howard City,Khauard,havarda,hawrd,huo hua de,hward,Хауард,هاورد,هوارد,हावर्ड,霍华德', 44.0108100, -97.5267400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143181, 'Huron', 'Huron', 'Guron,HON,Khjuron,hyurona,hywrn  dakwtay jnwby,xiu lun hu,Гурон,Хјурон,هیورن، داکوتای جنوبی,ह्यूरॉन,休伦湖', 44.3633200, -98.2142600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143182, 'Ipswich', 'Ipswich', '', 45.4444200, -99.0292800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143183, 'Kennebec', 'Kennebec', 'Hotch City,Kennebec', 43.9036000, -99.8617800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143184, 'Lake Andes', 'Lake Andes', '', 43.1563800, -98.5414700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143185, 'Lennox', 'Lennox', 'Lennoks,Леннокс', 43.3541500, -96.8920000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143186, 'Leola', 'Leola', '', 45.7227500, -98.9409400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143187, 'Madison', 'Madison', 'Madison,Medison,Mehdison,XMD,madyswn,mai di xun,maidisana,mdyswn  dakwtay jnwby,Мадисон,Медисон,Медісон,Мэдисон,ماديسون,مدیسون، داکوتای جنوبی,میڈیسون، جنوبی ڈکوٹا,मैडिसन,麦迪逊', 44.0060800, -97.1139500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143188, 'Milbank', 'Milbank', 'Milbank,Millbank,mi er ban ke,milabainka,mylbank,mylbank  dakwtay jnwby,Милбанк,ملبینک، جنوبی ڈکوٹا,ميلبانك,میلبانک، داکوتای جنوبی,मिलबैंक,米尔班克', 45.2191300, -96.6356200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143189, 'Miller', 'Miller', '', 44.5183100, -98.9884300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143190, 'Mitchell', 'Mitchell', 'MHE,Michel,Mitchell,mi qie er,mitsela,mychl  dakwtay jnwby,Митчелл,Мичел,میچل، داکوتای جنوبی,मिट्शॅल,米切尔', 43.7094300, -98.0298000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143191, 'North Sioux City', 'North Sioux City', 'Nort Su Siti,bei su cheng,nwrt sw syty  dakwtay jnwby,nwrth sywks syty,Норт Су Сити,نارتھ سیو سٹی، جنوبی ڈکوٹا,نورت سو سیتی، داکوتای جنوبی,نورث سيوكس سيتي,北苏城', 42.5272200, -96.4830900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143192, 'Olivet', 'Olivet', '', 43.2408200, -97.6753400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143193, 'Parker', 'Parker', 'Kimball City,Parker,barkr,pa ke,parkara,parkr  dakwtay jnwby,Паркер,باركر,پارکر، جنوبی ڈکوٹا,پارکر، داکوتای جنوبی,पार्कर,帕克', 43.3974800, -97.1364500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143194, 'Parkston', 'Parkston', '', 43.3988800, -97.9836800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143195, 'Plankinton', 'Plankinton', '', 43.7155500, -98.4850900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143196, 'Platte', 'Platte', 'New Platte,Platte', 43.3869400, -98.8445300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143197, 'Redfield', 'Redfield', 'Redfield,Stennett Junction', 44.8758100, -98.5187100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143198, 'Salem', 'Salem', 'Sejlem,sai lei mu,salm,selama,sylm  dakwtay jnwby,Сейлем,Сејлем,سالم,سیلم، جنوبی ڈکوٹا,سیلم، داکوتای جنوبی,सेलम,塞勒姆', 43.7241500, -97.3889500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143199, 'Sioux Falls', 'Sioux Falls', 'FSD,Siou Fols,Sioux Falls,Siuks Fols,Su Fols,Su-Fols,Sufolsa,Sūfolsa,saywks falz,siyuka folsa,su fxls,su pholsa,su pu,suforuzu,supolseu,sw falz  dakwtay jnwby,sw pwls,Σιου Φολς,Сиукс Фолс,Су Фолс,Су-Фолс,סו פולס,سايوكس فالز,سو فالز، داکوتای جنوبی,سیو فالز، جنوبی ڈکوٹا,सियुक फ़ॉल्स,सू फॉल्स,ซูฟอลส์,スーフォールズ,蘇瀑,수폴스', 43.5499700, -96.7003300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143200, 'Sisseton', 'Sisseton', 'Siseton,sis''setana,systwn,sysytn  dakwtay jnwby,xi sai dun,Сисетон,سسیٹن، جنوبی ڈکوٹا,سيستون,سیسیتن، داکوتای جنوبی,सिस्सेटन,锡塞顿', 45.6646800, -97.0498000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143201, 'Springfield', 'Springfield', 'Springfild,aspryngfyld  dakwtay jnwby,sbrynghfyld,si pu lin fei er de,Спрингфилд,Спрінгфілд,اسپرینگفیلد، داکوتای جنوبی,سبرينغفيلد,سپرنگفیلڈ، جنوبی ڈکوٹا,斯普林菲尔德', 42.8541700, -97.8972900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143202, 'Tea', 'Tea', 'Byron,Tea', 43.4463700, -96.8358800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143203, 'Tyndall', 'Tyndall', '', 42.9933300, -97.8628500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143204, 'Vermillion', 'Vermillion', 'Vermilion,Vermillion,fu mi li en,fyrmlywn,varmiliyana,wrmylyn  dakwtay jnwby,Вермилион,Вермиллион,Вермілліон,فيرمليون,ورمیلین، داکوتای جنوبی,ویرملین، جنوبی ڈکوٹا,वर्मिलियन,弗米利恩', 42.7794400, -96.9292100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143205, 'Volga', 'Volga', 'Volga,fu er jia,fwlgha,walga  dakwtay jnwby,Волга,فولغا,والگا، داکوتای جنوبی,وولگا، جنوبی ڈکوٹا,伏尔加', 44.3235800, -96.9264500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143206, 'Wagner', 'Wagner', '', 43.0797200, -98.2931300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143207, 'Watertown', 'Watertown', 'ATY,Uotertaun,Votertaun,u~otataun,votarata''una,wo te dui,woteotaun,wtrtawn  dakwtay jnwby,Вотертаун,Уотертаун,وترتاون، داکوتای جنوبی,वॉटरटाउन,ウォータータウン,沃特敦,워터타운', 44.8994100, -97.1150700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143208, 'Webster', 'Webster', '', 45.3321800, -97.5200900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143209, 'Wessington Springs', 'Wessington Springs', 'Elmer,Vesington Springs,Wessington,Wessington Springs,vesingtana springsa,wei xin dun quan,wsyngtwn aspryngz  dakwtay jnwby,wysynghtwn sbrynghz,Весингтон Спрингс,وسینگتون اسپرینگز، داکوتای جنوبی,ويسينغتون سبرينغز,वॅसिंग्टन स्प्रिंग्स,韦辛顿泉', 44.0791600, -98.5695400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143210, 'Winner', 'Winner', 'Viner,vinara,wen na,wynr,wynr  dakwtay jnwby,Винер,ونر، جنوبی ڈکوٹا,وينر,وینر، داکوتای جنوبی,विनर,温纳', 43.3766700, -99.8590100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143211, 'Woonsocket', 'Woonsocket', '', 44.0536000, -98.2756400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143212, 'Yankton', 'Yankton', 'Jankton,YKN,yang ke dun,yenkatana,ynktwn  dakwtay jnwby,Јанктон,Янктон,ینکتون، داکوتای جنوبی,यॅङ्कटन,扬克顿', 42.8711100, -97.3972800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143213, 'Addison', 'Addison', 'Addison,Addison Four Corners,Four Corners,adyswn,adyswn  wrmant,أديسون,ادیسون، ورمانت,ایڈسن، ورمونٹ', 44.0886700, -73.3026200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143214, 'Arlington', 'Arlington', 'Arlington,Tory Hollow,arlynghtwn,Арлингтон,آرلنگٹن، ورمونٹ,أرلينغتون', 43.0748000, -73.1540000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143215, 'Barre', 'Barre', 'Barre,Barre-siti,MPV,ba li,bari,barr,bary,Барре-сити,بارر,باري,باری,バリ,巴里', 44.1970100, -72.5020500, 'US', '2017-07-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143216, 'Bellows Falls', 'Bellows Falls', 'Bellows Falls,Bellows Falls Village,Bellows'' Falls,Bellowston,Belous Fols,Great Falls,bwls fals,Белоус Фолс,بولس فالس', 43.1334100, -72.4439800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143217, 'Bennington', 'Bennington', 'Algiers,Benington,Beningtun,Bennington,Pollywogs,Tigertown,ben ning dun,beninton,bnyngtwn  wrmwnt,bynynghtwn,Бенингтон,Бенингтън,Беннингтон,Беннінгтон,بنینگتون، ورمونت,بينينغتون,بینینگٹن، ورمونٹ,ベニントン,本宁顿', 42.8781300, -73.1967700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143218, 'Bridport', 'Bridport', 'Birdport,Bridport', 43.9850600, -73.3126200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143219, 'Brandon', 'Brandon', 'Brandon,Brehndon,Meshobe,Брэндон', 43.7981200, -73.0876100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143220, 'Brattleboro', 'Brattleboro', 'Bratlboro,Brattleboro,Brattleborough,East Brattleboro,East Village,Fort Dummer,bratlbwrw,buratoruboro,Братлборо,براتلبورو,بریٹلبورو، ورمونٹ,ブラトルボロ', 42.8509200, -72.5578700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143221, 'Bristol', 'Bristol', 'Bristol,Bristol Village,Pocock,brystwl,Бристол,برسٹل، ورمونٹ,بريستول', 44.1333900, -73.0790100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143222, 'Burlington', 'Burlington', 'BTV,Berlington,Berlingtona,Bjorlington,Borlington,Burlington,Burlingtun,Bērlingtona,Gorad Berlingtan,Odzihozek,Paliten,Queen City,Skanentgraksenge,barinton,barlingtana,beollingteon,bo ling dun,brlynghtwn,brlyngtwn,brlyngtwn  wrmant,Берлингтон,Берлінгтон,Бърлингтън,Бёрлингтон,Бӧрлингтон,Горад Берлінгтан,ברלינגטון,برلنگٹن، ورمونٹ,برلينغتون,برلینگتون، ورمانت,बर्लिंग्टन,バーリントン,伯靈頓,벌링턴', 44.4758800, -73.2120700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143223, 'Charlotte', 'Charlotte', 'Charlotta,Charlotte,Charlotte Four Corners,Sharlott,West Charlotte,sharlwt,Шарлотт,شارلوت', 44.3097700, -73.2609600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143224, 'Chelsea', 'Chelsea', 'Chelsea,Turnersburgh', 43.9897900, -72.4476000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143225, 'Chester', 'Chester', 'Chester-Chester Depot', 43.2628500, -72.5950900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143226, 'Chittenden', 'Chittenden', 'Chittenden,Slab City', 43.7078400, -72.9481600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143227, 'Clarendon', 'Clarendon', 'Clarendon,Durham,South Clarendon,South Flats,klarndwn,كلارندون', 43.5161800, -72.9698300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143228, 'Colchester', 'Colchester', 'Kolchester,koruchesuta,kwlshstr,Колчестер,كولشستر,کولچیسٹر، ورمونٹ,コルチェスター', 44.5439400, -73.1479100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143229, 'Danby', 'Danby', 'Danby,Danby Borough', 43.3461800, -72.9953800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143230, 'Dover', 'Dover', 'Dover,Dover Center,Dover Common,Довер', 42.9436900, -72.8039900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143231, 'Enosburg Falls', 'Enosburg Falls', 'Enosburg Falls,Enosburg Falls Village,Enosburgh Falls', 44.9069900, -72.8065200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143232, 'Essex Junction', 'Essex Junction', 'Eseks DZankshon,Essex Junction,Hubbels Falls,Painesville,asks jankshn,Есекс Џанкшон,إسكس جانكشن', 44.4906100, -73.1109600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143233, 'Fair Haven', 'Fair Haven', 'Fair Haven,Fairhaven,Fer Khejven,fyr hyfn,Фер Хејвен,فير هيفن,فیئر ہون، ویرمونٹ', 43.5947900, -73.2656700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143234, 'Ferrisburgh', 'Ferrisburgh', 'Ferrisbourg,Ferrisburg,Ferrisburgh,Ferrissburg', 44.2056100, -73.2462300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143235, 'Guildhall', 'Guildhall', 'Gilhall,Guildhall', 44.5650600, -71.5598100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143236, 'Hardwick', 'Hardwick', 'Hardwick,Khardvik,Lameilleville,Lamoilleville,Lamoilville,South Hardwick,hardwyk,Хардвик,هاردويك', 44.5047800, -72.3681600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143237, 'Hartford', 'Hartford', 'Centerville,Hartford,Khartford,Sucker City,hartfwrd,hatofodo,Хартфорд,هارتفورد,ہارٹفورڈ، ورمونٹ,ハートフォード', 43.6606300, -72.3384200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143238, 'Hinesburg', 'Hinesburg', 'Hinesburg,Hinesburgh', 44.3292200, -73.1106800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143239, 'Hyde Park', 'Hyde Park', 'Hide Center,Hyde Park,Hyde Park Village,Hydepark', 44.5939400, -72.6165100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143240, 'Jamaica', 'Jamaica', '', 43.1003600, -72.7784300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143241, 'Jericho', 'Jericho', 'Jericho,Jericho Four Corners,Jericho Village', 44.5039400, -72.9976300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143242, 'Johnson', 'Johnson', 'Johnson,Johnson Village', 44.6356100, -72.6804000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143243, 'Leicester', 'Leicester', 'Leicester,Leicester Corners,Leicester Four Corners', 43.8667300, -73.1078900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143244, 'Lincoln', 'Lincoln', '', 44.1058900, -72.9970600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143245, 'Londonderry', 'Londonderry', 'Kent,Londonderry', 43.2264600, -72.8064900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143246, 'Lunenburg', 'Lunenburg', 'Lunenburg,Lunenburg Corners,Lunenburg Village,Lunenburgh', 44.4631100, -71.6820300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143247, 'Lyndon', 'Lyndon', 'lyndwn,لنڈن، ورمونٹ,ليندون', 44.5142200, -72.0109300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143248, 'Lyndonville', 'Lyndonville', 'LLX,Lyndonville,Lyndonville Village', 44.5336700, -72.0031500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143249, 'Manchester Center', 'Manchester Center', 'Factory Point,Factoryville,Manchester Center,Manchester Center Depot,Manchester Centre', 43.1770200, -73.0570500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143250, 'Mendon', 'Mendon', 'Medway,Mendon,Parkerstown', 43.6519800, -72.9278000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143251, 'Middlebury (village)', 'Middlebury (village)', 'Middlebury,Middlebury (village),Middlebury Village,Midlberi,Midulburi,mi de er bao,Мидлбери,Мидълбъри,米德尔堡', 44.0155300, -73.1693700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143252, 'Milton', 'Milton', 'Mil''ton,Milton,Milton Falls,Milton Village,miruton,myltwn,Милтон,Мильтон,ملٹن، ورمونٹ,ميلتون,ミルトン', 44.6397700, -73.1104100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143253, 'Montgomery', 'Montgomery', 'Montgomeri,mwntghmry,Монтгомери,مونتغمري,مونٹگمری، ورمونٹ', 44.9025500, -72.6381800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143254, 'Montpelier', 'Montpelier', 'Gorad Mantpilier,MPV,Monpelie,Montpelier,Montpelier City,Montpelier on Uermonte,Montpelier-on-the Onion,Montpilier,Montpilijer,Montpiljera,Montpiljeres,Montpiljeris,Montpiljerės,Montpīljera,mamtapeli''e,mantpeliyar,mantpiliyar,meng bi li ai,montapeliyara,monteupillieo,montopiria,mwnblyyh,mwnplyh  wrmwnt,mwntplyyr,mxn t phe leiy r,Μονπελιέ,Горад Мантпіліер,Монпелие,Монтпилиер,Монтпилијер,Монтпілієр,Մոնտպիլիեր,מונטפלייר,مونبلييه,مونٹپلیئر,مونٹپیلیئر، ورمونٹ,مونپلیه، ورمونت,माँतपेलिए,मान्ट्पेलियर्,मोन्टपेलियर,மான்ட்பீலியர்,มอนต์เพเลียร์,モントピリア,蒙彼利埃,몬트필리어', 44.2600600, -72.5753900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143255, 'Moretown', 'Moretown', '', 44.2508900, -72.7609500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143256, 'Morristown', 'Morristown', 'Morristown,Morristown Corners,Morristown Four Corners', 44.5572700, -72.6237300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143257, 'Morrisville', 'Morrisville', 'Morrisville,Morrisville Village', 44.5617200, -72.5984500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143258, 'Mount Holly', 'Mount Holly', '', 43.4522900, -72.8248200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143259, 'Newport', 'Newport', 'Duncansboro,Duncansborough,EFK,N''juport,Newport,Njuport,Park''s Flats,niu bo te,nyupoto,nywbwrt,nywprt,Њупорт,Ньюпорт,Нюпорт,نيوبورت,نیوپرت,نیوپورٹ,ニューポート,纽波特', 44.9364400, -72.2051000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143260, 'Newfane', 'Newfane', 'Fayetteville,Newfane,Newfane Village,Njufejn,Parks Flats,Parkville,nu fan,nyufein,nywfan,Њуфејн,Нюфейн,نيوفان,ニューフェイン,努凡', 42.9856400, -72.6559300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143261, 'North Bennington', 'North Bennington', 'North Bennington,North Bennington Village,Sages City', 42.9303600, -73.2426100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143262, 'North Hero', 'North Hero', 'Island City,North Hero,The City', 44.8312500, -73.2732300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143263, 'Northfield', 'Northfield', 'Depot Village,Nortfild,Northfield,Northfield Depot,Northfield Village,nwrthfyld,Нортфилд,نارتھفیلڈ، ورمونٹ,نورثفيلد', 44.1511700, -72.6565000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143264, 'Pawlet', 'Pawlet', '', 43.3467400, -73.1762200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143265, 'Poultney', 'Poultney', 'Poultney,Poultney Village,West Poultney', 43.5170100, -73.2362200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143266, 'Pownal', 'Pownal', 'bwnal,بونال', 42.7656400, -73.2359400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143267, 'Randolph', 'Randolph', 'Randol''f,Randolf,Randolph,Slab City,West Randolph,randwlf,Рандолф,Рандольф,راندولف,رینڈولف، ورمونٹ', 43.9250700, -72.6659400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143268, 'Richford', 'Richford', 'Richford,rytshfwrd,Ричфорд,ريتشفورد', 44.9969900, -72.6712400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143269, 'Rockingham', 'Rockingham', 'rwkynghham,راکنگہیم، ورمونٹ,روكينغهام', 43.1875800, -72.4889800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143270, 'Rutland', 'Rutland', 'City of Rutland,Mill Village,RUT,Ratland,Ratlend,Rutland,Rutland City,Rutlandas,The Marble City,la te lan shi,ratlnd,ratorando,rwtland,Ратланд,Ратленд,Рътланд,راتلند,روتلاند,رٹلینڈ,ラトランド,拉特蘭市', 43.6106200, -72.9726100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143271, 'Saint Albans', 'Saint Albans', '', 44.8108800, -73.0831900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143272, 'Saint Johnsbury', 'Saint Johnsbury', 'Saint Johnsbury,Saint Johnsbury Plain', 44.4192200, -72.0150900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143273, 'Salisbury', 'Salisbury', 'Salisbury,West Salisbury,salzbry  wrmant,salzbwry,سالزبری، ورمانت,سالزبوري', 43.8964500, -73.0998400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143274, 'South Barre', 'South Barre', '', 44.1770100, -72.5056600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143275, 'South Burlington', 'South Burlington', 'Burlington on Burlington Bay,Saut Burlington,Saut-Berlington,South Burlington,brlyngtwn jnwby  wrmwnt,nan bo ling dun,sausubarinton,sawth brlnghtwn,Саут Бурлингтон,Саут-Берлингтон,Саут-Берлінгтон,برلینگتون جنوبی، ورمونت,ساؤتھ برلنگٹن، ورمونٹ,ساوث برلنغتون,サウスバーリントン,南伯灵顿', 44.4669900, -73.1709600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143276, 'Springfield', 'Springfield', 'Springfild,VSF,sbrynghfyld,seupeulingpildeu,si pu lin fei er de,Спрингфилд,Спрингфілд,سبرينغفيلد,سپرنگفیلڈ، ورمونٹ,斯普林菲爾德,스프링필드', 43.2984100, -72.4823100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143277, 'Starksboro', 'Starksboro', 'Starksboro,Starksborough', 44.2272800, -73.0573400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143278, 'Stowe', 'Stowe', 'Center Village,MVL,Stou,Stow,Stowe,Stowe Village,stw,Стоу,ستو', 44.4653300, -72.6845600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143279, 'Swanton', 'Swanton', 'Swanton,Swanton Village', 44.9181000, -73.1243000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143280, 'Townshend', 'Townshend', 'Flypot,Townsend,Townshend,Townshend Village,tawnshynd,تاونشيند', 43.0473000, -72.6675900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143281, 'Vergennes', 'Vergennes', 'De Vergens,Deergeens,Devergennesburg,Devergensburg,Vargeens,Verdzens,Vergeens,Vergennes,Vergennes City,Vergennesburg,bajenzu,fu jin si,fyrghynys,wrjyns  wrmwnt,Верџенс,فيرغينيس,ورجینس، ورمونت,ویرگینیز، ورمونٹ,バージェンズ,弗金斯', 44.1672800, -73.2540100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143282, 'Washington', 'Washington', 'Kingsland,Vashington,Washington,Вашингтон', 44.1056200, -72.4326000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143283, 'Waterbury', 'Waterbury', 'Uoturburi,Voterberi,Waterbury,Waterbury Village,watrbwry,Вотербери,Уотърбъри,واتربوري,واٹربری، ورمونٹ', 44.3378300, -72.7562300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143284, 'West Brattleboro', 'West Brattleboro', 'West Brattleboro,West Brattleborough', 42.8559200, -72.6031500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143285, 'West Rutland', 'West Rutland', '', 43.5931200, -73.0451100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143286, 'White River Junction', 'White River Junction', 'Vajt River DZankshon,White River Junction,Whiteriver Junction,Вајт Ривер Џанкшон', 43.6489600, -72.3192600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143287, 'Wilder', 'Wilder', 'Olcott,Olcott Falls,Wilder', 43.6728500, -72.3087000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143288, 'Williamstown', 'Williamstown', '', 44.1217300, -72.5414900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143289, 'Williston', 'Williston', 'Williston,Williston Centre,wylystwn,ويليستون,ویلسٹن، ورمونٹ', 44.4375500, -73.0681800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143290, 'Windsor', 'Windsor', 'Vindzor,wndswr,Виндзор,وندسور', 43.4803500, -72.3848100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143291, 'Winooski', 'Winooski', 'Allens Settlement,Mill City,Vinuski,Winooski,Winooski Falls,u~inusuki,wei nu si ji,wynwsky,wynwsky  wrmwnt,Винуски,ونوسکی، ورمونٹ,وينوسكي,وینوسکی، ورمونت,ウィヌースキー,威努斯基', 44.4914400, -73.1856800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143292, 'Woodstock', 'Woodstock', 'The Green,Udstok,Vudstok,Woodstock,Woodstock Green,uddosutokku,wu de si tuo ke,wwdstwk,Вудсток,Удсток,وودستوك,ウッドストック,伍德斯托克', 43.6242400, -72.5184300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143293, 'Abbotsford', 'Abbotsford', '', 44.9463600, -90.3159700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143294, 'Adams', 'Adams', 'Adams,South Friendship,adamsi,adamz,admz  wyskansyn,Адамс,آدامز,آدمز، ویسکانسین,ადამსი', 43.9560800, -89.8181800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143295, 'Addison', 'Addison', '', 43.4227800, -88.3745400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143296, 'Albany', 'Albany', 'Olbani,Олбани', 42.7077800, -89.4370600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143297, 'Algoma', 'Algoma', 'Ahnapee,Ahnepee,Algoma,Wolf River,alghwma,algwma  wyskansyn,Алгома,آلگوما، ویسکانسین,ألغوما', 44.6088900, -87.4325900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143298, 'Allouez', 'Allouez', '', 44.4774900, -88.0162100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143299, 'Alma', 'Alma', 'Alma,Twelve Mile Bluff,alma,alma  wskwnsn,alma  wyskansyn,Алма,آلما، ویسکانسین,ألما,الما، وسکونسن,ალმა', 44.3199700, -91.9148800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143300, 'Alto', 'Alto', '', 43.6766500, -88.7951100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143301, 'Altoona', 'Altoona', 'Altoona,Altuna,East Eau Claire,altwna,altwna  wyskansyn,Алтуна,آلتونا، ویسکانسین,ألتونا', 44.8046800, -91.4432100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143302, 'Amery', 'Amery', 'AHH,Ameri,amry  wyskansyn,amyry,Амери,آمری، ویسکانسین,أميري', 45.3069100, -92.3621400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143303, 'Amherst', 'Amherst', 'Amkherst,Амхерст', 44.4508100, -89.2848400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143304, 'Antigo', 'Antigo', 'Antigo,antyghw,antygw  wyskansyn,Антиго,أنتيغو,انتیگو، ویسکانسین', 45.1402500, -89.1523400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143305, 'Appleton', 'Appleton', 'ATW,Aplton,Appleton,Epplton,ablytwn,aepeulteon,apltwn  wyskansyn,appuruton,Аплтон,Епплтон,أبليتون,اپلتون، ویسکانسین,ایپلٹن، وسکونسن,ეპლტონი,アップルトン,애플턴', 44.2619300, -88.4153800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143306, 'Arcadia', 'Arcadia', 'Arkadija,Arkejdija,arkadya,arkadya  wyskansyn,Аркадия,Аркејдија,آرکادیا، ویسکانسین,آرکیڈیا، وسکونسن,أركاديا', 44.2527400, -91.5015400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143307, 'Ashford', 'Ashford', 'Ashford,Chili', 43.5869400, -88.3706600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143308, 'Ashland', 'Ashland', 'ASX,Ashland,Bay City,Eshland,Gichi-wiikwedong,Saint Mark,Whittlesey,Wikwedong,Zham-a-wa-mik,aesyullaendeu,ashland,ashlendi,ashlnd  wyskansyn,ya shi lan,Ешланд,آشلاند,آشلند، ویسکانسین,ایشلنڈ، وسکونسن,აშლენდი,亞士蘭,애슐랜드', 46.5924400, -90.8838000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143309, 'Ashwaubenon', 'Ashwaubenon', '', 44.4822100, -88.0701000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143310, 'Athens', 'Athens', '', 45.0330200, -90.0740200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143311, 'Augusta', 'Augusta', 'Augusta,Ogasta,Ridge Creek,Огаста', 44.6802400, -91.1198800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143312, 'Aztalan', 'Aztalan', '', 43.0727800, -88.8623300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143313, 'Baldwin', 'Baldwin', 'Baldwin,Bolduin,Clarkesville,Болдуин', 44.9666300, -92.3743600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143314, 'Balsam Lake', 'Balsam Lake', '', 45.4521800, -92.4546400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143315, 'Bangor', 'Bangor', 'Bangor,Бангор', 43.8930200, -90.9904100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143316, 'Baraboo', 'Baraboo', 'Barabu,barabw,barabw  wyskansyn,Барабу,بارابو,بارابو، ویسکانسین', 43.4710900, -89.7442900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143317, 'Barneveld', 'Barneveld', '', 43.0155500, -89.8954000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143318, 'Barron', 'Barron', 'Baron,Barron,Quaderers Camp,baroni,barwn,barwn  wyskansyn,Барон,بارون,بارون، ویسکانسین,ბარონი', 45.4013500, -91.8490600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143319, 'Barton', 'Barton', 'Barton,Newark,Salisburys Mills,Salzburg', 43.4436100, -88.1806500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143320, 'Bayside', 'Bayside', '', 43.1805600, -87.9006400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143321, 'Beaver Dam', 'Beaver Dam', 'Beaver Dam,Beaverdam,Biver Dam,byfr dam,bywr dam  wyskansyn,Бивер Дам,بيفر دام,بیور دام، ویسکانسین,بیور ڈیم، وسکونسن', 43.4577700, -88.8373300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143322, 'Belgium', 'Belgium', '', 43.4997200, -87.8503700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143323, 'Belle Plaine', 'Belle Plaine', 'Belle Plaine,Belleplaine', 44.7152600, -88.6662100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143324, 'Belleville', 'Belleville', '', 42.8597200, -89.5381800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143325, 'Bellevue', 'Bellevue', 'Belleview,Bellevue', 44.4441600, -87.9201000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143326, 'Beloit', 'Beloit', 'Beloit,Belojt,Blodgett Settlement,New Albany,The Turtle,Turtle Creek,blwyt,bylwyt  wyskansyn,Белойт,Белојт,بلويت,بیلوئٹ، وسکونسن,بیلویت، ویسکانسین', 42.5083500, -89.0317800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143327, 'Berlin', 'Berlin', 'Berlin,Strongs Landing,Strongville,berlini,brln  wskwnsn,brlyn,brlyn  wyskansyn,Берлин,برلن، وسکونسن,برلين,برلین، ویسکانسین,ბერლინი', 43.9680400, -88.9434500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143328, 'Bevent', 'Bevent', '', 44.7705300, -89.3895600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143329, 'Big Bend', 'Big Bend', '', 42.8814000, -88.2067600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143330, 'Black Creek', 'Black Creek', 'Black Creek,Blackcreek', 44.4774900, -88.4506600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143331, 'Black Earth', 'Black Earth', 'Black Earth,Farmersville,Ray', 43.1372200, -89.7467900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143332, 'Black River Falls', 'Black River Falls', 'Blek River Fols,blak ryfr fwlz,blk rywr falz  wyskansyn,Блек Ривер Фолс,بلاك ريفر فولز,بلک ریور فالز، ویسکانسین', 44.2946800, -90.8515300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143333, 'Blair', 'Blair', 'Blair,Porterville', 44.2944000, -91.2351600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143334, 'Bloomer', 'Bloomer', 'Bloomer,Bloomer Prairie,Vanville', 45.1002400, -91.4887700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143335, 'Bohners Lake', 'Bohners Lake', '', 42.6230700, -88.2803700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143336, 'Bonduel', 'Bonduel', '', 44.7402700, -88.4448200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143337, 'Boscobel', 'Boscobel', '', 43.1344300, -90.7054000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143338, 'Boyceville', 'Boyceville', '', 45.0435700, -92.0410100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143339, 'Brice Prairie', 'Brice Prairie', '', 43.9385700, -91.2998600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143340, 'Brillion', 'Brillion', 'Brillion,Spring Creek', 44.1772100, -88.0642700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143341, 'Bristol', 'Bristol', 'Bristol,Village of Bristol', 42.5589100, -88.0492500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143342, 'Brodhead', 'Brodhead', '', 42.6183400, -89.3762300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143343, 'Brookfield', 'Brookfield', 'Brukfild,brwkfyld,brwkfyld  wyskansyn,Брукфилд,بروكفيلد,بروکفیلد، ویسکانسین,بروکفیلڈ، وسکونسن', 43.0605700, -88.1064800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143344, 'Brooklyn', 'Brooklyn', 'Bruklin,Бруклин', 42.8536100, -89.3704000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143345, 'Brothertown', 'Brothertown', '', 43.9680500, -88.3089900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143346, 'Brown Deer', 'Brown Deer', 'Brown Deer,White Deer', 43.1633400, -87.9645300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143347, 'Browns Lake', 'Browns Lake', '', 42.6925200, -88.2312000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143348, 'Burlington', 'Burlington', 'Berlington,brlnghtwn,brlyngtwn  wyskansyn,Берлингтон,برلنغتون,برلنگٹن، وسکونسن,برلینگتون، ویسکانسین', 42.6780700, -88.2762000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143349, 'Butler', 'Butler', 'Butler,New Butler', 43.1058400, -88.0695300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143350, 'Cadott', 'Cadott', 'Cadott,Cadotte Falls', 44.9480200, -91.1507000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143351, 'Caledonia', 'Caledonia', 'Caledonia,Kaledonija,Village of Caledonia,Каледония', 42.8078000, -87.9242500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143352, 'Cambridge', 'Cambridge', 'Kembridzh,Кембридж', 43.0036100, -89.0165000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143353, 'Cameron', 'Cameron', '', 45.4085700, -91.7440600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143354, 'Camp Lake', 'Camp Lake', '', 42.5347400, -88.1437000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143355, 'Campbellsport', 'Campbellsport', 'Campbells Port,Campbellsport,Crouchville,New Cassel', 43.5977700, -88.2789900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143356, 'Cashton', 'Cashton', 'Cashton,Mount Pisgah', 43.7419100, -90.7793000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143357, 'Cato', 'Cato', 'Cato,Harris,Harrisville', 44.1427700, -87.8612000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143358, 'Cedar Grove', 'Cedar Grove', 'Cedar Grove,Cedargrove', 43.5697200, -87.8234200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143359, 'Cedarburg', 'Cedarburg', 'Cedarburg,Cedarburgh,Sidarberg,sydarbwrgh,sydrbrg  wyskansyn,Сидарберг,سيداربورغ,سیدربرگ، ویسکانسین', 43.2966700, -87.9875900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143360, 'Chetek', 'Chetek', '', 45.3141300, -91.6510000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143361, 'Chilton', 'Chilton', 'Chillington,Chilton,Stantonville,chyltwn  wyskansyn,shyltwn,Чилтон,شيلتون,چیلتون، ویسکانسین,ჩილტონი', 44.0288800, -88.1628800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143362, 'Chippewa Falls', 'Chippewa Falls', 'Chipeva Fols,Chippeva-Folls,chypwa falz  wyskansyn,shbwa fwlz,Чипева Фолс,Чіппева-Фоллс,شبوا فولز,چیپوا فالز، ویسکانسین', 44.9369100, -91.3929300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143363, 'Clear Lake', 'Clear Lake', 'Clear Lake,Clearlake', 45.2519100, -92.2713000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143364, 'Cleveland', 'Cleveland', 'Centerville Station,Centreville,Cleveland,Klivlend,Кливленд', 43.9149900, -87.7473100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143365, 'Clinton', 'Clinton', 'Clinton,Clinton Junction,Klinton,New York,Клинтон', 42.5577900, -88.8651100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143366, 'Clintonville', 'Clintonville', 'CLI,Clintonville,Klintonvil,Pigeon,klyntwn wyl  wyskansyn,klyntwnfyl,Клинтонвил,كلينتونفيل,کلینتون ویل، ویسکانسین', 44.6205300, -88.7623200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143367, 'Colby', 'Colby', 'Kolbi,kwby  wyskansyn,kwlby,Колби,كولبي,کوبی، ویسکانسین', 44.9099700, -90.3156900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143368, 'Colfax', 'Colfax', 'Begga Town,Colfax', 44.9974600, -91.7271200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143369, 'Columbus', 'Columbus', 'Kolambus,Kolumbus,klmbws  wyskansyn,kwlmbs  wskwnsn,kwlwmbws,Коламбус,Колумбус,كولومبوس,کلمبوس، ویسکانسین,کولمبس، وسکونسن,კოლუმბუსი', 43.3380500, -89.0153900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143370, 'Combined Locks', 'Combined Locks', '', 44.2658200, -88.3142700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143371, 'Como', 'Como', '', 42.6122400, -88.4823200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143372, 'Concord', 'Concord', '', 43.0694500, -88.5987100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143373, 'Cooperstown', 'Cooperstown', '', 44.3127700, -87.7745300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143374, 'Cornell', 'Cornell', 'Brunets Falls,Cornell', 45.1671900, -91.1493100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143375, 'Cottage Grove', 'Cottage Grove', 'Cottage Grove,Cottagegrove', 43.0761100, -89.1995600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143376, 'Crandon', 'Crandon', 'Ayr,Crandon,Krandon,krandwn,krndn  wyskansyn,Крандон,كراندون,کرندن، ویسکانسین', 45.5719100, -88.9028900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143377, 'Cross Plains', 'Cross Plains', 'Baerville,Christina,Cross Plains,Crossplains,Foxville', 43.1144400, -89.6556800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143378, 'Cuba City', 'Cuba City', 'Craiglaw,Cuba,Cuba City,Western,Yuba', 42.6055500, -90.4298500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143379, 'Cudahy', 'Cudahy', 'Kadakhej,kwdahy,kwdahy  wyskansyn,Кадахеј,كوداهي,کوداهی، ویسکانسین,کیڈاہی، وسکونسن,კადაჰი', 42.9597400, -87.8614700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143380, 'Cumberland', 'Cumberland', 'Cumberland,Island City,Kamberland,Kamberlend,kmbrland,kwmbrlnd  wyskansyn,Камберланд,Камберленд,كمبرلاند,کومبرلند، ویسکانسین', 45.5321800, -92.0193500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143381, 'Dakota', 'Dakota', '', 43.9902500, -89.3565100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143382, 'Dane', 'Dane', 'Dane,Dane Station', 43.2505500, -89.5015100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143383, 'Darien', 'Darien', 'Bruceville,Darien', 42.6016800, -88.7076000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143384, 'Darlington', 'Darlington', 'Darlington,darlyngtwn  wyskansyn,darlynjtwn,Дарлингтон,دارلينجتون,دارلینگتون، ویسکانسین,დარლინგტონი', 42.6830600, -90.1176300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143385, 'De Forest', 'De Forest', 'De Forest,Deforest', 43.2477700, -89.3437300, 'US', '2017-06-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143386, 'De Pere', 'De Pere', 'De Per,De Pere,Depere,Depierre,dy byr,dy pr  wyskansyn,Де Пер,دي بير,دی پر، ویسکانسین,ڈی پیر، وسکونسن,დი-პერი', 44.4488800, -88.0603800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143387, 'Deerfield', 'Deerfield', '', 43.0519400, -89.0756700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143388, 'Delafield', 'Delafield', 'Delafield,Delafild,Hayopolis,Nehamabin,Nemahbin,dlfyld  wyskansyn,dylafyld,Делафилд,دلفیلد، ویسکانسین,ديلافيلد', 43.0608400, -88.4037100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143389, 'Delavan', 'Delavan', 'Delavan,dlwan  wyskansyn,dylafan,Делаван,دلوان، ویسکانسین,ديلافان', 42.6330700, -88.6437100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143390, 'Delavan Lake', 'Delavan Lake', '', 42.5841800, -88.6326000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143391, 'Denmark', 'Denmark', '', 44.3477700, -87.8273200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143392, 'Dickeyville', 'Dickeyville', 'Dickeysville,Dickeyville', 42.6272200, -90.5920700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143393, 'Dodgeville', 'Dodgeville', 'Dodgeville,Dodzvil,Minersville,dajvili,dwdjfyl,dwjwyl  wyskansyn,Доџвил,دوجویل، ویسکانسین,دودجفيل,დაჯვილი', 42.9602700, -90.1301200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143394, 'Dousman', 'Dousman', 'Dousman,Utica', 43.0141800, -88.4726000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143395, 'Durand', 'Durand', 'Djurand,dwrand,dwrnd  wyskansyn,Дјуранд,دوراند,دورند، ویسکانسین', 44.6263500, -91.9657300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143396, 'Eagle', 'Eagle', 'Eagle,Eagle Center,Pittman', 42.8794600, -88.4742700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143397, 'Eagle Lake', 'Eagle Lake', '', 42.7069600, -88.1281400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143398, 'Eagle River', 'Eagle River', 'EGV,Igl River,ayghl ryfr,aygl rywr  wyskansyn,Игл Ривер,إيغل ريفر,ایگل ریور، ویسکانسین', 45.9171800, -89.2443000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143399, 'East Troy', 'East Troy', '', 42.7852900, -88.4051000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143400, 'Easton', 'Easton', '', 43.8380300, -89.8067900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143401, 'Eau Claire', 'Eau Claire', 'Clearwater,EAU,Eau Claire,Eauclaire,O Kler,O Kleras,O-Klehr,O-Kler,Oklera,Oklēra,Ou Kler,aw klyr,aww klyyr  wskwnsn,aywklyr  wyskansyn,okeulleeo,okurea,ou ke lei er,qing shui shi,О Клер,О-Клер,О-Клэр,Оу Клер,أو كلير,اوو کلیئر، وسکونسن,ایوکلیر، ویسکانسین,โอแคลร์,ო-კლერი,オークレア,歐克雷爾,清水市,오클레어', 44.8113500, -91.4984900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143402, 'Edgar', 'Edgar', '', 44.9271900, -89.9634600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143403, 'Edgerton', 'Edgerton', 'Edgerton,Edzerton,Egerton,Fulton Station,ajrtwn  wyskansyn,aydjyrtwn,Еџертон,إيدجيرتون,اجرتون، ویسکانسین', 42.8352800, -89.0676100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143404, 'Eldorado', 'Eldorado', 'Eldon,Eldorado', 43.8247100, -88.6217800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143405, 'Elkhorn', 'Elkhorn', 'Bradleys,Elkhorn,Elkkhorn,alhwrn  wyskansyn,alkwrn,Елкхорн,إلكورن,الهورن، ویسکانسین', 42.6727900, -88.5445400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143406, 'Ellsworth', 'Ellsworth', 'Ellsworth,Perry', 44.7321900, -92.4874100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143407, 'Elm Grove', 'Elm Grove', 'Elm Grove,Elmgrove', 43.0430700, -88.0789800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143408, 'Elroy', 'Elroy', '', 43.7408000, -90.2723500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143409, 'Evansville', 'Evansville', 'Ehvansvill,Evansvil,Evansville,The Grove,awanswyl  wyskansyn,ayfansfyl,ebanzubiru,Евансвил,Эвансвилл,إيفانسفيل,اوانسویل، ویسکانسین,エバンズビル', 42.7802800, -89.2992800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143410, 'Evergreen', 'Evergreen', '', 44.8424700, -89.6376200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143411, 'Fall Creek', 'Fall Creek', 'Cousins,Fall Creek,Fallcreek', 44.7635700, -91.2771000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143412, 'Fall River', 'Fall River', 'Fall River,Fallriver', 43.3844300, -89.0451100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143413, 'Fennimore', 'Fennimore', 'Fennimore,Fennimore Center', 42.9836000, -90.6554000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143414, 'Fitchburg', 'Fitchburg', 'Fichburg,Fitchburg,Fitchburg Station,Greenfield,fychbrg  wskwnsn,fychbrg  wyskansyn,fytshbwrgh,Фичбург,فيتشبورغ,فیچبرگ، وسکونسن,فیچبرگ، ویسکانسین', 42.9608300, -89.4698400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143415, 'Florence', 'Florence', 'Eagle,Florence', 45.9221800, -88.2518000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143416, 'Fond du Lac', 'Fond du Lac', 'FLD,Fon du Lak,Fon-dju-Lak,Fond du Lac,Wanikamiu,fonde~yuraku,fwnd dw lak,fwnd dw lk  wyskansyn,Фон ду Лак,Фон-дю-Лак,فوند دو لاك,فوند دو لک، ویسکانسین,فونڈ ڈو لاک، وسکونسن,ფონდ-დუ-ლაკი,フォンデュラク', 43.7750000, -88.4388300, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143417, 'Fontana', 'Fontana', 'Fontana,Fontana on Geneva Lake,Fontana-on-Geneva Lake,Фонтана', 42.5514100, -88.5751000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143418, 'Fort Atkinson', 'Fort Atkinson', 'Fort Atkinson,Fort Coscong,Fort Koshkonong,fwrt atkynswn,fwrt atkynswn  wyskansyn,Форт Аткинсон,فورت أتكينسون,فورت اتکینسون، ویسکانسین', 42.9288900, -88.8370500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143419, 'Fox Lake', 'Fox Lake', 'Day-wau-sha-ra,Fox Lake,Foxlake,Waushara', 43.5655400, -88.9065000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143420, 'Fox Point', 'Fox Point', 'Dutch Settlement,Fox Point,Foxs Point', 43.1575100, -87.9017500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143421, 'Franklin', 'Franklin', 'Franklin,Frenklin,franklyn,franklyn  wyskansyn,Франклин,Френклин,فرانكلين,فرانکلین، ویسکانسین,فرینکلن، ملواکی کاؤنٹی، وسکونسن,ფრანკლინი', 42.8886300, -88.0384200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143422, 'Franksville', 'Franksville', 'Franks Villa,Franksville,Skunk Grove', 42.7600200, -87.9134100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143423, 'Frederic', 'Frederic', 'Frederic,Frederick', 45.6591200, -92.4671400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143424, 'Fredonia', 'Fredonia', 'Fredonia,Fredonia Station,Stoney Creek', 43.4705600, -87.9506500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143425, 'French Island', 'French Island', '', 43.8583000, -91.2604200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143426, 'Friendship', 'Friendship', 'Frendship,frynd shyb,Френдшип,فريند شيب,فرینڈشپ، وسکونسن,ფრენდშიპი', 43.9705300, -89.8167900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143427, 'Galesville', 'Galesville', 'Gejlsvil,ghalsfyl,glswyl  wyskansyn,Гејлсвил,غالسفيل,گلسویل، ویسکانسین', 44.0816300, -91.3490400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143428, 'Genoa City', 'Genoa City', 'Genoa City,Genoa Junction', 42.4983500, -88.3281500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143429, 'Germantown', 'Germantown', '', 43.2286200, -88.1103700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143430, 'Gillett', 'Gillett', 'Gillett,Gillett Center', 44.8899900, -88.3073200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143431, 'Glendale', 'Glendale', 'Glendeilas,Glendejl,ghlyndyl,glendeili,glndyl  wyskansyn,Глендейл,Глендејл,غلينديل,گلندیل، ویسکانسین,გლენდეილი', 43.1352900, -87.9356400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143432, 'Glenmore', 'Glenmore', '', 44.3858300, -87.9273200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143433, 'Glenwood City', 'Glenwood City', 'Glenwood,Glenwood City', 45.0585700, -92.1724100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143434, 'Grafton', 'Grafton', 'Grafton,Hamburg', 43.3197300, -87.9534200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143435, 'Grantsburg', 'Grantsburg', 'GTG,Grantsburg,Kitchi-maski-gimi-nika-ning', 45.7763400, -92.6827000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143436, 'Green Bay', 'Green Bay', 'GRB,Green Bay,Greenbay,Grijn Bej,Grin Bej,Grin Bejus,Grin Bey,Grin Bėjus,Grin-Bej,Nkrin Bei,ge lin bei,geulinbei,ghryn bay,grin-bei,grina be,gryn byy,gurinbei,kri nbey,Γκριν Μπέι,Грийн Бей,Грин Беј,Грин-Бей,Грін-Бей,Գրին Բեյ,גרין ביי,غرين باي,گرین بے، وسکانسن,گرین‌بی، ویسکانسین,ग्रीन बे,กรีนเบย์,გრინ-ბეი,グリーンベイ,格林贝,그린베이', 44.5191600, -88.0198300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143437, 'Green Lake', 'Green Lake', 'Dartford,Green Lake,Village of Dartford', 43.8441500, -88.9601100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143438, 'Greendale', 'Greendale', 'Grindejl,Gryndeilas,ghryndyl,grindeili,Гриндејл,غرينديل,გრინდეილი', 42.9405700, -87.9959200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143439, 'Greenfield', 'Greenfield', 'Grinfild,ghrynfyld,grinpildi,grynfyld  wyskansyn,Гринфилд,غرينفيلد,گرین فیلڈ، وسکونسن,گرینفیلد، ویسکانسین,გრინფილდი', 42.9614000, -88.0125900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143440, 'Greenwood', 'Greenwood', '', 44.7702400, -90.5993100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143441, 'Hales Corners', 'Hales Corners', '', 42.9375100, -88.0487000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143442, 'Hammond', 'Hammond', 'Khammond,Хаммонд', 44.9788600, -92.4357500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143443, 'Hartford', 'Hartford', 'Hartford,Khartford,Wright,hartfwrd,Хартфорд,هارتفورد,ہارٹفورڈ، وسکونسن', 43.3177800, -88.3789900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143444, 'Hartland', 'Hartland', 'Hartland,Hershey''s Mills,Hersheyville,Sha-ba-qua-nake,Warren', 43.1050100, -88.3420400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143445, 'Hayward', 'Hayward', 'HYR,Khejuurd,Khejvard,hai wo de,hayward,hywrd  wyskansyn,Хейуърд,Хејвард,هايوارد,هیورد، ویسکانسین,海沃德', 46.0130100, -91.4846200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143446, 'Hazel Green', 'Hazel Green', 'Hard Scrabble,Hardy Scrape,Hazel Green,Hazelgreen,Hazle', 42.5327800, -90.4345700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143447, 'Hilbert', 'Hilbert', '', 44.1402700, -88.1639900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143448, 'Hillsboro', 'Hillsboro', 'Hillsboro,Hillsborough,Khillsboro,Хиллсборо', 43.6522000, -90.3440200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143449, 'Holmen', 'Holmen', 'Cricken,Frederickstown,Holmen', 43.9633000, -91.2562500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143450, 'Horicon', 'Horicon', 'Elk Village,Horicon,Hubbard''s Town,Hubbards Rapids,Indian Ford', 43.4513800, -88.6312100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143451, 'Hortonville', 'Hortonville', '', 44.3347000, -88.6381600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143452, 'Howard', 'Howard', '', 44.5436000, -88.0881600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143453, 'Howards Grove', 'Howards Grove', 'Howards Grove,Pitchville', 43.8338800, -87.8200900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143454, 'Hudson', 'Hudson', 'Buena Vista,Gudzon,Hudson,Khadson,Willow River,hdswn,hwdswn  wyskansyn,Гудзон,Хадсон,هدسون,هودسون، ویسکانسین,ہڈسن، وسکونسن', 44.9746900, -92.7568700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143455, 'Hurley', 'Hurley', 'Kherli,harli,hwrly  wyskansyn,hyrly,Херли,هورلی، ویسکانسین,هيرلي,ჰარლი', 46.4496700, -90.1865600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143456, 'Hustisford', 'Hustisford', 'Hushsford,Hustis Rapids,Hustisford,Rock River Rapids', 43.3461100, -88.6006600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143457, 'Independence', 'Independence', '', 44.3569100, -91.4204300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143458, 'Iola', 'Iola', '', 44.5080300, -89.1306700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143459, 'Ixonia', 'Ixonia', '', 43.1438900, -88.5973200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143460, 'Jackson', 'Jackson', 'Dzhekson,Джексон', 43.3238900, -88.1667600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143461, 'Janesville', 'Janesville', 'Black Hawk,Dzejnsvil,Dzhejnsvil'',Dzhejnsvill,E-nee-poro-poro,JVL,Janesville,jaynsfyl,jeinseubil,jeinsvili,jenzubiru,jnswyl  wskwnsn,jynswyl  wyskansyn,Џејнсвил,Джейнсвилл,Джейнсвіль,جاينسفيل,جنسویل، وسکونسن,جینسویل، ویسکانسین,ჯეინსვილი,ジェーンズビル,제인스빌', 42.6827900, -89.0187200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143462, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefferson,jepersoni,jfrswn  wyskansyn,jyfrswn,Џеферсон,Джефферсон,جفرسون، ویسکانسین,جيفرسون,ჯეფერსონი', 43.0055600, -88.8073300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143463, 'Johnson Creek', 'Johnson Creek', 'Belleville,Johnson City,Johnson Creek,Johnson''s Creek', 43.0761100, -88.7742700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143464, 'Juneau', 'Juneau', 'Dodge Center,Dzhuno,Juneau,UNU,Victory,Джуно', 43.4055500, -88.7051000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143465, 'Kaukauna', 'Kaukauna', 'Kakaling,Kaukauna,Kokona,Okakaning,kakana  wyskansyn,kawkawna,kawkawna  wskwnsn,Кокона,كاوكاونا,كاوكاونا، وسکونسن,کاکانا، ویسکانسین,კაუკაუნა', 44.2780400, -88.2720500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143466, 'Kenosha', 'Kenosha', 'ENW,Kenosa,Kenosha,Kenoša,Southport,kenosha,keonosya,knwsha  wyskansyn,kynwsha,kynwsha  wskwnsn,qnwsh,Кеноша,Կենոշա,קנושה,كينوشا,کنوشا، ویسکانسین,کینوشا، وسکونسن,კენოშა,ケノーシャ,커노샤', 42.5847400, -87.8211900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143467, 'Keshena', 'Keshena', '', 44.8838700, -88.6337200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143468, 'Kewaskum', 'Kewaskum', 'Kewaskum,Kewaskums Camp', 43.5208300, -88.2289900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143469, 'Kewaunee', 'Kewaunee', 'Kivoni,kywany  wyskansyn,kywawny,Кивони,كيواوني,کیوانی، ویسکانسین,კეუონი', 44.4583300, -87.5031400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143470, 'Kiel', 'Kiel', 'Kiel,Schleswig', 43.9124900, -88.0356500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143471, 'Kimberly', 'Kimberly', '', 44.2722100, -88.3390000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143472, 'King', 'King', 'King,Wisconsin Veterans Home', 44.3374800, -89.1417800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143473, 'Kohler', 'Kohler', 'Kohler,Koller', 43.4963900, -88.0234300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143474, 'Kronenwetter', 'Kronenwetter', '', 44.8221900, -89.5904000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143475, 'La Crosse', 'La Crosse', 'Gateway City,LSE,La Crosse,La Kros,La-Kross,Lac Rosse,Lacrosse,Prairie La Crosse,Prairie la Crosse,la ke luo si,la kras  wyskansyn,la krws  wskwnsn,lakrws,rakurosu,Ла Крос,Ла-Кросс,لا کراس، ویسکانسین,لا کروس، وسکونسن,لاكروس,ლა-კროსი,ラクロス,拉克罗斯', 43.8013600, -91.2395800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143476, 'Lac du Flambeau', 'Lac du Flambeau', '', 45.9696700, -89.8921000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143477, 'Ladysmith', 'Ladysmith', 'Corbett,Flambeau Falls,Ladysmith,Lejdismit,Warner,lydy asmyt  wyskansyn,lydysmyth,Лејдисмит,ليديسميث,لیدی اسمیت، ویسکانسین,لیڈی سمتھ، وسکونسن,ლედისმიტი', 45.4630200, -91.1040400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143478, 'Lake Delton', 'Lake Delton', '', 43.6010900, -89.7937400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143479, 'Lake Geneva', 'Lake Geneva', 'Lake Geneva,Lejk DZenova,Lejk-Dzheniva,Lejk-Zheneva,XES,lyk jnwa  wyskansyn,lyk jnyf,lyk jnywa  wskwnsn,Лейк-Дженива,Лейк-Женева,Лејк Џенова,ليك جنيف,لیک جنوا، ویسکانسین,لیک جنیوا، وسکونسن,レイク・ジェニーバ', 42.5916800, -88.4334300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143480, 'Lake Hallie', 'Lake Hallie', '', 44.8757900, -91.4407100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143481, 'Lake Koshkonong', 'Lake Koshkonong', '', 42.9097300, -88.9195500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143482, 'Lake Mills', 'Lake Mills', 'Keyes Mills,Lake Mills,Lakemills,Tyranea', 43.0813900, -88.9117700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143483, 'Lake Nebagamon', 'Lake Nebagamon', '', 46.5149400, -91.6999100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143484, 'Lake Ripley', 'Lake Ripley', '', 43.0058300, -88.9862200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143485, 'Lake Wazeecha', 'Lake Wazeecha', '', 44.3710800, -89.7565100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143486, 'Lake Wisconsin', 'Lake Wisconsin', '', 43.3736000, -89.5756800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143487, 'Lake Wissota', 'Lake Wissota', 'Lake Wissota,Wissota Beach', 44.9263500, -91.3009900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143488, 'Lamartine', 'Lamartine', 'Lamartine,Seven Mile Creek', 43.7333200, -88.5687200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143489, 'Lancaster', 'Lancaster', 'Lankaster,lankstr,lnkstr  wyskansyn,Ланкастер,لانكستر,لانکیسٹر، وسکونسن,لنکستر، ویسکانسین', 42.8474900, -90.7106800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143490, 'Lannon', 'Lannon', 'Lannon,Stone City', 43.1461200, -88.1662000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143491, 'Little Chute', 'Little Chute', 'Litl Shut,Little Chute,Littlechute,lytl tshwt,Литл Шут,ليتل تشوت,ლიტლ-შუტი', 44.2799900, -88.3184400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143492, 'Little Round Lake', 'Little Round Lake', '', 45.9649500, -91.3679500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143493, 'Lodi', 'Lodi', 'Lodaj,Lodi,lady  wyskansyn,lwdy,Лодај,Лоди,لادی، ویسکانسین,لودي', 43.3138800, -89.5265100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143494, 'Lomira', 'Lomira', 'Lomira,Springfield', 43.5913800, -88.4437100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143495, 'Loyal', 'Loyal', '', 44.7369100, -90.4959700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143496, 'Luck', 'Luck', '', 45.5760700, -92.4827000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143497, 'Luxemburg', 'Luxemburg', 'Luxembourg,Luxemburg', 44.5386100, -87.7039800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143498, 'Madison', 'Madison', 'Gorad Madysan,MSN,Madison,Madisonas,Madisonia,Madisons,Madisun,Mantison,Medison,Medisona,Mehdison,madisan,madison,madisoni,madyswn,maediseun,mai di xun,maidisana,mdysn  wyskansyn,mdyswn,medisana,metican,Μάντισον,Горад Мадысан,Мадисон,Мадисън,Медисон,Медісон,Мэдисон,Մեդիսոն,מדיסון,ماديسون,مدیسن، ویسکانسین,میڈیسن,میڈیسون، وسکونسن,माडिसन्,मॅडिसन,मेडिसन,मैडिसन,மேடிசன்,მადისონი,マディソン,麦迪逊,매디슨', 43.0730500, -89.4012300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143499, 'Manawa', 'Manawa', 'Brickley,Manawa', 44.4644300, -88.9198300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143500, 'Manchester', 'Manchester', 'Albany,Hardin,Manchester,Манчестер', 43.6905400, -89.0484500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143501, 'Manitowoc', 'Manitowoc', 'MTW,Manitovok,Manitowoc,Munedowk,manitowakku,manytwwk,myntwwak  wyskansyn,Манитовок,مانيتووك,مینتوواک، ویسکانسین,مینیٹوواک، وسکونسن,მანიტოუოკი,マニトワック', 44.0886100, -87.6575800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143502, 'Maple Bluff', 'Maple Bluff', 'Lakewood Bluff,Maple Bluff', 43.1183300, -89.3795600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143503, 'Marathon', 'Marathon', 'Marathon,Marathon City', 44.9291300, -89.8404000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143504, 'Marinette', 'Marinette', 'Marinet,marynyt,mrynt  wyskansyn,Маринет,مارينيت,مرینت، ویسکانسین,მარინეტი', 45.0999800, -87.6306600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143505, 'Marion', 'Marion', 'Marion,Mehrion,Perry''s Mill,Perrys Mill,Perrys Mills,Мэрион', 44.6708100, -88.8892700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143506, 'Markesan', 'Markesan', 'Granville,Markesan', 43.7072000, -88.9901100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143507, 'Marshall', 'Marshall', 'Bird''s Ruins,Hanchettsville,Hanchettville,Howard City,Marshall,Маршалл', 43.1683300, -89.0667800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143508, 'Marshfield', 'Marshfield', 'MFI,Marshfild,marshfyld,marshfyld  wyskansyn,Маршфилд,مارشفيلد,مارشفیلد، ویسکانسین,مارشفیلڈ، وسکونسن', 44.6688500, -90.1718000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143509, 'Mauston', 'Mauston', 'Maughs Mills,Maughstown,Mauston,To-ko-nee', 43.7971900, -90.0773500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143510, 'Mayville', 'Mayville', '', 43.4941600, -88.5448200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143511, 'Mazomanie', 'Mazomanie', 'Mazo Manie,Mazomanie', 43.1766600, -89.7948500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143512, 'McFarland', 'McFarland', 'Macfarland,McFarland', 43.0125000, -89.2898400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143513, 'Medford', 'Medford', 'MDF,Medford,mdfwrd  wyskansyn,mydfwrd,Медфорд,مدفورد، ویسکانسین,ميدفورد,میڈفورڈ، وسکونسن', 45.1385800, -90.3401400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143514, 'Menasha', 'Menasha', 'Menasha,Menassa,menasha,mnasha  wyskansyn,mynasha,mynasha  wskwnsn,Менаша,مناشا، ویسکانسین,ميناشا,میناشا، وسکونسن,მენაშა,メナシャ', 44.2022100, -88.4465000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143515, 'Menomonee Falls', 'Menomonee Falls', 'Menomonee,Menomonee Falls,Menomoni Fols,Nehsville,mynwmwny falz  wskwnsn,mynwmwny fwlz,Меномони Фолс,مينوموني فولز,مینومونی فالز، وسکونسن', 43.1789000, -88.1173100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143516, 'Menomonie', 'Menomonie', 'Menomonee,Menomonee Mills,Menomoni,Menomonie,mei nuo mo ni,minomini,mnwmny  wyskansyn,mynwmwny,mynwmwny  wskwnsn,Меномони,منومنی، ویسکانسین,مينوموني,مینومونی، وسکونسن,მინომინი,梅诺莫尼', 44.8755200, -91.9193400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143517, 'Mequon', 'Mequon', 'mkwan  wyskansyn,mykwyn  wskwnsn,mykywn,ميكيون,مکوان، ویسکانسین,میکوئن، وسکونسن', 43.2155500, -88.0300100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143518, 'Merrill', 'Merrill', 'Jenny,Jenny Bull Falls,Jenny Falls,Meril,Merrill,Mush-ko-da-yaw Tosh-ko-bo-je-gun,merili,mryl  wyskansyn,myryl,Мерил,مریل، ویسکانسین,ميريل,მერილი', 45.1805200, -89.6834600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143519, 'Merton', 'Merton', 'Merton,Moreton,Warren', 43.1466700, -88.3067600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143520, 'Middleton', 'Middleton', 'Midlton,mydltwn,mydltwn  wyskansyn,Мидлтон,ميدلتون,مڈلٹن، وسکونسن,میدلتون، ویسکانسین', 43.0972200, -89.5042900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143521, 'Milford', 'Milford', '', 43.1008300, -88.8467700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143522, 'Milton', 'Milton', 'Grainfield,Mil''ton,Milton,myltwn,myltwn  wyskansyn,Милтон,Мильтон,ملٹن، وسکونسن,ميلتون,میلتون، ویسکانسین', 42.7755600, -88.9440000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143523, 'Milwaukee', 'Milwaukee', 'Gorad Miluoki,Juneautown,Kilbourntown,MKE,Mahn-a-wau-kee Seepe,Mahn-a-wauk-ee See-pe,Mahn-a-waukee Seepe,Mahn-a-waukie,Mahn-ah-wauk Seepe,Mahnawauk,Man-a-wau-kee,Man-a-wauk-ee,Man-na-wah-kie,Mana''wa,Manawaki,Manawaukee,Manayaukee,Maunahwauke,Mee-lee-waug-ee,Meliki,Melleoki,Melwarik,Meneawkee,Meolaki,Mil-wah-kie,Milgouoki,Milioke,Millewacki,Millicki,Milo-aki,Milouagui,Milouakik,Milowages,Miluoki,Miluokʻi,Milvauchia,Milvoki,Milvokio,Milvokis,Milwacky,Milwahkie,Milwalka,Milwalky,Milwarck,Milwarik,Milwaucki,Milwaukee,Milwaukie,Minewaki,Miniaki,Minnawack,Winnipesaukee,mi er wo ji,mil wxki,mil-woki,mila''oyaki,milavoki,miluokʼi,milvaki,milvakki,milvauki,miruu~oki,mlwaky,mylwaky,mylwaky  wyskansyn,mylwwqy,Μιλγουόκι,Горад Мілуокі,Милвоки,Милуоки,Мілуокі,Միլուոքի,מילוואקי,מילווקי,ملواکی,ميلواكي,میلواکی، ویسکانسین,मिलवॉकी,मिल्वौकी,মিলওয়াকি,மில்வாக்கி,మిల్వాకీ,ಮಿಲ್ವಾಕೀ,มิลวอกี,მილუოკი,ミルウォーキー,密尔沃基,密爾沃基,밀워키', 43.0389000, -87.9064700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143524, 'Mineral Point', 'Mineral Point', 'Mineral Point,Mineral Pojnt,Mineralpoint,mynral pwynt  wyskansyn,mynyral nqtt,Минерал Појнт,مينيرال نقطة,مینرال پوینت، ویسکانسین,მინერალ-პოინტი', 42.8600000, -90.1798500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143525, 'Mishicot', 'Mishicot', 'Mishicot,Mishicott,Saxonburgh', 44.2391600, -87.6411900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143526, 'Mondovi', 'Mondovi', 'Farringtons,Mondovi,Pan Cake Valley', 44.5677400, -91.6709900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143527, 'Monona', 'Monona', '', 43.0622200, -89.3340100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143528, 'Monroe', 'Monroe', 'Monro,manrw  wyskansyn,meonlo,monro,mwnrw,Монро,مانرو، ویسکانسین,مونرو,მონრო,먼로', 42.6011200, -89.6384500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143529, 'Montello', 'Montello', 'Hill River,Montello,Montelo,Serairo,mwntlw  wyskansyn,mwntylw,Монтело,مونتلو، ویسکانسین,مونتيلو,მონტელო', 43.7913700, -89.3198400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143530, 'Monticello', 'Monticello', '', 42.7455600, -89.5948400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143531, 'Mosinee', 'Mosinee', 'Little Bull Falls,Mosinee,Mosini,masyny  wyskansyn,mwsyny,Мосини,ماسینی، ویسکانسین,موسيني', 44.7930200, -89.7031800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143532, 'Mount Horeb', 'Mount Horeb', 'Horeb''s Corners,Mount Horeb,Staangi', 43.0086100, -89.7384600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143533, 'Mount Morris', 'Mount Morris', '', 44.1144200, -89.1906700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143534, 'Mukwonago', 'Mukwonago', 'Makvonago,Mequanigo,Mukwonago,mwkwnaghw,Маквонаго,موكوناغو', 42.8666800, -88.3334300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143535, 'Muscoda', 'Muscoda', '', 43.1849900, -90.4431800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143536, 'Muskego', 'Muskego', 'Maskigo,maskygw  wyskansyn,mwskyghw,mwskygw  wskwnsn,Маскиго,ماسکیگو، ویسکانسین,موسكيغو,موسکیگو، وسکونسن', 42.9058500, -88.1389800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143537, 'Nashotah', 'Nashotah', 'Nashotah,Nashotah Station', 43.0977900, -88.4023200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143538, 'Nashville', 'Nashville', 'Nashvill,Нашвилл', 45.5227400, -89.0248400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143539, 'Neenah', 'Neenah', 'Neenah,Nina,Winnebago Rapids,nyna  wyskansyn,nynah,Нина,نيناه,نینا، ویسکانسین,نیناہ، وسکونسن', 44.1858200, -88.4626100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143540, 'Neillsville', 'Neillsville', 'Neillsville,Nilsvil,O''Neills Mills,nylsfyl,nylswyl  wyskansyn,Нилсвил,نيلسفيل,نیلسویل، ویسکانسین', 44.5599600, -90.5962500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143541, 'Nekoosa', 'Nekoosa', 'Bungehjewin,Nekoosa,Point Basse,Point Boss,Pointe Bas,Whitney''s Rapids', 44.3124600, -89.9042900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143542, 'New Berlin', 'New Berlin', 'Mentor,Naujasis Berlynas,New Berlin,Nju Berlin,brlyn jdyd  wyskansyn,nyw brln  wskwnsn,nyw brlyn,Њу Берлин,برلین جدید، ویسکانسین,نيو برلين,نیو برلن، وسکونسن', 42.9764000, -88.1084200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143543, 'New Glarus', 'New Glarus', 'New Glaris,New Glarus,Nju Glarus,Nova Glarona,nyw ghlarws,Њу Гларус,نيو غلاروس', 42.8144500, -89.6351200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143544, 'New Holstein', 'New Holstein', 'Nju Kholstajn,hwlstyn jdyd  wyskansyn,nyw hwlstayn,Њу Холстајн,نيو هولستاين,هولستین جدید، ویسکانسین,ნიუ-ჰოლსტაინი', 43.9499900, -88.0842600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143545, 'New Lisbon', 'New Lisbon', '', 43.8791400, -90.1654100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143546, 'New London', 'New London', 'N''ju-London,Nju London,lndn jdyd  wyskansyn,niu-londoni,nyw lndn,nyw lndn  wskwnsn,Њу Лондон,Нью-Лондон,لندن جدید، ویسکانسین,نيو لندن,نیو لندن، وسکونسن,ნიუ-ლონდონი', 44.3927600, -88.7398300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143547, 'New Richmond', 'New Richmond', 'Fosters Crossing,New Richmond,Nju Richmond,RNH,nyw rytshmwnd,nyw ryzmwnd,rychmwnd jdyd  wyskansyn,Њу Ричмонд,ניו ריצמונד,ریچموند جدید، ویسکانسین,نيو ريتشموند', 45.1230200, -92.5365900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143548, 'Newburg', 'Newburg', 'Newburg,Newburgh', 43.4316700, -88.0464800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143549, 'Niagara', 'Niagara', '', 45.7713500, -87.9948500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143550, 'North Fond du Lac', 'North Fond du Lac', '', 43.8113800, -88.4834400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143551, 'North Hudson', 'North Hudson', '', 44.9930200, -92.7568700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143552, 'North La Crosse', 'North La Crosse', '', 43.8463500, -91.2481900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143553, 'North Prairie', 'North Prairie', '', 42.9344600, -88.4053700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143554, 'Oak Creek', 'Oak Creek', 'Ouk Krik,awk gryk  wyskansyn,awk kryk,awk kryk  wskwnsn,xiang shu xi,Оук Крик,أوك كريك,اوک کریک، وسکونسن,اوک گریک، ویسکانسین,ოუკ-კრიკი,橡樹溪', 42.8858500, -87.8631400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143555, 'Oakfield', 'Oakfield', 'Avoca,Oakfield', 43.6861000, -88.5465000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143556, 'Oconomowoc', 'Oconomowoc', 'akwnwmwwak  wskwnsn,awkanmawak  wyskansyn,awkwnwmwk,أوكونوموك,اوکانماواک، ویسکانسین,اکونوموواک، وسکونسن', 43.1116700, -88.4992700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143557, 'Oconto', 'Oconto', 'Okonto,awkantw  wyskansyn,awkwntw,Оконто,أوكونتو,اوکانتو، ویسکانسین,ოკონტო', 44.8872100, -87.8645500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143558, 'Oconto Falls', 'Oconto Falls', '', 44.8738800, -88.1428800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143559, 'Okauchee Lake', 'Okauchee Lake', '', 43.1233400, -88.4406500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143560, 'Omro', 'Omro', 'Beckwith Town,Omro,Smalleys Landing,awmrw,awmrw  wyskansyn,Омро,أومرو,اومرو، ویسکانسین', 44.0394300, -88.7442800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143561, 'Onalaska', 'Onalaska', '', 43.8844100, -91.2351400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143562, 'Oneida', 'Oneida', '', 44.4986000, -88.1828800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143563, 'Oostburg', 'Oostburg', 'Oostburg,Oostburgh Station', 43.6227700, -87.7945300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143564, 'Oregon', 'Oregon', 'Oregon,Oregono,Rome Corners,awryghwn,Орегон,أوريغون', 42.9261100, -89.3845600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143565, 'Orfordville', 'Orfordville', 'Orford,Orfordville', 42.6275100, -89.2531700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143566, 'Osceola', 'Osceola', 'Leroy,Osceola,Osceola Mills,Osiola,awsywla,Осиола,أوسيولا', 45.3205200, -92.7049300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143567, 'Oshkosh', 'Oshkosh', 'Algoma,Athens,Brooklyn,OSH,Oshkosh,Oskosh,Sawdust City,ashkwsh  wyskansyn,ausakosa,awshkwsh,awshkwsh  wskwnsn,oshukoshu,Ошкош,אושקוש,أوشكوش,اشکوش، ویسکانسین,اوشکوش، وسکونسن,औशकोश,ოშკოში,オシュコシュ', 44.0247100, -88.5426100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143568, 'Osseo', 'Osseo', '', 44.5721800, -91.2273800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143569, 'Paddock Lake', 'Paddock Lake', '', 42.5775200, -88.1050900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143570, 'Palmyra', 'Palmyra', '', 42.8777900, -88.5862100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143571, 'Pardeeville', 'Pardeeville', '', 43.5377600, -89.3001200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143572, 'Park Falls', 'Park Falls', 'Muskallonge Falls,PKF,Park Falls,Park Fols,Parkfalls,bark fwlz,park falz  wyskansyn,Парк Фолс,بارك فولز,پارک فالز، ویسکانسین', 45.9344000, -90.4415500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143573, 'Pell Lake', 'Pell Lake', '', 42.5380700, -88.3509300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143574, 'Peshtigo', 'Peshtigo', 'Peshtigo,byshtyghw,pshtygw  wyskansyn,Пештиго,بيشتيغو,پشتیگو، ویسکانسین', 45.0544300, -87.7492700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143575, 'Pewaukee', 'Pewaukee', 'City of Pewaukee,Pewaukee,Pewaukeewinick,Village of Pewaukee', 43.0805700, -88.2612000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143576, 'Phillips', 'Phillips', '', 45.6966300, -90.4004300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143577, 'Pittsfield', 'Pittsfield', '', 44.5994400, -88.2451000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143578, 'Platteville', 'Platteville', 'Lebanon,Platte River,Platte River Diggings,Platteville,Plattville,Platvil,blatfyl,pltywyl  wyskansyn,Платвил,بلاتفيل,پلتیویل، ویسکانسین', 42.7341600, -90.4784600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143579, 'Pleasant Prairie', 'Pleasant Prairie', 'Plezant Preri,bylstant brayry,Плезант Прери,بيلستانت برايري,پلیزینٹ پریری، وسکونسن', 42.5530800, -87.9334100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143580, 'Plover', 'Plover', 'Mush-ko-da-ny,Plover', 44.4563600, -89.5440100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143581, 'Plymouth', 'Plymouth', 'Plimut,Plymouth,Quit-Qui-Oc,blymwth,playmawt  wskwnsn,plymwth  wyskansyn,Плимут,بليموث,پلایماؤت، وسکونسن,پلیموث، ویسکانسین', 43.7486100, -87.9770400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143582, 'Port Edwards', 'Port Edwards', 'Frenchtown,Port Edwards', 44.3508000, -89.8654000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143583, 'Port Washington', 'Port Washington', 'Port Voshington,Port Washington,Sauk Harbor,Sauk Washington,The Little City of Seven Hills,Washington,Wisconsin City,bwrt washntn,pwrt washyngtn  wyskansyn,Порт Вошингтон,بورت واشنطن,پورت واشینگتن، ویسکانسین', 43.3872200, -87.8756400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143584, 'Portage', 'Portage', 'Portage,Portage City,Portidz,bwrtagh,pwrtyj  wyskansyn,Портиџ,بورتاغ,پورتیج، ویسکانسین,پورٹیج، وسکونسن', 43.5391500, -89.4626200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143585, 'Portland', 'Portland', 'Portlend,Портленд', 43.7688600, -90.8581900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143586, 'Potter Lake', 'Potter Lake', '', 42.8216800, -88.3489800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143587, 'Powers Lake', 'Powers Lake', '', 42.5536300, -88.2945400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143588, 'Poynette', 'Poynette', 'Pauquette,Poynette', 43.3902600, -89.4029000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143589, 'Prairie du Chien', 'Prairie du Chien', 'Dogs Prairie,La Prairie,La Prairie des Chiens,Prairie du Chien,Tipisagi,brayry dw shyn,pryry dw chyyn  wyskansyn,برايري دو شين,پریری دو چیئن، ویسکانسین', 43.0516500, -91.1412400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143590, 'Prairie du Sac', 'Prairie du Sac', 'Prairie du Sac,Sauk Prairie', 43.2869300, -89.7240100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143591, 'Prescott', 'Prescott', 'Elizabeth,Lake Mouth,Mouth of the Saint Croix,Prescott,Preskot,bryskwt,prskat  wyskansyn,Прескот,بريسكوت,پرسکات، ویسکانسین', 44.7488600, -92.8021500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143592, 'Princeton', 'Princeton', 'Princeton,Prinston,Treats Landing,Принстон', 43.8508100, -89.1217800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143593, 'Pulaski', 'Pulaski', '', 44.6722200, -88.2426000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143594, 'Racine', 'Racine', 'Kipikawi,Port Gilbert,RAC,Racine,Rasijn,Rasin,Rasinas,la xin,leosin,rashin,rasini,rasyn,rasyn  wskwnsn,rysyn  wyskansyn,Расийн,Расин,Расін,ראסין,راسين,راسین، وسکونسن,ریسین، ویسکانسین,რასინი,ラシーン,拉辛,러신', 42.7261300, -87.7828500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143595, 'Randolph', 'Randolph', 'Conversville,LeRoy,Randol''f,Randolph,Westford,Рандольф', 43.5391500, -89.0067800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143596, 'Random Lake', 'Random Lake', 'Greenleaf,Random Lake', 43.5522200, -87.9617600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143597, 'Redgranite', 'Redgranite', '', 44.0419200, -89.0984500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143598, 'Reedsburg', 'Reedsburg', 'Reedsburg,Reedsburgh,Ridsburg,rydsbwrgh,rydzbrg  wyskansyn,Ридсбург,ريدسبورغ,ریدزبرگ، ویسکانسین', 43.5324800, -90.0026300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143599, 'Reedsville', 'Reedsville', 'Mud Creek,Reedsville', 44.1536000, -87.9567600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143600, 'Rhinelander', 'Rhinelander', 'City of the Hodag,Pelican Rapids,RHI,Rajnlander,Rhinelander,Zhede-zhiibiing,raylndr  wyskansyn,rynlandr,Рајнландер,رایلندر، ویسکانسین,رينلاندر', 45.6366200, -89.4120800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143601, 'Rib Mountain', 'Rib Mountain', '', 44.9127500, -89.6754000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143602, 'Rice Lake', 'Rice Lake', 'RIE,Rajs Lejk,rays lyk  wyskansyn,rayz lyk,Рајс Лејк,رايز ليك,رایس لیک، ویسکانسین', 45.5060700, -91.7382300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143603, 'Richfield', 'Richfield', '', 43.2561200, -88.1939800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143604, 'Richland Center', 'Richland Center', 'Richland Center,Richland Centre,Richland Senter,li qi lan zhong xin,rychlnd sntr  wyskansyn,rytshland sntr,Ричланд Сентер,ريتشلاند سنتر,رچلینڈ سینٹر، وسکونسن,ریچلند سنتر، ویسکانسین,里奇蘭中心', 43.3347100, -90.3867900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143605, 'Richmond', 'Richmond', 'Richmond,Ричмонд', 42.7147300, -88.7492700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143606, 'Ripon', 'Ripon', 'Ceresco,Morena,Ripon,rybwn,rypwn  wyskansyn,Рипон,ريبون,ریپون، ویسکانسین', 43.8422000, -88.8359400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143607, 'Rio', 'Rio', '', 43.4477600, -89.2398400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143608, 'River Falls', 'River Falls', 'Greenwood,Kinnickinnic,River Falls,River Fols,ryfr fwlz,rywr falz  wskwnsn,rywr falz  wyskansyn,Ривер Фолс,ريفر فولز,ریور فالز، وسکونسن,ریور فالز، ویسکانسین', 44.8613600, -92.6238100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143609, 'River Hills', 'River Hills', '', 43.1741800, -87.9242500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143610, 'Roberts', 'Roberts', 'Roberts,Roberts Station,Warren', 44.9838600, -92.5560300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143611, 'Rochester', 'Rochester', 'Rochester,Waukeeshah,Рочестер', 42.7414100, -88.2242600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143612, 'Rosendale', 'Rosendale', '', 43.8077600, -88.6748300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143613, 'Rothschild', 'Rothschild', '', 44.8871900, -89.6201200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143614, 'Roxbury', 'Roxbury', 'Rocksbury,Roxbury', 43.2494300, -89.6754000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143615, 'Rutland', 'Rutland', 'Ratlend,Rutland,Rutland Center,Ратленд', 42.8788900, -89.3501200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143616, 'Saint Croix Falls', 'Saint Croix Falls', '', 45.4099600, -92.6396500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143617, 'Saint Francis', 'Saint Francis', '', 42.9675200, -87.8775800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143618, 'Saint Peter', 'Saint Peter', '', 43.8363800, -88.3414900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143619, 'Salem', 'Salem', 'Brooklyn,Salem,Sejlem,Сейлем', 42.5547400, -88.1109200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143620, 'Sauk City', 'Sauk City', 'Harszthy,Sauk,Sauk City,Sok Siti,Westfield,sak syty,Сок Сити,ساك سيتي', 43.2708200, -89.7220700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143621, 'Saukville', 'Saukville', 'Mechanicsville,Saint Finbars,Saukville,Schmit''s Mill,Voelker''s Mills', 43.3816700, -87.9406500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143622, 'Schofield', 'Schofield', 'Schofield,Schofield Mills', 44.9096900, -89.6045700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143623, 'Seymour', 'Seymour', '', 44.8266300, -91.4312700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143624, 'Seymour', 'Seymour', 'seimuri,symwr,symwr  wyskansyn,سيمور,سیمور، ویسکانسین,სეიმური', 44.5149900, -88.3303800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143625, 'Sharon', 'Sharon', 'Sharon,Шарон', 42.5025200, -88.7289900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143626, 'Shawano', 'Shawano', 'Shono,shawanw,shawanw  wyskansyn,Шоно,شاوانو,شاوانو، ویسکانسین', 44.7822100, -88.6089900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143627, 'Sheboygan', 'Sheboygan', 'Chair City,SBM,Seboiganas,Shebojgan,Sheboyegan,Sheboygan,shiboigan,shybwygan  wskwnsn,shybwygan  wyskansyn,shybwyjan,Šeboiganas,Шебойган,Шебојган,شيبويجان,شیبویگان، وسکونسن,شیبویگان، ویسکانسین,シボイガン', 43.7508300, -87.7145300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143628, 'Sheboygan Falls', 'Sheboygan Falls', 'Rochester,Sheboygan Falls', 43.7319700, -87.8221300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143629, 'Shell Lake', 'Shell Lake', '', 45.7393900, -91.9254500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143630, 'Sherwood', 'Sherwood', 'Nicolais Corners,Sherwood', 44.1736000, -88.2598300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143631, 'Shorewood', 'Shorewood', 'Cementville,East Milwaukee,Mechanicsville,Shorewood,Shorvud,shorvudi,shwrwwd,shwrwwd  wyskansyn,Шорвуд,شوروود,شوروود، ویسکانسین,შორვუდი', 43.0891800, -87.8875800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143632, 'Shorewood Hills', 'Shorewood Hills', 'Mendota Heights,Shorewood Hills', 43.0775000, -89.4456800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143633, 'Shullsburg', 'Shullsburg', '', 42.5733400, -90.2309600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143634, 'Silver Lake', 'Silver Lake', 'Silver Lake,Silverlake', 42.5461300, -88.1656400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143635, 'Silver Lake', 'Silver Lake', '', 44.0552600, -89.2262300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143636, 'Siren', 'Siren', 'Siren,Syren', 45.7857800, -92.3810300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143637, 'Slinger', 'Slinger', 'Scheisinger,Schleighsingerville,Schleisinger,Schleisingerville,Slinger', 43.3336100, -88.2862100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143638, 'Somers', 'Somers', 'Pike,Somers', 42.6403000, -87.9103600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143639, 'Somerset', 'Somerset', 'Somerset,Сомерсет', 45.1244100, -92.6735400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143640, 'South Milwaukee', 'South Milwaukee', 'Oak Creek,South Milwaukee', 42.9105700, -87.8606400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143641, 'Sparta', 'Sparta', 'CMY,Sparta,asparta  wyskansyn,sbarta,Спарта,اسپارتا، ویسکانسین,سبارتا', 43.9441300, -90.8129100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143642, 'Spencer', 'Spencer', '', 44.7577400, -90.2968000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143643, 'Spooner', 'Spooner', 'Spuner,aspwnr  wyskansyn,sbwnr,Спунер,اسپونر، ویسکانسین,سبونر', 45.8224500, -91.8893400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143644, 'Spring Green', 'Spring Green', 'Spring Green,Spring Grin,Springgreen,chun lu cun,sbryngh ghryn,Спринг Грин,سبرينغ غرين,春綠村', 43.1752700, -90.0679000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143645, 'Spring Valley', 'Spring Valley', 'Spring Valley,Spring-Vehlli,Springvalley,Спринг-Вэлли', 44.8452400, -92.2388000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143646, 'Stanley', 'Stanley', '', 44.9599700, -90.9370800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143647, 'Stevens Point', 'Stevens Point', 'First Island,Kah-kag-e-winch-e-min-it-e-gong,STE,Stephens Point,Steven''s Point,Stevens Point,Stivens Pojnt,astywn pwynt  wyskansyn,seutibeunseupointeu,Стивенс Појнт,استیون پوینت، ویسکانسین,سٹیونس پوائنٹ، وسکونسن,스티븐스포인트', 44.5235800, -89.5745600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143648, 'Stoughton', 'Stoughton', 'Stouton,astwtwn  wyskansyn,stwtwn,stwwtwn,Стоутон,סטווטון,استوتون، ویسکانسین,ستوتون', 42.9169500, -89.2178900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143649, 'Stratford', 'Stratford', 'Stratford,Стратфорд', 44.8010800, -90.0793000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143650, 'Strum', 'Strum', 'Strum,Tilden', 44.5496900, -91.3926600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143651, 'Sturgeon Bay', 'Sturgeon Bay', 'Graham,Ottumba,SUE,Sterdzen Bej,Sturgeon Bay,Tehema,astwrjn by  wyskansyn,stwrghwn bay,Стерџен Беј,استورجن بی، ویسکانسین,ستورغون باي', 44.8341600, -87.3770400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143652, 'Sturtevant', 'Sturtevant', 'Corliss,Johnson,Sturtevant,Western Union Junction', 42.6980700, -87.8945200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143653, 'Suamico', 'Suamico', 'Big Suamico,Suamico', 44.6319400, -88.0392700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143654, 'Sun Prairie', 'Sun Prairie', 'San Preri,san pryry  wyskansyn,sana preri,sn brayry,sn pryry  wskwnsn,Сан Прери,سان پریری، ویسکانسین,سن پریری، وسکونسن,صن برايري,सन प्रेरी', 43.1836000, -89.2137300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143655, 'Superior', 'Superior', 'Gete-oodenaang,S''jupirior,SUW,Superior,Supirior,siupʼiriori,spyryyr  wskwnsn,su bi li er,superioru,swbrywr,swprywr  wyskansyn,Супириор,Сьюпириор,سوبريور,سوپریور، ویسکانسین,سپیریئر، وسکونسن,სიუპირიორი,スペリオル,苏必利尔', 46.7207700, -92.1040800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143656, 'Sussex', 'Sussex', '', 43.1339000, -88.2220400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143657, 'Tainter Lake', 'Tainter Lake', '', 44.9891300, -91.8476700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143658, 'Theresa', 'Theresa', '', 43.5172200, -88.4512100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143659, 'Thiensville', 'Thiensville', '', 43.2375100, -87.9787000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143660, 'Thorp', 'Thorp', 'North Fork,Thorp', 44.9610800, -90.7998600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143661, 'Tichigan', 'Tichigan', 'Tichigan,Tischigan,Tish-shar-gan,Tishagan,Tishigan', 42.8289000, -88.1975900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143662, 'Tomah', 'Tomah', 'tamh  wyskansyn,twma,تامه، ویسکانسین,توما', 43.9785800, -90.5040200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143663, 'Tomahawk', 'Tomahawk', 'Tomakhavk,tamhawk  wyskansyn,twmahwk,Томахавк,تامهاوک، ویسکانسین,توماهوك', 45.4710800, -89.7298600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143664, 'Trempealeau', 'Trempealeau', 'Montoville,Mountainville,Reeds Landing,Reeds Town,Trempealeau,Trempelo,trymbylyw,Тремпело,تريمبيليو', 44.0055200, -91.4420900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143665, 'Turtle Lake', 'Turtle Lake', 'Skowhagen,Turtle Lake', 45.3944000, -92.1424100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143666, 'Twin Lakes', 'Twin Lakes', 'Twin Lakes,Twinlakes', 42.5311300, -88.2481500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143667, 'Two Rivers', 'Two Rivers', 'Nashotah,Neshota,Tu Rivers,Two Rivers,tu rivels,tw ryfrz,tw rywrz  wyskansyn,Ту Риверс,تو ريفرز,تو ریورز، ویسکانسین,ٹو ریورز، وسکونسن,ടൂ റിവേഴ്സ്', 44.1538800, -87.5692500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143668, 'Union Grove', 'Union Grove', 'Union Grove,Uniongrove', 42.6880700, -88.0514700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143669, 'Verona', 'Verona', 'The Corners,Verona,Verona Corners', 42.9908300, -89.5331800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143670, 'Viroqua', 'Viroqua', 'fyrwkwa,wayrwka  wyskansyn,فيروكوا,وایروکا، ویسکانسین', 43.5569200, -90.8887400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143671, 'Wales', 'Wales', '', 43.0044500, -88.3767600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143672, 'Walworth', 'Walworth', 'Douglass Corners,Walworth', 42.5311300, -88.5995500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143673, 'Washburn', 'Washburn', 'Voshbern,vashbarni,wa shi ben shi,washbrn,washbrn  wyskansyn,Вошберн,واشبرن,واشبرن، ویسکانسین,ვაშბარნი,瓦士本市', 46.6732700, -90.8949100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143674, 'Waterloo', 'Waterloo', 'Vaterlo,Ватерло', 43.1838800, -88.9884400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143675, 'Waterford', 'Waterford', 'Uoterford,Уотерфорд', 42.7630700, -88.2142600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143676, 'Watertown', 'Watertown', 'Johnsons Rapids,Votertaun,Watertown,watrtwn  wyskansyn,woteotaun,wwtrtawn,Вотертаун,واترتون، ویسکانسین,واٹر ٹاؤن، وسکونسن,ووترتاون,워터타운', 43.1947200, -88.7289900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143677, 'Waukesha', 'Waukesha', 'Prairieville,UES,Uokesho,Uokisha,Vokesha,Vokisha,Waukesha,u~okisho,wakysha  wyskansyn,wawkysha  wskwnsn,wkysha,Вокеша,Вокиша,Уокешо,Уокиша,واوکیشا، وسکونسن,واکیشا، ویسکانسین,وكيشا,უოკეშო,ウォキショー', 43.0116800, -88.2314800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143678, 'Waunakee', 'Waunakee', '', 43.1919400, -89.4556700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143679, 'Waupaca', 'Waupaca', 'Vermonter''s Camp,Vopaka,Waupaca,Waupaca Falls,wapaka  wyskansyn,wawbaka,Вопака,واوباكا,واپاکا، ویسکانسین', 44.3580300, -89.0859500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143680, 'Waupun', 'Waupun', 'Madrid,Waubun,Waupun,wapwn  wyskansyn,wawbwn,واوبون,واپون، ویسکانسین', 43.6333200, -88.7295500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143681, 'Wausau', 'Wausau', 'AUW,Big Bull Falls,Pah-je-tak-a-ke-ning-a-ning,Voso,Wassa,Wausau,wasa  wskwnsn,wasa  wyskansyn,wawsw,Восо,واسا، وسکونسن,واسا، ویسکانسین,واوسو', 44.9591400, -89.6301200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143682, 'Wautoma', 'Wautoma', '', 44.0747000, -89.2879000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143683, 'Wauwatosa', 'Wauwatosa', 'Harts Mills,Vovatosa,Wauwatosa,wawatwsa  wyskansyn,wawatwza,Воватоса,واواتوزا,واواتوسا، ویسکانسین,واواٹوسا، وسکونسن,უავატოსა', 43.0494600, -88.0075900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143684, 'West Baraboo', 'West Baraboo', '', 43.4744300, -89.7704000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143685, 'West Allis', 'West Allis', 'Vest Alis,alys ghrby  wyskansyn,wyst alys,Вест Алис,آلیس غربی، ویسکانسین,ويست أليس,ویسٹ الیس، وسکونسن,უესტ-ალისი', 43.0166800, -88.0070300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143686, 'West Bend', 'West Bend', 'ETB,Vest Bend,West Bend,Westbend,bnd ghrby  wyskansyn,uesutobendo,wyst bynd,xi ben de,Вест Бенд,بند غربی، ویسکانسین,ويست بيند,ویسٹ بینڈ، وسکونسن,ウエストベンド,西本德', 43.4252800, -88.1834300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143687, 'West Milwaukee', 'West Milwaukee', '', 43.0125100, -87.9725900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143688, 'West Salem', 'West Salem', 'Salem,Vest Sejlem,West Salem,wst salm,Вест Сејлем,وست سالم', 43.8991300, -91.0812500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143689, 'Westby', 'Westby', '', 43.6569200, -90.8543000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143690, 'Westfield', 'Westfield', '', 43.8835900, -89.4934600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143691, 'Weston', 'Weston', '', 44.8908000, -89.5476200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143692, 'Weyauwega', 'Weyauwega', 'Wayauwega,Weyauwega', 44.3213700, -88.9337200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143693, 'Whitefish Bay', 'Whitefish Bay', 'Vajtfish Bej,waytfysh,Вајтфиш Беј,وايتفيش,უაიტფიშ-ბეი', 43.1133400, -87.9000900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143694, 'Whitehall', 'Whitehall', '', 44.3674600, -91.3165500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143695, 'Whitewater', 'Whitewater', 'Vajtvoter,waytwatr  wyskansyn,waytwwtr,Вајтвотер,وائٹ واٹر، وسکونسن,وايتووتر,وایتواتر، ویسکانسین', 42.8336200, -88.7323300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143696, 'Whiting', 'Whiting', 'McDill,Whiting', 44.4935800, -89.5587300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143697, 'Williams Bay', 'Williams Bay', '', 42.5780700, -88.5409300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143698, 'Wind Lake', 'Wind Lake', '', 42.8294600, -88.1587000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143699, 'Wind Point', 'Wind Point', '', 42.7844600, -87.7661900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143700, 'Windsor', 'Windsor', 'Vindzor,Виндзор', 43.2183300, -89.3415100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143701, 'Winneconne', 'Winneconne', 'Winneconne,Winnekona', 44.1108200, -88.7126100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143702, 'Wisconsin Dells', 'Wisconsin Dells', 'Kilbourn,Kilbourn City,Uiskonsin Dels,Uiskonsin-Dels,Viskonsin Dels,Viskonsin Delsas,Wisconsin Dells,wyskansyn dlz  wyskansyn,wyskwnsn dylz,Висконсин Делс,Уисконсин Делс,Уисконсин-Делс,ويسكونسن ديلز,ویسکانسین دلز، ویسکانسین', 43.6274800, -89.7709600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143703, 'Wisconsin Rapids', 'Wisconsin Rapids', 'Ah-dah-wa-gam,Grand Rapids,Grand Rapids Mills,ISW,Viskonsin Rapids,Wisconsin Rapids,wyskansyn rpydz  wyskansyn,wyskwnsn rabydz,Висконсин Рапидс,وسکونسن ریپڈس، وسکونسن,ويسكونسن رابيدز,ویسکانسین رپیدز، ویسکانسین', 44.3835800, -89.8173500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143704, 'Wittenberg', 'Wittenberg', 'Wittenberg,Wittenburg', 44.8272000, -89.1695600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143705, 'Woodville', 'Woodville', 'Kellys Switch,Woodville', 44.9530200, -92.2913000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143706, 'Wrightstown', 'Wrightstown', 'Wrights Ferry,Wrightstown', 44.3258200, -88.1628800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143707, 'Benwood', 'Benwood', 'Bens Woods,Benwood,Benwood Junction', 40.0181300, -80.7342500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143708, 'Bethany', 'Bethany', 'Betani,btny  wyrjynyay ghrby,bythany,Бетани,بتنی، ویرجینیای غربی,بيثاني,بیتھانی، ورجینیا', 40.2056300, -80.5567400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143709, 'Bethlehem', 'Bethlehem', 'Vifleem,Вифлеем', 40.0439600, -80.6906400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143710, 'Chester', 'Chester', 'Chester,Mercer,Честер', 40.6131200, -80.5628500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143711, 'Follansbee', 'Follansbee', 'Cross Creek,Follansbee', 40.3275700, -80.5959100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143712, 'Hooverson Heights', 'Hooverson Heights', '', 40.3247900, -80.5775700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143713, 'New Cumberland', 'New Cumberland', 'Brick Bend,Brick Town,Cuppy Town,Cuppytown,N''ju-Kamberlend,New Cumberland,Nju Kamberland,Vernon,nyw kambrlnd  wyrjynyay ghrby,nyw kmbrland,Њу Камберланд,Нью-Камберленд,نيو كمبرلاند,نیو کامبرلند، ویرجینیای غربی', 40.4967300, -80.6067400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143714, 'Newell', 'Newell', '', 40.6184000, -80.6042400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143715, 'Weirton', 'Weirton', 'Uirton,Virtn,Virton,u~iaton,wyrtwn,wyrtwn  wyrjynyay ghrby,Виртн,Віртон,Уиртон,ويرتون,ویئرٹن، مغربی ورجینیا,ویرتون، ویرجینیای غربی,ウィアトン', 40.4189600, -80.5895200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143716, 'Weirton Heights', 'Weirton Heights', '', 40.4084000, -80.5392400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143717, 'Wellsburg', 'Wellsburg', 'Buffaloe Town,Charles Town,Charlestown,Uehlsberg,Velsburg,Wellsburg,Wellsburgh,wlsbwrg  wyrjynyay ghrby,wylsbwrgh,Велсбург,Уэлсберг,ولسبورگ، ویرجینیای غربی,ويلسبورغ', 40.2720100, -80.6095200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143718, 'West Liberty', 'West Liberty', 'Blacks Cabin,Short Creek,Vest Liberti,West Liberty,wst lybrty  wyrjynyay ghrby,wyst lybrty,Вест Либерти,وست لیبرتی، ویرجینیای غربی,ويست ليبرتي', 40.1697900, -80.5936900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143719, 'Wheeling', 'Wheeling', 'Fort Fincastle,Fort Henry,HLG,Nail City,Uijling,Uiling,Viling,Weeling,Whealing,Wheelin,Wheeling,Zanesburg,hoiringu,hui ling,hwilling,wylyng  mghrby wrjynya,wylyng  wyrjynyay ghrby,wylyngh,Вилинг,Вілінг,Уийлинг,Уилинг,ويلينغ,ویلینگ، مغربی ورجینیا,ویلینگ، ویرجینیای غربی,ホイーリング,惠灵,휠링', 40.0639600, -80.7209100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143720, 'Baltic', 'Baltic', '', 41.6170400, -72.0845200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143721, 'Newtown', 'Newtown', 'N''jutaun,Njutaun,n''yuta''una,niu dui,nyutaun,nywtawn,nywtawn  kntykt,Њутаун,Ньютаун,ניוטאון,نيوتاون,نیو ٹاؤن، کنیکٹیکٹ,نیوتاون، کنتیکت,न्युटाउन,न्यूटाउन,ന്യൂടൗൺ,纽敦,뉴타운', 41.4139800, -73.3034500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143722, 'Three Rivers', 'Three Rivers', '', 42.1812000, -72.3606400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143723, 'South Duxbury', 'South Duxbury', 'Halls Corner,South Duxbury', 42.0231600, -70.6828100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143724, 'Groton', 'Groton', 'Groton,Groton Centre,ge luo dun,ghrwtwn,grwtwn,Гротон,Ґротон,غروتون,گروتون,格罗顿', 42.6112000, -71.5745100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143725, 'Sheffield', 'Sheffield', 'Houssatonneck,Houssatonnock,Houssatonnuc,Sheffield,Shehffild,Skatecook,shfyld  masachwst,Шэффилд,شفیلد، ماساچوست', 42.1103700, -73.3551100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143726, 'Carmel', 'Carmel', 'Carmel,Carmel Village,Karmel'',Кармель', 44.7975700, -69.0511500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143727, 'Phillips', 'Phillips', '', 44.8231100, -70.3395100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143728, 'West Kennebunk', 'West Kennebunk', '', 43.4087000, -70.5814400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143729, 'Nowthen', 'Nowthen', '', 45.3280200, -93.4702300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143730, 'Castleton', 'Castleton', 'Castleton,Kaslton,Pillar Town,kasltwn,Каслтон,كاسلتون', 43.6106200, -73.1798300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143731, 'Kohler', 'Kohler', 'Kohler,Kohler Village,Koler,Riverside,kolleo,kwhlr,Колер,كوهلر,콜러', 43.7391600, -87.7817500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143732, 'Ansonia', 'Ansonia', 'Ansonia,Ansonija,an suo ni ya,anasoniya,ansonia,answnya,answnya  kntykt,ensoniya,Ансониа,Ансонија,Ансоніа,آنسونیا، کنتیکت,أنسونيا,انسونیا، کنیکٹیکٹ,अनसोनिया,एन्सोनिया,アンソニア,安索尼亚', 41.3462100, -73.0790000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143733, 'Bethel', 'Bethel', 'Behzel,Besehl,Betel,bei sai er,bethela,Бесэл,Бетел,Бэзел,بیتھل، کنیکٹیکٹ,बेथेल,贝塞尔', 41.3712100, -73.4140100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143734, 'Blue Hills', 'Blue Hills', '', 41.8128800, -72.6975900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143735, 'Bridgeport', 'Bridgeport', 'BDR,Bricport,Bridgeport,Bridzhport,Bridzport,Bridzporta,Bridzportas,Bridžporta,Bridžportas,Gorad Brydzhpart,Newfield,Park City,Stratfield,beulijipoteu,brijaporta,brydgpwrt,brydjbwrt,bryjpwrt  kntykt,bu li qi bo te,burijjipoto,Бриджпорт,Бриџпорт,Бріджпорт,Горад Брыджпарт,ברידגפורט,برج پورٹ، کنیکٹیکٹ,بريدجبورت,بریجپورت، کنتیکت,ब्रिजपोर्ट,ブリッジポート,布里奇波特,브리지포트', 41.1670400, -73.2048300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143736, 'Bristol', 'Bristol', 'Bristol,Bristol'',Bristul,Mixville Brook,beuliseuteul,bristala,brystwl,brystwl  kntykt,bu li si tuo er,burisutoru,Бристол,Бристоль,Бристъл,برسٹل، کنیکٹی کٹ,بريستول,بریستول، کنتیکت,ब्रिस्टल,ブリストル,布里斯托尔,브리스틀', 41.6717600, -72.9492700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143737, 'Broad Brook', 'Broad Brook', 'Braud Brook,Broad Brook,Broadbrook', 41.9123200, -72.5450900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143738, 'Branford', 'Branford', 'Branford,Branford Center,Brehnford,Totoket,Бранфорд,Брэнфорд,برینفورڈ، کنیکٹیکٹ', 41.2795400, -72.8151000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143739, 'Byram', 'Byram', 'Byram,East Port Chester,East Portchester,New Lebanon', 41.0042600, -73.6537400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143740, 'Canaan', 'Canaan', 'Canaan,Canaan Depot,Canaan Village,Kanaan,Kejnan,kanan,sen''yana,Канаан,Кејнан,كانان,کنعان، کنیکٹیکٹ,सेन्यान', 42.0273100, -73.3292800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143741, 'Canton Valley', 'Canton Valley', '', 41.8342600, -72.8917700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143742, 'Cheshire', 'Cheshire', 'Cheshair,Cheshir,Cheshir Vilidz,Cheshire,Cheshire Center,Cheshire Village,cesayara bhileja,chesyeo,tshyshayr,Чешаир,Чешир,Чешир Вилиџ,تشيشاير,چیشائر، کنیکٹیکٹ,चेशायर भिलेज,체셔', 41.4989900, -72.9006600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143743, 'Clinton', 'Clinton', 'Clinton,Hammonassett,Killingworth,Klinton,Klintun,Old Killingworth,klintana,klyntwn,Клинтон,Клинтън,كلينتون,کلنٹن، کنیکٹیکٹ,क्लिन्टन', 41.2787100, -72.5275900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143744, 'Colchester', 'Colchester', 'Kolchester,kwltshstr,Колчестер,كولتشستر,کولچیسٹر، کنیکٹیکٹ', 41.5756500, -72.3320300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143745, 'Collinsville', 'Collinsville', 'Cantonville,Collinsville,Kollinsvil'',South Canton,Коллинсвиль', 41.8128800, -72.9201000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143746, 'Holbrook', 'Holbrook', 'Golbruk,HBK,Kholbruk,Tʼiisyaakin,halbrwk,holbruka,huo er bu lu ke,hwlbrwk,Голбрук,Холбрук,هالبروک,هولبروك,होल्ब्रूक,ሆልብሩክ፥ አሪዞና,霍尔布鲁克', 34.9022500, -110.1581800, 'US', '2017-07-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143747, 'Fillmore', 'Fillmore', 'Fillmor,Filmor,fei er mo er,flmwr  kylyfwrnya,fyl mwr  kalyfrnya,fylmwry,philamora,Филмор,Філлмор,فلمور، کیلیفورنیا,فيلموري,فیل مور، کالیفرنیا,फिलमोर,菲尔莫尔', 34.3991600, -118.9181500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143748, 'Cool', 'Cool', 'Cave Valley,Cool', 38.8872200, -121.0147200, 'US', '2017-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143749, 'Bisbee', 'Bisbee', 'BSQ,Bisbi,Bizbi,bi si bi,bijeubi,bisbi,bysby,bysby  aryzwna,Бизби,Бисби,Бісбі,بيسبي,بیسبی، آریزونا,बिस्बी,ቢስቢ፥ አሪዞና,比斯比,비즈비', 31.4481500, -109.9284100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143750, 'Middletown', 'Middletown', 'Middle Station,Middleton,Middletown,Midltaun,midalata''una,midorutaun,Мидлтаун,مڈل ٹاؤن، کیلیفورنیا,मिडलटाउन,ミドルタウン', 38.7524000, -122.6149900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143751, 'Black Canyon City', 'Black Canyon City', 'Black Canyon,Black Canyon City,Canon,Canyon,Goddards', 34.0708700, -112.1507100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143752, 'South Taft', 'South Taft', '', 35.1346900, -119.4562300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143753, 'Vine Hill', 'Vine Hill', '', 38.0085300, -122.0960800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143754, 'Dighton', 'Dighton', 'Dighton,Watson', 38.4819600, -100.4670800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143755, 'Mora', 'Mora', 'De lo Mora,Lo de Mora,Mora,San Antonio lo de Mora,Santa Gertrudis', 35.9742000, -105.3300100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143756, 'Blackwater', 'Blackwater', 'Blackwater,Oo-Kut,Standing Tree,Uhs Kug', 33.0311700, -111.5826300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143757, 'Mona', 'Mona', '', 39.8160700, -111.8554900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143758, 'Buckeye', 'Buckeye', 'BXK,Bakaj,Buckeye,Bukaj,Sydney,ba ke ai,baka''a''i,bakay  aryzwna,bakyy,bkayy  ayryzwna,Бакай,Бакај,Бъкай,باكيي,باکای، آریزونا,بکآئی، ایریزونا,बकआइ,巴克艾', 33.3703200, -112.5837800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143759, 'Bullhead City', 'Bullhead City', 'Bulkhed,Bulkhed Siti,Bullged-Siti,Bullkhed-Siti,IFP,bu er hai de shi,bulaheda siti,bwlhd syty  aryzwna,bwlhyd syts,Буллгед-Сіті,Буллхед-Сити,Булхед,Булхед Сити,بولهد سیتی، آریزونا,بولهيد سيتس,बुलहेड सिटी,布尔海德市', 35.1477800, -114.5683000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143760, 'Bylas', 'Bylas', '', 33.1342800, -110.1200400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143761, 'Cactus Flat', 'Cactus Flat', 'Algodon,Cactus Flat', 32.7584000, -109.7161900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143762, 'Camp Verde', 'Camp Verde', 'Camp Lincoln,Camp Verde,Campverde,Fort Verde,Kamp Verdi,Kemp Verde,Verde,kamb fyrdy,kan pu wei de,kmp wrdy  aryzwna,kyampa bharde,Камп Верди,Кемп Верде,كامب فيردي,کمپ وردی، آریزونا,क्याम्प भर्डे,坎普维德', 34.5636400, -111.8543200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143763, 'Canyon Day', 'Canyon Day', 'Canyon Day,Canyon Day Flat Village', 33.7847700, -110.0264900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143764, 'Carefree', 'Carefree', 'Bandar Carefree,Karefri,Kerfri,Keurfrij,kai er fu li,keraphri,kryfry,kyrfry  aryzwna,Карефрі,Керфри,Кеърфрий,كريفري,کیرفری، آریزونا,केरफ्री,凯尔福利', 33.8222600, -111.9182000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143765, 'Casa Blanca', 'Casa Blanca', 'A-vuc-hoo-mar-lish,Baaki,Bahki,Casa Blanca,Fort Barrett,Pima Villages,Whites Mill', 33.1203300, -111.8881900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143766, 'Casa Grande', 'Casa Grande', 'CGZ,Casa Grande,Casagrande,Kasa Grand,Kasa Grande,Kasa-Grande,ka sa ge lan de,kaesageulaendi,kasa gryanda,kaza ghrandy,kaza grandh,Каса Гранд,Каса Гранде,Каса-Гранде,كازا غراندي,کازا گرانده,कासा ग्र्यान्ड,卡萨格兰德,캐사그랜디', 32.8795000, -111.7573500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143767, 'Casas Adobes', 'Casas Adobes', 'Casas Adobes,Kasas Adobes,Kazas-Edobs,kasas adwbz,kasas edobej,Казас-Едобс,Касас Адобес,كاساس أدوبز,कासास् एडोबेज्', 32.3234100, -110.9951000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143768, 'Catalina', 'Catalina', 'Catalina,Vista Catalina', 32.5055600, -110.9211100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143769, 'Catalina Foothills', 'Catalina Foothills', 'Catalina Foothills', 32.2978500, -110.9187000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143770, 'Cave Creek', 'Cave Creek', '', 33.8333700, -111.9507000, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143771, 'Cave Creek', 'Cave Creek', 'Cave Creek,Cavecreek,Kejv Krijk,Kejv Krik,Kejv-Krik,dong xi,kebha krika,kyf kryk,kyw kryk  aryzwna,Кейв Крийк,Кейв-Крік,Кејв Крик,كيف كريك,کیو کریک، آریزونا,केभ क्रीक,洞溪', 33.8333300, -111.9508300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143772, 'Chandler', 'Chandler', 'Candler,Candleris,Chandler,Chandler Junction,Chandlur,chaendeulleo,chandora,chndlr  aryzwna,cyandlara,qian de lei,tshandlr,Çandler,Čandleris,Чандлер,Чандлър,تشاندلر,چانڈلر، ایریزونا,چندلر، آریزونا,च्यान्ड्लर,チャンドラー,钱德勒,챈들러', 33.3061600, -111.8412500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143773, 'Chinle', 'Chinle', 'Chin Lee,Chinl,Chinle,Chinlee,Chinli,Chʼínílį́,cinle,Чинл,Чинлі,चिन्ले', 36.1544500, -109.5526100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143774, 'Chino Valley', 'Chino Valley', 'Chino Vali,chynw wly  aryzwna,cino bhyali,qi nuo gu,shynw faly,Чино Вали,شينو فالي,چینو ولی، آریزونا,चिनो भ्याली,奇诺谷', 34.7575200, -112.4537800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143775, 'Cibecue', 'Cibecue', 'Cibecue,Cibicu,She-be-ku', 34.0447700, -110.4853900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143776, 'Cienega Springs', 'Cienega Springs', '', 34.1886300, -114.2246700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143777, 'Citrus Park', 'Citrus Park', '', 33.5486500, -112.4443300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143778, 'Clarkdale', 'Clarkdale', 'Klarkdejl,ke la ke dai er,klarkadela,klarkdyl,klarkdyl  aryzwna,Кларкдейл,Кларкдејл,קלארקדייל,كلاركديل,کلارکدیل، آریزونا,क्लार्कडेल,克拉克代尔', 34.7711300, -112.0579400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143779, 'Claypool', 'Claypool', '', 33.4111700, -110.8426100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143780, 'Clifton', 'Clifton', 'Klifton,Kliftun,ke li fu dun,keullipeuteon,kliphatana,klyftn  aryzwna,klyftwn,Клифтон,Клифтън,Кліфтон,كليفتون,کلیفتن، آریزونا,क्लिफटन,ክሊፍተን፥ አሪዞና,克利夫頓,클리프턴', 33.0509000, -109.2961800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143781, 'Colorado City', 'Colorado City', 'Kolorado Siti,Kolorado-Siti,Short Creek,ke luo la duo cheng,klradw syty  aryzwna,kolorryado siti,kwlwradw syty,Колорадо Сити,Колорадо-Сити,Колорадо-Сіті,كولورادو سيتي,کلرادو سیتی، آریزونا,कोलोर्र्याडो सिटी,科罗拉多城', 36.9902600, -112.9757700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143782, 'Congress', 'Congress', 'Congress,Congress Junction,Weaver', 34.1625300, -112.8507400, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143783, 'Coolidge', 'Coolidge', 'Kulidz,Kulidzh,ke li zhi,kulija,kwlydj,kwlyj  aryzwna,Кулидж,Кулиџ,Кулідж,كوليدج,کولیج، آریزونا,कूलिज,柯立芝', 32.9778400, -111.5176200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143784, 'Cordes Lakes', 'Cordes Lakes', '', 34.3078100, -112.1034900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143785, 'Cornville', 'Cornville', '', 34.7178000, -111.9215400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143786, 'Corona de Tucson', 'Corona de Tucson', '', 31.9653600, -110.7756400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143787, 'Cottonwood', 'Cottonwood', 'CTW,Cottonwood  okrug Apache,Kotonvud,Kotunud,ka dun,katanavuda,katn wwd  aryzwna,kwtnwwd,Котонвуд,Котънуд,كوتنوود,کاتن وود، آریزونا,कटनवूड,卡顿', 34.7391900, -112.0098800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143788, 'Desert Hills', 'Desert Hills', '', 34.5539000, -114.3724600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143789, 'Dilkon', 'Dilkon', 'Castle Butte,Dilcon,Dilkon,Maddox,Stiles', 35.3852900, -110.3206800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143790, 'Dolan Springs', 'Dolan Springs', '', 35.5919400, -114.2732900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143791, 'Douglas', 'Douglas', 'DUG,Daglas,Duglas,dagalasa,daglas  aryzwna,dao ge la si,dwghlas,Даглас,Дуглас,Дъглас,داگلاس، آریزونا,دوغلاس,डगलस,道格拉斯', 31.3445500, -109.5453400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143792, 'Drexel Heights', 'Drexel Heights', '', 32.1411900, -111.0284300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143793, 'Eagar', 'Eagar', 'Igar,Iger,Ijgur,aghar,aygar  aryzwna,igara,yi ge er,Іґер,Игар,Ийгър,إغار,ایگار، آریزونا,इगर,伊格尔', 34.1112400, -109.2923800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143794, 'East Sahuarita', 'East Sahuarita', '', 31.9428600, -110.9284200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143795, 'Ehrenberg', 'Ehrenberg', 'Ehrenberg,Mineral City', 33.6041900, -114.5252300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143796, 'El Mirage', 'El Mirage', 'El Mirazh,El''-Mirazh,al myrazh  aryzwna,almyraj,ela miraja,sa er wa duo huan ying,Ел Мираж,Ель-Міраж,ال میراژ، آریزونا,الميراج,एल मिराज,萨尔瓦多幻影', 33.6130900, -112.3246000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143797, 'Eloy', 'Eloy', 'Cotton City,Eloi,Eloy,Iloj,ai luo yi,alwy,alwy  aryzwna,elo''i,Ілой,Илой,Илој,إلوي,الوی، آریزونا,एलोइ,埃洛伊', 32.7559000, -111.5548400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143798, 'First Mesa', 'First Mesa', '', 35.8366700, -110.3815200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143799, 'Flagstaff', 'Flagstaff', 'FLG,Flagstaf,Flagstaff,Flankstaf,Flegstaff,Kinlani,Kinłání,Milltown,Skylight City,flaghstaf,flgstf  aryzwna,fu la ge si ta fu,furaggusutaffu,peullaegeuseutaepeu,phlegastapha,phlyagastapha,plgstp,Φλάγκσταφ,Флагстаф,Флагстафф,Флегстафф,פלגסטף,فلاغستاف,فلگستف، آریزونا,فلیگ سٹاف، ایریزونا,फ्लॅगस्टाफ,फ्ल्यागस्टाफ,แฟลกสแตฟฟ์,ፍላግስታፍ፥ አሪዞና,フラッグスタッフ,弗拉格斯塔夫,플래그스태프', 35.1980700, -111.6512700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143800, 'Florence', 'Florence', 'Florencija,Florens,Floruns,flwrns,flwrns  aryzwna,flwrns  ayryzwna,fu luo lun si,peullolenseu,phlorensa,Флоренс,Флоренция,Флоренція,Флорънс,فلورنس,فلورنس، آریزونا,فلورنس، ایریزونا,फ्लोरेन्स,ፍሎረንስ፥ አሪዞና,弗洛伦斯,플로렌스', 33.0314500, -111.3873400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143801, 'Flowing Wells', 'Flowing Wells', '', 32.2939600, -111.0098200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143802, 'Fort Defiance', 'Fort Defiance', '', 35.7444600, -109.0764800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143803, 'Fortuna Foothills', 'Fortuna Foothills', '', 32.6578300, -114.4118900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143804, 'Fountain Hills', 'Fountain Hills', '', 33.6117100, -111.7173600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143805, 'Fredonia', 'Fredonia', 'Fredonija,Fridonija,frdwnya  aryzwna,frydwnya,fu li duo ni ya,phredoniya,Фредонія,Фридония,Фридонија,فردونیا، آریزونا,فريدونيا,फ्रेडोनिया,弗里多尼亚', 36.9455400, -112.5265900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143806, 'Ganado', 'Ganado', 'Ganado,Gando Trading Post,Ganejdo,Lókʼaahnteel,Pueblo Colorado,Pueblo Ganado,Wukopapabi,ganado,Ганејдо,Ґанадо,गानाडो', 35.7114000, -109.5420500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143807, 'Gila Bend', 'Gila Bend', 'Big Bend,Gila Bend,Gila Bend Station,Gila Ranch,Gila Station,Gila-Bend,Khila Bend,Old Fort,Opansoitak,Opasoitac,Rinconada,San Simon y Judas,Santos Apostoles San Simon y Judas,Tesota,Tezotal,Uhupat Oidak,Uparsoytac,Upasoitac,Uupatoitak,ghyla bynd,gila benda,jyla bnd  aryzwna,xi la ben de,Гіла-Бенд,Хила Бенд,جیلا بند، آریزونا,غيلا بيند,गिला बेन्ड,希拉本德', 32.9478200, -112.7168300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143808, 'Gilbert', 'Gilbert', 'Gilbert,Gilbertas,Gilburt,gilbarta,gilbeoteu,girubato,gylbrt,gylbrt  aryzwna,ji er bo te,Гилберт,Гилбърт,Гілберт,גילברט,گلبرٹ، ایریزونا,گیلبرت، آریزونا,गिल्बर्ट,ギルバート,吉尔伯特,길버트', 33.3528300, -111.7890300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143809, 'Glendale', 'Glendale', 'Glendale,Glendeilas,Glendejl,Gorad Glendehjl,Nklenteil,Qlendeyl,ge lan dai er,geullendeil,ghlandyl,glenadela,glndyl  aryzwna,glndyyl,gurenderu,Γκλέντεϊλ,Глендейл,Глендејл,Горад Глендэйл,גלנדייל,غلانديل,گلندیل، آریزونا,گلنڈیل، ایریزونا,ग्लेनडेल,グレンデール,格蘭岱爾,글렌데일', 33.5386500, -112.1859900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143810, 'Globe', 'Globe', 'Beesh Ba Hooghan,Béésh Bá Hooghan,GLB,Globe,Globe City,Gloub,ge luo bu,geullobeu,ghlwb,globa,glwb  aryzwna,Глоуб,غلوب,گلوب، آریزونا,ग्लोब,ግሎብ፥ አሪዞና,格洛布,글로브', 33.3942200, -110.7865000, 'US', '2017-07-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143811, 'Gold Camp', 'Gold Camp', '', 33.2936700, -111.3042900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143812, 'Golden Valley', 'Golden Valley', '', 35.2233300, -114.2230100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143813, 'Goodyear', 'Goodyear', 'Egypt,GYR,Goodyear,Goodyear Farms,Gudier,Gudir,Gudiur,Gudjer,ghwdyyr,gudayara,guddoiya,gwdyr  aryzwna,jia nian,Гудиер,Гудиър,Гудїр,Гудјер,غوديير,گودیر، آریزونا,گڈایر، ایریزونا,गूडयर,グッドイヤー,嘉年', 33.4353200, -112.3582100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143814, 'Grand Canyon', 'Grand Canyon', 'GCN,Grand Canyon,Grand Canyon Village', 36.0544300, -112.1393400, 'US', '2013-10-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143815, 'Grand Canyon Village', 'Grand Canyon Village', '', 36.0463700, -112.1540600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143816, 'Green Valley', 'Green Valley', 'Green Valley,Grin Vali,Grin-Vejli,Tecota,grina bhyali,gryn wly  aryzwna,Грин Вали,Ґрін-Вейлі,گرین ولی، آریزونا,ग्रीन भ्याली', 31.8542500, -110.9937000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143817, 'Guadalupe', 'Guadalupe', 'Guadalupe,Gvadalupe,ghwadalwby,gua da lu pei,guvadulupa,gwadalwp  aryzwna,Гвадалупе,Гуадалупе,غوادالوبي,گوادالوپ، آریزونا,गुवादुलुप,瓜达卢佩', 33.3708800, -111.9629200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143818, 'Houck', 'Houck', '', 35.2830800, -109.2070400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143819, 'Huachuca City', 'Huachuca City', '', 31.6278700, -110.3339700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143820, 'Joseph City', 'Joseph City', 'Allen Camp,Allens Camp,Joseph City,Saint Joesph', 34.9558600, -110.3340100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143821, 'Kachina Village', 'Kachina Village', '', 35.0969600, -111.6926600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143822, 'Kaibito', 'Kaibito', 'K''ai'' Bii'' To,Kabito,Kaibeto,Kaibiito,Kaibito', 36.5972200, -111.0743100, 'US', '2016-12-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143823, 'Kayenta', 'Kayenta', 'Keenta,MVM,Tó Dínéeshzheeʼ,kayenta,Кеєнта,कायेन्ता', 36.7277800, -110.2545800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143824, 'Kearny', 'Kearny', 'Kerni,Керни', 33.0570100, -110.9106700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143825, 'Kingman', 'Kingman', 'IGM,Kingman,Kingmen,Kingmun,jin man,kingamana,kingamyana,kinguman,kngmyn  ayryzwna,kyngmn  aryzwna,kynjman,qyngmn,Кингман,Кингмен,Кингмън,Кінгмен,קינגמן,كينجمان,کنگمین، ایریزونا,کینگمن، آریزونا,किंगमन,किङ्गम्यान,ኪንግማን፥ አሪዞና,キングマン,金曼', 35.1894400, -114.0530100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143826, 'Lake Havasu City', 'Lake Havasu City', 'HII,Lejk Khavasu Siti,Lejk-Gavasu-Siti,Lejk-Khavasu-Siti,ha wa su hu cheng,leikeuhaebeosusiti,leka habhasu siti,lyk hafasw syty,lyk hawasw syty  aryzwna,reikuhabasushiti,Лейк Хавасу Сити,Лейк-Гавасу-Сіті,Лейк-Хавасу-Сити,Лејк Хавасу Сити,לייק האווסו סיטי,ليك هافاسو سيتي,لیک هاواسو سیتی، آریزونا,لیک ہاواسو سٹی، اریزونا,लेक हभासु सिटी,レイクハバスシティ,哈瓦苏湖城,레이크해버수시티', 34.4839000, -114.3224500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143827, 'Lake Montezuma', 'Lake Montezuma', '', 34.6322400, -111.7779300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143828, 'Lake of the Woods', 'Lake of the Woods', '', 34.1639300, -109.9895500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143829, 'Laveen', 'Laveen', '', 33.3628200, -112.1693200, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143830, 'LeChee', 'LeChee', 'LeChee,Lechee,Lichii''ii', 35.0322400, -110.7529100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143831, 'Linden', 'Linden', 'Juniper,Linden,Lindon', 34.2850400, -110.1570600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143832, 'Litchfield Park', 'Litchfield Park', 'Lichfijld,Lichfild Park,Litchfield,Litchfield Park,Litchfild-Park,Litchton,li qi fei er de gong yuan,licaphilda parka,lychfyld park,lytshfyld bark,Личфийлд,Личфилд Парк,Літчфілд-Парк,ليتشفيلد بارك,لیچفیلد پارک,لیچفیلڈ پارک، ایریزونا,लीचफिल्ड पार्क,利奇菲尔德公园', 33.4933700, -112.3579400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143833, 'Lukachukai', 'Lukachukai', '', 36.4169500, -109.2287100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143834, 'Mammoth', 'Mammoth', 'Mammoth,Shultz', 32.7225700, -110.6406500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143835, 'Many Farms', 'Many Farms', '', 36.3527800, -109.6178900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143836, 'Marana', 'Marana', 'MZJ', 32.4367400, -111.2253800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143837, 'Maricopa', 'Maricopa', 'Maricopa,Maricopa Junction,Marikopa,ma li ke pa,marykwba,marykwpa  aryzwna,merikopa,Марикопа,ماريكوبا,ماریکوپا، آریزونا,मेरिकोपा,马里科帕', 33.0581100, -112.0476400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143838, 'Mayer', 'Mayer', '', 34.3978100, -112.2362700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143839, 'Meadview', 'Meadview', 'Meadview,Meadville', 36.0022100, -114.0682900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143840, 'Mesa', 'Mesa', 'Gorad Mesa,Hayden,MSC,Mejsa,Mesa,Mesa City,Zenos,me sa,mei sa,mesa,msh,mysa,mysa  ayryzwna,myza,Μέσα,Горад Меса,Мейса,Меса,Մեսա,מסה,ميسا,میزا,میسا، ایریزونا,मेसा,মেসা,เมซา,მესა,メサ,梅薩,메사', 33.4222700, -111.8226400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143841, 'Mescal', 'Mescal', '', 31.9900800, -110.4353500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143842, 'Miami', 'Miami', 'Majami,mai a mi,mayami,myamy,myamy  aryzwna,myamy  ayryzwna,Майами,Маями,Маямі,Мајами,ميامي,میامی، آریزونا,میامی، ایریزونا,मायामी,迈阿密', 33.3992200, -110.8687200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143843, 'Mohave Valley', 'Mohave Valley', '', 34.9330600, -114.5888500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143844, 'Morenci', 'Morenci', 'Marenci,Morenci', 33.0786700, -109.3653500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143845, 'Mountainaire', 'Mountainaire', '', 35.0852900, -111.6659900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143846, 'Naco', 'Naco', '', 31.3353800, -109.9481300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143847, 'New River', 'New River', 'Duppa Station,New River,Newriver', 33.9158700, -112.1359900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143848, 'Nogales', 'Nogales', 'Dos Nogales,Isaacson,Isaactown,Line City,Los Nogales,Nogales,OLS,Villa Rivas,nogalesa,nuo jia li si,nwgals  aryzwna,nwghalys,Ногалес,Նոգալես,نوغاليس,نوگالس، آریزونا,नोगालेस,ኖጋሌስ፥ አሪዞና,诺加利斯', 31.3403800, -110.9342500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143849, 'Oracle', 'Oracle', 'Orakl,orekala,Оракл,ओरेकल', 32.6109100, -110.7709300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143850, 'Oro Valley', 'Oro Valley', 'Oro Vali,Oro-Vejli,ao luo gu,awrw faly,awrw wly  aryzwna,olobaelli,oro bhyali,Оро Вали,Оро-Вейлі,أورو فالي,اورو ولی، آریزونا,ओरो भ्याली,奥罗谷,오로밸리', 32.3909100, -110.9664900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143851, 'Page', 'Page', 'Naʼníʼá Hótsaa,PGA,Pejdz,Pejdzh,byj,pei ji shi,peja,pyj,pyj  ayryzwna,pyyg,Пейдж,Пејџ,פייג,بيج,پیج,پیج، ایریزونا,पेज,佩吉市', 36.9147200, -111.4558300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143852, 'Paradise Valley', 'Paradise Valley', 'Paradajs Vali,Paradajs-Vejli,Paradajz Vali,bradys faly,pradays wly  aryzwna,pyarada''ija bhyali,xian gu,Парадайз Вали,Парадайс-Вейлі,Парадајс Вали,براديس فالي,پرادایس ولی، آریزونا,प्याराडाइज भ्याली,仙谷', 33.5311500, -111.9426500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143853, 'Parker', 'Parker', 'Parker,Parkur,barkr,pa ke,parkara,parkr  aryzwna,parkr  ayryzwna,Паркер,Паркър,باركر,پارکر، آریزونا,پارکر، ایریزونا,पार्कर,ፓርከር፥ አሪዞና,帕克', 34.1500200, -114.2891200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143854, 'Parks', 'Parks', 'Maine,Park,Parks', 35.2605700, -111.9487700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143855, 'Paulden', 'Paulden', '', 34.8855800, -112.4682300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143856, 'Payson', 'Payson', 'PJB,Pejson,Pejsun,bayswn,pei sen,peiseun,pesana,pyzan  aryzwna,Пейсън,Пејсон,بايسون,پیزان، آریزونا,पेसन,佩森,페이슨', 34.2308700, -111.3251400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143857, 'Peach Springs', 'Peach Springs', 'PGS,Pich Springs,Pich-Sprigns,pica springas,Пич Спрингс,Піч-Спригнс,पीच स्प्रिङ्गस्', 35.5291600, -113.4254900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143858, 'Peoria', 'Peoria', 'Peori,Peoria,Peorija,Piorija,bywrya,pe''oriya,pi ao li ya,pioria,pywrya  aryzwna,pywrya  ayryzwna,Пеори,Пеория,Пиорија,Піорія,بيوريا,پیوریا، آریزونا,پیوریا، ایریزونا,पेओरिया,ピオリア,皮奧里亞', 33.5806000, -112.2373800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143859, 'Peridot', 'Peridot', '', 33.3103400, -110.4553800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143860, 'Phoenix', 'Phoenix', 'East Phoenix,Feniks,Fenikso,Finiks,Finiksa,Finiksas,Finiksos,Foinix,Féniks,Fīniksa,Gorad Finiks,Hellings Mill,Hoozdoh,Mill City,PHX,Peniki,Phenix,Phoeniks,Phoenix,Pumpkinsville,Pēniki,Salt River,Smith Station,Smith Station Phenix,Smiths Station,feng huang cheng,fenikkusu,finikasa,finiks,finiksa,fynks,fynyks,fynyks  aryzwna,phiniks,phiniks nagaram,phiniksa,pinigseu,piniks,piniksi,pnyqs,pynyqs,Φοίνιξ,Горад Фінікс,Финикс,Фінікс,Ֆինիքս,פיניקס,פניקס,فينيكس,فینکس,فینیکس، آریزونا,फ़ीनिक्स,फिनिक्स,फिनिक्स्,फीनिक्स,ফিনিক্স,ਫ਼ੀਨਿਕਸ,பீனிக்ஸ்,ఫీనిక్స్ నగరం,ಫೀನಿಕ್ಸ್,ഫീനിക്സ്,ฟีนิกซ์,ფინიქსი,ፊኒክስ፥ አሪዞና,フェニックス,凤凰城,鳳凰城,피닉스', 33.4483800, -112.0740400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143861, 'Picture Rocks', 'Picture Rocks', '', 32.3459100, -111.2462100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143862, 'Pima', 'Pima', '', 32.8965600, -109.8283500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143863, 'Pine', 'Pine', '', 34.3844700, -111.4551400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143864, 'Pinetop-Lakeside', 'Pinetop-Lakeside', 'Lakeside,Pinetop,Pinetop-Lakeside', 34.1425400, -109.9603800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143865, 'Pirtleville', 'Pirtleville', '', 31.3571600, -109.5635200, 'US', '2015-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143866, 'Prescott', 'Prescott', 'PRC,Preskot,Preskott,bryskwt,preskata,prskt  aryzwna,pu lei si ke te,puresukotto,Прескот,Прескотт,بريسكوت,پرسکت، آریزونا,پریسکوٹ، ایریزونا,प्रेस्कट,ፕሬስኮት፥ አሪዞና,プレスコット,普雷斯科特', 34.5400200, -112.4685000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143867, 'Prescott Valley', 'Prescott Valley', 'Preskot Vali,bryskwt faly,preskata bhyali,prskat wly  aryzwna,pu lei si ke te shan gu,Прескот Вали,بريسكوت فالي,پرسکات ولی، آریزونا,प्रेस्कट भ्याली,普雷斯科特山谷', 34.6100200, -112.3157200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143868, 'Quartzsite', 'Quartzsite', 'Fort Tyson,Kuarcsajt,Kvarcsajt,Kvorcsajt,Old Fort Tyson,Posas,Quartsite,Quartzite,Quartzsite,Quarzite,Tyson,kvartjasa''ita,kwartzsayt,kwrtsayt,shui jing zhen,Кварцсайт,Кворцсајт,Куарцсайт,كورتسايت,کوارتزسایت,کوارٹزسائٹ، ایریزونا,क्वार्ट्जसाइट,水晶镇', 33.6639100, -114.2299500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143869, 'Queen Creek', 'Queen Creek', 'Kuijn Krijk,Kvin Krik,Kvin-Krik,Queen Creek,Rittenhouse,kvina krika,kwyn kryk,kwyyn kryk  aryzwna,nu wang xi,Квин Крик,Квін-Крік,Куийн Крийк,كوين كريك,کوئین کریک، آریزونا,क्वीन क्रीक,女王溪', 33.2486600, -111.6343000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143870, 'Rio Verde', 'Rio Verde', '', 33.7225400, -111.6756900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143871, 'Rio Rico', 'Rio Rico', '', 31.4714800, -110.9764800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143872, 'Sacaton', 'Sacaton', 'El Tusonimo,La Encarnacion,Pima Agency,Sacaton,San Juan Capistrano,Soacson,Tucsonimon,Tusonimo,Uturitu,Vturituc,Zacatone Camp', 33.0767200, -111.7393000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143873, 'Safford', 'Safford', 'Achʼįʼ Náhiłtį́į́,Layton,Safford,Saford,Sefford,Stafford,sa fu de,safodo,safwrd,sfwrd  aryzwna,syaphapharda,Сафорд,Сеффорд,سافورد,سففورڈ، ایریزونا,سفورد، آریزونا,स्याफफर्ड,ሳፎርድ፥ አሪዞና,サフォード,萨福德', 32.8339500, -109.7075800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143874, 'Sahuarita', 'Sahuarita', 'Saguarita,Sahuarita,Sahuarito,Sakhuarita,Saurita,Sorita,sa wa li ta,sahu''arita,sahualita,sahwryta,shwaryta  aryzwna,Сагуаріта,Сахуарита,Сорита,ساهوريتا,سهوآریتا، آریزونا,سہوارتھ، ایریزونا,साहुआरिता,萨瓦里塔,사후아리타', 31.9575800, -110.9556500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143875, 'Saint David', 'Saint David', '', 31.9042500, -110.2142400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143876, 'Saint Johns', 'Saint Johns', 'SJN,Saint John,Saint Johns', 34.5058700, -109.3609300, 'US', '2017-07-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143877, 'Saint Michaels', 'Saint Michaels', '', 35.6447400, -109.0956500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143878, 'Salome', 'Salome', '', 33.7811400, -113.6146500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143879, 'San Carlos', 'San Carlos', 'San - Karlos,Сан - Карлос', 33.3456200, -110.4550400, 'US', '2015-08-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143880, 'San Carlos', 'San Carlos', '', 33.3458800, -111.8507000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143881, 'San Luis', 'San Luis', 'San Luis,san lwys,sheng lu yi si,sn lwyys  aryzwna,syana lu''i,Сан Луис,سان لويس,سن لوئیس، آریزونا,स्यान लुई,圣路易斯', 32.4870000, -114.7821800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143882, 'San Manuel', 'San Manuel', '', 32.5997900, -110.6309300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143883, 'Scottsdale', 'Scottsdale', 'SCF,Scottsdale,Skotsdejl,Skottsdejl,seukocheudeil,si ke ci dai er,skatasdela,skatzdyl  aryzwna,skwtsdyl,sqwtsdyyl,sukottsuderu,Скотсдейл,Скотсдејл,Скоттсдейл,סקוטסדייל,سكوتسديل,سکاتزدیل، آریزونا,سکاٹسڈیل، ایریزونا,स्कटस्डेल,スコッツデール,斯科茨代爾,스코츠데일', 33.5092100, -111.8990300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143884, 'Sedona', 'Sedona', 'SDX,Sedona,sai duo na,sdwna  aryzwna,sedona,sydwna,Седона,Սեդոնա,سدونا، آریزونا,سيدونا,सेडोना,セドナ,塞多纳', 34.8697400, -111.7609900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143885, 'Sells', 'Sells', 'Indian Oasis,Sells', 31.9120200, -111.8812300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143886, 'Show Low', 'Show Low', 'SOW,Sholow,Shou Lou,Shou-Lov,Show Low,Show Slow,shw la  aryzwna,shw lw,so lo,xiao luo,Шоу Лоу,Шоу-Лов,شو لا، آریزونا,شو لو,शो लो,肖洛', 34.2542100, -110.0298300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143887, 'Sierra Vista', 'Sierra Vista', 'FHU,S''erra-Vista,Siera Vista,Sijera Vista,shierabisuta,siyara bhista,syra wysta  aryzwna,syyra fysta,xie la wei si ta,Сиера Виста,Сијера Виста,Сьерра-Виста,Сьєрра-Віста,سييرا فيستا,سیرا وسٹا، ایریزونا,سیرا ویستا، آریزونا,सीयरा भिस्ता,シエラビスタ,谢拉维斯塔', 31.5545400, -110.3036900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143888, 'Snowflake', 'Snowflake', 'Snouflejk,To Dilhil Biih Yili,Tó Diłhił Biih Yílį́,asnwflyk  aryzwna,snophleka,snw flak,xue hua,Сноуфлейк,Сноуфлејк,اسنوفلیک، آریزونا,سنو فلاك,स्नोफ्लेक,雪花', 34.5133700, -110.0784500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143889, 'Somerton', 'Somerton', 'Algodones Land Grant,Somerton', 32.5964400, -114.7096800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143890, 'South Tucson', 'South Tucson', 'Juzhen Tuson,Saut Tuson,Sauz-Tuson,nan tu sen,sa''utha taksana,sauseutuson,sawth twkswn,sawth twsan,Сауз-Тусон,Саут Тусон,Южен Тусон,ساوث توسان,ساوث توكسون,साउथ टक्सन,南图森,사우스투손', 32.1995200, -110.9684200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143891, 'Spring Valley', 'Spring Valley', 'Spring-Vehlli,Спринг-Вэлли', 34.3450300, -112.1590500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143892, 'Springerville', 'Springerville', 'Springervil,Springervill,Springurvil,Tse Noodooz,Tsé Noodǫ́ǫ́z,aspryngrwyl  aryzwna,sbrynghfyl,si pi ling wei er,springarabhila,Спрингервил,Спрингервілл,Спрингървил,اسپرینگرویل، آریزونا,سبرينغفيل,स्प्रिङ्गरभिल,斯皮灵威尔', 34.1335500, -109.2883400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143893, 'Star Valley', 'Star Valley', 'Diamond Star,Star Valley,Starr Valley', 34.2550400, -111.2584700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143894, 'Summit', 'Summit', '', 32.0670200, -110.9514800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143895, 'Sun City', 'Sun City', 'Marinette,San Siti,San-Siti,Sun City,san syty  aryzwna,sana siti,sanshiti,Сан Сити,Сан-Сіті,سان سیتی، آریزونا,सन सिटी,サンシティ', 33.5975400, -112.2718200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143896, 'Sun City West', 'Sun City West', '', 33.6619800, -112.3412700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143897, 'Sun Lakes', 'Sun Lakes', '', 33.2111600, -111.8754200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143898, 'Sun Valley', 'Sun Valley', '', 34.2542000, -111.2612500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143899, 'Superior', 'Superior', 'Hastings,Superior,Supirior,Supiriur,Yoolgai,Yoołgai,su bi li er,superiyara,swbrywr,swprywr  aryzwna,Супириор,Супириър,سوبريور,سوپریور، آریزونا,सुपेरियर,苏必利尔', 33.2939500, -111.0962300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143900, 'Surprise', 'Surprise', 'Ennis,Serprajz,Sjurprajz,Sjurpriz,Surprajz,Surprise,sapuraizu,sarpra''ija,se pu lai si,seopeulaijeu,swpryyz,swrbrayz,swrprayz  aryzwna,Серпрайз,Сурпрајз,Сърпрайз,Сюрпрайз,Сюрприз,סופרייז,سوربرايز,سورپرایز، آریزونا,सर्प्राइज,サプライズ,瑟普赖斯,서프라이즈', 33.6305900, -112.3332200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143901, 'Swift Trail Junction', 'Swift Trail Junction', '', 32.7297900, -109.7139700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143902, 'Tanque Verde', 'Tanque Verde', '', 32.2517400, -110.7373100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143903, 'Taylor', 'Taylor', 'TYZ,Tejlor,Тейлор', 34.4650400, -110.0912300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143904, 'Tempe', 'Tempe', 'Butte City,Haydens Butte,Haydens Ferry,Haydens Mill,San Pablo,Tempe,Tempi,tan pei,tempe,tempi,tenpi,tmb,tmpy  aryzwna,Темпе,Темпи,Темпі,تمب,تمپی، آریزونا,ٹیمپے، ایریزونا,तेम्पे,テンピ,坦佩,템피', 33.4147700, -111.9093100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143905, 'Tempe Junction', 'Tempe Junction', '', 33.4142100, -111.9434800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143906, 'Thatcher', 'Thatcher', 'Tacher,Tachur,Tetcher,sa qie er,tachr  aryzwna,tatshr,thyacara,Тачер,Тачър,Тетчер,تاتشر,تاچر، آریزونا,थ्याचर,撒切尔', 32.8492300, -109.7592500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143907, 'Three Points', 'Three Points', '', 32.0767500, -111.3137100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143908, 'Tolleson', 'Tolleson', 'Toleson,Tolisun,Tollison,tollesana,tuo li sen,twlsan  aryzwna,twlyswn,Толесон,Толисън,Толлісон,تولسان، آریزونا,توليسون,तोल्लेसन,托利森', 33.4500400, -112.2593200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143909, 'Tombstone', 'Tombstone', 'Tombston,Tombstone,Tumston,Tumstoun,tambastona,tang mu si tong,to~umusuton,tumbastona,tumseuton,Тумстон,Тумстоун,توم‌استون، آریزونا,टुम्बस्टोन,টম্বস্টোন,トゥームストーン,汤姆斯通,툼스톤', 31.7128700, -110.0675800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143910, 'Tonto Basin', 'Tonto Basin', '', 33.8317100, -111.2945700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143911, 'Tortolita', 'Tortolita', 'Portolita,Tortolita', 32.4103500, -111.0173200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143912, 'Tuba City', 'Tuba City', 'TBC,To Naneesdizi,Tuba,Tuba City,Tuba Siti,Tuba-Siti,Tó Naneesdizí,tuba siti,Туба Сити,Туба-Сіті,तुबा सिटी', 36.1349900, -111.2398600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143913, 'Tubac', 'Tubac', 'Tubak,to~ubaku,tubaka,Тубак,तुबाक,トゥバク', 31.6125900, -111.0459200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143914, 'Tucson', 'Tucson', 'Fucson,Gorad Tusan,Lucson,San Casme del Tucson,TUS,Takson,Teuson,Toison,Touson,Tucson,Tuczon,Tugson,Tuguison,Tuison,Tuksonas,Tulquson,Tuozon,Tuquisson,Tuqulson,Tuson,Tusona,Tūsona,taksana,thu sxn,tsuson,tu sen,tusana,tuson,tusona,twsan,twswn,tʼusoni,Τουσόν,Горад Тусан,Тусон,Թուսոն,טוסון,توسان,توسون,ٹوسان، ایریزونا,टक्सन,तुसॉन,টুসান,ทูซอน,ტუსონი,ツーソン,图森,투손', 32.2217400, -110.9264800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143915, 'Tucson Estates', 'Tucson Estates', '', 32.1875800, -111.0909300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143916, 'Vail', 'Vail', 'Vejl,bhela,Вейл,Вејл,भेल', 32.0478600, -110.7120300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143917, 'Wellton', 'Wellton', 'Saint Peter,San Pedro,Ueltun,Velton,Wellton,hua er deng,velatana,wltn  aryzwna,wltwn,Велтон,Уелтън,ولتن، آریزونا,ولتون,वेलटन,华尔登', 32.6728300, -114.1468800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143918, 'Whetstone', 'Whetstone', '', 31.9573100, -110.3420200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143919, 'White Mountain Lake', 'White Mountain Lake', '', 34.3486500, -109.9978900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143920, 'Whiteriver', 'Whiteriver', 'WTR,Whiteriver', 33.8369900, -109.9642700, 'US', '2013-06-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143921, 'Wickenburg', 'Wickenburg', 'Uikunburg,Vikenberg,Vikenburg,Wickenburg,Wickenburg Ranch,vikenabarga,wei ken bo ge,wyknbrg  aryzwna,wyknbwrgh,Викенбург,Вікенберг,Уикънбърг,ويكنبورغ,ویکنبرگ، آریزونا,विकेनबर्ग,威肯勃格', 33.9686400, -112.7296200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143922, 'Willcox', 'Willcox', 'CWX,Uilkoks,Vilkoks,Villkoks,Wilcox,Willcox,vilakaksa,wei er ke ke si,wylkaks  aryzwna,Вилкокс,Віллкокс,Уилкокс,ویلکاکس، آریزونا,विलकक्स,威尔科克斯', 32.2528500, -109.8320100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143923, 'Williams', 'Williams', 'Uilijams,Vil''jams,Vilijams,u~iriamuzu,viliyamsa,vilyamsa,wei lian mu si,wylyamz,wylyamz  aryzwna,Вилијамс,Вільямс,Уилиямс,ويليامز,ویلیامز، آریزونا,विलियम्स,विल्यम्स,ウィリアムズ,威廉姆斯', 35.2494600, -112.1910000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143924, 'Williamson', 'Williamson', '', 34.6900200, -112.5410100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143925, 'Willow Valley', 'Willow Valley', '', 34.9119500, -114.6066300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143926, 'Window Rock', 'Window Rock', 'Tseghahoodzani,Tségháhoodzání,Uindou-Rok,Vindou Rok,Vindov-Rok,vindo raka,wen duo luo ke,Виндоу Рок,Віндов-Рок,Уиндоу-Рок,विन्डो रक,温多罗克', 35.6805700, -109.0525900, 'US', '2012-03-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143927, 'Winslow', 'Winslow', 'Beesh Sinil,Béésh Sinil,INW,Uinslou,Vinslou,Vinslov,vinslo,wen si luo,wynslw,wynslw  aryzwna,wynslw  ayryzwna,Винслоу,Вінслов,Уинслоу,وينسلو,وینسلو، آریزونا,وینسلو، ایریزونا,विन्स्लो,温斯洛', 35.0241900, -110.6973600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143928, 'Youngtown', 'Youngtown', 'Youngstown,Youngtown', 33.5939300, -112.3029400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143929, 'Yuma', 'Yuma', 'Arizona,Arizona City,Colorado City,Doonysio,Juma,La Purisima Concepcion,Pueblo de la Concepcion,Puutsiyumah,San Dionisio,San Dionysio,YUM,Yuma,Yuma City,Yumas,you ma,yuma,ywma,ywma  aryzwna,ywma  ayryzwna,ywmh,Јума,Юма,יומה,يوما,یوما، آریزونا,یوما، ایریزونا,युमा,ዩማ፥ አሪዞና,ユマ,尤馬', 32.7253200, -114.6244000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143930, 'Acton', 'Acton', 'Akton,Ehkton,aktwn  kalyfrnya,entana,Актон,Эктон,اکتون، کالیفرنیا,ایکٹن، کیلیفورنیا,एन्टन', 34.4699900, -118.1967400, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143931, 'Adelanto', 'Adelanto', 'Adelanto,a de lan tuo,adellanto,adlantw  kalyfrnya,adylantw,edelanto,Аделанто,آدلانتو، کالیفرنیا,أديلانتو,एडेलान्तो,阿德兰托,아델란토', 34.5827700, -117.4092200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143932, 'Agoura', 'Agoura', 'Agoura,Agoura Hills,Picture City', 34.1430600, -118.7378700, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143933, 'Agoura Hills', 'Agoura Hills', '', 34.1363900, -118.7745300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143934, 'Agua Dulce', 'Agua Dulce', '', 34.4963800, -118.3256300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143935, 'Aguanga', 'Aguanga', '', 33.4428100, -116.8650200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143936, 'Ahwahnee', 'Ahwahnee', 'Ahwahnee,Awahnee', 37.3655000, -119.7262700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143937, 'Alameda', 'Alameda', 'Alameda,Alamida,Alaminta,a la mi da,aelleomida,alamda  kalyfrnya,alameda,alamyda,arameda,Αλαμήντα,Аламеда,Аламида,آلامدا، کالیفرنیا,ألاميدا,अलामेदा,アラメダ,阿拉米達,앨러미다', 37.7652100, -122.2416400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143938, 'Alamo', 'Alamo', 'Alamo,alamw  kalyfrnya,aramo,elamo,Álamo,Аламо,الامو، کالیفرنیا,एलामो,アラモ', 37.8502000, -122.0321800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143939, 'Albany', 'Albany', 'Albany,O''Shean''s View,Ocean View,Olbani,albany,albany  kalyfrnya,albany  kylyfwrnya,ao bai ni,elbani,olbeoni,Олбани,Олбані,آلبانی، کالیفرنیا,ألباني,البانی، کیلیفورنیا,एल्बानी,奧柏尼,올버니', 37.8868700, -122.2977500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143940, 'Alhambra', 'Alhambra', 'Al''gambra,Algambra,Alhambra,Alkhambra,a han bu la,alhambra,alhambra  kalyfrnya,alhmra  kylyfwrnya,el''hambra,Алгамбра,Алхамбра,Альгамбра,آلهامبرا، کالیفرنیا,ألهامبرا,الحمرا، کیلیفورنیا,الہامبرا,एल्हाम्ब्रा,阿罕布拉', 34.0952900, -118.1270100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143941, 'Aliso Viejo', 'Aliso Viejo', 'Aliso Viekho,Aliso Vijekho,alysw fyjw,alysw wyjw  kalyfrnya,eliso bhiyo,ya li suo wei ye he,Алисо Виехо,Алисо Вијехо,آلیسو ویجو، کالیفرنیا,أليسو فيجو,एलिसो भियो,アリソ・ビエホ,亚里索维耶荷', 33.5650400, -117.7271200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143942, 'Allendale', 'Allendale', '', 38.4446300, -121.9430200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143943, 'Alondra Park', 'Alondra Park', '', 33.8894600, -118.3309100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143944, 'Alpaugh', 'Alpaugh', 'Alpaugh,Alspaugh', 35.8877300, -119.4873400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143945, 'Alpine', 'Alpine', 'Alpajn,Alpine,Alpine El Capitan,Viejas Stage Stop,Viejas Stop,alpyn  kalyfrnya,elpina,Алпајн,الپین، کالیفرنیا,एल्पिन', 32.8350500, -116.7664100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143946, 'Alta Sierra', 'Alta Sierra', '', 35.7312600, -118.5539000, 'US', '2016-02-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143947, 'Alta Sierra', 'Alta Sierra', '', 39.1415600, -121.0538400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143948, 'Altadena', 'Altadena', 'Al''tadena,Altadina,altadena,altadna  kalyfrnya,Алтадина,Альтадена,التادنا، کالیفرنیا,अल्टाडेना', 34.1897300, -118.1311800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143949, 'Alum Rock', 'Alum Rock', '', 37.3660500, -121.8271800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143950, 'American Canyon', 'American Canyon', 'Amerikan Kanjon,Amerikan Keniun,Amerikan-Kan''on,amerikana kyan''yana,amrykn knywn  kalyfrnya,amyrykan kanywn,mei li jian xia gu,Американ Канјон,Американ Кениън,Американ-Каньон,أميريكان كانيون,امریکن کنیون، کالیفرنیا,अमेरिकन क्यान्यन,美利堅峽穀,美利堅峽谷', 38.1749200, -122.2608000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143951, 'Amesti', 'Amesti', '', 36.9635600, -121.7791200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143952, 'Anaheim', 'Anaheim', 'ANA,Anachaim,Anahaima,Anahaym,Anaheim,Anaheimas,Anakhajm,Campo Aleman,Gorad Anakhajm,a na hai mu,aeneohaim,an na han,anahaimi,anahaimu,anahaym,anahaym  kalyfrnya,enaha''ima,Άναχαϊμ,Анахайм,Анахајм,Горад Анахайм,Անահայմ,אנאהיים,אנהיים,آناهايم,آناهایم، کالیفرنیا,اناہیم، کیلیفورنیا,ایناہیم,अ‍ॅनाहाइम,एनाहाइम,ანაჰაიმი,アナハイム,安那罕,阿納海姆,애너하임', 33.8352900, -117.9145000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143953, 'Angels Camp', 'Angels Camp', 'Angel''s Camp,Angels,Angels City,Carson''s Creek,City of Angels,Clearlake,Ejndzels Kemp,Ejndzhuls Kemp,anjls kamb,anjls kmp  kalyfrnya,aynjlz kymp  kylyfwrnya,einjeolseukaempeu,enjelsa siti,tian shi ying,Ейнджълс Кемп,Ејнџелс Кемп,آنجلس کمپ، کالیفرنیا,أنجلس كامب,اینجلز کیمپ، کیلیفورنیا,एन्जेल्स सिटी,天使营,에인절스캠프', 38.0682600, -120.5396500, 'US', '2012-06-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143954, 'Angwin', 'Angwin', 'Angvin,en''gvina,Ангвин,एन्ग्विन', 38.5757400, -122.4499800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143955, 'Antelope', 'Antelope', 'Antelop,Антелоп', 38.7082400, -121.3299500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143956, 'Antioch', 'Antioch', 'Antioch,Antiocheia,Antiok,Antiokas,East Antioch,Marshs Landing,Smith''s Landing,an tiao ke,antiokku,antywch  kalyfrnya,antywk,entiyaka,Αντιόχεια,Антиок,Антиоч,آنتیوچ، کالیفرنیا,أنتيوك,اینٹیوخ,एन्टियक,アンティオック,安條克', 38.0049200, -121.8057900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143957, 'Anza', 'Anza', '', 33.5550300, -116.6736300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143958, 'Apple Valley', 'Apple Valley', 'APV,Apple Valley,Apul Vali,Epl Vali,abbl faly,aepeulbaelli,apl wly  kalyfrnya,aypl wyly  kylyfwrnya,eppala bhyali,ping guo gu,Апъл Вали,Епл Вали,أببل فالي,اپل ولی، کالیفرنیا,ایپل ویلی، کیلیفورنیا,एप्पल भ्याली,苹果谷,애플밸리', 34.5008300, -117.1858800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143959, 'Aptos', 'Aptos', 'Aptos,Aptos Rancho,Rancho Aptos,eptasa,Аптос,एप्टस', 36.9771700, -121.8994000, 'US', '2015-11-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143960, 'Arbuckle', 'Arbuckle', '', 39.0174000, -122.0577500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143961, 'Arcadia', 'Arcadia', 'Arkadija,Arkejdija,akeidia,arkadiya,arkadya,arkadya  kalyfrnya,ya kai di ya,Аркадия,Аркадія,Аркејдија,آرکادیا، کالیفرنیا,آرکیڈیا، کیلیفورنیا,أركاديا,आर्काडिया,亞凱迪亞,아케이디아', 34.1397300, -118.0353400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143962, 'Armona', 'Armona', '', 36.3157800, -119.7084600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143963, 'Arnold', 'Arnold', 'Arnol''d,Арнольд', 38.2554700, -120.3510300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143964, 'Aromas', 'Aromas', 'Aromas,Sand Cut', 36.8885600, -121.6430000, 'US', '2015-06-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143965, 'Arroyo Grande', 'Arroyo Grande', '', 35.1185900, -120.5907300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143966, 'Artesia', 'Artesia', 'Artisija,Artizha,a di xi ya,artesiya,artsya  kalyfrnya,artysya,Артижа,Артісія,آرتسیا، کالیفرنیا,أرتيسيا,ارٹیسیا، کیلیفورنیا,आर्टेसिया,阿蒂西亚', 33.8658500, -118.0831200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143967, 'Arvin', 'Arvin', 'Arvin,a wen,arbhina,arfyn,arwyn  kalyfrnya,Арвин,آروین، کالیفرنیا,أرفين,अर्भिन,阿文', 35.2091300, -118.8284300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143968, 'Ashland', 'Ashland', 'Ashland,San Leandro South', 37.6946500, -122.1138500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143969, 'Atascadero', 'Atascadero', 'Ataskadero,Ataskaderou,a ta si ka de luo,atasadyrw,ataskadrw  kalyfrnya,etaskadero,Атаскадеро,Атаскадероу,آتاسکادرو، کالیفرنیا,أتاساديرو,एटास्काडेरो,阿塔斯卡德罗', 35.4894200, -120.6707300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143970, 'Atherton', 'Atherton', 'Adurtun,Aterton,Atherton,Fair Oaks,a se dun,atharatana,athrtwn,atrtwn  kalyfrnya,Адъртън,Атертон,آترتون، کالیفرنیا,آتھرتن، کیلیفورنیا,أثرتون,आथरटन,阿瑟顿', 37.4613300, -122.1977400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143971, 'Atwater', 'Atwater', 'Atvoter,Etuotur,a te wo te,atwatr  kalyfrnya,atwwtr,etvatara,Атвотер,Етуотър,آتواتر، کالیفرنیا,أتووتر,एट्वाटर,阿特沃特', 37.3477200, -120.6090800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143972, 'Auberry', 'Auberry', '', 37.0807800, -119.4854100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143973, 'Auburn', 'Auburn', 'AUN,Auburn,North Fork Dry Diggins,Obern,Oburn,Rich Dry Diggings,Wood''s Dry Diggings,Woods Dry Diggings,abarna,ao ben,awbrn  kalyfrnya,awbwrn,oban,obeon,Оберн,Обърн,آوبرن، کالیفرنیا,أوبورن,अबर्न,オーバーン,奥本,오번', 38.8965700, -121.0768900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143974, 'Auburn Lake Trails', 'Auburn Lake Trails', '', 38.9143400, -120.9524400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143975, 'August', 'August', '', 37.9788100, -121.2621700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143976, 'Avalon', 'Avalon', 'AVX,Avalon,Shatto,a wa long,abaron,aebeollon,afalwn,awalwn  kalyfrnya,aywalwn  kylyfwrnya,ebhelana,Авалон,آوالون، کالیفرنیا,أفالون,ایوالون، کیلیفورنیا,एभेलन,アバロン,阿瓦隆,애벌론', 33.3428100, -118.3278500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143977, 'Avenal', 'Avenal', 'Avenal,a wei na er,afynal,awnal  kalyfrnya,ebhenala,Авенал,آونال، کالیفرنیا,أفينال,एभेनल,阿维纳尔', 36.0041200, -120.1290300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143978, 'Avila Beach', 'Avila Beach', 'Avila,Avila Beach', 35.1799800, -120.7318400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143979, 'Avocado Heights', 'Avocado Heights', '', 34.0361200, -117.9911800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143980, 'Azusa', 'Azusa', 'Azjusa,Azusa,a su sa,ajusa,azusa,azwsa,azwsa  kalyfrnya,Азуса,Азюса,آزوسا، کالیفرنیا,أزوسا,گلیڈسٹون، کیلیفورنیا,अजुसा,アズサ,阿苏萨', 34.1336200, -117.9075600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143981, 'Bakersfield', 'Bakersfield', 'Alkali City,BFL,Baker''s Field,Bakersfield,Beikersfilda,Beikersfildas,Beikersfilnt,Beikersfīlda,Bejkersfild,Bejkursfijld,Beykersfild,Kern Island,bei ke si fei er de,beikeojeupildeu,bekarsaphilda,bekazufirudo,bykrsfyld,bykrzfyld  kalyfrnya,byyqrspyld,Μπέικερσφιλντ,Бейкерсфилд,Бейкерсфілд,Бейкърсфийлд,Бејкерсфилд,Բեյկերսֆիլդ,בייקרספילד,بيكرسفيلد,بیکرزفیلد، کالیفرنیا,بیکرزفیلڈ,بیکرزفیلڈ، کیلیفورنیا,बेकर्सफिल्ड,बेकर्सफील्ड,ბეიკერსფილდი,ベーカーズフィールド,贝克斯菲尔德,베이커즈필드', 35.3732900, -119.0187100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143982, 'Baldwin Park', 'Baldwin Park', 'Baldwin Park,Bolduin Park,Bolduin-Park,Boldvin Park,Boldvin-Park,baldavina parka,baldwyn bark,baldwyn park  kalyfrnya,bao de wen gong yuan,Болдвин Парк,Болдвін-Парк,Болдуин Парк,Болдуин-Парк,بالدوين بارك,بالدوین پارک، کالیفرنیا,بالڈون پارک، کیلیفورنیا,बाल्डविन पार्क,鲍德温公园', 34.0852900, -117.9609000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143983, 'Banning', 'Banning', 'BNG,Baning,Banning,Moore City,ban ning,banyng  kalyfrnya,banyngh,byaninga,Банинг,بانينغ,بانینگ، کالیفرنیا,ब्यानिंग,班宁', 33.9255700, -116.8764100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143984, 'Barstow', 'Barstow', 'Barstou,Barstow,Bashdo,Báshdo,Fishpond,Fishponds,Grapevine,Waterman,Waterman Junction,ba si tuo,barasto,barstaw,barstw  kalyfrnya,baseuto,brstw,Барстоу,ברסטו,بارستاو,بارستو، کالیفرنیا,बारस्टो,巴斯托,바스토', 34.8985900, -117.0228200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143985, 'Barstow Heights', 'Barstow Heights', '', 34.8697100, -117.0561500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143986, 'Bay Point', 'Bay Point', '', 38.0290900, -121.9616300, 'US', '2014-02-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143987, 'Bear Valley Springs', 'Bear Valley Springs', '', 35.1591300, -118.6284200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143988, 'Beaumont', 'Beaumont', 'Beaumont,Bomont,Boumont,Edgar Station,San Gorgonio,Summit,bi''umonta,bo meng te,bomonteu,bwmant  kalyfrnya,bywmwnt,Бомонт,Боумонт,بومانت، کالیفرنیا,بيومونت,बीउमोन्ट,博蒙特,보몬트', 33.9294600, -116.9772500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143989, 'Bell', 'Bell', 'Bel,Bell,Bella,bei er,bela,bl  kalyfrnya,byl,byl  kylyfwrnya,Бел,Белл,Белла,بل، کالیفرنیا,بيل,بیل، کیلیفورنیا,बेल,贝尔', 33.9775100, -118.1870200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143990, 'Bell Gardens', 'Bell Gardens', 'Bel Gardens,Bel Garduns,Bell-Gardens,bei er hua yuan,bela gardensa,bl gardnz  kalyfrnya,byl ghardyns,Бел Гарденс,Бел Гардънс,Белл-Гарденс,بل گاردنز، کالیفرنیا,بيل غاردينس,بیل گارڈنز، کیلیفورنیا,बेल गार्डेन्स,貝爾花園', 33.9652900, -118.1514600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143991, 'Bellflower', 'Bellflower', 'Belflauer,Belflauur,Bellflauehr,Bellflaver,Bellflower,Somerset,bei er fu lao er,belaphlavara,belpeullawo,berufurawa,blflawr  kalyfrnya,bylflawr  kylyfwrnya,bylflawyr,Беллфлавер,Беллфлауэр,Белфлауер,Белфлауър,بلفلاور، کالیفرنیا,بيلفلاوير,بیلفلاور، کیلیفورنیا,बेलफ्लावर,ベルフラワー,贝尔弗劳尔,벨플라워', 33.8816800, -118.1170100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143992, 'Belmont', 'Belmont', 'Belmont,Portezuelo de las Pulgas,bei er meng te,belamonta,blmwnt  kalyfrnya,bylmwnt,Белмонт,بلمونت، کالیفرنیا,بيلمونت,बेलमोन्ट,贝尔蒙特', 37.5202100, -122.2758000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143993, 'Belvedere', 'Belvedere', '', 34.0405700, -118.1692400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143994, 'Belvedere', 'Belvedere', 'Belvedere,Belvedir,bei er wei dai lei,belabhedere,beruvu~edia,blwdr  kalyfrnya,bylfydyry,Белведере,Белведир,بلودر، کالیفرنیا,بيلفيديري,बेलभेडेरे,ベルヴェディア,贝尔韦代雷', 37.8727000, -122.4644200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143995, 'Ben Lomond', 'Ben Lomond', 'Ben Lomond,Pacific Mills', 37.0891100, -122.0863500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143996, 'Benicia', 'Benicia', 'Benecia,Benicia,Benisha,Bunisha,Francisca,bei ni xi ya,benisiya,bnysya,bnysya  kalyfrnya,Бениша,Бъниша,بنيسيا,بنیسیا، کالیفرنیا,बेनिसिया,贝尼西亚', 38.0493700, -122.1585800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143997, 'Berkeley', 'Berkeley', 'Berkeleia,Berkeley,Berkli,Berklis,Burkli,Bērkli,Gorad Berkli,JBK,bakure,bakuri,barkali,barkeli,barkli,beokeulli,bo ke li,brkly  kalyfrnya,brqly,byrkyly,Беркли,Берклі,Бъркли,Горад Берклі,ברקלי,برکلی، کالیفرنیا,برکلے,بيركيلي,बर्कली,बर्केली,बर्क्ली,ბერკლი,バークリー,バークレー,伯克利,버클리', 37.8715900, -122.2727500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143998, 'Bermuda Dunes', 'Bermuda Dunes', 'UDD', 33.7428000, -116.2891800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(143999, 'Berry Creek', 'Berry Creek', '', 39.6451600, -121.4033000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144000, 'Bethel Island', 'Bethel Island', '', 38.0149200, -121.6405100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144001, 'Beverly Hills', 'Beverly Hills', 'Bev"rli Khils,Beverley Hills,Beverly Hills,beverli hilsi,bibarihiruzu,bwrly hylz,bwwrly hyls,Бевърли Хилс,בוורלי הילס,بورلی هیلز,ბევერლი ჰილსი,ビバリーヒルズ', 34.0736200, -118.4003600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144002, 'Big Bear City', 'Big Bear City', 'Big Bear,Big Ber Siti,RBF,biga byara siti,Биг Бер Сити,बिग ब्यर सिटी', 34.2611200, -116.8450300, 'US', '2017-07-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144003, 'Big Bear Lake', 'Big Bear Lake', 'Big Bear Lake,Big Ber Lejk,Big Beur Lejk,Big Pear Lake Village,Pine Lake,bg byyr lyk  kylyfwrnya,biga byara leka,bigbeeoleikeu,byg byr lyk  kalyfrnya,bygh byr laky,da xiong hu,Биг Бер Лејк,Биг Беър Лейк,بيغ بير لاكي,بگ بیئر لیک، کیلیفورنیا,بیگ بیر لیک، کالیفرنیا,बिग ब्यर लेक,大熊湖,빅베어레이크', 34.2439000, -116.9114200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144004, 'Big Pine', 'Big Pine', 'Big Pajn,Big Pine,Bigpine,biga pa''ina,Биг Пајн,बिग पाइन', 37.1649300, -118.2895500, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144005, 'Big River', 'Big River', '', 34.1400200, -114.3613400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144006, 'Biggs', 'Biggs', 'Biggs,Biggs Station,Bigs,bi ge si,bigsa,byghghs,bygz  kalyfrnya,Бигс,بيغغس,بیگز، کالیفرنیا,बिग्स,比格斯', 39.4123900, -121.7127500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144007, 'Biola', 'Biola', '', 36.8021700, -120.0162700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144008, 'Bishop', 'Bishop', 'BIH,Bishop,Bishop Creek,Bishup,bi xiao pu,bisapa,bishoppu,bisyob,byshap  kalyfrnya,byshwb,Бишоп,Бишъп,بيشوب,بیشاپ، کالیفرنیا,बिशप,ビショップ,毕晓普,비숍', 37.3635400, -118.3951100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144009, 'Blackhawk', 'Blackhawk', 'Blackhawk-Camino Tassajara', 37.8207600, -121.9077400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144010, 'Bloomington', 'Bloomington', 'Blumington,blumingatana,Блумингтон,بلومنگٹن، کیلیفورنیا,ब्लूमिंगटन', 34.0702900, -117.3958800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144011, 'Blythe', 'Blythe', 'BLH,Blajd,Blajt,blayt  kalyfrnya,blayth,blitha,bu lai si,buraisu,Блайт,Блајд,بلايث,بلایت، کالیفرنیا,ब्लीथ,ブライス,布莱斯', 33.6103000, -114.5963500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144012, 'Bodega Bay', 'Bodega Bay', 'Bay,Bodega Bay,Bodega Bej,Porto Bodega,bodega be,Бодега Беј,बोडेगा बे', 38.3332500, -123.0480600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144013, 'Bodfish', 'Bodfish', 'Bodfish,Vaughn', 35.5880100, -118.4920300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144014, 'Bolinas', 'Bolinas', 'Ballenas,Baulenas,Baulings,Bawlines,Bolinas,bolinasa,Болинас,बोलिनास', 37.9093700, -122.6863700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144015, 'Bonita', 'Bonita', '', 32.6578300, -117.0300300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144016, 'Bonny Doon', 'Bonny Doon', 'Bonney Doon,Bonnie Doon,Bonny Doon', 37.0416200, -122.1505200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144017, 'Bonsall', 'Bonsall', '', 33.2889200, -117.2255900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144018, 'Boonville', 'Boonville', 'Bonneville,Boonville,Kendall''s City,The Corners', 39.0090700, -123.3661200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144019, 'Boron', 'Boron', 'Amargo,Baker,Borate,Boron,Kern,borona,Борон,बोरोन', 34.9994200, -117.6497800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144020, 'Boronda', 'Boronda', '', 36.6988500, -121.6749500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144021, 'Borrego Springs', 'Borrego Springs', 'BXS,Borego,Borego Spirng,Borego Springs,Borrego Springs,San Gregory Springs,borrego springas,Борего Спрингс,बोर्रेगो स्प्रिङ्गस्', 33.2558700, -116.3750100, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144022, 'Bostonia', 'Bostonia', '', 32.8075500, -116.9364200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144023, 'Boulder Creek', 'Boulder Creek', 'Boulder,Boulder Creek,Lorenzo', 37.1260600, -122.1221900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144024, 'Boyle Heights', 'Boyle Heights', '', 34.0339000, -118.2053500, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144025, 'Boyes Hot Springs', 'Boyes Hot Springs', 'Boyes Hot Springs,Boyes Springs', 38.3138000, -122.4819300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144026, 'Bradbury', 'Bradbury', 'Bradburi,Bredberi,Brehdberi,bai pu li,bradbwry,brdbry  kalyfrnya,bryadabyuri,Брадбъри,Бредбери,Бредбері,Брэдбери,برادبوري,بردبری، کالیفرنیا,ब्र्याडब्युरी,白普理', 34.1469500, -117.9709000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144027, 'Brawley', 'Brawley', 'BWC,Broli,Brouli,brawly,brawly  kalyfrnya,bu lao li,Броли,Броули,براولي,براولی، کالیفرنیا,布劳利', 32.9786600, -115.5302700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144028, 'Brea', 'Brea', 'Brea,Breja,La Brea,beulea,breya,bry,bry  kalyfrnya,bu lei ya,Брея,Бреја,بري,بری، کالیفرنیا,ब्रेया,布雷亚,브레아', 33.9166800, -117.9000600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144029, 'Brentwood', 'Brentwood', 'Brentud,Brentvud,beulenteuudeu,brentavuda,brnt wwd  kalyfrnya,bryntwwwd,bu lun te wu de,burentoudo,Брентвуд,Брентуд,برنت وود، کالیفرنیا,برينتووود,برینٹووڈ، کیلیفورنیا,ब्रेन्टवूड,ブレントウード,布伦特伍德,브렌트우드', 37.9318700, -121.6957900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144030, 'Bridgeport', 'Bridgeport', 'Bridzhport,Bridzport,burijjipoto,Бриджпорт,Бриџпорт,برج پورٹ، کیلیفورنیا,ブリッジポート', 38.2557500, -119.2312700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144031, 'Brisbane', 'Brisbane', 'Brisbane,Brisben,Brizbejn,Visitacion City,brisabena,brysbany,brysbyn  kalyfrnya,bu li si ban,Бризбейн,Бризбејн,Брисбен,بريسباني,بریسبین، کالیفرنیا,ब्रिसबेन,布里斯班', 37.6807700, -122.3999700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144032, 'Broadmoor', 'Broadmoor', '', 37.6866000, -122.4827500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144033, 'Brookdale', 'Brookdale', 'Brookdale,Clear Creek,Reed''s Spur', 37.1063400, -122.1060800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144034, 'Brooktrails', 'Brooktrails', '', 39.4437700, -123.3852900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144035, 'Buellton', 'Buellton', 'Bjulton,Bjultun,bi er dun,bwltwn  kalyfrnya,bwyltwn,byu''elatana,Бюлтън,Бјултон,بولتون، کالیفرنیا,بويلتون,ब्युएलटन,比尔顿', 34.6136000, -120.1926500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144036, 'Buena Park', 'Buena Park', 'Buehna-Park,Buena Park,Buenapark,Northam,buenapaku,buyana parka,bwyna bark,bwyna park,bywna park  kalyfrnya,pu an na gong yuan,Буена Парк,Буэна-Парк,بوينا بارك,بوینا پارک,بیونا پارک، کالیفرنیا,बुयना पार्क,ブエナパーク,普安那公园', 33.8675100, -117.9981200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144037, 'Buena Vista', 'Buena Vista', '', 37.3213300, -121.9166200, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144038, 'Burbank', 'Burbank', 'B"rbank,BUR,Berbank,Berbanka,Berbankas,Bermpan''k,Burbank,Bērbanka,babanku,barbyanka,beobaengkeu,bo ban ke,brbank,brbnk,brbnk  kalyfrnya,brbnq,brbynk  kylyfwrnya,Μπέρμπανκ,Бербанк,Бърбанк,Բըրբանք,ברבנק,بربانك,بربنک,بربنک، کالیفرنیا,بربینک، کیلیفورنیا,बर्ब्याङ्क,เบอร์แบงก์,バーバンク,伯班克,버뱅크', 34.1808400, -118.3089700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144039, 'Burbank', 'Burbank', 'Berbank,Бербанк', 37.3232800, -121.9316200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144040, 'Burlingame', 'Burlingame', 'Berlingejm,Berlingem,Burlingejm,barlingema,beolling-geim,bo ling ge mu,brlyngym  kalyfrnya,bwrlynghamy,Берлингем,Берлингејм,Бурлінгейм,Бърлингейм,برلینگیم، کالیفرنیا,بورلينغامي,बर्लिङ्गेम,伯灵格姆,벌링게임', 37.5841000, -122.3660800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144041, 'Buttonwillow', 'Buttonwillow', 'Batonvilou,Buena Vista,Buttonwillow,batanavilo,Батонвилоу,बटनविलो', 35.4005200, -119.4695600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144042, 'Byron', 'Byron', '', 37.8671500, -121.6380100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144043, 'Bystrom', 'Bystrom', '', 37.6207600, -120.9857700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144044, 'Cabazon', 'Cabazon', 'Cabazon,Hall''s Siding,Jacinto', 33.9175200, -116.7872400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144045, 'Calabasas', 'Calabasas', 'Kalabasas,ka la ba sa si,kalabasas,kalabasas  kalyfrnya,kallabasaseu,kyalabasaja,Калабасас,Կալաբասաս,كالاباساس,کالاباساس، کالیفرنیا,क्यालाबासाज,卡拉巴萨斯,칼라바사스', 34.1577800, -118.6384200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144046, 'Calexico', 'Calexico', 'CXL,Kaleksiko,jia li xi ge,kalkzykw  kalyfrnya,kalyksykw,kyaleksiko,qlqsyqw,Калексико,Калексіко,קלקסיקו,كاليكسيكو,کالکزیکو، کالیفرنیا,क्यालेक्सिको,加利西哥', 32.6789500, -115.4988800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144047, 'California City', 'California City', '', 35.1258000, -117.9859000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144048, 'Calipatria', 'Calipatria', 'CLR,Calipatria,Date City,Kalipatrija,ka li pa te li ya,kalybatrya,kalypatrya  kalyfrnya,kyalipyatriya,Калипатрия,Калипатрија,كاليباتريا,کالیپاتریا، کالیفرنیا,क्यालिप्याट्रिया,卡利帕特里亚', 33.1256000, -115.5141500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144049, 'Calistoga', 'Calistoga', 'Kalistoga,ka li si tuo jia,kalystwga  kalyfrnya,kalystwgha,karisutoga,kyalistoga,Калистога,كاليستوغا,کالیستوگا، کالیفرنیا,क्यालिस्टोगा,カリストガ,卡利斯托加', 38.5788000, -122.5797100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144050, 'Calimesa', 'Calimesa', 'Kalimesa,kalymsa  kalyfrnya,kalymysa,kyalimesa,Калимеса,كاليميسا,کالیمسا، کالیفرنیا,क्यालिमेसा', 34.0039000, -117.0619800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144051, 'Callender', 'Callender', '', 35.0530300, -120.5962800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144052, 'Camarillo', 'Camarillo', 'Camarillo,Camarillo Station,Kamaril''jo,Kamaril''o,Kamarilo,Pleasant Valley,ka ma li ao,kaemeolillo,kamariro,kamarylw,kamarylw  kalyfrnya,kyamarillo,Камарило,Камарильо,Камарільйо,كاماريلو,کاماریلو، کالیفرنیا,क्यामारिल्लो,カマリロ,卡马里奥,캐머릴로', 34.2163900, -119.0376000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144053, 'Cambria', 'Cambria', 'Cambria,Kambrija,Rosaville,San Simeon,Santa Rosa,Slabtown,kyambriya,Камбрија,क्याम्ब्रिया', 35.5641400, -121.0807500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144054, 'Cambrian Park', 'Cambrian Park', 'Cambrian Park,Cambrian Village', 37.2568900, -121.9307900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144055, 'Cameron Park', 'Cameron Park', '', 38.6687900, -120.9871600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144056, 'Camino', 'Camino', 'Camino,Seven Mile House', 38.7382400, -120.6749300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144057, 'Camp Meeker', 'Camp Meeker', 'Camp Meeker,Meeker''s', 38.4251900, -122.9594400, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144058, 'Campbell', 'Campbell', 'Kehmpbell,Kembel,Kembul,Kempbell,kambbyl,kan bei er,kmpbl  kalyfrnya,kyampabela,kymbl  kylyfwrnya,Кембел,Кембъл,Кемпбелл,Кэмпбелл,كامببيل,کمپبل، کالیفرنیا,کیمبل، کیلیفورنیا,क्याम्पबेल,坎貝爾', 37.2871700, -121.9499600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144059, 'Campo', 'Campo', 'Kampo,Кампо', 32.6064500, -116.4689100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144060, 'Canoga Park', 'Canoga Park', 'Canoga Park,Owensmouth', 34.2011200, -118.5981400, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144061, 'Canyon Lake', 'Canyon Lake', 'Kanjon Lejk,Keniun Lejk,kanywn laky,kanywn lyk  kalyfrnya,kyan''yana leka,kynyn lyk  kylyfwrnya,xia gu hu,Канјон Лејк,Кениън Лейк,كانيون لاكي,کانیون لیک، کالیفرنیا,کینین لیک، کیلیفورنیا,क्यान्यन लेक,峡谷湖', 33.6850200, -117.2730900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144062, 'Capitola', 'Capitola', 'Kapitola,ka pi tuo la,kabytwla,kapytwla  kalyfrnya,kyapitola,Капитола,كابيتولا,کاپیتولا، کالیفرنیا,کیپیٹولا، کیلیفورنیا,क्यापितोला,卡皮托拉', 36.9752300, -121.9532900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144063, 'Carlsbad', 'Carlsbad', 'Carlsbad,Frazier''s Station,Karlsbad,ka er si ba de,kaljeubaedeu,karlsabada,karlsbad,karls‌bd  kalyfrnya,karusubaddo,Карлсбад,كارلسباد,کارلزبیڈ,کارلس‌بد، کالیفرنیا,कार्ल्सबाद,คาร์ลสแบด,カールスバッド,卡尔斯巴德,칼즈배드', 33.1580900, -117.3505900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144064, 'Carmel Valley Village', 'Carmel Valley Village', '', 36.5060500, -121.7659400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144065, 'Carmel-by-the-Sea', 'Carmel-by-the-Sea', 'Carmel,Carmel City,Carmel by the Sea,Carmel-by-the-Sea,Karmel,Karmel baj du Sij,Karmel na Moru,ka mei er hai,kameolbaideosi,karmelaba''idasi,karml bhry  kylyfwrnya,karml-bay-d-sy  kalyfrnya,karmyl-by-thy-sy,Кармел,Кармел бай дъ Сий,Кармел на Мору,كارميل-بي-ثي-سي,کارمل بحری، کیلیفورنیا,کارمل-بای-د-سی، کالیفرنیا,कार्मेलबाइदसी,カーメル・バイ・ザ・シー,卡梅尔海,카멀바이더시', 36.5552400, -121.9232900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144066, 'Carmichael', 'Carmichael', 'Karmajkl,Karmajkul,karmisela,Кармайкл,Кармайкъл,Кармајкл,कार्मिशेल', 38.6171300, -121.3282800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144067, 'Carpinteria', 'Carpinteria', 'Carpenteria,Carpinteria,Carpintería,Karpinterija,La Carpinteria,San Roque,ka ping te li ya,karbyntyrya,karpinteriya,karpyntrya  kalyfrnya,Карпинтерия,Карпинтерија,كاربينتيريا,کارپینتریا، کالیفرنیا,कार्पिन्टेरिया,卡平特里亚', 34.3988800, -119.5184600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144068, 'Carson', 'Carson', 'Carson,Karson,Karsun,Lungsod ng Carson,ka sen,karsana,karsn,karswn,karswn  kalyfrnya,kaseun,kason,Κάρσον,Карсон,Карсън,كارسون,کارسن,کارسون، کالیفرنیا,कार्सन,カーソン,卡森,카슨', 33.8314100, -118.2820200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144069, 'Caruthers', 'Caruthers', '', 36.5427300, -119.8332000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144070, 'Casa Conejo', 'Casa Conejo', '', 34.1836200, -118.9434300, 'US', '2017-03-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144071, 'Castaic', 'Castaic', 'Castac,Castaic,Kastejik,Кастејик', 34.4888800, -118.6228700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144072, 'Castro Valley', 'Castro Valley', 'Castro Valley,Kastro Vali,kaeseuteulobaelli,kyastro bhyali,Кастро Вали,क्यास्ट्रो भ्याली,캐스트로밸리', 37.6941000, -122.0863500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144073, 'Castroville', 'Castroville', 'Castroville,Del Monte Junction,Kastrovil,kyastrobhila,Кастровил,क्यास्ट्रोभिल', 36.7657900, -121.7580000, 'US', '2015-06-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144074, 'Cathedral City', 'Cathedral City', 'Katidral Siti,Katidral-Siti,Kutidrul Siti,Lungsod ng Cathedral,da jiao tang cheng,kathydral syty,ktdral syty  kalyfrnya,kyathedrala siti,Катидрал Сити,Катидрал-Сити,Кътидръл Сити,كاثيدرال سيتي,کتدرال سیتی، کالیفرنیا,क्याथेड्रल सिटी,大教堂城', 33.7797400, -116.4652900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144075, 'Cayucos', 'Cayucos', '', 35.4427500, -120.8921300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144076, 'Cedar Ridge', 'Cedar Ridge', '', 38.0657600, -120.2768600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144077, 'Ceres', 'Ceres', 'Cerera,Sirijz,Siriz,krs  kalyfrnya,siresa,syrys,xi li si,Сириз,Сирийз,Церера,سيريس,کرس، کالیفرنیا,सीरेस,锡里斯', 37.5949300, -120.9577100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144078, 'Century City', 'Century City', 'Senchuri Siti,Сенчъри Сити,سنچری سیتی، لس‌آنجلس', 34.0555700, -118.4178600, 'US', '2012-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144079, 'Cerritos', 'Cerritos', 'Cerritos,Dairy Valley,Seritos,Serritos,krytws  kalyfrnya,selitoseu,seritoja,syrrytws,xi rui dou,Серитос,Серритос,سيرريتوس,کریتوس، کالیفرنیا,सेरिटोज,喜瑞都,세리토스', 33.8583500, -118.0647900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144080, 'Channel Islands Beach', 'Channel Islands Beach', '', 34.1580600, -119.2231600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144081, 'Charter Oak', 'Charter Oak', '', 34.1030600, -117.8458900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144082, 'Chatsworth', 'Chatsworth', '', 34.2572300, -118.6012000, 'US', '2012-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144083, 'Cherry Valley', 'Cherry Valley', '', 33.9725200, -116.9772500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144084, 'Cherryland', 'Cherryland', '', 37.6793800, -122.1033000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144085, 'Chico', 'Chico', 'CIC,Chico,Chiko,chiko,chykw,chykw  kalyfrnya,ciko,qi ke,tshykw,Чико,Чіко,Չիքո,تشيكو,چیکو,چیکو، کالیفرنیا,चिको,チコ,奇科,치코', 39.7284900, -121.8374800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144086, 'China Lake Acres', 'China Lake Acres', '', 35.6405100, -117.7639500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144087, 'Chino', 'Chino', 'CNO,Chino,chino,chynw,chynw  kalyfrnya,qi nuo,sino,tshynw,Чино,Чіно,تشينو,چینو,چینو، کالیفرنیا,शिनो,チノ,奇诺,치노', 34.0122300, -117.6889400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144088, 'Chino Hills', 'Chino Hills', '', 33.9938000, -117.7588800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144089, 'Chowchilla', 'Chowchilla', '', 37.1230000, -120.2601800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144090, 'Chualar', 'Chualar', '', 36.5705200, -121.5185500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144091, 'Chula Vista', 'Chula Vista', 'Chula Vista,Chula-Vista,Chulavista,Cula Vista,chullabiseuta,churabisuta,chwla wsta,chwla wysta  kalyfrnya,cula bhista,qiu la wei si ta,tshwla fysta,zwlh wysth,Čula Vista,Чула Виста,Чула-Виста,Чула-Віста,צולה ויסטה,تشولا فيستا,چولا وستا,چولا ویستا، کالیفرنیا,चुला भिस्टा,チュラビスタ,丘拉維斯塔,출라비스타', 32.6400500, -117.0842000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144092, 'Citrus', 'Citrus', '', 34.1150100, -117.8917300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144093, 'Citrus Heights', 'Citrus Heights', 'Citrus Heights,Sitrus Khajts,gan ju gao de,sa''itrasa ha''itsa,sytrws hayts  kalyfrnya,sytrws hyayts,Ситрус Хајтс,Ситръс Хайтс,سيتروس هيايتس,سٹرس ہائٹس,سیتروس هایتس، کالیفرنیا,साइट्रस हाइट्स,柑橘高地', 38.7071200, -121.2810600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144094, 'Claremont', 'Claremont', 'Klermont,Kleurmont,ke lai meng te,keulleeomonteu,klarymwnt,kleramonta,klrmwnt  kalyfrnya,kureamonto,Клермонт,Клеърмонт,كلاريمونت,کلرمونت، کالیفرنیا,क्लेरमोन्ट,クレアモント,克莱蒙特,클레어몬트', 34.0966800, -117.7197800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144095, 'Clay', 'Clay', '', 38.3360200, -121.1593900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144096, 'Clayton', 'Clayton', 'Clayton,Clayton''s,Claytonville,Deadfall,Klejton,Klejtun,ke lai dun,klaytwn,kletana,klytwn  kalyfrnya,kureiton,qlyytwn,Клейтън,Клејтон,קלייטון,كلايتون,کلیتون، کالیفرنیا,क्लेटन,クレイトン,克莱顿', 37.9410300, -121.9357900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144097, 'Clear Lake Riviera', 'Clear Lake Riviera', '', 38.9540600, -122.7208200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144098, 'Clearlake', 'Clearlake', 'Klijrlejk,Klirlejk,ke li er lei ke,kliyaraleka,klyrlaky,klyrlyk  kalyfrnya,kuriareiku,Клийрлейк,Клирлејк,كليرلاكي,کلیرلیک، کالیفرنیا,क्लियरलेक,クリアレイク,克里尔雷克', 38.9582300, -122.6263700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144099, 'Clearlake Oaks', 'Clearlake Oaks', 'Clear Lake Oaks,Clearlake Oaks,Stubbs', 39.0262800, -122.6719300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144100, 'Cloverdale', 'Cloverdale', 'Cloverdale,Kloverdejl,Klovurdejl,Markle Place,Markle''s Place,Markleville,ke luo fu dai er,klobharadela,klwfyrdaly,klwwrdyl  kalyfrnya,Кловердејл,Кловърдейл,كلوفيردالي,کلووردیل، کالیفرنیا,क्लोभरडेल,克罗弗戴尔', 38.8054600, -123.0172200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144101, 'Clovis', 'Clovis', 'Clovis,Klovis,ke luo wei si,keullobiseu,klobhisa,klwfys,klwws,klwwys  kalyfrnya,kurovu~isu,Кловис,كلوفيس,کلووس,کلوویس، کالیفرنیا,क्लोभिस,クローヴィス,克洛维斯,클로비스', 36.8252300, -119.7029200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144102, 'Coachella', 'Coachella', 'Coachella,Kochela,Kouchela,Woodspur,ke qie la,ko''asella,kochella,kwatshyla,kwchla  kalyfrnya,Коучела,Кочела,كواتشيلا,کوچلا، کالیفرنیا,कोआशेल्ला,科切拉,코첼라', 33.6803000, -116.1738900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144103, 'Coalinga', 'Coalinga', 'CLG,Coaling Station,Coalinga,Coalinga Station,Coalingo,Koalinga,ke ling jia,ko''alinga,kwalyngha,kwlynga  kalyfrnya,Коалинга,كوالينغا,کولینگا، کالیفرنیا,कोआलिंगा,科灵加', 36.1396800, -120.3601500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144104, 'Coarsegold', 'Coarsegold', 'Coarse Gold,Coarsegold,Gold Gulch,Michaels,Oro Grosso,Texas Flat', 37.2621700, -119.7009800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144105, 'Cobb', 'Cobb', '', 38.8221300, -122.7230500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144106, 'Colfax', 'Colfax', 'Alden Grove,Alder Grove,Colfax,Illinoistown,Kolfaks,Upper Corral,ke er fa ke si,kolphyaksa,kwlfaks,kwlfaks  kalyfrnya,Колфакс,كولفاكس,کولفاکس، کالیفرنیا,कोल्फ्याक्स,科爾法克斯', 39.1007300, -120.9532800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144107, 'Collierville', 'Collierville', '', 38.2146400, -121.2688400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144108, 'Colma', 'Colma', 'Colma,Kolma,School House Station,Sutter''s Fort,Sutter''s Mill,ke er ma,kolma,kwlma,kwlma  kalyfrnya,Колма,كولما,کولما، کالیفرنیا,कोल्मा,科尔马', 37.6768800, -122.4596900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144109, 'Colton', 'Colton', 'Kolton,Koltun,ke er dun,koltana,kolteon,kwltwn,kwltwn  kalyfrnya,Колтон,Колтън,كولتون,کولتون، کالیفرنیا,کولٹن، کیلیفورنیا,कोल्टन,科尔顿,콜턴', 34.0739000, -117.3136500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144110, 'Columbia', 'Columbia', 'COA,Columbia,Columbia Diggings,Hildreth''s Diggings,Kolambija,Kolumbija,kolambiya,kwlmbya  kylyfwrnya,Коламбија,Колумбия,کولمبیا، کیلیفورنیا,कोलम्बिया', 38.0363100, -120.4013100, 'US', '2017-07-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144111, 'Colusa', 'Colusa', 'Colusa,Colusi,Colusi''s,Kolusa,Koluza,Koru,Salmon Bend,ke lu sa,kolusa,korusa,kwlwsa,kwlwsa  kalyfrnya,Колуза,Колуса,كولوسا,کولوسا، کالیفرنیا,कोलुसा,コルサ,科卢萨', 39.2143300, -122.0094200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144112, 'Commerce', 'Commerce', 'City of Commerce,Komers,Kommers,Komurs,kamarsa,kamrs  kalyfrnya,kamrs  kylyfwrnya,ke mo si,syty awf kwmyrsy,Комерс,Коммерс,Комърс,سيتي أوف كوميرسي,کامرس، کالیفرنیا,کامرس، کیلیفورنیا,कमर्स,科默斯', 34.0005700, -118.1597900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144113, 'Compton', 'Compton', 'Compton,Kompton,Komptun,kamptana,kamptwn  kalyfrnya,kang pu dun,kompeuteon,konputon,kwmbtwn,qwmptwn,Комптон,Комптън,קומפטון,كومبتون,کامپتون، کالیفرنیا,کامپٹن، کیلیفورنیا,کیمپٹن,कम्प्टन,コンプトン,康普顿,콤프턴', 33.8958500, -118.2200700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144114, 'Concord', 'Concord', 'CCR,Concord,Drunken Indian,Konkord,Todos Santos,kang ke de,kankarda,kankwrd  kalyfrnya,konkodo,kwnkwrd,qwnqwrd,Конкорд,קונקורד,كونكورد,کانکورد، کالیفرنیا,کونکورڈ,کونکورڈ، کیلیفورنیا,कन्कर्ड,コンコード,康科德', 37.9779800, -122.0310700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144115, 'Copperopolis', 'Copperopolis', 'Koperopolis,kaparopolisa,Коперополис,कपरोपोलिस', 37.9810400, -120.6418700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144116, 'Corcoran', 'Corcoran', 'CRO,Korkoran,ke ke lun,kokoran,korkorana,kwrkwran,kwrkwran  kalyfrnya,Коркоран,كوركوران,کورکوران، کالیفرنیا,कोर्कोरान,コーコラン,科克伦', 36.0980100, -119.5604000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144117, 'Corning', 'Corning', 'Korning,kang ning,karninga,kwrnyng  kalyfrnya,kwrnyngh,Корнинг,كورنينغ,کورنینگ، کالیفرنیا,कर्निंग,康宁', 39.9276600, -122.1791600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144118, 'Corona', 'Corona', 'Circle City,Corona,Korona,South Riverside,ke luo na,kolona,korona,kwrwna,kwrwna  kalyfrnya,Корона,كورونا,کورونا,کورونا، کالیفرنیا,कोरोना,コロナ,科洛納,코로나', 33.8752900, -117.5664400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144119, 'Coronado', 'Coronado', 'Coronado,Koronado,Poppy City,South Island,ke luo na duo,koron''yado,kwrwnadw,kwrwnadw  kalyfrnya,Коронадо,كورونادو,کورونادو، کالیفرنیا,कोरोन्याडो,科罗纳多', 32.6858900, -117.1830900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144120, 'Corralitos', 'Corralitos', 'Corallitas,Corralitos', 36.9885600, -121.8063400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144121, 'Corte Madera', 'Corte Madera', 'Korte Madera,ke te ma de la,korte madera,kwrt madra  kalyfrnya,kwrt madyra,Корте Мадера,كورت ماديرا,کورت مادرا، کالیفرنیا,कोर्ते मदेरा,科特马德拉', 37.9254800, -122.5274800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144122, 'Costa Mesa', 'Costa Mesa', 'Costa Mesa,Costa Mesa (Orange County),Fairview,Goat Hill,Harper,Kosta Mesa,Kosta-Mesa,Thurin,ke si ta mei sa,kosta mesa,kosutamesa,kwsta msa  kalyfrnya,kwsta mysa,Коста Меса,Коста-Меса,كوستا ميسا,کوستا مسا، کالیفرنیا,کوسٹا میسا,कोस्टा मेसा,コスタメサ,科斯塔梅薩', 33.6411300, -117.9186700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144123, 'Cotati', 'Cotati', 'Cotati,Kotati,Page''s Station,kotati,kwtaty  kalyfrnya,kwtaty  swnwma  kalyfwrnya,Котати,كوتاتي، سونوما، كاليفورنيا,کوتاتی، کالیفرنیا,कोटाटी', 38.3268600, -122.7072100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144124, 'Coto De Caza', 'Coto De Caza', 'Coto de Caza', 33.6041900, -117.5869900, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144125, 'Cottonwood', 'Cottonwood', '', 38.6582400, -121.9710800, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144126, 'Country Club', 'Country Club', '', 37.9688100, -121.3407800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144127, 'Covelo', 'Covelo', '', 39.7932700, -123.2492200, 'US', '2015-01-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144128, 'Covina', 'Covina', 'Kovina,ke wen na,kobhina,kobina,kwfyna,kwwyna  kalyfrnya,qwbynh,Ковина,Ковіна,קובינה,كوفينا,کووینا، کالیفرنیا,कोभिना,柯汶纳,코비나', 34.0900100, -117.8903400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144129, 'Crest', 'Crest', '', 32.8072700, -116.8680800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144130, 'Crestline', 'Crestline', '', 34.2419500, -117.2856000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144131, 'Crockett', 'Crockett', 'Crockett,Crockettville,Kroket,kraketa,Крокет,क्रकेट', 38.0524200, -122.2130200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144132, 'Cudahy', 'Cudahy', 'Kadagi,Kadakhej,Kadakhi,Kudukhij,ka de xi,kudahi,kwdahy,kwdahy  kalyfrnya,Кадагі,Кадахеј,Кадахи,Къдъхий,كوداهي,کوداهی، کالیفرنیا,کیڈاہی، کیلیفورنیا,कुदाही,卡德希', 33.9605700, -118.1853500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144133, 'Culver City', 'Culver City', 'CVR,Culver,Culver City,Kalver Siti,Kalver-Siti,Kulvur Siti,ka er fu cheng,kalbhara siti,kalwr syty  kalyfrnya,karubashiti,keolbeositi,kwlfr syty,Калвер Сити,Калвер-Сити,Калвер-Сіті,Кълвър Сити,كولفر سيتي,کالور سیتی، کالیفرنیا,कल्भर सिटी,カルバーシティ,卡尔弗城,컬버시티', 34.0211200, -118.3964700, 'US', '2017-07-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144134, 'Cupertino', 'Cupertino', 'Cupertino,Kupertino,ku bi di nuo,kupachino,kupartino,kupeotino,kwbyrtynw,kwprtynw  kalyfrnya,kyuparatino,qwprtynw,Купертино,Купертіно,קופרטינו,كوبيرتينو,کوپرتینو، کالیفرنیا,کپرٹینو,कुपर्तिनो,कूपर्टीनो,क्युपरटिनो,クパチーノ,庫比蒂諾,쿠퍼티노', 37.3230000, -122.0321800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144135, 'Cutler', 'Cutler', '', 36.5232800, -119.2867800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144136, 'Cypress', 'Cypress', 'Cypress,Sajpres,Sajprus,Sipres,Waterville,kyprs  kalyfrnya,sa''ipresa,sai pu li si,saipeuleoseu,saybrys,Сайпръс,Сајпрес,سايبريس,کیپرس، کالیفرنیا,साइप्रेस,赛普里斯,사이프러스', 33.8169600, -118.0372900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144137, 'Daly City', 'Daly City', 'Daly City,Dalyurbo,Dejli Siti,Dejli-Siti,Lungsod ng Daly,Thanh pho Daly,Thành phố Daly,dai li cheng,daly syty,deillisiti,deirishiti,deli siti,dyly syty  kalyfrnya,Дейли Сити,Дейли-Сити,Дејли Сити,دالي سيتي,دیلی سیتی، کالیفرنیا,ڈالی سٹی,ڈالی سٹی، کیلیفورنیا,डेली सिटी,デイリーシティ,戴利城,데일리시티', 37.7057700, -122.4619200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144138, 'Dana Point', 'Dana Point', 'Dejna Pojnt,da na dian,dana bwynt,dana po''inta,dana pwynt  kalyfrnya,deinapointeu,Дейна Пойнт,Дејна Појнт,دانا بوينت,دانا پوینت، کالیفرنیا,डाना पोइन्ट,达纳点,데이나포인트', 33.4669700, -117.6981100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144139, 'Danville', 'Danville', 'Danvil,daenbil,dan wei er,dan wyl  kalyfrnya,danbiru,danfyl,dyanabhila,Данвил,دان ویل، کالیفرنیا,دانفيل,ड्यानभिल,ダンビル,丹维尔,댄빌', 37.8215900, -121.9999600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144140, 'Davis', 'Davis', 'Davies,Davis,Davisville,Dejvis,Devis,dafys,dai wei si,debhisa,deibiseu,deibisu,dywys  kalyfrnya,Девіс,Дейвис,Дејвис,دافيس,دیویس، کالیفرنیا,ڈیوس، کیلیفورنیا,डेभिस,デイビス,戴維斯,데이비스', 38.5449100, -121.7405200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144141, 'Day Valley', 'Day Valley', '', 37.0357800, -121.8624600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144142, 'Deer Park', 'Deer Park', '', 38.6818500, -120.8232700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144143, 'Deer Park', 'Deer Park', '', 38.5326900, -122.4697000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144144, 'Del Mar', 'Del Mar', 'Del Mar,de er ma,dela mara,dl mar  kalyfrnya,dyl mar,Дел Мар,دل مار، کالیفرنیا,ديل مار,डेल मार,デル・マー,德尔马', 32.9594900, -117.2653100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144145, 'Del Monte Forest', 'Del Monte Forest', '', 36.5863500, -121.9474600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144146, 'Del Aire', 'Del Aire', '', 33.9161300, -118.3695200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144147, 'Del Rey', 'Del Rey', 'Clifton,Del Rey', 36.6591200, -119.5937400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144148, 'Del Rey Oaks', 'Del Rey Oaks', 'Del Rej Ouks,Del Rey Oaks,Del Rey Woods,dela re oksa,dl ry awkz  kalyfrnya,dyl ry awaks,Дел Рей Оукс,Дел Реј Оукс,دل ری اوکز، کالیفرنیا,ديل ري أواكس,डेल रे ओक्स', 36.5932900, -121.8349500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144149, 'Del Rio', 'Del Rio', '', 37.7435400, -121.0118800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144150, 'Delano', 'Delano', 'Delano,Delejno,de la nuo,delyano,dlanw  kalyfrnya,dylanw,Делано,Делејно,دلانو، کالیفرنیا,ديلانو,डेल्यानो,德拉诺', 35.7688400, -119.2470500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144151, 'Delhi', 'Delhi', '', 37.4321600, -120.7785400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144152, 'Denair', 'Denair', 'Denair,Elmdale,Elmwood Colony', 37.5263200, -120.7968700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144153, 'Descanso', 'Descanso', '', 32.8528300, -116.6158500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144154, 'Desert Hot Springs', 'Desert Hot Springs', 'Dezert Khot Springs,Dezert-Got-Springs,Dezert-Khot-Springs,Dezurt Khot Springs,dejarta hata springas,dysyrt hwt sbrynghs,dzrt hat aspryngz  kalyfrnya,sha mo wen quan,Дезерт Хот Спрингс,Дезерт-Гот-Спрінґс,Дезерт-Хот-Спрингс,Дезърт Хот Спрингс,دزرت هات اسپرینگز، کالیفرنیا,ديسيرت هوت سبرينغس,डेजर्ट हट स्प्रिङ्गस्,沙漠温泉', 33.9617300, -116.5035300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144155, 'Desert Shores', 'Desert Shores', 'Desert Shores,Fish Springs', 33.4042000, -116.0397200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144156, 'Desert View Highlands', 'Desert View Highlands', '', 34.5908200, -118.1525700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144157, 'Diablo', 'Diablo', '', 37.8349300, -121.9580100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144158, 'Diamond Bar', 'Diamond Bar', 'Dajmond Bar,Dajmond-Bar,Dajmund Bar,dayamanda bara,dyamwnd bar,dyamwnd bar  kalyfrnya,zuan shi ba,Даймонд-Бар,Даймънд Бар,Дајмонд Бар,دياموند بار,دیاموند بار، کالیفرنیا,डायमन्ड बार,钻石吧', 34.0286200, -117.8103400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144159, 'Diamond Springs', 'Diamond Springs', 'Diamond,Diamond Spring,Diamond Springs', 38.6946300, -120.8149400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144160, 'Dinuba', 'Dinuba', 'Dajnuba,Dinjuba,Dinuba,Sibleyville,di niu ba,dinuba,dynwba,dynwba  kalyfrnya,Дајнуба,Динюба,دينوبا,دینوبا، کالیفرنیا,डिनुबा,迪纽巴', 36.5432800, -119.3870700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144161, 'Discovery Bay', 'Discovery Bay', '', 37.9085400, -121.6002300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144162, 'Dixon', 'Dixon', 'Dickson,Dikson,Diksun,Dixon,di ke xun,diksana,dykswn,dykswn  kalyfrnya,Диксон,Диксън,ديكسون,دیکسون، کالیفرنیا,ڈکسن، کیلیفورنیا,डिक्सन,狄克逊', 38.4454600, -121.8233000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144163, 'Dogtown', 'Dogtown', '', 38.2138100, -121.0885500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144164, 'Dollar Point', 'Dollar Point', '', 39.1879600, -120.0999100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144165, 'Dos Palos', 'Dos Palos', 'Dos Palos,Dospalos,dosa palosa,duo si pa luo si,dws balws,dws palws  kalyfrnya,Дос Палос,دوس بالوس,دوس پالوس، کالیفرنیا,दोस पालोस,多斯帕洛斯', 36.9860600, -120.6265700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144166, 'Downey', 'Downey', 'Dauni,Daunis,Davni,Downey,da''uni,dauni,dawny,dwny  kalyfrnya,tang ni,Давні,Дауни,داوني,دونی، کالیفرنیا,ڈاؤنی,डाउनी,ダウニー,唐尼,다우니', 33.9400100, -118.1325700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144167, 'Downieville', 'Downieville', 'Downeyville,Downieville,The Forks,Washingtonville', 39.5593400, -120.8268900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144168, 'Duarte', 'Duarte', 'Duarte,Duarti,Dvarti,du a er te,du''arte,durarte,dwarth  kalyfrnya,dwarty,Дварти,Дуарте,Дуарти,Дуарті,دوآرته، کالیفرنیا,دوارتي,डुरार्टे,दुआर्ते,杜阿尔特', 34.1394500, -117.9772900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144169, 'Dublin', 'Dublin', 'Amador,Dablin,Dougherty''s Station,Dublin,dablina,deobeullin,dou bo lin,dwblyn,dwblyn  kalyfrnya,Даблин,Дублин,Дублін,Дъблин,دوبلين,دوبلین، کالیفرنیا,ڈبلن، کیلیفورنیا,डब्लिन,都伯林,더블린', 37.7021500, -121.9357900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144170, 'Dunnigan', 'Dunnigan', 'Antelope,Dunnigan', 38.8851800, -121.9696900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144171, 'Durham', 'Durham', 'Darem,Durham,Durham Station,Дарем', 39.6462700, -121.7999800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144172, 'Earlimart', 'Earlimart', 'Alila,Earlimart', 35.8841200, -119.2723300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144173, 'East Rancho Dominguez', 'East Rancho Dominguez', 'East Compton', 33.8980700, -118.1953500, 'US', '2012-06-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144174, 'East Foothills', 'East Foothills', '', 37.3810500, -121.8174500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144175, 'East Hemet', 'East Hemet', '', 33.7400200, -116.9389100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144176, 'East La Mirada', 'East La Mirada', '', 33.9244600, -117.9889500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144177, 'East Los Angeles', 'East Los Angeles', 'East Los Angeles,Este de Los Angeles,Este de Los Ángeles,Ist Los Andzeles,Orienta Losangeleso,Orienta Losanĝeleso,dong luo shan ji,iseuteuloseuaenjelleseu,ista lasa enjelsa,isutorosanzerusu,Ист Лос Анџелес,इस्ट लस एन्जेल्स,イーストロサンゼルス,东洛杉矶,이스트로스앤젤레스', 34.0239000, -118.1720200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144178, 'East Oakdale', 'East Oakdale', '', 37.7879800, -120.8038200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144179, 'East Palo Alto', 'East Palo Alto', 'Aslagang Palo Alto,East Palo Alto,Ist Palo Alto,Ist-Palo-Al''to,Iztochen Palo Alto,Ravenswood,Silangang Palo Alto,aast balw altw,ayst palw altw  kalyfrnya,dong pa luo ao tu,ista palo alto,Іст-Пало-Альто,Източен Пало Алто,Ист Пало Алто,إاست بالو ألتو,ایست پالو آلتو، کالیفرنیا,مشرقی پالو آلٹو، کیلیفورنیا,इस्ट पालो अल्टो,东帕罗奥图', 37.4688300, -122.1410800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144180, 'East Pasadena', 'East Pasadena', '', 34.1381400, -118.0738400, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144181, 'East Porterville', 'East Porterville', '', 36.0574500, -118.9756600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144182, 'East Quincy', 'East Quincy', '', 39.9340600, -120.8980100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144183, 'East Richmond Heights', 'East Richmond Heights', '', 37.9449200, -122.3135800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144184, 'East San Gabriel', 'East San Gabriel', '', 34.0916800, -118.0911800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144185, 'East Sonora', 'East Sonora', '', 37.9777000, -120.3613000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144186, 'Easton', 'Easton', 'Covell,Easton,Iston,Истон', 36.6502300, -119.7907000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144187, 'El Cajon', 'El Cajon', 'CJN,Ehl''-Kakhon,El Cajon,El Cajón,El Kakhon,Elcajon,ai er ka hong,al kajwn,al kajwn  kalyfrnya,alkahwn,ela kyayom,elkahon,erukahon,Ел Кахон,Эль-Кахон,ال کاجون,ال کاجون، کالیفرنیا,الكاهون,एल क्यायों,エルカホン,埃尔卡洪,엘카혼', 32.7947700, -116.9625300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144188, 'El Centro', 'El Centro', 'Cabarker,Ehl''-Sentro,El Centras,El Centro,El Sentro,ai er sen te luo,al sntrw,al sntrw  kalyfrnya,ela sentro,elsenteulo,Ел Сентро,Эль-Сентро,אל סנטרו,إل سنترو,ال سنترو، کالیفرنیا,एल सेन्ट्रो,エル・セントロ,埃尔森特罗,엘센트로', 32.7920000, -115.5630500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144189, 'El Cerrito', 'El Cerrito', 'County Line,El Cerito,El Cerrito,El Serito,Rust,ai er sai li tuo,al srytw  kalyfrnya,al syrrytw,ela serito,erusarito,Ел Серито,إل سيرريتو,ال سریتو، کالیفرنیا,एल सेरिटो,エルサリート,艾尔赛里托', 37.9157600, -122.3116400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144190, 'El Cerrito', 'El Cerrito', '', 33.8405700, -117.5228300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144191, 'El Dorado Hills', 'El Dorado Hills', '', 38.6857400, -121.0821700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144192, 'El Granada', 'El Granada', '', 37.5027200, -122.4694200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144193, 'El Monte', 'El Monte', 'EMT,Ehl''-Monte,El Monte,El Monti,El Montė,Elmonte,Monte,ai er meng de,al mwnth  kalyfrnya,al mwnty,ela monte,erumonte,Ел Монте,Ел Монти,Эль-Монте,إل مونتي,ال مونته، کالیفرنیا,ال مونٹی,एल मोन्ते,エルモンテ,艾爾蒙地', 34.0686200, -118.0275700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144194, 'El Rio', 'El Rio', 'El Rio,El Río,Elrio,Jerusalem,New Jerusalem,ela riyo,Ел Рио,एल रियो', 34.2357800, -119.1638300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144195, 'El Segundo', 'El Segundo', 'El Segundo,El''-Segundo,ai er sai gong duo,al sghwndw,al sgwndw  kalyfrnya,ela segundo,Ел Сегундо,Ель-Сегундо,إل سغوندو,ال سگوندو، کالیفرنیا,एल सेगुन्दो,埃尔塞贡多', 33.9191800, -118.4164700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144196, 'El Sobrante', 'El Sobrante', 'El Sobrante,Sobrante,ela sobrante,Ел Собранте,एल सोब्रान्ते', 37.9771500, -122.2952500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144197, 'El Verano', 'El Verano', '', 38.2976900, -122.4916500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144198, 'Eldridge', 'Eldridge', '', 38.3488000, -122.5108100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144199, 'Elk Grove', 'Elk Grove', 'Ehlk-Grov,Elk Grouv,Elk Grove,Elk-Grouv,Elkgrove,ai er ke ge luo fu,al kgrww  kalyfrnya,alk ghrwfy,alk grww,elka grobha,elkeugeulobeu,erukugurobu,Елк Гроув,Елк-Ґроув,Элк-Гров,إلك غروفي,ال کگروو، کالیفرنیا,الک گروو,एल्क ग्रोभ,エルクグローブ,埃爾克格羅夫,엘크그로브', 38.4088000, -121.3716200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144200, 'Elkhorn', 'Elkhorn', '', 36.8244000, -121.7405000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144201, 'Elverta', 'Elverta', '', 38.7137900, -121.4627300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144202, 'Emerald Lake Hills', 'Emerald Lake Hills', '', 37.4646600, -122.2680200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144203, 'Emeryville', 'Emeryville', 'Emerivil,Emerivill,Emerivill'',Emeryville,Golden Gate Village,JEM,ai mo li wei er,amry wyl  kalyfrnya,amyryfyly,emeolibil,emeribhila,emeribiru,Емеривил,Емерівілль,إميريفيلي,امری ویل، کالیفرنیا,एमेरीभिल,エメリービル,愛莫利維爾,에머리빌', 37.8313200, -122.2852500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144204, 'Empire', 'Empire', 'Empire,Empire City', 37.6382600, -120.9021500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144205, 'Encinitas', 'Encinitas', 'Ehnsinitas,Encenitos,Encinitas,Encinitos,Ensinitas,ansynytas,ansynytas  kalyfrnya,en xi ni ta si,ensinitasa,ensiniteoseu,Енсинитас,Енсінітас,Энсинитас,إنسينيتاس,انسینیتاس، کالیفرنیا,एन्सिनितास,恩西尼塔斯,엔시니터스', 33.0369900, -117.2919800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144206, 'Escalon', 'Escalon', '', 37.7978100, -120.9979200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144207, 'Escondido', 'Escondido', 'Apex,Ehskondido,Escondido,Eskondidas,Eskondido,ai si kong di duo,askandydw  kalyfrnya,askwndydw,eseukondido,eskandido,esukondido,Ескондидо,Эскондидо,إسكونديدو,اسکاندیدو، کالیفرنیا,اسکونڈیڈو,एस्कन्डिडो,エスコンディード,埃斯孔迪多,에스콘디도', 33.1192100, -117.0864200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144208, 'Esparto', 'Esparto', 'Esparto,Esperanza', 38.6921300, -122.0171900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144209, 'Eucalyptus Hills', 'Eucalyptus Hills', '', 32.8797700, -116.9466900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144210, 'Exeter', 'Exeter', 'Ekseter,Eksitur,Exeter,Firebaugh,ai ke sai te,akstr  kalyfrnya,aksytyr,ekstara,Ексетер,Екситър,إكسيتير,اکستر، کالیفرنیا,एक्स्टर,埃克塞特', 36.2960600, -119.1420500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144211, 'Fair Oaks', 'Fair Oaks', 'Fair Oaks,Fairoaks,Fer Ouks,fyyr awks  kylyfwrnya,pheyara oksa,Фер Оукс,فیئر اوکس، کیلیفورنیا,फेयर ओक्स', 38.6446300, -121.2721700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144212, 'Fairbanks Ranch', 'Fairbanks Ranch', '', 32.9939300, -117.1872600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144213, 'Fairfax', 'Fairfax', 'Ferfaks,Feurfaks,fei er fa ke si,fyrfaks,fyrfaks  kalyfrnya,fyyrfyks  kylyfwrnya,pheyaraphyaksa,Ферфакс,Феърфакс,فيرفاكس,فیئرفیکس، کیلیفورنیا,فیرفاکس، کالیفرنیا,फेयरफ्याक्स,费尔法克斯', 37.9871500, -122.5888700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144214, 'Fairfield', 'Fairfield', 'Fairfield,Fehrfild,Fejrfild,Ferfild,Ferfildas,Feurfijld,SUU,feafirudo,fei er fei er de,fyrfyld,fyrfyld  kalyfrnya,peeopildeu,pheyaraphilda,Фейрфілд,Ферфилд,Феърфийлд,Фэрфилд,فئرفیلڈ,فيرفيلد,فیئرفیلڈ، کیلیفورنیا,فیرفیلد، کالیفرنیا,फेयरफिल्ड,フェアフィールド,費爾菲爾德,페어필드', 38.2493600, -122.0399700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144215, 'Fairmead', 'Fairmead', '', 37.0763300, -120.1929500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144216, 'Fairview', 'Fairview', '', 37.6785400, -122.0458000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144217, 'Fallbrook', 'Fallbrook', 'Fall Brook,Fallbrook,Folbruk,North Fallbrook,falbrwk  kylyfwrnya,phalabruka,Фолбрук,فالبروک، کیلیفورنیا,फलब्रूक', 33.3764200, -117.2511500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144218, 'Farmersville', 'Farmersville', 'Farmersvil,Farmursvil,fa mo si wei er,farmrz wyl  kalyfrnya,farmyrsfyly,pharmarsabhila,Фармерсвил,Фармърсвил,فارمرز ویل، کالیفرنیا,فارميرسفيلي,फार्मर्सभिल,法默斯维尔', 36.2977300, -119.2067800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144219, 'Felton', 'Felton', 'Felton,Felton Depot,Felton Junction,Felton Station,Feltun,pheltana,Фелтон,Фелтън,فیلٹن، کیلیفورنیا,फेल्टन', 37.0513400, -122.0733000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144220, 'Firebaugh', 'Firebaugh', 'Fajerbo,Fajurbou,Firebaugh,Firebaugh''s Ferry,fa er bo,fayr baw  kalyfrnya,fayrbawgh,phayarabau,Файърбоу,Фајербо,فايرباوغ,فایر باو، کالیفرنیا,फायरबौ,法尔博', 36.8588400, -120.4560100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144221, 'Florin', 'Florin', 'Florin,Флорин', 38.4960200, -121.4088400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144222, 'Folsom', 'Folsom', 'Folsom,Folsom City,Folsum,fu sen,fwlswm,fwlswm  kalyfrnya,pholsama,Фолсом,Фолсъм,فولسوم,فولسوم، کالیفرنیا,फोल्सम,佛森', 38.6779600, -121.1760600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144223, 'Fontana', 'Fontana', 'Fontana,Rosena,fang ta na,fontana,fwntana,fwntana  kalyfrnya,phontana,pontaena,Фонтана,فونتانا,فونتانا، کالیفرنیا,فونٹانا,فونٹانا، کیلیفورنیا,फोन्टाना,フォンタナ,方塔納,폰태나', 34.0922300, -117.4350500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144224, 'Foothill Farms', 'Foothill Farms', '', 38.6787700, -121.3511400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144225, 'Foothill Ranch', 'Foothill Ranch', '', 33.6864100, -117.6608800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144226, 'Ford City', 'Ford City', '', 35.1544100, -119.4562300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144227, 'Forest Meadows', 'Forest Meadows', '', 38.1685100, -120.4065900, 'US', '2015-01-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144228, 'Forest Ranch', 'Forest Ranch', '', 39.8821100, -121.6727500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144229, 'Foresthill', 'Foresthill', 'Forest Hill,Foresthill', 39.0201800, -120.8179900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144230, 'Forestville', 'Forestville', 'Forestvil,Forestville,Forrestville,pharestabhila,Форествил,फरेस्टभिल', 38.4735200, -122.8902700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144231, 'Fort Bragg', 'Fort Bragg', 'FOB,Fort Brag,Fort-Breg,Fort-Brehgg,bu la ge bao,fwrt bragh,fwrt brg  kalyfrnya,pharta bryaga,poteubeulaegeu,Форт Браг,Форт-Бреґ,Форт-Брэгг,فورت براغ,فورت برگ، کالیفرنیا,फर्ट ब्र्याग,布拉格堡,포트브래그', 39.4457200, -123.8052900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144232, 'Fort Irwin', 'Fort Irwin', 'BYS,Camp Irwin,Fort Irwin', 35.2627500, -116.6847500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144233, 'Foster City', 'Foster City', 'Foster Siti,Foster-Siti,Fostur Siti,fosutashiti,fu si te cheng,fwstr syty  kalyfrnya,fwstyr syty,phastara siti,Фостер Сити,Фостер-Сіті,Фостър Сити,فوستر سیتی، کالیفرنیا,فوستير سيتي,فوسٹر سٹی، کیلیفورنیا,फस्टर सिटी,フォスターシティ,福斯特城', 37.5585500, -122.2710800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144234, 'Fountain Valley', 'Fountain Valley', 'Fauntin Vali,Fauntun Vali,Fountain Valley,Talbert,fang quan gu,fantyn wly  kalyfrnya,fwwntyn faly,pauntinbaelli,pha''untena bhyali,Фаунтин Вали,Фаунтън Вали,فانتین ولی، کالیفرنیا,فوونتين فالي,फाउन्टेन भ्याली,芳泉谷,파운틴밸리', 33.7091800, -117.9536700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144235, 'Fowler', 'Fowler', 'Fauler,Faulur,Fowler,Fowler''s Switch,fawlyr,fu lei,fwlr  kalyfrnya,pha''ulara,Фаулер,Фаулър,فاولير,فولر، کالیفرنیا,फाउलर,福勒', 36.6305100, -119.6784700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144236, 'Frazier Park', 'Frazier Park', '', 34.8227600, -118.9448200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144237, 'Freedom', 'Freedom', 'Freedom,Whiskey Hill,Whisky Hill', 36.9352300, -121.7730100, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144238, 'Fremont', 'Fremont', 'Centerville,Centreville,Fremont,Fremontas,Frimont,Hardscrabble,Irvington,Mission San Jose,Nikes,Warm Springs,fei li meng,frymant  kalyfrnya,frymwnt,furimonto,peulimonteu,phremonta,phrimamta,prymwnt,Фремонт,Фримонт,פרימונט,فريمونت,فریمانت، کالیفرنیا,فریمونٹ,فریمونٹ، کیلیفورنیا,फ्रिमाँट,फ्रेमोन्ट,フリーモント,費利蒙,프리몬트', 37.5482700, -121.9885700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144239, 'French Camp', 'French Camp', 'Campo De Los Franceses,Castoria,French Camp', 37.8840900, -121.2710600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144240, 'Fresno', 'Fresno', 'FAT,Fraxinus,Fresnas,Fresno,Fresno i California,Frezno,Gorad Frehsna,fers no,frnsw  kylyfwrnya,frynsw,frysnw,frznw,fu lei si nuo,furezuno,peulejeuno,phresano,phresno,presno,prznw,Φρέσνο,Горад Фрэсна,Фрезно,Фресно,Ֆրեզնո,פרזנו,فرزنو,فرنسو، کیلیفورنیا,فريسنو,فرینسو,फ्रेस्नो,ফ্রেসনো,เฟรสโน,ფრესნო,フレズノ,弗雷斯诺,프레즈노', 36.7477300, -119.7723700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144241, 'Fullerton', 'Fullerton', 'FUL,Fulerton,Fulertonas,Fullerton,Fulurtun,fu lei dun,furaton,fwlrtwn  kalyfrnya,fwlyrtwn,phularatana,Фулертон,Фуллертон,Фулъртън,فلرٹن,فلرٹن، کیلیفورنیا,فولرتون، کالیفرنیا,فوليرتون,फुलरटन,フラートン,富勒顿', 33.8702900, -117.9253400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144242, 'Galt', 'Galt', 'Galt,Golt,galt  kalyfrnya,galta,gao er te,ghalt,Галт,Голт,غالت,گالت، کالیفرنیا,गाल्ट,高尔特', 38.2546400, -121.2999500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144243, 'Garden Acres', 'Garden Acres', '', 37.9638100, -121.2293900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144244, 'Garden Grove', 'Garden Grove', 'Garden Grouv,Garden Grov,Garden Grovas,Garden Grove,Garden-Grov,Gardengrove,Gardun Grouv,gadengurobu,gadeungeulobeu,gardena grobha,gardn grww  kalyfrnya,ghardyn ghrwfy,jia deng ge luo fu,Гарден Гров,Гарден Гроув,Гарден-Гров,Гардън Гроув,غاردين غروفي,گاردن گروو، کالیفرنیا,گارڈن گروو,गार्डेन ग्रोभ,ガーデングローブ,加登格羅夫,가든그로브', 33.7739100, -117.9414500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144245, 'Gardena', 'Gardena', 'Gardena,Gardina,gadena,gardena,gardna  kalyfrnya,ghardyna,jia di na,Гардена,Гардина,غاردينا,گاردنا، کالیفرنیا,गार्डेना,ガーデナ,加迪纳,가데나', 33.8883500, -118.3089600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144246, 'Garnet', 'Garnet', 'Garnet,Gray,Palm Springs,Palms,Pierce,Seven Palms', 33.9019600, -116.5455700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144247, 'Georgetown', 'Georgetown', 'Dzordztaun,Georgetown,Growlersburg,jorjata''una,Џорџтаун,जोर्जटाउन', 38.9068400, -120.8385500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144248, 'Gilroy', 'Gilroy', 'Gilroj,Gilroy,Pleasant Valley,ghylrwy,gilro''i,giruroi,glrwy  kylyfwrnya,gylrwy  kalyfrnya,ji er luo yi,Гилрой,Гилрој,Гілрой,غيلروي,گلروی، کیلیفورنیا,گیلروی، کالیفرنیا,गिल्रोइ,ギルロイ,吉尔罗伊', 37.0057800, -121.5682800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144249, 'Glen Avon', 'Glen Avon', 'Glen Avon,Glen Avon Heights,Glenavon,West Riverside', 34.0116800, -117.4847700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144250, 'Glendale', 'Glendale', 'Glendale,Glendeilas,Glendejl,Glendel,Gorad Glendehjl,JGX,Mason,Riverdale,ge lun dai er,geullendeil,ghlyndyl,glenadela,glndyl,glndyyl,gurenderu,Глендейл,Глендејл,Горад Глендэйл,Ґлендейл,Գլենդել,גלנדייל,غلينديل,گلندیل,گلینڈیل,ग्लेनडेल,グレンデール,格倫代爾,글렌데일', 34.1425100, -118.2550800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144251, 'Glendora', 'Glendora', 'Glendora,ge lun duo la,ghlyndwra,glenadora,glndwra  kalyfrnya,Глендора,غليندورا,گلندورا، کالیفرنیا,ग्लेनडोरा,格伦多拉', 34.1361200, -117.8653400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144252, 'Gold River', 'Gold River', 'Gold River,golda ribhara,Голд Ривер,गोल्ड रिभर', 38.6262900, -121.2466200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144253, 'Golden Hills', 'Golden Hills', '', 35.1424700, -118.4903600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144254, 'Goleta', 'Goleta', 'Goelette,Goleta,Golita,Goélette,Kuunari,La Patera Village,Schoener,Schoner,Schooner,Shkhuna,Skonert,Skonnert,Skonnorta,Skuna,Skuner,Szkuner,ge li ta,ghwlyta,goleta,gorita,gwlyta  kalyfrnya,Škuna,Škuner,Голита,Шхуна,غوليتا,گولیتا، کالیفرنیا,गोलेटा,ゴリータ,戈利塔', 34.4358300, -119.8276400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144255, 'Gonzales', 'Gonzales', 'Gonzales,gang sa lei si,ghwnzalys,gonjaleja,gonjalleoseu,gwnzals  kalyfrnya,Гонзалес,غونزاليس,گونزالس، کالیفرنیا,गोन्जालेज,冈萨雷斯,곤잘러스', 36.5066300, -121.4443800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144256, 'Good Hope', 'Good Hope', '', 33.7647400, -117.2669800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144257, 'Goshen', 'Goshen', 'Goshen,Goshen Junction,Гошен', 36.3510600, -119.4201200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144258, 'Grand Terrace', 'Grand Terrace', 'Grand Teras,Grand Terrace,The Terrace,da lu tai,geulaendeutelaseu,ghrand tyrrasy,grnd tras  kalyfrnya,gryanda teresa,Гранд Терас,غراند تيرراسي,گرند تراس، کالیفرنیا,ग्र्यान्ड टेरेस,大露台,그랜드테라스', 34.0339000, -117.3136500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144259, 'Granite Bay', 'Granite Bay', '', 38.7632300, -121.1638400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144260, 'Granite Hills', 'Granite Hills', '', 32.8031100, -116.9047500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144261, 'Grass Valley', 'Grass Valley', 'Centerville,Centreville,Gras Vali,Grass Valley,Grass-Valli,cao gu,geulaeseubaelli,ghras faly,gras wyly  kylyfwrnya,grasa bhyali,grs wly  kalyfrnya,gurasubare,Грас Вали,Грасс-Валли,غراس فالي,گراس ویلی، کیلیفورنیا,گرس ولی، کالیفرنیا,ग्रास भ्याली,グラスバレー,草谷,그래스밸리', 39.2190600, -121.0610600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144262, 'Graton', 'Graton', 'Graton,Grayton', 38.4363000, -122.8697200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144263, 'Green Acres', 'Green Acres', '', 33.7380800, -117.0764200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144264, 'Green Valley', 'Green Valley', 'Green Valley,La Joya', 34.6216500, -118.4139700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144265, 'Green Valley', 'Green Valley', '', 38.2529700, -122.1621900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144266, 'Greenacres', 'Greenacres', 'Green Acres,Greenacres', 35.3832900, -119.1098300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144267, 'Greenfield', 'Greenfield', 'Delkern,Greenfield,Greenfiled', 35.2688500, -119.0028800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144268, 'Greenfield', 'Greenfield', 'Clarke City,Greenfield,Grijnfijld,Grinfild,ge lin fei er de,ghrynfyld,grinaphilda,grynfyld  kalyfrnya,Грийнфийлд,Гринфилд,غرينفيلد,گرین فیلڈ، کیلیفورنیا,گرینفیلد، کالیفرنیا,ग्रीनफिल्ड,格林菲尔德', 36.3208000, -121.2438100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144269, 'Gridley', 'Gridley', 'Gridley,Gridley Station,Gridli,ge li de li,ghrydly,gridali,grydly  kalyfrnya,Гридли,غريدلي,گریدلی، کالیفرنیا,ग्रिडली,格里德利', 39.3637800, -121.6935800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144270, 'Grover Beach', 'Grover Beach', 'Grouvur Bijch,Grover,Grover Beach,Grover Bich,Grover City,ge luo fu hai tan,ghrwfyr bytsh,grobharabica,grwwr bych  kalyfrnya,Гровер Бич,Гроувър Бийч,غروفير بيتش,گروور بیچ، کالیفرنیا,ग्रोभरबीच,格罗弗海滩', 35.1216400, -120.6212800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144271, 'Guadalupe', 'Guadalupe', 'Guadaloupe,Guadalupe,Gvadalup,ghwadalwby,gua da lu pei,guvadalupa,gwadalwpy  kalyfrnya,Гвадалуп,Гуадалупе,غوادالوبي,گوادالوپی، کالیفرنیا,गुवादालुप,瓜达卢佩', 34.9716400, -120.5718400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144272, 'Guerneville', 'Guerneville', 'Big Bottom,Gernevil,Guerneville,Stumptown,gu''ernabhila,Герневил,गुएर्नभिल', 38.5018600, -122.9961100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144273, 'Gustine', 'Gustine', 'Gastin,Gustajn,gastina,ghwstayn,jastyn  kalyfrnya,jia si ting,Гастин,Гъстайн,جاستین، کالیفرنیا,غوستاين,गस्टिन,加斯廷', 37.2577200, -120.9988200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144274, 'Hacienda Heights', 'Hacienda Heights', 'Khacijenda Khajts,asiendahaicheu,asynda hayts  kalyfrnya,ha xian da gang,hyasi''enda ha''itsa,Хацијенда Хајтс,آسیندا هایتس، کالیفرنیا,ह्यासिएन्डा हाइट्स,哈仙達崗,아시엔다하이츠', 33.9930700, -117.9686800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144275, 'Half Moon Bay', 'Half Moon Bay', 'Half Moon Bay,Halfmoon Bay,Khaf Mun Bej,Khalf Mun Bej,San Benito,San Benitos,Spanish Town,Spanishtown,ban yue wan,haf mwn by,hafumunbei,half mwwn bay,hapha muna be,Халф Мун Бей,Хаф Мун Беј,هاف مون بی,هالف موون باي,हाफ मून बे,ハーフムーンベイ,半月灣', 37.4635500, -122.4285900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144276, 'Hamilton City', 'Hamilton City', 'Hamilton,Hamilton City', 39.7426600, -122.0135900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144277, 'Hanford', 'Hanford', 'Hanford,Khanford,Khehnford,Khenford,haenpeodeu,han fu de,hanfodo,hanfwrd,hyanapharda,Ханфорд,Хенфорд,Хэнфорд,هانفورد,ह्यानफर्ड,ハンフォード,汉福德,핸퍼드', 36.3274500, -119.6456800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144278, 'Harbison Canyon', 'Harbison Canyon', '', 32.8203300, -116.8300200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144279, 'Hartley', 'Hartley', '', 38.4171300, -121.9469100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144280, 'Hawaiian Gardens', 'Hawaiian Gardens', 'Khauajun Garduns,Khavajan Gardens,hava''iyana gardensa,hawayyn gadrnz,hawyyan ghardyns,xia wei yi hua yuan,Хавајан Гарденс,Хауайън Гардънс,هاوایین گادرنز,هاوييان غاردينس,ہوائیین گارڈنز، کیلیفورنیا,हवाइयन गार्डेन्स,夏威夷花园', 33.8314000, -118.0728400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144281, 'Hawthorne', 'Hawthorne', 'HHR,Hawthorne,Khotorn,hahtharna,hawthwrny,hawtwrn,hoson,huo sang,Хоторн,هاوتورن,هاوثورني,ہاتھورن,ہاوتھرون، کیلیفورنیا,हःथर्न,ホーソーン,霍桑,호손', 33.9164000, -118.3525700, 'US', '2017-04-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144282, 'Hayward', 'Hayward', 'Gejvard,HWD,Hayward,Hayward Station,Hayward''s,Haywards,Haywards Station,Haywood,Heivordas,Kheju"rd,Khejvard,hai wo de,hayward,heiwado,heiwodeu,hevarda,hywrd  kalyfrnya,Гейвард,Хейвард,Хейуърд,Хејвард,هايوارد,هیورد، کالیفرنیا,ہےوارڈ,हेवार्ड,ヘイワード,海沃德,헤이워드', 37.6688200, -122.0808000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144283, 'Healdsburg', 'Healdsburg', 'Gildsburg,Healdsburg,Healdsburgh,Khijldsburg,Khildsberg,Khildsburg,Russian River,heldsbarga,hiljeubeogeu,hirusubagu,hldzbrg  kalyfrnya,hyldsbwrgh,xi er ci bao,Гілдсбурґ,Хийлдсбърг,Хилдсберг,Хилдсбург,هلدزبرگ، کالیفرنیا,هيلدسبورغ,हेल्ड्स्बर्ग,ヒールスバーグ,希尔兹堡,힐즈버그', 38.6104700, -122.8691600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144284, 'Heber', 'Heber', '', 32.7308900, -115.5297200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144285, 'Hemet', 'Hemet', 'HMT,Hemet,Hemicia,Khemet,he mi te,hemeta,hmt  kalyfrnya,hymyt,Хемет,همت، کالیفرنیا,هيميت,ہیمٹ,ہیمٹ، کیلیفورنیا,हेमेट,赫米特', 33.7476100, -116.9730700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144286, 'Herald', 'Herald', '', 38.2957500, -121.2443900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144287, 'Hercules', 'Hercules', 'Gerkules,Kherkjuliz,Khurkjulijz,hakyurizu,harkulija,he la ke lei si,hrkwls  kalyfrnya,hyrkwlys,Геркулес,Херкјулиз,Хъркюлийз,هرکولس، کالیفرنیا,هيركوليس,हर्कुलिज,ハーキュリーズ,赫拉克勒斯', 38.0171400, -122.2885800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144288, 'Hermosa Beach', 'Hermosa Beach', 'Khermosa Bich,Khermosa Bijch,harmosa bica,he er mo sha hai tan,hrmwsa bych  kalyfrnya,hyrmwsa bytsh,Хермоса Бийч,Хермоса Бич,هرموسا بیچ، کالیفرنیا,هيرموسا بيتش,ہیرموسا بیچ، کیلیفورنیا,हर्मोसा बीच,何尔摩沙海滩', 33.8622400, -118.3995200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144289, 'Hesperia', 'Hesperia', 'Hesperia,Khespirija,heseupelia,hespariya,hsprya  kalyfrnya,hysbyrya,xi si pi li ya,Хеспирия,Хеспирија,هسپریا، کالیفرنیا,هيسبيريا,ہسپیریا,हेस्परिया,希斯皮里亚,헤스페리아', 34.4263900, -117.3008800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144290, 'Hidden Hills', 'Hidden Hills', '', 34.1602800, -118.6523100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144291, 'Hidden Meadows', 'Hidden Meadows', '', 33.2253100, -117.1125300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144292, 'Hidden Valley Lake', 'Hidden Valley Lake', '', 38.8079600, -122.5583200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144293, 'Highgrove', 'Highgrove', 'Citrus,East Riverside,High Grove,Highgrove,Merril,Merrill', 34.0158500, -117.3333800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144294, 'Highland', 'Highland', 'Highland,Highlands,Khajland,ha''ilyanda,hai lan,haillaendeu,hayland,haylnd  kalyfrnya,Хайланд,Хајланд,هايلاند,هایلند، کالیفرنیا,हाइल्यान्ड,海兰,하일랜드', 34.1283400, -117.2086500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144295, 'Hillsborough', 'Hillsborough', '', 37.5741000, -122.3794200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144296, 'Hollister', 'Hollister', 'Gollister,HLI,Kholister,Kholistur,halystr,holistara,holliseuteo,horisuta,huo li si te,hwlystyr,Голлістер,Холистер,Холистър,هالیستر,هوليستير,होलिस्टर,ホリスター,霍利斯特,홀리스터', 36.8524500, -121.4016000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144297, 'Hollywood', 'Hollywood', 'Cholygount,Galivud,Gollivud,Holivud,Holivuda,Holivudas,Holivudo,Hollivud,Hollywood,Huolevods,Huolėvods,Kholivud,Ruscisilva,Tinseltown,hali''uda,halivud,halivut,halliudeu,halywwd,halywwd  ls‌anjls,hao lai wu,hariuddo,he li huo,healivud,holivuda,holivudi,hwlywwd,hxl li wud,Χόλυγουντ,Галівуд,Голливуд,Голлівуд,Холивуд,Հոլիվուդ,האליוואד,הוליווד,هاليووډ,هالیوود,هالیوود، لس‌آنجلس,هوليوود,ھۆلیوود,ہالی وڈ,हलिउड,हॉलिवूड,हॉलीवुड,হলিউড,ஹாலிவுட்,హాలీవుడ్,ಹಾಲಿವುಡ್,ഹോളിവുഡ്,ฮอลลีวูด,ဟောလိဝုဒ်,ჰოლივუდი,ハリウッド,好莱坞,荷里活,할리우드', 34.0983400, -118.3267400, 'US', '2016-05-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144298, 'Holtville', 'Holtville', 'Holton,Holtville,Kholtvil,halt wyl  kalyfrnya,hao te wei er,holtabhila,hwltfyly,Холтвил,هالت ویل، کالیفرنیا,هولتفيلي,होल्टभिल,豪特维尔', 32.8111600, -115.3802600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144299, 'Home Garden', 'Home Garden', '', 36.3032800, -119.6362400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144300, 'Home Gardens', 'Home Gardens', 'Home Gardens,Riverside Valley Home Gardens', 33.8780700, -117.5208800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144301, 'Homeland', 'Homeland', '', 33.7430800, -117.1092000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144302, 'Hughson', 'Hughson', 'Khjuson,Khjusun,haswn,hwghswn,hyusana,xiao chen,Хюсън,Хјусон,هاسون,هوغسون,ह्युसन,晓臣', 37.5968800, -120.8660400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144303, 'Huntington Beach', 'Huntington Beach', 'Gantington-Bich,Hantington Bycas,Hantington Byčas,Huntington Beach,Kh"ntingt"n Bijch,Khantington Bich,Khantington-Bich,Pacific Beach,Pacific City,han ting tan bich,hantingatana bica,hantintonbichi,hantyngtwn bych  kalyfrnya,heng ting dun bi qi,heontingteonbichi,hwntynghtwn bytsh,Гантінґтон-Біч,Хантингтон Бич,Хантингтон-Бич,Хънтингтън Бийч,هانتینگتون بیچ، کالیفرنیا,هونتينغتون بيتش,ہنٹنگٹن بیچ,हन्टिंगटन बीच,ฮันติงตันบีช,ハンティントンビーチ,亨廷頓比奇,헌팅턴비치', 33.6603000, -117.9992300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144304, 'Huntington Park', 'Huntington Park', 'Huntington Park,Khantington Park,Khantington-Park,Khuntingtun Park,hantingatana parka,hantyngtwn park,heng ting dun gong yuan,hwntynghtwn bark,Хантингтон Парк,Хантингтон-Парк,Хънтингтън Парк,هانتینگتون پارک,هونتينغتون بارك,ہنٹنگٹن پارک، کیلیفورنیا,हन्टिंगटन पार्क,亨廷顿公园', 33.9816800, -118.2250700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144305, 'Huron', 'Huron', '', 36.2027300, -120.1029200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144306, 'Idyllwild', 'Idyllwild', 'Ajdilvajld,Idyllwild,Strawberry Valley,Айдилвайлд', 33.7400200, -116.7189100, 'US', '2010-06-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144307, 'Imperial', 'Imperial', 'IPL,Impirijal,Impiriul,ambyryal,aympryal  kalyfrnya,imperiyala,yin pi li er,Импириъл,Импиријал,إمبيريال,ایمپریال، کالیفرنیا,इम्पेरियल,因皮里尔', 32.8475500, -115.5694400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144308, 'Imperial Beach', 'Imperial Beach', 'Impirijal Bich,Impiriul Bijch,NRS,ambyryal bytsh,aympryal bych  kalyfrnya,imperiyala bica,impilieolbichi,yin pi li er tan,Импириъл Бийч,Импиријал Бич,אימפריאל ביץ,إمبيريال بيتش,ایمپریال بیچ، کالیفرنیا,इम्पेरियल बीच,因皮里尔滩,임피리얼비치', 32.5839400, -117.1130800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144309, 'Indian Wells', 'Indian Wells', 'Indian Velsas,Indian-Uehlls,Indian-Vells,Indijan Vels,Indiun Uels,andyan wylz,ayndyn wlz  kalyfrnya,indian''u~eruzu,indiyana velsa,yin di an wei er si,Індіан-Веллс,Индиан-Уэллс,Индиън Уелс,Индијан Велс,إنديان ويلز,انڈین ویلز، کیلیفورنیا,ایندین ولز، کالیفرنیا,इन्डियन वेल्स,インディアンウェルズ,印第安維爾斯', 33.7179100, -116.3431100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144310, 'Indio', 'Indio', 'Indian Wells,Indio,Indiou,andyw,ayndyw  kalyfrnya,indio,indiyo,yin di ao,Індіо,Индио,Индиоу,إنديو,ایندیو، کالیفرنیا,इन्डियो,インディオ,印第奥,인디오', 33.7207000, -116.2167700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144311, 'Inglewood', 'Inglewood', 'Inglewood,Inglvud,Inglvudas,Ingulud,anghlywwwd,aynglwwd  kalyfrnya,in''gelavuda,ing-geul-udeu,inguruuddo,ying ge er wu de,Інґлвуд,Инглвуд,Ингълуд,Ինգլվուդ,אינגלווד,إنغليووود,انگل ووڈ,انگلووڈ، کیلیفورنیا,اینگلوود، کالیفرنیا,इन्गेलवूड,イングルウッド,英格爾伍德,잉글우드', 33.9616800, -118.3531300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144312, 'Interlaken', 'Interlaken', '', 36.9513400, -121.7338400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144313, 'Inverness', 'Inverness', 'Invernes,inbharnesa,Инвернес,इन्भर्नेस', 38.1010300, -122.8569400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144314, 'Inyokern', 'Inyokern', 'IYK,Inyokern,Magnolia,Siding 16,in''yokarna,इन्योकर्न', 35.6469000, -117.8125700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144315, 'Ione', 'Ione', 'Ajon,Ajoni,Bed Bug,Bedbug,Freeze Out,Freezeout,Hardscrabble,Ione,Ione City,Rickeyville,Woosterville,ai ao ni,awny,ayona,aywn  kalyfrnya,Айони,Ајон,آیون، کالیفرنیا,إوني,आयोन,艾奥尼', 38.3526900, -120.9327200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144316, 'Irvine', 'Irvine', '"rvajn,Ervajn,Irvajn,Irvin,Irvinas,Irvine,abain,arfayn,arwayn,arwayn  kalyfrnya,eobain,er wan,ou wen,Ервайн,Ервајн,Ирвайн,Ирвин,Ървайн,אירוויין,إرفاين,اروائن,ارواین، کالیفرنیا,アーバイン,歐文,爾灣,어바인', 33.6694600, -117.8231100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144317, 'Irwindale', 'Irwindale', '"ruindejl,Ervindejl,Irvindejl,arvinadela,arwyndaly,ayrwyndl  kalyfrnya,Ірвіндейл,Ервиндејл,Ирвиндейл,Ъруиндейл,آیرویندل، کالیفرنیا,إرويندالي,अर्विनडेल', 34.1069500, -117.9353400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144318, 'Isla Vista', 'Isla Vista', 'Ajla Vista,a''ila bhista,airabisuta,aysla wysta  kalyfrnya,Ајла Виста,ایسلا ویستا، کالیفرنیا,आइला भिस्टा,アイラビスタ', 34.4133300, -119.8609700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144319, 'Ivanhoe', 'Ivanhoe', 'Ivanhoe,Klink', 36.3871700, -119.2178900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144320, 'Jackson', 'Jackson', 'Botellas,Botilleas,Botilleas Spring,Bottileas,Bottle Spring,Dzekson,Dzhaksun,Dzhehkson,Dzhekson,Jackson,jakswn,jakuson,jie ke xun,jkswn  kalyfrnya,jyakasana,jyksn  kyly fwrnyw,Џексон,Джаксън,Джексон,Джэксон,جاكسون,جکسون، کالیفرنیا,جیکسن، کیلی فورنیو,ज्याकसन,ジャクソン,杰克逊', 38.3488000, -120.7741000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144321, 'Jamestown', 'Jamestown', 'American Camp,Jamestown,Jimtown', 37.9532600, -120.4227000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144322, 'Jamul', 'Jamul', '', 32.7170000, -116.8761300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144323, 'Joshua Tree', 'Joshua Tree', 'Dzoshua Tri,josuva tri,josyuateuli,yue shu ya shu,Џошуа Три,जोशुवा ट्री,約書亞樹,조슈아트리', 34.1347300, -116.3130700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144324, 'Julian', 'Julian', 'Dzulijan,Julian,Julian City,Julián,juliyana,Џулијан,जुलियन', 33.0786600, -116.6019600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144325, 'Kelseyville', 'Kelseyville', 'Kelsey,Kelsey Creek,Kelsey Town,Kelseyville,Kelsivil,Peartown,Uncle Sam,kelsibhila,Келсивил,केल्सीभिल', 38.9779500, -122.8394400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144326, 'Kennedy', 'Kennedy', '', 37.9299200, -121.2527200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144327, 'Kensington', 'Kensington', 'Kensington,Kensington Park,kensingatana,Кенсингтон,केन्सिंगटन', 37.9104800, -122.2802500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144328, 'Kentfield', 'Kentfield', 'Kent,Kentfield,Kentfild,Ross Landing,Tamalpais,kentaphilda,Кентфилд,केन्टफिल्ड', 37.9521500, -122.5572000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144329, 'Kenwood', 'Kenwood', '', 38.4138000, -122.5460900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144330, 'Kerman', 'Kerman', 'Collis,Kerman,Kurman,ke er man,kermyana,krman,kyrman,Керман,Кърман,كيرمان,کرمان,केर्म्यान,克尔曼', 36.7235600, -120.0598800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144331, 'Kernville', 'Kernville', 'Kernvil,kernabhila,Кернвил,केर्नभिल', 35.7546700, -118.4253600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144332, 'Kettleman City', 'Kettleman City', 'Kettelman City,Kettleman City', 36.0082900, -119.9618000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144333, 'Keyes', 'Keyes', '', 37.5566000, -120.9154900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144334, 'King City', 'King City', 'City of King,KIC,King City,King Siti,Kings City,Kings Siti,Kings Station,jin cheng,kinga siti,kingsiti,kyng syty  kalyfrnya,kyngh syty,Кинг Сити,Кингс Сити,كينغ سيتي,کنگ سٹی، کیلیفورنیا,کینگ سیتی، کالیفرنیا,किङ्ग सिटी,金城,킹시티', 36.2127400, -121.1260300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144335, 'Kings Beach', 'Kings Beach', '', 39.2376800, -120.0265800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144336, 'Kingsburg', 'Kingsburg', 'Drapersville,Kings River Switch,Kingsberg,Kingsburg,Kingsburgh,Wheatville,jin si bao,kingasbarga,kynghsbwrgh,kyngz brg  kalyfrnya,Кингсберг,Кингсбърг,كينغسبورغ,کینگز برگ، کالیفرنیا,किङ्गस्बर्ग,金斯堡', 36.5138400, -119.5540200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144337, 'Knightsen', 'Knightsen', 'Knightsen,Knightsen Station', 37.9688100, -121.6680100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144338, 'La Cañada Flintridge', 'La Canada Flintridge', 'Flintridge,La Canada,La Canada Flintridge,La Cañada Flintridge,La Kanjada Flintridz,La-Kan''jada-Flintridzh,la kanyada flyntrydj,la kanyada flyntryj  kalyfrnya,la kyanada phlintarija,lakanyadapeullinteuliji,Ла Канјада Флинтриџ,Ла-Каньяда-Флинтридж,لا كانيادا فلينتريدج,لا کاناڈا فلینٹریڈگی، کیلیفورنیا,لا کانیادا فلینتریج، کالیفرنیا,ला क्यानाडा फ्लिन्टरिज,라카냐다플린트리지', 34.1991700, -118.1878500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144339, 'La Habra', 'La Habra', 'La Khabra,la ha bu la,la habra,la habra  kalyfrnya,Ла Хабра,لا هابرا,لا هابرا، کالیفرنیا,ला हाब्रा,拉哈布拉', 33.9319600, -117.9461700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144340, 'La Habra Heights', 'La Habra Heights', 'La Khabra Khajts,la ha bu la gao de,la habra ha''itsa,la habra hayts  kalyfrnya,la habra hyayts,Ла Хабра Хайтс,Ла Хабра Хајтс,لا هابرا هایتس، کالیفرنیا,لا هابرا هيايتس,ला हाब्रा हाइट्स,拉哈布拉高地', 33.9608500, -117.9506200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144341, 'La Jolla', 'La Jolla', 'El Nito,La Jolla,La Joya,La Khoja,La-Khojja,La-Khol''ja,Lajolla,la huo ya,la hwya,lahoia,lahwya,rahoya,Ла Хоя,Ла-Хойя,Ла-Холья,لا هویا,لاهويا,ラホヤ,拉霍亚,라호이아', 32.8472700, -117.2742000, 'US', '2011-06-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144342, 'La Mesa', 'La Mesa', 'Allison Springs,La Mesa,La Mesa Heights,La Mesa Springs,Lamesa,la mesa,la mi sa,la msa  kalyfrnya,la mysa,Ла Меса,لا مسا، کالیفرنیا,لا ميسا,ला मेसा,拉米萨', 32.7678300, -117.0230800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144343, 'La Mirada', 'La Mirada', 'La Mirada,La-Mirada,la mi la da,la mirada,la myrada,la myrada  kalyfrnya,lamilada,Ла Мирада,Ла-Мирада,لا ميرادا,لا میرادا، کالیفرنیا,ला मिराडा,拉米拉达,라미라다', 33.9172400, -118.0120100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144344, 'La Palma', 'La Palma', 'Dairyland,La Palma,la balma,la pa er ma,la palma,la palma  kalyfrnya,Ла Палма,لا بالما,لا پالما، کالیفرنیا,ला पाल्मा,拉帕尔马', 33.8464000, -118.0467300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144345, 'La Presa', 'La Presa', '', 32.7081100, -116.9972500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144346, 'La Puente', 'La Puente', 'Hillgrove,La Puente,La Puenti,Puente,la bwynty,la pu''ente,la pwnt  kalyfrnya,Ла Пуенте,Ла Пуенти,لا بوينتي,لا پونت، کالیفرنیا,لا پیونتے، کیلیفورنیا,ला पुएन्टे', 34.0200100, -117.9495100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144347, 'La Quinta', 'La Quinta', 'La Kinta,La Kuinta,la kvinta,la kwynta,la kwyynta  kalyfrnya,Ла Кинта,Ла Куинта,لا كوينتا,لا کوئینتا، کالیفرنیا,لا کوینٹا، کیلیفورنیا,ला क्विन्टा', 33.6633600, -116.3100100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144348, 'La Riviera', 'La Riviera', '', 38.5668500, -121.3569000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144349, 'La Selva Beach', 'La Selva Beach', 'La Selva Beach,Manresa,Rob Roy,Robroy,Roy Roy', 36.9366200, -121.8646800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144350, 'La Verne', 'La Verne', 'La Vern,La Verne,La Vurn,La-Vern,Lordsburg,POC,la bharna,la fyrny,la wrn  kalyfrnya,Ла Верн,Ла Върн,Ла-Верн,لا فيرني,لا ورن، کالیفرنیا,ला भर्न', 34.1008400, -117.7678400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144351, 'Ladera', 'Ladera', '', 37.3999400, -122.1983000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144352, 'Ladera Heights', 'Ladera Heights', '', 33.9941800, -118.3753500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144353, 'Ladera Ranch', 'Ladera Ranch', '', 33.5708600, -117.6356100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144354, 'Lafayette', 'Lafayette', 'La Fayette,Lafajet,Lafayette,Lafejet,la fei te,lafayt  kalyfrnya,lafayyty,laphayeta,lapies,rafaietto,Лафайет,Лафејет,لافاييتي,لافایت، کالیفرنیا,लाफायेट,ラファイエット,拉斐特,라피엣', 37.8857600, -122.1180200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144355, 'Laguna', 'Laguna', '', 38.4210200, -121.4238400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144356, 'Laguna Beach', 'Laguna Beach', 'Lagona,Laguna,Laguna Beach,Laguna Bich,Laguna Bijch,Laguna-Bich,la gu na hai tan,laghwna bytsh,laguna bica,lagwna bych  kalyfrnya,lagwna bych  kylyfwrnya,leogunabichi,Лагуна Бийч,Лагуна Бич,Лагуна-Бич,Лагуна-Біч,لاغونا بيتش,لاگونا بیچ، کالیفرنیا,لاگونا بیچ، کیلیفورنیا,लागुना बीच,ラグナ・ビーチ,拉古纳海滩,러구나비치', 33.5422500, -117.7831100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144357, 'Laguna Hills', 'Laguna Hills', '', 33.6125200, -117.7128300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144358, 'Laguna Niguel', 'Laguna Niguel', 'Laguna Nigel,Laguna Niguel,laghwna nyghwyl,laguna nigela,lagwna nygwyl  kalyfrnya,ni gu hu,Лагуна Нигел,لاغونا نيغويل,لاگونا نیگوئل، کالیفرنیا,लागुना निगेल,尼古湖', 33.5225300, -117.7075500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144359, 'Laguna Woods', 'Laguna Woods', 'Laguna Uds,Laguna Vuds,la gu na wu ci,laghwna wwwds,laguna vudsa,lagwna wwdz  kalyfrnya,Лагуна Вудс,Лагуна Удс,لاغونا ووودس,لاگونا وودز، کالیفرنیا,लागुना वुद्स,拉古纳伍兹', 33.6103000, -117.7253300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144360, 'Lake Arrowhead', 'Lake Arrowhead', 'Lake Arrowhead,Lejk Aroukhed,Little Bear Lake,leka eroheda,Лејк Ароухед,लेक एरोहेड', 34.2483400, -117.1892100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144361, 'Lake Elsinore', 'Lake Elsinore', 'Elsinore,Etengvo,Etengvo Wumona,Laguna,Laguna Grande,Lake Elsinore,Lejk Elsinor,Lejk Elzinor,Lejk-Ehlsinor,Machadao,Machado,Wamoma,hu ai er xi nuo,lak alsynwry,leka elsinora,lyk al synwr  kalyfrnya,lyk aylsynwry  kylyfwrnya,Лейк Елзинор,Лейк-Элсинор,Лејк Елсинор,لاك إلسينوري,لیک ال سینور، کالیفرنیا,لیک ایلسینوری، کیلیفورنیا,लेक एल्सिनोर,湖埃尔西诺', 33.6680800, -117.3272600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144362, 'Lake Forest', 'Lake Forest', 'El Toro,Eltoro,Lake Forest,Lejk Forest,Lejk Forist,lak fwryst,leikeupoliseuteu,leka pharesta,lyk farst  kalyfrnya,reikuforesuto,sen lin hu,Лейк Форест,Лејк Форист,لاك فوريست,لیک فارست، کالیفرنیا,لیک فارسٹ، کیلیفورنیا,لیک فورسٹ,लेक फरेस्ट,レイクフォレスト,森林湖,레이크포리스트', 33.6469700, -117.6892200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144363, 'Lake Isabella', 'Lake Isabella', 'Isabella,Kernvale,Lake Isabella,Lejk Izabela,leka ijabela,Лејк Изабела,लेक इजाबेला', 35.6180100, -118.4731400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144364, 'Lake Los Angeles', 'Lake Los Angeles', '', 34.6124900, -117.8281200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144365, 'Lake Nacimiento', 'Lake Nacimiento', '', 35.7283000, -120.8796300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144366, 'Lake San Marcos', 'Lake San Marcos', '', 33.1261500, -117.2083700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144367, 'Lake Wildwood', 'Lake Wildwood', '', 39.2329500, -121.2005100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144368, 'Lake of the Pines', 'Lake of the Pines', '', 39.0396200, -121.0566100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144369, 'Lakeland Village', 'Lakeland Village', '', 33.6386300, -117.3439300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144370, 'Lakeport', 'Lakeport', 'Forbestown,Lakeport,Lejkport,Rocky Point,Stony Point,Tuckertown,la ke bo te,lakybwrt,lekaporta,lykpwrt  kalyfrnya,reikupoto,Лейкпорт,Лејкпорт,لاكيبورت,لیکپورت، کالیفرنیا,लेकपोर्ट,レイクポート,拉克波特', 39.0429500, -122.9158300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144371, 'Lakeside', 'Lakeside', 'Lejksajd,lekasa''ida,Лејксајд,लेकसाइड', 32.8572700, -116.9222500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144372, 'Lakeview', 'Lakeview', 'Algooton,Algootoon,Lake View,Lakeview,Lakeview Junction', 33.8386300, -117.1180900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144373, 'Lakewood', 'Lakewood', 'Lakewood,Lakewood Village,Lejkud,Lejkvud,lai ke wu de,lakywwwd,leikeuudeu,lekavuda,lykwwd  kalyfrnya,reikuuddo,Лейквуд,Лейкуд,Лејквуд,لاكيووود,لیکوود، کالیفرنیا,لیکووڈ,लेकवूड,レイクウッド,莱克伍德,레이크우드', 33.8536300, -118.1339600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144374, 'Lamont', 'Lamont', '', 35.2596800, -118.9142700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144375, 'Lancaster', 'Lancaster', 'Lancaster,Lankaster,Lankastur,WJF,lan kai si te,lankstr,lnkstr  kalyfrnya,lnqstr,lyancestara,rankasuta,Ланкастер,Ланкастър,לנקסטר,لانكستر,لنکستر، کالیفرنیا,لینکاسٹر,ल्यान्चेस्टर,ランカスター,蘭開斯特', 34.6980400, -118.1367400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144376, 'Larkspur', 'Larkspur', 'Larksper,Larkspur,la ke si po,larkaspara,larksbwr,larkspwr  kalyfrnya,Ларкспер,Ларкспър,لاركسبور,لارکسپور، کالیفرنیا,लार्कस्पर,拉克斯珀', 37.9340900, -122.5352500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144377, 'Las Flores', 'Las Flores', 'Las Flores,Malibu La Costa', 34.0372300, -118.6359200, 'US', '2010-02-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144378, 'Las Flores', 'Las Flores', '', 33.5880800, -117.6267200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144379, 'Las Lomas', 'Las Lomas', 'Hall,Las Lomas', 36.8652300, -121.7349500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144380, 'Lathrop', 'Lathrop', 'LRO,Lathrop,Latroup,Lejtrop,la si luo pu,lathrwb,latrwp  kalyfrnya,lyatharopa,Латроуп,Лејтроп,لاتروپ، کالیفرنیا,لاثروب,ल्याथरोप,拉斯罗普', 37.8227000, -121.2766100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144381, 'Laton', 'Laton', '', 36.4332800, -119.6868000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144382, 'Lawndale', 'Lawndale', 'Londejl,lanadela,lawn dyl  kalyfrnya,lawndaly,Лондейл,Лондејл,لانڈیل، کیلیفورنیا,لاون دیل، کالیفرنیا,لاوندالي,लनडेल', 33.8872400, -118.3525700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144383, 'Laytonville', 'Laytonville', 'Lejtonvil,letanabhila,Лејтонвил,लेटनभिल', 39.6882100, -123.4827900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144384, 'Le Grand', 'Le Grand', '', 37.2285500, -120.2482300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144385, 'Lebec', 'Lebec', '', 34.8416400, -118.8648200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144386, 'Lemon Grove', 'Lemon Grove', 'Lemon Grouv,Lemon Grove,Lemongrove,Lemun Grouv,lai meng ge luo wei,lemana grobha,lemongeulobeu,lmwn grww  kalyfrnya,lymwn ghrwfy,Лемон Гроув,Лемън Гроув,لمون گروو، کالیفرنیا,ليمون غروفي,लेमन ग्रोभ,莱蒙格罗韦,레몬그로브', 32.7425500, -117.0314200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144387, 'Lemoore', 'Lemoore', 'La Tache,Latache,Lee Moore''s,Lemoore,Lemur,Limor,NLC,lei mu er,lemura,lmwr  kalyfrnya,lymwwry,Лемур,Лимор,لمور، کالیفرنیا,ليمووري,लेमूर,勒穆尔', 36.3007800, -119.7829100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144388, 'Lennox', 'Lennox', 'Inglewood Rancho,Jefferson,Lennoks,Lennox,Леннокс', 33.9380700, -118.3525800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144389, 'Lenwood', 'Lenwood', '', 34.8766500, -117.1039300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144390, 'Leona Valley', 'Leona Valley', '', 34.6183200, -118.2881300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144391, 'Lexington Hills', 'Lexington Hills', '', 37.1646700, -121.9730100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144392, 'Lincoln', 'Lincoln', 'Linkol''n,Linkoln,Linkuln,lin ken,linkana,lnkn  kylyfwrnya,lynkln  kalyfrnya,lynkwn,Линколн,Линкольн,Линкълн,لنکن، کیلیفورنیا,لينكون,لینکلن، کالیفرنیا,लिङ्कन,林肯', 38.8915600, -121.2930100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144393, 'Lincoln Village', 'Lincoln Village', '', 38.0052000, -121.3282800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144394, 'Linda', 'Linda', '', 39.1276700, -121.5508000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144395, 'Linden', 'Linden', 'Linden,Linden Mills,Линден', 38.0213100, -121.0838300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144396, 'Lindsay', 'Lindsay', 'Lindsi,Lindzi,lin sai,lindse,lyndsay,lyndsy  kalyfrnya,rinji,Линдзи,Линдси,ليندساي,لیندسی، کالیفرنیا,लिन्ड्से,リンジー,林赛', 36.2030100, -119.0881600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144397, 'Littlerock', 'Littlerock', 'Little Rock,Littlerock', 34.5211000, -117.9836800, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144398, 'Live Oak', 'Live Oak', '', 36.9835600, -121.9805200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144399, 'Live Oak', 'Live Oak', 'Lajv Ouk,Live Oak,Liveoak,la''ibha oka,layw awk  kalyfrnya,li fu ao ke,lyf awak,Лайв Оук,Лајв Оук,لایو اوک، کالیفرنیا,ليف أواك,लाइभ ओक,利夫奥克', 39.2757200, -121.6599700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144400, 'Livingston', 'Livingston', 'Cressey,Livingston,Livingstun,li wen si dun,libhingastana,lyfynghstwn,lywyngstwn  kalyfrnya,Ливингстон,Ливингстън,ليفينغستون,لیونگسٹن، کیلیفورنیا,لیوینگستون، کالیفرنیا,लिभिंगस्टन,利文斯顿', 37.3868800, -120.7235300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144401, 'Livermore', 'Livermore', 'LVK,Laddville,Liv"rmor,Livermor,Livermore,Livermore''s,Nottingham,li fu mo,libeomo-eo,libharamora,lybrmwr,lyfyrmwry,lywrmwr,lywrmwr  kalyfrnya,ribamoa,Ливермор,Ливърмор,Лівермор,ליברמור,ليفيرموري,لیورمور,لیورمور، کالیفرنیا,लिभरमोर,リバモア,利佛摩,리버모어', 37.6818700, -121.7680100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144402, 'Lockeford', 'Lockeford', 'Locke''s Ford,Lockeford', 38.1635300, -121.1499400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144403, 'Lodi', 'Lodi', 'Lodaj,Lodi,Loudaj,Mokelumne,Moquelumne,lodi,luo di,lwdy,lwdy  kalyfrnya,rodai,Лодай,Лодај,Лоди,Лоді,Лоудай,لودي,لودی، کالیفرنیا,लोडी,ローダイ,洛迪,로디', 38.1302000, -121.2724500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144404, 'Loma Linda', 'Loma Linda', 'Loma Linda,Loma-Linda,Lomalinda,Lonesome Linda,Mound City,Mound Station,loma linda,lomalinda,luo ma lin da,lwma lynda,lwma lynda  kalyfrnya,Лома Линда,Лома-Линда,Лома-Лінда,لوما ليندا,لوما لیندا، کالیفرنیا,लोमा लिन्डा,罗马琳达,로마린다', 34.0483500, -117.2611500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144405, 'Loma Rica', 'Loma Rica', '', 39.3118300, -121.4177400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144406, 'Lomita', 'Lomita', 'Lomita,lomita,lwmyta,lwmyta  kalyfrnya,Ломита,لوميتا,لومیتا، کالیفرنیا,لومیٹا، کیلیفورنیا,लोमिता', 33.7922400, -118.3150700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144407, 'Lompico', 'Lompico', '', 37.1055000, -122.0527400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144408, 'Lompoc', 'Lompoc', 'LPC,Lompoc,Lompoco,Lompok,Lompokas,lampwk  kalyfrnya,lompoka,lompokeu,long bo ke,lwmbwk,Ломпок,لامپوک، کالیفرنیا,لومبوك,लोम्पोक,隆波克,롬포크', 34.6391500, -120.4579400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144409, 'London', 'London', 'London,Londres,New London', 36.4760600, -119.4431800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144410, 'Lone Pine', 'Lone Pine', 'Lone Pine,Lonepine,Loun Pajn,lona pa''ina,Лоун Пајн,लोन पाइन', 36.6062600, -118.0646200, 'US', '2015-01-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144411, 'Long Beach', 'Long Beach', 'Gorad Long-Bich,LGB,Litus Longum,Lon''nk Bits,Long Beach,Long Bich,Long Bijch,Long Bycas,Long Byčas,Long-Bich,Longbica,Longbīča,Lonq Bic,Lonq Biç,Willmore City,lam bica,lamga bica,lang bic,lang bych  kalyfrnya,lang bych  kylyfwrnya,langa bica,long-bichi,longbichi,lwng byz,lwngh bytsh,lxng bich,rongubichi,zhang tan,Λονγκ Μπιτς,Горад Лонг-Біч,Лонг Бийч,Лонг Бич,Лонг-Бич,Лонг-Біч,Լոնգ Բիչ,לונג ביץ,لانگ بیچ، کالیفرنیا,لانگ بیچ، کیلیفورنیا,لونغ بيتش,लङ्ग बीच,लाँग बीच,লং বিচ,లాంగ్ బీచ్,ลองบีช,ლონგ-ბიჩი,ឡងបច,ឡងប៊ិច,ロングビーチ,長灘,롱비치', 33.7669600, -118.1892300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144412, 'Loomis', 'Loomis', 'Loomis,Lumis,Pine,Pino,Smithville,lu mi si,lumisa,lwmys  kalyfrnya,lwwmys,Лумис,لومیس، کالیفرنیا,لووميس,लूमिस,卢米斯', 38.8212900, -121.1930000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144413, 'Los Alamitos', 'Los Alamitos', 'Los Alamitos,lasa elamitoja,luo si a la mi tuo si,lws alamytws,lws alamytws  kalyfrnya,Лос Аламитос,لوس آلامیتوس، کالیفرنیا,لوس ألاميتوس,लस एलामितोज,洛斯阿拉米托斯', 33.8030700, -118.0725600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144414, 'Los Alamos', 'Los Alamos', 'Los-Alamos,Лос-Аламос', 34.7444300, -120.2782100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144415, 'Los Altos', 'Los Altos', 'Los Altos,Los-Al''tos,Los-Altos,lasa eltosa,loseuaeltoseu,ls‌altws,luo si a tu si,luo si la tu si,lws altws,rosuarutosu,Лос Алтос,Лос-Алтос,Лос-Альтос,לוס אלטוס,لس‌آلتوس,لوس ألتوس,लस एल्टोस,ロスアルトス,洛思阿圖斯,洛斯拉图斯,로스앨토스', 37.3852200, -122.1141300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144416, 'Los Altos Hills', 'Los Altos Hills', '', 37.3796600, -122.1374600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144417, 'Los Angeles', 'Los Angeles', 'Angelopolis,Cuidad De Los Angelos,Cuidad De los Angelos,El Pueblo de Nuestra Senora La Reina de Los Angeles de Porcivncula,El Pueblo de Nuestra Senora de los Angeles de Porciuncula,El Pueblo de Nuestra Señora de los Ángeles de Porciúncula,El Pueblo del Rio de Nuestra Senora,Gorad Los-Andzhehles,L.A.,LA,LAX,La Reina de Los Angeles de Porciuncula,Lok-chham-ki,Los And''eles,Los Andzelas,Los Andzeles,Los Andzheles,Los Andzhelis,Los Andželas,Los Andželes,Los Angeles,Los Anjeles,Los Anjélés,Los Antzeles,Los Anxheles,Los Anxhelos,Los Anzeles,Los Anzheles,Los Ángeles,Los-Anceles,Los-Andzeles,Los-Andzheles,Los-Angeleso,Los-Anjeles,Los-Anzheles,Los-Anzheles shaary,Los-Anĝeleso,Losandzelosa,Losandželosa,Lo̍k-chhám-kî,Lungsod ng Los Angeles,Luos Andzels,Luos Andžels,Os Anxeles,Os Ánxeles,Pueblo De Los Angeles,Pueblo Los Angelos,el-ei,las aynjls,las encalas,las enjales,las enjalis,lasa ainjalasa,lasa enjalasa,lasa enjilasa,leas anceles,los-anjelesi,losa enjelasa,losa enjelisa,losa enjelsa,loseuaenjelleseu,loseuenjelleseu,ls anjls,luo shan ji,lws anjls,lws anjlws,lws anjlys,lws ʼngls,rosanzerusu,Λος Άντζελες,Горад Лос-Анджэлес,Лос Анджелес,Лос Анджелис,Лос Андьелес,Лос Анжелес,Лос Анђелес,Лос Анџелес,Лос Анҷелес,Лос Анӂелес,Лос-Анджелес,Лос-Анжелес,Лос-Анжелес шаары,Лос-Анџелес,Լոս Անջելես,לאס אנדזשעלעס,לוס אנגלס,لاس اینجلس,لس آنجلس,لس‌آنجلس,لوس آنجلس,لوس أنجلوس,لوس ئانجېلېس,لوس انجليس,لوس‌آنجلس,لۆس ئانجلەس,लस एञ्जिलस,लस एन्जलस,लास एंजलस,लॉस एंजेलिस,लॉस एंजेल्स,লস অ্যাঞ্জেলেস,ਲਾਸ ਐਂਜਲਸ,લોસ એન્જેલસ,லாஸ் ஏஞ்சலஸ்,లాస్ ఏంజలెస్,ಲಾಸ್ ಎಂಜಲೀಸ್,ലോസ് ആഞ്ചെലെസ്,ลอสแอนเจลิส,လော့စ်အိန်ဂျယ်လိစ်မြို့,ლოს-ანჯელესი,ሎስ አንጄሌስ,ロサンゼルス,洛杉矶,洛杉磯,로스앤젤레스,로스엔젤레스,엘에이', 34.0522300, -118.2436800, 'US', '2017-06-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144418, 'Los Banos', 'Los Banos', 'Kreyenhagen''s,LSN,Los Ban''os,Los Banos,Los Baños,Los-Ban''os,lasa benosa,luo si ba nuo si,lws banws,lws banws  kalyfrnya,Лос Банос,Лос Баньос,Лос-Баньос,لوس بانوس,لوس بانوس، کالیفرنیا,लस बेनोस,洛斯巴诺斯', 37.0582800, -120.8499200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144419, 'Los Gatos', 'Los Gatos', 'Forbes Mill,Forbestown,Los Gatos,Los-Gatos,lasa getosa,luo si jia tu si,lws gatws  kalyfrnya,lws ghatws,Лос Гатос,Лос-Гатос,لوس غاتوس,لوس گاتوس، کالیفرنیا,लस गेतोस,洛思加圖斯', 37.2266100, -121.9746800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144420, 'Los Olivos', 'Los Olivos', '', 34.6677600, -120.1148700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144421, 'Los Osos', 'Los Osos', 'Baywood-Los Osos', 35.3110900, -120.8324000, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144422, 'Los Serranos', 'Los Serranos', 'Los Seranos,Los Serranos', 33.9727900, -117.7081100, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144423, 'Lost Hills', 'Lost Hills', 'Lost Hill,Lost Hills', 35.6163500, -119.6942900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144424, 'Lower Lake', 'Lower Lake', 'Grantville,Louer Lejk,Lower Lake,lovara leka,Лоуер Лејк,लोवर लेक', 38.9104500, -122.6102600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144425, 'Loyola', 'Loyola', '', 37.3513300, -122.1005200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144426, 'Lucerne', 'Lucerne', '', 36.3807800, -119.6643000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144427, 'Lucerne', 'Lucerne', 'Clear Lake Beach,Lucerne', 39.0901700, -122.7963800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144428, 'Lucerne Valley', 'Lucerne Valley', '', 34.4438900, -116.9678100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144429, 'Lynwood', 'Lynwood', 'Linud,Linvud,Lynwood,lin wu de,lin-udeu,linavuda,lynwwd  kalyfrnya,lynwwwd,rin''uddo,Линвуд,Линуд,لينووود,لینوود، کالیفرنیا,لینووڈ، کیلیفورنیا,लीनवूड,リンウッド,林伍德,린우드', 33.9302900, -118.2114600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144430, 'Madera', 'Madera', 'MAE,Madera,ma de la,madera,madra  kalyfrnya,madyra,Мадера,مادرا، کالیفرنیا,ماديرا,मादेरा,マデラ,马德拉', 36.9613400, -120.0607200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144431, 'Madera Acres', 'Madera Acres', '', 37.0191100, -120.0668300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144432, 'Magalia', 'Magalia', 'Butte Mills,Dog Town,Dogtown,Magalia,Mill City,Mountain View', 39.8121100, -121.5783100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144433, 'Malibu', 'Malibu', '', 34.0257700, -118.7804000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144434, 'Malibu Beach', 'Malibu Beach', '', 34.0327900, -118.6884200, 'US', '2010-02-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144435, 'Mammoth Lakes', 'Mammoth Lakes', 'MMH,Mamot Lejks,Mamut Lejks,ma mai si hu,mamwt lyks  kalyfrnya,mamwth lakys,myamatha leksa,Мамот Лејкс,Мамът Лейкс,ماموت لیکس، کالیفرنیا,ماموث لاكيس,म्यामथ लेक्स,马麦斯湖', 37.6485500, -118.9720800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144436, 'Manhattan Beach', 'Manhattan Beach', 'Manhattan,Manhattan Beach,Mankhatun Bijch,Menkhetn Bich,Shore Acres,maenhaeteunbichi,man ha dun hai tan,manhatan bytsh,mnhtn bych  kalyfrnya,myanahyatana bica,Манхатън Бийч,Менхетн Бич,مانهاتان بيتش,منهتن بیچ، کالیفرنیا,म्यानह्याटन बीच,曼哈顿海滩,맨해튼비치', 33.8847400, -118.4109100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144437, 'Manteca', 'Manteca', 'Cowell,Cowell''s Station,Manteca,Mantika,man te ka,mantka  kalyfrnya,mantyka,myanateka,Мантика,مانتيكا,مانتکا، کالیفرنیا,म्यानटेका,曼特卡', 37.7974300, -121.2160500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144438, 'Maricopa', 'Maricopa', 'Marikopa,ma li ke pa,marykwba,marykwpa  kalyfrnya,merikopa,Марикопа,Марікопа,ماريكوبا,ماریکوپا، کالیفرنیا,मेरिकोपा,马里科帕', 35.0588600, -119.4009500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144439, 'Marin City', 'Marin City', 'Marin Siti,Marin-Siti,Марин Сити,Марин-Сити', 37.8685400, -122.5091400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144440, 'Marina', 'Marina', 'Marina,ma li na,marina,maryna,maryna  kalyfrnya,Марина,مارينا,مارینا، کالیفرنیا,मारिना,玛丽娜', 36.6844000, -121.8021700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144441, 'Marina del Rey', 'Marina del Rey', 'Marina Del Rey,Marina del Rej,marina dela re,maryna dl ry  kalyfrnya,meolinadellei,Марина дел Реј,مارینا دل ری، کالیفرنیا,मारिना डेल रे,マリナ・デル・レイ,머리나델레이', 33.9802900, -118.4517400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144442, 'Mariposa', 'Mariposa', 'Mariposa,Maripousa,RMY,mariposa,myrypwsa,Марипоуса,Маріпоса,میریپوسا,मारिपोसा,マリポサ', 37.4849400, -119.9662800, 'US', '2017-07-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144443, 'Martinez', 'Martinez', 'Martines,Martinez,Martínez,ma ding nei si,martineja,martynz,martynz  kalyfrnya,matinezu,Мартинес,Мартінес,مارتينز,مارتینز، کالیفرنیا,मार्टिनेज,マーティネズ,馬丁內斯,马丁内斯', 38.0193700, -122.1341300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144444, 'Marysville', 'Marysville', 'Jubaville,MYV,Marysville,Merisvil,New Mecklenberg,New Mecklenburg,ma li si wei er,marys wyl  kalyfrnya,marysfyly,mearizubiru,melijeubil,merijbhila,myryzwyl  kylyfwrnya,Мерисвил,ماريسفيلي,ماریس ویل، کالیفرنیا,میریزویل، کیلیفورنیا,मेरीज्भिल,メアリーズビル,马里斯维尔,메리즈빌', 39.1457300, -121.5913500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144445, 'Maxwell', 'Maxwell', 'Maxwell,Occident', 39.2762800, -122.1913700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144446, 'Mayflower Village', 'Mayflower Village', '', 34.1150100, -118.0097900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144447, 'Maywood', 'Maywood', 'Mejud,Mejvud,maywwwd,mei wu de,meiudeu,mevuda,mywwd  kalyfrnya,Мейуд,Мејвуд,مئیووڈ، کیلیفورنیا,مايووود,میوود، کالیفرنیا,मेवूड,梅伍德,메이우드', 33.9866800, -118.1853500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144448, 'McFarland', 'McFarland', 'Hunt,Lone Pine,Makfarland,McFarland,mai ke fa lan,mikapharalyanda,mkfarland,Макфарланд,مكفارلاند,مک‌فارلند، کالیفرنیا,मिकफारल्यान्ड,麦克法兰', 35.6780100, -119.2292700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144449, 'Mead Valley', 'Mead Valley', '', 33.8333500, -117.2961500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144450, 'Meadow Vista', 'Meadow Vista', '', 39.0010100, -121.0218900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144451, 'Mecca', 'Mecca', 'Mecca,Meka,Walters,mekka,mka  kalyfrnya,mkt,Мека,مكة,مکا، کالیفرنیا,मेक्का', 33.5721900, -116.0782000, 'US', '2014-11-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144452, 'Meiners Oaks', 'Meiners Oaks', 'Meiners Oak,Meiners Oaks', 34.4469400, -119.2792800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144453, 'Mendota', 'Mendota', 'Mendota,men duo ta,mendota,mndwta  kalyfrnya,myndwta,Мендота,مندوتا، کالیفرنیا,ميندوتا,मेन्दोता,门多塔', 36.7535600, -120.3815600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144454, 'Menifee', 'Menifee', 'Menifi,Munufij,mny fy  kalyfrnya,mynyfy,Менифи,Мънъфий,منی فی، کالیفرنیا,مينيفي,مینیفی', 33.7283500, -117.1464200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144455, 'Menlo Park', 'Menlo Park', 'Menlo Park,Menlo-Park,men lo phar k,men luo pa ke,menlo parka,menlopakeu,menropaku,mnlw park  kalyfrnya,mynlw bark,Менло Парк,Менло-Парк,منلو پارک، کالیفرنیا,مينلو بارك,मेन्लो पार्क,เมนโลพาร์ก,メンローパーク,门洛帕克,멘로파크', 37.4538300, -122.1821900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144456, 'Mentone', 'Mentone', '', 34.0700100, -117.1344800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144457, 'Merced', 'Merced', 'MCE,Merced,Mersed,Mursed,marsida,masedo,mei xi de,meosedeu,mrsd  kalyfrnya,myrsyd,Мерсед,Мърсед,مرسد، کالیفرنیا,مرسڈ,ميرسيد,मर्सिड,マーセド,美熹德,머세드', 37.3021600, -120.4829700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144458, 'Mesa Verde', 'Mesa Verde', 'Mesa Verde,Nicholls Warm Springs,Palowalla', 33.6058600, -114.7310700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144459, 'Midpines', 'Midpines', '', 37.5443800, -119.9204500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144460, 'Midway City', 'Midway City', '', 33.7447400, -117.9892300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144461, 'Mill Valley', 'Mill Valley', 'Mil Vali,Mil Valis,mi er gu,mila bhyali,milbaelli,ml faly,myl wly  kalyfrnya,Мил Вали,مل فالي,میل ولی، کالیفرنیا,मिल भ्याली,米尔谷,밀밸리', 37.9060400, -122.5449800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144462, 'Millbrae', 'Millbrae', 'Milbrej,mi er bu rui,milabre,milbeule,myl bry  kalyfrnya,mylbray,Милбрей,Милбреј,Мілбрей,ميلبراي,میل بری، کالیفرنیا,मिलब्रे,密尔布瑞,밀브레', 37.5985500, -122.3871900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144463, 'Milpitas', 'Milpitas', 'Milpitas,Penitencia,mi er pi ta si,milpitaja,milpitasa,mirupitasu,mylbytas,mylpytas,Милпитас,Мілпітас,ميلبيتاس,میلپیتاس,मिल्पिटास,मिल्पिताज,ミルピタス,米尔皮塔斯', 37.4282700, -121.9066200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144464, 'Minkler', 'Minkler', '', 36.7238400, -119.4581800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144465, 'Mira Loma', 'Mira Loma', 'Majra Loma,Mira Loma,Stalder,Wineville,mira loma,myra lwma,Мајра Лома,ميرا لوما,मिरा लोमा', 33.9925100, -117.5164400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144466, 'Mira Mesa', 'Mira Mesa', '', 32.9156000, -117.1439200, 'US', '2017-03-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144467, 'Mira Monte', 'Mira Monte', '', 34.4336100, -119.2851100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144468, 'Mission Canyon', 'Mission Canyon', '', 34.4508300, -119.7129100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144469, 'Mission Hills', 'Mission Hills', '', 34.6860900, -120.4368300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144470, 'Mission Hills', 'Mission Hills', '', 34.6930400, -120.4343300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144471, 'Mission Viejo', 'Mission Viejo', 'Mishen-V''ekho,Mishn-Vekho,Mishon Vijekho,Mishun Viekho,Mission Viejo,mi shen wei ye huo,misana bhi''eyo,misshonbieho,misyeonbieho,mshn wyjw,myshn wyjw  kalyfrnya,mysywn fyjw,Мишен-Вьехо,Мишон Вијехо,Мишън Виехо,Мішн-Вєхо,مشن ویجو,ميسيون فيجو,میشن ویجو، کالیفرنیا,मिसन भिएयो,ミッションビエホ,米申维耶霍,미션비에호', 33.6000200, -117.6720000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144472, 'Modesto', 'Modesto', 'MOD,Modesto,Ralston,meodeseuto,mo de si tuo,modesto,modesuto,mwdstw,mwdstw  kalyfrnya,mwdystw,Модесто,מודסטו,مودستو، کالیفرنیا,موديستو,موڈیسٹو,मोदेस्तो,モデスト,莫德斯托,머데스토', 37.6391000, -120.9968800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144473, 'Mojave', 'Mojave', 'MHV,Mohave,Mojave,Mokhavi,moyabhe,Мохави,मोयाभे', 35.0524700, -118.1739600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144474, 'Mono Vista', 'Mono Vista', '', 37.9977000, -120.2699100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144475, 'Monrovia', 'Monrovia', 'Monrovija,meng luo wei ya,monrobhiya,mwnrwfya,mwnrwya  kalyfrnya,Монровия,Монровија,Монровія,مونروفيا,مونرویا، کالیفرنیا,मोन्रोभिया,蒙罗维亚', 34.1480600, -117.9989500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144476, 'Montalvin', 'Montalvin', 'Montalvin,Montalvin Manor', 37.9954800, -122.3327500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144477, 'Montara', 'Montara', 'Montara,montara,Монтара,मोन्टारा', 37.5421600, -122.5160900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144478, 'Montclair', 'Montclair', 'Montclair,Monte Vista,Montkler,meng te ke lai er,montaklera,monteukeulleeo,montokurea,mwnt klyr  kalyfrnya,mwntklyr,Монтклер,مونت کلیر، کالیفرنیا,مونتكلير,मोन्टक्लेर,モントクレア,蒙特克莱尔,몬트클레어', 34.0775100, -117.6897800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144479, 'Monte Rio', 'Monte Rio', 'Monte Rio,Montrio', 38.4654700, -123.0088900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144480, 'Monte Sereno', 'Monte Sereno', 'Monte Sereno,Monte-Sereno,Monti Sereno,meng di sheng li nuo,monte sereno,mwnt syrynw,mwnth srnw  kalyfrnya,Монте Серено,Монте-Серено,Монти Серено,مونت سيرينو,مونته سرنو، کالیفرنیا,मोन्ते सेरेनो,蒙堤聖利諾', 37.2363300, -121.9924600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144481, 'Montebello', 'Montebello', 'Montebello,Montebelo,Newmark,meng ti bei luo,montebello,montebelo,montebero,mwntybylw,mwnt‌blw  kalyfrnya,Монтебелло,Монтебело,Մոնթեբելլո,مونتيبيلو,مونت‌بلو، کالیفرنیا,मोन्तेबेलो,モンテベロ,蒙提贝罗,몬테벨로', 34.0094600, -118.1053500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144482, 'Montecito', 'Montecito', 'Montecito,Montekito,Montesito,Monticito,montesito,Монтекито,Монтесито,मोन्तेसितो,몬테시토', 34.4366600, -119.6320800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144483, 'Monterey', 'Monterey', 'MRY,Monterei,Monterej,Monterey,Monterrey,mamtere,manterre,meng te lei,monteolei,montere,montore,mwnth‌ry  kalyfrnya,mwntryy,mwntyry,Μοντερέι,Монтерей,Монтереј,מונטריי,مونته‌ری، کالیفرنیا,مونتيري,माँटेरे,मोन्तेरे,மான்டெர்ரே,モントレー,蒙特雷,몬터레이', 36.6002400, -121.8946800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144484, 'Monterey Park', 'Monterey Park', 'Monterej Park,Monterey Park,Ramona Acres,meng te li gong yuan,montere parka,mwnth ry park  kalyfrnya,mwntyry bark,Монтерей Парк,Монтереј Парк,مونته ری پارک، کالیفرنیا,مونتيري بارك,मोन्तेरे पार्क,蒙特利公园', 34.0625100, -118.1228500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144485, 'Moorpark', 'Moorpark', 'Moorpark,Morpark,Murpark,Star of the Valley,mu er pa ke,muraparka,mwrpark  kalyfrnya,mwwrbark,Морпарк,Мурпарк,مورپارک، کالیفرنیا,مووربارك,मूरपार्क,穆尔帕克', 34.2855600, -118.8820400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144486, 'Morada', 'Morada', '', 38.0385300, -121.2457800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144487, 'Moraga', 'Moraga', 'Moraga,Moraga Town,Rheem,Rheem Valley,mo la jia,moraga,morryaga,mwraga  kalyfrnya,mwragha,Морага,موراغا,موراگا، کالیفرنیا,मोर्र्यागा,モラガ,莫拉加', 37.8349300, -122.1296900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144488, 'Moreno Valley', 'Moreno Valley', 'Moreno Vali,Moreno Valley,Moreno-Valli,mo lei nuo gu,morano bhyali,morenobare,mwrnw wly  kalyfrnya,mwrynw faly,mwrynw wyly,Морено Вали,Морено-Валли,Морено-Валлі,مورنو ولی، کالیفرنیا,مورينو فالي,مورینو ویلی,मोरनो भ्याली,モレノバレー,莫雷諾谷', 33.9375200, -117.2305900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144489, 'Morgan Hill', 'Morgan Hill', 'Morgan Hill,Morganhill', 37.1305000, -121.6543900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144490, 'Morongo Valley', 'Morongo Valley', '', 34.0469500, -116.5808500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144491, 'Morro Bay', 'Morro Bay', 'El Morro Bay,Mono Bay,Moro Bay,Moro Bej,Morou Bej,Morro,Morro Bay,Morro Beach,Morrofloi,Morroflói,mo luo bei,molobei,morro be,mwrrw bay  san lwys awbysbw  kalyfwrnya,mwrw by  kalyfrnya,Моро Беј,Мороу Бей,موررو باي، سان لويس أوبيسبو، كاليفورنيا,مورو بی، کالیفرنیا,मोर्रो बे,莫罗贝,모로베이', 35.3658100, -120.8499000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144492, 'Moss Beach', 'Moss Beach', '', 37.5274400, -122.5133100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144493, 'Mount Hermon', 'Mount Hermon', 'Mount Herman,Mount Hermon', 37.0510600, -122.0585700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144494, 'Mountain House', 'Mountain House', 'Mountain House,Mountain House Township', 37.7832600, -121.5427300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144495, 'Mountain Ranch', 'Mountain Ranch', 'El Dorado,El Dorado Town,Mountain Ranch', 38.2282500, -120.5407600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144496, 'Mountain View', 'Mountain View', '', 38.0088100, -122.1174600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144497, 'Mountain View', 'Mountain View', 'Mauntin Vju,Mauntin Vyu,Mauntin-V''ju,Mauntin-Vju,Mountain View,Mountainview,NUQ,Prospectus Montis,ma''untana vhyu,ma''unte''ina bhi''u,ma''untena bhyu,ma''untena vyu,mang ting wei you,mantyn wyw,mauntenbyu,mauntinbyu,mavuntan viyu,mawntn fyw,mea n the nwiw,shan jing cheng,Маунтин Вю,Маунтин Вју,Маунтин-Вью,Маунтін-Вю,מאונטיין ויו,مانتین ویو,ماونتن فيو,माउंटन व्ह्यू,माउंटेन व्यू,माउन्टेन भ्यु,माउन्टेन भ्यू,মাউন্টেইন ভিউ,மவுண்டன் வியூ,เมาน์เทนวิว,マウンテンビュー,山景城,芒廷维尤,마운틴뷰', 37.3860500, -122.0838500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144498, 'Mountain View Acres', 'Mountain View Acres', '', 34.4966600, -117.3489400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144499, 'Murphys', 'Murphys', 'Merfi,Murphy,Murphy''s,Murphy''s Camp,Murphy''s Diggins,Murphys,Queen of the Sierra,marphija,Мерфи,मर्फीज', 38.1376200, -120.4610500, 'US', '2015-01-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144500, 'Murrieta', 'Murrieta', 'Mjurijeta,Murieta,Murietta,Murrieta,Murrietta,RBK,marieta,mu lie ta,muri''eta,mwrryta  ryfyrsydy  kalyfwrnya,mwryta  kalyfrnya,Муриета,Мјуријета,مورريتا، ريفيرسيدي، كاليفورنيا,موریتا، کالیفرنیا,موریٹا,मुरिएटा,マリエータ,穆列塔', 33.5539100, -117.2139200, 'US', '2017-06-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144501, 'Murrieta Hot Springs', 'Murrieta Hot Springs', 'Hot Sulphur Springs,Murrieta Hot Springs', 33.5605800, -117.1580900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144502, 'Muscoy', 'Muscoy', '', 34.1541800, -117.3442100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144503, 'Napa', 'Napa', 'APC,Napa,Napa City,Nappa,na pa,naba,napa,napa  kalyfrnya,napa  kyly fwrnya,Напа,نابا,ناپا,ناپا، کالیفرنیا,ناپا، کیلی فورنیا,नापा,แนปา,ナパ,纳帕,나파', 38.2971400, -122.2855300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144504, 'National City', 'National City', 'Lungsod ng National,Nashonal Siti,National City,National Ranch,Neshunul Siti,Rancho de la Nacion *,n''yasanala siti,na xiong nai er cheng,naesyeoneolsiti,nashnal syty,nshnal syty  kalyfrnya,Нашонал Сити,Нешънъл Сити,ناشنال سيتي,نشنال سیتی، کالیفرنیا,نیشنل سٹی، کیلیفورنیا,न्यासनल सिटी,纳雄耐尔城,내셔널시티', 32.6781100, -117.0992000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144505, 'Needles', 'Needles', 'EED,Needles,Nidls,Nijduls,The Needles,ni de er si,nidalsa,nideulseu,nydlys,nydlz  kalyfrnya,Нидлс,Нийдълс,نيدليس,نیدلز، کالیفرنیا,नीडल्स,尼德尔斯,니들스', 34.8480600, -114.6141300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144506, 'Nevada City', 'Nevada City', 'Beer Creek Diggings,Caldwell''s Upper Store,Deer Creek Dry Diggins,Lungsod ng Nevada,Nevada,Nevada City,Nevada Lakanbalen,Nevada Siti,Nevada-Siti,Thanh pho Nevada,Thành phố Nevada,nebadashiti,nebadasiti,nebhada siti,nei hua da cheng,nwada syty  kalyfrnya,nyfada syty,Невада Сити,Невада-Сити,نوادا سیتی، کالیفرنیا,نيفادا سيتي,नेभादा सिटी,ネバダシティ,内华达城,네바다시티', 39.2617300, -121.0177900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144507, 'Newark', 'Newark', 'N''juark,Njuark,n''yu''arka,niu hua ke,nyueokeu,nywark,nywark  kalyfrnya,nywark  kylyfwrnya,Њуарк,Ньюарк,Нюарк,نيوارك,نیوآرک، کیلیفورنیا,نیوارک، کالیفرنیا,न्युआर्क,紐華克,뉴어크', 37.5296600, -122.0402400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144508, 'Newcastle', 'Newcastle', '', 38.8740700, -121.1332800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144509, 'Newman', 'Newman', 'Njuman,Njumun,n''yumyana,niu man,nywman,nywmn  kalyfrnya,nywmyn  kylyfwrnya,Њуман,Нюмън,نيومان,نیومن، کالیفرنیا,نیومین، کیلیفورنیا,न्युम्यान,纽曼', 37.3138300, -121.0207600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144510, 'Newport Beach', 'Newport Beach', 'JNP', 33.6189100, -117.9289500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144511, 'Nice', 'Nice', 'Clear Lake Villas,Nice', 39.1232300, -122.8483300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144512, 'Niland', 'Niland', 'Hobgood,Imperial Junction,Niland,Old Beach', 33.2400400, -115.5188800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144513, 'Nipomo', 'Nipomo', 'Nimpomo,Nipoma,Nipomo', 35.0427500, -120.4760000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144514, 'Norco', 'Norco', 'Norko,narko,nuo ke,nwrkw,nwrkw  kalyfrnya,Норко,نوركو,نورکو، کالیفرنیا,नर्को,诺科', 33.9311300, -117.5486600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144515, 'North Auburn', 'North Auburn', '', 38.9312900, -121.0818900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144516, 'North Edwards', 'North Edwards', 'Edgemont Acres,North Edwards,North Muroc', 35.0166400, -117.8328400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144517, 'North El Monte', 'North El Monte', '', 34.1027900, -118.0242300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144518, 'North Fair Oaks', 'North Fair Oaks', '', 37.4743800, -122.1966300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144519, 'North Glendale', 'North Glendale', '', 34.1605600, -118.2645200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144520, 'North Highlands', 'North Highlands', 'Nort Khajlands,nartha ha''ilyandsa,Норт Хајландс,नर्थ हाइल्यांड्स', 38.6857400, -121.3721700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144521, 'North Hollywood', 'North Hollywood', 'Lankershim,North Hollywood,Severnyj Gollivud,Toluca,noseuhalliudeu,Северный Голливуд,نورث هالیوود، لس‌آنجلس,노스할리우드', 34.1722300, -118.3789700, 'US', '2012-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144522, 'North Richmond', 'North Richmond', '', 37.9588100, -122.3674700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144523, 'Northridge', 'Northridge', 'Northridge,Zelzah,northarija,نورثریج، لس‌آنجلس,नॉर्थरिज', 34.2283400, -118.5367500, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144524, 'Norwalk', 'Norwalk', 'Corvallis,Noruok,Noruolk,Norvok,Norvolk,Norvolkas,Norwalk,naravaka,nou~oku,nowokeu,nuo wo ke,nwrwak  kalyfrnya,nwrwak  kylyfwrnya,nwrwalk,nwrwwq,Норвок,Норволк,Норуок,Норуолк,נורווק,نوروالك,نوروالک,نورواک، کالیفرنیا,نورواک، کیلیفورنیا,नरवाक,ノーウォーク,諾沃克,노워크', 33.9022400, -118.0817300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144525, 'Novato', 'Novato', 'NOT,Novato,nobhato,nuo wa tuo,nwfatw,nwwatw  kalyfrnya,Новато,نوفاتو,نوواتو، کالیفرنیا,नोभातो,诺瓦托', 38.1074200, -122.5697000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144526, 'Nuevo', 'Nuevo', '', 33.8014100, -117.1458700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144527, 'Oak Hills', 'Oak Hills', '', 34.3831300, -117.3813500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144528, 'Oak Park', 'Oak Park', 'Ouk-Park,Оук-Парк', 34.1791700, -118.7628700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144529, 'Oak View', 'Oak View', 'Oak View,Oakview', 34.4000000, -119.3001100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144530, 'Oakdale', 'Oakdale', 'Longworth,ODC,Oakdale,Oukdejl,ao ke dai er,awakdaly,awk dyl  kalyfrnya,okadela,Оукдейл,Оукдејл,أواكدالي,اوک دیل، کالیفرنیا,ओकडेल,奥克戴尔', 37.7665900, -120.8471500, 'US', '2017-04-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144531, 'Oakhurst', 'Oakhurst', 'Fresno Flats,Oakhurst,Oukkherst,okaharsta,Оукхерст,ओकहर्स्ट', 37.3280000, -119.6493200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144532, 'Oakland', 'Oakland', 'Gorad Oklend,OAK,Oakland,Oakland i California,Okland,Oklandas,Oklend,Oklenda,Oouklant,Oukland,Ouklend,Quercupolis,ao ke lan,awkland,awklnd,okalanda,okalyanda,okeullaendeu,oklant,okurando,Όουκλαντ,Горад Окленд,Окланд,Окленд,Оукланд,Оукленд,Օքլենդ,אוקלנד,אקלאנד,أوكلاند,اوکلند,اوکلینڈ,اوکلینڈ، کیلیفورنیا,ओकलंड,ओकल्याण्ड,ओकल्यान्ड,ওকল্যান্ড,ஓக்லண்ட்,ოკლენდი,オークランド,奥克兰,奧克蘭,오클랜드', 37.8043700, -122.2708000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144533, 'Oakley', 'Oakley', 'Oukli,ao ke li,awakly,awkly  kalyfrnya,okali,okure,Оукли,أواكلي,اوکلی، کالیفرنیا,ओकली,オークレー,奥克利,奧克利', 37.9974200, -121.7124500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144534, 'Oasis', 'Oasis', 'Oasis,Oasis Station', 33.4658600, -116.0988900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144535, 'Occidental', 'Occidental', 'Howard''s Station,Howards,Meeker,Meekers,Occidental,Summit', 38.4074100, -122.9483300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144536, 'Oceano', 'Oceano', '', 35.0988600, -120.6123900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144537, 'Oceanside', 'Oceanside', 'OCN,Ocean Side,Oceanside,Oushansajd,Oushensajd,Oushunsajd,awshn sayd  kalyfrnya,awsyansydy,osanasa''ida,oshansaido,osyeonsaideu,ou shen sai de,Оушансајд,Оушенсайд,Оушънсайд,אושנסייד,أوسيانسيدي,اوشن ساید، کالیفرنیا,اوشینسائڈ,ओसनसाइड,オーシャンサイド,歐申賽德,오션사이드', 33.1958700, -117.3794800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144538, 'Oildale', 'Oildale', 'North Side,Oildale,Waits', 35.4196800, -119.0195500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144539, 'Ojai', 'Ojai', 'Nordhoff,Ojai,Ojailand,Ojain,Okhaj,ao hai zhen,awhay,awjy,ohai,oja''i,Охай,Охај,أوجي,اوهای,ओजाइ,奧海鎮,오하이', 34.4480500, -119.2428900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144540, 'Olivehurst', 'Olivehurst', 'Olivkherst,olibhaharsta,Оливхерст,ओलिभहर्स्ट', 39.0954500, -121.5521900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144541, 'Ontario', 'Ontario', 'ONT,Ontario,Ontehrio,an da e,antaryw  kalyfrnya,awntaryw,ontalio,ontario,ontariyo,Онтарио,Онтаріо,Онтэрио,أونتاريو,انتاریو، کالیفرنیا,اونٹاریو،کیلیفورنیا,ओन्टारियो,オンタリオ,安大略,온타리오', 34.0633400, -117.6508900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144542, 'Opal Cliffs', 'Opal Cliffs', '', 36.9607800, -121.9641300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144543, 'Orange', 'Orange', 'JOR,Orandzh,Orange,Orindz,Orindzh,Richland,arenja,awranj,awrnj  kalyfrnya,awrynj,chen shi,olenji,orenji,Орандж,Ориндж,Оринџ,أورانج,اورنج، کالیفرنیا,اورینج,अरेन्ज,オレンジ,橙市,오렌지', 33.7877900, -117.8531100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144544, 'Orange Cove', 'Orange Cove', '', 36.6243900, -119.3137300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144545, 'Orangevale', 'Orangevale', 'Orange Vale,Orange Vale Colony,Orangevale,The Vale', 38.6785100, -121.2257800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144546, 'Orcutt', 'Orcutt', '', 34.8652600, -120.4360000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144547, 'Orinda', 'Orinda', 'Orinda,Orinda Park,ao lin da,awrynda,awrynda  kalyfrnya,orinda,Оринда,أوريندا,اوریندا، کالیفرنیا,ओरिन्डा,オリンダ,奥林达,奧林達', 37.8771500, -122.1796900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144548, 'Orland', 'Orland', 'Orland,Orlund,ao lan de,arlyanda,awrland,awrlnd  kalyfrnya,Орланд,Орлънд,أورلاند,اورلند، کالیفرنیا,अर्ल्यांड,奥兰德', 39.7473800, -122.1963700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144549, 'Orosi', 'Orosi', '', 36.5449500, -119.2873400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144550, 'Oroville', 'Oroville', 'OVE,Ophir,Ophir City,Orovil,Orovil'',Orovill,Oroville,ao luo wei er,awrwfyly,awrwwyl  kalyfrnya,orobhila,orobiru,Оровил,Оровилл,Оровіль,أوروفيلي,اوروویل، کالیفرنیا,ओरोभिल,オーロビル,奥罗维尔', 39.5139400, -121.5577600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144551, 'Oxnard', 'Oxnard', 'OXR,Oksnard,Oxnard,aksanarda,ao ke si na de,awks nard  kalyfrnya,awksnard,ogseunadeu,okkusunado,Окснард,אוקסנארד,أوكسنارد,اوکس نارد، کالیفرنیا,اوکسنارڈ,अक्सनार्ड,オックスナード,奥克斯纳德,옥스나드', 34.1975000, -119.1770500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144552, 'Oxnard Shores', 'Oxnard Shores', '', 34.1908400, -119.2415000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144553, 'Pacheco', 'Pacheco', 'paseko,पाशेको', 37.9835300, -122.0752400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144554, 'Pacifica', 'Pacifica', 'Edgemar,Fairway Park,Pacifica,Pacífica,Pasifika,Pedro Point,Pedro Valley,Punta De Las Almejas,Rockaway Beach,Sharp Park,Vallemar,basyfyka  san matyw  kalyfwrnya,pa xi fei ka,pasyfyka  kalyfrnya,pyasiphika,Пасифика,باسيفيكا، سان ماتيو، كاليفورنيا,پاسیفیکا، کالیفرنیا,प्यासिफिका,帕西菲卡', 37.6138300, -122.4869200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144555, 'Pacific Grove', 'Pacific Grove', 'Pasifik Grouv,basyfyk ghrwfy,pasyfyk grww  kalyfrnya,pyasiphika grobha,tai ping yang cong lin,Пасифик Гроув,باسيفيك غروفي,پاسیفیک گروو، کالیفرنیا,प्यासिफिक ग्रोभ,太平洋丛林', 36.6177400, -121.9166200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144556, 'Pajaro', 'Pajaro', '', 36.9041200, -121.7485600, 'US', '2015-04-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144557, 'Palermo', 'Palermo', '', 39.4354400, -121.5380200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144558, 'Palm Desert', 'Palm Desert', 'Old McDonald Ranch,Palm Desert,Palm Dezert,Palm Dezurt,Palm Village,Palm-Dezert,Sand Hole,balm dysyrt,palm dzrt  kalyfrnya,pama dejarta,pamdejeoteu,zong lu sha mo,Палм Дезерт,Палм Дезърт,Палм-Дезерт,بالم ديسيرت,پالم دزرت، کالیفرنیا,पाम डेजर्ट,棕榈沙漠,팜데저트', 33.7225500, -116.3769700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144559, 'Palm Springs', 'Palm Springs', 'Agua Caliente,Big Palm Spring,PSP,Palm City,Palm Springs,Palm-Springs,Palm-Springz,Palmetto Spring,balm sbrynghs,palm aspryngz  kalyfrnya,palm spring s,pama springas,pamseupeulingseu,pamusupuringusu,zong lu quan,Палм Спрингс,Палм-Спрингс,Палм-Спрінгз,פאלם ספרינגס,بالم سبرينغس,پالم اسپرینگز، کالیفرنیا,पाम स्प्रिङ्गस्,ปาล์มสปริงส์,パームスプリングス,棕櫚泉,팜스프링스', 33.8303000, -116.5452900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144560, 'Palmdale', 'Palmdale', 'PMD,Palmdale,Palmdejl,balmdyl,palm dyl  kalyfrnya,pamadela,pamuderu,zong lu gu,Палмдейл,Палмдејл,פאלמדייל,بالمديل,پالم دیل، کالیفرنیا,پالم ڈیل,पामडेल,パームデール,棕櫚谷', 34.5794300, -118.1164600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144561, 'Palo Alto', 'Palo Alto', 'Gorad Pala-Al''ta,PAO,Palo Al''to,Palo Alto,Palo-Al''to,Palo-Alto,Paloalto,University Park,balw altw,pa luo ao duo,pa luo ao tu,paelloaelto,palo alto,palo elto,palw altw  kalyfrnya,palwaltw,paroaruto,Πάλο Άλτο,Горад Пала-Альта,Пало Алто,Пало Альто,Пало-Альто,פאלו אלטו,بالو ألتو,پالو آلتو، کالیفرنیا,پالوآلتو,पालो आल्टो,पालो एल्टो,パロアルト,帕羅奧圖,帕羅奧多,팰로앨토', 37.4418800, -122.1430200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144562, 'Palos Verdes Estates', 'Palos Verdes Estates', 'Palos Verdes Estates,Palos Verdes Peninsula', 33.8010500, -118.3924500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144563, 'Paradise', 'Paradise', 'Leonards Mill,PYS,Paradajs,Paradice,Paradise,Paraiso,Pari-O-Dice,Peradajz,Poverty Ridge,baradys,paradaisu,prdays  kalyfrnya,pyarada''ija,tian tang,Парадајс,Перадайз,باراديس,پردایس، کالیفرنیا,پيراڈائز، کیلیفورنیا,प्याराडाइज,パラダイス,天堂', 39.7596100, -121.6219200, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144564, 'Paramount', 'Paramount', 'Hynes,Paramaunt,Paramount,baramwwnt,pai la meng,paramwnt  kalyfrnya,pyarama''unta,Парамаунт,باراموونت,پارامونت، کالیفرنیا,پیراماؤنٹ، کیلیفورنیا,प्यारामाउन्ट,派拉蒙', 33.8894600, -118.1597900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144565, 'Parksdale', 'Parksdale', '', 36.9471700, -120.0229400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144566, 'Parkway', 'Parkway', '', 38.4960200, -121.4588400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144567, 'Parkwood', 'Parkwood', '', 36.9268900, -120.0446100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144568, 'Parlier', 'Parlier', 'Parlir,Parliur,barlyr,pa li ye,parliyah,parlyr  kalyfrnya,Парлир,Парлиър,بارلير,پارلیر، کالیفرنیا,पार्लियः,帕利耶', 36.6116200, -119.5270700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144569, 'Pasadena', 'Pasadena', 'Gorad Pasadehna,Indiana Colony,JPD,Pasadena,Pasadina,Pasadīna,Pasantina,Pasedena,basadyna,pa sa di na,paeseodina,pasadena,pasadyna  kalyfrnya,psdynh,Πασαντίνα,Горад Пасадэна,Пасадена,Пасадина,Փասադենա,פסדינה,باسادينا,پاسادینا، کالیفرنیا,پاساڈینا,पासादेना,แพซาดีนา,パサデナ,帕萨迪纳,패서디나', 34.1477800, -118.1445200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144570, 'Pasatiempo', 'Pasatiempo', '', 37.0043900, -122.0258000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144571, 'Paso Robles', 'Paso Robles', 'El Paso de Robles,PRB,Pasco Robles,Paso De Robles,Paso Robles,basw rwblys,ela paso de robleja,paso roblesa,pasoroburesu,pasw rwblz  kalyfrnya,Пасо Роблес,باسو روبليس,پاسو روبلز، کالیفرنیا,एल पासो दे रोब्लेज,पासो रोब्लेस,パソロブレス', 35.6266400, -120.6910000, 'US', '2006-01-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144572, 'Patterson', 'Patterson', 'Paterson,Patersun,batyrswn,pa te sen,patrswn  kalyfrnya,pyatarasana,Патерсон,Патерсън,باتيرسون,پاترسون، کالیفرنیا,प्याटरसन,帕特森', 37.4716000, -121.1296600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144573, 'Pedley', 'Pedley', '', 33.9752900, -117.4758800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144574, 'Penn Valley', 'Penn Valley', '', 39.1960000, -121.1910700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144575, 'Penngrove', 'Penngrove', 'Penn,Penn''s Grove,Penngrove,Penns,Penns Grove', 38.2996400, -122.6666500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144576, 'Perris', 'Perris', 'Peris,Perris,byrrys,pei li si,perisa,prys  kalyfrnya,Перис,Перрис,بيرريس,پریس، کالیفرنیا,पेरिस,佩里斯', 33.7825200, -117.2286500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144577, 'Petaluma', 'Petaluma', 'Chickaluma,Petaloma,Petaluma,Petluma,bytalwma,pei ta lu ma,petaluma,petaruma,ptalwma  kalyfrnya,Петалума,Петлума,بيتالوما,پتالوما، کالیفرنیا,पेतालुमा,ペタルーマ,佩塔卢马', 38.2324200, -122.6366500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144578, 'Phelan', 'Phelan', '', 34.4261100, -117.5722800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144579, 'Pico Rivera', 'Pico Rivera', 'Pico,Pico Rivera,Piko Rivera,Rivera,bykw ryfyra,pi ke li wei la,piko ribhera,pykw rywra  kalyfrnya,Пико Ривера,بيكو ريفيرا,پیکو ریورا، کالیفرنیا,पिको रिभेरा,皮科里韦拉', 33.9830700, -118.0967300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144580, 'Piedmont', 'Piedmont', 'Pemont,Pidmont,bydmwnt,pa''idamonta,pi meng te,pideumonteu,pydmant  kalyfrnya,Пидмонт,Пємонт,بيدمونت,پیدمانت، کالیفرنیا,पाइडमोन्ट,皮蒙特,피드몬트', 37.8243700, -122.2316300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144581, 'Pine Grove', 'Pine Grove', 'Lincoln,Pine Grove,Pinegrove', 38.4129700, -120.6588200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144582, 'Pine Mountain Club', 'Pine Mountain Club', '', 34.8463700, -119.1495500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144583, 'Pine Mountain Club', 'Pine Mountain Club', '', 34.8469200, -119.1567800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144584, 'Pine Valley', 'Pine Valley', '', 32.8214400, -116.5291800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144585, 'Pinole', 'Pinole', 'El Pinole,Il Pinole,Penole,Pinol,Pinole,Pinoli,bynwly,pi nuo er,pinola,pinoru,pynwl  kalyfrnya,Пинол,Пиноли,بينولي,پینول، کالیفرنیا,पिनोल,ピノール,皮諾爾,皮诺尔', 38.0043700, -122.2988600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144586, 'Pioneer', 'Pioneer', 'Pioneer,Pioneer Station', 38.4318600, -120.5718700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144587, 'Piru', 'Piru', 'Piru,Piru City,Piru Rancho,piru,पिरु', 34.4152700, -118.7939800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144588, 'Pismo Beach', 'Pismo Beach', 'El Pizmo,Pismo,Pismo Beach,Pizmo Bich,Pizmo-Bich,Pizmou Bijch,bysmw bytsh,pi si mo hai tan,pismo bica,pysmw bych  kalyfrnya,Пизмо Бич,Пизмо-Бич,Пизмоу Бийч,بيسمو بيتش,پیسمو بیچ، کالیفرنیا,पिस्मो बीच,皮斯摩海滩', 35.1427500, -120.6412800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144589, 'Pittsburg', 'Pittsburg', 'Black Diamond,City of New York of the Pacific,New York of the Pacific,Pitsb"rg,Pitsburg,Pittsburg,Pittsburgh,bytsbwrgh,pi ci bao,pi zi bao,picheubeogeu,pitsabarga,pittsubagu,pytz brg  kalyfrnya,Питсбург,Питсбърг,بيتسبورغ,پیتز برگ، کالیفرنیا,पिट्सबर्ग,ピッツバーグ,匹兹堡,匹茲堡,피츠버그', 38.0279800, -121.8846800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144590, 'Pixley', 'Pixley', '', 35.9685600, -119.2917800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144591, 'Piñon Hills', 'Pinon Hills', 'Desert Springs,Desmont,Pinon Hills,Piñon Hills,Smithson Springs', 34.4333300, -117.6467200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144592, 'Placentia', 'Placentia', 'Plasensha,Plasentija,blasyntya,peullasentia,plasntya  kalyfrnya,plesensiya,pu la sen,Пласентия,Пласенша,بلاسينتيا,پلاسنتیا، کالیفرنیا,प्लेसेन्सिया,普拉森,플라센티아', 33.8722400, -117.8703400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144593, 'Placerville', 'Placerville', 'Dry Diggings,Dry Diggins,Hangtown,Old Dry Diggings,Old Dry Diggins,PVF,Placerville,Plaservil,Plejsurvil,blysrfyl,plesarabhila,plysrwyl  kalyfrnya,pu lai se wei er,purasabiru,Пласервил,Плейсървил,بليسرفيل,پلیسرویل، کالیفرنیا,प्लेसरभिल,プラサービル,普莱瑟维尔', 38.7296300, -120.7985500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144594, 'Planada', 'Planada', 'Geneva,Planada,Whitton', 37.2907700, -120.3185200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144595, 'Pleasant Hill', 'Pleasant Hill', '', 37.9479800, -122.0608000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144596, 'Pleasanton', 'Pleasanton', 'Alisal,JBS,Pleasanton,Pleasonton,Plezant"n,Plezanton,blysantwn,peullejeonteon,plijentatana,plyzantwn  kalyfrnya,pu lai sen dun,Плезантон,Плезантън,بليسانتون,پلیزانتون، کالیفرنیا,प्लिजेन्टटन,普莱森顿,플레전턴', 37.6624300, -121.8746800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144597, 'Plumas Lake', 'Plumas Lake', '', 39.0207300, -121.5580200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144598, 'Pollock Pines', 'Pollock Pines', 'Polok Pajns,polaka pa''insa,Полок Пајнс,पोलक पाइन्स', 38.7613800, -120.5891100, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144599, 'Pomona', 'Pomona', 'Pomon,Pomona,bo mo na,bwmwna,pomona,pwmwna,pwmwna  kalyfrnya,pwmwnh,Помона,פומונה,بومونا,پومونا,پومونا، کالیفرنیا,पोमोना,ポモナ,波莫纳,포모나', 34.0552900, -117.7522800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144600, 'Port Hueneme', 'Port Hueneme', 'Hueneme,NTD,Port Hueneme,Port Uinijmi,Port Vajnimi,Port-Vajnimi,Wynema,bwrt hwynymy,huai ni mi gang,porta hyu''enema,pwrt hwnym  kalyfrnya,Порт Вајними,Порт Уинийми,Порт-Вайнімі,بورت هوينيمي,پورت هونیم، کالیفرنیا,पोर्ट ह्युएनेम,怀尼米港', 34.1477800, -119.1951100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144601, 'Portola', 'Portola', 'Headquarters,Mormon,Portola,Reposa,bo tuo la,bwrtwla,portola,pwrtwla  kalyfrnya,Портола,بورتولا,پورتولا، کالیفرنیا,पोर्टोला,波托拉', 39.8104600, -120.4691000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144602, 'Portola Hills', 'Portola Hills', '', 33.6791900, -117.6311600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144603, 'Porterville', 'Porterville', 'PTV,Porter''s Station,Porter''s Village,Porter''sville,Porters Trading Post,Portersville,Portervil,Porterville,Porturvil,Putnamville,bo te wei er,bwrtyrfyl,portarabhila,potabiru,pwrtrwyl  kalyfrnya,Портервил,Портървил,بورتيرفيل,پورترویل، کالیفرنیا,पोर्टरभिल,ポータービル,波特维尔', 36.0652300, -119.0167700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144604, 'Portola Valley', 'Portola Valley', 'Portola,Portola Vali,Portola Valley,Portolo Valley,bo tuo la gu,bwrtwla faly,portola bhyali,pwrtwla wly  kalyfrnya,Портола Вали,بورتولا فالي,پورتولا ولی، کالیفرنیا,पोर्टोला भ्याली,波托拉谷', 37.3841100, -122.2352400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144605, 'Poway', 'Poway', 'Pauej,Pawai,Poway,baway,bo wei,pawei,pove,pwwy  kalyfrnya,Пауей,Пауеј,باواي,پووی، کالیفرنیا,पोवे,波威,파웨이', 32.9628200, -117.0358600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144606, 'Prunedale', 'Prunedale', '', 36.7757900, -121.6696700, 'US', '2015-06-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144607, 'Quail Valley', 'Quail Valley', '', 33.7069700, -117.2450400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144608, 'Quartz Hill', 'Quartz Hill', '', 34.6452600, -118.2181300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144609, 'Quincy', 'Quincy', 'American Ranch,Kuinsi,Kvinsi,Quincy,Quinsy,kuinshi,kvinsi,kwynsy  kylyfwrnya,Квинси,Куинси,کوئنسی، کیلیفورنیا,क्विन्सी,クインシー', 39.9368200, -120.9464700, 'US', '2016-02-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144610, 'Rainbow', 'Rainbow', '', 33.4103100, -117.1478100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144611, 'Ramona', 'Ramona', 'Nuevo,Ramona,Valley of the Sun,ramona,Рамона,रमोना', 33.0417100, -116.8680800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144612, 'Rancho Calaveras', 'Rancho Calaveras', '', 38.1274200, -120.8582700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144613, 'Rancho Calaveras', 'Rancho Calaveras', '', 38.1275000, -120.8583300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144614, 'Rancho Cordova', 'Rancho Cordova', 'Rancho Kordova,lan qiao ke er duo wa,ranchw kwrdwwa  kalyfrnya,rantshw kwrdwfa,rryanco kordobha,Ранчо Кордова,رانتشو كوردوفا,رانچو کوردووا، کالیفرنیا,र्र्यान्चो कोर्दोभा,兰乔科尔多瓦', 38.5890700, -121.3027300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144615, 'Rancho Cucamonga', 'Rancho Cucamonga', 'Cucamonga,North Cucamonga,Nuestra Senora del Pilar de Cucamonga,Rancho Cucamonga,Rancho Kukamanga,Rancho Kukamonga,Rancho-Kukamonga,ku ka meng ge mu chang,laenchokukamong-ga,ranchokukamonga,ranchw kwkamwnga  kalyfrnya,rantshw kwkamwngha,rryanco kukamonga,Ранчо Кукаманга,Ранчо Кукамонга,Ранчо-Кукамонга,Ранчо-Кукамонґа,رانتشو كوكامونغا,رانچو کوکامونگا، کالیفرنیا,رانچھو کیوکامونگا,र्र्यान्चो कुकामोंगा,ランチョクカモンガ,庫卡蒙格牧場,랜초쿠카몽가', 34.1064000, -117.5931100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144616, 'Rancho Mirage', 'Rancho Mirage', 'Rancho Mirazh,laenchomilaji,lan qiao mi la,ranchw mayraj  kalyfrnya,rantshw myraj,rryanco miraja,Ранчо Мираж,رانتشو ميراج,رانچو مایراج، کالیفرنیا,र्र्यान्चो मिराज,兰乔米拉,랜초미라지', 33.7397400, -116.4127900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144617, 'Rancho Murieta', 'Rancho Murieta', '', 38.5018500, -121.0946700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144618, 'Rancho Palos Verdes', 'Rancho Palos Verdes', 'Rancho Palos Verdes,ranchw palws wrds  kalyfrnya,rantshw balws fyrdys,rryanco palosa bhardeja,Ранчо Палос Вердес,رانتشو بالوس فيرديس,رانچو پالوس وردس، کالیفرنیا,र्र्यान्चो पालोस भर्डेज', 33.7444600, -118.3870200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144619, 'Rancho Penasquitos', 'Rancho Penasquitos', '', 32.9594900, -117.1153100, 'US', '2017-03-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144620, 'Rancho San Diego', 'Rancho San Diego', '', 32.7472700, -116.9353000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144621, 'Rancho Santa Fe', 'Rancho Santa Fe', 'Rancho Santa Fe,San Dieguito Ranch,rryanco syanta phe,Ранчо Санта Фе,ریںچو سانتا فے، کیلیفورنیا,र्र्यान्चो स्यान्टा फे', 33.0203200, -117.2028100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144622, 'Rancho Santa Margarita', 'Rancho Santa Margarita', 'Rancho Santa Margarita,ranchw santa margaryta  kalyfrnya,rantshw santa margharyta,rryanco syanta margarita,Ранчо Санта Маргарита,رانتشو سانتا مارغاريتا,رانچو سانتا مارگاریتا، کالیفرنیا,र्र्यान्चो स्यान्टा मार्गारिता', 33.6408600, -117.6031000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144623, 'Redlands', 'Redlands', 'Lugonia,Redlands,Redlends,Redlunds,ledeullaenjeu,lei de lan ci,rdlndz  kalyfrnya,redalyandsa,reddoranzu,rydlands,Редландс,Редлендс,Редлъндс,ردلندز، کالیفرنیا,ريدلاندس,रेडल्यान्ड्स,レッドランズ,雷德兰兹,레들랜즈', 34.0555700, -117.1825400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144624, 'Redondo Beach', 'Redondo Beach', 'Redondo Beach,Redondo Bich,Redondo Bijch,Redondo-Bich,lei dong duo hai tan,lidondobichi,rdwndw bych  kalyfrnya,redondo bica,redondobichi,rydwndw bytsh,Редондо Бийч,Редондо Бич,Редондо-Бич,Редондо-Біч,ردوندو بیچ، کالیفرنیا,ريدوندو بيتش,ریڈونڈو بیچ، کیلیفورنیا,रेडोन्डो बीच,レドンドビーチ,雷东多海滩,리돈도비치', 33.8491800, -118.3884100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144625, 'Redwood City', 'Redwood City', 'Lungsod ng Redwood,Menzesville,Mezesville,Red Woods City,Redud Siti,Redvud Siti,Redvud-Siti,Redwood,Redwood City,Redwood Lakanbalen,hong mu cheng,ledeuudeusiti,rdwwd syty  kalyfrnya,redavuda siti,reddouddoshiti,rydwwd,Редвуд Сити,Редвуд-Сити,Редвуд-Сіті,Редуд Сити,ردوود سیتی، کالیفرنیا,ريدوود,ریڈووڈ شہر، کیلیفورنیا,रेडवूड सिटी,レッドウッドシティ,紅木城,레드우드시티', 37.4852200, -122.2363500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144626, 'Redwood Shores', 'Redwood Shores', '', 37.5318800, -122.2480200, 'US', '2012-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144627, 'Redwood Valley', 'Redwood Valley', 'Basil,Redwood Valley', 39.2654400, -123.2044500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144628, 'Reedley', 'Reedley', 'Ridli,Rijdli,li de li,ridali,rydly,rydly  kalyfrnya,Ридли,Рийдли,ريدلي,ریدلی، کالیفرنیا,रीडली,里德利', 36.5963400, -119.4504000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144629, 'Rialto', 'Rialto', 'Rial''to,Rialto,Rijalto,li ya tuo,liaelto,ri xal to,riaruto,riyalto,ryaltw,ryaltw  kalyfrnya,Риалто,Риальто,Ријалто,ريالتو,ریالتو، کالیفرنیا,ریالٹو,रियाल्तो,รีอัลโต,リアルト,里亚托,리앨토', 34.1064000, -117.3703200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144630, 'Richgrove', 'Richgrove', 'Rich Grove,Richgrove,Wildflower', 35.7966200, -119.1078800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144631, 'Richmond', 'Richmond', 'Richmond,Richmund,lichimeondeu,lie zhi wen,ricamanda,ritchimondo,rychmwnd  kalyfrnya,rytshmwnd,Ричмонд,Ричмънд,Річмонд,ريتشموند,ریچموند، کالیفرنیا,रिचमंड,リッチモンド,列治文,리치먼드', 37.9357600, -122.3477500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144632, 'Ridgecrest', 'Ridgecrest', 'Crumville,Ridgecrest,Ridzhkrest,Ridzkrest,li qi ke lai si te,lijikeuleseuteu,rijakresta,rydjkryst,ryjy krst  kalyfrnya,Риджкрест,Риџкрест,ريدجكريست,ریجی کرست، کالیفرنیا,रिजक्रेस्ट,里奇克莱斯特,리지크레스트', 35.6224600, -117.6709000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144633, 'Ridgemark', 'Ridgemark', '', 36.8124600, -121.3657700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144634, 'Rio Del Mar', 'Rio Del Mar', 'Rio del Mar', 36.9682800, -121.9002300, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144635, 'Rio Linda', 'Rio Linda', 'Dry Creek,Rio Linda,Río Linda,riyo linda,Рио Линда,रियो लिन्डा', 38.6910100, -121.4485700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144636, 'Ripon', 'Ripon', 'Ripon,Ripun,Stanislaus,Stanislaus City,li peng,ripom,rybwn,rypwn  kalyfrnya,Рипон,Рипън,Ріпон,ريبون,ریپون، کالیفرنیا,रिपों,里彭', 37.7415900, -121.1243800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144637, 'Riverbank', 'Riverbank', 'Burneyville,Riverbank,Rivurbank,li fu ban ke,ribharabyanka,ryfyrbank,rywr bank  kalyfrnya,Ривербанк,Ривърбанк,ريفيربانك,ریور بانک، کالیفرنیا,रिभरब्याङ्क,里弗班克', 37.7360400, -120.9354900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144638, 'Riverdale', 'Riverdale', 'Liberty Settlement,Riverdale', 36.4310600, -119.8595800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144639, 'Riverdale Park', 'Riverdale Park', '', 37.6093800, -121.0518800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144640, 'Riverside', 'Riverside', 'Jurupa,RAL,Riversaida,Riversaint,Riversajd,Riversayd,Riverside,Rivursajd,li fu sai de,libeosaideu,ribasaido,ribharasa''ida,riversaidi,rybrsyyd,ryfrsayd,rywrsayd  kalyfrnya,Ριβερσάιντ,Риверсайд,Риверсајд,Ривърсайд,Ріверсайд,ריברסייד,رور سائڈ,ريفرسايد,ریورساید، کالیفرنیا,रिभरसाइड,რივერსაიდი,リバーサイド,里弗赛德,리버사이드', 33.9533500, -117.3961600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144641, 'Rocklin', 'Rocklin', 'Rocklin,Rocklissa,Roklin,luo ke lin,rakalina,raklyn  kalyfrnya,rwklyn,Роклин,راکلین، کالیفرنیا,روكلين,रकलिन,罗克林', 38.7907300, -121.2357800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144642, 'Rodeo', 'Rodeo', 'Rodeo,rodiyo,Родео,रोडियो', 38.0329800, -122.2669100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144643, 'Rohnert Park', 'Rohnert Park', 'Ronert Park,Ronurt Park,luo nei te pa ke,ronarta parka,rwhnyrt bark,rwnrt park  kalyfrnya,Ронерт Парк,Ронърт Парк,رونرت پارک، کالیفرنیا,روهنيرت بارك,रोनर्ट पार्क,罗内特帕克', 38.3396400, -122.7011000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144644, 'Rolling Hills', 'Rolling Hills', '', 33.7573900, -118.3575200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144645, 'Rolling Hills Estates', 'Rolling Hills Estates', '', 33.7877900, -118.3581300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144646, 'Rollingwood', 'Rollingwood', '', 37.9652000, -122.3299700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144647, 'Romoland', 'Romoland', 'Romaland,Romola Farms,Romoland,Roneland', 33.7458500, -117.1750300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144648, 'Rosamond', 'Rosamond', 'Rozamond,rojamanda,Розамонд,रोजामंड', 34.8641400, -118.1634100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144649, 'Rosedale', 'Rosedale', '', 35.3835700, -119.1453800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144650, 'Roseland', 'Roseland', '', 38.4221300, -122.7280400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144651, 'Rosemead', 'Rosemead', 'Rouzmid,Rouzmijd,rojamida,rou shi mi,rwsymyd,rzmyd  kalyfrnya,Роузмид,Роузмийд,رزمید، کالیفرنیا,روزمیڈ، کیلیفورنیا,روسيميد,रोजमीड,柔似蜜', 34.0805700, -118.0728500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144652, 'Rosemont', 'Rosemont', 'Rozemont,Роземонт', 38.5518500, -121.3646700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144653, 'Roseville', 'Roseville', 'Griders,Roseville,Roseville Junction,Rouzvil,Rozvell,Rozvill,lojeubil,luo si wei er,rojabhila,rozubiru,rwzfyl,rzwyl  kalyfrnya,Розвелл,Розвилл,Роузвил,رزویل، کالیفرنیا,روزفيل,روسولے,रोजभिल,ローズビル,羅斯維爾,로즈빌', 38.7521200, -121.2880100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144654, 'Ross', 'Ross', 'Ros,Ross,Sunnyside,luo si,ras  kalyfrnya,rasa,rws,Рос,راس، کالیفرنیا,روس,रस,罗斯', 37.9624200, -122.5549800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144655, 'Rossmoor', 'Rossmoor', 'Leisure World,Rossmoor', 33.7855700, -118.0850600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144656, 'Rowland Heights', 'Rowland Heights', 'Rovland Khajts,luo lan gang,rolyanda ha''itsa,Ровланд Хајтс,रोल्यान्ड हाइट्स,罗兰岗', 33.9761200, -117.9053400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144657, 'Rubidoux', 'Rubidoux', 'Rubidoux,West Riverside,rubidu,rwbydwks,روبيدوكس,रुबिडू', 33.9961300, -117.4056000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144658, 'Running Springs', 'Running Springs', '', 34.2077900, -117.1092000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144659, 'Sacramento', 'Sacramento', 'Gorad Sakramenta,Kakalameko,New Helvetia,SAC,Sacramento,Sacramento Stad,Sacramentum,Sakramentas,Sakramento,Sakraments,Sakraminto,Sakraménto,cekramento,saekeulamento,saikaramainto,saikramento,sakramento,sakramntw,sakramntw  kalyfrnya,sakuramento,sekramento,sha jia mian du,sqrmntw,Σακραμέντο,Горад Сакрамента,Сакраменто,Սակրամենտո,סאקראמענטא,סקרמנטו,ساكرامنتو,ساکرامنتو,ساکرامنتو، کالیفرنیا,ساکرامنٹو,سکرامنٹو، کیلی فورنیا,साक्रामेंटो,साक्रामेन्टो,सेक्रामेन्टो,सेक्रामेन्तो,सैक्रामेण्टो,সাক্রামেন্টো,ਸੈਕਰਾਮੈਂਟੋ,சேக்ரமெண்டோ,แซคราเมนโต,საკრამენტო,ሳክራመንቶ,サクラメント,沙加緬度,새크라멘토', 38.5815700, -121.4944000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144660, 'Saint Helena', 'Saint Helena', 'St. Helena', 38.5051900, -122.4702600, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144661, 'Salida', 'Salida', 'Murphys Ferry,Salida', 37.7057600, -121.0849400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144662, 'Salinas', 'Salinas', 'SNS,Salinae,Salinas,sa li na si,salinasa,sallinaseu,salynas,salynas  kalyfrnya,sarinasu,Салинас,Салінас,ساليناس,سالیناس,سالیناس، کالیفرنیا,सालिनास,サリナス,萨利纳斯,살리나스', 36.6777400, -121.6555000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144663, 'Salton City', 'Salton City', 'SAS', 33.2986500, -115.9561100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144664, 'San Andreas', 'San Andreas', 'San Andrus,San-Andreas,saen-aendeulieoseu,san''andoreasu,syana endriyaja,Сан Андрус,Сан-Андреас,स्यान एन्ड्रियाज,サンアンドレアス,샌앤드리어스', 38.1960300, -120.6804900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144665, 'San Anselmo', 'San Anselmo', 'San Anselmo,san ansylmw,sheng an sai er mo,sn anslmw  kalyfrnya,syana enselmo,Сан Анселмо,سان أنسيلمو,سن آنسلمو، کالیفرنیا,स्यान एन्सेल्मो,圣安塞尔莫', 37.9746500, -122.5616400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144666, 'San Antonio Heights', 'San Antonio Heights', 'San Antonio,San Antonio Heights', 34.1555600, -117.6564400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144667, 'San Bernardino', 'San Bernardino', 'Kaampu`u,SBD,SBT,San Bernandino,San Bernardino,San-Bernardino,saenbeoneodino,san byrnardynw  kalyfwrnya,sanbanadino,sanbanadino_,sheng bei na di nuo,sn brnardynw  kalyfrnya,sn brnrdynw,Сан Бернандино,Сан Бернардино,Сан-Бернардино,סן ברנרדינו,سان بيرناردينو، كاليفورنيا,سانبرنارڈینو,سن برناردینو، کالیفرنیا,サンバーナーディーノ,サンバーナーディーノ_,聖貝納迪諾,샌버너디노', 34.1083400, -117.2897700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144668, 'San Bruno', 'San Bruno', '', 37.6304900, -122.4110800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144669, 'San Carlos', 'San Carlos', 'SQL,San Karlos,San-Karlos,san karlws,san karlws  kalyfrnya,sheng ka luo si,sn qrlws,syana karlosa,Сан Карлос,Сан-Карлос,סן קרלוס,سان كارلوس,سان کارلوس، کالیفرنیا,स्यान कार्लोस,圣卡洛斯', 37.5071600, -122.2605200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144670, 'San Clemente', 'San Clemente', 'San Clemente,San Klemente,San-Klemente,Spanish Village,saenkeullemente,san klmnt  kalyfrnya,san klymynty,sheng ke lai men te,syana klemente,Сан Клементе,Сан-Клементе,Սան Կլեմենտե,سان كليمينتي,سان کلمنت، کالیفرنیا,स्यान क्लेमेन्ते,แซนเคลเมนที,圣克莱门特,샌클레멘테', 33.4269700, -117.6119900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144671, 'San Diego', 'San Diego', 'Davis'' Folly,Didacopolis,Gorad San-Dyega,Graytown,Lungsod ng San Diego,New San Diego,SAN,San Diegas,San Diego,San Diegu,San Dijego,San Diyego,San Diyégo,San Miguel,San Ntienko,San-Diego,San-Dieqo,Sandjego,can tiyeko,saendiego,saendieigo,saina di''ego,san diyago,san dyyghw,san-diego,sana di''ego,sana diyago,sandiego,sena diyego,sheng de ya ge,sn dygw,sn dyygw,syana di''ego,Σαν Ντιέγκο,Горад Сан-Дыега,Сан Диего,Сан Дијего,Сан-Диего,Сан-Дієго,Սան Դիեգո,סאן דיעגא,סן דייגו,سان دييغو,سان ڈیاگو,سان ڈیگو,سن دیگو,सॅन डियेगो,सैन डिएगो,स्यान डिएगो,সান ডিয়াগো,ਸਾਨ ਦੀਏਗੋ,சான் டியேகோ,శాన్ డియాగో,แซนดีเอโก,სან-დიეგო,ሳንዲየጎ,サンディエゴ,聖地牙哥,샌디에고,샌디에이고', 32.7153300, -117.1572600, 'US', '2017-07-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144672, 'San Diego Country Estates', 'San Diego Country Estates', '', 33.0067100, -116.7836400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144673, 'San Dimas', 'San Dimas', 'Mud Springs,San Dimas,san dymas,san dymas  kalyfrnya,sheng di ma si,syana dimasa,Сан Димас,سان ديماس,سان دیماس، کالیفرنیا,स्यान दिमास,圣迪马斯', 34.1066800, -117.8067300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144674, 'San Fernando', 'San Fernando', 'SFR,San Fernando,San-Fernando,Sao Fernando,São Fernando,saenpeoneondo,san frnandw  kalyfrnya,san fyrnandw,sheng fei er nan duo,syana pharn''yando,Сан Фернандо,Сан-Фернандо,سان فرناندو، کالیفرنیا,سان فيرناندو,स्यान फर्न्यान्डो,圣费尔南多,샌퍼넌도', 34.2819500, -118.4389700, 'US', '2017-06-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144675, 'San Francisco', 'San Francisco', 'Franciscopolis,Frisco,Gorad San-Francyska,Kapalakiko,Khiu-kim-san,Khiu-kîm-sân,Lungsod ng San Francisco,New Albion,SF,SFO,San Francisco,San Franciscu,San Francisko,San Fransisco,San Fransiskas,San Fransisko,San Frantzisko,San Phransisko,San-Francisko,San-Fransisko,Sanfrancisko,Sao Francisco,São Francisco,Yerba Buena,can pirancisko,jiu jin shan,saenpeulan,saenpeulansiseuko,saina pharansisako,saina phransisko,san f ran si s ko,san fan shi,san fransskw,san fransyskw,san fransyskۆ,san phransisko,sana phransisako ka''unti,sana phransisko,sanfuranshisuko,sena phransisko,sn prnsysqw,syana phransisko,Σαν Φρανσίσκο,Горад Сан-Францыска,Сан Франсиско,Сан Франциско,Сан-Франциско,Сан-Франціско,Սան Ֆրանցիսկո,סאן פראנציסקא,סן פרנסיסקו,سان فرانسسکو,سان فرانسيسكو,سان فرانسیسکو,سان فرانسیسکۆ,सॅन फ्रान्सिस्को,सैन फ्रांसिस्को,स्यान फ्रान्सिस्को,সান ফ্রান্সিসকো কাউন্টি,সান ফ্রান্সিস্কো,ਸੈਨ ਫਰਾਂਸਿਸਕੋ,சான் பிரான்சிஸ்கோ,శాన్ ఫ్రాన్సిస్కో,സാൻ ഫ്രാൻസിസ്കോ,සැන් ෆ්‍රැන්සිස්කෝ,ซานฟรานซิสโก,སན་ཧྥུ་རན་སིས་ཁོ,ဆန်ဖရန်စစ္စကိုမြို့,სან-ფრანცისკო,サンフランシスコ,三藩市,旧金山,舊金山,샌프란,샌프란시스코', 37.7749300, -122.4194200, 'US', '2017-06-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144676, 'San Gabriel', 'San Gabriel', 'San Gabriel,San Gabrijel,San-Gabriel,San-Gejbriel,Sao Gabriel,São Gabriel,saengeibeulieol,san gabryl  kalyfrnya,san ghabryl,sheng gai bo,syana gyabriyala,Сан Габриел,Сан Габријел,Сан-Гейбриел,Сан-Ґабріел,سان غابريل,سان گابریل، کالیفرنیا,स्यान ग्याब्रियल,圣盖博,샌게이브리얼', 34.0961100, -118.1058300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144677, 'San Jacinto', 'San Jacinto', 'Hewitt Town,San DZasinto,San Jacinto,San Khasinto,San-Dzhasinto,san jasyntw,san jasyntw  kalyfrnya,sheng ha xin tuo,syana jyakinto,Сан Џасинто,Сан Хасинто,Сан-Джасинто,سان جاسينتو,سان جاسینتو، کالیفرنیا,स्यान ज्याकिन्तो,圣哈辛托', 33.7839100, -116.9586400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144678, 'San Joaquin', 'San Joaquin', 'San Joaquin,San Joaquín,San Khoakin,San Uakin,san jwakwyn,san khwakyn  kalyfrnya,sheng hua jin,syana jo''akvina,Сан Уакин,Сан Хоакин,سان جواكوين,سان خواکین، کالیفرنیا,स्यान जोआक्विन,圣华金', 36.6066200, -120.1890400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144679, 'San Joaquin Hills', 'San Joaquin Hills', '', 33.6116900, -117.8367200, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144680, 'San Jose', 'San Jose', 'Gorad San-Khaseh,Iosephopolis,Pueblo De Alvarado,Pueblo De San Jose De Guadalupe,SJC,San Chose,San Choze,San Chozė,San Jose,San Jose De Alvarado,San Jose De Guadalupe *,San Jose i California,San José,San Khose,San Khoze,San Xose,San Xosé,San-Joseo,San-Khose,San-Xose,Sanhose,Sanhosē,can hoce,sa n jwz,saeneojei,saina hoze,san hwzyh,san ose,san''noze,san-khose,sana hose,sana hoze,sanhose,sena hoje,sheng he xi,sn hwzh,sn‌khwzh  kalyfrnya,syana hose,Σαν Χοσέ,Горад Сан-Хасэ,Сан Хозе,Сан Хосе,Сан-Хосе,Սան Խոսե,סן חוזה,سا ن جوز,سان هوزيه,سان ہوزے، کیلیفورنیا,سن‌خوزه، کالیفرنیا,सान होसे,सॅन होजे,सैन होज़े,স্যান হোসে,ਸਾਨ ਹੋਜ਼ੇ,સાન હોસે,சான் ஹொசே,శాన్ ఓసె,ಸ್ಯಾನ್‌ ಜೋಸ್‌‌,แซนโฮเซ,სან-ხოსე,サンノゼ,聖荷西,산호세,새너제이', 37.3393900, -121.8949600, 'US', '2017-07-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144681, 'San Juan Bautista', 'San Juan Bautista', 'San Juan,San Juan Bautista,San Khuan Batista,San Khuan Bautista,San-Khuan-Bautista,san jwan batysta  kalyfrnya,san jwan bawtysta,sheng hu an bao di si ta,syana yu''am bautista,Сан Хуан Батиста,Сан Хуан Баутиста,Сан-Хуан-Баутіста,سان جوان باتیستا، کالیفرنیا,سان جوان باوتيستا,स्यान युआं बौटिस्टा,圣胡安包蒂斯塔', 36.8455100, -121.5380000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144682, 'San Juan Capistrano', 'San Juan Capistrano', 'San Khuan Kapistrano,San-Khuan-Kapistrano,san jwan kabystranw,sheng hu an - ka pi si te la nuo,sn khwan kpystranw  kalyfrnya,syana yu''am kyapistryano,Сан Хуан Капистрано,Сан Хуан Капістрано,Сан-Хуан-Капистрано,سان جوان كابيسترانو,سن خوان کپیسترانو، کالیفرنیا,स्यान युआं क्यापिस्ट्र्यानो,圣胡安 - 卡皮斯特拉诺', 33.5016900, -117.6625500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144683, 'San Leandro', 'San Leandro', 'Cherry City of California,San Leandro,San Lijandro,San-Leandro,saenliaendeulo,san lyandrw  kalyfrnya,san lyndrw,sanreandoro,sheng li an zhuo,syana liyandro,Сан Леандро,Сан Лијандро,Сан-Леандро,سان لئاندرو، کالیفرنیا,سان ليندرو,سان لیانڈرو,स्यान लीयान्द्रो,サンレアンドロ,聖利安卓,샌리앤드로', 37.7249300, -122.1560800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144684, 'San Lorenzo', 'San Lorenzo', 'Lorenzo,San Lorenzo,Squattersville', 37.6810400, -122.1244100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144685, 'San Luis Obispo', 'San Luis Obispo', 'SBP,San Luis Obispo,San Luis Oubispou,San-Luis-Obispo,saenlu-iseuobiseupo,san lwys awbysbw,san lwyys awbyspw  kalyfrnya,sanruisuobisupo,sheng lu yi si-ao bi si bao,syana lu''i obispo,Сан Луис Обиспо,Сан Луис Оубиспоу,Сан-Луїс-Обіспо,סן לואיס אוביספו,سان لوئیس اوبیسپو، کالیفرنیا,سان لويس أوبيسبو,स्यान लुई ओबिस्पो,サンルイスオビスポ,聖路易斯-奧比斯保,샌루이스오비스포', 35.2827500, -120.6596200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144686, 'San Marcos', 'San Marcos', 'San Marcos,San Markos,San-Markos,saenmakoseu,san markws,san markws  kalyfrnya,sanmarkws,sanmarukosu,sheng ma ke si,syana markosa,Сан Маркос,Сан-Маркос,سان ماركوس,سان مارکوس، کالیفرنیا,سانمارکوس,स्यान मार्कोस,サンマルコス,聖馬可斯,샌마코스', 33.1433700, -117.1661400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144687, 'San Marino', 'San Marino', 'San Marino,San-Marino,saenmalino,san marynw,san marynw  kalyfrnya,sheng ma li nuo,syana myarino,Сан Марино,Сан-Марино,Сан-Маріно,سان مارينو,سان مارینو، کالیفرنیا,स्यान म्यारिनो,圣玛利诺,샌마리노', 34.1214000, -118.1064600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144688, 'San Martin', 'San Martin', 'Mills Switch Station,San Martin,San Martín,San-Martin,sheng ma ding,syana maratina,Сан Мартин,Сан-Мартін,स्यान मारटिन,圣马丁', 37.0849500, -121.6102200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144689, 'San Mateo', 'San Mateo', 'Matthaeopolis,San Mateo,San Matheo,San-Mateo,saenmeoteio,san matyw,san matyw  kalyfrnya,sanmateo,sheng ma diao,syana myatiyo,Сан Матео,Сан-Матео,سان ماتيو,سان ماتیو، کالیفرنیا,سانماٹیو,स्यान म्याटियो,サンマテオ,聖馬刁,샌머테이오', 37.5629900, -122.3255300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144690, 'San Miguel', 'San Miguel', 'SYL,San Miguel', 35.7524700, -120.6962800, 'US', '2013-05-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144691, 'San Pablo', 'San Pablo', 'San Pablo,san bablw,san pablw  kalyfrnya,san pablw  kylyfwrnya,sanpaburo,sheng ba bo luo,sheng ba bu luo,syana pablo,Сан Пабло,سان بابلو,سان پابلو، کالیفرنیا,سان پابلو، کیلیفورنیا,स्यान पाब्लो,サンパブロ,圣巴勃罗,聖巴布羅', 37.9621500, -122.3455300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144692, 'San Pasqual', 'San Pasqual', '', 33.0917100, -116.9539200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144693, 'San Pedro', 'San Pedro', 'San Pedro,San Pedro y San Pablo,San Pedro y San Pablo Bicuner *,saenpideulo,sanpedoro,Сан Педро,サンペドロ,샌피드로', 33.7358500, -118.2922900, 'US', '2013-06-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144694, 'San Rafael', 'San Rafael', 'SRF,San Rafael,San Rafel,San-Rafael'',San-Rafel,Sao Rafael,São Rafael,san rafayyl,sanraferu,sheng la fei er,sn rafayl  kalyfrnya,syana raphela,Сан Рафаел,Сан Рафел,Сан-Рафаель,Сан-Рафел,سان رافاييل,سن رافائل، کالیفرنیا,स्यान राफेल,サンラフェル,圣拉菲尔', 37.9735300, -122.5310900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144695, 'San Ramon', 'San Ramon', 'Limerick,Lynchville,San Ramon,San Ramón,San-Ramon,san ramwn,san ramwn  kalyfrnya,sheng la meng,syana ramona,Сан Рамон,Сан-Рамон,سان رامون,سان رامون، کالیفرنیا,स्यान रामोन,圣拉蒙,聖拉蒙', 37.7799300, -121.9780200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144696, 'Sanger', 'Sanger', 'Sanger,Sengur,sang ge,sangr  kalyfrnya,sanjr,syangara,Сангер,Сенгър,سانجر,سانگر، کالیفرنیا,स्यांगर,桑格', 36.7080100, -119.5559700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144697, 'Santa Ana', 'Santa Ana', 'Gorad Santa-Ana,SNA,Santa Ana,Santa-Ana,Santanna,saentaaena,santa ana,santa ana  kalyfrnya,santa ana  kylyfwrnya,santaana,sheng an na,syanta ena,Горад Санта-Ана,Санта Ана,Санта-Ана,Սանտա Անա,סנטה אנה,سانتا آنا، کالیفرنیا,سانتا أنا,سانتا انا، کیلیفورنیا,स्यान्टा एना,แซนตาแอนา,サンタアナ,圣安娜,샌타애나', 33.7455700, -117.8678300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144698, 'Santa Barbara', 'Santa Barbara', 'Barbaropolis,La Laguna de la Concepcion *,SBA,Santa Barbara,Santa Barmpara,Santa Bàrbara,Santa Bárbara,Santa-Barbara,Santabarbara,saentababeola,samta barbara,santa barbara,santababara,sheng ba ba la,snta barbara  kalyfrnya,snth brbrh,syanta barbara,Σάντα Μπάρμπαρα,Санта Барбара,Санта-Барбара,סנטה ברברה,سانتا باربارا,سانٹا باربرا,سنتا باربارا، کالیفرنیا,सँटा बार्बरा,स्यान्टा बार्बरा,แซนตาบาร์บารา,サンタバーバラ,圣巴巴拉,샌타바버라', 34.4208300, -119.6981900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144699, 'Santa Clara', 'Santa Clara', 'Santa Clara,Santa Klara,Santa-Klara,saentakeullaela,santa klara,santa klara  kalyfrnya,santakurara,sheng ke la la,snth qlrh,syanta klera,Санта Клара,Санта-Клара,סנטה קלרה,سانتا كلارا,سانتا کلارا، کالیفرنیا,سانٹا کلارا,स्यान्टा क्लेरा,サンタクララ,圣克拉拉,샌타클래라', 37.3541100, -121.9552400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144700, 'Santa Clarita', 'Santa Clarita', 'Sanita Clarita,Santa Clarita,Santa Klarita,Santa-Klarita,saentakeullalita,santa klaryta,santa klaryta  kalyfrnya,santakurarita,sheng ta ke la li ta,snth qlryth,syanta klarita,Санта Кларита,Санта-Кларита,Санта-Кларіта,סנטה קלריטה,سانتا كلاريتا,سانتا کلاریتا، کالیفرنیا,سانٹا کلاریٹا,स्यान्टा क्लारिता,サンタクラリタ,聖塔克拉利塔,샌타클라리타', 34.3916600, -118.5425900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144701, 'Santa Cruz', 'Santa Cruz', 'City of the Holy Cross,Newport of California,Newport of the Pacific,Santa Cruz,Santa Krouz,Santa Krus,Santa Kruz,Santa-Krus,Santa-Kruz,Santakruza,Santakrūza,Surf City,Swantacruz,saentakeulujeu,santa krwz,santa krwz  kalyfrnya,santakuruzu,sheng ta ke lu zi,syanta kruja,Σάντα Κρουζ,Санта Круз,Санта Крус,Санта-Круз,Санта-Крус,سانتا كروز,سانتا کروز، کالیفرنیا,स्यान्टा क्रुज,サンタクルーズ,聖塔克魯茲,샌타크루즈', 36.9741200, -122.0308000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144702, 'Santa Fe Springs', 'Santa Fe Springs', 'Fulton Sulphur Springs,Santa Fe Springs,santa f sbrynghs,santa fy aspryngz  kalyfrnya,sheng fei si pu lin si,syanta phe springas,Санта Фе Спрингс,سانتا ف سبرينغس,سانتا فی اسپرینگز، کالیفرنیا,سانتا فے سپرنگز، کیلیفورنیا,स्यान्टा फे स्प्रिङ्गस्,圣菲斯普林斯', 33.9472400, -118.0853500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144703, 'Santa Margarita', 'Santa Margarita', '', 35.3899700, -120.6090600, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144704, 'Santa Maria', 'Santa Maria', 'Central City,Central Valley,Grangeville,SMX,Santa Maria,Santa Marija,Santa María,Santa-Marija,santa mariya,santa marya,santa marya  kalyfrnya,santamaria,sheng ma li ya,Санта Мария,Санта Марија,Санта-Мария,سانتا ماريا,سانتا ماریا، کالیفرنیا,سانٹا ماریا,सान्ता मारिया,サンタマリア,圣玛丽亚', 34.9530300, -120.4357200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144705, 'Santa Monica', 'Santa Monica', 'Gorad Santa-Monika,Monicopolis,SMO,Santa Monica,Santa Monika,Santa Mónica,Santa Mônica,Santa-Monika,Santamonika,canta monikka,saentamonika,santa mwnyka,santa mwnyka  kylyfwrnya,santa mۆnyka  kalyfۆrnya,santamonika,sheng mo ni ka,snta mwnyka  kalyfrnya,snth mwnyqh,syanta monika,Σάντα Μόνικα,Горад Санта-Моніка,Санта Моника,Санта-Моника,Санта-Моніка,סנטה מוניקה,سانتا مونيكا,سانتا مونیکا، کیلیفورنیا,سانتا مۆنیکا، کالیفۆرنیا,سانٹا مونیکا,سنتا مونیکا، کالیفرنیا,स्यान्टा मोनिका,சாந்தா மொனிக்கா,แซนตามอนิกา,サンタモニカ,圣莫尼卡,샌타모니카', 34.0194500, -118.4911900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144706, 'Santa Paula', 'Santa Paula', 'SZP,Santa Pola,Santa-Paula,santa bawla,santa paywla  kalyfrnya,sheng bao la,syanta pala,Санта Пола,Санта-Паула,سانتا باولا,سانتا پائولا، کالیفرنیا,स्यान्टा पला,圣保拉', 34.3541700, -119.0592700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144707, 'Santa Rosa', 'Santa Rosa', 'Franklin Town,STS,Santa Rosa,Santa Roza,Santa-Rosa,Santa-Roza,saentaloja,santa rwsa,santa rwza  kalyfrnya,santaroza,sheng luo sha,snth rwzh,syanta roja,Санта Роза,Санта Роса,Санта-Роза,Санта-Роса,סנטה רוזה,سانتا روزا، کالیفرنیا,سانتا روسا,سانٹا روزا,स्यान्टा रोजा,サンタローザ,聖羅莎,샌타로자', 38.4404700, -122.7144300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144708, 'Santa Susana', 'Santa Susana', '', 34.2716700, -118.7089800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144709, 'Santa Venetia', 'Santa Venetia', '', 37.9985300, -122.5252500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144710, 'Santa Ynez', 'Santa Ynez', 'New Town,SQA,Sagunto,Santa Inez,Santa Ynez,syanta yneja,Санта Инез,स्यान्टा य्नेज', 34.6144300, -120.0798700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144711, 'Santee', 'Santee', 'Cowles,Cowles Station,Cowlestown,Fanita,Santee,Santi,Sentij,saenti,sang di,santy,santy  kalyfrnya,syanti,Санти,Сентий,سانتي,سانتی، کالیفرنیا,स्यान्टी,桑蒂,샌티', 32.8383800, -116.9739200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144712, 'Saranap', 'Saranap', 'Dewing Park,Sacanap,Saranap', 37.8849200, -122.0760700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144713, 'Saratoga', 'Saratoga', 'Bank Mills,McCarthysville,Redwood Mills,Saratoga,sa la tuo jia,saratoga,saratwga  kalyfrnya,saratwgha,Саратога,Саратоґа,ساراتوغا,ساراتوگا، کالیفرنیا,सारातोगा,サラトガ,薩拉托加', 37.2638300, -122.0230100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144714, 'Saticoy', 'Saticoy', 'Lower Saticoy,Saticoy', 34.2830600, -119.1498300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144715, 'Sausalito', 'Sausalito', 'El Ojo la Agua de Zaucito,JMC,Saucelito,Sauceta,Sauceto,Saucilito,Saucito,Sausalito,Sauselito,Sauzalito,Sosalito,Zaucito,sausalito,sausarito,sawsalytw,saywsalytw  kalyfrnya,suo sa li tuo,Саусалито,Саусаліто,Сосалито,سائوسالیتو، کالیفرنیا,ساوساليتو,सौसालितो,サウサリート,索萨利托', 37.8590900, -122.4852500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144716, 'Scotts Valley', 'Scotts Valley', 'Scott Valley,Scotts Valley,Skots Vali,Skots-Valli,askats wly  kalyfrnya,si ke ci gu,skatsabhyali,skwts faly,Скотс Вали,Скотс-Валлі,اسکاتس ولی، کالیفرنیا,سكوتس فالي,स्कट्सभ्याली,斯科茨谷', 37.0510600, -122.0146800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144717, 'Sea Ranch', 'Sea Ranch', '', 38.7151900, -123.4544500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144718, 'Seacliff', 'Seacliff', 'Seacliff,Seacliff Park', 36.9741200, -121.9157900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144719, 'Seal Beach', 'Seal Beach', 'Bay City,Seal Beach,Sijl Bijch,Sil Bich,hai bao tan,sila bica,silbichi,syl bych,syl bytsh,syl byz,Сийл Бийч,Сил Бич,סיל ביץ,سيل بيتش,سیل بیچ,सील बीच,海豹滩,실비치', 33.7414100, -118.1047900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144720, 'Searles Valley', 'Searles Valley', '', 35.7674500, -117.4039500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144721, 'Seaside', 'Seaside', 'East Monterey,Seaside,Sijsajd,Sisajd,hai bin,sisa''ida,sysayd  kalyfrnya,sysydy,Сийсайд,Сисайд,Сисајд,سيسيدي,سیساید، کالیفرنیا,सीसाइड,海滨', 36.6110700, -121.8516200, 'US', '2015-06-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144722, 'Sebastopol', 'Sebastopol', 'Pine Grove,Sebastopol,sai wa si tuo bo er,sebasatopola,sybastwbwl,Себастопол,سيباستوبول,सेबासतोपोल,塞瓦斯托波尔', 38.4021400, -122.8238800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144723, 'Sedco Hills', 'Sedco Hills', '', 33.6416900, -117.2908700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144724, 'Seeley', 'Seeley', '', 32.7931100, -115.6911100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144725, 'Selma', 'Selma', 'Sel''ma,Selma,sai er ma,selma,slma  kalyfrnya,sylma,Селма,Сельма,سلما، کالیفرنیا,سيلما,सेल्मा,塞尔玛', 36.5707800, -119.6120800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144726, 'Seven Trees', 'Seven Trees', '', 37.2860500, -121.8385600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144727, 'Shackelford', 'Shackelford', '', 37.6138200, -120.9927100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144728, 'Shadow Hills', 'Shadow Hills', '', 34.2619500, -118.3517500, 'US', '2017-04-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144729, 'Shafter', 'Shafter', 'MIT,Shafter,Shaftur,saphtara,sha fu te,shaftr  kalyfrnya,shaftyr,Шафтер,Шафтър,شافتر، کالیفرنیا,شافتير,शाफ्टर,沙夫特', 35.5005100, -119.2717800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144730, 'Shandon', 'Shandon', 'Shandon,Sunset', 35.6552500, -120.3754300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144731, 'Sherman Oaks', 'Sherman Oaks', 'syeomeon-okeuseu,شرمن اوکس، لس‌آنجلس,셔먼오크스', 34.1511200, -118.4492500, 'US', '2017-07-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144732, 'Shingle Springs', 'Shingle Springs', 'Shingle,Shingle Springs', 38.6657400, -120.9260500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144733, 'Sierra Madre', 'Sierra Madre', 'Siera Madre,Sijera Madre,ma de lei,siyara madre,syra madrh  kalyfrnya,syrra madry,Сиера Мадре,Сијера Мадре,سيررا مادري,سیرا مادره، کالیفرنیا,सियरा माद्रे,马德雷', 34.1616700, -118.0528500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144734, 'Signal Hill', 'Signal Hill', '', 33.8044600, -118.1678500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144735, 'Simi Valley', 'Simi Valley', 'Chimii,Simi,Simi Vali,Simi Valley,Simi-Vehlli,Simi-Velli,Simih,Simiopolis,shimibare,simi bhyali,simibaelli,smy wyly,symy faly,symy wly  kalyfrnya,xi mi gu,Сими Вали,Сими-Вэлли,Сімі-Веллі,סימי ואלי,سمی ویلی,سيمي فالي,سیمی ولی، کالیفرنیا,सिमि भ्याली,シミバレー,西米谷,시미밸리', 34.2694500, -118.7814800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144736, 'Sky Valley', 'Sky Valley', '', 33.8900100, -116.3525100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144737, 'Sleepy Hollow', 'Sleepy Hollow', '', 38.0104800, -122.5844200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144738, 'Soda Bay', 'Soda Bay', '', 39.0010100, -122.7891600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144739, 'Solana Beach', 'Solana Beach', 'Solana Bich,Solana Bijch,solena bica,sollanabichi,suo la na hai tan,swlana bych  kalyfrnya,swlana bytsh,Солана Бийч,Солана Бич,سولانا بيتش,سولانا بیچ، کالیفرنیا,सोलेना बीच,索拉纳海滩,솔라나비치', 32.9911500, -117.2711500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144740, 'Soledad', 'Soledad', 'Soledad,soledyada,suo lai da,swldd  kalyfrnya,swlydad,Соледад,سولدد، کالیفرنیا,سوليداد,सोलेड्याड,索莱达', 36.4246900, -121.3263200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144741, 'Solvang', 'Solvang', 'Solvang,Solvang i California,Solvanq,Solveng,solbhyanga,sorubangu,suo fu ang,swlfangh,swlwang  kalyfrnya,Солванг,Солвенг,سولفانغ,سولوانگ، کالیفرنیا,सोल्भ्यांग,ソルバング,索夫昂', 34.5958200, -120.1376500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144742, 'Sonoma', 'Sonoma', 'Sonoma,Zanoma,conoma,sonoma,swnwma,swnwma  kalyfrnya,Сонома,سونوما,سونوما، کالیفرنیا,सोनोमा,சோனோமா', 38.2918600, -122.4580400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144743, 'Sonora', 'Sonora', 'Sonora,Sonorian Camp,Stewart,sonara,sonora,suo nuo la,swnwra,swnwra  kalyfrnya,Сонора,سونورا,سونورا، کالیفرنیا,सोनारा,ソノラ,索诺拉', 37.9840900, -120.3821400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144744, 'Soquel', 'Soquel', 'El Rosario,Saquel,Sauguel,Sauquil,Shoquel,Soque,Soquel', 36.9880100, -121.9566300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144745, 'Sorrento Valley', 'Sorrento Valley', 'Soledad,Sorrento Valley', 32.8999100, -117.1945100, 'US', '2017-03-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144746, 'Soulsbyville', 'Soulsbyville', '', 37.9846500, -120.2638000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144747, 'South Dos Palos', 'South Dos Palos', 'Dos Palos Station,South Dos Palos', 36.9643900, -120.6532400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144748, 'South El Monte', 'South El Monte', 'Juzhen El Monti,Saut El Monti,Timog El Monte,nan ai er meng de,sa''utha ela monte,swt al mwnth  kalyfrnya,swwth al mwnty,Саут Ел Монти,Южен Ел Монти,سوت ال مونته، کالیفرنیا,سووث إل مونتي,साउथ एल मोन्ते,南艾爾蒙地', 34.0519500, -118.0467300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144749, 'South Gate', 'South Gate', 'Juzhen Gejt,Saut Gejt,South Gate,nan men,sa''utha geta,sausugeito,swt gyt  kalyfrnya,swth ghyt,sʼwt gyyt,Саут Гејт,Южен Гейт,סאות גייט,ساؤتھ گیٹ,ساؤتھ گیٹ، کیلیفورنیا,سوت گیت، کالیفرنیا,سوث غيت,साउथ गेट,サウスゲイト,南门', 33.9547400, -118.2120200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144750, 'South Lake Tahoe', 'South Lake Tahoe', 'Al Tahoe,Bihou Park,Bijou,Rowland''s,Saut Lejk Takho,South Lake Tahoe,Stateline,TVL,Tahoe Valley,Tallac Village,nan tai hao hu,sa''utha leka taho''i,swt lyk tahw  kalyfrnya,swwth lak tahwy,Саут Лейк Тахо,Саут Лејк Тахо,ساوتھ شور لیک تاہو,سوت لیک تاهو، کالیفرنیا,سووث لاك تاهوي,साउथ लेक ताहोई,南太浩湖', 38.9332400, -119.9843500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144751, 'South Oroville', 'South Oroville', '', 39.4965500, -121.5521900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144752, 'South Pasadena', 'South Pasadena', 'Juzhna Pasadina,Saut Pasadena,nan pa sa di na,sa''utha pasadena,sauseupaeseodina,sawt pasadna  kalyfrnya,swwth basadyna,Саут Пасадена,Южна Пасадина,ساوت پاسادنا، کالیفرنیا,سووث باسادينا,साउथ पासादेना,南帕萨迪纳,사우스패서디나', 34.1161200, -118.1503500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144753, 'South San Francisco', 'South San Francisco', 'Baden,Juzhen San Francisko,Saus-San-Francisko,Saut San Francisko,South San Francisco,nan jiu jin shan,sa''utha syana phransisko,saususanfuranshisuko,swt san fransyskw  kalyfrnya,swwth san fransyskw,Саус-Сан-Франциско,Саут Сан Франциско,Южен Сан Франциско,سوت سان فرانسیسکو، کالیفرنیا,سووث سان فرانسيسكو,साउथ स्यान फ्रान्सिस्को,サウスサンフランシスコ,南旧金山,南舊金山', 37.6546600, -122.4077500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144754, 'South San Gabriel', 'South San Gabriel', '', 34.0491500, -118.0946200, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144755, 'South San Jose Hills', 'South San Jose Hills', '', 34.0127900, -117.9047800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144756, 'South Whittier', 'South Whittier', '', 33.9501500, -118.0391700, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144757, 'South Yuba City', 'South Yuba City', '', 39.1165600, -121.6391300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144758, 'Spring Valley', 'Spring Valley', 'Spring Vali,Spring-Vehlli,springa bhyali,Спринг Вали,Спринг-Вэлли,سپرنگ ویلی، سان ڈیگو کاؤنٹی، کیلیفورنیا,स्प्रिङ्ग भ्याली', 32.7447700, -116.9989200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144759, 'Squaw Valley', 'Squaw Valley', '', 36.7402300, -119.2467900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144760, 'Stallion Springs', 'Stallion Springs', '', 35.0888600, -118.6425900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144761, 'Stanford', 'Stanford', 'Gorad Stehnfard,Stanford,Stenford,astnfwrd  kalyfrnya,seutaenpeodeu,shi dan fu,si tan fu,stanfwrd,styanapharda,Горад Стэнфард,Станфорд,Стенфорд,استنفورد، کالیفرنیا,ستانفورد,स्ट्यानफर्ड,史丹福,斯坦福,스탠퍼드', 37.4241100, -122.1660800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144762, 'Stanton', 'Stanton', 'Stanton,Stehnton,Stentun,astantwn  kalyfrnya,si tan dun,stantwn,styanatana,Стантон,Стентън,Стэнтон,استانتون، کالیفرنیا,ستانتون,سٹینٹن، کیلیفورنیا,स्ट्यानटन,斯坦顿', 33.8025200, -117.9931200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144763, 'Stockton', 'Stockton', 'SCK,Stockton,Stokt"n,Stokton,Tuleburg,Weberville,astwktwn,seutogteon,shi de dun,si tuo ke dun,stakatana,stwktwn,stwqtwn,sutokkuton,Стоктон,Стоктън,סטוקטון,استوکتون,ستوكتون,سٹوکٹن,स्टकटन,ストックトン,士德頓,斯托克顿,스톡턴', 37.9577000, -121.2907800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144764, 'Stratford', 'Stratford', 'Stratford,Stratton,Стратфорд', 36.1894000, -119.8231900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144765, 'Strathmore', 'Strathmore', 'Balfour,Filo,Roth''s Spur,Santos,Strathmore', 36.1455100, -119.0606600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144766, 'Strawberry', 'Strawberry', '', 37.8968700, -122.5088600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144767, 'Suisun', 'Suisun', 'Suisun,Suisun City', 38.2382500, -122.0402400, 'US', '2014-02-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144768, 'Summerland', 'Summerland', '', 34.4213800, -119.5965200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144769, 'Sun City', 'Sun City', '', 33.7091900, -117.1972600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144770, 'Sunland', 'Sunland', '', 34.2669500, -118.3023000, 'US', '2017-04-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144771, 'Sunnyside', 'Sunnyside', 'Granz,Maltermoro,Sunnyside', 36.7491200, -119.6993100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144772, 'Sunnyslope', 'Sunnyslope', '', 34.0119600, -117.4333800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144773, 'Sunnyvale', 'Sunnyvale', 'Encinal,S"nivejl,Sanivejl,Sannivejl,Sunnyvale,saniberu,sanivela,sannibhela,sanyfal,sany‌wyl  kalyfrnya,sen ni wei er,seonibeil,snywyl,Санивејл,Саннивейл,Саннівейл,Сънивейл,סאניווייל,سانيفال,سانی‌ویل، کالیفرنیا,سنیویل,सनीवेल,सन्नीभेल,サニーベール,森尼韦尔,서니베일', 37.3688300, -122.0363500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144774, 'Sutter', 'Sutter', 'South Butte,Sutter,Sutter City', 39.1598900, -121.7527500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144775, 'Sutter Creek', 'Sutter Creek', 'Sater Krik,Satur Krijk,Sutter,Sutter Creek,Sutter''s Creek,Suttercreek,Suttersville,sa te ke li ke,satr kryk  kalyfrnya,sutara krika,swtyr kryk,Сатер Крик,Сатър Крийк,ساتر کریک، کالیفرنیا,سوتير كريك,सुटर क्रीक,萨特克里克', 38.3929700, -120.8024400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144776, 'Taft', 'Taft', 'Moro,Moron,Siding Number Two,Taft,ta fu tuo,taft,taft  kalyfrnya,taphta,Тафт,تافت,تافت، کالیفرنیا,टाफ्ट,塔夫脱', 35.1424700, -119.4565100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144777, 'Taft Heights', 'Taft Heights', 'Boust City,Taft Heights', 35.1346900, -119.4726200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144778, 'Tahoe Vista', 'Tahoe Vista', '', 39.2399100, -120.0510200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144779, 'Tahoma', 'Tahoma', 'Chambers Lodge,Tahoma', 39.0674100, -120.1282400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144780, 'Talmage', 'Talmage', 'Talmadge,Talmage', 39.1332300, -123.1677800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144781, 'Tamalpais Valley', 'Tamalpais Valley', 'Big Coyote,Tamalpais Valley', 37.8796500, -122.5458100, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144782, 'Tara Hills', 'Tara Hills', '', 37.9935300, -122.3163600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144783, 'Tarpey Village', 'Tarpey Village', '', 36.7930100, -119.7009700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144784, 'Tehachapi', 'Tehachapi', 'Greenwich,TSP,Tehachapa,Tehachapai,Tehachapi,Tehachepi,Tehachipi,Tekhachapi,Tukhechapi,te ha cha bi,tehacapi,thachapy  kalyfrnya,tyhatshaby,Техачапи,Тъхечапи,تهاچاپی، کالیفرنیا,تيهاتشابي,तेहाचापी,特哈查比', 35.1321900, -118.4489700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144785, 'Temecula', 'Temecula', 'Temecula,Temecula Station,Temekjula,Temekula,te man ku la,temakula,temekyura,tmwkwla  kalyfrnya,tymykwla,Темекула,Темекјула,تموکولا، کالیفرنیا,تيميكولا,ٹیمکولا,तेमाकुला,テメキュラ,特曼库拉', 33.4936400, -117.1483600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144786, 'Temelec', 'Temelec', '', 38.2665800, -122.4927600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144787, 'Temple City', 'Temple City', 'Templ Siti,Temple,Temple City,Tempul Siti,tan pu er shi,tempala siti,tempeulsiti,tmpl syty  kalyfrnya,tymbl syty,Темпл Сити,Темпъл Сити,تمپل سیتی، کالیفرنیا,تيمبل سيتي,टेम्पल सिटी,ടെമ്പിൾ സിറ്റി,坦普爾市,템플시티', 34.1072300, -118.0578500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144788, 'Templeton', 'Templeton', 'Crocker,Templeton', 35.5496900, -120.7060000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144789, 'Terra Bella', 'Terra Bella', 'Deer Creek Switch,Salem,Terra Bella,Terrabella', 35.9624500, -119.0442700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144790, 'Thermal', 'Thermal', 'Kokell,TRM,Termal,Thermal,Термал', 33.6403000, -116.1394500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144791, 'Thermalito', 'Thermalito', '', 39.5112800, -121.5869200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144792, 'Thornton', 'Thornton', '', 38.2260300, -121.4246700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144793, 'Thousand Oaks', 'Thousand Oaks', 'Tauzand Ouks,Tauzend-Ouks,Tauzund Ouks,qian xiang shi,saujeondeuokeuseu,sauzandookusu,tawznd awks,tha''ujenda oksa,thwsnd awks,Таузанд Оукс,Таузенд-Оукс,Таузънд Оукс,تاوزند اوکس,تھاؤسینڈ اوکس,ثوسند أوكس,थाउजेन्ड ओक्स,サウザンドオークス,千橡市,사우전드오크스', 34.1705600, -118.8375900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144794, 'Thousand Palms', 'Thousand Palms', 'Edom,Thousand Palms', 33.8200200, -116.3902900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144795, 'Tiburon', 'Tiburon', 'E-Tiburon,Tiberon,Tiburon,Tiburón,di bo long,tibrana,tybwrwn,tybwrwn  kalyfrnya,Тиберон,Тибурон,تيبورون,تیبورون، کالیفرنیا,टिब्रन,蒂伯龙', 37.8735400, -122.4566400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144796, 'Tierra Buena', 'Tierra Buena', 'Terra Buena,Tierra Buena', 39.1487800, -121.6669100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144797, 'Tipton', 'Tipton', 'Tip Town,Tipton', 36.0594000, -119.3120600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144798, 'Topanga', 'Topanga', 'Topanga,Topanga Canyon,topang-ga,twpnga  kalyfrnya,Топанга,توپنگا، کالیفرنیا,토팡가', 34.0936200, -118.6014700, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144799, 'Toro Canyon', 'Toro Canyon', '', 34.4200000, -119.5670700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144800, 'Torrance', 'Torrance', 'TOA,Torans,Torrance,Torrans,Torrens,Toruns,toleonseu,toransa,toransu,tuo lun si,twrans  kalyfrnya,twrransy,Торанс,Торранс,Торренс,Торънс,تورانس، کالیفرنیا,توررانسي,ٹورینس,टोरान्स,トーランス,托倫斯,토런스', 33.8358500, -118.3406300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144801, 'Trabuco Canyon', 'Trabuco Canyon', 'Trabuco,Trabuco Canyon,Trabuco Oaks', 33.6625200, -117.5903300, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144802, 'Tracy', 'Tracy', 'Tracy,Trejsi,te lei xi,trasay,tresi,trysy  kalyfrnya,Трейси,Трејси,تراساي,تریسی، کالیفرنیا,ٹریسی,ट्रेसी,特雷西', 37.7398700, -121.4261800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144803, 'Truckee', 'Truckee', 'Coburn Station,TKF,Traki,Truckee,Truki,te la ji,teuleoki,torakki,traky  kalyfrnya,trki,trwky,Траки,Тръки,تراکی، کالیفرنیا,تروكي,ट्र्की,トラッキー,特拉基,트러키', 39.3279600, -120.1832500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144804, 'Tujunga', 'Tujunga', 'Los Terrenitos,Tuhunga,Tujunga', 34.2522300, -118.2884100, 'US', '2017-04-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144805, 'Tulare', 'Tulare', 'TLR,Tjuleri,Tular,Tuleri,tu lai li,tulera,twlary,twlr  kalyfrnya,Тулар,Тулери,Тюлери,تولاري,تولر، کالیفرنیا,टुलेर,图莱里', 36.2077300, -119.3473400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144806, 'Tuolumne City', 'Tuolumne City', '', 37.9627000, -120.2413000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144807, 'Turlock', 'Turlock', 'Sierra,Terlok,Turlock,Turlok,taralaka,te luo ke,trlwk,twrlak  kalyfrnya,Терлок,Търлок,ترلوك,تورلاک، کالیفرنیا,टरलक,特洛克', 37.4946600, -120.8465900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144808, 'Tustin', 'Tustin', 'Tastin,Tustin,Tustin City,ta si ting,tasatina,tastyn  kalyfrnya,teoseutin,twstyn,Тастин,Тъстин,تاستین، کالیفرنیا,توستين,टसटिन,塔斯廷,터스틴', 33.7458500, -117.8261700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144809, 'North Tustin', 'North Tustin', 'North Tustin,Tustin Foothills', 33.7644600, -117.7939400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144810, 'Twain Harte', 'Twain Harte', '', 38.0396500, -120.2326900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144811, 'Twentynine Palms', 'Twentynine Palms', 'TNP,Tuehntinajn-Palms,Tuentinajn Palms,Tventinajn Palms,Tventinajn-Palms,er shi jiu zong lu cun,tuwentinainpamseu,tventina''ina pamsa,twynty nayn palmz  kalyfrnya,twyntynyn balms,Твентинајн Палмс,Твентінайн-Палмс,Туентинайн Палмс,Туэнтинайн-Палмс,توئنتی ناین پالمز، کالیفرنیا,توينتينين بالمس,ट्वेन्टीनाइन पाम्स,二十九棕榈村,투웬티나인팜스', 34.1355600, -116.0541700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144812, 'Twin Lakes', 'Twin Lakes', '', 36.9674500, -121.9980200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144813, 'Ukiah', 'Ukiah', 'Jukaja,UKI,Ukiah,Ukiah City,uki''a,wkyah,you qi ya,yukaia,ywkyah  kalyfrnya,Јукаја,Юкайа,Юкая,وكياه,یوکیاه، کالیفرنیا,उकिआ,ユカイア,尤奇亚,유카이아', 39.1501700, -123.2077800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144814, 'Union City', 'Union City', 'Juni"n Siti,Junion Siti,Junion-Siti,Thanh pho Union,Thành phố Union,Union City,lian he shi,yunieonsiti,yuniyana siti,ywnyn syty  kalyfrnya,ywnywn syty,Јунион Сити,Юниън Сити,Юніон-Сіті,يونيون سيتي,یونین سٹی، کیلیفورنیا,یونین سیتی، کالیفرنیا,युनियन सिटी,聯合市,유니언시티', 37.5957700, -122.0191300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144815, 'Universal City', 'Universal City', 'Juniversal-Siti,Junivursul Siti,huan qiu shi,yunibeoseolsiti,ywnyfrsal syty,ywnywrsal syty  kalyfrnya,Юниверсал-Сити,Юнивърсъл Сити,يونيفرسال سيتي,یونیورسال سیتی، کالیفرنیا,環球市,유니버설시티', 34.1389000, -118.3534100, 'US', '2010-03-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144816, 'Upland', 'Upland', '"plend,Apland,CCB,Magnolia Villa,North Ontario,Upland,a pu lan,abland,ap lnd  kalyfrnya,apalyanda,eoblaendeu,Апланд,Ъпленд,آبلاند,آپ لند، کالیفرنیا,अपल्यांड,阿普兰,업랜드', 34.0975100, -117.6483900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144817, 'Upper Lake', 'Upper Lake', 'Aper Lejk,Upper Clear Lake,Upper Lake,Upperlake,apara leka,Апер Лејк,अपर लेक', 39.1646100, -122.9105500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144818, 'Vacaville', 'Vacaville', 'Vacaville,Vakavil,bhakabhila,fakafyly,wa ka wei er,wakawyl  kalyfrnya,Βάκαβιλ,Вакавил,فاكافيلي,واکاولے,واکاویل، کالیفرنیا,भाकाभिल,瓦卡维尔', 38.3565800, -121.9877400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144819, 'Val Verde', 'Val Verde', 'Val Verde,Val Verde Park', 34.4450000, -118.6575900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144820, 'Valencia', 'Valencia', '', 34.4436100, -118.6095300, 'US', '2012-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144821, 'Valinda', 'Valinda', '', 34.0452900, -117.9436700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144822, 'Valle Vista', 'Valle Vista', 'Florida,Valle Vista,Vallevista', 33.7478000, -116.8933600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144823, 'Vallejo', 'Vallejo', 'VLO,Val''ekho,Val''jo,Valejo,Valekho,Vallejo,balleio,bhaleyo,falyjw,vu~areho,wa lie huo,walhw  kalyfrnya,walyjw,Валехо,Валејо,Вальехо,Вальйо,فاليجو,والهو، کالیفرنیا,والیجو,भालेयो,ヴァレーホ,瓦列霍,발레이오', 38.1040900, -122.2566400, 'US', '2017-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144824, 'Valley Center', 'Valley Center', 'Valley Center,Valley Centre', 33.2183700, -117.0342000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144825, 'Valley Springs', 'Valley Springs', 'Spring Valley,Valley Spring,Valley Springs', 38.1915900, -120.8291000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144826, 'Van Nuys', 'Van Nuys', 'Van-Najs,baennaijeu,fan nwys,Ван-Найс,فان نويس,ون نایز، لس‌آنجلس,밴나이즈', 34.1866700, -118.4489700, 'US', '2012-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144827, 'Vandenberg Village', 'Vandenberg Village', '', 34.7083200, -120.4676600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144828, 'Ventura', 'Ventura', 'La Asumpta,La Asuncionde Nuestra Senora,La Pueblo de los Canoas,Mishkanakan,Mitskanakan,Poinsettia City,Ponsettia City by the Sea,Pueblo De las Canoas,Pueblo de Canoas,S B Ventura,San Buenaventura,The Palm City,Ventura,Ventura-by-the Sea,benchura,bentula,fyntwra,syana byuyanabhencura,wen tu la,wnchra,wntwra  kalyfrnya,Вентура,فينتورا,ونتورا، کالیفرنیا,ونچرا,स्यान ब्युयनाभेन्चुरा,ベンチュラ,文图拉,벤투라', 34.2783400, -119.2931700, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144829, 'Victorville', 'Victorville', 'Huntington,Mormon Crossing,VCV,Victor,Victorville,Viktorvil,Viktorvill,Vikturvil,bhiktarabhila,bigteobil,fyktwrfyly,vu~ikutavu~iru,wei ke duo wei er,wyktwr wyl  kalyfrnya,Викторвил,Викторвилл,Виктървил,فيكتورفيلي,وکٹورولے,ویکتور ویل، کالیفرنیا,भिक्टरभिल,ヴィクターヴィル,维克多维尔,빅터빌', 34.5361100, -117.2911600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144830, 'Villa Park', 'Villa Park', 'Mountain View,Vila Park,Villa Park,bhilla parka,fyla bark,wei la gong yuan,wyla park  kalyfrnya,Вила Парк,Вилла Парк,فيلا بارك,ویلا پارک، کالیفرنیا,भिल्ला पार्क,维拉公园', 33.8144600, -117.8131100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144831, 'Vincent', 'Vincent', '', 34.5005500, -118.1164600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144832, 'Visalia', 'Visalia', 'Buena Vista,VIS,Vajsejlija,Vajselija,Vicealia,Visaija,Visalia,Visejlija,baiseiria,bhisaliya,fysalya,wei sai li ya,wysalya,wysalya  kalyfrnya,Вайселия,Вајсејлија,Висейлия,Вісейлія,فيساليا,ویسالیا,ویسالیا، کالیفرنیا,भिसालिया,バイセイリア,維塞利亞', 36.3302300, -119.2920600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144833, 'Vista', 'Vista', 'Vista,bhista,biseuta,fysta,wei si ta,wysta  kalyfrnya,Виста,فيستا,وسٹا,ویستا، کالیفرنیا,भिस्टा,维斯塔,비스타', 33.2000400, -117.2425400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144834, 'Vista Santa Rosa', 'Vista Santa Rosa', '', 33.6278000, -116.2180600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144835, 'Waldon', 'Waldon', '', 37.9263100, -122.0555200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144836, 'Walnut', 'Walnut', 'Lemon,Uolnat,Uolnut,Volnat,Walnut,valanata,walnat  kalyfrnya,walnwt,wo er na te,Волнат,Уолнат,Уолнът,والنات، کالیفرنیا,والنوت,वालनट,沃尔纳特', 34.0202900, -117.8653400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144837, 'Walnut Creek', 'Walnut Creek', 'Uoln"t Krijk,Uolnat-Krik,Volnat Krik,Volnat-Krik,Walnut Creek,he tao xi,u~orunattokuriku,valanata krika,walnat kryk  kalyfrnya,walnwt kryk,wolneoskeulig,Волнат Крик,Волнат-Крік,Уолнат-Крик,Уолнът Крийк,والنات کریک، کالیفرنیا,والنوت كريك,वालनट क्रीक,ウォールナットクリーク,核桃溪,월넛크릭', 37.9063100, -122.0649600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144838, 'Walnut Grove', 'Walnut Grove', 'Volnat Grouv,Walnut Grove,Walnutgrove,valanata grobha,walnat grw  kalyfrnya,Волнат Гроув,والنات گرو، کالیفرنیا,वालनट ग्रोभ', 38.2421400, -121.5116200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144839, 'Walnut Park', 'Walnut Park', '', 33.9680700, -118.2250700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144840, 'Waterford', 'Waterford', 'Uoterford,Uoturford,Voterford,vatarapharda,watrfwrd  kalyfrnya,watyrfwrd,wo te fu de,Вотерфорд,Уотерфорд,Уотърфорд,واترفورد، کالیفرنیا,واتيرفورد,वाटरफर्ड,沃特福德', 37.6413200, -120.7604800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144841, 'Watsonville', 'Watsonville', 'Apple City,Pajaro,Sugar City,Uotsunvil,Votsonvil,WVI,Watsonville,vatasanabhila,watosonbiru,watswn wyl  kalyfrnya,watswnfyl,wo sen wei er,Вотсонвил,Уотсънвил,واتسون ویل، کالیفرنیا,واتسونفيل,वाटसनभिल,ワトソンビル,沃森维尔', 36.9102300, -121.7568900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144842, 'Weedpatch', 'Weedpatch', 'Alexander''s Corner,Weed Patch,Weedpatch', 35.2380200, -118.9151000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144843, 'Weldon', 'Weldon', '', 35.6657900, -118.2903600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144844, 'West Athens', 'West Athens', '', 33.9233500, -118.3034100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144845, 'West Carson', 'West Carson', '', 33.8216800, -118.2925700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144846, 'West Rancho Dominguez', 'West Rancho Dominguez', 'West Compton,West Rancho Dominguez', 33.8939000, -118.2706300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144847, 'West Covina', 'West Covina', 'Okcidenta Covina,Uehst-Kovina,Vest Kovina,West Covina,Zapadna Kovina,Zapadnaja Kovina,u~esutokobina,vesta kobhina,weseuteukobina,wst kwwyna  kalyfrnya,wst qwbynh,wyst kwfyna,xi ke wen na,Вест Ковина,Западна Ковина,Западная Ковина,Уэст-Ковина,וסט קובינה,وست کووینا، کالیفرنیا,وسٹ کووینا,ويست كوفينا,वेस्ट कोभिना,ウェストコビーナ,西柯汶纳,웨스트코비나', 34.0686200, -117.9389500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144848, 'West Hollywood', 'West Hollywood', 'Sherman,Vest Kholivud,West Hollywood,Zakhidnij Gollivud,Zapaden Kholivud,Zapadnyj Gollivud,vesta halivuda,weseuteuhalliudeu,wst halywwd  kalyfrnya,wyst hwlywwd,xi hao lai wu,Вест Холивуд,Западен Холивуд,Западный Голливуд,Західний Голлівуд,مغربی ہالی ووڈ، کیلیفورنیا,وست هالیوود، کالیفرنیا,ويست هوليوود,वेस्ट हलिवूड,ウェスト・ハリウッド,西好莱坞,웨스트할리우드', 34.0900100, -118.3617400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144849, 'West Menlo Park', 'West Menlo Park', '', 37.4335500, -122.2030200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144850, 'West Park', 'West Park', '', 36.7102300, -119.8512600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144851, 'West Puente Valley', 'West Puente Valley', '', 34.0516800, -117.9684000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144852, 'West Sacramento', 'West Sacramento', 'Vest Sakramento,Zapaden Sakramento,vesta syakramento,wst sakramntw  kalyfrnya,wyst sakramyntw,xi sa ke la men tuo,Вест Сакраменто,Западен Сакраменто,وست ساکرامنتو، کالیفرنیا,ويست ساكرامينتو,वेस्ट स्याक्रामेन्टो,西萨克拉门托', 38.5804600, -121.5302300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144853, 'Westlake Village', 'Westlake Village', 'Uestlejk Vilidzh,Vestlejk Vilidz,Vestlejk-Villedzh,u~esutoreikubirejji,vestaleka bhileja,weseuteuleikeubilliji,wst lyk wylyj  kalyfrnya,wystlak fylaj,xi hu cun,Вестлейк-Вілледж,Вестлејк Вилиџ,Уестлейк Вилидж,وست لیک ویلیج، کالیفرنیا,ويستلاك فيلاج,वेस्टलेक भिलेज,ウェストレイクビレッジ,西湖村,웨스트레이크빌리지', 34.1458400, -118.8056500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144854, 'Westminster', 'Westminster', 'Uestministur,Vestminster,Westminister,Westminster,vestaminstara,wei si min si te,wst mynstr  kalyfrnya,wystmynstyr,Вестминстер,Уестминистър,وست مینستر، کالیفرنیا,وسٹ منسٹر,ويستمينستير,वेस्टमिन्स्टर,威斯敏斯特', 33.7591800, -118.0067300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144855, 'Westmont', 'Westmont', '', 33.9414000, -118.3023000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144856, 'Westmorland', 'Westmorland', 'Westmoreland,Westmorland', 33.0372700, -115.6213800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144857, 'Westwood', 'Westwood', 'Sunset,Westwood Hills,Westwood  Los Angeles,weseuteuudeu,wst wwd,xi mu qu,وست وود,西木區,웨스트우드', 34.0561200, -118.4306300, 'US', '2017-04-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144858, 'Wheatland', 'Wheatland', 'Uijtlend,Vitland,hui te lan,vhitalyanda,wyt lnd  kalyfrnya,wytland,Витланд,Уийтленд,ويتلاند,ویت لند، کالیفرنیا,ویٹلینڈ، کیلیفورنیا,व्हिटल्यान्ड,惠特兰', 39.0098900, -121.4230100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144859, 'Whittier', 'Whittier', 'Uitiur,Vitir,Whittier,hui ti er,hwitieo,u~ittia,vhitiyara,waytyr  kalyfrnya,wytyr,Витир,Уитиър,وائٹئر,وایتیر، کالیفرنیا,ويتير,व्हिटियर,ウィッティア,惠提尔,휘티어', 33.9791800, -118.0328400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144860, 'Wildomar', 'Wildomar', 'Uajldomar,Vildomar,vikdomara,wyldwmar,wyldwmar  kalyfrnya,Вилдомар,Уайлдомар,ويلدومار,ویلدومار، کالیفرنیا,विक्डोमार', 33.5989100, -117.2800400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144861, 'Williams', 'Williams', 'Central,Uilijams,Vilijams,Williams,viliyamsa,wei lian mu si,wylyams,wylyamz  kalyfrnya,Вилијамс,Уилиямс,ويليامس,ویلیامز، کالیفرنیا,विलियम्स,威廉姆斯', 39.1546100, -122.1494200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144862, 'Willits', 'Willits', 'Little Lake,Uilits,Vilits,Willits,Willitsville,vilitsa,wei li ci,wylyts,wylytz  kalyfrnya,Вилитс,Уилитс,ويليتس,ویلیتز، کالیفرنیا,विलिट्स,威利茨', 39.4096100, -123.3555700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144863, 'Willowbrook', 'Willowbrook', 'Viloubruk,vilobruka,Вилоубрук,विलोब्रूक', 33.9169600, -118.2550700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144864, 'Willows', 'Willows', 'Uillous,Uilous,Villovs,Vilous,WLW,Willow,Willows,u~irozu,viloja,wei luo si,wylaws,wylwz  kalyfrnya,wylwz  kylyfwrnya,Вилоус,Вілловс,Уиллоус,Уилоус,ويلاوس,ویلوز، کالیفرنیا,ویلوز، کیلیفورنیا,विलोज,ウィローズ,威洛斯', 39.5243300, -122.1935900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144865, 'Wilton', 'Wilton', '', 38.4118600, -121.2721700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144866, 'Winchester', 'Winchester', '', 33.7069700, -117.0844700, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144867, 'Windsor', 'Windsor', 'Poor Man''s Flat,Uindzor,Vindzor,Windsor,vindara,wen sha,wyndswr,wyndswr  kalyfrnya,Виндзор,Уиндзор,ويندسور,ویندسور، کالیفرنیا,विन्डर,温莎', 38.5471300, -122.8163800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144868, 'Winters', 'Winters', 'Uinturs,Vinters,vintaras,wen te si,wyntrz  kalyfrnya,wyntyrs,Винтерс,Уинтърс,وينتيرس,وینترز، کالیفرنیا,विन्टरस्,温特斯', 38.5249100, -121.9708000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144869, 'Winter Gardens', 'Winter Gardens', '', 32.8311600, -116.9333600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144870, 'Winton', 'Winton', 'Windfield,Winton', 37.3893800, -120.6132500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144871, 'Wofford Heights', 'Wofford Heights', '', 35.7069000, -118.4562000, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144872, 'Woodacre', 'Woodacre', '', 38.0127000, -122.6452600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144873, 'Woodbridge', 'Woodbridge', 'Wood''s Ferry,Woodbridge,Woods'' Ferry', 38.1540800, -121.3013400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144874, 'Woodcrest', 'Woodcrest', '', 33.8822400, -117.3572700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144875, 'Woodlake', 'Woodlake', 'Udlejk,Vudlejk,vudaleka,wu de lai ke,wwdlyk  kalyfrnya,wwwdlaky,Вудлејк,Удлейк,وودلیک، کالیفرنیا,ووودلاكي,वूडलेक,伍德莱克', 36.4135600, -119.0987200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144876, 'Woodland', 'Woodland', 'By Hell,Udlend,Vudland,Woodland,Yolo City,uddorando,udeullaendeu,vudalyanda,wu de lan,wwdlnd  kalyfrnya,wwwdland,Вудланд,Удленд,وودلند، کالیفرنیا,ووودلاند,ووڈلینڈ، کیلیفورنیا,वूडल्यान्ड,ウッドランド,伍德兰,우들랜드', 38.6785200, -121.7733000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144877, 'Woodland Hills', 'Woodland Hills', 'Girad,Girard,Woodland Hills', 34.1683400, -118.6059200, 'US', '2012-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144878, 'Woodside', 'Woodside', 'Udsajd,Vudsajd,vudsa''ida,wu de sai de,wwdsayd  kalyfrnya,wwwdsyd,Вудсајд,Удсайд,وودساید، کالیفرنیا,ووودسيد,वूड्साइड,伍德赛德', 37.4299400, -122.2538600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144879, 'Woodville', 'Woodville', 'Irish Town,Irishtown,Sloverville,Wood''s Cabin,Woodsville,Woodville', 36.0935600, -119.1990000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144880, 'Wrightwood', 'Wrightwood', 'Circle C Ranch,Rajtvud,Wrightwood,ra''itavuda,Рајтвуд,राइटवूड', 34.3608300, -117.6333900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144881, 'Yorba Linda', 'Yorba Linda', 'Jorba Linda,Jorba-Linda,Jorbalinda,Yorba Linda,yobalinda,yobarinda,yobra linda,yue ba lin da,ywrba lynda,ywrba lynda  kalyfrnya,Јорба Линда,Йорба Линда,Йорба-Линда,Йорба-Лінда,يوربا ليندا,یوربا لیندا، کالیفرنیا,یوربہ لنڈا، کیلی فورنیا,योब्रा लिन्डा,ヨーバリンダ,约巴林达,요바린다', 33.8886300, -117.8131100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144882, 'Yosemite Lakes', 'Yosemite Lakes', '', 37.1910600, -119.7726500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144883, 'Yountville', 'Yountville', 'Jantvil,Jauntvil,Sebastopol,Yountville,yang te wei er,yontabhila,ywntwyl  kalyfrnya,ywntwyl  kyly fwrnya,ywwntfyl,Јаунтвил,Янтвил,يوونتفيل,یونتویل، کالیفرنیا,یونتویل، کیلی فورنیا,योन्टभिल,扬特维尔', 38.4015800, -122.3608100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144884, 'Yuba City', 'Yuba City', 'Juba Siti,Juba-Siti,Kota Yuba,Thanh pho Yuba,Thành phố Yuba,Yuba Lakanbalen,you ba cheng,yuba siti,yubashiti,ywba syty,ywba syty  kalyfrnya,Јуба Сити,Юба Сити,Юба-Сити,يوبا سيتي,یبا سٹی، کیلی فورنیا,یوبا سیتی، کالیفرنیا,युबा सिटी,ユバシティ,尤巴城', 39.1404500, -121.6169100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144885, 'Yucaipa', 'Yucaipa', 'Jukajpa,Jukipa,you ka pa,yuka''ipa,yukaipa,ywkaypa  kalyfrnya,ywkyba,ywkypa  kyly fwrnya,Јукајпа,Юкипа,يوكيبا,یوکایپا، کالیفرنیا,یوکیپا، کیلی فورنیا,युकाइपा,尤卡帕,유카이파', 34.0336300, -117.0430900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144886, 'Yucca Valley', 'Yucca Valley', 'Juka Vali,si lan gu,yka wyly  kyly fwrnya,yukabaelli,yukka bhyali,ywka wly  kalyfrnya,ywkka faly,Јука Вали,Юка Вали,يوككا فالي,یوکا ولی، کالیفرنیا,یکا ویلی، کیلی فورنیا,युक्का भ्याली,丝兰谷,유카밸리', 34.1141700, -116.4322400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144887, 'Acres Green', 'Acres Green', '', 39.5566600, -104.8960900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144888, 'Alamosa', 'Alamosa', 'ALS,Alamosa,Alamoza,a la mo sa,alamwsa,alamwsa  klradw,elamoja,Аламоза,Аламоса,آلاموسا، کلرادو,ألاموسا,الاموسا، کولوراڈو,एलामोजा,阿拉莫萨', 37.4694500, -105.8700200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144889, 'Applewood', 'Applewood', '', 39.7577800, -105.1625000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144890, 'Arvada', 'Arvada', 'Arvada,Arvado,Arveda,Ralston Point,Ralston Station,a wa da,abada,arbhada,arfada,arvada  kwlwradw,arwada  klradw,Арвада,Арведа,ארבאדה,آروادا، کلرادو,آرواڈا، کولوراڈو,آرڤادا، کولورادو,أرفادا,अर्भादा,アーバダ,阿瓦達', 39.8027600, -105.0874800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144891, 'Aspen', 'Aspen', 'ASE,Aspen,Aspenas,Aspun,Ute City,a si peng,aeseupeon,aespena,asbn,aspn  klradw,asupen,espena,Аспен,Аспън,Ասպեն,אספן,أسبن,اسپن، کلرادو,ایسپن، کولوراڈو,अॅस्पेन,एस्पेन,アスペン,阿斯彭,애스펀', 39.1911000, -106.8175400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144892, 'Aurora', 'Aurora', 'Aurora,Avrora,Fletcher,Orora,ao luo la,arwra  klradw,aurora,awrwra,olola,orora,Аврора,Аурора,Орора,אורורה,آرورا، کلرادو,أورورا,ارورا، کولوراڈو,ऑरोरा,औरोरा,オーロラ,奥罗拉,오로라', 39.7294300, -104.8319200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144893, 'Avon', 'Avon', 'Avin,Avon,Ehjvon,Ejvon,Ejvun,afwn,awwn  klradw,ebhona,ya fang,Ейвън,Ејвон,Эйвон,آوون، کلرادو,أفون,एभोन,雅芳', 39.6313700, -106.5222500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144894, 'Basalt', 'Basalt', 'Aspen Junction,Basalt,Basolt,Bazal''t,Bazalt,Eagle,Frying Pan City,basalt,basalt  klradw,basalta,xuan wu yan,Базалт,Базальт,Басолт,باسالت,باسالت، کلرادو,बसाल्ट,玄武岩', 39.3688700, -107.0328200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144895, 'Battlement Mesa', 'Battlement Mesa', '', 39.4413700, -108.0250700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144896, 'Bayfield', 'Bayfield', '', 37.2255600, -107.5981100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144897, 'Bennett', 'Bennett', 'Benet,Bennet,Bennett,Kiowa,bei nei te,beneta,bnt  klradw,bynyt,Бенет,Беннет,بنت، کلرادو,بينيت,बेनेट,贝内特', 39.7588700, -104.4274600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144898, 'Berkley', 'Berkley', '', 39.8044300, -105.0260900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144899, 'Black Forest', 'Black Forest', 'Blek Forist,blyaka pharesta,Блек Форист,ब्ल्याक फरेस्ट', 39.0130500, -104.7008100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144900, 'Breckenridge', 'Breckenridge', 'Breckenridge,Breckinridge,Brekenridz,Brekenridzh,Brekkinridzh,Brekunridzh,brekenarija,brknryj  klradw,bryknrydj,bu lei ken li qi,Брекенридж,Брекенриџ,Брекенрідж,Бреккинридж,Брекънридж,بريكنريدج,برکنریج، کلرادو,بریکنریج، کولوراڈو,ब्रेकेनरिज,布雷肯里奇', 39.4816500, -106.0383500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144901, 'Brighton', 'Brighton', 'Brajton,Brajtun,Brighton,Hughes,Hughes Junction,bra''itana,braytn  klradw,braytwn,bu lai dun,Брайтон,Брайтън,Брајтон,برائٹن، کولوراڈو,برايتون,برایتن، کلرادو,ब्राइटन,布莱顿', 39.9852600, -104.8205300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144902, 'Broomfield', 'Broomfield', 'BJC,Broomfield,Broomfield Heights,City of Broomfield,Zangs Spur', 39.9205400, -105.0866500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144903, 'Buena Vista', 'Buena Vista', 'Bjuna Vista,Buena Vista,bu ai na wen tu la,bwyna fysta,bwyna wysta  klradw,byuyana bhista,Буена Виста,Бјуна Виста,بوئنا ویستا، کلرادو,بوينا فيستا,بیونا وسٹا، کولوراڈو,ब्युयना भिस्टा,布埃纳文图拉', 38.8422200, -106.1311300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144904, 'Burlington', 'Burlington', 'Berlington,Burlington,Burlingtun,Lowell,barlingatana,bo ling dun,brlnghtwn,bwrlyngtwn  klradw,Берлингтон,Бърлингтън,برلنغتون,برلنگٹن، کولوراڈو,بورلینگتون، کلرادو,बर्लिङ्गटन,伯灵顿', 39.3061100, -102.2693600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144905, 'Byers', 'Byers', 'Bijou,Byers', 39.7113700, -104.2277400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144906, 'Cañon City', 'Canon City', 'CNE,Canon City,Canyon City,Cañon City,East Canon,Kanon Siti,Kanono siti,Keniun Siti,kann syty  klradw,kanwn syty,kyanana siti,Каноно сити,Кањон Сити,Кениън Сити,كانون سيتي,کانن سیتی، کلرادو,کینن سٹی، کولوراڈو,क्यानन सिटी', 38.4409800, -105.2424500, 'US', '2013-07-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144907, 'Carbondale', 'Carbondale', 'Karbondehjl,Karbondejl,Karbundejl,ka ben dai er,karbanadela,karbwndyl,krbwndyl  klradw,Карбондејл,Карбондэйл,Карбъндейл,كاربونديل,کاربنڈیل، کولوراڈو,کربوندیل، کلرادو,कार्बनडेल,卡本代尔', 39.4022100, -107.2111600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144908, 'Carriage Club', 'Carriage Club', '', 39.5324900, -104.9010900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144909, 'Castle Pines', 'Castle Pines', '', 39.4580400, -104.8960900, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144910, 'Castle Rock', 'Castle Rock', 'Kasl Rok,Kasul Rok,cheng bao shi,kasl rak  klradw,kasl rwk,kyasala raka,Касл Рок,Касъл Рок,كاسل روك,کاسل راک، کلرادو,کیسل راک، کولوراڈو,क्यासल रक,城堡石', 39.3722100, -104.8560900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144911, 'Castlewood', 'Castlewood', '', 39.5847100, -104.9010900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144912, 'Cedaredge', 'Cedaredge', '', 38.9016500, -107.9264500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144913, 'Centennial', 'Centennial', 'Centennial,Sentenial,Sentenijal,Sentennial,sen te ni er,senteniaru,sntnyal  klradw,syntynyal,Сентениал,Сентенијал,Сентенниал,Сентенніал,Центенниал,סנטניאל,سنتنیال، کلرادو,سينتينيال,سینٹینیل، کولوراڈو,センテニアル,森特尼尔', 39.5791600, -104.8769200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144914, 'Center', 'Center', 'Center,Senter,Sentur,sen te,sentara,sntr,sntr  klradw,Сентер,Сентър,Центер,سنتر,سنتر، کلرادو,سینٹر، کولوراڈو,सेन्टर,森特', 37.7530600, -106.1086400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144915, 'Central City', 'Central City', 'Central Siti,Sentral Siti,sentrala siti,sntral syty,sntral syty  klradw,zhong xin cheng,Сентрал Сити,Централ Сити,سنترال سيتي,سنترال سیتی، کلرادو,सेन्ट्रल सिटी,中心城', 39.8019300, -105.5141600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144916, 'Cherry Hills Village', 'Cherry Hills Village', '', 39.6416500, -104.9594300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144917, 'Cheyenne Wells', 'Cheyenne Wells', '', 38.8214000, -102.3532400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144918, 'Cimarron Hills', 'Cimarron Hills', '', 38.8586100, -104.6988600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144919, 'Clifton', 'Clifton', 'Klifton,Клифтон', 39.0919300, -108.4489800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144920, 'Coal Creek', 'Coal Creek', '', 39.9063800, -105.3774900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144921, 'Colorado City', 'Colorado City', 'Colorado City,Crow Junction', 37.9452900, -104.8352600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144922, 'Colorado Springs', 'Colorado Springs', 'COS,Colorado Springs,El Paso,Fontes Coloratenses,Gorad Kalarada-Spryngs,Kolorado Springs,Kolorado Springsas,Kolorado Sprinqs,Kolorado-Springs,Kolorado-Springz,Koloradospringsa,Koloranto Sprin''nks,Kolorādospringsa,kalorado sprinsa,ke luo la duo si pu lin si,klradw aspryngz,kolloladoseupeulingseu,kolorado springja,kolorado springs,kolorryado springas,kororadosupuringusu,kwlwradw sbrynghs,qwlwrdw spryngs,Κολοράντο Σπρινγκς,Горад Каларада-Спрынгс,Колорадо Спрингс,Колорадо-Спрингс,Колорадо-Спрінгз,Կոլորադո Սպրինգս,קולורדו ספרינגס,كولورادو سبرينغس,کلرادو اسپرینگز,کولاریڈو سپرنگس، کولاریڈو,कॉलोराडो स्प्रिंग्ज,कोलोराडो स्प्रिंग्स्,कोलोर्र्याडो स्प्रिङ्गस्,কলোরাডো স্প্রিংস,კოლორადო-სპრინგზი,コロラドスプリングス,科罗拉多斯普林斯,콜로라도스프링스', 38.8338800, -104.8213600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144923, 'Columbine', 'Columbine', 'Kolombina,Коломбина', 39.5877700, -105.0694300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144924, 'Columbine Valley', 'Columbine Valley', '', 39.6011000, -105.0322100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144925, 'Commerce City', 'Commerce City', 'Commerce City,Commerce Town,Derby,Komers Siti,Kommerse Siti,Kumurs Siti,kamarsa siti,kamrs syty  klradw,keomeoseusiti,kwmyrk syty,shang mao cheng,Комерс Сити,Коммерсе Сити,Къмърс Сити,كوميرك سيتي,کامرس سٹی، کولوراڈو,کامرس سیتی، کلرادو,कमर्स सिटी,商贸城,커머스시티', 39.8083200, -104.9338700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144926, 'Conejos', 'Conejos', '', 37.0883500, -106.0197400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144927, 'Cortez', 'Cortez', 'CEZ,Kortes,Kortez,Tse Yaatohi,Tsé Yaatóhí,karteja,ke er te si,kwrtyz,kwrtz  klradw,Кортез,Кортес,كورتيز,کورتز، کلرادو,کورٹیز، کولوراڈو,कर्टेज,科尔特斯', 37.3488800, -108.5859300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144928, 'Creede', 'Creede', 'Krid,Kriid,ke li de,krida,kryd,kryd  klradw,Крид,Криид,كريد,کرید، کلرادو,क्रीड,克里德', 37.8491700, -106.9264300, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144929, 'Crested Butte', 'Crested Butte', 'CSE,Krested Bat,Krested Bjut,kresteda bata,krstd bywt  klradw,krystyd bat,Крестед Бат,Крестед Бют,Крестед Бјут,كريستيد بات,کرستد بیوت، کلرادو,क्रेस्टेड बट', 38.8697100, -106.9878200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144930, 'Cripple Creek', 'Cripple Creek', 'Cripple Creek,Fremont,Kripl Krik,Kripl-Krik,Krippl Krik,Kripul Krijk,ke li pu er xi,kripala krika,krybl kryk,krypl kryk  klradw,Крипл Крик,Криппл Крик,Крипъл Крийк,Кріпл-Крік,كريبل كريك,کریپل کریک، کلرادو,क्रिपल क्रीक,克里普尔溪', 38.7466600, -105.1783100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144931, 'Del Norte', 'Del Norte', 'Del Nort,Del Norte,Del'' Norte,de er nuo te,dela narte,dl nwrth  klradw,dyl nwrt,Дел Норт,Дел Норте,Дель Норте,دل نورث، کلرادو,ديل نورت,डेल नर्टे,德尔诺特', 37.6788900, -106.3533700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144932, 'Delta', 'Delta', 'Dehl''ta,Delta,de er ta,delta,dlta,dlta  klradw,Делта,Дэльта,دلتا,دلتا، کلرادو,ڈیلٹا، کولوراڈو,डेल्टा,德尔塔', 38.7422100, -108.0689600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144933, 'Denver', 'Denver', 'DEN,Dehnver,Denber,Denv"r,Denver,Denver County,Denvera,Denveres,Denveris,Denverium,Denvero,Denverės,Denwer,Dénwér,Gorad Dehnver,Mile-High City,Ntenver,Queen City of the Plains,Saint Charles,The Mexican Diggings,The Spanish Diggings,dainavara,dan fu,denabhara,denabhara ka''unti,denavara,denba,denbeo,denbhara,denvar,denveri,denvhara,denwexr,dnfr,dnwr,dnwr  klradw,dnwwr,tenvar,Ντένβερ,Горад Дэнвер,Денвер,Денвър,Дэнвер,Դենվեր,דנוור,דענווער,دنفر,دنور,دنور، کلرادو,ڈینور,डॅनवर,डेन्भर,डेन्वर्,डेन्व्हर,देन्भर,ডেনভার,ডেনভার কাউন্টি,ਡੈਨਵਰ,டென்வர்,డెన్వర్,ഡെൻവർ,เดนเวอร์,დენვერი,ደንቨር,デンバー,丹佛,덴버', 39.7391500, -104.9847000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144934, 'Derby', 'Derby', '', 39.8394300, -104.9185900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144935, 'Dove Creek', 'Dove Creek', 'Dav Krik,Dov Krik,daw kryk  klradw,dobha krika,dwf kryk,jiu he,Дав Крик,Дов Крик,داو کریک، کلرادو,دوف كريك,डोभ क्रीक,鸠河', 37.7661000, -108.9059400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144936, 'Durango', 'Durango', 'DRO,Durango,Kin Lani,Kin Łání,de~yurango,du lan ge,durango,dwranghw,dwrangw  klradw,Дуранго,دورانغو,دورانگو، کلرادو,ڈورینگو، کولوراڈو,डुरांगो,デュランゴ,杜兰戈', 37.2752800, -107.8800700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144937, 'Eads', 'Eads', 'Dayton,Eads,Ids,ayds,ayds  klradw,idsa,yi ci,Идс,إيدس,ایدس، کلرادو,इड्स,伊兹', 38.4805600, -102.7818600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144938, 'Eagle', 'Eagle', 'Castle,EGE,Eagle,Igl,Igul,McDonald,Rio Aguila,ayghl,aygl  klradw,igala,yi ge er,Игл,Игъл,إيغل,ایگل، کلرادو,इगल,伊格尔', 39.6552600, -106.8286500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144939, 'Edgewater', 'Edgewater', 'Edzhuotur,Edzvoter,Ehdzhuater,ai qi wo te,aydjwwtr,ayjwatr  klradw,ejvatara,Еджуотър,Еџвотер,Эджуатер,إيدجووتر,ایجواتر، کلرادو,एज्वाटर,埃奇沃特', 39.7530400, -105.0641500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144940, 'Edwards', 'Edwards', 'Berrys Ranch,Edwards', 39.6449900, -106.5942000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144941, 'El Jebel', 'El Jebel', '', 39.3949800, -107.0903300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144942, 'Elizabeth', 'Elizabeth', 'Ehlizabet,Elizabet,alyzabt  klradw,alyzabyth,elijabetha,yi li sha bai,Елизабет,Элизабет,إليزابيث,الزبتھ، کولوراڈو,الیزابت، کلرادو,एलिजाबेथ,伊丽莎白', 39.3602700, -104.5969100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144943, 'Ellicott', 'Ellicott', '', 38.8383300, -104.3869100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144944, 'Englewood', 'Englewood', 'Ehnglevud,Englewood,Engulud,Fisks Gardens,Inglvud,Orchard Place,anglwwd  klradw,anjlwwd,en ge er wu de,eng-geul-udeu,enjelavuda,Енгълуд,Инглвуд,Энглевуд,إنجلوود,انگلوود، کلرادو,اینگلووڈ، کولوراڈو,एंजेलवूड,恩格尔伍德,엥글우드', 39.6477700, -104.9877600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144945, 'Evergreen', 'Evergreen', 'Evergreen,Evergrin,The Post,ebharagrina,Евергрин,एभरग्रीन', 39.6333200, -105.3172100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144946, 'Fairplay', 'Fairplay', 'Fairplay,Fehjrplehj,Ferplej,Platte City,South Park City,fayrply  klradw,fei er pu lai,fyrblay,pheyaraple,Ферплеј,Фэйрплэй,فایرپلی، کلرادو,فيربلاي,فیئرپلے، کولوراڈو,फेयरप्ले,费尔普莱', 39.2247100, -106.0019600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144947, 'Federal Heights', 'Federal Heights', '', 39.8513700, -104.9985900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144948, 'Florence', 'Florence', 'Florence,Florencija,Florens,Floruns,Frazerville,flwrns,flwrns  klradw,fu luo lun sa,furorensu,peullolenseu,phlorensa,Флоренс,Флоренция,Флорънс,فلورنس,فلورنس، کلرادو,فلورنس، کولوراڈو,फ्लोरेन्स,フローレンス,佛罗伦萨,플로렌스', 38.3902800, -105.1186000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144949, 'Fort Carson', 'Fort Carson', 'Camp Carson,Fort Carson,Fort Karson,pharta karasana,Форт Карсон,फर्ट कारसन', 38.7374900, -104.7888600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144950, 'Fountain', 'Fountain', 'Fauntin,Fountehjn,fawntn,fwntn  klradw,pen quan,pha''untena,Фаунтин,Фоунтэйн,فاؤنٹین، کولوراڈو,فاونتن,فونتن، کلرادو,फाउन्टेन,喷泉', 38.6822200, -104.7008100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144951, 'Fowler', 'Fowler', 'Fowler,Oxford Siding,Sibley,South Side', 38.1291700, -104.0232900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144952, 'Fraser', 'Fraser', 'Easton,Fraser,Frazier,Frehjzer,Frejzer,fryzr,fryzr  klradw,fu lei ze,phrejara,Фрејзер,Фрэйзер,فريزر,فریزر، کلرادو,फ्रेजर,弗雷泽', 39.9449900, -105.8172300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144953, 'Frisco', 'Frisco', 'Frisko,fryskw,fryskw  klradw,fu li si ke,phrisko,Фриско,فريسكو,فریسکو، کلرادو,فریسکو، کولوراڈو,फ्रिस्को,弗里斯科', 39.5744300, -106.0975200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144954, 'Fruita', 'Fruita', 'Fruita,Fruitdale,Fruta,frwta  klradw,frwyta,fu lu ta,peulu-ita,phruta,Фруита,Фрута,فروتا، کلرادو,فرويتا,फ्रुटा,弗鲁塔,프루이타', 39.1588700, -108.7289900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144955, 'Fruitvale', 'Fruitvale', '', 39.0816500, -108.4967600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144956, 'Genesee', 'Genesee', '', 39.6858200, -105.2727700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144957, 'Georgetown', 'Georgetown', 'Dzhordzhtaun,Dzhorzhtaun,Dzordztaun,jorjata''una,jrj‌tawn  klradw,jwrjtawn,qiao zhi dui,Џорџтаун,Джорджтаун,Джоржтаун,جارج ٹاؤن، کولوراڈو,جرج‌تاون، کلرادو,جورجتاون,जोर्जटाउन,乔治敦', 39.7061000, -105.6975000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144958, 'Glendale', 'Glendale', 'Glendehjl,Glendejl,ge lun dai er,ghlyndal,glenadela,glndyl  klradw,Глендейл,Глендэйл,غليندال,گلندیل، کلرادو,ग्लेनडेल,格伦代尔', 39.7049900, -104.9335900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144959, 'Gleneagle', 'Gleneagle', '', 39.0452700, -104.8244200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144960, 'Glenwood Springs', 'Glenwood Springs', 'Defiance,GWS,Glenud Springs,Glenvud Springs,Glenvud-Springs,Glenwood Hot Springs,Glenwood Springs,Glinvud Springs,ge lun wu de si pu lin si,ghlynwwd sbrynghz,glenavuda springas,glenavuda springja,glnwwd aspryngz  klradw,Гленвуд Спрингс,Гленвуд-Спрингс,Гленуд Спрингс,Глинвуд Спрингс,Ґленвуд-Спрінґс,غلينوود سبرينغز,گلنوود اسپرینگز، کلرادو,گلینووڈ سپرنگز، کولوراڈو,ग्लेनवूड स्प्रिंग्ज,ग्लेनवूड स्प्रिङ्गस्,グレンウッド・スプリングス,格伦伍德斯普林斯', 39.5505400, -107.3247800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144961, 'Golden', 'Golden', 'Golden,Goldun,ge er deng,ghwldn,gldn  klradw,goldena,Голден,Голдън,Ґолден,غولدن,گلدن، کلرادو,گولڈن، کولوراڈو,गोल्डेन,戈尔登', 39.7555400, -105.2211000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144962, 'Grand Junction', 'Grand Junction', 'GJT,Grand DZankshon,Grand Dzhankshen,Grand Dzhankshn,Grand Dzhunkshun,Grand Junction,Grand-Dzhankshen,Grand-Dzhankshn,Ute,da zhang ke shen,ghrand jnkshn,gramda janksana,grand jankshn  klradw,gryanda janksana,gurandojankushon,Гранд Џанкшон,Гранд Джанкшен,Гранд Джанкшн,Гранд Джънкшън,Гранд-Джанкшен,Ґранд-Джанкшн,גראנד גנקשן,غراند جنكشن,گراند جانکشن، کلرادو,گرینڈ جنکشن، کولوراڈو,ग्रँड जंक्शन,ग्र्यान्ड जंक्सन,グランドジャンクション,大章克申', 39.0638700, -108.5506500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144963, 'Greenwood Village', 'Greenwood Village', 'Grijnud Vilidzh,Grinvud Vilidz,Grinvud Villehjdzh,Grinvud-Villedzh,ge lin wu de cun,ghrynwwd fylyj,grinavuda bhileja,grynwwd wylyj  klradw,Грийнуд Вилидж,Гринвуд Вилиџ,Гринвуд Виллэйдж,Гринвуд-Вилледж,Ґрінвуд-Вілледж,غرينوود فيليج,گرینوود ویلیج، کلرادو,گرینووڈ گاؤں، کولوراڈو,ग्रीनवूड भिलेज,格林伍德村', 39.6172100, -104.9508100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144964, 'Gunnison', 'Gunnison', 'GUC,Ganison,Gannison,Gunisun,gannisana,ganysn  klradw,ghwnyswn,ji na sen,Ганисон,Ганнисон,Гънисън,غونيسون,گانیسن، کلرادو,گینیسن، کولوراڈو,गन्निसन,吉纳森', 38.5458200, -106.9253200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144965, 'Gypsum', 'Gypsum', 'Dzhipsum,Dzipsum,ghybswm,gypswm  klradw,ji pu se mu,jipsama,Џипсум,Джипсъм,غيبسوم,گیپسوم، کلرادو,जिप्सम,吉普瑟姆', 39.6469300, -106.9517100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144966, 'Highlands Ranch', 'Highlands Ranch', 'Hailands Rancas,Hailands Rančas,Highlands Ranch,Khajlands Ranch,ha''ilyandsa rryanca,Хайландс Ранч,Хајландс Ранч,हाइल्यांड्स र्र्यान्च', 39.5538800, -104.9694300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144967, 'Hugo', 'Hugo', '', 39.1361000, -103.4699400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144968, 'Idaho Springs', 'Idaho Springs', 'Ajdakho Spring,Ajdakho Springs,Idaho,Idaho City,Idaho Springs,Idahoe,Jacksons Diggings,Sacramento City,a''id''aho springas,ai da he quan,aydahw sbrynghz,aydahwaspryngz  klradw,Айдахо Спринг,Айдахо Спрингс,Ајдахо Спрингс,آیداهواسپرینگز، کلرادو,أيداهو سبرينغز,आइडाहो स्प्रिङ्गस्,爱达荷泉', 39.7424900, -105.5136100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144969, 'Indian Hills', 'Indian Hills', '', 39.6166500, -105.2372100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144970, 'Ken Caryl', 'Ken Caryl', '', 39.5758200, -105.1122100, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144971, 'Keystone', 'Keystone', '', 39.5994300, -105.9872400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144972, 'Kiowa', 'Kiowa', '', 39.3472100, -104.4644100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144973, 'Kittredge', 'Kittredge', '', 39.6547100, -105.2997100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144974, 'La Junta', 'La Junta', 'La Junta,La Khuenta,La Khunta,Lajunta,Otero,la hong ta,la junta,la jwnta,la khwnta  klradw,Ла Хуента,Ла Хунта,لا جنتا، کولوراڈو,لا جونتا,لا خونتا، کلرادو,ला जुन्टा,ལ་ཇུན་ཏ།,拉洪塔', 37.9850100, -103.5438300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144975, 'Lafayette', 'Lafayette', 'Lafajet,Lafajett,Lafejet,la fa ye,lafayt  klradw,lafayyt,laphayeta,lapies,Лафайет,Лафайетт,Лафејет,لافائیٹ، کولوراڈو,لافاييت,لافایت، کلرادو,लाफायेट,拉法叶,라피엣', 39.9936000, -105.0897100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144976, 'Lake City', 'Lake City', 'Lehjk Siti,Lejk Siti,hu cheng,leka siti,lyk syty,lyk syty  klradw,Лејк Сити,Лэйк Сити,ليك سيتي,لیک سٹی، کولوراڈو,لیک سیتی، کلرادو,लेक सिटी,湖城', 38.0300000, -107.3153300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144977, 'Lakewood', 'Lakewood', 'Lakewood,Lehjkvud,Lejkud,Lejkvud,lai ke wu de,leikeuudeu,lekavuda,lykwwd,lykwwd  klradw,lyyqwwd,reikuuddo,Лейквуд,Лейкуд,Лејквуд,Лэйквуд,לייקווד,ليكوود,لیک ووڈ، کولوراڈو,لیکوود، کلرادو,लेकवूड,レイクウッド,萊克伍德,레이크우드', 39.7047100, -105.0813700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144978, 'Lamar', 'Lamar', 'LAA,Lamar,la ma er,lamar,lamar  klradw,lamara,Ламар,لامار,لامار، کلرادو,لامار، کولوراڈو,लामार,拉马尔', 38.0872300, -102.6207500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144979, 'Las Animas', 'Las Animas', 'Las Animas,Las Ehnimas,Las Ánimas,la si a ni ma si,las anymas,las anymas  klradw,lasa enimasa,Лас Анимас,Лас Энимас,لاس أنيماس,لاس انیماس، کلرادو,लस एनिमास,拉斯阿尼马斯', 38.0666700, -103.2227100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144980, 'Leadville', 'Leadville', 'Agassiz,Bough City,Boughtown,Carbonate,Cloud City,Harrison,LXV,Leadville,Ledvil,Ledvil'',Ledvill,Lidvil,Lidvill,Oro City,Slabtown,lai de wei er,ledeubil,lidabhila,lydfyl,lydwyl  klradw,Ледвил,Ледвилл,Ледвіль,Лидвил,Лидвилл,ليدفيل,لیدویل، کلرادو,لیڈویل، کولوراڈو,लीडभिल,莱德维尔,레드빌', 39.2508200, -106.2925200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144981, 'Limon', 'Limon', 'LIC,Lajmun,Limon,Limons Camp,Limons Junction,Limón,Lyman Junction,layamana,li meng,limona,lymwn,lymwn  klradw,Лаймън,Лимон,ليمون,لیمون، کلرادو,लायमन,लिमोन,利蒙', 39.2638800, -103.6921700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144982, 'Lincoln Park', 'Lincoln Park', '', 38.4291600, -105.2199900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144983, 'Littleton', 'Littleton', 'Litlton,Littlton,Litultun,li te er dun,litalatana,liteulteon,lytltwn,lytltwn  klradw,Λίτλτον,Литлтон,Литтлтон,Литълтън,Літлтон,ليتلتون,لٹلٹن، کولوراڈو,لیتلتون، کلرادو,लिटलटन,利特尔顿,리틀턴', 39.6133200, -105.0166500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144984, 'Loma', 'Loma', '', 39.1958100, -108.8131600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144985, 'Lone Tree', 'Lone Tree', 'Lon Tri,Loun Tri,Loun Trij,lan try  klradw,lona tri,long na te li,lwn try,Лон Три,Лоун Три,Лоун Трий,لان تری، کلرادو,لون تري,लोन ट्री,隆娜特里', 39.5517100, -104.8863000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144986, 'Louisville', 'Louisville', 'Luisvil,Lujsvill,lu yi si wei er,lu''ibhila,lwyyswyl  klradw,lwyzfyl,Луисвил,Луйсвилл,لوئیزویل، کولوراڈو,لوئیسویل، کلرادو,لويزفيل,लुईभिल,路易斯维尔', 39.9777600, -105.1319300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144987, 'Mancos', 'Mancos', '', 37.3450000, -108.2892500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144988, 'Manitou Springs', 'Manitou Springs', 'Manitou,Manitou Springs,Manitu Springs,Villa La Font,ke luo la duo wen quan,manytw sbrynghz,manytww aspryngz  klradw,myanito springas,Маниту Спрингс,مانيتو سبرينغز,مانیتوو اسپرینگز، کلرادو,म्यानिटो स्प्रिङ्गस्,科罗拉多温泉', 38.8597100, -104.9172000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144989, 'Meridian', 'Meridian', 'Meridian,Меридиан', 39.5395700, -104.8452800, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144990, 'Minturn', 'Minturn', 'Miaturn,Mintern,Minturn,ming te en,mintarna,myntrn  klradw,myntwrn,Минтерн,Минтурн,Минтърн,مينتورن,مینترن، کلرادو,मिन्टर्न,明特恩', 39.5863700, -106.4308600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144991, 'Monte Vista', 'Monte Vista', 'Henry,Lariat,Monte,Monte Vista', 37.5791700, -106.1480800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144992, 'Montrose', 'Montrose', 'MTJ,Montrouz,meng te luo si,montaroja,mwntrw  klradw,mwntrwz,Монтроуз,مونترو، کلرادو,مونتروز,مونٹروز، کولوراڈو,मोन्टरोज,蒙特罗斯', 38.4783200, -107.8761700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144993, 'Monument', 'Monument', 'Henry Station,Monjument,Monjumunt,Monument,mo niu men te,monumenta,mwnwmnt,mwnwmnt  klradw,Монумент,Монюмънт,Монјумент,مونومنت,مونومنت، کلرادو,मोनुमेन्ट,莫纽门特', 39.0916600, -104.8727600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144994, 'Mountain Village', 'Mountain Village', '', 37.9313800, -107.8564500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144995, 'Nederland', 'Nederland', 'Brownsville,Middle Border,Nederland,Nedurlend,Niderland,Tungston Town,hwlnda,ndrlnd  klradw,nedaralyanda,ni de lan,Недерланд,Недърленд,Нидерланд,ندرلند، کلرادو,هولندا,नेदरल्यांड,尼德兰', 39.9613800, -105.5108300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144996, 'New Castle', 'New Castle', 'Chapman,Grand Butte,New Castle', 39.5727600, -107.5364400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144997, 'Northglenn', 'Northglenn', 'Nortglen,bei ge lun,narthaglena,nwrthghlyn,nwrthgln  klradw,Нортглен,نارتھگلین، کولوراڈو,نورثغلين,نورثگلن، کلرادو,नर्थग्लेन,北葛伦', 39.8855400, -104.9872000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144998, 'Olathe', 'Olathe', 'Brown,Colorow,Olathe', 38.6049900, -107.9822900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(144999, 'Orchard Mesa', 'Orchard Mesa', '', 39.0430400, -108.5523200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145000, 'Orchard City', 'Orchard City', 'Eckert,Orchard City', 38.8283200, -107.9709000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145001, 'Ordway', 'Ordway', '', 38.2180600, -103.7560600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145002, 'Ouray', 'Ouray', 'Jerej,Jurej,Ouray,Ourehj,Uncompahgre,Uncompahgre City,aure,awray,awray  klradw,wu lei,Јереј,Оурэй,Юрей,أوراي,اورای، کلرادو,औरे,乌雷', 38.0227700, -107.6714500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145003, 'Pagosa Springs', 'Pagosa Springs', 'PGO,Pagosa Sprins,Pogouza Springs,To Sido Haali,Tó Sido Háálį́,baghwsa sbrynghz,pa ge sa si pu lin si,pagwsa aspryngz  klradw,pyagosa springas,Пагоса Спринс,Погоуза Спрингс,باغوسا سبرينغز,پاگوسا اسپرینگز، کلرادو,प्यागोसा स्प्रिङ्गस्,帕戈萨斯普林斯', 37.2694500, -107.0097600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145004, 'Palisade', 'Palisade', 'Palisade,Palisades', 39.1102600, -108.3509200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145005, 'Palmer Lake', 'Palmer Lake', 'Divide,Divide Lake,Palmer Lake,Palmer Lehjk,Palmur Lejk,Pamer Lejk,balmr lyk,pa er mo hu,palmr lyk  klradw,pamara leka,Палмер Лэйк,Палмър Лейк,Памер Лејк,بالمر ليك,پالمر لیک، کلرادو,पामर लेक,帕尔默湖', 39.1222100, -104.9172000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145006, 'Parachute', 'Parachute', 'Grand Valley,Parachute,Parashhjut,Parashut,Perashut,barashwt,jiang luo san,parashwt  klradw,pyarasuta,Парашут,Паращют,Перашут,باراشوت,پاراشوت، کلرادو,प्याराशुट,降落伞', 39.4519200, -108.0528500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145007, 'Parker', 'Parker', 'Parker,Parkur,barkr,pa ke,parkara,parkr  klradw,Паркер,Паркър,باركر,پارکر، کلرادو,پارکر، کولوراڈو,पार्कर,帕克', 39.5186000, -104.7613600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145008, 'Penrose', 'Penrose', '', 38.4250000, -105.0227600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145009, 'Perry Park', 'Perry Park', '', 39.2566600, -104.9924800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145010, 'Ponderosa Park', 'Ponderosa Park', '', 39.4083200, -104.6510800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145011, 'Pueblo', 'Pueblo', 'Independence,PUB,Pueblo,Puehblo,bwyblw,peblo,phiw bol,pu wei bu luo,puebeullo,pueburo,pwablw  klradw,pyu''eblo,pywblw,Пуебло,Пуэбло,פואבלו,بويبلو,پوابلو، کلرادو,پوابلو، کولوراڈو,پیوبلو,पेब्लो,प्युएब्लो,พิวโบล,プエブロ,普韋布洛,푸에블로', 38.2544500, -104.6091400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145012, 'Pueblo West', 'Pueblo West', '', 38.3500000, -104.7227500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145013, 'Redlands', 'Redlands', '', 39.0788700, -108.6356500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145014, 'Rifle', 'Rifle', 'RIL,Rajfl,Rifl,Riful,lai fu er,ra''iphala,ryfl,ryfl  klradw,Рајфл,Рифл,Рифъл,ريفل,ریفل، کلرادو,राइफल,赖夫尔', 39.5347000, -107.7831200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145015, 'Rocky Ford', 'Rocky Ford', '', 38.0525100, -103.7202300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145016, 'Roxborough Park', 'Roxborough Park', '', 39.4738800, -105.0852600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145017, 'Saguache', 'Saguache', 'Saguach,Saguache,Savach,Siwatch,Siwatche,sa wo qi,saghwatsh,sgwaych  klradw,syagu''ace,Савач,Сагуач,ساغواتش,سگاچے، کولوراڈو,سگوایچ، کلرادو,स्यागुआचे,萨沃奇', 38.0875000, -106.1419700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145018, 'Salida', 'Salida', 'Ephraim,SLT,Salajda,Salida,South Arkansas,sa li da,salyda,salyda  klradw,syalida,Салајда,Салида,ساليدا,سالیدا، کلرادو,سالیڈا، کولوراڈو,स्यालिदा,萨利达', 38.5347200, -105.9989000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145019, 'San Luis', 'San Luis', 'Culebra,Plaza del Medio,San Luis,San Luis de Culebra,San Lujs,Sent-Luis,san lwys,sheng lu yi si,sn lwyys  klradw,syana lu''i,Сан Луис,Сан Луйс,Сент-Луис,سان لويس,سن لوئیس، کلرادو,स्यान लुई,圣路易斯', 37.2008500, -105.4239000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145020, 'Sheridan', 'Sheridan', 'Petersburg,Sheridan,seridyana,shrydan  klradw,shyrydan,xie li deng,Шеридан,شریدان، کلرادو,شيريدان,शेरिड्यान,谢里登', 39.6469300, -105.0252600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145021, 'Sherrelwood', 'Sherrelwood', '', 39.8377600, -105.0013700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145022, 'Silt', 'Silt', 'Ferguson,Silt', 39.5485900, -107.6561700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145023, 'Silverthorne', 'Silverthorne', 'Sil''versorn,Silverthorn,Silverthorne,Silvertorn,Silvurtorn,silbharatharna,sylfrthwrn,sylwrswrn  klradw,yin zuo,Силверторн,Силвърторн,Сильверсорн,سيلفرثورن,سیلورسورن، کلرادو,सिल्भरथर्न,银座', 39.6321400, -106.0742800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145024, 'Silverton', 'Silverton', 'Bakers Park,Greenville,Quito,Reeseville,Sil''verton,Silverton,Tonhidigaii,Tónhidigaii,silbharatana,sylfrtwn,sylwrtwn  klradw,xi er fu dun,Силвертон,Сильвертон,سيلفرتون,سیلورتون، کلرادو,सिल्भरटन,锡尔弗顿', 37.8119400, -107.6645100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145025, 'Snowmass Village', 'Snowmass Village', 'Snowmass Village,Snowmass-at-Aspen', 39.2130400, -106.9378200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145026, 'Southglenn', 'Southglenn', '', 39.5872100, -104.9527600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145027, 'Springfield', 'Springfield', 'Springfijld,Springfild,aspryngfyld  klradw,sbrynghfyld,si pu lin fei er de,springaphilda,Спрингфийлд,Спрингфилд,Спринґфілд,اسپرینگفیلد، کلرادو,سبرينغفيلد,स्प्रिङ्गफिल्ड,斯普林菲尔德', 37.4083500, -102.6143600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145028, 'Stonegate', 'Stonegate', '', 39.5308200, -104.8038600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145029, 'Strasburg', 'Strasburg', '', 39.7383200, -104.3232900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145030, 'Stratmoor', 'Stratmoor', '', 38.7738800, -104.7797000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145031, 'Superior', 'Superior', 'Superior,Supirior,Supiriur,su bi li er,superiyara,swbrywr,swpryr  klradw,Супериор,Супириор,Съпириър,سوبريور,سوپریر، کلرادو,سپیریئر، کولوراڈو,सुपेरियर,苏必利尔', 39.9527600, -105.1686000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145032, 'Telluride', 'Telluride', 'Columbia,TEX,Teljurajd,Telljurid,Telluride,te liu lai de,tellyulaideu,telura''ida,tlywrayd  klradw,tylwrayd,Теллюрид,Телюрайд,Телјурајд,تلیوراید، کلرادو,تيلورايد,टेलुराइड,特柳賴德,텔류라이드', 37.9374900, -107.8122900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145033, 'The Pinery', 'The Pinery', '', 39.4552700, -104.7344200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145034, 'Thornton', 'Thornton', 'Sorton,Thornton,Tornton,Torntun,sang dun,sonton,swrntwn  klradw,tharnatana,thwrntwn,twrntwn,Сортон,Торнтон,Торнтън,תורנטון,تھورن ٹن، کولوراڈو,ثورنتون,سورنتون، کلرادو,थर्नटन,ソーントン,桑頓', 39.8680400, -104.9719200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145035, 'Todd Creek', 'Todd Creek', '', 39.9780400, -104.8733100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145036, 'Towaoc', 'Towaoc', '', 37.2044400, -108.7295400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145037, 'Trinidad', 'Trinidad', 'Rio de las Animas,Santisima Trinidad,TAD,Trinidad,te li ni da,torinidado,trinidada,trinidyada,trynydad,trynydad  klradw,Тринидад,Тринідад,ترينيداد,ترینیداد، کلرادو,ٹرینیڈاڈ، کولوراڈو,ट्रिनिडाड,ट्रिनिड्याड,トリニダード,特立尼达', 37.1694600, -104.5005400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145038, 'Twin Lakes', 'Twin Lakes', '', 39.8249900, -105.0047000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145039, 'Vail', 'Vail', 'Vail,Vehjl,Vejl,bhela,fyl,wayl  klradw,wei er,wel,wyyl,Вейл,Вејл,Вэйл,וייל,فيل,وایل، کلرادو,ویل، کولوراڈو,भेल,വെയ്‌ൽ,เวล,韦尔', 39.6402600, -106.3742000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145040, 'Walsenburg', 'Walsenburg', 'La Plaza de los Leones,Tourist City,Uolsunburg,Val''senburg,Volsenberg,Walsen,Walsenburg,valasenabarga,volsenabarga,walsnbwrg  klradw,walsnbwrgh,wo er sen bao,Вальсенбург,Волсенберг,Уолсънбърг,والسنبورغ,والسنبورگ، کلرادو,वालसेनबर्ग,वॉल्सेनबर्ग,沃尔森堡', 37.6241800, -104.7802600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145041, 'Welby', 'Welby', '', 39.8366500, -104.9591500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145042, 'Westcliffe', 'Westcliffe', 'Uestkliff,Vestklif,vestaklipha,wei si te ke li fu,wstklyf  klradw,wystklyf,Вестклиф,Уестклифф,وستکلیف، کلرادو,ويستكليف,वेस्टक्लिफ,韦斯特克利夫', 38.1347200, -105.4658400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145043, 'Westminster', 'Westminster', 'Harris Park,Uestminstur,Vestminster,Westminster,u~esutominsuta,vestaminstara,wei si min si te,wstmnstr,wstmynstr,wstmynstr  klradw,Вестминстер,Вестмінстер,Уестминстър,וסטמינסטר,وستمنستر,وستمینستر، کلرادو,ویسٹ منسٹر، کولوراڈو,वेस्टमिन्स्टर,ウェストミンスター,威斯敏斯特', 39.8366500, -105.0372000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145044, 'Wheat Ridge', 'Wheat Ridge', 'Uijt Ridzh,Uit Ridzh,Vit Ridz,mai ling,vhita rija,wyt rydj,wyt rydj  klradw,Вит Риџ,Уийт Ридж,Уит Ридж,ويت ريدج,ویت ریدج، کلرادو,ویٹ ریج، کولوراڈو,व्हिट रीज,麦岭', 39.7661000, -105.0772100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145045, 'Woodland Park', 'Woodland Park', 'Manitou,Summit Park,Woodland Park', 38.9938800, -105.0569300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145046, 'Woodmoor', 'Woodmoor', '', 39.1013800, -104.8474800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145047, 'Atwood', 'Atwood', 'Attwood,Atvud,Atwood,atwwd,atwwd  kanzas,Атвуд,أتوود,اتوود، کانزاس', 39.8066700, -101.0421000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145048, 'Colby', 'Colby', 'CBK,Kolbi,kolbi,kwlby,kwlby  kanzas,Колби,كولبي,کولبی، کانزاس,कोल्बी', 39.3958400, -101.0523800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145049, 'Dodge City', 'Dodge City', 'Buffalo City,DDC,Dadz Siti,Dodge City,Dodzh Siti,Dodzh-Siti,Dodzh-siti,Fort Dodge,daj syty  kanzas,doja siti,dojisiti,dojjishiti,dwdj syty,Даџ Сити,Додж Сити,Додж-Сити,Додж-Сіті,Додж-сити,داج سیتی، کانزاس,دودج سيتي,ڈاج سٹی، کنساس,डॉज सिटी,ドッジシティ,도지시티', 37.7528000, -100.0170800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145050, 'Elkhart', 'Elkhart', 'Ehlkkhart,Elkhart,Elkkhart,Sid,alkhart,alkhart  kanzas,Елкхарт,Элкхарт,إلكهارت,الخارت، کانزاس', 37.0080800, -101.8901700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145051, 'Garden City', 'Garden City', 'Fulton,GCK,Garden City,Garden Siti,gardn syty  kanzas,ghardn syty,Гарден Сити,غاردن سيتي,گاردن سیتی، کانزاس,گارڈن سٹی، کنساس', 37.9716900, -100.8726600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145052, 'Goodland', 'Goodland', 'GLD,Gandy,Goodland,Gudland,Sherman Center,ghwdland,gudalamda,gwdland  kanzas,Гудланд,غودلاند,گودلاند، کانزاس,गूडलँड', 39.3508300, -101.7101700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145053, 'Gove', 'Gove', 'Gove,Gove City', 38.9577900, -100.4887500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145054, 'Holcomb', 'Holcomb', 'Holcomb,Kholkomb,Sherlock,hwlkwm,hwlkwmb  kanzas,Холкомб,هولكوم,هولکومب، کانزاس', 37.9861400, -100.9893300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145055, 'Hoxie', 'Hoxie', 'Hoxie,Kenneth', 39.3575000, -100.4418100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145056, 'Hugoton', 'Hugoton', 'Hugo,Hugoton,hwghwtwn,hwgwtwn  kanzas,هوغوتون,هوگوتون، کانزاس', 37.1753000, -101.3496000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145057, 'Johnson', 'Johnson', 'Johnson,Johnson City,Veteran', 37.5705700, -101.7510000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145058, 'Lakin', 'Lakin', '', 37.9405800, -101.2548900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145059, 'Leoti', 'Leoti', 'Bonasa,Leoti', 38.4797400, -101.3587700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145060, 'Liberal', 'Liberal', 'LBL,Liberal,Liberal''naja,Neutral City,lbrl  knsas,lybral,lybral  kanzas,Либерал,Либеральная,لبرل، کنساس,ليبرال,لیبرال، کانزاس', 37.0430800, -100.9210000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145061, 'Meade', 'Meade', 'Meade,Meade Center,Meade Centre,Meade City,Skidmore', 37.2855800, -100.3401500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145062, 'Oakley', 'Oakley', 'Blaiseville,Gilmore,Oakley,Oukli,awkly,awwkly  kanzas,okali,Оукли,أوكلي,اووکلی، کانزاس,ओकली', 39.1333400, -100.8637600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145063, 'Oberlin', 'Oberlin', 'Oberle,Oberlin,Sappa,Westfield,awbrlyn,awbrlyn  kanzas,Оберле,أوبرلين,اوبرلین، کانزاس', 39.8183400, -100.5282000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145064, 'Plains', 'Plains', 'Plains,Plains City,West Plains', 37.2603000, -100.5926500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145065, 'Saint Francis', 'Saint Francis', '', 39.7722200, -101.7999000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145066, 'Satanta', 'Satanta', 'Santanta,Satanta', 37.4372500, -100.9721100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145067, 'Scott City', 'Scott City', 'Scott,Scott City,Skot Siti,askat syty  kanzas,skwt syty,Скот Сити,اسکات سیتی، کانزاس,سكوت سيتي', 38.4825200, -100.9070900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145068, 'Sharon Springs', 'Sharon Springs', 'Eagel Tail,Eagle Tail,Sharon Springs', 38.8977900, -101.7521200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145069, 'Syracuse', 'Syracuse', 'Holidaysburg,Syracuse', 37.9807100, -101.7543000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145070, 'Sublette', 'Sublette', '', 37.4816900, -100.8437700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145071, 'Tribune', 'Tribune', 'Cappaqua,Tribune', 38.4697400, -101.7526700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145072, 'Ulysses', 'Ulysses', 'Julisiz,New Ulysses,Uliss,Ulysses,aywlysyz  kanzas,ywlysys,Јулисиз,Улисс,ایولیسیز، کانزاس,يوليسيس', 37.5814100, -101.3551700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145073, 'Agua Fria', 'Agua Fria', '', 35.6544800, -106.0222400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145074, 'Alamo', 'Alamo', '', 34.4208900, -107.5108800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145075, 'Alamogordo', 'Alamogordo', 'ALM,Alamo Gordo,Alamogordo,aellamogodo,alamwghwrdw,almagwrdw  nywmkzykw,aramogodo,Аламогордо,Аламоґордо,ألاموغوردو,الماگوردو، نیومکزیکو,ایلاموگورڈو، نیو میکسیکو,แอละโมกอร์โด,アラモゴード,앨라모고도', 32.8995300, -105.9602700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145076, 'Albuquerque', 'Albuquerque', 'ABQ,Al''bukerke,Albak"rki,Albakerki,Albjukuehrokju,Albukerke,Albukerki,Albukerkė,Albukwer kwe,Albukwér kwé,Albuquerque,Alburquerque,Almpoukerki,Beeldil Daesenili *,Beeʼeldííl Dahsinil,Duke City,New Albuquerque,San Felipe de Neri,San Francisco Xavier,San Francisco de Albuquerque,The Duke City,Vokekyi Leuwi *,a bu kui ji,aelbeokeoki,alabakarki,alabukaraki,albakrky,albukark,albukarki,albukʼerkʼe,albwkrk  nyw myksykw,albwkrky,alpukerkki,arubakaki,Αλμπουκέρκη,Албакерки,Албакърки,Албукерки,Албюкуэрокю,Альбукерке,Ալբուկերկե,אלבקרקי,آلبوکرک، نیو میکسیکو,ألباكركي,البوکرکی,आल्बुकर्की,আলবাকার্কি,ਅਲਬੂਕਰਕੀ,ஆல்புகெர்க்கி,ಆಲ್ಬುಕರ್ಕ್,แอลบูเคอร์คี,ალბუკერკე,アルバカーキ,阿布奎基,앨버커키', 35.0844900, -106.6511400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145077, 'Angel Fire', 'Angel Fire', 'AXX,Angel Fire', 36.3930900, -105.2850100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145078, 'Anthony', 'Anthony', 'Anthony,Half Way House,La Tuna', 32.0039900, -106.6058300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145079, 'Arenas Valley', 'Arenas Valley', '', 32.7939600, -108.1842100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145080, 'Arroyo Seco', 'Arroyo Seco', 'Arroyo Seco,Arroyoseco,Pakuba *,Pakut''a *', 36.5166900, -105.5691800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145081, 'Artesia', 'Artesia', 'ATS,Artehzija,Artezija,Artizha,artyshya,artyzha  nywmkzykw,Артезія,Артижа,Артэзия,آرتیژا، نیومکزیکو,أرتيشيا,ارٹیسیا، نیو میکسیکو,ཨར་ཊེ་སི་ཡ།', 32.8423300, -104.4033000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145082, 'Atoka', 'Atoka', '', 32.7695600, -104.3888500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145083, 'Aztec', 'Aztec', 'Aztehg,Aztek,Kinteel,aztk  nywmkzykw,aztyk,azutekku,Азтек,Азтэг,أزتيك,ازتک، نیومکزیکو,アズテック', 36.8222300, -107.9928500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145084, 'Bayard', 'Bayard', '', 32.7617400, -108.1306000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145085, 'Belen', 'Belen', 'Behlen,Belem,Belen,Belén,Bethel,Nuestra Senora de Belen *,bln  nywmkzykw,bylyn,Белен,Бэлен,بلن، نیومکزیکو,بيلين', 34.6628400, -106.7764200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145086, 'Berino', 'Berino', 'Berino,Berino Siding', 32.0709300, -106.6213800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145087, 'Bernalillo', 'Bernalillo', 'Balalijo *,Bernalille,Bernalillo,Bernalilo,Khin Nodozi *,Kin Noodooz,Kin Noodǫ́ǫ́z,Las Cocinitas,Real de Bernalillo,berunario,brnalylw  nywmkzykw,Берналило,برنالیلو، نیومکزیکو,ベルナリオ', 35.3000400, -106.5511400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145088, 'Black Rock', 'Black Rock', '', 35.0883700, -108.7911900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145089, 'Bloomfield', 'Bloomfield', 'Ahihodiiteel,Bloomfield,Porter', 36.7111200, -107.9845100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145090, 'Boles Acres', 'Boles Acres', '', 32.8070300, -105.9861000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145091, 'Bosque Farms', 'Bosque Farms', '', 34.8547800, -106.7053000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145092, 'Capitan', 'Capitan', 'Capitan,Gray', 33.5453600, -105.5722000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145093, 'Carlsbad', 'Carlsbad', 'CNM,Karlsbad,kaljeubaedeu,karlsbad,karlzbd  nywmkzykw,karuzubaddo,Карлсбад,كارلسباد,کارلزبد، نیومکزیکو,کارلزبیڈ، نیو میکسیکو,カールズバッド,칼즈배드', 32.4206700, -104.2288400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145094, 'Carnuel', 'Carnuel', 'Carna-aye,Carnue,Carnuel', 35.0639400, -106.4572500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145095, 'Carrizozo', 'Carrizozo', 'Gunung Berapi Carrizozo,Karizozo,karzwzw,kryzwzw  nywmkzykw,Каризозо,كارزوزو,کریزوزو، نیومکزیکو', 33.6417400, -105.8772100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145096, 'Chama', 'Chama', 'Chama,Chama Crossing', 36.9030700, -106.5794800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145097, 'Chaparral', 'Chaparral', 'Chaparral,Chapparal', 32.0237600, -106.3856600, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145098, 'Chimayo', 'Chimayo', 'Chimaco,Chimayo,Chinayo,San Buenaventura de Chimayo,Tsimajobu''u,Tsimayo', 36.0039100, -105.9469700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145099, 'Church Rock', 'Church Rock', 'Church Rock,Kinlitsosinili', 35.5339100, -108.5998000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145100, 'Clayton', 'Clayton', 'CAO,Clayton,Klejton,Perico,klaytwn,kletana,klytn  nywmkzykw,kureiton,Клејтон,كلايتون,کلیتن، نیومکزیکو,کلیٹن، نیو میکسیکو,क्लेटन,クレイトン', 36.4516900, -103.1841000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145101, 'Clovis', 'Clovis', 'CVN,Clovis,Glovis,Klovis,Riley Station,Riley Switch,klwfys  nywmksykw,klwwys  nywmkzykw,kurovu~isu,Гловис,Кловис,كلوفيس، نيومكسيكو,کلوویس، نیومکزیکو,クローヴィス', 34.4048000, -103.2052300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145102, 'Columbus', 'Columbus', 'CUS,Colombus,Columbus,Kolambus,Kolumbus,ge lun bu,klmbws  nywmkzykw,kwlmbs  nyw myksykw,kwlwmbws,Коламбус,Колумбус,كولومبوس,کلمبوس، نیومکزیکو,کولمبس، نیو میکسیکو,哥伦布', 31.8276000, -107.6400200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145103, 'Corrales', 'Corrales', 'Corales,Corrales,Los Corrales,Sandoval', 35.2378200, -106.6066900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145104, 'Crownpoint', 'Crownpoint', 'Crownpoint,Hasta Butte,Natanih yazih,T''iists''ooz nideeshgizh,Tsiistsooz Ndeeshqiizh', 35.6780800, -108.1511800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145105, 'Deming', 'Deming', 'DMN,Dehming,Deming,New Chicago,de ming,demingu,dmyng  nywmkzykw,dymyngh,Деминг,Демінг,Дэминг,دمینگ، نیومکزیکو,ديمينغ,ڈیمنگ، نیو میکسیکو,デミング,德明', 32.2687000, -107.7586400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145106, 'Dexter', 'Dexter', '', 33.1973300, -104.3730200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145107, 'Doña Ana', 'Dona Ana', 'Dona Ana', 32.3895400, -106.8139000, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145108, 'Dulce', 'Dulce', 'Beehaih keehat''i,Du:shi an K''yan''a,Dulce,Po''d''iwe *', 36.9336200, -106.9989300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145109, 'Edgewood', 'Edgewood', 'Barton,Edgewood,Mountain View,New Barton,Venus', 35.0614400, -106.1914100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145110, 'El Cerro', 'El Cerro', '', 34.7270000, -106.7108600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145111, 'El Rancho', 'El Rancho', '', 35.8891900, -106.0797500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145112, 'El Valle de Arroyo Seco', 'El Valle de Arroyo Seco', '', 35.9628000, -106.0294700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145113, 'Eldorado at Santa Fe', 'Eldorado at Santa Fe', '', 35.5264200, -105.9347400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145114, 'Elephant Butte', 'Elephant Butte', '', 33.1486800, -107.1847500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145115, 'Española', 'Espanola', 'Butsabi''i,ESO,Ehspan''ola,Ehspanola,Espan''ola,Espaniola,Espanola,Española,asbanwla,aspanywla  nywmkzykw,ayspanwla  nyw myksykw,Еспаньола,Еспањола,Эспанола,Эспаньола,إسبانولا,اسپانیولا، نیومکزیکو,ایسپانولا، نیو میکسیکو', 35.9911300, -106.0805800, 'US', '2011-12-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145116, 'Estancia', 'Estancia', 'Estancia,Estancia Spring', 34.7583900, -106.0558500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145117, 'Eunice', 'Eunice', '', 32.4373400, -103.1590800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145118, 'Farmington', 'Farmington', 'FMN,Farmington,To Ta,Tohta,Tqo Tah,Tótaʼ,farmynghtwn,farmyngtn  nywmkzykw,prmyngtwn,Фармингтон,Фармінґтон,פרמינגטון,فارمنگٹن، نیو میکسیکو,فارمينغتون,فارمینگتن، نیومکزیکو', 36.7280600, -108.2186900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145119, 'Flora Vista', 'Flora Vista', '', 36.7944500, -108.0803500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145120, 'Fort Sumner', 'Fort Sumner', 'FSU,Fort Sumner,Rudolph,Sunnyside', 34.4717300, -104.2455300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145121, 'Gallup', 'Gallup', 'GUP,Galap,Gallap,Gallup,Gehllap,Na''nizhoozhi,Nanizhoozhi,Naʼnízhoozhí,gelapa,ghalwb,glwp  nywmkzykw,gylp  nyw myksykw,Галап,Галлуп,Гэллап,Ґаллап,غالوب,گلوپ، نیومکزیکو,گیلپ، نیو میکسیکو,गॅलप', 35.5280800, -108.7425800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145122, 'Grants', 'Grants', 'Alamitos,Anaa''taskiaki,GNT,Grant,Grantes,Grants,Grants Camp,Grants Station,Naatooh Sikʼaiʼí,Nat-toh-si-quy,ge lan ci,ghrants,grnts  nywmkzykw,gurantsu,Грантс,Ґрантс,غرانتس,گرانٹس، نیو میکسیکو,گرنتس، نیومکزیکو,グランツ,格兰茨', 35.1476000, -107.8526100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145123, 'Hagerman', 'Hagerman', 'Feliz,Hagerman', 33.1151100, -104.3269100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145124, 'Hatch', 'Hatch', 'Hatch,Hatchs Station,Santa Barbara', 32.6653600, -107.1530700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145125, 'Hobbs', 'Hobbs', 'Gobbs,HOB,Hobbs,Khobbs,Khobs,New Hobbs,habz  nywmkzykw,hwbz,Гоббс,Хоббс,Хобс,هابز، نیومکزیکو,هوبز,ہابس، نیو میکسیکو', 32.7026100, -103.1360400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145126, 'Hurley', 'Hurley', 'Hurley,Hurley Siding', 32.6992400, -108.1319900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145127, 'Jal', 'Jal', 'Jal,Muleshoe', 32.1131800, -103.1935100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145128, 'Jarales', 'Jarales', '', 34.6131200, -106.7636400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145129, 'Jemez Pueblo', 'Jemez Pueblo', 'Ameyes,Amies,Emashi *,Emmes,Ha-mish *,Hae-mish *,Haemishetsae *,Hay mish,He''mi *,He''wa *,He-me-shu-tsa *,He-mi-ma *,Heimai *,Hejo *,Hekwa *,Hemes,Hemeshitse *,Hemez,Hemishitz *,Hemisi,Hetowa *,Hewa *,Hewa''walatojo *,Hewa''walatowa *,Hiam-aye,Himez,Jemas,Jemes,Jemex,Jemez,Jemez Pueblo,Jemos,Los Emes,Ma''ii deeshgiishi,Mai-dec-kiz-ne *,Tojo *,Tokwa *,Wa-la-nah *,Walaktowa *,Walatojo *,Walatow,Walatowa *,Wange''ongwi *,Xemes,Ximes,Yemez', 35.6142200, -106.7283200, 'US', '2015-07-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145130, 'Kirtland', 'Kirtland', 'Kirtland,Olio', 36.7341700, -108.3598000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145131, 'La Cienega', 'La Cienega', 'Cienaga,La Cienaga,La Cienega,La Cinega', 35.5628100, -106.1308600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145132, 'La Huerta', 'La Huerta', '', 32.4429000, -104.2210600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145133, 'La Luz', 'La Luz', 'La Luz,Nuestra Senora de la Luz *', 32.9778700, -105.9419300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145134, 'La Mesilla', 'La Mesilla', '', 35.9483600, -106.0705800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145135, 'La Puebla', 'La Puebla', '', 35.9891900, -105.9964100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145136, 'La Union', 'La Union', 'La Union,La Union Nueva,La Union Vieja', 31.9506600, -106.6616600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145137, 'Laguna', 'Laguna', 'Bieri *,K''ya-na-thlana-kwe*,Kawaihka *,Kawaik,Kawaika *,Keowe''egi''i *,Kuhkweai *,Laguna,Laguna de San Jose,Laguna''ongwi *,Pahwima *,Pokwindiwe onwi,Pokwindiwe''ongwi *,Poto''iweongwi *,San Jose de Laguna,San Jose de la Laguna,Sitsime *,To-zan''-ne *,Tqo lani *', 35.0367100, -107.3828200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145138, 'Las Cruces', 'Las Cruces', 'LRU,Las Cruces,Las Krjusehs,Las Kruses,Las Krusis,Las-Kruses,la si ke lu sai si,las kruces,las krwss  nywmkzykw,las krwsys,las krwsys  nyw myksykw,laseukeulusiseu,rasukurusesu,Лас Крусес,Лас Крусис,Лас Крюсэс,Лас-Крусес,לאס קרוסס,لاس كروسيس,لاس کروسس، نیومکزیکو,لاس کروسیس، نیو میکسیکو,லாஸ் க்ரூசெஸ்,ラスクルーセス,拉斯克鲁塞斯,라스크루시스', 32.3123200, -106.7783400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145139, 'Las Vegas', 'Las Vegas', 'East Las Vegas,LVS,Las Vegas,Las Vegas City,Las-Vegas,Nuestra Senora de los Dolores de las Vegas,Vegas de las Gallinas,West Las Vegas,las fyghas,las wgas  nywmkzykw,las wygas  nyw myksykw,lasa vhegasa,laseubeigeoseu,rasubegasu,Лас Вегас,Лас-Вегас,Лас-Веґас,لاس فيغاس,لاس وگاس، نیومکزیکو,لاس ویگاس، نیو میکسیکو,लास व्हेगास,ラスベガス,라스베이거스', 35.5939300, -105.2239000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145140, 'Lee Acres', 'Lee Acres', '', 35.1486600, -106.6469700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145141, 'Lee Acres', 'Lee Acres', '', 36.6988900, -108.0367400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145142, 'Lordsburg', 'Lordsburg', 'LSB,Lordsberg,Lordsburg,luo ci bao,lwrdsbwrg  nywmkzykw,lwrdzbwrgh,Лордсберг,Лордсбург,لوردزبورغ,لوردسبورگ، نیومکزیکو,洛兹堡', 32.3503600, -108.7086600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145143, 'Los Alamos', 'Los Alamos', 'LAM,Los Alamos,Los Álamos,Los-Alamos,las aylmws  nyw myksykw,leas alameas,los-alamosi,loseuaelleomoseu,ls alamws  nywmkzykw,luo si a la mo si,lws alamws,rosuaramosu,Лос Аламос,Лос-Аламос,لاس ایلموس، نیو میکسیکو,لس آلاموس، نیومکزیکو,لوس ألاموس,ലോസ് അലാമോസ്,ლოს-ალამოსი,ロスアラモス,洛斯阿拉莫斯,로스앨러모스', 35.8880800, -106.3069700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145144, 'Los Chavez', 'Los Chavez', 'Los Chaves,Los Chavez', 34.7257100, -106.7572600, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145145, 'Los Lunas', 'Los Lunas', 'Los Lunas,Los-Lunas,las lwns  nyw myksykw,loseuluneoseu,lws lwna  nywmkzykw,lws lwnas,rosurunasu,Лос Лунас,Лос-Лунас,لاس لونس، نیو میکسیکو,لوس لونا، نیومکزیکو,لوس لوناس,ロスルナス,로스루너스', 34.8061700, -106.7333600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145146, 'Los Ranchos de Albuquerque', 'Los Ranchos de Albuquerque', 'El Ranchito,Los Ranchitos,Los Ranchos de Albuquerque', 35.1619900, -106.6428000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145147, 'Loving', 'Loving', '', 32.2862300, -104.0957700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145148, 'Lovington', 'Lovington', 'Lavington,Lovington,lawyngtwn  nywmkzykw,lwfynghtwn,ravu~inguton,Лавингтон,Ловингтон,Ловінґтон,لاوینگتون، نیومکزیکو,لوفينغتون,لوونگٹن، نیو میکسیکو,ラヴィングトン', 32.9440100, -103.3485500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145149, 'McIntosh', 'McIntosh', '', 34.8647800, -106.0516900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145150, 'Meadow Lake', 'Meadow Lake', '', 34.8014400, -106.5436300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145151, 'Mescalero', 'Mescalero', 'Mescalero,South Fork,White Sulfur Springs,White Sulphur Springs', 33.1575900, -105.7741500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145152, 'Mesilla', 'Mesilla', 'La Mesilla,Mesila,Mesill,Mesilla,Old Mesilla,msyla  nywmkzykw,mysyla,Месила,مسیلا، نیومکزیکو,ميسيلا', 32.2700900, -106.8008400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145153, 'Mesquite', 'Mesquite', '', 32.1645400, -106.6966600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145154, 'Milan', 'Milan', '', 35.1697600, -107.8908900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145155, 'Moriarty', 'Moriarty', '', 34.9900500, -106.0491900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145156, 'Mosquero', 'Mosquero', '', 35.7769800, -103.9566400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145157, 'Nambe', 'Nambe', '', 35.8933600, -105.9825200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145158, 'Navajo', 'Navajo', '', 35.9000100, -109.0339800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145159, 'Navajo', 'Navajo', '', 36.9461200, -107.0630900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145160, 'North Valley', 'North Valley', '', 35.1733800, -106.6233600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145161, 'Paradise Hills', 'Paradise Hills', '', 35.2006000, -106.7011400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145162, 'Pecos', 'Pecos', 'Levy,Pecos', 35.5742000, -105.6750200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145163, 'Peralta', 'Peralta', 'Los Pinos,Peralta,Placeres', 34.8370000, -106.6905800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145164, 'Placitas', 'Placitas', 'Las Placitas,Placitas', 35.3069800, -106.4247500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145165, 'Ponderosa Pine', 'Ponderosa Pine', 'Ponderosa Pine,Ponderosa Pines', 34.9769900, -106.3241900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145166, 'Portales', 'Portales', 'Portales,bwrtalys,poteiruzu,Порталес,بورتاليس,پورٹالیس، نیو میکسیکو,ポーテイルズ', 34.1861900, -103.3344000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145167, 'Questa', 'Questa', 'Questa,San Antonio del Rio Colorado', 36.7039100, -105.5950100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145168, 'Radium Springs', 'Radium Springs', 'Fort Selden Springs,Radium Springs,Radium Springs Junction,Randall Station', 32.5012000, -106.9280700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145169, 'Ranchos de Taos', 'Ranchos de Taos', 'Francisco Ranchos,Ranches of Taos,Ranchos,Ranchos de Don Fernando de Taos,Ranchos de Francisco,Ranchos de Taos,Ranchos of Taos,Rantshu *,Rio de las Trampas de Taos,San Francisco del Rancho de Taos,T''a''lumuna *,Talamora *', 36.3586400, -105.6094600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145170, 'Raton', 'Raton', 'RTN,Raton,Ratun,Ratón,Willow Springs,raton,ratona,ratwn,rytwn  nywmkzykw,Ратон,Ратън,راتون,ریتون، نیومکزیکو,ریٹون، نیو میکسیکو,रटॉन,ラトン', 36.9033600, -104.4391500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145171, 'Reserve', 'Reserve', 'Milligan,Milligans Plaza,Reserve,Rizerv,Upper Frisco Plaza,Upper San Francisco Plaza,rizavu,rysrf,Ризерв,ريسرف,リザーヴ', 33.7131100, -108.7578400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145172, 'Rio Rancho', 'Rio Rancho', 'Rio Rancho,Rio-Rancho,Río Rancho,liolaencho,riorancho,ryw rantshw,ryw rnchw  nywmkzykw,ryw rynchw  nyw myksykw,Рио Ранчо,Рио-Ранчо,Ріо-Ранчо,ريو رانتشو,ریو رنچو، نیومکزیکو,ریو رینچو، نیو میکسیکو,リオランチョ,리오랜초', 35.2600400, -106.7061400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145173, 'Rio Rancho', 'Rio Rancho', 'Rio Rancho,Rio Rancho Estates,Rio-Rancho,Рио-Ранчо', 35.2333800, -106.6644700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145174, 'Roswell', 'Roswell', 'ROW,Rosvehll,Roswell,Rozuehll,Rozuel,Rozuell,Rozvel,lojeuwel,luo si wei er,raja''oyela,razwl  nywmkzykw,rozuu~eru,rwzwwl,rwzwyl,rwzwyl  nyw myksykw,Розвел,Розуел,Розуелл,Розуэлл,Росвэлл,רוזוול,رازول، نیومکزیکو,روزويل,روزویل، نیو میکسیکو,রজওয়েল,ロズウェル,羅斯維爾,로즈웰', 33.3943700, -104.5249100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145175, 'Ruidoso', 'Ruidoso', 'Dowlins Mill,RUI,Ruidosa at Forks,Ruidoso,Ruidozo,ruidoso,rwydwsw,rwydwsw  nywmkzykw,Руидозо,Руідозо,رويدوسو,رویئڈوسو، نیو میکسیکو,رویدوسو، نیومکزیکو,ルイドソ', 33.3317500, -105.6730400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145176, 'Ruidoso Downs', 'Ruidoso Downs', 'Green Tree,Palo Verde,Ruidoso Downs', 33.3289700, -105.6044300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145177, 'San Felipe Pueblo', 'San Felipe Pueblo', 'Debe Lizhini *,Kacht''ya *,Katishtya,Katistsha *,Katitshaie *,Katshtya*,Kwilegi''i *,Nangkwaeirige''ongwi *,P''atu''ak *,Sai behoghan *,San Felipe Pueblo,San Felipe de Keres,Thostalawiama *,To Hachele *,Tsiwiri''ongwi *,Wi''-li-gi *', 35.4339200, -106.4466900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145178, 'San Miguel', 'San Miguel', 'San Miguel,Telles', 32.1553800, -106.7350000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145179, 'San Ysidro', 'San Ysidro', '', 32.3509300, -106.8111200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145180, 'Sandia Heights', 'Sandia Heights', '', 35.1769900, -106.4914100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145181, 'Sandia Knolls', 'Sandia Knolls', '', 35.1639300, -106.3114100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145182, 'Santa Clara', 'Santa Clara', 'Central,Santa Clara,Santa Klara,Санта Клара', 32.7795200, -108.1503200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145183, 'Santa Clara Pueblo', 'Santa Clara Pueblo', '''anaa''shash,Ak-e-ji *,Ana S''ushi *,Caypa *,Giowaka-a *,Giowatsa-a *,Hai''bata *,Haiba''yu *,Haipaai *,K''apo''ungwi *,K''haibahi *,Kah-po,Kaipa *,Kapo,Nasabe''etewa *,Santa Clara Pueblo,Shi-ap-a-gi *,Shjapagi''i *,Tinjititjame *', 35.9655800, -106.0886300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145184, 'Santa Fe', 'Santa Fe', 'Alavija *,Gorad Santa-Feh,Hashoko *,Hulpana *,Kwa''apoge *,La Villa,La Villa Real de Santa Fe de San Francisco,La Villa de Santa Fe,Ogapoge *,Pala *,Poge *,SAF,San daxeye *,Sanctae Fidei fanum,Santa Fe,Santa Fe Analco,Santa Fe de San Francisco,Santa Fe ou Granada,Santa Feh,Santa Fé,Santa Fė,Santa-Fe,Santafe,Santafē,Yoo''to,Yooto,Yootó,Yotqo *,ZSH,canta pe,santa fe,santa fyh,santa phe,santafe,santape,sheng da fei,sheng fei,sntafh  nywmkzykw,snth ph,Σάντα Φε,Горад Санта-Фэ,Санта Фе,Санта Фэ,Санта-Фе,Սանտա Ֆե,סנטה פה,سانتا فيه,سانتا فێ,سانتا فے، نیو میکسیکو,سانٹا فے,سنتافه، نیومکزیکو,सांता फे,साण्टा फे,सान्टा फ़े,सान्ता फे,சாந்தா பே,แซนตาเฟ,სანტა-ფე,サンタフェ,圣菲,聖大非,산타페', 35.6869800, -105.9378000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145185, 'Santa Rosa', 'Santa Rosa', 'Agua Negra Chiquita,Santa Rosa,Santa-Rosa,santa rwza,santa rwza  nywmkzykw,Санта Роса,Санта-Роса,سانتا روزا,سانتا روزا، نیومکزیکو', 34.9386700, -104.6824900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145186, 'Santa Teresa', 'Santa Teresa', '', 36.1533500, -106.6794800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145187, 'Santa Teresa', 'Santa Teresa', '', 31.8559400, -106.6391600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145188, 'Santo Domingo Pueblo', 'Santo Domingo Pueblo', 'Dji''wi *,Ki''wa *,Kin Klekai Ni *,Quigui,Quiqui,Santo Domingo,Santo Domingo Pueblo,T''wi''wi *,Ta-wi-gi *,Tawigi''i *,Tewiai *,Tewige *,Ti''wi *,Tihua *,To''hajilo,Towi *,Tqo Hajilo *,Tu-a-wi-hol *,Tu-wit-ha *,Tuwii *,Tuwita *,Tye''wa *,Wehl''hluwalla *', 35.5147600, -106.3658600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145189, 'Shiprock', 'Shiprock', 'Naataaniineez,Needle,Needles,Sebatai,Ship Rock,Shiprock,Tooh,Tsebidai', 36.7855500, -108.6870300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145190, 'Silver City', 'Silver City', 'SVC,San Vicente,San Vicente de la Cienaga,Silver City,Silver Siti,Silver-Siti,shiruvu~ashiti,sylbr syty,sylfr syty,sylwr syty  nywmkzykw,Силвер Сити,Силвер-Сити,Сілвер-Сіті,סילבר סיטי,سلور سٹی، نیو میکسیکو,سيلفر سيتي,سیلور سیتی، نیومکزیکو,シルヴァーシティ', 32.7700700, -108.2803300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145191, 'Socorro', 'Socorro', 'Nuestra Senora de Socorro de Pilabo *,Nuestra Senora del So,ONM,San Miguel de Socorro,Sighola,Sighóla,Socorro,Sokoro,Sokorro,Teypana,sakwrw  nywmkzykw,sokolo,sokoro,swkwrw,swkwrw  nyw myksykw,Сокоро,Сокорро,ساکورو، نیومکزیکو,سوكورو,سوکورو، نیو میکسیکو,ソコロ,소코로', 34.0584000, -106.8914200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145192, 'South Valley', 'South Valley', '', 35.0100500, -106.6780800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145193, 'Spencerville', 'Spencerville', '', 36.8200000, -108.0581300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145194, 'Sunland Park', 'Sunland Park', 'Sanland Park,Sanlehnd Park,Sanlend-Park,sanlnd park  nywmkzykw,sanrandopaku,snland bark,Санланд Парк,Санленд-Парк,Санлэнд Парк,سانلند پارک، نیومکزیکو,سنلاند بارك,سنلینڈ پارک، نیو میکسیکو,サンランドパーク', 31.7965000, -106.5799900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145195, 'Taos Pueblo', 'Taos Pueblo', 'Braba,Ialap''ait''a *,Ju''alata *,Kituawai *,Koho''hlte *,Kwapihalki *,Pinso''ongwi *,San Geronimo Thaos,San Geronimo de Taos,San Geronimo de los Tahos,San Geronimo de los Taos,T''awi''ongwi *,Ta-uth,Tahos,Tainanam *,Takhe,Taos Pueblo,Tayberon,Thaos,To Wolh,Topoliana-kuin *,Touse,Towirnin *,Tu-o-ta,Tua-tah,Tuaba *,Tuopa *,Tuwirat *,Tyetysheokotsae *,Valladolid,Wee-ka-nahs *,Yualata *', 36.4386400, -105.5444500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145196, 'Taos', 'Taos', 'TSM,Taos,Thanh pho Taos,Thành phố Taos,Towol,Tówoł,ta''osa,taoseu,taosu,tayws  nywmkzykw,Таос,تائوس، نیومکزیکو,ٹاوس، نیو میکسیکو,ताओस,タオス,타오스', 36.4072500, -105.5730700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145197, 'Texico', 'Texico', 'Escavado,Texico', 34.3886900, -103.0513400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145198, 'Thoreau', 'Thoreau', 'Dlo''oyazhi,Dloi Yazhi,Mitchell,Thoreau', 35.4025300, -108.2234000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145199, 'Tierra Amarilla', 'Tierra Amarilla', 'Las Nutrias,Litsoi,Litsooi,Nantsejiwebu''u *,Tierra Amarilla,Tijera Amarila,Łitsooí,Тијера Амарила', 36.7002900, -106.5497600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145200, 'Tome', 'Tome', '', 34.7408900, -106.7283600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145201, 'Truth or Consequences', 'Truth or Consequences', 'Hot Springs,Palomas Springs,TCS,Trjus o Konsegjuensehs,Trut or Konsekuenses,Trut or Konsekvensiz,Trut-or-Konsekuehnses,Trut-or-Konsekuenses,Truth and Consequences,Truth or Consequences,trwt awr kanskwns  nywmkzykw,trwth awr kwnskywnsys,Трут ор Консеквенсиз,Трут-ор-Консекуенсес,Трут-ор-Консекуэнсес,Трюс о Консегюенсэс,تروت اور کانسکونس، نیومکزیکو,تروث أور كونسكيونسيس,トゥルース・オア・コンシクエンシーズ', 33.1284000, -107.2528100, 'US', '2017-07-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145202, 'Tucumcari', 'Tucumcari', 'Douglas,Rag Town,Six Gun Siding,Six Shooter Siding,TCC,Tucumcari,Tukumkehri,Tukumkeri,Tusumkari,to~ukumukari,twkmkry  nywmkzykw,twkwmkary,Тукумкері,Тукумкэри,Тусумкари,توكومكاري,توکمکری، نیومکزیکو,ٹوکمکاری، نیو میکسیکو,トゥクムカリ', 35.1719100, -103.7268600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145203, 'Tularosa', 'Tularosa', '', 33.0739700, -106.0186000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145204, 'Twin Lakes', 'Twin Lakes', 'Bahastlah,Twin Lakes', 35.7091900, -108.7748100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145205, 'University Park', 'University Park', 'Agricultural College,State College,University Park', 32.2834300, -106.7533400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145206, 'Upper Fruitland', 'Upper Fruitland', '', 36.7158400, -108.3142400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145207, 'Vado', 'Vado', 'Center Valley,Earlham,Herron,Vado', 32.1117600, -106.6625000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145208, 'Valencia', 'Valencia', '', 34.7995000, -106.7003000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145209, 'Waterflow', 'Waterflow', 'Ch''indii lich''ii,Jewett Valley,Kentucky Mesa,Liberty,Waterflow', 36.7597200, -108.4817500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145210, 'White Rock', 'White Rock', '', 35.8275300, -106.2039100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145211, 'White Sands', 'White Sands', 'WSD', 32.3809300, -106.4794400, 'US', '2017-05-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145212, 'Zuni Pueblo', 'Zuni Pueblo', '', 35.0725300, -108.8506400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145213, 'Alamo', 'Alamo', '', 37.3649600, -115.1644600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145214, 'Boulder City', 'Boulder City', 'Adaven,Bolder Siti,Boulder,Boulder City,Boulder-Siti,Bouldur Siti,Hidam,Hoover City,Kota Boulder,Thanh pho Boulder,Thành phố Boulder,Wilbur,blwdyr syty,buldeositi,bwldr syty  nwada,Болдер Сити,Боулдер,Боулдер-Сіті,Боулдър Сити,بلودير سيتي,بولدر سیتی، نوادا,بولڈر شہر، نیواڈا,불더시티', 35.9785900, -114.8324900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145215, 'Bunkerville', 'Bunkerville', '', 36.7730300, -114.1280200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145216, 'Caliente', 'Caliente', 'Caliente,Calientes,Clover Junction,Culverwell Ranch,Jackman Ranch,Kalient,Kalijente,kalynth  nwada,kalynyty,Калиент,Калијенте,كالينيتي,کالینته، نوادا,کیلیانٹے، نیواڈا', 37.6149600, -114.5119400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145217, 'Carson City', 'Carson City', 'Altepetl Carson,CSN,Carson,Carson City,Carson City County,Carson city,Carsonurbo,Gorad Karsan-Sici,Karson Siti,Karson Sitis,Karson-Siti,Karsonsitija,Karsun Siti,Kota Carson,Kārsonsitija,Lungsod ng Carson,Thanh pho Carson,Thành phố Carson,ka sen cheng,karcan nakaram,karsan siti,karsana siti,karswn syty,kaseunsiti,kasonshiti,kharsansiti,qrswn syty,Κάρσον Σίτι,Горад Карсан-Сіці,Карсон Сити,Карсон-Сити,Карсон-Сіті,Карсън Сити,Քարսոն Սիթի,קרסון סיטי,كارسون سيتى,كارسون سيتي,کارسن سٹی,کارسن شہر، نیواڈا,کارسون‌سیتی,कार्सन सिटी,कार्सन सिति,कार्सन् सिटी,কার্সন সিটি,கார்சன் நகரம்,คาร์สันซิตี,カーソンシティ,卡森城,카슨시티', 39.1638000, -119.7674000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145218, 'Cold Springs', 'Cold Springs', '', 39.6801900, -119.9765900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145219, 'Dayton', 'Dayton', 'Chinatown,Dayton,Dejton,Gold Creek Station,Halls Station,Johntown,McMartins Station,Mineral Rapids,Nevada City,Ponderers Rest,Дейтон', 39.2371400, -119.5929500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145220, 'Ely', 'Ely', 'ELY,Ehlaj,Ehli,Eli,Ijli,Ili,aly,aly  nwada,illi,yi li,Елі,Ийли,Или,Элай,Эли,إلي,الی، نوادا,ایلی، نیواڈا,伊利,일리', 39.2474400, -114.8886300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145221, 'Enterprise', 'Enterprise', 'Enterprajz,antrbrayz,antrprayz  nwada,entapuraizu,Ентерпрајз,إنتربرايز,انترپرایز، نوادا,انٹرپرائز، نیواڈا,エンタープライズ', 36.0252500, -115.2419400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145222, 'Eureka', 'Eureka', 'EUE,Jurika,awryka,you li ka,ywrka  nwada,Јурика,إوريكا,یورکا، نوادا,یوریکا، نیواڈا,尤里卡', 39.5127100, -115.9606100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145223, 'Fallon', 'Fallon', 'Falun,Follon,Folon,NFL,fa lun,faln  nwada,falwn,Фалън,Фоллон,Фолон,פאלון,فالن، نوادا,فالون,فیلن، نیواڈا,法伦', 39.4735300, -118.7773700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145224, 'Fernley', 'Fernley', 'Fernlehj,Fernli,frnly  nwada,fyrnly,Фернли,Фернлэй,فرنلی، نوادا,فرینلی، نیواڈا,فيرنلي', 39.6079700, -119.2518300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145225, 'Gardnerville', 'Gardnerville', '', 38.9413000, -119.7496200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145226, 'Gardnerville Ranchos', 'Gardnerville Ranchos', '', 38.8882400, -119.7412900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145227, 'Golden Valley', 'Golden Valley', '', 39.6154700, -119.8265800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145228, 'Goldfield', 'Goldfield', 'Goldfield,Goldfild,North Goldfield,South Goldfield,ge er de fei er de,ghwldfyld,gldfyld  nwada,Голдфилд,غولدفيلد,گلدفیلد، نوادا,گولڈفیلڈ، نیواڈا,戈尔德菲尔德', 37.7085400, -117.2356300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145229, 'Hawthorne', 'Hawthorne', 'HTH,Hawthorne,Hawthorne City,Khosorn,Khotorn,hawthwrn,hawthwrn  nwada,huo suo en,hwtwrn,Хосорн,Хоторн,הותורן,هاوثورن,هاوثورن، نوادا,ہاوتھرون، نیواڈا,霍索恩', 38.5246400, -118.6245800, 'US', '2017-04-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145230, 'Henderson', 'Henderson', 'Basic,Chenterson,Genderson,Gorad Khendehrsan,Henderson,Hendersonas,Jericho Heights,Khenderson,Khendersun,Midway City,Pittman,hendason,hendeoseun,heng de sen,hndrswn,hndrswn  nwada,Χέντερσον,Гендерсон,Горад Хендэрсан,Хендерсон,Хендерсън,הנדרסון,هندرسون,هندرسون، نوادا,ہینڈرسن، نیواڈا,ヘンダーソン,亨德森,헨더슨', 36.0397000, -114.9819400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145231, 'Incline Village', 'Incline Village', 'Incline,Incline Village', 39.2513000, -119.9729700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145232, 'Johnson Lane', 'Johnson Lane', '', 39.0479600, -119.7221200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145233, 'Kingsbury', 'Kingsbury', '', 38.9771300, -119.9068500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145234, 'Las Vegas', 'Las Vegas', 'Campi,Gorad Las-Vegas,LAS,Las Vegas,Las Vegas Mission,Las Vegas Ranch,Las Vegasas,Las Venkas,Las-Vegas,Las-Veqas,Lasvegasa,Lasvegaso,Los Vegas,Lungsod ng Las Vegas,McWilliamstown,Naʼazhǫǫsh Hátsoh,Old Town,Piigisi,Ragtown,Vegas,Westside,la si wei jia si,las fyghas,las vegas,las vekas,las veygas,las weka s,las wgas,las wygas  nywaڈa,las-vegasi,lasa bhegasa,lasa vegasa,lasa vhegasa,laseubegaseu,laseubeigeoseu,lʼs wgʼs,rasubegasu,Λας Βέγκας,Горад Лас-Вегас,Лас Вегас,Лас-Вегас,Լաս Վեգաս,לאס וגאס,לאס וועגאס,لاس فيغاس,لاس وگاس,لاس ویگاس، نیواڈا,لاس‌وقاس,लास वेगास,लास व्हेगस,লাস ভেগাস,ਲਾਸ ਵੇਗਸ,લાસ વેગાસ,லாஸ் வேகஸ்,లాస్ వెగాస్,ലാസ് വെയ്ഗസ്,ลาสเวกัส,လပ်ဗီးဂပ်စ်မြို့,ლას-ვეგასი,ላስ ቬጋስ,ラスベガス,拉斯維加斯,拉斯维加斯,라스베가스,라스베이거스', 36.1749700, -115.1372200, 'US', '2017-07-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145235, 'Laughlin', 'Laughlin', 'Laflin,Laughlin,Loflin,Tristate,lahlyn,lflyn  nwada,Лафлін,Лофлин,لافلن، نیواڈا,لاهلين,لفلین، نوادا', 35.1677800, -114.5730200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145236, 'Lemmon Valley', 'Lemmon Valley', '', 39.6360200, -119.8432500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145237, 'McGill', 'McGill', 'MakGill,Makgil,Makgill,makghyl,МакГилл,Макгил,Макгилл,ماكغيل,مک‌گیل، نوادا', 39.4049400, -114.7786300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145238, 'Mesquite', 'Mesquite', 'Meskit,Muskijt,meseukiteu,mesukito,mskyt  nwada,myskyt,Мескит,Мъскийт,مسکیت، نوادا,مسکیٹ، نیواڈا,ميسكيت,メスキート,메스키트', 36.8055300, -114.0671900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145239, 'Minden', 'Minden', 'MEV,Millerville,Mindehn,Minden,mayndn  nwada,ming deng,myndyn,Минден,Миндэн,مائنڈن، نیواڈا,مایندن، نوادا,ميندين,明登', 38.9540700, -119.7657300, 'US', '2013-03-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145240, 'Moapa Town', 'Moapa Town', '', 36.6821900, -114.5941600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145241, 'Moapa Valley', 'Moapa Valley', '', 36.5805300, -114.4702600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145242, 'Mogul', 'Mogul', '', 39.5138000, -119.9260300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145243, 'North Las Vegas', 'North Las Vegas', 'Bac Las Vegas,Bắc Las Vegas,Norda Lasvegaso,Nort-Las-Vegas,North Las Vegas,Severen Las Vegas,Severni Las Vegas,Vegas Verdes,Vegas Verdi,bei la si wei jia si,las wgas shmaly  nwada,noseulaseubeigeoseu,nosurasubegasu,nwrth las fyghas,Норт-Лас-Вегас,Северен Лас Вегас,Северни Лас Вегас,لاس وگاس شمالی، نوادا,نارتھ لاس ویگاس، نیواڈا,نورث لاس فيغاس,ノースラスベガス,北拉斯維加斯,노스라스베이거스', 36.1988600, -115.1175000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145244, 'Pahrump', 'Pahrump', 'Pahrump,Pakhrump,Parimpa,bahrwmb,pa lang,phramp  nwada,Пахрумп,باهرومب,پارومپ، نیواڈا,پهرامپ، نوادا,帕朗', 36.2082900, -115.9839100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145245, 'Paradise', 'Paradise', 'Paradajs,Paradajz,Paradise,baradays,paeleodaiseu,paradaisu,paradays  nwada,tian tang shi,Парадайз,Парадайс,Парадајс,بارادايس,پارادایس، نوادا,پيراڈائز، نیواڈا,パラダイス,天堂市,패러다이스', 36.0971900, -115.1466600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145246, 'Pioche', 'Pioche', 'Meadow Valley,Pioche,Pioche City,bywtsh,pi ao qi,pywsh  nwada,بيوتش,پیوش، نوادا,پیوش، نیواڈا,皮奥奇', 37.9296900, -114.4522100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145247, 'Reno', 'Reno', 'Fullers Crossing,Lakes Crossing,RNO,Rehno,Reno,Reno-Stead,Rino,Rynas,Rīno,lei nuo,lino,rino,rynw,rynw  nwada,Ρίνο,Рено,Рино,Рэно,רינא,רינו,رينو,رینو,رینو، نوادا,رینو، نیواڈا,रिनो,リノ,雷諾,리노', 39.5296300, -119.8138000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145248, 'Sandy Valley', 'Sandy Valley', 'Sandy,Sandy Valley', 35.8169200, -115.6322300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145249, 'Silver Springs', 'Silver Springs', 'Silver Springs,Silver Springs Station', 39.4154700, -119.2246100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145250, 'Smith', 'Smith', '', 38.8004700, -119.3273800, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145251, 'Spanish Springs', 'Spanish Springs', '', 39.6490800, -119.7074100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145252, 'Sparks', 'Sparks', 'Harriman,Sparks,asparks  nwada,sbarks,seupakeuseu,Спаркс,اسپارکس، نوادا,سباركس,سپارکس، نیواڈا,스파크스', 39.5349100, -119.7526900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145253, 'Spring Valley', 'Spring Valley', 'Spring Vali,Spring Valley,Spring-Vehlli,aspryng wly  nwada,sbryngh faly,seupeulingbaelli,supuringubare,Спринг Вали,Спринг-Вэлли,اسپرینگ ولی، نوادا,سبرينغ فالي,سپرنگ ویلی، نیواڈا,スプリングバレー,스프링밸리', 36.1080300, -115.2450000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145254, 'Stagecoach', 'Stagecoach', '', 39.3738000, -119.3740600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145255, 'Sun Valley', 'Sun Valley', '', 39.5963000, -119.7760200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145256, 'Sunrise Manor', 'Sunrise Manor', 'Sanrajz Mejnor,Sanrajz-Mehner,Sunrise Manor,sanraizumana,sanrayz mnwr  nwada,snrayz manwr,Санрайз-Мэнер,Санрајз Мејнор,سانرایز منور، نوادا,سنرائز مینور، نیواڈا,سنرايز مانور,サンライズマナー', 36.2110800, -115.0730600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145257, 'Tonopah', 'Tonopah', 'Butler,TPH,Tonapah,Tonopa,Tonopah,Tonopakh,tnwpa  nwada,tuo nuo pa,twnwbah,Тонопа,Тонопах,تنوپا، نوادا,تونوباه,ٹونوپاہ، نیواڈا,托诺帕', 38.0671600, -117.2300800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145258, 'Verdi', 'Verdi', '', 39.5182400, -119.9888100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145259, 'Virginia City', 'Virginia City', 'Ophir,Pleasant Hill,Silver City,Thanh pho Virginia,Thành phố Virginia,Virdzhinija-Siti,Virdzinija Siti,Virginia City,Virginiurbo,bajiniashiti,fu ji ni ya cheng,fyrjynya syty,wyrjynya syty  mwntana,Вирджиния-Сити,Вирџинија Сити,Вірджинія-Сіті,فيرجينيا سيتي,ورجینیا سٹی، نیواڈا,ویرجینیا سیتی، مونتانا,バージニアシティ,弗吉尼亚城', 39.3096300, -119.6496200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145260, 'Whitney', 'Whitney', 'Uitni,Уитни', 36.0983100, -115.0363000, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145261, 'Winchester', 'Winchester', 'Vinchestehr,Vinchester,wincheseuteo,wynchstr  nwada,wynshstr,Винчестер,Винчестэр,Вінчестер,ونچیسٹر، نیواڈا,وينشستر,وینچستر، نوادا,윈체스터', 36.1299700, -115.1188900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145262, 'Yerington', 'Yerington', 'EYR,Greenfield,Jerington,Jeringtun,Mason Valley,Pizen Switch,Poison Switch,Yerington,ye ling dun,yrynghtwn,yryngtwn  nwada,Јерингтон,Йерингтон,Йерингтън,يرينغتون,یرینگتون، نوادا,یرینگتوں، نیواڈا,耶灵顿', 38.9857500, -119.1629300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145263, 'Beaver', 'Beaver', 'Beaver,Beaver City,Biver,bywr  aklahma,Бивер,بیور، اکلاهما', 36.8161400, -100.5198700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145264, 'Boise City', 'Boise City', 'Boise City,Bojs Siti,Bojsi Siti,Cimarron,bwyz syty,bwyzy syty  aklahma,Бойс Сити,Бојси Сити,بويز سيتي,بویزی سیتی، اکلاهما', 36.7294700, -102.5132400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145265, 'Goodwell', 'Goodwell', '', 36.5953000, -101.6365500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145266, 'Guymon', 'Guymon', 'GUY,Gajmon,ghymwn,gwymwn  aklahma,Гаймон,Гајмон,غيمون,گویمون، اکلاهما', 36.6828000, -101.4815500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145267, 'Hooker', 'Hooker', 'Hook,Hooker', 36.8600300, -101.2135000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145268, 'Abernathy', 'Abernathy', 'Abernati,abrnaty  tgzas,abyrnathy,Абернати,آبرناتی، تگزاس,أبيرناثي', 33.8323000, -101.8429500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145269, 'Agua Dulce', 'Agua Dulce', '', 31.6551100, -106.1388700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145270, 'Alpine', 'Alpine', 'ALE,Alpajn,Alpine,Murphyville,Osborne,albyny,alpayn,Алпайн,Алпајн,آلپاین,البيني', 30.3586200, -103.6620600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145271, 'Amarillo', 'Amarillo', 'AMA,Amarilas,Amarillo,Amarilo,Amarilyo,Oneida,a ma li luo,aemeolillo,amariro,amariyo,amarylw,amarylw  tgzas,Амарилло,Амарило,Ամարիլլո,אמרילו,آماریلو، تگزاس,آماریلو، ٹیکساس,أماريلو,اماریلو,आमारियो,アマリロ,阿馬里洛,애머릴로', 35.2220000, -101.8313000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145272, 'Andrews', 'Andrews', 'Andrus,Endruz,aendeuluseu,an de lu si,andrwz,andrwz  tgzas,Андрус,Ендруз,أندروز,اندروز، تگزاس,安德鲁斯,앤드루스', 32.3187200, -102.5457200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145273, 'Anthony', 'Anthony', 'Anthony,La Tuna', 31.9992700, -106.6055500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145274, 'Aspermont', 'Aspermont', '', 33.1334300, -100.2273300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145275, 'Big Lake', 'Big Lake', 'Big Lejk,byg lyk  tgzas,bygh lyk,Биг Лејк,بيغ ليك,بیگ لیک، تگزاس', 31.1915400, -101.4603900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145276, 'Big Spring', 'Big Spring', 'Big Spring,Big Springs,Bigspring,HCA,byg aspryng  tgzas,bygh sbryngh,Биг Спринг,بيغ سبرينغ,بیگ اسپرینگ، تگزاس', 32.2504000, -101.4787400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145277, 'Booker', 'Booker', '', 36.4533600, -100.5373700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145278, 'Borger', 'Borger', 'BGD,Borger,bwrgr  tgzas,bwrjyr,Боргер,بورجير,بورگر، تگزاس', 35.6678200, -101.3973900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145279, 'Bovina', 'Bovina', 'Bovina,Bull Town', 34.5136800, -102.8830000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145280, 'Brackettville', 'Brackettville', 'Brackett,Brackettville,Braketvil,braktwyl  tgzas,brakytfyl,Бракетвил,براكيتفيل,براکتویل، تگزاس', 29.3105100, -100.4178600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145281, 'Brownfield', 'Brownfield', 'Braunfild,brawnfyld,brawnfyld  tgzas,Браунфилд,براونفيلد,براونفیلد، تگزاس', 33.1812000, -102.2743500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145282, 'Bushland', 'Bushland', 'Bush,Bushland', 35.1920000, -102.0646400, 'US', '2010-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145283, 'Cactus', 'Cactus', '', 36.0522600, -102.0024000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145284, 'Canadian', 'Canadian', 'Kanejdijan,kaenadian,kanydyn  tgzas,kndyan,Канејдијан,كنديان,کانیدین، تگزاس,캐나디안', 35.9128200, -100.3820800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145285, 'Canutillo', 'Canutillo', '', 31.9114900, -106.6002700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145286, 'Canyon', 'Canyon', 'Kanjon,kanywn,kanywn  tgzas,Канјон,كانيون,کانیون، تگزاس', 34.9803300, -101.9188000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145287, 'Channing', 'Channing', '', 35.6836500, -102.3302000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145288, 'Childress', 'Childress', 'CDS,Childres,chyldrs  tgzas,cildresa,tshayldrys,Чилдрес,تشايلدريس,چیلدرس، تگزاس,चिल्ड्रेस', 34.4264500, -100.2040000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145289, 'Cienegas Terrace', 'Cienegas Terrace', '', 29.3674500, -100.9437100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145290, 'Clarendon', 'Clarendon', 'Klarendon,klarndwn  tgzas,klaryndwn,Кларендон,كلاريندون,کلارندون، تگزاس', 34.9378300, -100.8882000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145291, 'Claude', 'Claude', 'Klod,ke lao de,klwd,klwd  tgzas,Клод,كلود,کلود، تگزاس,克劳德', 35.1117200, -101.3632200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145292, 'Clint', 'Clint', '', 31.5923400, -106.2241400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145293, 'Colorado City', 'Colorado City', 'Colorado,Colorado City,Kolorado Siti,klradw syty  tgzas,kwlwradw syty,Колорадо Сити,كولورادو سيتي,کلرادو سیتی، تگزاس', 32.3881700, -100.8645600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145294, 'Crane', 'Crane', 'CCG,Krejn,kran,kryn  tgzas,Крејн,كران,کرین، تگزاس,کرین، ٹیکساس', 31.3973600, -102.3501400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145295, 'Crosbyton', 'Crosbyton', '', 33.6600800, -101.2379300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145296, 'Dalhart', 'Dalhart', 'DHT,Dalhart,Dalkhart,Denrock,Twist,Twist Junction,dalhart,dalhart  tgzas,delaharta,Далхарт,دالهارت,دالهارت، تگزاس,डॅलहार्ट', 36.0594800, -102.5132500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145297, 'Del Rio', 'Del Rio', 'DRT,Del Rio,Del Río,Del''-Rio,Delrio,dl ryw  tgzas,dyl ryw,Дел Рио,Дель-Рио,Дель-Ріо,دل ریو، تگزاس,ديل ريو,デル・リオ', 29.3627300, -100.8967600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145298, 'Denver City', 'Denver City', 'Denver,Denver City', 32.9645500, -102.8291000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145299, 'Dickens', 'Dickens', '', 33.6217500, -100.8365200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145300, 'Dimmitt', 'Dimmitt', 'Dimit,dymyt,dymyt  tgzas,Димит,ديميت,دیمیت، تگزاس', 34.5509000, -102.3118600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145301, 'Dumas', 'Dumas', 'Dumas,dwmas,dwmas  tgzas,dyumasa,Думас,دوماس,دوماس، تگزاس,ड्युमास', 35.8655900, -101.9732400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145302, 'Eagle Pass', 'Eagle Pass', 'EGP,Eagle Pass,Igl Pas,ayghl bas,aygl ps  tgzas,Игл Пас,إيغل باس,ایگل پس، تگزاس', 28.7091400, -100.4995200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145303, 'Earth', 'Earth', 'Earth,Fairleen', 34.2331400, -102.4107500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145304, 'Eidson Road', 'Eidson Road', '', 28.6772000, -100.4870200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145305, 'El Paso', 'El Paso', 'Concordia,ELP,Ehl''-Paso,El Pasas,El Paso,El''-Paso,El-Paso,Elpaso,Franklin,Gorad Ehl''-Pasa,Magoffinsville,Passus,ai er pa suo,al basw,al pasw,ayl pasw,el-paso,ela peso,ela pyaso,elpaeso,Ελ Πάσο,Горад Эль-Паса,Ел Пасо,Ель-Пасо,Эль-Пасо,Էլ Պասո,אל פאסו,إل باسو,ال پاسو,ایل پاسو,एल पॅसो,এল প্যাসো,เอลแพโซ,ელ-პასო,ელ-ფასო,エル・パソ,艾爾帕索,엘패소', 31.7587200, -106.4869300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145306, 'Eldorado', 'Eldorado', 'Eldorado,Verand', 30.8601700, -100.6009300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145307, 'Elm Creek', 'Elm Creek', '', 28.7744200, -100.4917400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145308, 'Fabens', 'Fabens', '', 31.5023400, -106.1585900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145309, 'Farwell', 'Farwell', 'Farvel,farwl  tgzas,farwyl,Фарвел,فارول، تگزاس,فارويل', 34.3834100, -103.0380000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145310, 'Floydada', 'Floydada', 'Flojdejda,flwydada,flwydada  tgzas,Флојдејда,فلويدادا,فلویدادا، تگزاس', 33.9845200, -101.3376600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145311, 'Fort Clark Springs', 'Fort Clark Springs', '', 29.3060700, -100.4220200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145312, 'Fort Davis', 'Fort Davis', 'Fort Dejvis,fwrt dywys,fwrt dywys  tgzas,Форт Дејвис,فورت ديويس,فورت دیویس، تگزاس', 30.5882100, -103.8946300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145313, 'Fort Hancock', 'Fort Hancock', 'Fort Hancock,Fort Handcock', 31.2984600, -105.8452500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145314, 'Fort Stockton', 'Fort Stockton', 'FST,Fort Stokton,Fort-Stokton,fwrt astaktwn  tgzas,Форт Стоктон,Форт-Стоктон,فورت استاکتون، تگزاس', 30.8940400, -102.8793200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145315, 'Friona', 'Friona', '', 34.6417300, -102.7241000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145316, 'Fritch', 'Fritch', '', 35.6397700, -101.6032300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145317, 'Gail', 'Gail', '', 32.7703800, -101.4454100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145318, 'Garden City', 'Garden City', 'Garden City,New California', 31.8640200, -101.4812300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145319, 'Gardendale', 'Gardendale', '', 32.0204000, -102.3801500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145320, 'Grape Creek', 'Grape Creek', '', 31.5793200, -100.5476000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145321, 'Guthrie', 'Guthrie', '', 33.6206400, -100.3228900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145322, 'Hale Center', 'Hale Center', '', 34.0642400, -101.8437900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145323, 'Hamlin', 'Hamlin', '', 32.8848300, -100.1264900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145324, 'Hart', 'Hart', '', 34.3850700, -102.1157400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145325, 'Hereford', 'Hereford', 'Herefoid,Hereford,Kherford,hrfwrd  tgzas,hyrfwrd,Херфорд,هرفورد، تگزاس,هيرفورد', 34.8152100, -102.3993200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145326, 'Homestead Meadows North', 'Homestead Meadows North', 'Homestead Meadows North', 31.8496300, -106.1728500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145327, 'Homestead Meadows South', 'Homestead Meadows South', 'Homestead Meadows South', 31.8109700, -106.1642700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145328, 'Horizon City', 'Horizon City', '', 31.6926100, -106.2074800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145329, 'Idalou', 'Idalou', '', 33.6664700, -101.6829400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145330, 'Iraan', 'Iraan', 'IRB', 30.9140500, -101.8979100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145331, 'Jayton', 'Jayton', '', 33.2481500, -100.5737300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145332, 'Kermit', 'Kermit', '', 31.8576300, -103.0926700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145333, 'Lamesa', 'Lamesa', 'Chicago,Lamesa,Lamisa,lamsa  tgzas,lamysa,leomisa,Ламиса,لامسا، تگزاس,لاميسا,لامیسا، ٹیکساس,러미사', 32.7376000, -101.9509900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145334, 'Las Quintas Fronterizas', 'Las Quintas Fronterizas', '', 28.6905300, -100.4686900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145335, 'Las Quintas Fronterizas Colonia', 'Las Quintas Fronterizas Colonia', '', 28.6913700, -100.4692400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145336, 'Levelland', 'Levelland', 'Levland,lwlnd  tgzas,lyfyland,Левланд,لولند، تگزاس,ليفيلاند', 33.5873200, -102.3779600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145337, 'Littlefield', 'Littlefield', 'Litlfild,liteulpildeu,lytlfyld,lytlfyld  tgzas,Литлфилд,ليتلفيلد,لیتلفیلد، تگزاس,리틀필드', 33.9173100, -102.3249000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145338, 'Lockney', 'Lockney', '', 34.1245200, -101.4415500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145339, 'Lorenzo', 'Lorenzo', '', 33.6706400, -101.5351600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145340, 'Lubbock', 'Lubbock', 'LBB,Labbok,Labok,Lubbock,Lubuk,la bo ke,labak  tgzas,labaka,lbk,leobeog,lwbwk,rabokku,Лаббок,Лабок,Лъбък,לאבק,لاباک، تگزاس,لابوک، ٹیکساس,لبک,لوبوك,लबक,ラボック,拉伯克,러벅', 33.5778600, -101.8551700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145341, 'Marfa', 'Marfa', 'Jarja,MRF,Marfa,marfa,marfa  tgzas,Марфа,مارفا,مارفا، تگزاس', 30.3097300, -104.0213400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145342, 'Matador', 'Matador', '', 34.0120200, -100.8220800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145343, 'McCamey', 'McCamey', '', 31.1359800, -102.2243000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145344, 'Memphis', 'Memphis', 'Memfis,menfisu,mmfys,mmfys  tgzas,Мемфис,ممفيس,ممفیس، تگزاس,メンフィス', 34.7247800, -100.5340100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145345, 'Mentone', 'Mentone', 'Juanita,Mentone,Porterville', 31.7051300, -103.5993500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145346, 'Merkel', 'Merkel', '', 32.4706800, -100.0128700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145347, 'Mertzon', 'Mertzon', '', 31.2618300, -100.8173300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145348, 'Miami', 'Miami', 'Majami,Майами', 35.6914300, -100.6381900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145349, 'Midland', 'Midland', 'MAF,Midland,Midlend,Midway,mdland,mi de lan,middorando,mideullaendeu,mydlnd,mydlnd  tgzas,Мидланд,Мидленд,Мідленд,מידלנד,مدلاند,مڈلینڈ، ٹیکساس,میدلند، تگزاس,ミッドランド,米德蘭,미들랜드', 31.9973500, -102.0779100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145350, 'Monahans', 'Monahans', 'MIF,Monakhans,manahnz  tgzas,mwnahanz,Монаханс,ماناهنز، تگزاس,موناهانز', 31.5943000, -102.8926500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145351, 'Morton', 'Morton', '', 33.7251000, -102.7593800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145352, 'Muleshoe', 'Muleshoe', 'Mjulshu,mwlshw,mwlshw  tgzas,Мјулшу,مولشو,مولشو، تگزاس', 34.2264700, -102.7238300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145353, 'Odessa', 'Odessa', 'Odesa,Odessa,ao de sa,awdsa,awdysa,odessa,Одеса,Одесса,أوديسا,اودسا,اوڈیسا، ٹیکساس,اوڈیسہ، ٹیکساس,オデッサ,敖德薩', 31.8456800, -102.3676400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145354, 'Olton', 'Olton', '', 34.1834100, -102.1346300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145355, 'Ozona', 'Ozona', 'awzana  tgzas,awzwna,ozona,أوزونا,اوزانا، تگزاس,オゾナ', 30.7101700, -101.2006700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145356, 'Paducah', 'Paducah', '', 34.0123000, -100.3020600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145357, 'Pampa', 'Pampa', 'Glasgow,Pampa,Sutton,bamba,pampa  tgzas,Пампа,بامبا,پامپا، تگزاس', 35.5361600, -100.9598700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145358, 'Panhandle', 'Panhandle', 'Carson City,Panhandle,Panhandle City', 35.3456000, -101.3804400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145359, 'Pecos', 'Pecos', 'Pekos,bykws,pyks  tgzas,Пекос,بيكوس,پیکس، تگزاس', 31.4229100, -103.4932300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145360, 'Perryton', 'Perryton', 'Periton,byrytwn,prytn  tgzas,Перитон,بيريتون,پریتن، تگزاس', 36.4000300, -100.8026500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145361, 'Petersburg', 'Petersburg', 'Peterburg,Петербург', 33.8695200, -101.5973900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145362, 'Plains', 'Plains', '', 33.1887100, -102.8279900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145363, 'Plainview', 'Plainview', 'PVW,Plejnvju,blynfyw,plynwyw  tgzas,Плејнвју,بلينفيو,پلینویو، تگزاس', 34.1847900, -101.7068400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145364, 'Post', 'Post', 'Poust,bwst,pst  tgzas,Поуст,بوست,پست، تگزاس', 33.1912200, -101.3790000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145365, 'Presidio', 'Presidio', 'Presidio,bryzydyw,prsydyw  tgzas,Пресидио,Пресідіо,بريزيديو,پرسیدیو، تگزاس', 29.5607400, -104.3721500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145366, 'Rankin', 'Rankin', '', 31.2226500, -101.9379100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145367, 'Ransom Canyon', 'Ransom Canyon', 'Lake Ransom Canyon,Lake Ransome Canyon Village,Ransom Canyon', 33.5334200, -101.6796100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145368, 'Robert Lee', 'Robert Lee', '', 31.8923700, -100.4848200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145369, 'Roby', 'Roby', '', 32.7448300, -100.3776100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145370, 'Rocksprings', 'Rocksprings', '', 30.0157600, -100.2053600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145371, 'Roscoe', 'Roscoe', 'Roscoe,Vista', 32.4459500, -100.5387200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145372, 'Rosita North', 'Rosita North', 'Rosita North,Rosita North Census Designated Place', 28.6564400, -100.4221800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145373, 'Rosita South', 'Rosita South', 'Rosita South,Rosita South Census Designated Place', 28.6237500, -100.4283700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145374, 'Rotan', 'Rotan', '', 32.8520500, -100.4656600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145375, 'San Angelo', 'San Angelo', 'SJT,San Andzelo,San Angelo,saen-aenjello,san anjylw,san aynjlw,san''anjero,sheng an ji luo,sn anjlw  tgzas,Сан Анџело,سان أنجيلو,سان اینجلو,سان اینجلو، ٹیکساس,سن آنجلو، تگزاس,サンアンジェロ,聖安吉洛,샌앤젤로', 31.4637700, -100.4370400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145376, 'San Elizario', 'San Elizario', '', 31.5851100, -106.2727600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145377, 'Sanderson', 'Sanderson', '', 30.1424100, -102.3940300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145378, 'Seagraves', 'Seagraves', '', 32.9442700, -102.5649100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145379, 'Seminole', 'Seminole', '', 32.7189900, -102.6449100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145380, 'Seth Ward', 'Seth Ward', '', 34.2117400, -101.6901700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145381, 'Shallowater', 'Shallowater', '', 33.6889700, -101.9982300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145382, 'Shamrock', 'Shamrock', 'Shamrok,shamrwk tksas,shmrak  tgzas,Шамрок,شامروك تكساس,شمراک، تگزاس', 35.2142200, -100.2490100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145383, 'Sierra Blanca', 'Sierra Blanca', 'Sijera Blanka,syra blnka  tgzas,Сијера Бланка,سیرا بلنکا، تگزاس', 31.1745700, -105.3571800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145384, 'Silverton', 'Silverton', 'Silverton,shirubaton,sylfrtwn,sylwrtwn  tgzas,Силвертон,سيلفرتون,سیلورتون، تگزاس,シルバートン', 34.4742300, -101.3046100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145385, 'Slaton', 'Slaton', '', 33.4373100, -101.6434900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145386, 'Snyder', 'Snyder', 'Snajder,asnaydr  tgzas,seunaideo,snaydr,Снајдер,اسنایدر، تگزاس,سنايدر,스나이더', 32.7178900, -100.9176200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145387, 'Socorro', 'Socorro', 'Casey,Socorro,Sokorro,Сокорро', 31.6545600, -106.3033100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145388, 'Socorro Mission Number 1 Colonia', 'Socorro Mission Number 1 Colonia', '', 31.6362200, -106.2905400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145389, 'Sonora', 'Sonora', '', 30.5668500, -100.6434300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145390, 'Sparks', 'Sparks', 'Sparks,Спаркс', 31.6726100, -106.2397000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145391, 'Spearman', 'Spearman', '', 36.1983700, -101.1923800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145392, 'Stanton', 'Stanton', 'Grelton,Marienfeld,Stanton,Stehnton,Стэнтон', 32.1292900, -101.7884600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145393, 'Sterling City', 'Sterling City', '', 31.8362500, -100.9848300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145394, 'Stinnett', 'Stinnett', '', 35.8269800, -101.4429400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145395, 'Stratford', 'Stratford', 'Stratford,Стратфорд', 36.3361400, -102.0721200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145396, 'Sundown', 'Sundown', '', 33.4562100, -102.4893600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145397, 'Sunray', 'Sunray', '', 36.0167000, -101.8246200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145398, 'Sweetwater', 'Sweetwater', 'SWW,Svitvoter,swwytwatr  tgzas,swytwatr,Свитвотер,سوئیٹ واٹر، ٹیکساس,سوویتواتر، تگزاس,سويتواتر', 32.4709500, -100.4059400, 'US', '2017-07-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145399, 'Tahoka', 'Tahoka', '', 33.1667600, -101.7937700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145400, 'Tornillo', 'Tornillo', '', 31.4454000, -106.0883100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145401, 'Tulia', 'Tulia', 'Tulija,twlya,twlya  tgzas,Тулија,توليا,تولیا، تگزاس', 34.5358900, -101.7585200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145402, 'Val Verde Park', 'Val Verde Park', '', 29.3749500, -100.8317600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145403, 'Van Horn', 'Van Horn', 'VHN,Van Khorn,Van-Gorn,Van-Khorn,fan huo en,fan hwrn,wn hrn  tgzas,Ван Хорн,Ван-Горн,Ван-Хорн,فان هورن,ون هرن، تگزاس,范霍恩', 31.0402900, -104.8307300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145404, 'Vega', 'Vega', '', 35.2428300, -102.4282600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145405, 'Vinton', 'Vinton', '', 31.9512100, -106.6024900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145406, 'Wellington', 'Wellington', 'Velington,Vellington,wlyngtwn  tgzas,wylynghtwn,Велингтон,Веллингтон,ولینگتون، تگزاس,ويلينغتون,ویلنگٹن، ٹیکساس', 34.8561700, -100.2137300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145407, 'West Odessa', 'West Odessa', '', 31.8423500, -102.4987600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145408, 'Westway', 'Westway', '', 31.9587100, -106.5780500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145409, 'Wheeler', 'Wheeler', '', 35.4453300, -100.2709600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145410, 'Wink', 'Wink', 'INK', 31.7512400, -103.1598900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145411, 'Wolfforth', 'Wolfforth', '', 33.5059200, -102.0090600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145412, 'Aurora', 'Aurora', 'Aroura,Aurora,Avrora,Willow Bend,Аврора', 38.9221900, -111.9340900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145413, 'Beaver', 'Beaver', 'Bivur,bi fu,bywr  ywta,Бивър,بیور، یوتا,比弗', 38.2769100, -112.6410500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145414, 'Blanding', 'Blanding', 'BDG,Blanding,Grayson,blandyngh,blndyng  ywta,bu lan ding,Бландинг,بلاندينغ,بلندینگ، یوتا,布兰丁', 37.6243300, -109.4796600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145415, 'Carbonville', 'Carbonville', '', 39.6199600, -110.8343300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145416, 'Castle Dale', 'Castle Dale', 'Castle Dale,Castledale,Kasl Dejl,Kasul Dejl,cheng bao dai er,kasl dayl,Касл Дејл,Касъл Дейл,كاسل دايل,کاسل‌دیل، یوتا,城堡戴尔', 39.2121900, -111.0196100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145417, 'Cedar City', 'Cedar City', 'CDC,Cedar City,Coal Creek,Sidar Siti,Sidar-Siti,Sidur Siti,sdarsyty  ywta,shidashiti,sidara siti,sideositi,sydar syty,xue song cheng,Сидар Сити,Сидар-Сити,Сидър Сити,Сідар-Сіті,سدارسیتی، یوتا,سيدار سيتي,سیڈر سٹی، یوٹاہ,सीडार सिटी,シーダーシティ,雪松城,시더시티', 37.6774800, -113.0618900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145418, 'Delta', 'Delta', 'DTA,Delta,Melville,de er ta,dlta,dlta  ywta,Делта,دلتا,دلتا، یوتا,德尔塔', 39.3521800, -112.5771700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145419, 'East Carbon City', 'East Carbon City', 'Downtown,East Carbon,East Carbon City', 39.5477400, -110.4148800, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145420, 'Enoch', 'Enoch', 'Elk Horn Springs,Enoch,Inok,Inuk,Johnsons Settlement,aynwk,khnwkh  ywta,yi nuo ke,Инок,Инък,إينوك,خنوخ، یوتا,伊诺克', 37.7733100, -113.0243900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145421, 'Ephraim', 'Ephraim', 'Ephraim,Ephriam,Ifram,Ifrejm,Pine Creek,afraym,afraym  ywta,yi fa lian,Ифрам,Ифрейм,أفرايم,افرایم، یوتا,以法莲', 39.3596800, -111.5863100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145422, 'Enterprise', 'Enterprise', 'Enturprajz,antrbrayz,antrprayz  ywta,en te pu lai si,Ентърпрайз,إنتربرايز,انترپرایز، یوتا,恩特普赖斯', 37.5735900, -113.7191300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145423, 'Fairview', 'Fairview', 'Fair View,Fairview,Fervju,Feurvju,North Bend,fei er wei you,fyrfyw,fyrwyw  ywta,Фервју,Феървю,فيرفيو,فیئرویو، یوٹاہ,فیرویو، یوتا,费尔维尤', 39.6263500, -111.4396300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145424, 'Ferron', 'Ferron', 'Feron,Ferron,Ferrons City,Ferun,fei long,frrwn  ywta,fyrwn,Ферон,Ферън,فررون، یوتا,فيرون,费龙', 39.0935800, -111.1332200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145425, 'Fillmore', 'Fillmore', 'Filmor,fei er mo er,fylmwr,fylmwr  ywta,Филмор,فلمور، یوٹاہ,فيلمور,فیلمور، یوتا,菲尔莫尔', 38.9688500, -112.3235500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145426, 'Fountain Green', 'Fountain Green', 'Fauntin Grijn,Fauntin Grin,Fountain Green,Uintah Springs,fantyn gryn  ywta,fawntn ghryn,pen quan lu,Фаунтин Грийн,Фаунтин Грин,فانتین گرین، یوتا,فاونتن غرين,喷泉绿', 39.6299600, -111.6352000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145427, 'Genola', 'Genola', '', 39.9963400, -111.8432700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145428, 'Gunnison', 'Gunnison', 'Ganison,Gunisun,gan ni sen,ganysn  ywta,ghwnyswn,Ганисон,Гънисън,غونيسون,گانیسن، یوتا,甘尼森', 39.1552400, -111.8182600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145429, 'Helper', 'Helper', 'Khehlper,Khelper,Khelpur,bang shou,helpeo,hlbr,hlpr  ywta,Хелпер,Хелпър,Хэлпер,هلبر,هلپر، یوتا,帮手,헬퍼', 39.6841300, -110.8546100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145430, 'Hildale', 'Hildale', 'Hildale,Hilldale,Khajdejl,Khildejl,haydyl,he li dai er,Хајдејл,Хилдейл,هايديل,هیل‌دیل، یوتا,赫利戴尔', 37.0036000, -112.9668800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145431, 'Huntington', 'Huntington', 'Khantington,Khuntingtun,hantyngtwn  ywta,heng ting dun,hntnghtwn,Хантингтон,Хънтингтън,هانتینگتون، یوتا,هنتنغتون,亨廷顿', 39.3266400, -110.9646100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145432, 'Hurricane', 'Hurricane', 'Kharikejn,Khurikejn,ha li ken,harykn  ywta,hwrykan,Харикејн,Хърикейн,هاریکن، یوتا,هوريكان,哈里肯', 37.1752600, -113.2899500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145433, 'Ivins', 'Ivins', 'Ajvins,ai wen si,ayfynz,aywns  ywta,Айвинс,Ајвинс,إيفينز,ایونس، یوتا,艾文斯', 37.1685900, -113.6794100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145434, 'Junction', 'Junction', 'Dzankshon,jankshn  ywta,jnkshn,zhang ke shen,Џанкшон,جانکشن، یوتا,جنكشن,章克申', 38.2374800, -112.2199300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145435, 'Kanab', 'Kanab', 'KNB,Kanab,Kejnab,Kʼaiʼ Bił Hahazteel,ka na bu,kanab,kanab  ywta,Канаб,Кейнаб,קנאב,كاناب,کاناب، یوتا,卡纳布', 37.0474900, -112.5263100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145436, 'LaVerkin', 'LaVerkin', 'La Verkin,LaVerkin', 37.2010900, -113.2696700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145437, 'Loa', 'Loa', 'luo ya,lwa,lwa  ywta,لوا,لوا، یوتا,罗亚', 38.4027600, -111.6429600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145438, 'Manti', 'Manti', 'Manti,NTJ,man tai,manty,manty  ywta,Манти,مانتي,مانتی، یوتا,曼泰', 39.2683000, -111.6368600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145439, 'Milford', 'Milford', 'MLF,Milford,mi er fu de,mylfwrd,mylfwrd  ywta,Милфорд,ميلفورد,میلفورد، یوتا,میلفورڈ، یوٹاہ,米尔福德', 38.3969100, -113.0107900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145440, 'Moab', 'Moab', 'CNY,Elk Mountain Mission,Moab,Mouab,mo ya,moabu,moaeba,mwab,mwab  ywta,Моаб,Моуаб,מואב,مواب,مواب، یوتا,मोअॅब,モアブ,摩押', 38.5733200, -109.5498400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145441, 'Monroe', 'Monroe', 'Monro,men luo,mwnrw,mwnrw  ywta,Монро,مونرو,مونرو، یوتا,门罗', 38.6299700, -112.1207600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145442, 'Monticello', 'Monticello', 'Hammond,MXC,Maadiseloo,Maadíséloo,Monticello,Montiselo,Montiselou,mantyslw  ywta,meng di sai luo,mwntayslw,Монтисело,Монтиселоу,مانتیسلو، یوتا,مونتايسلو,蒙蒂塞洛', 37.8713800, -109.3428900, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145443, 'Moroni', 'Moroni', 'Mego,Moroni,mo luo ni,mwrwny,mwrwny  ywta,Морони,موروني,مورونی، یوتا,莫罗尼', 39.5249600, -111.5904700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145444, 'Mount Pleasant', 'Mount Pleasant', 'Fort Hamilton,Maunt Plezant,Mount Pleasant,mang te pu lin sen,mawnt blyzant,mwnt plznt  ywta,Маунт Плезант,ماونت بليزانت,مونت پلزنت، یوتا,芒特普林森', 39.5469100, -111.4554700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145445, 'Nephi', 'Nephi', 'NPH,Nefi,Nephi,Salt Creek,nfy  ywta,ni fei,nyfy,Нефи,نفی، یوتا,نيفي,尼腓', 39.7102300, -111.8363200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145446, 'Orangeville', 'Orangeville', '', 39.2271900, -111.0535000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145447, 'Panguitch', 'Panguitch', 'PNU,Panguitch,Pangvitch,Pejnguich,banghwytsh,pan gui qi,pngwyych  ywta,Пейнгуич,بانغويتش,پنگوئیچ، یوتا,潘圭奇', 37.8227600, -112.4357600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145448, 'Parowan', 'Parowan', 'Louisa,Parouan,Parovan,Parowan,barwan,pa luo wan,parwwan  ywta,Пароуан,باروان,پارووان، یوتا,帕罗宛', 37.8422000, -112.8280000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145449, 'Price', 'Price', 'PUC,Prajs,brays,peulaiseu,prays  ywta,pu lai si,puraisu,Прайс,Прајс,برايس,پرایس، یوتا,プライス,普赖斯,프라이스', 39.5994100, -110.8107100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145450, 'Richfield', 'Richfield', 'RIF,Richfijld,Richfild,li qi fei er de,rychfyld  ywta,rytshfyld,Ричфийлд,Ричфилд,ريتشفيلد,رچفیلڈ، یوٹاہ,ریچفیلد، یوتا,里奇菲尔德', 38.7724700, -112.0840900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145451, 'Saint George', 'Saint George', 'SGU', 37.1041500, -113.5841200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145452, 'Salina', 'Salina', 'SBO,Salajna,Salina,salayana,salyna,salyna  ywta,yan tian,Салайна,Салајна,Салина,سالينا,سالینا، یوتا,سیلائنا، یوٹاہ,सलायना,盐田', 38.9577400, -111.8599300, 'US', '2017-07-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145453, 'Santa Clara', 'Santa Clara', 'Santa Klara,santa klara,santa klara  ywta,sheng ke la la,Санта Клара,سانتا كلارا,سانتا کلارا، یوتا,圣克拉拉', 37.1330400, -113.6541300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145454, 'Santaquin', 'Santaquin', 'Santakuin,Santakvina,sang ta jin,santakwyn,santakyn  ywta,Сантакуин,سانتاكوين,سانتاکین، یوتا,桑塔金', 39.9755100, -111.7852100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145455, 'Spring City', 'Spring City', 'Spring Siti,aspryng syty  ywta,chun cheng,sbryngh syty,Спринг Сити,اسپرینگ سیتی، یوتا,سبرينغ سيتي,春城', 39.4824600, -111.4960200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145456, 'Spring Glen', 'Spring Glen', '', 39.6594100, -110.8534900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145457, 'Toquerville', 'Toquerville', 'Tokar,Toker,Tokerville,Toquerville,Toukurvil,takwyrwyl  ywta,tuo kai wei er,twkywrfyl,Тоукървил,تاکوئرویل، یوتا,توكيورفيل,托凯维尔', 37.2533200, -113.2846700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145458, 'Washington', 'Washington', 'Uoshingtun,Vashington,hua sheng dun,washntn,washyngtn  ywta,Вашингтон,Уошингтън,واشنطن,واشنگٹن، یوٹاہ,واشینگتن، یوتا,华盛顿', 37.1305400, -113.5082900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145459, 'Wellington', 'Wellington', 'Uelingtun,Velington,Vellington,hui ling dun,wellingteon,wlyngtwn  ywta,wylynghtwn,Велингтон,Веллингтон,Уелингтън,ولینگتون، یوتا,ويلينغتون,ویلنگٹن، یوٹاہ,惠灵顿,웰링턴', 39.5424700, -110.7354300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145460, 'West Sedona', 'West Sedona', '', 34.8672400, -111.8054300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145461, 'Sheridan', 'Sheridan', '', 38.9796200, -121.3755100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145462, 'Three Rivers', 'Three Rivers', 'Three Rivers,Threerivers,Tri Rivers,thri ribharas,Три Риверс,थ्री रिभरस्', 36.4388400, -118.9045400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145463, 'Wasco', 'Wasco', 'Dewey,Deweyville,Uasko,Vasko,Wasco,vasko,waskw,waskw  kalyfrnya,wo si ke,Васко,Уаско,واسكو,واسکو، کالیفرنیا,वास्को,沃斯科', 35.5941200, -119.3409500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145464, 'West Bishop', 'West Bishop', '', 37.3610400, -118.4551100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145465, 'Paonia', 'Paonia', 'Paonia,Paonija,WPO,bawnya,pa''oniya,paywnya  klradw,pei ao ni ya,Паониа,Паония,Паонија,باونيا,پائونیا، کلرادو,पाओनिया,佩奥尼亚', 38.8683200, -107.5920000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145466, 'Cimarron', 'Cimarron', 'Simaron,symarwn,symran  kanzas,Симарон,سيمارون,سیمران، کانزاس', 37.8066900, -100.3482000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145467, 'Pojoaque', 'Pojoaque', 'A''sona *,P''asuiap *,P''o-suwa-geh,Po-suan-gai *,Po-zuan-ge,Pohwake *,Pojague,Pojoaque,Pojouque,Pojuague *,Posonwu *,Posoong-wa-gay,Posunwaege *,Potzua-ge *,San Francisco Pajague', 35.8928000, -106.0230800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145468, 'Beatty', 'Beatty', 'BTY,Biti,Bitti,byty,byty  nwada,Бити,Битти,بيتي,بیتی، نوادا,بیٹی، نیواڈا', 36.9085600, -116.7592300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145469, 'Indian Hills', 'Indian Hills', '', 39.0860200, -119.7840700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145470, 'Anton', 'Anton', '', 33.8112000, -102.1637900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145471, 'Gruver', 'Gruver', '', 36.2650300, -101.4062700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145472, 'Ralls', 'Ralls', '', 33.6742500, -101.3876600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145473, 'Spur', 'Spur', 'Dockham,Espuela,Spur', 33.4764800, -100.8556900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145474, 'Centerfield', 'Centerfield', '', 39.1252400, -111.8190900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145475, 'Ajo', 'Ajo', 'Akho,aho,ajo,ajw  aryzwna,Ахо,اجو، اریزونا,अजो,アホ', 32.3717200, -112.8607100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145476, 'Anthem', 'Anthem', '', 33.8672600, -112.1468200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145477, 'Apache Junction', 'Apache Junction', 'Apachi DZankshon,Apachi Dzhunkshun,Apachi-Dzhankshen,Apachi-Dzhankshn,a pa qi zhang ke shen,abatshy jnkshn,apace jankasana,apachy jankshn  aryzwna,Апачи Џанкшон,Апачи Джънкшън,Апачи-Джанкшен,Апачі-Джанкшн,آپاچی جانکشن، آریزونا,أباتشي جنكشن,अपाचे जंकसन,阿帕奇章克申', 33.4150500, -111.5495800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145478, 'Arivaca Junction', 'Arivaca Junction', 'Arivaca Junction,Kinsley Ranch,Reventon', 31.7273100, -111.0612000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145479, 'Arizona City', 'Arizona City', '', 32.7558900, -111.6709600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145480, 'Avondale', 'Avondale', 'Avondale,Avondale Ranch,Avondejl,Avundejl,Ejvondejl,Litchfield,afwndyl,ai wen dai er,awndyl  aryzwna,ebhonadela,Авондејл,Авъндейл,Ейвондейл,أفونديل,اوندیل، آریزونا,ایونڈیل، ایریزونا,एभोनडेल,埃文代尔', 33.4356000, -112.3496000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145481, 'Avra Valley', 'Avra Valley', '', 32.4378500, -111.3153900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145482, 'Bagdad', 'Bagdad', 'BGT,Bagdad', 34.5811300, -113.2046400, 'US', '2016-12-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145483, 'Beaver Dam', 'Beaver Dam', 'Beaver Dam,Beaverdam,Littlefield', 36.8994200, -113.9327400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145484, 'Benson', 'Benson', 'Benson,Bensun,ben sen,benasana,bnswn  aryzwna,bynswn,Бенсон,Бенсън,بنسون، آریزونا,بينسون,बेनसन,本森', 31.9678600, -110.2945200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145485, 'Big Park', 'Big Park', '', 34.7803000, -111.7626500, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145486, 'Wray', 'Wray', 'Rehj,Rej,Vrej,lei,re,wray  klradw,Вреј,Рей,Рэй,ورای، کلرادو,रे,雷', 40.0758200, -102.2232500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145487, 'Rathdrum', 'Rathdrum', 'Rasdrum,Ratdram,Ratdrum,Rathdrum,Westwood,ratdrami,rathdrwm,rryacadrama,rtram  aydahw,Расдрум,Ратдрам,Ратдръм,راثدروم,رترام، آیداهو,र्र्याचड्रम,რათდრამი', 47.8124000, -116.8965900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145488, 'Juneau', 'Juneau', 'Cuno,Dzanti K''iheeni,Dzhuna,Dzhuno,Dzunas,Dzuno,Dzuns,Džunas,Džuns,Džūno,Fliptown,Harrisburg,Iunellum,JNU,Juneau,Juneau City,Juneau Wharf,Juno,Pilzburg,Rockwell,Tisaantikii Hiinii,Tzouno,Zhuno,gwnw,jun''yu,juna''u byuro,juno,junu,jwnw,jwnw  alaska,jwnyaw  alaska,zhu nuo,Τζούνο,Џуно,Джуна,Джуно,Жуно,Ջունո,גונו,اوکلاہوما سٹی,جونو,جونو، آلاسکا,جونیاؤ، الاسکا,جونیا‌ؤ,जुनू,जुनो,जुन्यु,জুনাউ ব্যুরো,ଜୁନୋ,ஜூனோ,ჯუნო,ジュノー,朱諾,주노', 58.3019400, -134.4197200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145489, 'Beach', 'Beach', '', 46.9180700, -104.0043700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145490, 'Ketchikan', 'Ketchikan', 'KTN,Kechikan,Kecingen,Ketchikan,Keçingen,Kichikan,Kitchikan,Kitskan,kchykan  alaska,ke qi kan,kechikan,kecikana,kytshykan,qtzyqn,Кетчикан,Кечикан,קטציקן,كيتشيكان,کٹچیکان، الاسکا,کچیکان، آلاسکا,केचिकान,ケチカン,克奇坎', 55.3418000, -131.6475700, 'US', '2017-05-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145491, 'Little Cottonwood Creek Valley', 'Little Cottonwood Creek Valley', '', 40.6043900, -111.8293800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145492, 'Salem', 'Salem', 'Pond Town,Pondtown,Salem,Sejlem,Summer Spring,Сейлем', 40.0530100, -111.6735400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145493, 'Wellsville', 'Wellsville', 'Uelsvil,Velsvil,wei er si wei er,wlzwyl  ywta,wylzfyl,Велсвил,Уелсвил,ولزویل، یوتا,ويلزفيل,韦尔斯维尔', 41.6385400, -111.9338300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145494, 'Lea Hill', 'Lea Hill', '', 47.3262100, -122.1815100, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145495, 'Metlakatla', 'Metlakatla', 'MTM,Maxlakxaala,Metla-katla,Metlah-Catlah,Metlahcatlah,Metlahkatlah,Metlakahtla,Metlakatla,New Metlakahta,New Metlakatla,Port Chester', 55.1284800, -131.5751900, 'US', '2017-06-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145496, 'Petersburg', 'Petersburg', 'Borough di Petersburg,PSG,Peterburg,Peterburgo,Petersburg,Pitersberg,Pitersburg,Seet Ka,bi de si bao,btrsbwrgh,pitarasbarga,pytrzbwrg  alaska,Петербург,Питерсберг,Питерсбург,Пітерсберг,بطرسبورغ,پیترزبورگ، آلاسکا,پیٹرزبرگ، الاسکا,पिटरस्बर्ग,彼得斯堡', 56.8125000, -132.9555600, 'US', '2017-07-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145497, 'Sitka', 'Sitka', 'City and Borough of Sitka,Fort New Archangel,Gorad Sitka,New Archangel,Novo - Arkhangel''sk,Novo Arkhangelsk,Novoarkhangelsk,SIT,Schitcha,Schitka,Schitkha,Sheet''ka,Sikhta,Sitcha,Sitka,Sitka City and Borough,Sitka srjan,Sitkae,Sitkha,Sitki,shitoka,siska,sitaka byuro,sitka,sytka,sytka  alaska,sytqh,xi te ka,Горад Сітка,Ситкæ,Ситка,Սիտկա շրջան,סיטקה,سيتكا,سیتکا، آلاسکا,سیٹکا، الاسکا,सित्का,সিটকা ব্যুরো,シトカ,錫特卡,싯카', 57.0531500, -135.3308800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145498, 'Wrangell', 'Wrangell', 'Fort Stikine,Fort Wrangel,Fort Wrangell,Redut Svataya Dioniciya,WRG,Wrangel,Wrangell,Wrangle', 56.4708300, -132.3766700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145499, 'Alturas', 'Alturas', 'Al''turas,Alturas,Dorris Bridge,Dorrisville,a er tu la si,altaurasa,altwras,altwras  kalyfrnya,aruto~urasu,Алтурас,Альтурас,آلتوراس، کالیفرنیا,ألتوراس,अल्टौरस,アルトゥラス,阿尔图拉斯', 41.4871400, -120.5434900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145500, 'Anderson', 'Anderson', 'Anderson,Andersun,an de sen,andrswn,andrswn  kalyfrnya,endarasana,Андерсон,Андерсън,آندرسون، کالیفرنیا,أندرسون,اینڈرسن، کیلیفورنیا,एन्डरसन,安德森', 40.4482100, -122.2977800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145501, 'Arcata', 'Arcata', 'ACV,Arcata,Arkata,Arkejta,Goad-La-Nah,Kori,Union,Union Town,Uniontown,a ke ta,aketa,arkata,arkata  kalyfrnya,arketa,Арката,Аркејта,آرکاتا، کالیفرنیا,آرکاٹا، کیلیفورنیا,أركاتا,आर्केटा,アーケータ,阿克塔', 40.8665200, -124.0828400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145502, 'Bayside', 'Bayside', '', 40.8423500, -124.0636700, 'US', '2010-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145503, 'Bayview', 'Bayview', '', 40.7726300, -124.1839500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145504, 'Bella Vista', 'Bella Vista', 'Bella Vista,Bellavista', 40.6407100, -122.2325000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145505, 'Blue Lake', 'Blue Lake', 'Blu Lejk,Blue Lake,Camp Skidaddle,Powersville,Scottsville,blu leka,blw laky,blw lyk  kalyfrnya,blyw lyk  kylyfwrnya,lan hu,Блу Лейк,Блу Лејк,بلو لاكي,بلو لیک، کالیفرنیا,بلیو لیک، کیلیفورنیا,ब्लु लेक,蓝湖', 40.8829100, -123.9839500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145506, 'Burney', 'Burney', 'Barni,Burney,Burney Valley,barni,Барни,बार्नी', 40.8823800, -121.6608200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145507, 'Central Valley (historical)', 'Central Valley (historical)', '', 40.6804300, -122.3711200, 'US', '2015-11-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145508, 'Chester', 'Chester', 'Big Meadows,Chester,cestara,Честер,चेस्टर', 40.3062700, -121.2319100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145509, 'Cottonwood', 'Cottonwood', '', 40.3857100, -122.2808400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145510, 'Crescent City', 'Crescent City', 'CEC,Crescent Lakanbalen,Kresent Siti,Kresent-Siti,Kresunt Siti,ke lei sen te cheng,keulesenteusiti,kres''senta siti,krs snt syty  kalyfrnya,krysynt syty,kuresentoshiti,Кресент Сити,Кресент-Сити,Кресънт Сити,كريسينت سيتي,کرس سنت سیتی، کالیفرنیا,کریسنٹ سٹی، کیلیفورنیا,क्रेस्सेन्ट सिटी,クレセントシティ,克雷森特城,크레센트시티', 41.7559500, -124.2017500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145511, 'Cutten', 'Cutten', '', 40.7698500, -124.1428400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145512, 'Dunsmuir', 'Dunsmuir', 'Dansmjur,Dunsmjuur,Dunsmuir,Pusher,dansmira,dansmwyr  kalyfrnya,deng si mou er,dwnsmwyr,Дансмјур,Дънсмюър,دانسمویر، کالیفرنیا,دونسموير,डन्स्मिर,鄧斯繆爾', 41.2082100, -122.2719500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145513, 'Eureka', 'Eureka', 'EKA,Ehvrika,Eurika,Jurika,awrka  kalyfrnya,awryka,you li ka,yulika,yureka,Јурика,Еуріка,Эврика,Юрика,إوريكا,اورکا، کالیفرنیا,युरेका,ユーレカ,尤里卡,유리카', 40.8020700, -124.1636700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145514, 'Ferndale', 'Ferndale', 'Cream City,Ferndale,Ferndejl,Furndejl,Little Denmark,fen dai er,frndyl  kalyfrnya,fyrndaly,peondeil,pharnadela,Ферндејл,Фърндейл,فرندیل، کالیفرنیا,فيرندالي,फर्नडेल,芬代尔,펀데일', 40.5762400, -124.2639400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145515, 'Fortuna', 'Fortuna', 'Fortjuna,Fortuna,Fortune,Friendly City,Slide,Springville,fartwna  kyly fwrnya,fochuna,fu tu na,fwrtwna,fwrtwna  kalyfrnya,pharcyuna,Фортуна,Фортјуна,فارتونا، کیلی فورنیا,فورتونا,فورتونا، کالیفرنیا,फर्च्युना,フォーチュナ,福图纳', 40.5981900, -124.1572800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145516, 'Gerber', 'Gerber', '', 40.0562700, -122.1502700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145517, 'Greenville', 'Greenville', 'Grinvill,Гринвилл', 40.1396100, -120.9510700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145518, 'Happy Camp', 'Happy Camp', 'Happy Camp,Murderer''s Bar', 41.7927500, -123.3808000, 'US', '2015-02-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145519, 'Hayfork', 'Hayfork', 'Hay Fork,Hay Town,Hayfork,Kingsberry', 40.5543100, -123.1830800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145520, 'Humboldt Hill', 'Humboldt Hill', '', 40.7259600, -124.1897800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145521, 'Hydesville', 'Hydesville', 'Goose Lake Prairie,Goose Prairie,Gooseberry,Hydesville', 40.5476300, -124.0972700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145522, 'Janesville', 'Janesville', 'Gas Point,Janesville,Lassen', 40.2965600, -120.5241100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145523, 'Johnstonville', 'Johnstonville', 'Johnstonville,Toadtown', 40.3843400, -120.5874500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145524, 'Lewiston', 'Lewiston', 'Bouis Bridge,L''juiston,Leviston,Lewiston,Lewistown,Louiston,Льюистон', 40.7073700, -122.8075200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145525, 'Los Molinos', 'Los Molinos', '', 40.0212700, -122.1002700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145526, 'McCloud', 'McCloud', '', 41.2557100, -122.1394500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145527, 'McKinleyville', 'McKinleyville', 'Dows,McKinleyville,Minorsville,Minorville', 40.9465200, -124.1006200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145528, 'Montague', 'Montague', 'Montagju,Montugju,SIY,meng tai gu,montaga,mwntaghwy,mwntagw  kalyfrnya,Монтагју,Монтъгю,مونتاغوي,مونتاگو، کالیفرنیا,मोन्टाग,蒙太古', 41.7282000, -122.5278000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145529, 'Mount Shasta', 'Mount Shasta', 'Berryvale,MHS,Maunt Shasta,Mount Shasta,Mount Shasta City,Mt Shasta City,Mt. Shasta City,Sisson,Strawberry Valley,ma''unta sasta,mang te sha si ta,maunteusyaseuta,mwnt shasta  kalyfrnya,mwwnt shasta,Маунт Шаста,مونت شاستا، کالیفرنیا,موونت شاستا,माउन्ट शास्ता,芒特沙斯塔,마운트샤스타', 41.3102400, -122.3122500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145530, 'Myrtletown', 'Myrtletown', '', 40.7887400, -124.1303400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145531, 'Palo Cedro', 'Palo Cedro', 'Palo Cedro,Palocedro', 40.5637600, -122.2388900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145532, 'Pine Hills', 'Pine Hills', '', 40.7331800, -124.1522800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145533, 'Red Bluff', 'Red Bluff', 'Covertsburg,Leodocia,RBL,Red Blaf,Red Bluf,Red Bluff,Red Bluffs,Redbluff,lei de bu la fu,rd blaf  kalyfrnya,reda blapha,reddoburafu,ryd blwf,Ред Блаф,Ред Блъф,رد بلاف، کالیفرنیا,ريد بلوف,रेड ब्लफ,レッドブラフ,雷德布拉夫', 40.1784900, -122.2358300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145534, 'Redding', 'Redding', 'Latona,RDD,Reading,Redding,Reding,leding,lei ding,rdyng  kalyfrnya,rdyngh,redinga,redingu,Реддинг,Рединг,ردينغ,ردینگ، کالیفرنیا,ریڈنگ،امریکہ,रेडिंग,レディング,雷丁,레딩', 40.5865400, -122.3916800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145535, 'Redway', 'Redway', '', 40.1201400, -123.8233600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145536, 'Rio Dell', 'Rio Dell', 'Eagle Prairie,Rio Del,Rio Dell,Río Dell,li ta dai er,riyo dela,ryw aydl  kalyfrnya,ryw dyl,Рио Дел,ريو ديل,ریو آیدل، کالیفرنیا,रियो डेल,力拓戴尔', 40.4993000, -124.1064400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145537, 'Shasta', 'Shasta', 'Diggins,Reading Spring,Reading''s Diggings,Reading''s Springs,Readings Springs,Shasta,Shasta City', 40.5993200, -122.4919600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145538, 'Shasta Lake', 'Shasta Lake', 'Central Valley,City of Shasta Lake,Lake Shasta,Project City,Sashta Lake,Shasta Lake City,Shasta Lejk,Summit City,sasta leka,sha si ta hu,shasta laky,shasta lyk  kalyfrnya,Шаста Лейк,Шаста Лејк,شاستا لاكي,شاستا لیک، کالیفرنیا,शास्ता लेक,沙斯塔湖', 40.6804300, -122.3708400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145539, 'Shingletown', 'Shingletown', 'Shingle Camp,Shingletown', 40.4923800, -121.8891600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145540, 'Susanville', 'Susanville', 'Rooptown,SVE,Sjuzunvil,Susanville,Suzanvil,su shan wei er,sujyanabhila,suzanbiru,swsanfyly,swzan wyl  kalyfrnya,Сузанвил,Сюзънвил,سوزان ویل، کالیفرنیا,سوسانفيلي,सुज्यानभिल,スーザンビル,苏珊维尔', 40.4162800, -120.6530100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145541, 'Weaverville', 'Weaverville', 'Vivervil,Weavertown,Weaverville,u~ibabiru,vibharabhila,wei hua wei li,Вивервил,वीभरभिल,ウィーバービル,威化韋利', 40.7309800, -122.9419700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145542, 'Weed', 'Weed', 'Uid,Uijd,Vid,u~ido,vida,wei de,wyd,wyd  kalyfrnya,Вид,Уид,Уийд,ويد,وید، کالیفرنیا,वीड,ウィード,威德', 41.4226500, -122.3861300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145543, 'Westwood', 'Westwood', 'Vestvud,vestavuda,Вествуд,ویسٹووڈ، کیلیفورنیا,वेस्टवूड', 40.3060000, -121.0057900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145544, 'Willow Creek', 'Willow Creek', 'China Flat,Willow Creek', 40.9395800, -123.6314400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145545, 'Yreka', 'Yreka', 'RKC,Shasta Butte City,Thompson Dry Diggings,Thompson''s Dry Diggings,Uajrika,Vajrika,Wyreka,Yreka,Yreka City,huai li ka,wairika,wayryka  kalyfrnya,yreka,yryka,yryka  kyly fwrnya,Вајрика,Уайрика,وایریکا، کالیفرنیا,يريكا,یریکا، کیلی فورنیا,य्रेका,ワイリーカ,怀里卡', 41.7354200, -122.6344700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145546, 'Akron', 'Akron', 'AKO,Akron,Akrun,a ke lun,akran  klradw,akrwn,ekrona,Акрон,Акрън,أكرون,اکران، کلرادو,اکرون، کولوراڈو,एक्रोन,阿克伦', 40.1605400, -103.2143800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145547, 'Aristocrat Ranchettes', 'Aristocrat Ranchettes', '', 40.1091500, -104.7624700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145548, 'Ault', 'Ault', '', 40.5824800, -104.7319100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145549, 'Berthoud', 'Berthoud', '', 40.3083200, -105.0810900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145550, 'Boulder', 'Boulder', 'Bolder,Boulder,Bouldur,WBU,ba''uldara,bo de,boldara,bolde xr,boldeo,boruda,bwldr,bwldr  klradw,Болдер,Боулдер,Боулдър,בולדר,بولدر,بولدر، کلرادو,بولڈر، کولوراڈو,बाउल्डर,बोल्डर,โบลเดอร์,ボルダー,波德,볼더', 40.0149900, -105.2705500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145551, 'Brush', 'Brush', 'Beaver Creek,Brash,Brush,brasa,brash  klradw,brwsh,bu la shen,Браш,Бруш,Бръш,براش، کلرادو,بروش,ब्रश,布拉什', 40.2588700, -103.6238400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145552, 'Campion', 'Campion', '', 40.3494300, -105.0777600, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145553, 'Craig', 'Craig', 'CIG,Krehjg,Krejg,ke lei ge,krega,kryg  klradw,krygh,Крейг,Крејг,Крэйг,كريغ,کریگ، کلرادو,کریگ، کولوراڈو,क्रेग,克雷格', 40.5152500, -107.5464500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145554, 'Dacono', 'Dacono', '', 40.0847100, -104.9394200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145555, 'Eaton', 'Eaton', 'Eaton,Eatonton', 40.5302600, -104.7113500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145556, 'Erie', 'Erie', 'Ehri,Eri,Iri,ary,ary  klradw,eri,yi li,Ери,Ири,Эри,إري,اری، کلرادو,ایری، کولوراڈو,एरी,伊利', 40.0502600, -105.0499800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145557, 'Estes Park', 'Estes Park', 'Ehstes Park,Estes Park,Estes Park Village,Estiz Park,Estus Park,ai si te si gong yuan,astys bark,astz park  klradw,esteja parka,Естиз Парк,Естъс Парк,Эстес Парк,إستيس بارك,استز پارک، کلرادو,एस्टेज पार्क,埃斯特斯公园', 40.3772100, -105.5216700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145558, 'Evans', 'Evans', 'Ehvans,Evans,Ivans,ai wen si,awans  klradw,ayfanz,ibhansa,Еванс,Иванс,Эванс,إيفانز,اوانس، کلرادو,ایونز، کولوراڈو,इभान्स,埃文斯', 40.3763700, -104.6921900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145559, 'Firestone', 'Firestone', '', 40.1124800, -104.9366400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145560, 'Fort Collins', 'Fort Collins', 'Camp Collins,FNL,Fort Collins,Fort Kolins,Fort Kolinsas,Fort Kollins,Fort-Kollins,Ft. Collins,fwrt kalynz  klradw,fwrt kwlnz,ke lin si bao,pharta kolinsa,phorta kolinsa,poteukollinseu,pwrt qwlyns,Форт Колинс,Форт Коллинс,Форт-Коллинс,Форт-Коллінс,פורט קולינס,فورت كولنز,فورت کالینز، کلرادو,فورٹ کولنز، کولوراڈو,फर्ट कोलिन्स,फोर्ट कॉलिन्स,フォート・コリンズ,科林斯堡,포트콜린스', 40.5852600, -105.0844200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145561, 'Fort Lupton', 'Fort Lupton', '', 40.0847100, -104.8130300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145562, 'Fort Morgan', 'Fort Morgan', 'Camp Tyler,Fort Morgan,Fort Wardwell,fwrt mwrgan  klradw,mo gen bao,pharta morgana,phorta morgana,Форт Морган,فورت مورگان، کلرادو,فورٹ مورگن، کولوراڈو,फर्ट मोर्गन,फोर्ट मॉर्गन,摩根堡', 40.2502600, -103.7999500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145563, 'Frederick', 'Frederick', 'Frederik,frdryk  klradw,frydryk,fu lei de li ke,phrederika,Фредерик,فردریک، کلرادو,فريدريك,فریڈرک، کولوراڈو,फ्रेडेरिक,弗雷德里克', 40.0991500, -104.9372000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145564, 'Gilcrest', 'Gilcrest', 'Gilcrest,Nantes', 40.2819300, -104.7777500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145565, 'Granby', 'Granby', 'Granbi,Grehnbi,Grenbi,ge lan bi,ghranby,grnby  klradw,gryanaba''i,guranbi,Гранби,Гренби,Грэнби,غرانبي,گرنبی، کلرادو,ग्र्यानबाइ,グランビー,格兰比', 40.0861000, -105.9394600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145566, 'Greeley', 'Greeley', 'GXY,Greeley,Greely,Grijli,Grili,ge li li,ghryly,grili,gryly,gryly  klradw,guriri,Грийли,Грили,גרילי,غريلي,گریلی، کلرادو,گریلی، کولوراڈو,ग्रीली,グリーリー,格里利', 40.4233100, -104.7091300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145567, 'Hayden', 'Hayden', 'HDN,Khehjden,Khejden,Khejdun,hai deng,haydn,haydn  klradw,hedana,Хейдън,Хејден,Хэйден,هايدن,هایدن، کلرادو,हेडन,海登', 40.4952900, -107.2572900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145568, 'Holyoke', 'Holyoke', 'Kholiok,Kholiouk,Kholjok,holiyoka,huo li ao ke,hwlywk,hwlywk  klradw,Холиок,Холиоук,Холјок,هوليوك,هولیوک، کلرادو,होलीयोक,霍利奧克', 40.5844400, -102.3024100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145569, 'Hot Sulphur Springs', 'Hot Sulphur Springs', '', 40.0730400, -106.1028000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145570, 'Hudson', 'Hudson', 'Gudzon,Гудзон', 40.0735900, -104.6430200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145571, 'Johnstown', 'Johnstown', 'Dzhonstaun,Dzhonstoun,Dzonstaun,jonsata''una,jwnstawn,jwnztawn  klradw,yue han si dui,Џонстаун,Джонстаун,Джонстоун,جونزتاون، کلرادو,جونستاون,जोन्सटाउन,约翰斯敦', 40.3369300, -104.9122000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145572, 'Julesburg', 'Julesburg', 'Dzhulsburg,Dzulsberg,Jul''sburg,julsabarga,jwlysbwrgh,khwlysbwrg  klradw,zhu er si bao,Џулсберг,Джулсбърг,Юльсбург,جوليسبورغ,خولیسبورگ، کلرادو,जुल्सबर्ग,朱尔斯堡', 40.9883300, -102.2643500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145573, 'Keenesburg', 'Keenesburg', 'Keene,Keenesburg', 40.1083200, -104.5199600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145574, 'Kersey', 'Kersey', 'Kersey,Orr', 40.3874800, -104.5616300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145575, 'Kremmling', 'Kremmling', 'Kinsey City,Kremling,Kremmling,ke lei mu ling,kremalinga,krmlyng  klradw,krmlyngh,Кремлинг,كرملينغ,کرملینگ، کلرادو,क्रेमलिङ्ग,克雷姆灵', 40.0588700, -106.3889200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145576, 'La Salle', 'La Salle', 'La Salle,LaSalle', 40.3488700, -104.7019100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145577, 'Laporte', 'Laporte', 'Colona,La Porte,Laporte', 40.6263300, -105.1391600, 'US', '2015-08-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145578, 'Lochbuie', 'Lochbuie', '', 40.0072100, -104.7160800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145579, 'Longmont', 'Longmont', 'Longmont,Longmott,Longmunt,lang meng te,langamonta,langmant  klradw,longmeonteu,lwnghmwnt,rongumonto,Лонгмонт,Лонгмотт,Лонгмънт,لانگمانت، کلرادو,لونغمونت,لونگمونٹ، کولوراڈو,लङ्गमोन्ट,ロングモント,朗蒙特,롱먼트', 40.1672100, -105.1019300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145580, 'Loveland', 'Loveland', 'FNL,Lavland,Lovland,Luvlend,la fu lan,labhalyanda,lawlnd  klradw,leobeulaendeu,lwfland,Лавланд,Ловланд,Лъвленд,لاولند، کلرادو,لوفلاند,لولینڈ، کولوراڈو,लभल्यान्ड,拉夫兰,러브랜드', 40.3977600, -105.0749800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145581, 'Lyons', 'Lyons', 'Lajons,Lajuns,Lions,li ang,liyonja,lywns  klradw,lywnz,Лайънс,Лајонс,Лионс,ليونز,لیونس، کلرادو,लीयोंज,里昂', 40.2247100, -105.2713800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145582, 'Mead', 'Mead', '', 40.2333200, -104.9985900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145583, 'Meeker', 'Meeker', 'Mijkur,Miker,mi ke,mikara,mykr,mykr  klradw,Мийкър,Микер,ميكر,میکر، کلرادو,मीकर,米克', 40.0374700, -107.9131300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145584, 'Milliken', 'Milliken', '', 40.3294300, -104.8552500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145585, 'Niwot', 'Niwot', 'Modoc,Niwot', 40.1038700, -105.1708200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145586, 'Platteville', 'Platteville', 'Plattevil,Platvil,Plejtvil,blatfyl,pletbhila,plytwyl  klradw,pu la te wei er,Платвил,Платтевил,Плейтвил,بلاتفيل,پلیتویل، کلرادو,پلیٹویل، کولوراڈو,प्लेट्भिल,普拉特维尔', 40.2149800, -104.8227500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145587, 'Rangely', 'Rangely', 'RNG,Rangeley,Rangely', 40.0874800, -108.8048300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145588, 'Severance', 'Severance', '', 40.5241500, -104.8510800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145589, 'Steamboat Springs', 'Steamboat Springs', 'SBS,Stijmbout Springs,Stimbot Springs,astymbt aspryngz  klradw,si ting bo te si pu lin si,stimabota springas,stymbwt sbrynghz,Стиймбоут Спрингс,Стимбот Спрингс,استیمبت اسپرینگز، کلرادو,ستيمبوت سبرينغز,سٹیمبوٹ سپرنگز، کولوراڈو,स्टिमबोट स्प्रिङ्गस्,斯廷博特斯普林斯', 40.4849800, -106.8317200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145590, 'Sterling', 'Sterling', 'Sterling,Sturling,astrlyng  klradw,si te lin,staralinga,starlinga,strlyngh,Стерлинг,Стърлинг,استرلینگ، کلرادو,سترلينغ,سٹرلنگ، کولوراڈو,स्टरलिङ्ग,स्टर्लिंग,斯特林', 40.6255400, -103.2077100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145591, 'Walden', 'Walden', 'Sagebrush,Uolden,Volden,Walden,valadena,wa er deng,waldn,waldn  klradw,Волден,Уолден,والدن,والدن، کلرادو,वालडेन,瓦尔登', 40.7316400, -106.2836400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145592, 'Wellington', 'Wellington', 'Uelingtun,Velington,Vellington,hui ling dun,velalingatana,wlynghtwn,wlyngtwn  klradw,Велингтон,Веллингтон,Уелингтън,ولينغتون,ولینگتون، کلرادو,वेललिङ्गटन,惠灵顿', 40.7038700, -105.0085900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145593, 'Windsor', 'Windsor', 'New Liberty,New Windsor,Uindzur,Vindzor,Windsor,vindara,wen sha,wndswr,wyndswr  klradw,Виндзор,Уиндзър,وندسور,ونڈسر، کولوراڈو,ویندسور، کلرادو,विन्डर,温莎', 40.4774800, -104.9013600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145594, 'Yuma', 'Yuma', 'Juma,you ma,yuma,ywma,ywma  klradw,Јума,Юма,يوما,یوما، کلرادو,یوما، کولوراڈو,युमा,尤馬', 40.1222100, -102.7252100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145595, 'Aberdeen', 'Aberdeen', 'Aberdin,Aburdijn,a bo ding,aberdini,abrdyn  aydahw,abyrdyn,aebeodin,ebardina,Абердин,Абърдийн,آبردین، آیداهو,أبيردين,एबर्डीन,აბერდინი,阿伯丁,애버딘', 42.9440800, -112.8383300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145596, 'American Falls', 'American Falls', 'Amerikan Fols,amelikanpolseu,amerikana phalsa,amrykn falz  aydahw,amyrykan fwls,Американ Фолс,أميريكان فولس,امریکن فالز، آیداهو,अमेरिकन फल्स,ამერიკან-ფოლსი,아메리칸폴스', 42.7860200, -112.8544400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145597, 'Ammon', 'Ammon', 'Ammon,Amon,Amun,amoni,amwn,amwn  aydahw,emona,Аммон,Амон,Амън,آمون، آیداهو,آمون، ایڈاہو,أمون,एमोन,ამონი', 43.4696400, -111.9666400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145598, 'Arco', 'Arco', 'Arko,Arkou,arko,arkw,arkw  aydahw,aruko,Арко,Аркоу,آرکو، آیداهو,أركو,आर्को,არკო,アルコ', 43.6365700, -113.3002800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145599, 'Ashton', 'Ashton', 'Ashtun,Ehshton,Eshton,ashtwn,ashtwn  aydahw,estana,Аштън,Ештон,Эштон,آشتون، آیداهو,أشتون,एश्टन,აშტონი', 44.0715800, -111.4482900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145600, 'Bellevue', 'Bellevue', 'Behllevju,Belevi,Bellevue,Belvju,Biddyville,belebhyu,belviu,blwyw  aydahw,bylyfw,Белвю,Белвју,Белеви,Бэллевю,بلویو، آیداهو,بيليفو,बेलेभ्यु,ბელვიუ', 43.4635200, -114.2606000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145601, 'Blackfoot', 'Blackfoot', 'Blakfut,Blehkfut,Blekfut,blakfwt,blyakaphuta,burakkufutto,Блакфут,Блекфут,Блэкфут,بلاكفوت,بلک‌فوت، آیداهو,بلیکفٹ، ایڈاہو,ब्ल्याकफूट,ბლეკფუტი,ブラックフット', 43.1904700, -112.3449800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145602, 'Boise', 'Boise', 'BOI,Boise,Boise City,Boisisitija,Boisė,Boizi,Boizis,Bojse,Bojsi,Bojzi,Boyse,Gorad Bojseh,baysi,bo yi xi,bo''ija,bo''ijhi,bo''isi,boise,boishi,boisi,bwysy,bwyz,bwyzy  aydahw,poyci,Μπόιζι,Бойзи,Бойсе,Бојси,Горад Бойсэ,Բոյսե,בויסי,بوئسے,بويسي,بویز,بویزی، آیداهو,बाय्सी,बॉइझी,बोइज,बोइसी,பொய்சி,ಬಾಯ್ಸಿ,ბოისე,ボイシ,博伊西,보이시', 43.6135000, -116.2034500, 'US', '2010-01-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145603, 'Bonners Ferry', 'Bonners Ferry', 'Boners Feri,Bonnehrs Fehrri,Bonners-Ferri,Bonurs Feri,bonarsa pheri,boners-peri,bwnrz fry  aydahw,bwnyrs fyry,Бонерс Фери,Боннерс-Ферри,Боннерс-Феррі,Боннэрс Фэрри,Бонърс Фери,بونرز فری، آیداهو,بونيرس فيري,बोनर्स फेरी,ბონერს-ფერი', 48.6913300, -116.3163100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145604, 'Buhl', 'Buhl', 'Bjul,Bukhl,Bul,buhla,buli,bwhl,bwhl  aydahw,Бул,Бухл,Бюл,بوهل,بوهل، آیداهو,बुह्ल,ბული', 42.5990700, -114.7594900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145605, 'Burley', 'Burley', 'BYI,Berli,Burlehj,Burley,Burli,Commerce,barli,brgly  aydahw,bwrly,Берли,Бурлэй,Бърли,برلی، ایڈاہو,برگلی، آیداهو,بورلي,बर्ली,ბარლი', 42.5357400, -113.7927900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145606, 'Caldwell', 'Caldwell', 'Caldwell,Hamburg Siding,Kolduehll,Kolduel,Koldvel,kaldavela,kaldwl,kaldwyl,koldeuwel,korudou~eru,qwldwwl,Колдвел,Колдуел,Колдуэлл,קולדוול,كالدويل,کالدول,کالڈویل، ایڈاہو,काल्डवेल,კოლდუელი,コールドウェル,콜드웰', 43.6629400, -116.6873600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145607, 'Cascade', 'Cascade', 'ICS,Kaskehjd,Kaskejd,kaskyd,kskyd  aydahw,kyaskeda,Каскейд,Каскејд,Каскэйд,كاسكيد,کسکید، آیداهو,क्यास्केड,კასკადი', 44.5162800, -116.0418000, 'US', '2017-07-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145608, 'Challis', 'Challis', 'CHL,Chalis,Challis,Cholis,Garden City,chalisi,chalys  aydahw,cyalisa,shalys,Чалис,Чолис,شاليس,چالیس، آیداهو,च्यालिस,ჩალისი', 44.5046400, -114.2317300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145609, 'Chubbuck', 'Chubbuck', 'Chabbak,Chabuk,Chubbock,Chubbuck,Chubuk,chabak  aydahw,cubbaka,tshwbwk,Чаббак,Чабук,Чъбък,تشوبوك,چاباک، آیداهو,چوبیک، ایڈاہو,चुब्बक,ჩაბაკი', 42.9207500, -112.4660900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145610, 'Coeur d''Alene', 'Coeur d''Alene', 'COE,Coeur d''Alene,Coeur d’Alene,Kjor-d''Alen,Kor Dulejn,kar d lyn  aydahw,kwywr dy alyny  aydahw,Кор Дълейн,Кёр-д’Ален,كويور دي أليني، أيداهو,کار د لین، آیداهو,კორ-დ’ალენი,コー・ダリーン', 47.6776800, -116.7804700, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145611, 'Council', 'Council', 'Kaunsil,Kaunsul,Kounsl,ka''unsila,kansyl  aydahw,kwnsyl,Каунсил,Каунсъл,Каунсіл,Коунсл,كونسيل,کانسیل، آیداهو,काउन्सिल,კაუნსილი', 44.7298900, -116.4382000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145612, 'Dalton Gardens', 'Dalton Gardens', '', 47.7296300, -116.7701900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145613, 'Driggs', 'Driggs', 'Driggs,Drigs,drigsa,drigsi,dryghs,drygz  aydahw,Дриггс,Дригс,دريغس,دریگز، آیداهو,ड्रिग्स,დრიგსი', 43.7232500, -111.1113300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145614, 'Dubois', 'Dubois', 'Djuboa,Dubois,Dubojs,diubua,dubo''i,dwbwys,dwbwys  aydahw,Дубоис,Дубојс,Дюбоа,دوبويس,دوبویس، آیداهو,डुबोइ,დიუბუა', 44.1763000, -112.2308200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145615, 'Eagle', 'Eagle', 'Igl,Igul,ayghyl,aygl  aydahw,igala,igli,Ігл,Игл,Игъл,إيغيل,ایگل، آیداهو,ایگل، ایڈاہو,इगल,იგლი', 43.6954400, -116.3540100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145616, 'Emmett', 'Emmett', 'Ehmett,Emet,aymt  aydahw,aymyt,im''meta,Емет,Эметт,إيميت,ایمت، آیداهو,इम्मेट,ემეტი', 43.8735000, -116.4993000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145617, 'Fairfield', 'Fairfield', 'Fairfield,Fajrfild,Ferfild,Feurfijld,Feurfild,New Soldier,fyrfyld,fyrfyld  aydahw,pairpildi,pheyaraphilda,Файрфилд,Ферфилд,Феърфийлд,Феърфилд,فيرفيلد,فیئرفیلڈ، آیڈاہو,فیرفیلد، آیداهو,फेयरफिल्ड,ფაირფილდი', 43.3465700, -114.7917300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145618, 'Filer', 'Filer', 'Fajler,Filehr,Filur,faylr  aydahw,fylyr,pha''ilara,pileri,Фајлер,Филър,Филэр,فایلر، آیداهو,فيلير,फाइलर,ფილერი', 42.5701900, -114.6078200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145619, 'Fort Hall', 'Fort Hall', '', 43.0332500, -112.4383100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145620, 'Fruitland', 'Fruitland', 'Fruitland,Frutland,frwtland,frwtlnd  aydahw,phrutalyanda,Фруитланд,Фрутланд,فروتلاند,فروتلند، آیداهو,फ्रुटल्यान्ड,ფრუტლენდი', 44.0076600, -116.9165500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145621, 'Garden City', 'Garden City', 'Garden Siti,Garden-Siti,Gardun Siti,gardena siti,gardn syty  aydahw,ghardn syty,Гарден Сити,Гарден-Сити,Гарден-Сіті,Гардън Сити,غاردن سيتي,گاردن سیتی، آیداهو,گارڈن سٹی، ایڈاہو,गार्डेन सिटी,გარდენ-სიტი', 43.6221100, -116.2381700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145622, 'Glenns Ferry', 'Glenns Ferry', 'Glehnns Fehrri,Glenn''s Ferry,Glenns Ferry,Glens Feri,ghlyns fyry,glenas pheri,glens-peri,glnz fry  aydahw,Гленс Фери,Глэннс Фэрри,غلينس فيري,گلنز فری، آیداهو,ग्लेनस् फेरी,გლენს-ფერი', 42.9549000, -115.3009000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145623, 'Gooding', 'Gooding', 'GNG,Gooding,Guding,Toponis,ghwdyngh,gudinga,gudingi,gwdyng  aydahw,Гудинг,غودينغ,گودینگ، آیداهو,गूडिंग,გუდინგი', 42.9387900, -114.7131100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145624, 'Grangeville', 'Grangeville', 'IDH', 45.9265500, -116.1223700, 'US', '2017-06-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145625, 'Hailey', 'Hailey', 'Khajlehj,Khejli,SUN,hayly,hayly  aydahw,he''ili,heili,Хайлэй,Хейли,Хејли,هايلي,هایلی، آیداهو,हेइली,ჰეილი', 43.5196300, -114.3153200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145626, 'Hansen', 'Hansen', '', 42.5306800, -114.3010100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145627, 'Hayden', 'Hayden', 'Khejden,Khejdun,haydn,haydn  aydahw,hedana,heideni,Хейден,Хейдън,Хејден,هايدن,هایدن، آیداهو,ہیڈن، ایڈاہو,हेडन,ჰეიდენი', 47.7660200, -116.7865800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145628, 'Heyburn', 'Heyburn', 'Khehjburn,Khejbern,Khejburn,hebarna,heibarni,hybrn  aydahw,hybwrn,Хейбърн,Хејберн,Хэйбурн,هيبورن,هیبرن، آیداهو,हेबर्न,ჰეიბარნი', 42.5585200, -113.7639000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145629, 'Homedale', 'Homedale', 'Khomdejl,Khoumdehjl,Khoumdejl,homadela,houmdeili,hwmdal,hwmdyl  aydahw,Хомдејл,Хоумдейл,Хоумдэйл,هومدال,هومدیل، آیداهو,होमडेल,ჰოუმდეილი', 43.6176600, -116.9337600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145630, 'Idaho City', 'Idaho City', 'Ajdakho Siti,a''id''aho siti,aydahw syty,aydahw syty  aydahw,Айдахо Сити,Ајдахо Сити,آیداهو سیتی، آیداهو,أيداهو سيتي,आइडाहो सिटी,აიდაჰო-სიტი', 43.8285000, -115.8345500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145631, 'Idaho Falls', 'Idaho Falls', 'Ajdago-Folls,Ajdakho Fols,Ajdakho-Fols,IDA,a''id''aho phalsa,ai da he fu er si,aidaho-polsi,aidahoforuzu,aydahw falz  aydahw,aydahw fwlz,Айдаго-Фоллс,Айдахо Фолс,Айдахо-Фолс,Ајдахо Фолс,آیداهو فالز، آیداهو,أيداهو فولز,ایڈاہو فالز، ایڈاہو,आइडाहो फल्स,აიდაჰო-ფოლსი,アイダホフォールズ,爱达荷福尔斯', 43.4665800, -112.0341400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145632, 'Iona', 'Iona', 'Ajona,Ijona,Iona,aiona,ayona,aywna,ywna  aydahw,Айона,Ајона,Иона,Ијона,أيونا,یونا، آیداهو,आयोना,აიონა', 43.5263000, -111.9330200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145633, 'Jerome', 'Jerome', 'Dzerom,Dzherom,Dzherum,jeroma,jeromi,jrwm  aydahw,jyrwm,Џером,Джером,Джеръм,جروم، آیداهو,جيروم,جیروم، ایڈاہو,जेरोम,ჯერომი', 42.7240700, -114.5186500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145634, 'Kamiah', 'Kamiah', 'Kamaja,Kamiah,Kamiaj,Kamiakh,Kamija,Kamijaj,Qamiyaqh,kamiyah,kamya  aydahw,kamyah,Камайа,Камиай,Камиах,Камия,Камијај,كامياه,کامیا، آیداهو,कामियाः,კამიაი', 46.2271200, -116.0293100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145635, 'Kellogg', 'Kellogg', 'Kehllogg,Kelog,Kelug,kelaga,klwg  aydahw,kylwgh,Келог,Келъг,Кэллогг,كيلوغ,کلوگ، آیداهو,केलग,კელოგი', 47.5382600, -116.1193300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145636, 'Ketchum', 'Ketchum', 'Gorad Ketchum,Kechum,Kehtcham,Ketchum,kcham  aydahw,kecama,kytshwm,Горад Кетчум,Кетчум,Кечум,Кечъм,Кэтчам,كيتشوم,کچام، آیداهو,केचम,კეტჩუმი', 43.6807400, -114.3636600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145637, 'Kimberly', 'Kimberly', '', 42.5338000, -114.3647600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145638, 'Kuna', 'Kuna', 'Kjuna,Kuna,kuna,kwna,kwna  aydahw,Куна,Кюна,Кјуна,كونا,کونا، آیداهو,کونا، ایڈاہو,कुना,კუნა', 43.4918300, -116.4201200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145639, 'Lapwai', 'Lapwai', '', 46.4048900, -116.8048700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145640, 'Lewiston', 'Lewiston', 'L''juiston,LWS,Leviston,Lewiston,Luiston,Luistun,Stqhweyiyep,liu yi si dun,livisatana,lwystwn,lwystwn  aydahw,ruisuton,Левистон,Луистон,Луистън,Льюистон,لويستون,لویستون، آیداهو,لیوئسٹں، ایڈاہو,लिविसटन,ლიუისტონი,ルイストン,刘易斯顿', 46.4165500, -117.0176600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145641, 'Lewiston Orchards', 'Lewiston Orchards', '', 46.3804400, -116.9754300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145642, 'Lincoln', 'Lincoln', '', 43.5129700, -111.9644100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145643, 'Malad City', 'Malad City', 'MLD,Malad,Malad City,Malad Siti,Malade,Malade City,malad kanty  aydahw,malad syty  aydahw,Малад Сити,مالاد سيتي، أيداهو,مالاد کانتی، آیداهو,მალად-სიტი', 42.1915900, -112.2508000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145644, 'Marsing', 'Marsing', 'Butte,Claytonia,Erb,Marsing', 43.5454400, -116.8132000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145645, 'McCall', 'McCall', 'Lakeport,MYL,MakKol,Makkol,Makol,McCall,makal,mika kala,МакКол,Маккол,Макол,ماكال,مک‌کال، آیداهو,मिक कल,მაკკოლი', 44.9110100, -116.0987400, 'US', '2017-05-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145646, 'Meridian', 'Meridian', 'Meridian,Meridijan,Muridiun,meridian,meridiani,meridiyana,mrydyan  aydahw,myrydyan,Меридиан,Меридијан,Меридіан,Мъридиън,مریدیان، آیداهو,ميريديان,میریڈیئن، ایڈاہو,मेरिडियन,მერიდიანი,メリディアン', 43.6121100, -116.3915100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145647, 'Middleton', 'Middleton', '', 43.7068300, -116.6201400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145648, 'Montpelier', 'Montpelier', 'Monpelie,Montpelehjr,Montpilijer,montapeliyara,mwntbylyr,mwntplyr  aydahw,Монпелие,Монтпелэйр,Монтпилијер,مونتبيلير,مونتپلیر، آیداهو,مونٹپیلیئر، ایڈاہو,मोन्टपेलियर,მონპელიე', 42.3221500, -111.2977000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145649, 'Moreland', 'Moreland', 'Keever,Moreland', 43.2226900, -112.4424800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145650, 'Moscow', 'Moscow', 'Hog Heaven,Moscow,Moskou,Moskov,Moskva,Paradise Valley,S''maqw''l,masko,moseuko,mosuko,mskw  aydahw,mwskw,Москва,Москов,Москоу,ماسکو، ایڈاہو,مسکو، آیداهو,موسكو,मस्को,მოსკოვი,モスコー,모스코', 46.7323900, -117.0001700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145651, 'Mountain Home', 'Mountain Home', 'MUO,Mountain Home,Tuttville', 43.1329500, -115.6912000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145652, 'Murphy', 'Murphy', '', 43.2182200, -116.5523400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145653, 'Nampa', 'Nampa', 'Nampa,New Jerusalem,namba,nampa,nampa  aydahw,nan pa,nanpa,Нампа,نامبا,نامپا، آیداهو,نامپا، ایڈاہو,नाम्पा,ნამპა,ナンパ,楠帕', 43.5407200, -116.5634600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145654, 'New Plymouth', 'New Plymouth', 'N''ju Plajmaus,N''ju-Plimut,Nju Plimut,n''yu plimath,nyw blaymwth,nyw playmwth  aydahw,Њу Плимут,Нью Плаймаус,Нью-Плимут,Нью-Плімут,Ню Плимът,نيو بلايموث,نیو پلایموث، آیداهو,न्यु प्लिमथ्,ნიუ-პლიმუთი', 43.9698900, -116.8190400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145655, 'Nezperce', 'Nezperce', 'Nehzpers,Nezpers,Nezpurs,nejparsa,nyzbyrs,nzprs  aydahw,Незперс,Незпърс,Нэзперс,نزپرس، آیداهو,نيزبيرس,नेज्पर्स,ნეზპერსი', 46.2348900, -116.2407000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145656, 'Orofino', 'Orofino', 'Orofino,awrwfynw,awrwfynw  aydahw,orophino,oropino,Орофино,أوروفينو,اوروفینو، آیداهو,ओरोफिनो,ოროფინო', 46.4793500, -116.2551400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145657, 'Osburn', 'Osburn', 'Georgetown,Osborne,Osburn', 47.5060400, -115.9993300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145658, 'Paris', 'Paris', 'Paris,Parizh,bars,parys  aydahw,perisa,Париж,Парис,بارس,پاریس، آیداهو,پیرس، ایڈاہو,पेरिस,პარიზი', 42.2271500, -111.4010400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145659, 'Parma', 'Parma', 'Lower Boise,Parma,Парма', 43.7851600, -116.9432100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145660, 'Paul', 'Paul', '', 42.6079600, -113.7833500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145661, 'Payette', 'Payette', 'Blossom City,Boomerang,Pajehtt,Pajet,Payette,Payettenville,Pejet,bayyt  aydahw,payt  aydahw,Пайет,Пайэтт,Пејет,باييت، أيداهو,پایت، آیداهو,პაიეტი', 44.0782200, -116.9337700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145662, 'Pinehurst', 'Pinehurst', '', 47.5388100, -116.2373900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145663, 'Plummer', 'Plummer', 'Hnt''achqn,Plamer,Plummehr,Plummer,Plumur,blwmyr,plamara,plamr  aydahw,Пламер,Плуммэр,Плъмър,بلومير,پلامر، آیداهو,प्लमर,პლამერი', 47.3351800, -116.8885100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145664, 'Pocatello', 'Pocatello', 'PIH,Pocatello,Pocatello Junction,Pokatello,Pokatelo,Poukatelou,bo ka te luo,bwkatylw,pokatelo,pokaterro,pokeotello,pwkatlw  aydahw,Покателло,Покатело,Поукателоу,بوكاتيلو,پوکاتلو، آیداهو,پوکاٹیلو، ایڈاہو,पोकातेलो,პოკატელო,ポカテッロ,波卡特洛,포커텔로', 42.8713000, -112.4455300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145665, 'Ponderay', 'Ponderay', '', 48.3054800, -116.5338000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145666, 'Post Falls', 'Post Falls', 'Marshall,Post Falls,Post Fols,Post-Folls,Post-Fols,Q''emiln,bwst fwlz,posta phalsa,pst falz  aydahw,Пост Фолс,Пост-Фоллс,Пост-Фолс,بوست فولز,پست فالز، آیداهو,پوسٹ فالز، ایڈاہو,पोस्ट फल्स,პოსტ-ფოლსი', 47.7179600, -116.9515900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145667, 'Preston', 'Preston', 'City of Preston,Prehston,Preston,Prestun,Worm Creek,brystwn  aydahw,prstwn  aydahw,Престон,Престън,Прэстон,بريستون، أيداهو,پرستون، آیداهو,პრესტონი', 42.0963100, -111.8766200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145668, 'Priest River', 'Priest River', 'Priest River,Valencia', 48.1809700, -116.9115700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145669, 'Rexburg', 'Rexburg', 'RXE,Reksberg,Reksburg,reksburgi,rksbrg  aydahw,ryksbwrgh  aydahw,Рексберг,Рексбург,Рексбърг,ريكسبورغ، أيداهو,رکسبرگ، آیداهو,რექსბურგი', 43.8260200, -111.7896900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145670, 'Rigby', 'Rigby', 'Rigbi,rigbi,rygby  aydahw,ryghby,Ригби,ريغبي,ریگبی، آیداهو,रिग्बी,რიგბი', 43.6724100, -111.9149700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145671, 'Rupert', 'Rupert', 'Rupehrt,Rupert,Rupurt,ruparta,rwbyrt,rwprt  aydahw,Руперт,Рупърт,Рупэрт,روبيرت,روپرت، آیداهو,रुपर्ट,რუპერტი', 42.6190800, -113.6772300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145672, 'Saint Anthony', 'Saint Anthony', '', 43.9663000, -111.6821800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145673, 'Saint Maries', 'Saint Maries', 'Hnch''emtsn,Saint Maries', 47.3143500, -116.5626700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145674, 'Salmon', 'Salmon', 'SMN,Salmon,Salmon City,Salmun,salmoni,salmwn  aydahw,Салмон,Салмън,سالمون، آیداهو,سالمون، أيداهو,სალმონი', 45.1757500, -113.8959000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145675, 'Sandpoint', 'Sandpoint', 'Hangtown,Q''apq''api,Sandpoint,Sandpojnt,samdapo''inta,sandbwynt,sang de bo yin te,sndpwynt  aydahw,syandapo''inta,Сандпойнт,Сандпојнт,ساندبوينت,سندپوینت، آیداهو,सँडपॉइंट,स्यान्डपोइन्ट,სანდპოინტი,桑德波因特', 48.2765900, -116.5532500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145676, 'Shelley', 'Shelley', '', 43.3813000, -112.1233100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145677, 'Shoshone', 'Shoshone', 'Bottoms,Naples,Shoshone,Shoshoni,Shoshoun,shoshouni,shwshwn,shwshwny  aydahw,sosona,Шошони,Шошоун,شوشون,شوشونی، آیداهو,शोशोन,შოშოუნი', 42.9360200, -114.4058800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145678, 'Soda Springs', 'Soda Springs', 'Soda Springs,Souda Springs,Tosoiba,swda aspryngz  aydahw,swda sbryngh  aydahw,Сода Спрингс,Соуда Спрингс,سودا اسپرینگز، آیداهو,سودا سبرينغ، أيداهو,სოდა-სპრინგსი', 42.6543700, -111.6046700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145679, 'Spirit Lake', 'Spirit Lake', '', 47.9662900, -116.8685300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145680, 'Star', 'Star', '', 43.6921100, -116.4934600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145681, 'Sugar City', 'Sugar City', '', 43.8729700, -111.7483000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145682, 'Sun Valley', 'Sun Valley', 'Gorad San-Vehli,San Vali,San Vallehj,San-Valli,Sun Vali,san wly  aydahw,san-veli,sana bhyali,sanbare,swn faly,Горад Сан-Вэлі,Сан Вали,Сан Валлэй,Сан-Валли,Сан-Валлі,Сън Вали,سان ولی، آیداهو,سون فالي,सन भ्याली,სან-ველი,サンバレー', 43.6971300, -114.3517200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145683, 'Twin Falls', 'Twin Falls', 'TWF,Tuin Fols,Tuin-Fols,Tvin Fols,te wen fu er si,tsuinforuzu,tvinaphalsa,twyn falz  aydahw,twyn fwlz,Твин Фолс,Туин Фолс,Туин-Фолс,توين فولز,توین فالز، آیداهو,ٹوئن فالز، ایڈاہو,ट्विनफल्स,ტვინ-ფოლსი,ツインフォールズ,特溫福爾斯', 42.5629700, -114.4608700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145684, 'Tyhee', 'Tyhee', '', 42.9515800, -112.4663700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145685, 'Ucon', 'Ucon', '', 43.5963000, -111.9638600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145686, 'Victor', 'Victor', 'Fox,Raymond,Victor', 43.6027000, -111.1113300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145687, 'Wallace', 'Wallace', 'Cedar Swamp,Placer Center,Uolus,Volas,Volehjs,Wallace,uolasi,valesa,walas,walas  aydahw,Волас,Волэйс,Уолъс,والاس,والاس، آیداهو,वालेस,უოლასი', 47.4740900, -115.9279400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145688, 'Weiser', 'Weiser', 'Uijzur,Vajser,Vehjser,Vizer,uizeri,ve''ijara,wysyr,wyzr  aydahw,Вайсер,Визер,Вэйсер,Уийзър,ويسير,ویزر، آیداهو,वेइजर,უიზერი', 44.2510000, -116.9693300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145689, 'Wendell', 'Wendell', '', 42.7757400, -114.7042200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145690, 'Wilder', 'Wilder', 'Wilder,Wilderia', 43.6765500, -116.9118200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145691, 'Absarokee', 'Absarokee', '', 45.5205000, -109.4429400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145692, 'Anaconda', 'Anaconda', 'Anaconda,Anaconda-Deer Lodge,Anaconda-Deer Lodge County,Anakonda,Deer Lodge County,Smelter City,a na kang da,anakonda,anakwnda,ankanda  mwntana,Анаконда,أناكوندا,انکاندا، مونتانا,ایناکونڈا، مونٹانا,アナコンダ,阿纳康达', 46.1285400, -112.9422600, 'US', '2011-03-01', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145693, 'Baker', 'Baker', 'Behjker,Bejker,Bejkur,bei ke,bykr,bykr  mwntana,Бейкър,Бејкер,Бэйкер,بيكر,بیکر، مونتانا,贝克', 46.3669500, -104.2846600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145694, 'Belgrade', 'Belgrade', 'Behlgrad,Belgrad,Belgrejd,bei er ge lai de,blgryd  mwntana,bylghrad,Белград,Белгрейд,Белгрејд,Бэлград,بلگرید، مونتانا,بيلغراد,بیلگریڈ، مونٹانا,貝爾格萊德', 45.7760400, -111.1769000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145695, 'Big Sky', 'Big Sky', '', 45.2846500, -111.3682900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145696, 'Big Timber', 'Big Timber', 'Big Timbehr,Big Timber,Big Timbur,Big-Timber,Dornix,byg tymbr  mwntana,bygh tymbr,da ting bo,Биг Тимбер,Биг Тимбър,Биг Тимбэр,Биг-Тимбер,Біг-Тімбер,بيغ تيمبر,بیگ تیمبر، مونتانا,大廷伯', 45.8349400, -109.9554600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145697, 'Bigfork', 'Bigfork', 'Big Fork,Bigfork', 48.0632900, -114.0726100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145698, 'Billings', 'Billings', 'Area metropolitana de Billings,BIL,Belinum,Billings,Billings Metropolitan Area,biringusu,Área metropolitana de Billings,Биллингс,ビリングス', 45.7832900, -108.5006900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145699, 'Boulder', 'Boulder', 'Bolder,Bouldehr,Boulder,Boulder Valley,bo er de,bwldr,bwwldr  mwntana,Болдер,Боулдер,Боулдэр,بولدر,بوولدر، مونتانا,博尔德', 46.2365900, -112.1208300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145700, 'Bozeman', 'Bozeman', 'BZN,Boseman,Bouzman,Bouzmehn,Bozeman,Bozeman Town,Bozetown,Bozmana,Bozmen,Missouri,Sweet Pea City,bo ci man shi,bozuman,bwwzmn  mwntana,bwzyman,Боземан,Бозмана,Бозмен,Боузман,Боузмэн,بوزمین، مونٹانا,بوزيمان,بووزمن، مونتانا,ボーズマン,博兹曼市', 45.6796500, -111.0385600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145701, 'Broadus', 'Broadus', 'BDX,Broadus,Brudas,brwdws,brwwds  mwntana,bu luo de si,Брудас,برودوس,بروودس، مونتانا,布罗德斯', 45.4438700, -105.4113300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145702, 'Browning', 'Browning', 'Brauning,brawnyngh,bu lang ning,Браунинг,براؤننگ، مونٹانا,براونينغ,布朗宁', 48.5569200, -113.0134200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145703, 'Butte', 'Butte', 'B''jutt,BTM,Batt-Silvehr Bou,Bjut,Bjut-Silver Bou,Bjutt,Butte,Butte City,Butte-Silver Bow,Butte-Silver Bow County,bi you te,bwt-sylwr baw  mwntana,bwty,byuto,Батт-Силвэр Боу,Бьютт,Бют,Бютт,Бјут-Силвер Боу,بوت-سیلور باو، مونتانا,بوتي,بوٹ، مونٹانا,ビュート,比尤特', 46.0038200, -112.5347400, 'US', '2011-03-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145704, 'Chester', 'Chester', 'Chehster,Chester,chstr  mwntana,qie si te,tshystr,Честер,Чэстер,تشيستر,چستر، مونتانا,چیسٹر، مونٹانا,切斯特', 48.5105400, -110.9674700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145705, 'Chinook', 'Chinook', 'Chinuk,Shinuk,qi nu ke,shynwk,shynwk  mwntana,Чинук,Шинук,شينوك,شینوک، مونتانا,奇努克', 48.5900000, -109.2312800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145706, 'Choteau', 'Choteau', 'Choteau,Chotiu,Chouteau,Four Men,Four Persons,Shoto,Shouteau,chwtaw  mwntana,tshwtya,xiao tuo,Чотиу,Шото,تشوتيا,چوتاو، مونتانا,肖托', 47.8124500, -112.1836300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145707, 'Circle', 'Circle', '', 47.4166700, -105.5922200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145708, 'Clancy', 'Clancy', 'Clancey,Clancy', 46.4652100, -111.9863800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145709, 'Clinton', 'Clinton', 'Blossberg,Clinton,Klinton,Клинтон', 46.7690900, -113.7126000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145710, 'Colstrip', 'Colstrip', 'Hooseohee,Hoóseohée,Kolstrip,ke er si te li pu,kwlstryp  mwntana,kwstryb,Колстрип,كوستريب,کولستریپ، مونتانا,科尔斯特里普', 45.8841600, -106.6236400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145711, 'Columbia Falls', 'Columbia Falls', 'Columbia,Columbia Falls,Columbus', 48.3724600, -114.1815200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145712, 'Columbus', 'Columbus', 'Columbus,Countrymans,Eagle''s Nest,Kolumbus,Sheep Dip,Stillwater,Колумбус', 45.6366100, -109.2521100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145713, 'Conrad', 'Conrad', 'Konrad,kang la de,kanrd  mwntana,kwnrad,Конрад,كونراد,کانرد، مونتانا,康拉德', 48.1702500, -111.9461300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145714, 'Crow Agency', 'Crow Agency', 'Krou Ajdzensi,Ooetaneno,krww ayjnsy  mwntana,Óoetanéno,Кроу Ајџенси,کروو ایجنسی، مونتانا', 45.6016400, -107.4611900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145715, 'Cut Bank', 'Cut Bank', 'CTB,Cut Bank,Cutbank,Kat Bank,Kat Benk,Kut Benk,ka te ban ke,katbnk  mwntana,kt bank,Кат Банк,Кат Бенк,Кът Бенк,كت بانك,کاتبنک، مونتانا,卡特班克', 48.6330400, -112.3261600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145716, 'Deer Lodge', 'Deer Lodge', 'Cottonwood,Deer Lodge,Deerlodge,Dia Lodzh,Dijr Lodzh,Dir Lodz,Idaho City,LaBarge,LaBarge City,Spanish Fork,Spanish Forks,di er luo qi,dyr laj  mwntana,dyr lwdj,Диа Лодж,Дийр Лодж,Дир Лоџ,دير لودج,دیر لاج، مونتانا,迪尔洛奇', 46.3957600, -112.7300400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145717, 'Dillon', 'Dillon', 'DLN,Dillon,Dilon,Dilun,di long,dyln  mwntana,dylwn,Диллон,Дилон,Дилън,Діллон,ديلون,دیلن، مونتانا,ڈلن، مونٹانا,迪龙', 45.2163100, -112.6375200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145718, 'East Helena', 'East Helena', 'East Helena,Easton,Prickly', 46.5896600, -111.9155500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145719, 'East Missoula', 'East Missoula', '', 46.8707600, -113.9445500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145720, 'Ekalaka', 'Ekalaka', 'Ekalaka,Puptown', 45.8888900, -104.5527300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145721, 'Eureka', 'Eureka', 'Dewey,Deweyville,Ehvrika,Eureka,Эврика', 48.8799600, -115.0535000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145722, 'Evergreen', 'Evergreen', '', 48.2257900, -114.2762400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145723, 'Forsyth', 'Forsyth', 'Forsajt,Forsis,Forsyth,Forsyth''s Landing,Forsythe,Tseskemahoevehoeno,Tšêškemâhoévehoéno,fu sai si,fwrsyth,fwrsyth  mwntana,Форсайт,Форсајт,Форсис,فورسيث,فورسیته، مونتانا,福塞斯', 46.2663800, -106.6778100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145724, 'Fort Belknap Agency', 'Fort Belknap Agency', 'Fort Belknap,Fort Belknap Agency,Fort Belknap Agency Headquarters', 48.4825000, -108.7654400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145725, 'Fort Benton', 'Fort Benton', 'Benton City,Fort Behnton,Fort Benton,Fort Bentun,ben dun bao,fotobenton,frt bntn  mwntana,fwrt bntwn,Форт Бентон,Форт Бентън,Форт Бэнтон,فرت بنتن، مونتانا,فورت بنتون,فورٹ بینٹن، مونٹانا,フォートベントン,本顿堡', 47.8183000, -110.6674400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145726, 'Four Corners', 'Four Corners', '', 45.6296500, -111.1860600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145727, 'Frenchtown', 'Frenchtown', 'French Town,Frenchtown', 47.0149200, -114.2298400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145728, 'Glasgow', 'Glasgow', 'GGW,Glazgou,ge la si ge,ghlaskw,glsgww  mwntana,Глазгоу,غلاسكو,گلسگوو، مونتانا,格拉斯哥', 48.1969600, -106.6367100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145729, 'Glendive', 'Glendive', 'GDV,Glehndajv,Glendajv,Glendiv,ge lun dai fu,ghlyndyf,glndyw  mwntana,Глендайв,Глендајв,Глэндайв,Ґлендів,غلينديف,گلندیو، مونتانا,گیلنڈائو، مونٹانا,格伦代夫', 47.1052900, -104.7124600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145730, 'Great Falls', 'Great Falls', 'Electric City,GTF,Great Falls,Grejt Fols,Grejt-Fols,Grit Fouls,da pu bu cheng,ghryt fwlz  mwntana,guretoforuzu,Грейт Фолс,Грейт-Фолс,Грејт Фолс,Грит Фоулс,غريت فولز، مونتانا,グレートフォールズ,大瀑布城', 47.5002400, -111.3008100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145731, 'Hamilton', 'Hamilton', 'Gamil''ton,Khamilton,Khamiltun,Khehmilton,hamyltwn,han mi er dun,hmltn  mwntana,Гамильтон,Хамилтон,Хамилтън,Хэмилтон,هاميلتون,هملتن، مونتانا,ہیملٹن، مونٹانا,汉密尔顿', 46.2468700, -114.1603700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145732, 'Hardin', 'Hardin', 'Hekonemahoevehoeno,Hekonemâhoevehoeno,Khardin,ha ding,hardn,Хардин,هاردن,哈丁', 45.7324800, -107.6120300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145733, 'Harlowton', 'Harlowton', 'Harlow,Harlowton,Kharlouton,Kharloutun,ha luo dun,harlwtwn,harlwwtwn,Харлоутон,Харлоутън,هارلوتون,هارلووتون,哈洛顿', 46.4355100, -109.8343500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145734, 'Havre', 'Havre', 'HVR,Khaver,Khavr,Khavur,ha fu,hafry,hwr  mwntana,Хавер,Хавр,Хавър,هافري,هور، مونتانا,ہاورے، مونٹانا,哈佛', 48.5500000, -109.6840900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145735, 'Helena', 'Helena', 'Chelena,Crabtown,Epl Yuts''mn,Epł Yuts’mn,Gelena,Gorad Khelena,HLN,Helena,Helena i Montana,Helenopolis,Helina,Hopkinsville,Khehlena,Khelena,Last Chance Gulch,he lei na,helena,hellena,herena,hlna  mwntana,hlnh,hylyna,Χέλενα,Гелена,Горад Хелена,Хелена,Хэлена,Հելենա,הלנה,هلنا، مونتانا,هيلينا,ہیلینا,ہیلینا، مونٹانا,हेलेना,ஹெலேனா,เฮเลนา,ヘレナ,赫勒拿,헬레나', 46.5927100, -112.0361100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145736, 'Hysham', 'Hysham', '', 46.2927700, -107.2342300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145737, 'Jordan', 'Jordan', 'Alibi,JDN,Jordan', 47.3208300, -106.9100700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145738, 'Kalispell', 'Kalispell', 'Alkali Flat,Calispel,Collapsetown,FCA,Kalispehll,Kalispel,Kalispell,Kalispelm,ka li si pei er,kalliseupel,kalysbyl,karisuperu,klspl  mwntana,Калиспел,Калиспелл,Калиспэлл,Каліспелл,كاليسبيل,کلسپل، مونتانا,کیلیسپیل، مونٹانا,カリスペル,卡利斯佩尔,칼리스펠', 48.1957900, -114.3129100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145739, 'Lakeside', 'Lakeside', 'Chautauqua,Lacon,Lakeside,Stoner,Stoner''s,Stoners', 48.0193900, -114.2245700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145740, 'Lame Deer', 'Lame Deer', 'Lame Deer,Lamedeer', 45.6230500, -106.6667000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145741, 'Laurel', 'Laurel', 'Laurehl,Lorel,Lorul,lao lei er,loleol,lrl  mwntana,lwryl,Лаурэл,Лорел,Лоръл,لرل، مونتانا,لورل، مونٹانا,لوريل,劳雷尔,로럴', 45.6691200, -108.7715300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145742, 'Lewistown', 'Lewistown', 'LWT,Levistaun,Lewiston,Lewistown,Luistaun,Reeds Fort,liu yi si dui,lwystawn,lwystwwn  mwntana,Левистаун,Луистаун,لويستاون,لویستوون، مونتانا,لیوس ٹاؤن، مونٹانا,刘易斯敦', 47.0624700, -109.4282400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145743, 'Libby', 'Libby', 'Libaj,Libbi,Libi,li bi,lyby,lyby  mwntana,Либай,Либби,Либи,Ліббі,ليبي,لیبی، مونتانا,利比', 48.3882900, -115.5560000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145744, 'Lincoln', 'Lincoln', 'Lincoln,Lincoln City,Lincoln Gulch City,Lincolnville,Linkol''n,Springfield City,Линкольн', 46.9549400, -112.6817100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145745, 'Livingston', 'Livingston', 'Clark,Clark City,Henry Roland''s Crossing,Island Crossing,LVM,Livingston,Livingstun,Windville,li wen si dun,lyfynghstwn,lywyngstn  mwntana,Ливингстон,Ливингстън,Лівінґстон,ليفينغستون,لیونگسٹن، مونٹانا,لیوینگستن، مونتانا,利文斯顿', 45.6624400, -110.5610400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145746, 'Lockwood', 'Lockwood', '', 45.8191200, -108.4148600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145747, 'Lolo', 'Lolo', '', 46.7588100, -114.0809400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145748, 'Malta', 'Malta', 'MLK,Mal''ta,Malta,Molta,ma er ta,malta,mlta  mwntana,Малта,Мальта,Молта,مالطا,ملتا، مونتانا,马耳他', 48.3597200, -107.8742800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145749, 'Manhattan', 'Manhattan', 'Hamilton,Manhattan,Mankhehtten,Moreland,Манхэттен', 45.8566000, -111.3324600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145750, 'Miles City', 'Miles City', 'MLS,Majls Siti,Maxemahoevehoeno,Maxemâhoévéhoeno,Miles City,Milestown,mai er si cheng,maylz syty,maylz syty  mwntana,Майлс Сити,Мајлс Сити,مائلز سٹی، مونٹانا,مايلز سيتي,مایلز سیتی، مونتانا,迈尔斯城', 46.4083400, -105.8405600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145751, 'Missoula', 'Missoula', 'Hnme''suuli,Im-i-sul-e-tiku,In-mae-soo-la,In-may-soo-let-que,MSO,Missoula,Missoula Mills,Missula,Misula,Mizula,Nemissoolatakoo,mi su la,mijulla,mizura,myswla,myzwla  mwntana,myzwlh,Мизула,Миссоула,Миссула,Мисула,Міссула,מיזולה,ميسولا,میزولا، مونتانا,میسولا، مونٹانا,ミズーラ,米蘇拉,미줄라', 46.8721500, -113.9940000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145752, 'Montana City', 'Montana City', 'Fort Minnesota,Montana,Montana City,Montana Town,Prickly Pear,Prickly Pear City', 46.5377100, -111.9327700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145753, 'North Browning', 'North Browning', '', 48.5702500, -113.0095300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145754, 'Orchard Homes', 'Orchard Homes', '', 46.8632600, -114.0484400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145755, 'Pablo', 'Pablo', 'Pablo,pablww  mwntana,Пабло,پابلوو، مونتانا', 47.6002100, -114.1190000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145756, 'Philipsburg', 'Philipsburg', 'Filipsburg,fei li pu,fylybsbwrgh,fylypsbwrg  mwntana,Филипсбург,فيليبسبورغ,فیلیپسبورگ، مونتانا,菲利普', 46.3321500, -113.2942300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145757, 'Plains', 'Plains', 'Horse Plains,Plains', 47.4602100, -114.8829100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145758, 'Plentywood', 'Plentywood', 'PWD,Plehntivud,Plentiud,Plentivud,blyntywwd,plntywwd  mwntana,po lan te wu de,Плентивуд,Плентиуд,Плэнтивуд,بلينتيوود,پلنتیوود، مونتانا,坡兰特伍德', 48.7747500, -104.5624600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145759, 'Polson', 'Polson', 'Foot of the Lake,Lambert''s Landing,Polson,Polsun,bo er sen,bwlswn,pwlswn  mwntana,Полсон,Полсън,بولسون,پولسن، مونٹانا,پولسون، مونتانا,波尔森', 47.6935500, -114.1631700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145760, 'Red Lodge', 'Red Lodge', 'Bad Lodge,Red Lodge,Red Lodz,Red Lodzh,Rehd Lodzh,Rocky Fork,lei de luo zhi,rd laj  mwntana,ryd lwdj,Ред Лодж,Ред Лоџ,Рэд Лодж,رد لاج، مونتانا,ريد لودج,雷德洛治', 45.1857800, -109.2468200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145761, 'Ronan', 'Ronan', 'Ronan,Ronan Springs,Spring Creek,luo nan,rwnan,rwwnan  mwntana,Ронан,رونان,روونان، مونتانا,罗南', 47.5288200, -114.1015000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145762, 'Roundup', 'Roundup', 'RPX,Raundap,Raundup,lang da pu,rawndab,rawndap  mwntana,Раундап,Раундъп,راوندأب,راونداپ، مونتانا,朗达普', 46.4452400, -108.5418000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145763, 'Ryegate', 'Ryegate', '', 46.2971800, -109.2587900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145764, 'Scobey', 'Scobey', 'Skobehj,Skobi,Skoubi,askwby  mwntana,si ke bi,skwby,Скоби,Скобэй,Скоуби,اسکوبی، مونتانا,سكوبي,斯科比', 48.7925200, -105.4208300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145765, 'Seeley Lake', 'Seeley Lake', 'Seeley Lake,Seeleys Ranch', 47.1793800, -113.4845200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145766, 'Shelby', 'Shelby', 'SBX,Shehlbi,Shelbi,Shelby,Shelby Junction,sherubi,shlby  mwntana,shylby,xie er bi,Шелби,Шэлби,شلبی، مونتانا,شيلبي,シェルビー,谢尔比', 48.5052600, -111.8569700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145767, 'Sidney', 'Sidney', 'Central City,Maggie''s Town,SDY,Sidnej,Sidney,Sidni,sydny,sydny  mwntana,xi de ni,Сидней,Сидни,سيدني,سڈنی، مونٹانا,سیدنی، مونتانا,西德尼', 47.7166800, -104.1563300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145768, 'Somers', 'Somers', '', 48.0802300, -114.2215100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145769, 'South Browning', 'South Browning', '', 48.5460800, -113.0142500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145770, 'Stanford', 'Stanford', 'Antelope Butte Springs,Stanford,Stanfordville,Станфорд', 47.1535800, -110.2182600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145771, 'Stevensville', 'Stevensville', 'Sheeptown,Stehvensvill,Stevensville,Stivensvil,Stivunsvil,astwnswyl  mwntana,shi di fen si wei er,Стивенсвил,Стивънсвил,Стэвенсвилл,استونسویل، مونتانا,史蒂芬斯维尔', 46.5099200, -114.0931600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145772, 'Sun Prairie', 'Sun Prairie', '', 47.5369000, -111.4813600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145773, 'Superior', 'Superior', 'Edgar,Superior,Superior City,Supirior,spyryar  mwntana,su bi li er,swbrywr,Супериор,Супириор,سوبريور,سپیریار، مونتانا,苏必利尔', 47.1915900, -114.8918000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145774, 'Terry', 'Terry', 'Joubert''s Landing,Tehrri,Teri,Terry,te li,try  mwntana,tyry,Тери,Тэрри,تری، مونتانا,تيري,特里', 46.7930600, -105.3122100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145775, 'Thompson Falls', 'Thompson Falls', 'THM,Thompson Falls,Tompson Fols,Tompsun Fols,tampsn flz  mwntana,tang pu sen pu bu,twmswn fwlz,Томпсон Фолс,Томпсън Фолс,تامپسن فلز، مونتانا,تومسون فولز,汤普森瀑布', 47.5948900, -115.3383400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145776, 'Three Forks', 'Three Forks', 'Bridgeville,Madison City,Shedd''s Bridges,Sheds Bridge,The Bridges,Three Forks', 45.8924300, -111.5521900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145777, 'Townsend', 'Townsend', 'Taunsehnd,Taunsend,Taunsund,tang sen,tawnsnd,tawnznd  mwntana,Таунсенд,Таунсънд,Таунсэнд,تاونزند، مونتانا,تاونسند,汤森', 46.3191000, -111.5208000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145778, 'Virginia City', 'Virginia City', 'Varina,Virdzhinia Siti,Virdzinija Siti,Virginia City,fu ji ni ya cheng,fyrjynya syty,Вирджиниа Сити,Вирџинија Сити,فيرجينيا سيتي,弗吉尼亚城', 45.2938100, -111.9460900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145779, 'Warm Springs', 'Warm Springs', 'Warm Springs,Warmsprings', 46.1813100, -112.7847600, 'US', '2013-12-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145780, 'West Glendive', 'West Glendive', '', 47.1108500, -104.7496800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145781, 'West Yellowstone', 'West Yellowstone', 'Vehst Jelloustoun,Vest Jelouston,WYS,wst ylwwstwwn  mwntana,wyst ylwstwn,xi huang shi,Вест Јелоустон,Вэст Йеллоустоун,وست یلووستوون، مونتانا,ويست يلوستون,西黄石', 44.6621500, -111.1041100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145782, 'White Sulphur Springs', 'White Sulphur Springs', 'Hot Sulphur Springs,Minnie Wabba,Uajt Sul''fur Springs,Uajt Sulful Springs,Vajt Sulfer Springs,Wampum Waters,White Sulphur Spring,White Sulphur Springs,bai liu huang quan zhen,wayt salfr aspryngz  mwntana,wayt swlfr sbrynghz,Вајт Сулфер Спрингс,Уайт Сульфур Спрингс,Уайт Сълфъл Спрингс,وايت سولفر سبرينغز,وایت سالفر اسپرینگز، مونتانا,白硫磺泉镇', 46.5482800, -110.9021600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145783, 'Whitefish', 'Whitefish', 'Stump Town,Uajtfish,Vajtfish,Whitefish,huai te fei shen,waytfysh,waytfysh  mwntana,Вајтфиш,Уайтфиш,وائٹ فش، مونٹانا,وايتفيش,وایتفیش، مونتانا,怀特菲什', 48.4110800, -114.3376300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145784, 'Whitehall', 'Whitehall', '', 45.8707600, -112.0974900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145785, 'Wibaux', 'Wibaux', 'Beaver,Mingusville,Wibaux', 46.9850100, -104.1882700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145786, 'Winnett', 'Winnett', '', 47.0027600, -108.3520700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145787, 'Wolf Point', 'Wolf Point', 'OLF,Ulf Pojnt,Volf Pojnt,Vulf Pojnt,Wolf Point,Wolfpoint,urufupointo,wlf pwynt  mwntana,wo er fu bo yin te,wwlf bwynt,Волф Пойнт,Вулф Појнт,Улф Пойнт,ولف پوینت، مونتانا,وولف بوينت,ウルフポイント,沃尔夫波因特', 48.0905700, -105.6405600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145788, 'Amidon', 'Amidon', '', 46.4822300, -103.3218500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145789, 'Belfield', 'Belfield', 'Belfield,Camp Houston,Houston', 46.8852900, -103.1996200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145790, 'Beulah', 'Beulah', 'Beulah,Farrington,Thomas,Troy', 47.2633400, -101.7779500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145791, 'Bismarck', 'Bismarck', 'BIS,Bismak,Bismarck,Bismarck i Nord-Dakota,Bismark,Bismarka,Bismarkas,Bismarks,Bismàk,Bizmark,Edwinton,Gorad Bismark,The Crossing,bi si mai,bijeumakeu,bismark,bismarka,bisumaku,bysmark,bysmark  dakwtay shmaly,bysmrq,pismark,Μπίσμαρκ,Бизмарк,Бисмарк,Бісмарк,Горад Бісмарк,Բիսմարկ,ביסמרק,انٹیل,بسمارک، شمالی ڈکوٹا,بيسمارك,بیسمارک، داکوتای شمالی,बिस्मार्क,பிஸ்மார்க்,บิสมาร์ก,ბისმარკი,ビスマーク,俾斯麥,비즈마크', 46.8083300, -100.7837400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145792, 'Bottineau', 'Bottineau', 'Botineo,Bottineau,Oak Creek,bo te nuo,bwtynaw  dakwtay shmaly,Ботинео,بوتیناو، داکوتای شمالی,波特诺', 48.8272300, -100.4457000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145793, 'Bowbells', 'Bowbells', 'Bobels,Boubells,Bovbells,bao bei er si,bwbylz,bwwbls  dakwtay shmaly,Бобелс,Бовбеллс,Боубеллс,بوبيلز,بووبلس، داکوتای شمالی,鲍贝尔斯', 48.8030800, -102.2460000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145794, 'Bowman', 'Bowman', 'BWM,Bouman,Bowman,Eden,Lowden,Twin Buttes,bao man,bwman,bwwmn  dakwtay shmaly,Боуман,بومان,بومین، شمالی ڈکوٹا,بوومن، داکوتای شمالی,鲍曼', 46.1830600, -103.3949100, 'US', '2017-06-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145795, 'Burlington', 'Burlington', 'Berlington,Burlington,Coltan,The Forks,bo ling dun,brlnghtwn,bwrlyngtwn  dakwtay shmaly,Берлингтон,برلنغتون,برلنگٹن، شمالی ڈکوٹا,بورلینگتون، داکوتای شمالی,伯灵顿', 48.2752900, -101.4287800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145796, 'Carson', 'Carson', 'Karson,Карсон', 46.4177800, -101.5648700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145797, 'Center', 'Center', '', 47.1163800, -101.2995900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145798, 'Crosby', 'Crosby', 'Krosbi,Krozbi,ke luo si bi,krwsby,krzby  dakwtay shmaly,Крозби,Кросби,Кросбі,كروسبي,کرزبی، داکوتای شمالی,کروسبی، شمالی ڈکوٹا,克罗斯比', 48.9142000, -103.2949100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145799, 'Dickinson', 'Dickinson', 'DIK,Dickinson,Dikinson,Dikinsòn,Pleasant Valley Siding,di jin sen,dikinseun,dykynsn  dakwtay shmaly,dykynswn,Дикинсон,ديكينسون,دیکینسن، داکوتای شمالی,ڈکنسن، شمالی ڈکوٹا,迪金森,디킨슨', 46.8791800, -102.7896200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145800, 'Fort Yates', 'Fort Yates', '', 46.0869400, -100.6301300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145801, 'Garrison', 'Garrison', '', 47.6522200, -101.4157200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145802, 'Hazen', 'Hazen', 'Khejzin,ha sen,hazn  dakwtay shmaly,hazyn,Хејзин,هازن، داکوتای شمالی,هازين,ہیزن، شمالی ڈکوٹا,哈森', 47.2944500, -101.6226600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145803, 'Hettinger', 'Hettinger', '', 46.0013900, -102.6368200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145804, 'Kenmare', 'Kenmare', 'Kenmare,Lignite', 48.6747500, -102.0826600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145805, 'Killdeer', 'Killdeer', '', 47.3719600, -102.7540800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145806, 'Lincoln', 'Lincoln', 'Fort Lincoln Estates,Lincoln,Linkol''n,Линкольн', 46.7624900, -100.7004000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145807, 'Linton', 'Linton', 'Liston,lin dun,lyntwn,lyntwn  dakwtay shmaly,Листон,لنٹن، شمالی ڈکوٹا,لينتون,لینتون، داکوتای شمالی,林顿', 46.2666600, -100.2328900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145808, 'Mandan', 'Mandan', 'Cushman,Lincoln,Mandan,Morton,man dan,mandan,mndn  dakwtay shmaly,Мандан,ماندان,مندن، داکوتای شمالی,مینڈین، شمالی ڈکوٹا,曼丹', 46.8266600, -100.8895800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145809, 'Manning', 'Manning', '', 47.2300100, -102.7701900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145810, 'McClusky', 'McClusky', '', 47.4858300, -100.4431800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145811, 'Medora', 'Medora', '', 46.9139000, -103.5243500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145812, 'Minot', 'Minot', 'MOT,Majnot,Majnut,Mina,mai nuo te,mainos,mainotto,maynt  dakwtay shmaly,mynwt,Майнот,Майнът,Мајнот,Мина,مائےناٹ,ماینت، داکوتای شمالی,مينوت,マイノット,邁諾特,마이놋', 48.2325100, -101.2962700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145813, 'Mohall', 'Mohall', 'Mogoll,Mokhol,Mokholl,mo huo er,mwhal,mwhal  dakwtay shmaly,Моголл,Мохол,Мохолл,موهال,موهال، داکوتای شمالی,莫霍尔', 48.7633600, -101.5132200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145814, 'Mott', 'Mott', 'Mot,mat  dakwtay shmaly,mo te,mwt,Мот,مات، داکوتای شمالی,موت,莫特', 46.3725000, -102.3271100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145815, 'New Town', 'New Town', 'New Town,Newton,Nju Taun,nyw tawn,nyw tawn  dakwtay shmaly,xin zhen,Њу Таун,نيو تاون,نیو تاون، داکوتای شمالی,نیو ٹاؤن، شمالی ڈکوٹا,新镇', 47.9808500, -102.4901800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145816, 'Parshall', 'Parshall', '', 47.9533500, -102.1348900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145817, 'Stanley', 'Stanley', '', 48.3172400, -102.3904500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145818, 'Stanton', 'Stanton', 'Stehnton,Стэнтон', 47.3211100, -101.3815500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145819, 'Surrey', 'Surrey', '', 48.2364000, -101.1334900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145820, 'Tioga', 'Tioga', '', 48.3972400, -102.9382400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145821, 'Towner', 'Towner', '', 48.3458300, -100.4054100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145822, 'Velva', 'Velva', 'Velva,fylfa,wei er wa,wlwa  dakwtay shmaly,Велва,فيلفا,ولوا، داکوتای شمالی,ویلوا، شمالی ڈکوٹا,韦尔瓦', 48.0561200, -100.9293200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145823, 'Washburn', 'Washburn', '', 47.2891600, -101.0290300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145824, 'Watford City', 'Watford City', 'Banks,Watford City', 47.8022400, -103.2832500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145825, 'Williston', 'Williston', 'ISN,Little Muddy,Uilliston,Viliston,Villiston,Williston,wei li si dun,wylstwn  dakwtay shmaly,wylystwn,Вилистон,Віллістон,Уиллистон,ويليستون,ویلستون، داکوتای شمالی,ویلسٹن، شمالی ڈکوٹا,威利斯顿', 48.1469700, -103.6179700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145826, 'Alliance', 'Alliance', 'AIA,Al''jans,Alajans,Allajans,Alliance,Grand Lake,Olians,alayns  nbraska,alayns  nybraska,alyans,eollaieonseu,Алајанс,Аллайанс,Альянс,Олианс,أليانس,الائنس، نیبراسکا,الاینس، نبراسکا,얼라이언스', 42.1016300, -102.8721500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145827, 'Arthur', 'Arthur', '', 41.5716500, -101.6915600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145828, 'Bayard', 'Bayard', '', 41.7549700, -103.3241000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145829, 'Benkelman', 'Benkelman', 'Benkelman,Benkleman,Collinsville', 40.0491600, -101.5329400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145830, 'Bridgeport', 'Bridgeport', 'Bridzhport,Bridzport,brydjbwrt,bryjprt  nbraska,Бриджпорт,Бриџпорт,برج پورٹ، نیبراسکا,بريدجبورت,بریجپرت، نبراسکا', 41.6652500, -103.0991000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145831, 'Cambridge', 'Cambridge', 'Cambridge,Kembridzh,Pickletown,Кембридж', 40.2819500, -100.1656900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145832, 'Chadron', 'Chadron', 'CDR,Chadron,chadrwn  nbraska,tshadrwn,Чадрон,تشادرون,چادرون، نبراسکا', 42.8294200, -102.9999100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145833, 'Chappell', 'Chappell', '', 41.0927700, -102.4707400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145834, 'Gering', 'Gering', 'Dzhering,Giring,ghyrngh,gryng  nbraska,gyyrng  nybraska,jie ling,Гиринг,Джеринг,غيرنغ,گئیرنگ، نیبراسکا,گرینگ، نبراسکا,傑靈', 41.8258000, -103.6605000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145835, 'Gordon', 'Gordon', 'GRN,Gordon,ghwrdn,grdn  nbraska,Гордон,غوردن,گردن، نبراسکا', 42.8047200, -102.2032200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145836, 'Gothenburg', 'Gothenburg', '', 40.9294500, -100.1606800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145837, 'Grant', 'Grant', 'Grant,ghrant,grnt  nbraska,Грант,غرانت,گرنت، نبراسکا', 40.8419400, -101.7251700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145838, 'Harrisburg', 'Harrisburg', 'Garrisberg,Гаррисберг', 41.5563600, -103.7385600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145839, 'Harrison', 'Harrison', 'Kharison,Kharrison,haryswn,hryswn  nbraska,Харисон,Харрисон,هاريسون,هریسون، نبراسکا', 42.6871900, -103.8827100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145840, 'Hayes Center', 'Hayes Center', '', 40.5108400, -101.0196000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145841, 'Hyannis', 'Hyannis', '', 42.0005400, -101.7618400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145842, 'Imperial', 'Imperial', 'IML,Imperial,Impirijal,ambryal,aympyryal  nbraska,Империал,Импиријал,إمبريال,ایمپیریال، نبراسکا', 40.5169400, -101.6432300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145843, 'Kimball', 'Kimball', 'Antelopeville,Kimbal,Kimball,Kimboll,kymbal,kymbl  nbraska,Кимбал,Кимболл,كيمبال,کیمبل، نبراسکا', 41.2358100, -103.6630000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145844, 'McCook', 'McCook', 'MCK,MakKuk,Makuk,McCook,makwk,mk kwk  nybraska,МакКук,Макук,ماكوك,مک کوک، نیبراسکا,مک‌کوک، نبراسکا', 40.2019500, -100.6257100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145845, 'Mitchell', 'Mitchell', '', 41.9402400, -103.8085600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145846, 'Mullen', 'Mullen', 'MHN', 42.0427800, -101.0426600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145847, 'North Platte', 'North Platte', 'LBF,Nors Plehjtt,Nort Plejt,Nort-Platt,bei pu la te,northa pleta,noseupeullaes,nwrth blat,plt shmaly  nbraska,Норс Плэйтт,Норт Плејт,Норт-Платт,نارتھ پلیٹ، نیبراسکا,نورث بلات,پلت شمالی، نبراسکا,नॉर्थ प्लॅट,北普拉特,노스플랫', 41.1238900, -100.7654200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145848, 'Ogallala', 'Ogallala', 'OGA,Ogalalla,Ogalalla Village,Ogallala,Oglala,awgalala  nbraska,ogalala,ogarara,wghalala,Огаллала,Оґаллала,اوگالالا، نبراسکا,وغالالا,ओगालाला,オガララ', 41.1280500, -101.7196200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145849, 'Oshkosh', 'Oshkosh', '', 41.4049800, -102.3443600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145850, 'Rushville', 'Rushville', 'Rashvil,Rashvill,rwshfyl,rwshwyl  nbraska,Рашвил,Рашвилл,روشفيل,روشویل، نبراسکا', 42.7183200, -102.4640600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145851, 'Scottsbluff', 'Scottsbluff', 'BFF,Scotts Bluff,Scottsbluff,Skotsblaf,Skotsblaff,Skottsbluff,askatsblaf  nbraska,si ke ci bu la fu,skwtsblwf,Скотсблаф,Скотсблафф,Скоттсблуфф,اسکاتسبلاف، نبراسکا,سكوتسبلوف,سکاٹسبلف، نیبراسکا,斯科茨布拉夫', 41.8666300, -103.6671700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145852, 'Sidney', 'Sidney', 'SNY,Sidnej,Sidney,Sidni,sydny,sydny  nbraska,Сидней,Сидни,سيدني,سیدنی، نبراسکا', 41.1427600, -102.9779800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145853, 'Stapleton', 'Stapleton', '', 41.4802800, -100.5129200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145854, 'Stockville', 'Stockville', '', 40.5327900, -100.3834800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145855, 'Sutherland', 'Sutherland', '', 41.1569400, -101.1262700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145856, 'Terrytown', 'Terrytown', '', 41.8474700, -103.6616100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145857, 'Thedford', 'Thedford', '', 41.9783300, -100.5762500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145858, 'Trenton', 'Trenton', 'Trail City,Trenton,Трентон', 40.1755500, -101.0129400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145859, 'Tryon', 'Tryon', '', 41.5527700, -100.9576500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145860, 'Valentine', 'Valentine', 'VTN,Valentajn,Valentin,falytyn  nbraska,wlntayn  nbraska,Валентајн,Валентин,فاليتين، نبراسكا,ولنتاین، نبراسکا', 42.8727800, -100.5509700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145861, 'Battle Mountain', 'Battle Mountain', 'BAM', 40.6421300, -116.9342700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145862, 'Carlin', 'Carlin', '', 40.7138100, -116.1039700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145863, 'Elko', 'Elko', 'Ballous Addition,Contae Elko,EKO,Ehlko,Elko,ai er ke,alkw,aylkw  nwada,Елко,Элко,إلكو,ایلکو، نوادا,ایلکو، نیواڈا,埃尔科', 40.8324200, -115.7631200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145864, 'Jackpot', 'Jackpot', 'Dzakpot,Horse Shu,Jackpot,KPT,gqpwt,jakbwt,jkpat  nwada,Џакпот,גקפוט,جاكبوت,جکپات، نوادا,جککپوت، نیواڈا', 41.9832400, -114.6747600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145865, 'Lovelock', 'Lovelock', 'Big Meadows,LOL,Lavlok,Lovelock,Lovelock Station,Lovelocks,Luvlok,la fu luo ke,lawlk  nwada,lwflwk,Лавлок,Лъвлок,لاولک، نوادا,لوفلوك,لوولوک، نیواڈا,拉夫洛克', 40.1793500, -118.4734800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145866, 'Spring Creek', 'Spring Creek', '', 40.7265900, -115.5859000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145867, 'Wells', 'Wells', 'LWL,Uehlls,Uels,Vels,Wells,wlz  nwada,wylz,Велс,Уелс,Уэллс,ولز، نوادا,ويلز', 41.1115900, -114.9644900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145868, 'West Wendover', 'West Wendover', 'Vehst Vednovehr,Vest Vendover,Zapaden Uendouvur,wst wndwr  nwada,wyst wyndwfyr,xi wen duo fu,Вест Вендовер,Вэст Ведновэр,Западен Уендоувър,وست وندور، نوادا,ويست ويندوفير,ویسٹ وینڈوور، نیواڈا,西温多弗', 40.7391000, -114.0733500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145869, 'Winnemucca', 'Winnemucca', 'Uinemuka,Vinemaka,Vinnemukka,WMC,wen ni ma ka,wynmwka  nwada,wynymwka,Винемака,Виннемукка,Уинемъка,וינמאקה,ونیموکا، نیواڈا,وينيموكا,وینموکا، نوادا,温尼马卡', 40.9729600, -117.7356800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145870, 'Albany', 'Albany', 'Albani,Ehlbani,Olbani,albany,albany  awrgn,albany  awrygwn,ao er ba ni,orubani,xxlbani,Албани,Олбани,Элбани,آلبانی، اورگن,ألباني,البانی، اوریگون,ออลบานี,オールバニ,奥尔巴尼', 44.6365100, -123.1059300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145871, 'Aloha', 'Aloha', 'Alokha,aroa,awha  awrgan,Алоха,الوہا، اوریگون,اوها، اورگان,アロア', 45.4942800, -122.8670500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145872, 'Altamont', 'Altamont', '', 42.2068100, -121.7372200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145873, 'Amity', 'Amity', 'Amiti,Ehmiti,amyty,amyty  awrgn,Амити,Эмити,أميتي,امیتی، اورگن,แอมิตี', 45.1156700, -123.2073300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145874, 'Ashland', 'Ashland', 'AHM,Ashlund,Ehshlehnd,Eshland,a shen lan,aesyullaendeu,ashland,ashlnd  awrgn,ashurando,asland,Ашлънд,Ешланд,Эшлэнд,آشلاند,اشلند، اورگن,ایشلنڈ، اوریگون,ಆಷ್ಲಂಡ್,แอชแลนด์,アシュランド,阿什兰,애슐랜드', 42.1945800, -122.7094800, 'US', '2017-03-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145875, 'Astoria', 'Astoria', 'AST,Astori,Astoria,Astorija,Clatsop,Fort Astoria,Fort George,astwrya,astwrya  awrgn,asutoria,xas tx reiy,Астори,Асториа,Астория,Асторија,Асторія,آستوریا، اورگن,أستوريا,اسٹوریا، اوریگون,อัสตอเรีย,アストリア', 46.1878800, -123.8312500, 'US', '2017-05-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145876, 'Athena', 'Athena', 'Athena,Centerville', 45.8118000, -118.4905300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145877, 'Aumsville', 'Aumsville', '', 44.8409500, -122.8709200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145878, 'Baker City', 'Baker City', 'BKE,Baker,Baker City,Behjker Siti,Bejker Siti,Bejkur Siti,Thanh pho Baker,Thành phố Baker,be kexr si ti,bekashiti,bykr syty,bykr syty  awrgn,Бейкър Сити,Бејкер Сити,Бэйкер Сити,بيكر سيتي,بیکر سٹی، اوریگون,بیکر سیتی، اورگن,เบเกอร์ซิตี,ベーカーシティ', 44.7748700, -117.8343800, 'US', '2017-07-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145879, 'Bandon', 'Bandon', 'BDY,Bandon,Bandun,bandwn,bndn  awrgn,Бандон,Бандън,باندون,بندن، اورگن,แบนดัน', 43.1190000, -124.4084500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145880, 'Banks', 'Banks', 'Banks,banks,bankusu,bnks  awrgn,Банкс,بانكس,بنکس، اورگن,แบงส์,バンクス', 45.6187200, -123.1142800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145881, 'Barview', 'Barview', '', 43.3542800, -124.3131700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145882, 'Bay City', 'Bay City', 'Bej-Siti,Бей-Сити', 45.5226000, -123.8893000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145883, 'Beavercreek', 'Beavercreek', 'Beavercreek', 45.2879000, -122.5356400, 'US', '2015-01-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145884, 'Beaverton', 'Beaverton', 'Beaverton,Beaverton Old Siding,Bijvurtun,Bivehrton,Biverton,bibaton,byfyrtwn,bywrtwn  awrgn,Бивертон,Бивэртон,Бийвъртън,Бівертон,بيفيرتون,بیورتون، اورگن,بیورٹن، اوریگون,ビーバートン', 45.4870600, -122.8037100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145885, 'Bend', 'Bend', 'Behnd,Bend,ben de,bendo,bnd,bnd  awrgn,bynd,Бенд,Бэнд,בנד,بند، اورگن,بيند,ベンド,本德', 44.0581700, -121.3153100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145886, 'Bethany', 'Bethany', '', 45.5578900, -122.8676000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145887, 'Boardman', 'Boardman', 'Bordman,Бордман', 45.8398600, -119.7005800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145888, 'Brookings', 'Brookings', 'BOK,Brukings,brwkngz  awrygwn,brwkynghz,brwkyngs  awrgn,burukkinguzu,Брукингс,بروكينغز,بروکنگز، اوریگون,بروکینگس، اورگن,ブルッキングズ', 42.0526100, -124.2839800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145889, 'Brownsville', 'Brownsville', 'Braunsvil,Braunsvill,brawnzfyl,brwnswyl  awrgn,buraunzubiru,Браунсвил,Браунсвилл,براونزفيل,برونسویل، اورگن,ブラウンズビル', 44.3934600, -122.9848100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145890, 'Bunker Hill', 'Bunker Hill', '', 43.3559500, -124.2048300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145891, 'Burns', 'Burns', 'BNO,Berns,Burns,bai en si,brnz  awrgn,bwrnz,Бернс,Бурнс,Бърнс,برنز، اورگن,بورنز,柏恩斯', 43.5862600, -119.0541000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145892, 'Canby', 'Canby', 'Kanbi,knby,knby  awrgn,Канби,كنبي,کنبی، اورگن', 45.2629000, -122.6925900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145893, 'Cannon Beach', 'Cannon Beach', 'Kanon Bich,Kanun Bijch,Kehnnon Bich,kanwn bych  awrgn,kanwn bytsh,Канон Бич,Канън Бийч,Кэннон Бич,كانون بيتش,کانون بیچ، اورگن', 45.8917700, -123.9615300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145894, 'Canyon City', 'Canyon City', 'Kanion Siti,Kanjon Siti,Keniun Siti,kanywn syty,knyn syty  awrgn,kyanionshiti,Канион Сити,Канјон Сити,Кениън Сити,كانيون سيتي,کنین سیتی، اورگن,キャニオンシティ', 44.3896000, -118.9502300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145895, 'Canyonville', 'Canyonville', 'Kanionvill,Kanjonvil,Keniunvil,kanywnfyl,knynwyl  awrgn,Канионвилл,Канјонвил,Кениънвил,كانيونفيل,کنینویل، اورگن', 42.9273400, -123.2811700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145896, 'Carlton', 'Carlton', '', 45.2942800, -123.1764900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145897, 'Cascade Locks', 'Cascade Locks', 'CZK,Kaskadeh Loks,Kaskejd Loks,kaskad lwks,kskd lks  awrgn,Каскадэ Локс,Каскейд Локс,Каскејд Локс,كاسكاد لوكس,کسکد لکس، اورگن', 45.6698400, -121.8906400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145898, 'Cave Junction', 'Cave Junction', 'Cave Junction,Caves City,Caves Junction,Kehjv Dzhankshn,Kejv DZankshon,Kejv Dzhunkshun,kw jankshn  awrgn,kyf jnkshn,Кейв Джънкшън,Кејв Џанкшон,Кэйв Джанкшн,كيف جنكشن,کو جانکشن، اورگن', 42.1628900, -123.6481200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145899, 'Cedar Hills', 'Cedar Hills', '', 45.5048400, -122.7984300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145900, 'Cedar Mill', 'Cedar Mill', '', 45.5248400, -122.8109300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145901, 'Central Point', 'Central Point', 'Sentral Pojnt,sntral bwynt,sntral pwynt  awrgn,Сентрал Пойнт,Сентрал Појнт,سنترال بوينت,سنترال پوینت، اورگن', 42.3759600, -122.9164300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145902, 'Chenoweth', 'Chenoweth', '', 45.6276200, -121.2434100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145903, 'Clackamas', 'Clackamas', 'Clackamas,Marshfield,Marshville', 45.4076200, -122.5703700, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145904, 'Clatskanie', 'Clatskanie', 'Clatskanie,Klaskain,Klaskania,Klaskonine,Klatskani,Klatskinaj,klatsksn,kltskny  awrgn,Клатскани,Клатскинай,كلاتسكسن,کلتسکنی، اورگن', 46.1012200, -123.2067900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145905, 'Coburg', 'Coburg', 'Koburg,kbwrg  awrgn,kwbwrgh,Кобург,كوبورغ,کبورگ، اورگن', 44.1370700, -123.0664800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145906, 'Columbia City', 'Columbia City', 'Columbia City,McBride', 45.8901100, -122.8070500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145907, 'Condon', 'Condon', 'Kondon,Kondun,kndn  awrgn,kwndwn,Кондон,Кондън,كوندون,کندن، اورگن', 45.2343000, -120.1850300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145908, 'Coos Bay', 'Coos Bay', 'Coos Bay,Coose Bay,Empire,Kus Behj,Kus Bej,Marshfield,kuzubei,kws bay,kws bay  awrgn,Кус Бей,Кус Беј,Кус Бэй,كوس باي,کوز بے، اوریگون,کوس بای، اورگن,クーズベイ', 43.3665000, -124.2178900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145909, 'Coquille', 'Coquille', 'Coquille,Coquille City,Kokil,Kokuill,Koukijl,kakwyl  awrgn,kokiru,kwkyl,Кокил,Кокуилл,Коукийл,كوكيل,کاکویل، اورگن,コキール', 43.1770500, -124.1876100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145910, 'Cornelius', 'Cornelius', 'Kornelijas,Kornelius,Kornilius,koneriasu,krnlyws  awrgn,kwrnylyws,Корнелиус,Корнелијас,Корнилиъс,كورنيليوس,کرنلیوس، اورگن,コーネリアス', 45.5198400, -123.0598300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145911, 'Corvallis', 'Corvallis', 'CVO,Corvallis,Korvalis,Korvallis,Kovalis,ke wa li si,kobaelliseu,kobarisu,krwlys  awrgn,kwrfalys,kwrwyls  awrygwn,Ковалис,Корвалис,Корваллис,كورفاليس,کرولیس، اورگن,کورویلس، اوریگون,コーバリス,科瓦利斯,코밸리스', 44.5645700, -123.2620400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145912, 'Cottage Grove', 'Cottage Grove', 'Cottage Grove,Kotidz Grouv,Kotidzh Grouv,Kottehjdzh Grouv,Lemati,katyj grw  awrgn,kwltagh ghrwf,Котидж Гроув,Котиџ Гроув,Коттэйдж Гроув,كولتاغ غروف,کاتیج گرو، اورگن', 43.7976200, -123.0595200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145913, 'Creswell', 'Creswell', 'Kresuel,Kresvehll,Kresvel,kryswyl,wrntn  awrgn,Кресвел,Кресвэлл,Кресуел,كريسويل,ورنتن، اورگن', 43.9179000, -123.0245300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145914, 'Culp Creek', 'Culp Creek', '', 43.7034600, -122.8475700, 'US', '2013-05-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145915, 'Culver', 'Culver', 'Kalver,Kulvehr,Kulvur,kalwr  awrgn,klfr,Калвер,Кулвэр,Кълвър,كلفر,کالور، اورگن', 44.5256800, -121.2131000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145916, 'Dallas', 'Dallas', 'Dalas,Dallas,dalas,dalas  awrgn,Далас,Даллас,دالاس,دالاس، اورگن', 44.9192800, -123.3170500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145917, 'Damascus', 'Damascus', 'City of Damascus,Damascus', 45.4176200, -122.4589800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145918, 'Dayton', 'Dayton', 'Dayton,Dehjton,Dejton,Dejtun,West Dayton,daytwn,detana,dytwn  awrgn,Дейтон,Дейтън,Дејтон,Дэйтон,دايتون,دیتون، اورگن,ڈیٹن، اوریگون,डेटन', 45.2206700, -123.0762100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145919, 'Depoe Bay', 'Depoe Bay', 'De Poe Bay,Depoe Bay,Depoeh Behj,Depot Bay,Dipo Bej,dp bay  awrgn,dybw bay,Депоэ Бэй,Дипо Бей,ديبو باي,دپ بای، اورگن', 44.8084500, -124.0631700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145920, 'Deschutes River Woods', 'Deschutes River Woods', '', 43.9915100, -121.3583600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145921, 'Donald', 'Donald', '', 45.2223400, -122.8392600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145922, 'Drain', 'Drain', 'Drain,Drains', 43.6587300, -123.3187000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145923, 'Dundee', 'Dundee', 'Dundee,Dundee Junction', 45.2781700, -123.0109400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145924, 'Dunes City', 'Dunes City', 'Dunes,Dunes City,North Beach,Westlake', 43.8831800, -124.1151200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145925, 'Durham', 'Durham', 'Daram,Darem,Djurkham,Duram,daramu,drham,dwrhm  awrgn,Дарам,Дарем,Дърам,Дюрхам,درهام,دورهم، اورگن,ダーラム', 45.4020600, -122.7528700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145926, 'Eagle Point', 'Eagle Point', 'Igl Rojnt,Ijgul Pojnt,ayghl bwynt,aygl pwynt  awrgn,Игл Ројнт,Ийгъл Пойнт,إيغل بوينت,ایگل پوینت، اورگن', 42.4726300, -122.8028200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145927, 'Elgin', 'Elgin', 'Ehlgin,Eldzin,Elgin,algyn  awrgn,aljyn,Елгин,Елџин,Элгин,إلجين,الگین، اورگن', 45.5648600, -117.9174300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145928, 'Enterprise', 'Enterprise', 'Ehnterprajz,Enterprajz,Enturprajz,antrbrayz,antrprayz  awrgn,Ентерпрајз,Ентърпрайз,Энтерпрайз,إنتربرايز,انترپرایز، اورگن', 45.4262600, -117.2787800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145929, 'Estacada', 'Estacada', 'Ehstakada,Estakada,Estakejda,astakada,astkada  awrgn,Естакада,Естакејда,Эстакада,إستاكادا,استکادا، اورگن', 45.2895700, -122.3337000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145930, 'Eugene', 'Eugene', 'EUG,Eugene,Eugine City,Gorad Judzhyn,Judzhijn,Judzhin,Judzin,Judzinas,Judžinas,you jin,yujin,ywgyn,ywjyn,ywjyn  awrgn,Јуџин,Горад Юджын,Юджийн,Юджин,Юджін,יוגין,يوجين,یوجین,یوجین، اورگن,ユージン,ユージーン,尤金,유진', 44.0520700, -123.0867500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145931, 'Fairview', 'Fairview', 'Fajrvju,Fervju,Feurvju,fyrfyw,fyrwyw  awrgn,fyyrwyw  awrygwn,Файрвю,Фервју,Феървю,فيرفيو,فیئرویو، اوریگون,فیرویو، اورگن,แฟร์วิว', 45.5384500, -122.4339800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145932, 'Florence', 'Florence', 'FMU,Florencija,Florens,Floruns,flwrans  awrgn,flwrns  awrygwn,flwryns,furorensu,peullolenseu,Флоренс,Флоренция,Флорънс,فلورانس، اورگن,فلورنس، اوریگون,فلورينس,フローレンス,플로렌스', 43.9826200, -124.0998400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145933, 'Forest Grove', 'Forest Grove', 'Forehst Grouv,Forest Grouv,Forist Grouv,foresutogurovu,fwrst ghrwf,fwrst grw  awrgn,Форест Гроув,Форист Гроув,Форэст Гроув,فورست غروف,فورست گرو، اورگن,フォレストグローヴ', 45.5198400, -123.1106600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145934, 'Fossil', 'Fossil', 'Fosil,Fossil,Fosul,fsyl  awrgn,fwsyl,Фосил,Фоссил,Фосъл,فسیل، اورگن,فوسيل', 44.9981900, -120.2161400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145935, 'Four Corners', 'Four Corners', '', 44.9279000, -122.9837100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145936, 'Gearhart', 'Gearhart', '', 46.0242700, -123.9112500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145937, 'Gervais', 'Gervais', 'Dzhurvejs,Gervais,ce xrwes,ghyrfys,grwys  awrgn,Герваис,Джървейс,غيرفيس,گرویس، اورگن,เจอร์เวส', 45.1081800, -122.8976000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145938, 'Gladstone', 'Gladstone', 'Gladston,Gladstoun,Gledston,Glehdstoun,ghladstwn,gldstwn  awrgn,Гладстон,Гладстоун,Гледстон,Глэдстоун,غلادستون,گلدستون، اورگن,گلیڈسٹون، اوریگون', 45.3806800, -122.5948100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145939, 'Glide', 'Glide', '', 43.3015100, -123.1011800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145940, 'Gold Hill', 'Gold Hill', '', 42.4317900, -123.0506000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145941, 'Grand Ronde', 'Grand Ronde', 'Grand Ronde,Grande Ronde', 45.0601100, -123.6092800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145942, 'Grants Pass', 'Grants Pass', 'GTP,Grants Pas,Grants-Pass,Grehnts Pass,ge lan ci pa si,geulaencheupaeseu,ghrants bas,grnts pas  awrgn,Грантс Пас,Грантс-Пасс,Грэнтс Пасс,Ґрантс-Пасс,غرانتس باس,گرانٹس پاس، اوریگون,گرنتس پاس، اورگن,格兰茨帕斯,그랜츠패스', 42.4393300, -123.3306700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145943, 'Green', 'Green', 'Green,Greens', 43.1603900, -123.3678500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145944, 'Gresham', 'Gresham', 'Eugene,Grehskham,Gresham,ghrysham,grsham  awrgn,grsm,grysham  awrygwn,gureshamu,Грешам,Грэсхам,גרשם,غريشام,گرشام، اورگن,گریشام، اوریگون,グレシャム', 45.4981800, -122.4314800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145945, 'Happy Valley', 'Happy Valley', 'Khapi Vali,Khappi Vallehj,Khepi Vali,haby faly,happibare,hpy wly  awrgn,Хапи Вали,Хаппи Валлэй,Хепи Вали,هابي فالي,هپی ولی، اورگن,ہیپی ویلی، اوریگون,ハッピーバレー', 45.4467900, -122.5303700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145946, 'Harbor', 'Harbor', '', 42.0531700, -124.2675900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145947, 'Harrisburg', 'Harrisburg', 'Garrisberg,Kharisburg,Kharrisburg,harysbwrgh,hrrysbwrg  awrgn,Гаррисберг,Харисбург,Харисбърг,Харрисбург,هاريسبورغ,هرریسبورگ، اورگن,ہیرسبرک، اوریگون', 44.2740100, -123.1706500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145948, 'Hayesville', 'Hayesville', '', 44.9859500, -122.9828700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145949, 'Heppner', 'Heppner', 'Khepner,Khepnur,Kheppnehr,hppnr  awrgn,hybnr,Хепнер,Хепнър,Хеппнэр,هيبنر,هپپنر، اورگن', 45.3531800, -119.5578000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145950, 'Hermiston', 'Hermiston', 'HES,Hermiston,Khehrmiston,Khurmistun,Maxwell,hrmystn  awrgn,hyrmystwn,Хърмистън,Хэрмистон,هرمیستن، اورگن,هيرميستون,ہرمیسٹن، اوریگون', 45.8404100, -119.2894600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145951, 'Hillsboro', 'Hillsboro', 'Chilsmporo,Gilsboro,HIO,Hillsboro,Khillsboro,Khillsborou,Khilsboro,Khilsburo,hiljeubeoleo,hiruzuboro,hylsbrw  awrgn,hylsbwrw,xi er si bo lei,Χίλσμπορο,Гілсборо,Хиллсборо,Хиллсбороу,Хилсборо,Хилсбъро,هيلسبورو,هیلسبرو، اورگن,ہلزبورو، اوریگون,ヒルズボロ,希尔斯伯勒,힐즈버러', 45.5228900, -122.9898300, 'US', '2017-04-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145952, 'Hines', 'Hines', '', 43.5640400, -119.0810500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145953, 'Hood River', 'Hood River', 'Khud Riveh,Khud River,Khud Rivur,hwd rywr  awrgn,hwwd ryfyr,Худ Ривер,Худ Ривър,Худ Ривэ,هود ریور، اورگن,هوود ريفير,ہڈ ریور، اوریگون', 45.7054000, -121.5214600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145954, 'Hubbard', 'Hubbard', '', 45.1823400, -122.8078700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145955, 'Independence', 'Independence', 'Indehpendehns,Independens,Indipenduns,ayndybydyns,ayndypndns  awrgn,du li shi,Индепенденс,Индипендънс,Индэпендэнс,إينديبيدينس,انڈیپینڈینس، اوریگون,ایندیپندنس، اورگن,獨立市', 44.8512300, -123.1867700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145956, 'Irrigon', 'Irrigon', 'Irrigon,Stokes', 45.8956900, -119.4914100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145957, 'Island City', 'Island City', '', 45.3409700, -118.0446600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145958, 'Jacksonville', 'Jacksonville', 'Dzeksonvil,Dzhaksunvil,Dzheksonvill,jakswnfyl,jie ke xun wei er,jkkswnwyl  wrygn,jksnwyl  awrgn,Џексонвил,Джаксънвил,Джексонвилл,جاكسونفيل,جکسنویل، اورگن,جککسونویل، وریگن,傑克遜維爾', 42.3134600, -122.9669900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145959, 'Jefferson', 'Jefferson', 'Dzeferson,Dzhefersun,Dzhefferson,Dzhehfferson,Jefferson,Santiam,Santiam City,jfrswn  awrgn,jyfrswn,Џеферсон,Джеферсън,Джефферсон,Джэфферсон,جفرسون، اورگن,جيفرسون', 44.7195700, -123.0103700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145960, 'Jennings Lodge', 'Jennings Lodge', '', 45.3912300, -122.6125900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145961, 'John Day', 'John Day', 'JDA', 44.4159900, -118.9530100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145962, 'Joseph', 'Joseph', 'Chief Joseph,Dzhouzef,Dzhozef,Dzozef,Joseph,jwzyf,zhwzf  awrgn,Џозеф,Джозеф,Джоузеф,جوزيف,ژوزف، اورگن', 45.3543200, -117.2296100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145963, 'Junction City', 'Junction City', 'Dzankshon Siti,Dzhankshn Siti,Dzhunkshun Siti,Junction,Junction City,jankshn syty  awrgn,jnkshn syty,Џанкшон Сити,Джанкшн Сити,Джънкшън Сити,جانکشن سیتی، اورگن,جنكشن سيتي', 44.2192900, -123.2056500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145964, 'Keizer', 'Keizer', 'Kajzer,Kajzur,Kejzer,kaiza,kyzr,kyzr  awrgn,Кайзър,Кајзер,Кейзер,كيزر,کیزر، اورگن,カイザー', 44.9901200, -123.0262100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145965, 'King City', 'King City', '', 45.4026200, -122.8039900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145966, 'Klamath Falls', 'Klamath Falls', 'Klamat Fols,Klamath Falls,LMT,Linkville,klamath falz,klmth falz  awrgn,kuramasuforuzu,Кламат Фолс,كلاماث فالز,کلمته فالز، اورگن,کلیمیتھ فالز، اوریگون,クラマスフォールズ', 42.2248700, -121.7816700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145967, 'La Grande', 'La Grande', 'Brown Town,Brownsville,LGD,La Grand,La Grande,la ghrandy,la grandh  awrgn,la grandy  awrygan,ragurando,Ла Гранд,Ла Гранде,لا غراندي,لا گرانده، اورگن,لا گراندی، اوریگان,ラグランド', 45.3245800, -118.0877200, 'US', '2017-07-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145968, 'La Pine', 'La Pine', 'La Pajn,La Pine,Lapine,Rosland,la bayn,la pynh  awrgn,la pyny  awrygwn,Ла Пайн,Ла Пајн,لا باين,لا پینه، اورگن,لا پینی، اوریگون', 43.6704000, -121.5036400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145969, 'Lafayette', 'Lafayette', 'Lafajehtt,Lafajet,Lafejet,lafayt  awrgn,lafayyt,lafyt  awrygan,Лафайет,Лафайэтт,Лафејет,لافاييت,لافایت، اورگن,لافیت، اوریگان', 45.2442800, -123.1148300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145970, 'Lake Oswego', 'Lake Oswego', 'Lake Oswego,Lejk Osuego,Lejk Osvigo,Oswego,lyk aswgw  awrgn,lyk awswyghw,lyk awswygw  awrygan,reikuosuu~igo,Лейк Осуего,Лејк Освиго,ليك أوسويغو,لیک اسوگو، اورگن,لیک اوسویگو، اوریگان,レイクオスウィーゴ', 45.4206700, -122.6706500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145971, 'Lakeside', 'Lakeside', '', 43.5756700, -124.1751100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145972, 'Lakeview', 'Lakeview', 'LKV,Lakeview,Lakeview District Ranger Office,Lakeview District Ranger Station,Lehjkvju,Lejkvju,la ke fu you,lyk wyw  awrygan,lykfyw,lykwyw  awrgn,Лейквю,Лејквју,Лэйквю,ليكفيو,لیک ویو، اوریگان,لیکویو، اورگن,拉克夫由', 42.1887700, -120.3457900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145973, 'Lebanon', 'Lebanon', 'Lebanon,lai ba nen,lbnan,lbnan  awrgn,lebeoneon,Лебанон,لبنان,لبنان، اورگن,莱巴嫩,레버넌', 44.5365100, -122.9070300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145974, 'Lents', 'Lents', '', 45.4798400, -122.5673100, 'US', '2016-09-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145975, 'Lincoln Beach', 'Lincoln Beach', '', 44.8503900, -124.0467800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145976, 'Lincoln City', 'Lincoln City', 'Cutler City,De Lake,Lincoln,Lincoln City,Linkol''n Siti,Linkoln Siti,Linkuln Siti,Nelscott,Oceanlake,Taft,lynkln syty  awrgn,lynkwln syty,Линколн Сити,Линкольн Сити,Линкълн Сити,لينكولن سيتي,لینکلن سیتی، اورگن', 44.9581600, -124.0178900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145977, 'Lowell', 'Lowell', 'Louehll,Louel,Louul,lwl  awrgn,lwyl,Лоуел,Лоуъл,Лоуэлл,لول، اورگن,لويل', 43.9184600, -122.7836800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145978, 'Lyons', 'Lyons', '', 44.7745700, -122.6150900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145979, 'Madras', 'Madras', 'MDJ,Madras,madorasu,madras,mdras  awrygwn,mdrs  awrgn,Мадрас,مادراس,مدراس، اوریگون,مدرس، اورگن,マドラス', 44.6334500, -121.1294900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145980, 'McMinnville', 'McMinnville', 'Mak Minvill,Makminvil,maegminbil,mkmnwyl  awrygwn,mkmynwyl  awrgn,mykmynfyl,Мак Минвилл,Макминвил,ميكمينفيل,مکمنویل، اوریگون,مکمینویل، اورگن,맥민빌', 45.2101200, -123.1987200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145981, 'Medford', 'Medford', 'MFR,Medford,mdfwd  awrgn,mdpwrd,medeupeodeu,medofodo,mei de fu,mydfwrd,Медфорд,מדפורד,مدفود، اورگن,ميدفورد,میڈفورڈ، اوریگون,メドフォード,梅德福,메드퍼드', 42.3265200, -122.8755900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145982, 'Merlin', 'Merlin', 'Jump Off Joe,Merlin', 42.5173400, -123.4197900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145983, 'Metzger', 'Metzger', 'Metzgar,Metzger', 45.4465100, -122.7589900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145984, 'Mill City', 'Mill City', '', 44.7540100, -122.4781400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145985, 'Millersburg', 'Millersburg', 'Millers,Millersburg', 44.6809500, -123.0614800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145986, 'Milton-Freewater', 'Milton-Freewater', 'Freewater,Milton,Milton-Freewater,Milton-Friuateh,Milton-Frivoter,Miltun-Frijuotur,myltwn frywtr,Милтон-Фривотер,Милтон-Фриуатэ,Милтън-Фрийуотър,ميلتون فريوتر,میلتون‌فری واتر، اورگن', 45.9326300, -118.3877400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145987, 'Milwaukie', 'Milwaukie', 'Miluoki,Milvauki,Milvoki,Milvokis,Milwaukee,Milwaukee City,Milwaukie,mlwawky  awrygwn,mylwaky  awrgn,mylwawky,Милвауки,Милвоки,Милуоки,ملواوکی، اوریگون,ميلواوكي,میلواکی، اورگن', 45.4462300, -122.6392600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145988, 'Mission', 'Mission', 'Missija,Mission,Mission Station,Миссия', 45.6704100, -118.6835900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145989, 'Molalla', 'Molalla', 'Molalla,Mulala,mwlala,mwlyla  awrgn,Молалла,Мълала,مولالا,مولیلا، اورگن', 45.1473400, -122.5770300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145990, 'Monmouth', 'Monmouth', 'Monaus,Monmaut,Monmut,mnmwth  awrgn,mwnmwth,Монаус,Монмаут,Монмут,منموته، اورگن,مونماوتھ، اوریگون,مونموث', 44.8484500, -123.2339900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145991, 'Moro', 'Moro', 'Moro,Morou,mo luo,mrw  awrgn,mwrw,Моро,Мороу,مرو، اورگن,مورو,莫羅', 45.4840100, -120.7311700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145992, 'Mount Angel', 'Mount Angel', 'Fillmore,Frankfort,Maunt Ejndzel,Maunt Ejndzhul,Mirtl Ehjndzhehl,Mount Angel,Roy,angl  awrgn,mt anjl,Маунт Ейнджъл,Маунт Ејнџел,Миртл Эйнджэл,آنگل، اورگن,مت إنجل', 45.0679000, -122.8000900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145993, 'Mount Hood Village', 'Mount Hood Village', '', 45.3554000, -121.9806400, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145994, 'Mulino', 'Mulino', '', 45.2215100, -122.5820300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145995, 'Myrtle Creek', 'Myrtle Creek', 'Mirtl Krik,Murtul Krijk,myrtl kryk,myrtl kryk  awrgn,Миртл Крик,Мъртъл Крийк,ميرتل كريك,میرتل کریک، اورگن,میرٹل کریک، اوریگون', 43.0201200, -123.2931200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145996, 'Myrtle Point', 'Myrtle Point', '', 43.0648300, -124.1389900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145997, 'New Hope', 'New Hope', 'New Hope,Newhope', 42.3623400, -123.3678400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145998, 'Newberg', 'Newberg', 'N''juberg,Newberg,Njuberg,Njuburg,Nyuberq,Pacific College,nyubagu,nywbrg  awrgn,nywbrg  awrygwn,nywbyrgh,Њуберг,Ньюберг,Нюбърг,نيوبيرغ,نیوبرگ، اورگن,نیوبرگ، اوریگون,ニューバーグ', 45.3001200, -122.9731600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(145999, 'Newport', 'Newport', 'N''juport,Njuport,ONP,nyupoteu,nyupoto,nywbwrt,nywpwrt  awrgn,Њупорт,Ньюпорт,Нюпорт,نيوبورت,نیوپورت، اورگن,نیوپورٹ، اوریگون,ニューポート,뉴포트', 44.6367800, -124.0534500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146000, 'North Bend', 'North Bend', 'Nors Behnd,Nort Bend,OTH,Severen Bend,nwrt bnd  awrgn,nwrth bynd,Норс Бэнд,Норт Бенд,Северен Бенд,نورت بند، اورگن,نورث بيند', 43.4065000, -124.2242800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146001, 'North Plains', 'North Plains', 'Nors Plehjns,Nort Plejns,Severen Plejns,nosupurenzu,nrt plyns  awrgn,nwrth blynz,Норс Плэйнс,Норт Плејнс,Северен Плейнс,نرت پلینس، اورگن,نورث بلينز,ノースプレーンズ', 45.5970600, -122.9934400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146002, 'Nyssa', 'Nyssa', 'Nisa,Nissa,nysa,nysa  awrgn,Ниса,Нисса,نيسا,نیسا، اورگن', 43.8768300, -116.9948800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146003, 'Oak Grove', 'Oak Grove', '', 45.4167900, -122.6400900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146004, 'Oak Hills', 'Oak Hills', '', 45.5412300, -122.8412100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146005, 'Oakridge', 'Oakridge', 'Oak Ridge,Oakridge,Oakridzh,Oukridz,Oukridzh,akrydg  awrgn,awakrydj,Оакридж,Оукридж,Оукриџ,أواكريدج,اکریدگ، اورگن', 43.7465100, -122.4617200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146006, 'Odell', 'Odell', '', 45.6270600, -121.5431300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146007, 'Ontario', 'Ontario', 'ONO,Ontario,Ontário,antaryw  awrgn,awntaryw,Онтарио,أونتاريو,انتاریو، اورگن,اونٹاریو، اوریگون', 44.0265500, -116.9629400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146008, 'Oregon City', 'Oregon City', 'Oregon City,Oregon Siti,Oregón City,Thanh pho Oregon,Thành phố Oregon,Willamette,Willamette Falls,awrgn syty  awrgn,awryghwn syty,e lei gang cheng,oregonshiti,Орегон Сити,أوريغون سيتي,اورگن سیتی، اورگن,اوریگون سٹی، اوریگون,オレゴンシティ,俄勒冈城', 45.3573400, -122.6067600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146009, 'Pacific City', 'Pacific City', 'PFC', 45.2023300, -123.9628900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146010, 'Pendleton', 'Pendleton', 'PDT,Pehndlton,Pendleton,Pendlton,Pendultun,byndlyntwn,pndltn  awrgn,Пендлтон,Пендълтън,Пэндлтон,بيندلينتون,پندلتن، اورگن,پینڈلٹن، اوریگون', 45.6720700, -118.7886000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146011, 'Philomath', 'Philomath', 'Filomas,Filomat,firomasu,fylwmath,fylwmt  awrgn,Филомас,Филомат,فيلوماث,فیلومت، اورگن,フィロマス', 44.5401200, -123.3676000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146012, 'Phoenix', 'Phoenix', 'Finiks,Foeniks,fwnyks,fwnyks  awrgn,fynks  awrygwn,Финикс,Фоеникс,فونيكس,فونیکس، اورگن,فینکس، اوریگون', 42.2754100, -122.8180900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146013, 'Pilot Rock', 'Pilot Rock', '', 45.4831800, -118.8299800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146014, 'Port Orford', 'Port Orford', 'Ewing Harbor,Indian Bay,Port Oksford,Port Orford,Port Orford City,Port Orfurd,bwrt awrfwrd,pwrt arfrd  awrgn,Порт Оксфорд,Порт Орфорд,Порт Орфърд,بورت أورفورد,پورت ارفرد، اورگن', 42.7456600, -124.4973300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146015, 'Portland', 'Portland', 'Bridgetown,Gorad Portlend,P-town,PDX,Portland,Portland i Oregon,Portlandas,Portlandia,Portlando,Portlant,Portlend,Portlenda,Puddletown,Rip City,River City,Stumptown,The City of Roses,bo te lan,bwrtland  awryghwn,port land,portalainda,portalanda,portlant,portlendi,poteullaendeu,potorando,pwrtlnd,pwrtlnd  awrgn,Πόρτλαντ,Горад Портленд,Портланд,Портленд,Պորտլենդ,פורטלנד,بورتلاند، أوريغون,پورتلند، اورگن,पोर्टलंड,पोर्टलैंड,போர்ட்லன்ட்,పోర్ట్ లాండ్,ಪೋರ್ಟ್‌ಲ್ಯಾಂಡ್‌,พอร์ตแลนด์,პორტლენდი,ფორთლენდი,ポートランド,波特蘭,포틀랜드', 45.5234500, -122.6762100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146016, 'Prineville', 'Prineville', 'PRZ,Prajnvil,Prajnvill,brynfyly,prynwyl  awrgn,purainbiru,Прайнвил,Прайнвилл,برينفيلي,پرینویل، اورگن,プラインビル', 44.2998500, -120.8344700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146017, 'Rainier', 'Rainier', 'Eminence,Rainier,Rehjniehr,Rejnir,Rejniur,rynyr  awrgn,rynyyr,Рейниър,Рејнир,Рэйниэр,رينيير,رینیر، اورگن', 46.0890000, -122.9359400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146018, 'Raleigh Hills', 'Raleigh Hills', 'Raleigh,Raleigh Hills', 45.4806700, -122.7620400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146019, 'Redmond', 'Redmond', 'RDM,Redmond,Redmund,Rehdmond,rdmnd  awrgn,redomondo,rydmwnd,Редмонд,Редмънд,Рэдмонд,ردمند، اورگن,ريدموند,ریڈمنڈ، اوریگون,レドモンド', 44.2726200, -121.1739200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146020, 'Redwood', 'Redwood', '', 42.4220600, -123.3872800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146021, 'Reedsport', 'Reedsport', 'Ridsport,Rijdsport,rydasprt  awrgn,rydsbwrt,Ридспорт,Рийдспорт,ريدسبورت,ریداسپرت، اورگن', 43.7023400, -124.0967800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146022, 'Riddle', 'Riddle', 'Riddle,Riddles,Riddlesburg', 42.9509500, -123.3642300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146023, 'Rockcreek', 'Rockcreek', '', 45.5501200, -122.8770500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146024, 'Rockaway Beach', 'Rockaway Beach', 'City of Rockaway,Rockaway,Rockaway Beach', 45.6134400, -123.9429100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146025, 'Rogue River', 'Rogue River', 'Rogju Riveh,Rogue River,Roug River,Roug Rivur,Woodville,rgw rywr  awrgn,rwgh ryfr,Рогю Ривэ,Роуг Ривер,Роуг Ривър,روغ ريفر,رگو ریور، اورگن', 42.4359500, -123.1720000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146026, 'Rose Lodge', 'Rose Lodge', '', 45.0103900, -123.8803900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146027, 'Roseburg', 'Roseburg', 'RBG,Rosberg,Roseburg,Rousburg,Rouzburg,lojeubeogeu,luo si bao,rozubagu,rsbwrg  awrgn,rwzbrg  awrygwn,rwzbyrgh,Росберг,Роузбърг,Роусбург,رسبورگ، اورگن,روزبرگ، اوریگون,روزبيرغ,ローズバーグ,罗斯堡,로즈버그', 43.2165000, -123.3417400, 'US', '2017-04-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146028, 'Saint Helens', 'Saint Helens', 'Casenau,Houlton,Kasenau,Milton,Plymouth,Saint Helens', 45.8640000, -122.8064900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146029, 'Salem', 'Salem', 'Chemeketa,Gorad Sejlem,SLE,Salem,Salemas,Salems,Seilema,Sejlem,Sejlum,celam,sai lei mu,salema,salm,saylm,se lem,seilleom,seiramu,selama,selem,sylm  awrgan,sylm  awrygwn,syylm,Σάλεμ,Горад Сейлем,Салем,Сейлем,Сейлъм,Сејлем,Սալեմ,סיילם,سالم,سايلم,سیلم، اورگان,سیلم، اوریگون,सालेम,सेलम,सेलेम्,சேலம்,เซเลม,セイラム,塞勒姆,세일럼', 44.9429000, -123.0351000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146030, 'Sandy', 'Sandy', 'Sandi,Sehndi,Sendi,sandy,sndy  awrgn,Санди,Сенди,Сэнди,ساندي,سندی، اورگن,سینڈی، اوریگون', 45.3973400, -122.2614800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146031, 'Scappoose', 'Scappoose', 'Skappus,Skapus,skabws,skpws  awrgn,Скаппус,Скапус,سكابوس,سکپوس، اورگن', 45.7542800, -122.8776000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146032, 'Seaside', 'Seaside', 'Sijsajd,Sisajd,sysayd,sysayd  awrgn,Сийсайд,Сисайд,Сисајд,سيسايد,سیساید، اورگن', 45.9931600, -123.9226400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146033, 'Shady Cove', 'Shady Cove', '', 42.6106800, -122.8125400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146034, 'Sheridan', 'Sheridan', 'Shehridan,Sheridan,shrydn  awrgn,shyrydan,Шеридан,Шэридан,شریدن، اورگن,شيريدان', 45.0992800, -123.3948300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146035, 'Sherwood', 'Sherwood', 'Shehrvud,Shervud,Shurud,shrwwd  awrgn,shyrwwd,Шервуд,Шъруд,Шэрвуд,شروود، اورگن,شيروود', 45.3565100, -122.8401000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146036, 'Siletz', 'Siletz', '', 44.7217800, -123.9201100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146037, 'Silverton', 'Silverton', 'Sil''verton,Silverton,Silvurtun,sylwrtn  awrgn,Силвертон,Силвъртън,Сильвертон,سیلورتن، اورگن', 45.0051200, -122.7831500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146038, 'Sisters', 'Sisters', 'Sistehrs,Sistersvil,Sisturs,systrz,systrz  awrgn,Систерсвил,Систърс,Систэрс,سيسترز,سیسترز، اورگن', 44.2909500, -121.5492100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146039, 'South Lebanon', 'South Lebanon', '', 44.5062300, -122.9031400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146040, 'Springfield', 'Springfield', 'Springfijld,Springfild,aspyryng fyld  awrgn,sbrynghfyld,seupeulingpildeu,si pu lin fei er de,supuringufirudo,Спрингфийлд,Спрингфилд,Спрінгфілд,اسپیرینگ فیلد، اورگن,سبرينغفيلد,سپرنگفیلڈ، اوریگون,スプリングフィールド,斯普林菲尔德,스프링필드', 44.0462400, -123.0220300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146041, 'Stafford', 'Stafford', '', 45.3573400, -122.7225900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146042, 'Stanfield', 'Stanfield', 'Foster,Stanfield', 45.7804100, -119.2172400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146043, 'Stayton', 'Stayton', 'Stehjton,Stejton,Stejtun,astytn  awrgn,stytwn,Стейтън,Стејтон,Стэйтон,استیتن، اورگن,ستيتون', 44.8006800, -122.7945300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146044, 'Sublimity', 'Sublimity', '', 44.8295700, -122.7945300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146045, 'Sunriver', 'Sunriver', 'SUO,Sun River,Sunriver', 43.8840100, -121.4386400, 'US', '2013-06-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146046, 'Sutherlin', 'Sutherlin', 'Saterlin,Sazehrlin,Sudurlin,swthyrlyn,swtrlyn  awrgn,Сазэрлин,Сатерлин,Съдърлин,سوترلین، اورگن,سوثيرلين', 43.3901200, -123.3125800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146047, 'Sweet Home', 'Sweet Home', 'Buckhead,Suijt Khoum,Suit Khoum,Svit Khoum,Sweet Home,swyt hwm,swyyt hwm  awrgn,Свит Хоум,Суийт Хоум,Суит Хоум,سوئیت هوم، اورگن,سويت هوم', 44.3976200, -122.7362000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146048, 'Talent', 'Talent', 'Talehnt,Talent,Talunt,Tolent,Wagner,talynt,tlnt  awrgn,Талент,Талънт,Талэнт,تالينت,تلنت، اورگن', 42.2456800, -122.7886500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146049, 'Tangent', 'Tangent', '', 44.5412300, -123.1081500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146050, 'Terrebonne', 'Terrebonne', 'Hillman,Terrebonne', 44.3529000, -121.1778100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146051, 'The Dalles', 'The Dalles', 'City of The Dalles,City of the Dalles,DLS,Dalles,Dalles City,Dals,Dalz,Rockfort Camp,The Dalles,Wascopum,Win-quatt,Zeh Dallehs,dha dalys,dls  awrgn,Далз,Далс,Зэ Даллэс,دلس، اورگن,دی ڈالیز، اوریگون,ذا داليس', 45.5945600, -121.1786800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146052, 'Three Rivers', 'Three Rivers', '', 43.8201200, -121.4691900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146053, 'Tigard', 'Tigard', 'Tajgard,Tigard,Tigurd,tai ge de,taigado,taigeodeu,taygrd  awrgn,thi kard,tyghard,Тајгард,Тигард,Тигърд,تایگرد، اورگن,تيغارد,ٹائگرڈ، اوریگون,ไทการ์ด,タイガード,泰格德,타이거드', 45.4312300, -122.7714900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146054, 'Tillamook', 'Tillamook', 'Hoquarton,Lincoln,OTK,Tilamuk,Tillamook,Tillamook Landing,Tillamuk,tiramukku,tylamwk,tylmwk  awrgn,Тиламук,Тилламук,تيلاموك,تیلموک، اورگن,ٹیلاموک، اوریگون,ティラムック', 45.4564000, -123.8455300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146055, 'Toledo', 'Toledo', 'Toledo,Толедо', 44.6215100, -123.9384500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146056, 'Tri-City', 'Tri-City', '', 42.9845600, -123.3117300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146057, 'Troutdale', 'Troutdale', 'Sandy,TTD,Trautdejl,Troutdale,trawtdl,trwtdl  awrgn,Траутдейл,Траутдејл,تراوتدل,تروتدل، اورگن', 45.5392900, -122.3873100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146058, 'Tualatin', 'Tualatin', 'Bridgeport,Tualatin,Tualatun,Tualitin,Tualtin,te~yuaratin,twalatyn,twaltyn  awrgn,Туалатин,Туалатън,توالاتين,توالتین، اورگن,ٹوالاٹن، اوریگون,テュアラティン', 45.3840100, -122.7639900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146059, 'Turner', 'Turner', 'Terner,Turnehr,Turnur,trnr  awrgn,twrnr,Тернер,Турнэр,Търнър,ترنر، اورگن,تورنر', 44.8431800, -122.9528700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146060, 'Umatilla', 'Umatilla', 'Columbia,Jumatila,Umatilla,Umatilla City,Umatilla Landing,Unatilla,awmatyla,ywmtyla  awrgn,Јуматила,Уматилла,Юматила,أوماتيلا,یومتیلا، اورگن,یومیٹیلا، اوریگون', 45.9173500, -119.3425200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146061, 'Union', 'Union', 'Junion,Juniun,ywnyn  awrygwn,ywnywn,ywnywn  awrgn,Јунион,Юнион,Юниън,يونيون,یونین، اوریگون,یونیون، اورگن', 45.2084700, -117.8652100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146062, 'Vale', 'Vale', 'Vehjl,Vejl,fal,wei er,wl  awrgn,Вейл,Вејл,Вэйл,فال,ول، اورگن,韋爾', 43.9821100, -117.2382300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146063, 'Veneta', 'Veneta', '', 44.0487300, -123.3509300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146064, 'Vernonia', 'Vernonia', 'Vernonia,Vernonija,Vurnonija,fyrnwnya,wrnanya  awrgn,Вернониа,Вернонија,Върнония,فيرنونيا,ورنانیا، اورگن', 45.8587200, -123.1928900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146065, 'Waldport', 'Waldport', 'Uoldport,Voldport,waldbwrt,wldpwrt  awrgn,Волдпорт,Уолдпорт,والدبورت,ولدپورت، اورگن', 44.4267900, -124.0687300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146066, 'Warm Springs', 'Warm Springs', 'Warm Spring,Warm Springs,Warmspring,Warmsprings', 44.7634500, -121.2661600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146067, 'Warren', 'Warren', 'Gillton,Warren', 45.8190000, -122.8489900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146068, 'Warrenton', 'Warrenton', 'Uoruntun,Varrehnton,Vorenton,krswl  awrgn,waryntwn,Варрэнтон,Ворентон,Уорънтън,وارنٹن، اوریگون,وارينتون,کرسول، اورگن', 46.1651000, -123.9237600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146069, 'West Haven', 'West Haven', '', 45.5176200, -122.7695400, 'US', '2016-09-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146070, 'West Linn', 'West Linn', 'Linn City,Robins Nest,Vehst Linn,Vest Lin,West Linn,Zapaden Lin,u~esutorin,wst lyn  awrgn,wyst lyn,Вест Лин,Вэст Линн,Западен Лин,وست لین، اورگن,ويست لين,ویسٹ لین، اوریگون,ウェストリン', 45.3656800, -122.6123100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146071, 'West Slope', 'West Slope', '', 45.4987300, -122.7645400, 'US', '2016-09-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146072, 'White City', 'White City', 'Camp White,White City', 42.4373500, -122.8589300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146073, 'Willamina', 'Willamina', 'Uilamina,Vilamina,Villamina,wylamyna,wylmyna  awrgn,Виламина,Вилламина,Уиламина,ويلامينا,ویلمینا، اورگن', 45.0787300, -123.4859400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146074, 'Williams', 'Williams', '', 42.2187300, -123.2739400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146075, 'Wilsonville', 'Wilsonville', 'Uilsunvil,Vilsonvil,Vilsonvill,wylsnwyl  awrgn,wylsnwyl  awrygwn,wylswnfyl,Вилсонвил,Вилсонвилл,Уилсънвил,ويلسونفيل,ویلسنویل، اورگن,ویلسنویل، اوریگون', 45.2998400, -122.7737100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146076, 'Winston', 'Winston', '', 43.1223400, -123.4125700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146077, 'Wood Village', 'Wood Village', 'Ud Vilidzh,Vud Vilidz,Vud Villadzh,wwd fylyj,wwd wylyj  awrgn,Вуд Вилиџ,Вуд Вилладж,Уд Вилидж,وود فيليج,وود ویلیج، اورگن', 45.5342900, -122.4187000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146078, 'Woodburn', 'Woodburn', 'Udburn,Vudbern,Vudbjorn,Vudburn,wwdbwrn,wwdbwrn  awrgn,Вудберн,Вудбурн,Вудбёрн,Удбърн,وودبورن,وودبورن، اورگن,ووڈبرن، اوریگون', 45.1437300, -122.8553700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146079, 'Yamhill', 'Yamhill', 'North Yamhill,Yamhill', 45.3415000, -123.1873300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146080, 'Yoncalla', 'Yoncalla', '', 43.5984500, -123.2834200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146081, 'Belle Fourche', 'Belle Fourche', 'Bel Fush,Belle Fourche,De Mores,bei er fu shen,bela forsa,bl fwrshy  dakwtay jnwby,Бел Фуш,بل فورشی، داکوتای جنوبی,बॅल फ़ोर्श,贝尔富什', 44.6713700, -103.8521500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146082, 'Bison', 'Bison', '', 45.5202600, -102.4612700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146083, 'Blackhawk', 'Blackhawk', 'Black Hawk,Blackhawk', 44.1511000, -103.3079600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146084, 'Box Elder', 'Box Elder', 'Box Elder,Boxelder', 44.1124900, -103.0682300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146085, 'Buffalo', 'Buffalo', 'Buffalo,Буффало', 45.5841600, -103.5460300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146086, 'Colonial Pine Hills', 'Colonial Pine Hills', '', 44.0077700, -103.3154600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146087, 'Custer', 'Custer', 'Camp Collins,Custer,Custer City,Kaster,Stonewall,ka si te,kastara,kastr  dakwtay jnwby,kstr,Кастер,كستر,کاستر، داکوتای جنوبی,کیسٹر، جنوبی ڈکوٹا,कस्टर,卡斯特', 43.7666500, -103.5988100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146088, 'Deadwood', 'Deadwood', 'Deadwood,Deadwood City,Dedvud,Miles City,dai de wu de,ddwwd  dakwtay jnwby,dedavuda,deddouddo,dydwwd,Дедвуд,ددوود، داکوتای جنوبی,ديدوود,ڈیڈووڈ، جنوبی ڈکوٹا,डॅडवुड,デッドウッド,戴德伍德', 44.3766500, -103.7296400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146089, 'Dupree', 'Dupree', '', 45.0474800, -101.6009900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146090, 'Eagle Butte', 'Eagle Butte', '', 45.0024800, -101.2334900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146091, 'Fort Pierre', 'Fort Pierre', 'Fort Pir,bao pi ai er,forta piyara,frt pyr  dakwtay jnwby,fwrt byyr,Форт Пир,فرت پیر، داکوتای جنوبی,فورت بيير,فورٹ پیری، جنوبی ڈکوٹا,फ़ोर्ट पियर,堡皮埃尔', 44.3535900, -100.3737400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146092, 'Hot Springs', 'Hot Springs', 'Hot Springs,Khot Springs,Khot-Springs,Minne-Ka-Tah,Minne-Kahta,hat aspryngz  dakwtay jnwby,hota springsa,re quan,Хот Спрингс,Хот-Спрингс,هات اسپرینگز، داکوتای جنوبی,हॉट स्प्रिंग्स,热泉', 43.4316500, -103.4743600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146093, 'Kadoka', 'Kadoka', '', 43.8338800, -101.5098700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146094, 'Lead', 'Lead', 'Lead,Lead City,Lid,Mile High City,Washington,lai de,lyd,lyd  dakwtay jnwby,Лид,ليد,لید، داکوتای جنوبی,لیڈ، جنوبی ڈکوٹا,莱德', 44.3522100, -103.7652000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146095, 'Lemmon', 'Lemmon', 'LEM', 45.9408300, -102.1593200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146096, 'Martin', 'Martin', '', 43.1725000, -101.7326500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146097, 'McIntosh', 'McIntosh', '', 45.9213900, -101.3495800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146098, 'Mission', 'Mission', 'Missija,Миссия', 43.3058400, -100.6581900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146099, 'Mobridge', 'Mobridge', 'Heigstadt,MBG,Mobridge', 45.5372200, -100.4279100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146100, 'Mound City', 'Mound City', '', 45.7252700, -100.0684500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146101, 'Murdo', 'Murdo', 'Merdo,mo duo,murdo,mwrdw,mwrdw  dakwtay jnwby,Мердо,موردو,موردو، داکوتای جنوبی,मुर्डो,默多', 43.8883200, -100.7129100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146102, 'North Eagle Butte', 'North Eagle Butte', '', 45.0041500, -101.2337600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146103, 'North Spearfish', 'North Spearfish', '', 44.5066500, -103.8921500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146104, 'Oglala', 'Oglala', '', 43.1885900, -102.7396200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146105, 'Onida', 'Onida', 'Onajda,ao nai da,awnyda,awnyda  dakwtay jnwby,onida,Онајда,أونيدا,اونیدا، داکوتای جنوبی,ओनिडा,奥奈达', 44.7080400, -100.0598400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146106, 'Philip', 'Philip', 'PHP', 44.0394300, -101.6651400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146107, 'Pierre', 'Pierre', 'Gorad Pir,Mato,PIR,Pier,Pierre,Pir,Pira,Piras,Pirr,Pirs,Pjer,Pīra,byyr,pi er,pia,pieo,piyara,piyer,piyera,piyere,pyr,pyr  dakwtay jnwby,Πιερ,Горад Пір,Пиер,Пир,Пирр,Пірр,Пјер,Պիեռ,פיר,بيير,پیر، داکوتای جنوبی,پیر،ساؤتھ ڈیکوٹا,پیری، جنوبی ڈکوٹا,पियर,पियेर,पियेरे,पियेर्,பியேர்,ピア,皮尔,피어', 44.3683200, -100.3509700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146108, 'Pine Ridge', 'Pine Ridge', 'Pine Ridge,Pine Ridge Agency,XPR', 43.0255400, -102.5562700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146109, 'Porcupine', 'Porcupine', '', 43.2397100, -102.3309900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146110, 'Rapid City', 'Rapid City', 'Haeohemahpe,Hay Camp,Háeohémahpe,RAP,Rapid,Rapid City,Rapid Siti,Rapid-Siti,la pi de cheng,laepideusiti,rabyd syty,raipida siti,rapiddoshiti,rpyd syty  dakwtay jnwby,Рапид Сити,Рапид-Сити,Рапід-Сіті,رابيد سيتي,رپید سیتی، داکوتای جنوبی,ریپڈ سٹی، جنوبی ڈکوٹا,रैपिड सिटी,แรพิดซิตี,ラピッドシティ,拉皮德城,래피드시티', 44.0805400, -103.2310100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146111, 'Rapid Valley', 'Rapid Valley', '', 44.0624900, -103.1462900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146112, 'Rosebud', 'Rosebud', '', 43.2327800, -100.8534800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146113, 'Selby', 'Selby', '', 45.5063800, -100.0320700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146114, 'Spearfish', 'Spearfish', 'SPF,Spirfish,aspyrfysh  dakwtay jnwby,sbyrfysh,si pi er fei shen,spiyarafisa,Спирфиш,اسپیرفیش، داکوتای جنوبی,سبيرفيش,سپئیرفش، جنوبی ڈکوٹا,स्पियरफ़िश,斯皮尔菲什', 44.4908200, -103.8593700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146115, 'Sturgis', 'Sturgis', 'Scooptown,Sterdzhis,Sterdzis,Sturgis,astrjys  dakwtay jnwby,si te ji si,sturjisa,stwrjys,sutajisu,Стерджис,Стерџис,استرجیس، داکوتای جنوبی,ستورجيس,سٹورجس، جنوبی ڈکوٹا,स्टुर्जिस,スタージス,斯特吉斯', 44.4097100, -103.5090800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146116, 'Timber Lake', 'Timber Lake', '', 45.4291500, -101.0740300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146117, 'White River', 'White River', '', 43.5680500, -100.7454200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146118, 'Alpine', 'Alpine', 'Alpajn,Alpine,Alpine City,Mountainville,a er pai,albayn,alpayn  ywta,Алпайн,Алпајн,آلپاین، یوتا,ألباين,阿尔派', 40.4532800, -111.7779900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146119, 'Ballard', 'Ballard', '', 40.2894000, -109.9432000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146120, 'Benjamin', 'Benjamin', '', 40.0982900, -111.7313200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146121, 'Benson', 'Benson', '', 41.7874300, -111.9302200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146122, 'Bluffdale', 'Bluffdale', 'Blafdejl,Blufdejl,blafdl  ywta,blwfdyl,bu la fu dai er,Блафдејл,Блъфдейл,بلافدل، یوتا,بلوفديل,布拉夫戴尔', 40.4896700, -111.9388200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146123, 'Bountiful', 'Bountiful', 'BTF,Bauntiful,Bountiful,Sessions Settlement,bang di fu er,bwntyfwl,bwntyfwl  ywta,Баунтифул,Баунтифъл,بونتيفول,بونتیفول، یوتا,بونٹیفل، یوٹاہ,邦蒂富尔', 40.8893900, -111.8807700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146124, 'Brigham City', 'Brigham City', 'BMC,Box Elder,Brigam Siti,Brigham,Brigham City,bryghham syty,bryghm syty  ywta,bu li ge mu cheng,Бригам Сити,بريغهام سيتي,بریگهم سیتی، یوتا,布里格姆城', 41.5102100, -112.0155000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146125, 'Canyon Rim', 'Canyon Rim', '', 40.7066100, -111.8218800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146126, 'Cedar Hills', 'Cedar Hills', '', 40.4141200, -111.7585400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146127, 'Centerfield', 'Centerfield', '', 40.6913400, -111.8979900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146128, 'Centerville', 'Centerville', 'Sentervil,Senturvil,sen te wei er,sntrfyl,sntrwyl  ywta,Сентервил,Сентървил,سنترفيل,سنترویل، یوتا,سینٹرویل، یوٹاہ,森特维尔', 40.9180000, -111.8721600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146129, 'Clearfield', 'Clearfield', 'Klirfild,Kliurfijld,ke li er fei er,klyrfyld,klyrfyld  ywta,Клирфилд,Клиърфийлд,كليرفيلد,کلیئرفیلڈ، یوٹاہ,کلیرفیلد، یوتا,克利尔菲尔', 41.1107800, -112.0260500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146130, 'Clinton', 'Clinton', 'Clinton,Klinton,Summit,Клинтон', 41.1396700, -112.0505000, 'US', '2017-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146131, 'Coalville', 'Coalville', 'Koulvil,ke wei er,kwlfyl,kwlwyl  ywta,Коулвил,كولفيل,کولویل، یوتا,科维尔', 40.9177300, -111.3993600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146132, 'Cottonwood Heights', 'Cottonwood Heights', 'Butlerville,Cottonwood Heights,Konutnud Khajts,Kotonvud Khajts,ka dun gao de,kwtnwwd hayts,Конътнуд Хайтс,Котонвуд Хајтс,كوتنوود هايتس,کاتن‌وود هایتس، یوتا,کاٹنووڈ ہائٹس، یوٹاہ,卡顿高地', 40.6196700, -111.8102100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146133, 'Daniel', 'Daniel', 'Buysville,Daniel,Daniels,Danielsville', 40.4707900, -111.4146300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146134, 'Draper', 'Draper', 'Draper,Drejper,Drejpur,South Willow Creek,de lei po,deuleipeo,drabr,drapr  ywta,Дрейпър,Дрејпер,درابر,دراپر، یوتا,ڈریپر، یوٹاہ,德雷珀,드레이퍼', 40.5246700, -111.8638200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146135, 'Duchesne', 'Duchesne', 'Dora,Duchesne,Dukejn,Dushejn,Theodore,dachsn  ywta,du shen,dwtshysn,Дукејн,Душейн,داچسن، یوتا,دوتشيسن,杜申', 40.1632900, -110.4029300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146136, 'Eagle Mountain', 'Eagle Mountain', '', 40.3141200, -112.0068800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146137, 'East Millcreek', 'East Millcreek', '', 40.6999500, -111.8104900, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146138, 'Elk Ridge', 'Elk Ridge', '', 40.0113400, -111.6768700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146139, 'Elwood', 'Elwood', '', 41.6904800, -112.1410600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146140, 'Erda', 'Erda', '', 40.6127200, -112.3043900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146141, 'Farmington', 'Farmington', 'Farmington,Farmingtun,Millers Settlement,fa ming dun,farmnghtwn,farmyngtwn  ywta,Фармингтон,Фармингтън,فارمنغتون,فارمنگٹن، یوٹاہ,فارمینگتون، یوتا,法明顿', 40.9805000, -111.8874400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146142, 'Farr West', 'Farr West', 'Farr West,West Harrisville', 41.2971700, -112.0277200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146143, 'Francis', 'Francis', '', 40.6105100, -111.2807400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146144, 'Fruit Heights', 'Fruit Heights', '', 41.0321700, -111.9021600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146145, 'Garland', 'Garland', 'Garland,Girljanda,garlnd  ywta,gharland,jia lan,Гарланд,Гирлянда,غارلاند,گارلند، یوتا,گارلینڈ، یوٹاہ,加兰', 41.7410400, -112.1616200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146146, 'Granite', 'Granite', 'Granite,Granite City', 40.5730000, -111.8060400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146147, 'Grantsville', 'Grantsville', 'Grantsvil,Grantsville,Grantsville City,Grantville,Twenty Wells,Willow Creek,ge lan ci wei er,ghrantsfyl,grntswyl  ywta,Грантсвил,غرانتسفيل,گرنتسویل، یوتا,格兰茨维尔', 40.5999400, -112.4644000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146148, 'Harrisville', 'Harrisville', '', 41.2813300, -111.9882800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146149, 'Heber City', 'Heber City', 'Heber', 40.5069000, -111.4132400, 'US', '2016-08-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146150, 'Herriman', 'Herriman', 'Heriman,Herriman,Kheriman,he er rui mu an,hrymn  ywta,hyryman,Хериман,هریمن، یوتا,هيريمان,赫尔瑞姆安', 40.5141100, -112.0329900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146151, 'Highland', 'Highland', 'Khajland,hai lan,hayland,haylnd  ywta,Хайланд,Хајланд,هايلاند,هایلند، یوتا,海兰', 40.4254800, -111.7944700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146152, 'Holladay', 'Holladay', 'Kholadej,huo la di,hwladay,Холадей,Холадеј,هال‌لیدی,هولاداي,ہولاڈے، یوٹاہ,霍拉迪', 40.6688400, -111.8246600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146153, 'Honeyville', 'Honeyville', '', 41.6385400, -112.0793900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146154, 'Hooper', 'Hooper', 'Hooper,Muskrat', 41.1638300, -112.1224400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146155, 'Hyde Park', 'Hyde Park', 'Hyde Park,Hydepark', 41.7988200, -111.8191100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146156, 'Hyrum', 'Hyrum', 'Khajrum,hai lun,hyrwm,hyrywm  ywta,Хайръм,هيروم,هیریوم، یوتا,海仑', 41.6341000, -111.8521700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146157, 'Kamas', 'Kamas', 'Kamas,ka mo si,kamas,kamas  ywta,Камас,كاماس,کاماس، یوتا,卡默斯', 40.6430100, -111.2807400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146158, 'Kaysville', 'Kaysville', 'Kays Creek,Kaysville,Kejsvil,Maysville,kai si wei er,kaysfyl,kayzwyl  ywta,Кейсвил,Кејсвил,كايسفيل,کایزویل، یوتا,کیئزویل، یوٹاہ,凯斯维尔', 41.0352200, -111.9385500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146159, 'Kearns', 'Kearns', 'Kerns,Кернс', 40.6599500, -111.9963300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146160, 'Layton', 'Layton', 'Layton,Lejton,Lejtun,laytwn,lei dun,leiteon,lytwn  ywta,Лейтон,Лейтън,Лејтон,لايتون,لیتون، یوتا,لیٹن، یوٹاہ,雷顿,레이턴', 41.0602200, -111.9710500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146161, 'Lehi', 'Lehi', 'Lehi,Lehi City,Lehi Junction,Lekhe,Likhaj,lhy  ywta,li hai,lyhy,Лехе,Лихай,لحی، یوتا,ليهي,لیہائی، یوٹاہ,李海', 40.3916200, -111.8507700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146162, 'Lewiston', 'Lewiston', 'Cub Hill,L''juiston,Lewiston,Льюистон', 41.9757600, -111.8563400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146163, 'Liberty', 'Liberty', '', 41.3335500, -111.8635500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146164, 'Lindon', 'Lindon', 'Lindon,Lindun,lin dun,lyndwn,lyndwn  ywta,Линдон,Линдън,ليندون,لیندون، یوتا,林顿', 40.3432900, -111.7207600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146165, 'Logan', 'Logan', 'LGU,Logan,Lougan,luo gen,lwgan  ywta,lwghan,rogan,Логан,Лоуган,لوغان,لوگان، یوتا,لوگن، یوٹاہ,ローガン,洛根', 41.7354900, -111.8343900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146166, 'Maeser', 'Maeser', 'Maeser,Measer,Mill Ward', 40.4771800, -109.5868100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146167, 'Magna', 'Magna', 'Magna,Магна', 40.7091100, -112.1016100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146168, 'Manila', 'Manila', 'Chambers,Lewisallen,Manila,ma ni la,manyl  ywta,manyla,Манила,مانيلا,مانیل، یوتا,马尼拉', 40.9880100, -109.7226500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146169, 'Mapleton', 'Mapleton', '', 40.1302300, -111.5785300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146170, 'Marriott-Slaterville', 'Marriott-Slaterville', 'Marriott,Marriott-Slaterville,Slaterville', 41.2516100, -112.0255000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146171, 'Mendon', 'Mendon', 'Mendon,Mendun,men dui,mndwn,mndwn  ywta,Мендон,Мендън,مندون,مندون، یوتا,门敦', 41.7099300, -111.9777300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146172, 'Midvale', 'Midvale', 'Bingham Junction,East Jordan,Midvale,Midvejl,mi de wa er,mydfal,mydwyl  ywta,Мидвейл,Мидвејл,ميدفال,مڈویل، یوٹاہ,میدویل، یوتا,米德瓦尔', 40.6110600, -111.8999400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146173, 'Midway', 'Midway', 'Miduej,Midvej,mi de wei,mydwy,mydwy  ywta,Мидвеј,Мидуей,ميدوي,میدوی، یوتا,米德韦', 40.5121800, -111.4743500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146174, 'Millcreek', 'Millcreek', 'Milkrik,Милкрик,میل‌کریک، یوتا', 40.6868900, -111.8754900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146175, 'Millville', 'Millville', '', 41.6816000, -111.8230000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146176, 'Morgan', 'Morgan', 'Morgan,Morgan City,Weber,Weber Station,mo gen,mwrgan  ywta,mwrghan,Морган,مورغان,مورگان، یوتا,摩根', 41.0360600, -111.6768800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146177, 'Mount Olympus', 'Mount Olympus', '', 40.6855000, -111.7885400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146178, 'Mountain Green', 'Mountain Green', '', 41.1430000, -111.7916000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146179, 'Murray', 'Murray', 'Mari,Mjurrej,Muri,mu lei,mwray,mwray  ywta,Мари,Мъри,Мюррей,مرے، یوٹاہ,موراي,مورای، یوتا,穆雷', 40.6668900, -111.8879900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146180, 'Naples', 'Naples', 'Merrill,Naples,Neapol'',Неаполь', 40.4269100, -109.4993000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146181, 'Nibley', 'Nibley', 'Nibli,ni bu li,nybly,nybly  ywta,Нибли,نيبلي,نیبلی، یوتا,尼布利', 41.6743800, -111.8330000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146182, 'North Logan', 'North Logan', '', 41.7693700, -111.8046700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146183, 'North Ogden', 'North Ogden', 'Nort Ogden,Severen Ogdun,awjn shmaly  ywta,nwrth awghdn,Норт Огден,Северен Огдън,اوجن شمالی، یوتا,نورث أوغدن', 41.3071600, -111.9602200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146184, 'North Salt Lake', 'North Salt Lake', 'Nort Solt Lejk,North,North Salt Lake,Severen Solt Lejk,bei yan hu cheng,nwrth swlt lyk,salt lyk shmaly  ywta,Норт Солт Лејк,Северен Солт Лейк,سالت لیک شمالی، یوتا,نورث سولت ليك,北盐湖城', 40.8485600, -111.9068800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146185, 'Oakley', 'Oakley', 'Oukli,ao ke li,awkly,awkly  ywta,Оукли,أوكلي,اوکلی، یوتا,奥克利', 40.7146700, -111.3007400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146186, 'Ogden', 'Ogden', 'Brownsville,Fort Buenaventura,Lynne,OGD,Ogden,Ogden City,Ogdun,ao ge deng,awdn  ywta,awghdn,ogeudeon,oguden,Огден,Огдън,Оґден,آگڈین، یوٹاہ,أوغدن,اودن، یوتا,オグデン,奥格登,오그던', 41.2230000, -111.9738300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146187, 'Oquirrh', 'Oquirrh', '', 40.6305000, -112.0338300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146188, 'Orem', 'Orem', 'Orem,Oremas,Orum,ao lei mu,awrym,awrym  ywta,oremu,Орем,Оръм,أوريم,اورم، یوٹاہ,اوریم، یوتا,オレム,奥勒姆', 40.2969000, -111.6946500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146189, 'Park City', 'Park City', 'Park City,Park Siti,Park-Siti,bark syty,pa ke cheng,pakeusiti,pakushiti,park syty  ywta,Парк Сити,Парк-Сити,Парк-Сіті,بارك سيتي,پارک سیتی، یوتا,パークシティ,帕克城,파크시티', 40.6460600, -111.4979700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146190, 'Payson', 'Payson', 'Pejson,Pejsun,bayswn,cha mao sheng,peiseun,pyswn  ywta,pyyswn,Пейсън,Пејсон,פייסון,بايسون,پیسون، یوتا,查懋声,페이슨', 40.0444000, -111.7321500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146191, 'Perry', 'Perry', '', 41.4649400, -112.0324500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146192, 'Plain City', 'Plain City', '', 41.2980000, -112.0860500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146193, 'Pleasant Grove', 'Pleasant Grove', 'Battle Creek,Pleasant Grove,Pleasantgrove,Plezant Grouv,blyzant ghrwf,plznt grww  ywta,pu lai sen te ge luo fu,Плезант Гроув,بليزانت غروف,پلزنت گروو، یوتا,پلیزینٹ گروو، یوٹاہ,普莱森特格罗夫', 40.3641200, -111.7385400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146194, 'Pleasant View', 'Pleasant View', 'Plezant Vju,Plezent Vju,blyzant fyw,plznt wyw  ywta,pu lai sen te wei you,Плезант Вю,Плезент Вју,بليزانت فيو,پلزنت ویو، یوتا,普莱森特维尤', 41.3182800, -111.9921600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146195, 'Providence', 'Providence', 'Providence,Providens,Providuns,Spring Creek,brwfydans,prawydns  ywta,pu luo wei deng si,Провиденс,Провидънс,بروفيدانس,پراویدنس، یوتا,پروویڈنس، یوٹاہ,普罗维登斯', 41.7063200, -111.8171700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146196, 'Provo', 'Provo', 'Fort Utah,PVU,Provas,Provo,Provo City,Provou,brwfw,peulobo,prwbw,prwww,prwww  ywta,pu ruo fu,purobo,Прово,Провоу,פרובו,بروفو,پرووو,پرووو، یوتا,پرووو، یوٹاہ,プロボ,普若佛,프로보', 40.2338400, -111.6585300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146197, 'Randolph', 'Randolph', 'Randol''f,Randolf,Randulf,lan duo fu,randwlf,randwlf  ywta,Рандолф,Рандольф,Рандълф,راندولف,راندولف، یوتا,رینڈولف، یوٹاہ,兰多夫', 41.6657800, -111.1821400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146198, 'Richmond', 'Richmond', 'Redmond,Richmond,Richmund,li shi man,rychmwnd  ywta,rytshmwnd,Ричмонд,Ричмънд,ريتشموند,رچمنڈ، یوٹاہ,ریچموند، یوتا,里士满', 41.9227100, -111.8135600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146199, 'River Heights', 'River Heights', '', 41.7216000, -111.8213300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146200, 'Riverdale', 'Riverdale', 'Riverdejl,Rivurdejl,he gu,ryfrdyl,rywrdyl  ywta,Ривердејл,Ривърдейл,ريفرديل,ریوردیل، یوتا,河谷', 41.1768900, -112.0038300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146201, 'Riverton', 'Riverton', 'Riverton,Rivurtun,li fu dun,ryfrtwn,rywrtwn  ywta,Ривертон,Ривъртън,ريفرتون,ریورتون، یوتا,ریورٹن، یوٹاہ,里弗顿', 40.5218900, -111.9391000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146202, 'Roosevelt', 'Roosevelt', 'ROL,Roosevelt,Rouzvelt,Ruzvelt,luo si fu,rwzflt,rwzwlt  ywta,Роузвелт,Рузвелт,روزفلت,روزولت، یوتا,罗斯福', 40.2994000, -109.9887600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146203, 'Roy', 'Roy', 'Roj,luo yi,rwy,rwy  ywta,Рой,Рој,روئے، یوٹاہ,روي,روی، یوتا,罗伊', 41.1616100, -112.0263300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146204, 'Salt Lake City', 'Salt Lake City', 'Cathair Salt Lake,Civitas Lacus Salsi,Gorad Solt-Lehjk-Sici,Kota Salt Lake,Lungsod ng Salt Lake,SLC,Sallaga Urbo,Salt Lake,Salt Lake Ceety,Salt Lake City,Sol Lek Siti,Solt Leik Sites,Solt Leik Siti,Solt Leik Sitis,Solt Leik Sitės,Solt Lejk Siti,Solt Leyk Siti,Solt-Lejk-Siti,Soltleiksitija,Thanh pho Salt Lake,Thành phố Salt Lake,calt lek nakaram,salata leka siti,salt lek siti,salt lyk,salt lyk syty,salta leka siti,solta leka siti,solteuleikeusiti,sorutoreikushiti,swlt lyyq syty,sxltleksiti,yan hu cheng,Σολτ Λέικ Σίτι,Горад Солт-Лэйк-Сіці,Солт Лейк Сити,Солт Лејк Сити,Солт-Лейк-Сити,Солт-Лейк-Сіті,Սոլթ Լեյք Սիթի,סולט לייק סיטי,سالت ليك,سالت لیک سیتی,سالت‌لیک‌سیتی,سالٹ لیک سٹی,سالٹ لیک سٹی، یوٹاہ,साल्ट लेक सिटी,साल्ट् लेक् सिटी,सॉल्ट लेक सिटी,ਸਾਲਟ ਲੇਕ ਸਿਟੀ,சால்ட் லேக் நகரம்,ಸಾಲ್ಟ್ ಲೇಕ್ ಸಿಟಿ,ซอลต์เลกซิตี,ཚྭ་མཚོའི་གྲོང་ཁྱེར།,სოლტ-ლეიკ-სიტი,ソルトレイクシティ,盐湖城,鹽湖城,솔트레이크시티', 40.7607800, -111.8910500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146205, 'Sandy', 'Sandy', 'Sandy,Sandy City', 40.5916100, -111.8841000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146206, 'Sandy Hills', 'Sandy Hills', '', 40.5810600, -111.8507700, 'US', '2010-09-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146207, 'Saratoga Springs', 'Saratoga Springs', 'Saratoga Springs,Saratoga-Springs,sa la tuo jia wen quan,saratwga aspryngz  ywta,saratwgha sbrynghz,Саратога Спрингс,Саратога-Спрингс,ساراتوغا سبرينغز,ساراتوگا اسپرینگز، یوتا,萨拉托加温泉', 40.3491200, -111.9046600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146208, 'Smithfield', 'Smithfield', 'Smitfijld,Smitfild,shi mi si fei er de,smythfyld,Смитфийлд,Смитфилд,اسمیت‌فیلد، یوتا,سمتھفیلڈ، یوٹاہ,سميثفيلد,史密斯菲尔德', 41.8382600, -111.8327200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146209, 'Snyderville', 'Snyderville', '', 40.6943900, -111.5438100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146210, 'South Jordan Heights', 'South Jordan Heights', '', 40.5638400, -111.9493800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146211, 'South Jordan', 'South Jordan', 'Juzhen Dzhordan,Saut DZordan,Saut-Dzhordan,jwrdn aljnwbyt,nan qiao dan,sawt jrdn  ywta,Саут Џордан,Саут-Джордан,Южен Джордан,جوردن الجنوبية,ساوت جردن، یوتا,ساوتھ جورڈن، یوٹاہ,南乔丹', 40.5621700, -111.9296600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146212, 'South Ogden', 'South Ogden', 'Saut Ogden,Saut Ogdun,Saut-Ogden,South Ogden,burch creek,jnwb awghdn,nan ao ge deng,sawt awdn  ywta,Саут Огден,Саут Огдън,Саут-Огден,Саут-Оґден,جنوب أوغدن,ساوت اودن، یوتا,南奥格登', 41.1918900, -111.9713300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146213, 'South Salt Lake', 'South Salt Lake', 'Centrral Park,Juzhen Solt Lejk,Saut Solt Lejk,South Salt Lake,nan yan hu cheng,sawt salt lyk  ywta,Саут Солт Лејк,Южен Солт Лейк,ساوت سالت لیک، یوتا,ساوتھ سالٹ لیک، یوٹاہ,南盐湖城', 40.7188400, -111.8882700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146214, 'South Weber', 'South Weber', 'Juzhen Uebur,Morristown,Saut Viber,South Weber,nan wei bo,sawt wbr  ywta,sawth wybr,Саут Вибер,Южен Уебър,ساوت وبر، یوتا,ساوث ويبر,南韦伯', 41.1324400, -111.9302200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146215, 'South Willard', 'South Willard', '', 41.3632700, -112.0357800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146216, 'Spanish Fork', 'Spanish Fork', 'Spanish Fork,Spanish Fork City,aspnysh fwrk  ywta,sbanysh fwrk,xi ban ya fu ke,Спаниш Форк,اسپنیش فورک، یوتا,سبانيش فورك,سپینش فورک، یوٹاہ,西班牙福克', 40.1149600, -111.6549200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146217, 'Springville', 'Springville', 'Springvil,aspryngwyl  ywta,sbrynghfyl,shi pu lin wei er,Спрингвил,اسپرینگویل، یوتا,سبرينغفيل,سپرنگزویل، یوٹاہ,史普林维尔', 40.1652300, -111.6107500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146218, 'Stansbury park', 'Stansbury park', 'Stansbury,Stansbury Park,Stansbury park', 40.6377200, -112.2960600, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146219, 'Summit Park', 'Summit Park', '', 40.7457800, -111.6115900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146220, 'Sunset', 'Sunset', '', 41.1363300, -112.0310500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146221, 'Syracuse', 'Syracuse', 'Sirakjus,Sirakjuz,Syracusae,syrakywz,syrakywz  ywta,xi lei jiu si,Сиракюз,Сиракјус,سيراكيوز,سیراکیوز، یوتا,西勒鸠斯', 41.0893900, -112.0646700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146222, 'Taylorsville', 'Taylorsville', 'Tejlorsvil,Tejlorsvil'',Tejlorsvill,Tejlursvil,tai lei si wei er,taylwrzfyl,teilleoseubil,tylwrzwyl  ywta,Тейлорсвилл,Тейлорсвіль,Тейлърсвил,Тејлорсвил,تايلورزفيل,تیلورزویل، یوتا,ٹیلرزویل، یوٹاہ,泰勒斯维尔,테일러스빌', 40.6677200, -111.9388300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146223, 'Tooele', 'Tooele', 'Tooele,Tooelle,Tuele,Tuilu,tu ai lei,twyl  ywta,twyly,Туеле,Туилъ,توئل، یوتا,تويلي,ٹوئل، یوٹاہ,图埃勒', 40.5307800, -112.2982800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146224, 'Tremonton', 'Tremonton', 'TRT,Tremonton,Trimuntun,te li meng dun,trmwntwn  ywta,trymwntwn,Тремонтон,Тримънтън,ترمونتون، یوتا,تريمونتون,特里蒙顿', 41.7118700, -112.1655100, 'US', '2017-07-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146225, 'Uintah', 'Uintah', 'East Weber,Easton,Juinta,Uinta,Uintah,you yin ta,ywnyta  ywta,ywyntah,Јуинта,Юинта,يوينتاه,یونیتا، یوتا,尤因塔', 41.1441100, -111.9232700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146226, 'Vernal', 'Vernal', 'Ashley,Ashley Center,VEL,Vernal,Vurnal,beoneol,fyrnal,wei na er,wrnal  ywta,Вернал,Върнал,فيرنال,ورنال، یوتا,韦纳尔,버널', 40.4555200, -109.5287500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146227, 'Washington Terrace', 'Washington Terrace', '', 41.1727200, -111.9766100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146228, 'Wendover', 'Wendover', 'ENV,Uendouvur,Vendover,wen duo fu,wndawr  ywta,wyndwfr,Вендовер,Уендоувър,ونداور، یوتا,ويندوفر,温多弗', 40.7371500, -114.0375100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146229, 'West Bountiful', 'West Bountiful', '', 40.8938300, -111.9018800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146230, 'West Haven', 'West Haven', '', 41.2030000, -112.0510500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146231, 'West Jordan', 'West Jordan', 'Okcidenta Jordan,Uehst-Dzhordan,Vest DZordan,Vest-Dzhordan,West Jordan,Zapaden Dzhordan,u~esutojodan,weseuteujodeon,wst gwrdn,wst jrdn  ywta,wyst jwrdan,xi qiao dan,Вест Џордан,Вест-Джордан,Западен Джордан,Уэст-Джордан,וסט גורדן,وست جردن، یوتا,ويست جوردان,ویسٹ جورڈن، یوٹاہ,ウェストジョーダン,西喬丹,웨스트조던', 40.6096700, -111.9391000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146232, 'West Mountain', 'West Mountain', '', 40.0607900, -111.7882700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146233, 'West Point', 'West Point', '', 41.1182800, -112.0841100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146234, 'West Valley City', 'West Valley City', 'Granger-Hunter,Uehst-Valli-Siti,Uest Vali Siti,Vest Vali Siti,Vest-Velli-Siti,Wast Valley Ceety,West Valley,West Valley City,u~esutobareshiti,wst wly syty  ywta,wyst faly syty,xi wa li cheng,Вест Вали Сити,Вест-Веллі-Сіті,Уест Вали Сити,Уэст-Валли-Сити,وست ولی سیتی، یوتا,ويست فالي سيتي,چیسٹرفیلڈ، یوٹاہ,ウェストバレーシティ,西瓦利城', 40.6916100, -112.0010500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146235, 'White City', 'White City', '', 40.5657800, -111.8643800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146236, 'Willard', 'Willard', 'North Willow Creek,Uilard,Vilard,Willard,wei la de,wylard,wylard  ywta,Вилард,Уилард,ويلارد,ویلارد، یوتا,威拉德', 41.4091100, -112.0360600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146237, 'Willard', 'Willard', '', 40.7063400, -111.8374300, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146238, 'Wolf Creek', 'Wolf Creek', '', 41.3332700, -111.8271600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146239, 'Woodland Hills', 'Woodland Hills', '', 40.0153200, -111.6486800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146240, 'Woods Cross', 'Woods Cross', 'Uds Kros,Vuds Kros,wu ci ke luo si,wwdz kras  ywta,wwdz krws,Вудс Крос,Удс Крос,وودز كروس,وودز کراس، یوتا,伍兹克洛斯', 40.8716100, -111.8921600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146241, 'Aberdeen', 'Aberdeen', 'Abardeen,Aberdeen,Aberdin,Aburdijn,Wishkah,a bo ding,abadin,aberdini,abrdyn,abrdyn  washyngtn,aebeodin,Абердин,Абърдийн,Աբերդին,אברדין,أبردين,ابردین، واشینگتن,აბერდინი,アバディーン,阿伯丁,애버딘', 46.9753700, -123.8157200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146242, 'Ahtanum', 'Ahtanum', 'Ahtahnam,Ahtanum,Altahnum,Atahnum,Atanum,Atinam', 46.5595700, -120.6220100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146243, 'Airway Heights', 'Airway Heights', 'Ervej Khajts,Euruej Khajts,ayrwy hayts,ayrwy hayts  washyngtn,qi dao gao de,Ервеј Хајтс,Еъруей Хайтс,أيروي هايتس,ایروی هایتس، واشینگتن,气道高地', 47.6446100, -117.5932700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146244, 'Alderton', 'Alderton', '', 47.1695500, -122.2292800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146245, 'Alderwood Manor', 'Alderwood Manor', '', 47.8220400, -122.2820700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146246, 'Algona', 'Algona', 'Algoma,Algona,Valley City', 47.2789900, -122.2520600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146247, 'Allyn', 'Allyn', '', 47.3856500, -122.8276400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146248, 'Amboy', 'Amboy', '', 45.9101100, -122.4464900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146249, 'Ames Lake', 'Ames Lake', '', 47.6328800, -121.9662300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146250, 'Anacortes', 'Anacortes', 'Anacortes,Anakortes,Anakortus,Magic City,OTS,Ship Harbor,Squaw Harbor,a na ke te si,anakorutesu,anakotiseu,anakwrts,anakwrtz  washyngtn,Анакортес,Анакортъс,أناكورتس,اناکورتز، واشینگتن,アナコルテス,阿纳科特斯,아나코티스', 48.5126000, -122.6126700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146251, 'Arlington Heights', 'Arlington Heights', '', 48.2020500, -122.0620800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146252, 'Arlington', 'Arlington', 'Arlington,Arlingtun,Haller,Haller City,a ling dun,allingteon,arinton,arlynghtwn,arlyngtwn  washyngtn,Арлингтон,Арлингтън,آرلنگٹن، واشنگٹن,آرلینگتون، واشینگتن,أرلينغتون,アーリントン,阿灵顿,알링턴', 48.1987100, -122.1251400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146253, 'Artondale', 'Artondale', '', 47.2995400, -122.6206900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146254, 'Asotin', 'Asotin', 'Asotan,Asotin,Assotan', 46.3393300, -117.0482100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146255, 'Auburn', 'Auburn', 'Auburn,Obern,Slaughter,ao ben,awbrn  washyngtn,awbwrn,oban,obeon,Оберн,آبرن، واشنگٹن,أوبورن,اوبرن، واشینگتن,オーバーン,奥本,오번', 47.3073200, -122.2284500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146256, 'Barberton', 'Barberton', 'Baberton,Barberton', 45.6931700, -122.5989900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146257, 'Basin City', 'Basin City', '', 46.5940300, -119.1522300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146258, 'Battle Ground', 'Battle Ground', 'Battle Ground,Battleground,Batul Graund,Betl Graund,ba te er ge lang de,baeteulgeulaundeu,batoruguraundo,batyl ghrawnd,btl grand  washyngtn,Батъл Граунд,Бетл Граунд,باتيل غراوند,بتل گراند، واشینگتن,バトルグラウンド,巴特爾格朗德,배틀그라운드', 45.7809500, -122.5334300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146259, 'Belfair', 'Belfair', '', 47.4506500, -122.8273700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146260, 'Bellevue', 'Bellevue', 'Bellevue,Belv''ju,Belvju,balfyw,bei er wei you,belavhyu,belbyu,berubyu,blwyw  washyngtn,Белвью,Белвю,Белвју,بالفيو,بلویو، واشنگٹن,بلویو، واشینگتن,बेलव्ह्यू,ベルビュー,贝尔维尤,벨뷰', 47.6103800, -122.2006800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146261, 'Bellingham', 'Bellingham', 'BLI,Belingam,Belinghem,Belingkham,Bellingham,Bellingkhem,Bellinqham,bei ling e mu,bellinghaem,berinhamu,blyngham  washyngtn,bylyngham,Белингам,Белингхам,Беллингхем,Беллінгхем,Բելինգհեմ,בלינגהאם,بلینگهام، واشینگتن,بيلينغام,بیلنگہام,ベリンハム,贝灵厄姆,벨링햄', 48.7595500, -122.4882200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146262, 'Benton City', 'Benton City', 'Benton Siti,Bentun Siti,ban dun shi,bntwn syty,bntwn syty  washyngtn,Бентон Сити,Бентън Сити,بنتون سيتي,بنتون سیتی، واشینگتن,斑顿市', 46.2631900, -119.4878000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146263, 'Bethel', 'Bethel', '', 47.4939800, -122.6312500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146264, 'Big Lake', 'Big Lake', '', 48.4028800, -122.2412700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146265, 'Birch Bay', 'Birch Bay', '', 48.9178900, -122.7446200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146266, 'Black Diamond', 'Black Diamond', 'Blek Dajmond,Blek Dajumund,beullaegdaiamondeu,blk dyamwnd  washyngtn,hei zuan shi shi,Блек Дайъмънд,Блек Дајмонд,بلک دیاموند، واشینگتن,黑鑽石市,블랙다이아몬드', 47.3087100, -122.0031700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146267, 'Blaine', 'Blaine', 'BWS,Blaine,Blaine City,Blejn,Bleyn,Concord,Semiahmoo,Whatcom,beullein,blyn,blyn  washyngtn,blyyn,bu lai en,Блейн,Блејн,בליין,بلين,بلین، واشینگتن,布莱恩,블레인', 48.9937200, -122.7471200, 'US', '2017-07-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146268, 'Bonney Lake', 'Bonney Lake', '', 47.1770500, -122.1865100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146269, 'Bothell', 'Bothell', 'Bodul,Botel,Bothell,Brackett''s Landing,Sothell,ba sa er,bosel,boseru,bwthl  washyngtn,bwthyl,Бодъл,Ботел,بوتهل، واشینگتن,بوثيل,ボセル,巴薩爾,보셀', 47.7623200, -122.2054000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146270, 'Boulevard Park', 'Boulevard Park', '', 47.4892700, -122.3151200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146271, 'Bremerton', 'Bremerton', 'Bremerton,Bremurtun,PWT,beulemeoteun,brmrtwn,brmrtwn  washyngtn,brymyrtwn,bu lei mo dun,burematon,Бремертон,Бремъртън,Բրեմերթոն,ברמרטון,برمرتون، واشینگتن,بريميرتون,ブレマートン,布雷默顿,브레머튼', 47.5673200, -122.6326400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146272, 'Brewster', 'Brewster', 'Brewster,Brjuster,Brjustur,Bruster,brwstr,brwstr  washyngtn,bu lu si te,Брустер,Брюстер,Брюстър,بروستر,بروستر، واشینگتن,布鲁斯特', 48.0959800, -119.7806200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146273, 'Bridgeport', 'Bridgeport', 'Bridzhport,Bridzport,brydj pwrt  washyngtn,brydjbwrt,bu li qi bo te,Бриджпорт,Бриџпорт,برج پورٹ، واشنگٹن,بريدجبورت,بریدج پورت، واشینگتن,布里奇波特', 48.0082000, -119.6711600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146274, 'Brier', 'Brier', '', 47.7845400, -122.2742900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146275, 'Browns Point', 'Browns Point', 'Browns Point,Hyada Park', 47.3003800, -122.4412400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146276, 'Brush Prairie', 'Brush Prairie', '', 45.7328900, -122.5464900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146277, 'Bryant', 'Bryant', '', 48.2389900, -122.1579200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146278, 'Buckley', 'Buckley', 'Bakli,Buckley,Bukli,Perkin''s Landing,Perkins Prairie,White River Siding,ba ke li,bakly,bakly  washyngtn,beokeulli,Бакли,Бъкли,باكلي,باکلی، واشینگتن,巴克利,버클리', 47.1631600, -122.0267800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146279, 'Burbank', 'Burbank', 'Berbank,Бербанк', 46.1998600, -119.0130600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146280, 'Burien', 'Burien', 'Bjurijen,Bjuriun,baryn  washyngtn,berian,bu li en,bwryn,byeolieon,Бюриън,Бјуријен,بارین، واشینگتن,بورين,ベリアン,布里恩,벼리언', 47.4703800, -122.3467900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146281, 'Burley', 'Burley', 'Burley,Circle City', 47.4178700, -122.6309700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146282, 'Burlington', 'Burlington', 'Berlington,Burlingtun,MVW,beollingteon,bo ling dun,brlyngtwn  washyngtn,bwrlynjtwn,Берлингтон,Бърлингтън,برلنگٹن، واشنگٹن,برلینگتون، واشینگتن,بورلينجتون,伯灵顿,벌링턴', 48.4756600, -122.3254400, 'US', '2017-07-02', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146283, 'Camano', 'Camano', 'Camano,Camano City', 48.1739900, -122.5282100, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146284, 'Camas', 'Camas', 'Camas,Kamas,La Camas,ka mo si,kamas,kamas  washyngtn,kyamasu,Камас,كاماس,کاماس، واشینگتن,キャマス,卡默斯', 45.5870600, -122.3995400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146285, 'Canterwood', 'Canterwood', '', 47.3751000, -122.5893000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146286, 'Carnation', 'Carnation', 'Carnation,Karnejshon,Karnejshun,Tolt,kaneisyeon,kang nai xin shi,karnyshn  washyngtn,Карнейшън,Карнејшон,کارنیشن، واشینگتن,康乃馨市,카네이션', 47.6478800, -121.9140100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146287, 'Carson', 'Carson', '', 45.7253900, -121.8192400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146288, 'Cascade Valley', 'Cascade Valley', '', 47.1345900, -119.3280800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146289, 'Cashmere', 'Cashmere', 'Cashmere,Kashmir,Kashmiur,Mission,kaesimieo,kai si mi,kashmr  washyngtn,kshmyr,Кашмир,Кашмиър,كشمير,کاشمر، واشینگتن,开司米,캐시미어', 47.5223500, -120.4698000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146290, 'Castle Rock', 'Castle Rock', 'Castle Rock,Castlerock,Kasl Rok,Kasul Rok,kasl rwk,kastl rak  washyngtn,yan bao shi,Касл Рок,Касъл Рок,كاسل روك,کاستل راک، واشینگتن,岩堡市', 46.2751100, -122.9076100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146291, 'Cathcart', 'Cathcart', '', 47.8478800, -122.0992900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146292, 'Cathlamet', 'Cathlamet', 'Birnie''s Retreat,Birnie''s Trading Post,Cathlamah,Cathlamet,Kahelamit,Katalamet,Kathlamet,Katlamet,kaeseullameteu,kathlamyt,Катламет,كاثلاميت,캐슬라메트', 46.2031700, -123.3831800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146293, 'Central Park', 'Central Park', '', 46.9734300, -123.6923900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146294, 'Centralia', 'Centralia', 'Centerville,Centralia,Sentralija,Sentrejlija,Skookumchuck,sen te lei li ya,senteuleillia,sentoraria,sntralya,sntralya  washyngtn,Сентралия,Сентрейлия,Сентрейлія,Сентрејлија,سنتراليا,سنترالیا، واشینگتن,سینٹریلیا، واشنگٹن,セントラリア,森特勒利亚,센트레일리아', 46.7162100, -122.9543000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146295, 'Chehalis', 'Chehalis', 'CLS,Chehalis,Saundersville,Shekhejlis,Shukhejlis,chehalliseu,chhalys  washyngtn,qi hei li si,shyhalys,Шехејлис,Шъхейлис,شيهاليس,چهالیس، واشینگتن,奇黑利斯,체할리스', 46.6620500, -122.9640200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146296, 'Chelan', 'Chelan', 'Chelan,Shelan,Shulan,Tsill-Anne,chylan  washyngtn,qi lan,shylan,swelan,Шелан,Шълан,شيلان,چیلان، واشینگتن,奇兰,쉐란', 47.8409700, -120.0164600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146297, 'Cheney', 'Cheney', 'Billings,Cheney,Chijni,Chini,Depot Springs,Section 13,Sile'',Willow Springs,Yts''piyits''p,cheni,chini,chny  washyngtn,qie ni,tshyny,Чийни,Чини,تشيني,چنی، واشینگتن,チーニー,切尼,체니', 47.4873900, -117.5757600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146298, 'Chewelah', 'Chewelah', 'Chevila,Chuuila,chwlah  washyngtn,qi wei la,tshwlah,Чевила,Чъуила,تشولاه,چولاه، واشینگتن,奇维拉', 48.2762900, -117.7155200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146299, 'Chico', 'Chico', '', 47.6114800, -122.7104200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146300, 'Clarkston', 'Clarkston', 'Clarkston,Concord,Klarkson,Klarkstun,Vineland,ke la ke si dun,klark astwn  washyngtn,klarkstwn,Кларксон,Кларкстън,كلاركستون,کلارک استون، واشینگتن,克拉克斯顿', 46.4162900, -117.0455700, 'US', '2017-06-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146301, 'Cle Elum', 'Cle Elum', 'Cle Elum,Clealum,Kli Elum,ke li ai lei mu,keul-ellum,kly alwm,kureeramu,sl alwm  washyngtn,Кли Елум,Кли Елъм,سل الوم، واشینگتن,كلي إلوم,クレエラム,克利埃勒姆,클엘룸', 47.1954000, -120.9392500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146302, 'Clear Lake', 'Clear Lake', 'Clear Lake,Clearlake,Mountain View', 48.4642700, -122.2340400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146303, 'Clearview', 'Clearview', '', 47.8337100, -122.1259600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146304, 'Clyde Hill', 'Clyde Hill', '', 47.6317700, -122.2179000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146305, 'Colfax', 'Colfax', 'Belleville,Colfax,Hnch''laqhemn,Kolfaks,ke er,klfks  washyngtn,kwlfaks,Колфакс,كولفاكس,کلفکس، واشینگتن,科尔', 46.8801700, -117.3643500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146306, 'College Place', 'College Place', '', 46.0493000, -118.3883000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146307, 'Colville', 'Colville', 'Colville,Kalvil,Kolvil,Pinkney City,ke er wei er,kwlfyl,kwlwyl  washyngtn,Калвил,Колвил,كولفيل,کولویل، واشینگتن,科尔维尔', 48.5465700, -117.9055400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146308, 'Connell', 'Connell', 'Connell,Palouse Junction', 46.6634700, -118.8611100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146309, 'Cosmopolis', 'Cosmopolis', '', 46.9553700, -123.7737800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146310, 'Cottage Lake', 'Cottage Lake', '', 47.7442700, -122.0773500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146311, 'Coulee Dam', 'Coulee Dam', '', 47.9654300, -118.9761300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146312, 'Country Homes', 'Country Homes', '', 47.7485000, -117.4043900, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146313, 'Coupeville', 'Coupeville', 'Coupeville,Kupvil,P''t-sa-tl-y,kopubiru,kwbyfyl,Купвил,كوبيفيل,コープビル', 48.2198200, -122.6862800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146314, 'Covington', 'Covington', 'Kavington,Kuvingtun,ka wen dun,kawyngtwn  washyngtn,keobingteon,kobinton,kwfynghtwn,Кавингтон,Къвингтън,كوفينغتون,کاوینگتون، واشینگتن,کوونگٹن، واشنگٹن,コビントン,卡温顿,커빙턴', 47.3581800, -122.1221600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146315, 'Dallesport', 'Dallesport', 'Dalles Port,Dallesport,Grand Dalles,Grandalles,North Dalles,Northdalles,Rockland', 45.6173400, -121.1795200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146316, 'Darrington', 'Darrington', 'Daringtun,Darrington,Derington,Sauk Portage,The Burn,darynghtwn,Дарингтън,Дерингтон,دارينغتون', 48.2553900, -121.6015100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146317, 'Davenport', 'Davenport', 'Cottonwood Springs,Davenport,Dehvenport,Epsp''it''em,Дэвенпорт', 47.6540500, -118.1499700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146318, 'Dayton', 'Dayton', 'Dayton,Dejton,Dejtun,Touchet,dai dun,daytwn,detana,dytwn  washyngtn,Дейтон,Дейтън,Дејтон,دايتون,دیتون، واشینگتن,ڈیٹن، واشنگٹن,डेटन,代顿', 46.3237500, -117.9724400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146319, 'Deer Park', 'Deer Park', 'Deer Park,Deerpark', 47.9543400, -117.4768900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146320, 'Des Moines', 'Des Moines', 'De Mojn,De Mojns,De-Mojn,DesMoines,de mei yin,demoin,dy mwynz  washyngtn,dys mwyns,Де Мойн,Де Мојнс,Де-Мойн,ديس موينس,دی موینز، واشینگتن,デモイン,得梅因', 47.4017700, -122.3242900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146321, 'Desert Aire', 'Desert Aire', '', 46.6793000, -119.9172700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146322, 'Dishman', 'Dishman', '', 47.6600700, -117.2759600, 'US', '2011-10-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146323, 'Dollar Corner', 'Dollar Corner', '', 45.7801200, -122.6001000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146324, 'DuPont', 'DuPont', 'Djupon,Du Pont,DuPont,Dupont,du bang,dwbwnt,dwpant  washyngtn,Дупонт,Дюпон,دوبونت,دوپانت، واشینگتن,杜邦', 47.0967600, -122.6312400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146325, 'Duvall', 'Duvall', 'Djuval,Duval,Duvall,du wa er,dwwal  washyngtn,dyubal,Дувал,Дювал,دووال، واشینگتن,杜瓦尔,듀발', 47.7423200, -121.9856800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146326, 'East Port Orchard', 'East Port Orchard', '', 47.5234300, -122.6243000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146327, 'East Renton Highlands', 'East Renton Highlands', '', 47.4848200, -122.1123400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146328, 'East Wenatchee', 'East Wenatchee', 'Ist Uinachi,Ist Venachi,ayst wanatshy,ayst wnatchy  washyngtn,dong wei na qi,isutowanatchi,Ист Веначи,Ист Уиначи,إيست واناتشي,ایست وناتچی، واشینگتن,イーストワナッチー,東韋納奇', 47.4156800, -120.2931300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146329, 'East Wenatchee Bench', 'East Wenatchee Bench', '', 47.4256800, -120.2811800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146330, 'Eastgate', 'Eastgate', '', 47.5726600, -122.1457800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146331, 'Eatonville', 'Eatonville', 'Itonvil,Itonvill,Itunvil,aytwnfyl,Итонвил,Итонвилл,Итънвил,إيتونفيل', 46.8673300, -122.2665000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146332, 'Edgewood', 'Edgewood', 'Edzhud,Edzvud,ai qi wu de,ajwwd,aydjwwd,Еджуд,Еџвуд,إيدجوود,اجوود,ایجووڈ، واشنگٹن,埃奇伍德', 47.2501000, -122.2937300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146333, 'Edmonds', 'Edmonds', 'Edmonds,Edmunds,Ehdmonds,admwndz,admwndz  washyngtn,ai de meng ci,edeumeonjeu,edomonzu,Едмондс,Едмъндс,Эдмондс,إدموندز,ادموندز، واشینگتن,エドモンズ,埃德蒙兹,에드먼즈', 47.8106500, -122.3773600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146334, 'Electric City', 'Electric City', 'GCD', 47.9323700, -119.0380800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146335, 'Elk Plain', 'Elk Plain', '', 47.0531600, -122.3976200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146336, 'Ellensburg', 'Ellensburg', 'ELN,Elensburg,Ellen''s Burgh,Ellensburg,Elunsburg,Robbers Roost,ai lun si bao,alns bwrg  washyngtn,alynsbwrgh,ellenseubeogeu,erenzubagu,Еленсбург,Елънсбърг,إلينسبورغ,النس بورگ، واشینگتن,エレンズバーグ,埃伦斯堡,엘렌스버그', 46.9965100, -120.5478500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146337, 'Elma', 'Elma', 'Elma,ai er ma,alma,alma  washyngtn,Елма,إلما,الما، واشینگتن,艾尔玛', 47.0034300, -123.4087700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146338, 'Enetai', 'Enetai', 'Bremerton East,Enetai', 47.5848200, -122.5987500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146339, 'Entiat', 'Entiat', '', 47.6759600, -120.2084100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146340, 'Enumclaw', 'Enumclaw', 'Inumklo,anamk law  washyngtn,anwmklaw,inamukuro,yi na mu ke luo,Инумкло,Инъмкло,إنومكلاو,انامک لاو، واشینگتن,イーナムクロー,伊纳姆克洛', 47.2042700, -121.9915000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146341, 'Ephrata', 'Ephrata', 'Beasley Springs,EPH,Ephrata,Ifrejta,Indian Grave Springs,afrata,afrata  washyngtn,ai fu la ta,Ифрейта,Ифрејта,إفراتا,افراتا، واشینگتن,埃夫拉塔', 47.3176400, -119.5536500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146342, 'Esperance', 'Esperance', '', 47.7889900, -122.3554100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146343, 'Everett', 'Everett', 'Ehverett,Everet,Everett,Evuret,PAE,ai fu li te,awrt  washyngtn,ayfryt,ebaretto,ebeoles,Еверет,Еверетт,Евърет,Эверетт,אוורט,إيفريت,اورت، واشینگتن,ایورٹ,ایوریٹ، واشنگٹن,エバレット,埃弗里特,에버렛', 47.9789800, -122.2020800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146344, 'Everson', 'Everson', 'Everson,Evursun,ai fu sen,awrswn  washyngtn,ayfrswn,ebeoseun,Еверсон,Евърсън,إيفرسون,اورسون، واشینگتن,埃弗森,에버슨', 48.9201200, -122.3426600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146345, 'Fairwood', 'Fairwood', 'Cascade-Fairwood', 47.4484300, -122.1573400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146346, 'Fairwood', 'Fairwood', '', 47.7668400, -117.4174400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146347, 'Fall City', 'Fall City', 'Fall City,Fol Siti,Mountain View,The Landing,Фол Сити,فال سٹی، واشنگٹن', 47.5673200, -121.8887300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146348, 'Felida', 'Felida', '', 45.7095600, -122.7073200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146349, 'Federal Way', 'Federal Way', 'Federal Vej,Federal Way,Fedural Uej,fdral wy  washyngtn,federaruu~ei,fei de lei er wei,fydral way,pedeoleol-wei,Федерал Веј,Федърал Уей,فدرال وی، واشینگتن,فيدرال واي,فیڈرل وئے، واشنگٹن,فیڈرل وے,フェデラルウェイ,费德勒尔韦,페더럴웨이', 47.3223200, -122.3126200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146350, 'Fern Prairie', 'Fern Prairie', '', 45.6365100, -122.3987000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146351, 'Ferndale', 'Ferndale', 'Ferndale,Jam', 48.8465000, -122.5910100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146352, 'Fife', 'Fife', '', 47.2392700, -122.3570700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146353, 'Fife Heights', 'Fife Heights', '', 47.2589900, -122.3456800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146354, 'Finley', 'Finley', '', 46.1540200, -119.0339000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146355, 'Fircrest', 'Fircrest', '', 47.2395400, -122.5159600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146356, 'Five Corners', 'Five Corners', '', 45.6845600, -122.5751000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146357, 'Fobes Hill', 'Fobes Hill', 'Fobes,Fobes Hill', 47.9489900, -122.1198500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146358, 'Fords Prairie', 'Fords Prairie', '', 46.7351000, -122.9890200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146359, 'Forks', 'Forks', 'Forks,fu ke si,fwrks,fwrks  washyngtn,pokeuseu,Форкс,Ֆորկս,فوركس,فورکس، واشینگتن,福克斯,포크스', 47.9503600, -124.3854900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146360, 'Fox Island', 'Fox Island', '', 47.2514900, -122.6290200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146361, 'Frederickson', 'Frederickson', '', 47.0962100, -122.3587300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146362, 'Freeland', 'Freeland', 'Freeland,Newell', 48.0095400, -122.5259800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146363, 'Friday Harbor', 'Friday Harbor', 'Bellvue,FRD,Frajdej Kharbor,Frajdi Kharbur,Friday Harbor,Friday''s Place,Kanaka''s Place,fraydy harbwr,Фрайди Харбър,Фрајдеј Харбор,فرايدي هاربور', 48.5342700, -123.0171200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146364, 'Garrett', 'Garrett', '', 46.0520800, -118.4027500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146365, 'Geneva', 'Geneva', 'Zheneva,Женева', 48.7456700, -122.4018300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146366, 'Gig Harbor', 'Gig Harbor', 'Gig Kharbor,Gig Kharbur,ghygh harbwr,gyg harbr  washyngtn,gyg hrbwr,ji ge gang,Гиг Харбор,Гиг Харбър,גיג הרבור,غيغ هاربور,گیگ هاربر، واشینگتن,吉格港', 47.3292600, -122.5801300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146367, 'Gleed', 'Gleed', '', 46.6581800, -120.6134000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146368, 'Gold Bar', 'Gold Bar', 'Gold Bar,Goldbar', 47.8567700, -121.6970600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146369, 'Goldendale', 'Goldendale', 'Goldendejl,Gouldundejl,ge er deng dai er,ghwldndyl,gldn dal  washyngtn,Голдендејл,Гоулдъндейл,غولدنديل,گلدن دال، واشینگتن,戈尔登代尔', 45.8206800, -120.8217300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146370, 'Graham', 'Graham', '', 47.0528800, -122.2942800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146371, 'Grand Coulee', 'Grand Coulee', 'Coulee Center,Coulee Heights,Grand Coulee', 47.9415400, -119.0033500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146372, 'Grand Mound', 'Grand Mound', 'Grand Mound,Mount Vernon', 46.7878800, -123.0112500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146373, 'Grandview', 'Grandview', '', 46.2509700, -119.9017000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146374, 'Granger', 'Granger', '', 46.3420700, -120.1872700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146375, 'Granite Falls', 'Granite Falls', '', 47.8901300, -120.2136900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146376, 'Granite Falls', 'Granite Falls', 'Granit Fols,Granite Falls,Portage,ghranyt fwlz,granyt falz  washyngtn,hua gang yan pu bu,Гранит Фолс,غرانيت فولز,گرانیت فالز، واشینگتن,花岗岩瀑布', 48.0839900, -121.9687400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146377, 'Hansville', 'Hansville', '', 47.9187000, -122.5543100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146378, 'Hazel Dell', 'Hazel Dell', '', 45.6715100, -122.6628800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146379, 'Highland', 'Highland', '', 46.1315200, -119.1141800, 'US', '2010-02-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146380, 'Hobart', 'Hobart', 'Khobart,Хобарт', 47.4217700, -121.9728900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146381, 'Hockinson', 'Hockinson', 'Eureka,Hockinson', 45.7378900, -122.4870400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146382, 'Home', 'Home', 'Home,Home Colony,Home Landing', 47.2748200, -122.7637500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146383, 'Hoquiam', 'Hoquiam', 'HQM,Khokvijam,Khoukuium,huo kui e mu,hwkwyam,hwkwyam  washyngtn,Хоквијам,Хоукуиъм,هوكويام,هوکویام، واشینگتن,霍奎厄姆', 46.9809200, -123.8893300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146384, 'Indianola', 'Indianola', '', 47.7470400, -122.5256900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146385, 'Issaquah', 'Issaquah', 'Englewood,Gilman,Isakua,Isakva,Isquah,Isquowh,Issaquah,Issquah,Squak,Squawk,Squowh,asakwh,ayskwa  washyngtn,isakua,isakwa,yi se kuo,Исаква,Исакуа,إساكوه,ایسکوا، واشینگتن,イサクア,伊瑟阔,이사콰', 47.5301000, -122.0326200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146386, 'Kalama', 'Kalama', 'Kalama,ka la ma,kalama,kalama  washyngtn,Калама,كالاما,کالاما، واشینگتن,卡拉马', 46.0084500, -122.8445500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146387, 'Kelso', 'Kelso', 'KLS,Kelso,Kelsou,Wallace''s,kai er suo,kelso,keruso,klsw  washyngtn,kylsw,Келсо,Келсоу,كيلسو,کلسو، واشینگتن,ケルソー,凱爾索,켈소', 46.1467800, -122.9084400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146388, 'Kenmore', 'Kenmore', 'KEH,Kenmor,Kenmore,ken mo er,kenmoa,knmwr  washyngtn,kynmwr,Кенмор,كينمور,کنمور، واشینگتن,ケンモア,肯莫尔', 47.7573200, -122.2440100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146389, 'Kennewick', 'Kennewick', 'Dell Haven,Kenevik,Keniuik,Kennevik,Kennewick,VSK,ken na wei ke,keneowig,keniu~ikku,kn wyk  washyngtn,kynwk,kynwyk,Кеневик,Кениуик,Кенневик,Кенневік,كينويك,کن ویک، واشینگتن,کیناویک، واشنگٹن,کینوک,ケニウィック,肯纳威克,케너윅', 46.2112500, -119.1372300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146390, 'Kent', 'Kent', 'Kent,Titusville,ken te,kenteu,kento,knt  washyngtn,kynt,Кент,كينت,کنت، واشینگتن,کینٹ، واشنگٹن,ケント,肯特,켄트', 47.3809300, -122.2348400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146391, 'Kettle Falls', 'Kettle Falls', 'Ketl Fols,Kettle Falls,Ketul Fols,Meyers Falls,ktl falz  washyngtn,kytl fwlz,shui hu pu bu,Кетл Фолс,Кетъл Фолс,كيتل فولز,کتل فالز، واشینگتن,水壶瀑布', 48.6107400, -118.0558200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146392, 'Key Center', 'Key Center', '', 47.3406500, -122.7454100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146393, 'Kingston', 'Kingston', 'Kingston,Кингстон', 47.7987100, -122.4981900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146394, 'Kingsgate', 'Kingsgate', '', 47.7270400, -122.1795700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146395, 'Kirkland', 'Kirkland', 'Kerkland,Kirklandas,Kurkland,kakurando,ke ke lan,keokeullaendeu,krklnd  washyngtn,kyrkland,Керкланд,Къркланд,كيركلاند,کرکلند، واشینگتن,کرکلینڈ، واشنگٹن,カークランド,柯克兰,커클랜드', 47.6814900, -122.2087400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146396, 'Kittitas', 'Kittitas', 'Kittitas,Kittitass', 46.9831800, -120.4170100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146397, 'Klahanie', 'Klahanie', '', 47.4312100, -122.4365200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146398, 'La Center', 'La Center', 'La Center,Lacenter', 45.8623400, -122.6703800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146399, 'Lacey', 'Lacey', 'Lacey,Lejsi,Woodland,lai xi,laky  washyngtn,lasy,reishi,Лейси,Лејси,لاسي,لاسے، واشنگٹن,لاکی، واشینگتن,レイシー,莱西', 47.0342600, -122.8231900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146400, 'Lake Forest Park', 'Lake Forest Park', 'Lejk Forest Park,Lejk Forist Park,hu lin gong yuan shi,lyk fwrst bark,lyk fwrt park  washyngtn,reikuforesutopaku,Лейк Форест Парк,Лејк Форист Парк,ليك فورست بارك,لیک فورت پارک، واشینگتن,لیک فوریسٹ پارک، واشنگٹن,レイクフォレストパーク,湖林公園市', 47.7567600, -122.2809600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146401, 'Lake Shore', 'Lake Shore', '', 45.6906700, -122.6909300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146402, 'Lake Stevens', 'Lake Stevens', 'Lake Stevens,Lejk Stivens,Lejk Stivuns,Stevens Lake,leikeuseutibeunseu,lyk astywns  washyngtn,lyk styfnz,reikusutibunsu,shi di wen si hu,Лейк Стивънс,Лејк Стивенс,ليك ستيفنز,لیک استیونس، واشینگتن,لیک سٹیونز، واشنگٹن,レイクスティーブンス,史帝文斯湖,레이크스티븐스', 48.0151000, -122.0637400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146403, 'Lakewood', 'Lakewood', 'Lakewood,Lakewood Center,Lejkud,Lejkvud,lai ke wu de,leikeuudeu,lyk wwd  washyngtn,lykwwd,reikuuddo,Лейквуд,Лейкуд,Лејквуд,ليكوود,لیک وود، واشینگتن,لیک ووڈ، واشنگٹن,レイクウッド,莱克伍德,레이크우드', 47.1717600, -122.5184600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146404, 'Langley', 'Langley', 'Langli,lan li,lang ly  washyngtn,langhly,Лангли,لانغلي,لانگ لی، واشینگتن,لینگلی، واشنگٹن,蘭里', 48.0400900, -122.4062600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146405, 'Leavenworth', 'Leavenworth', 'Icicle,Leavenworth,Levenvort,Levunuurt,Livenvors,lai wen fu si zhen,lyfnwrth,Левенворт,Левънуърт,Ливенворс,ليفنورث,لیون‌ورت، واشینگتن,莱温芙丝镇', 47.5962300, -120.6614800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146406, 'Lewisville', 'Lewisville', '', 45.8098400, -122.5231500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146407, 'Liberty Lake', 'Liberty Lake', '', 47.6759100, -117.1182100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146408, 'Lochsloy', 'Lochsloy', 'Lochloy,Lochsloy', 48.0514900, -122.0320800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146409, 'Lofall', 'Lofall', 'Lofall,Lovfall,Loyfall', 47.8120400, -122.6582100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146410, 'Long Beach', 'Long Beach', 'Long Beach,Long Bich,Long Bijch,Long-Bich,Longbeach,lang bych  washyngtn,longbichi,lwngh bytsh,zhang tan,Лонг Бийч,Лонг Бич,Лонг-Бич,لانگ بیچ، واشنگٹن,لانگ بیچ، واشینگتن,لونغ بيتش,长滩,롱비치', 46.3523200, -124.0543200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146411, 'Longbranch', 'Longbranch', 'Long Branch,Longbranch', 47.2089800, -122.7568000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146412, 'Longview', 'Longview', 'KLS,Longview,Longvju,lang wyw  washyngtn,lwnghfyw,rongubyu,zhang jing shi,Лонгвю,Лонгвју,لانگ ویو، واشینگتن,لونغفيو,لونگویئو، واشنگٹن,ロングビュー,長景市', 46.1381700, -122.9381700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146413, 'Longview Heights', 'Longview Heights', '', 46.1803900, -122.9570600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146414, 'Lynden', 'Lynden', 'Linden,Lindun,Lynden,Squ-o-hal-itch,lin ding,lindeon,lyndn  washyngtn,lyndyn,rinden,Линден,Линдън,ليندين,لیندن، واشینگتن,リンデン,林丁,린던', 48.9465000, -122.4521100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146415, 'Lynnwood', 'Lynnwood', 'Gorad Linvud,Linud,Linvud,lin wu de,lin-udeu,lyn wwd  washyngtn,lynwwd,rin''uddo,Горад Лінвуд,Линвуд,Линуд,Лінвуд,لينوود,لین وود، واشینگتن,لینووڈ، واشنگٹن,リンウッド,林伍德,린우드', 47.8209300, -122.3151300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146416, 'Mabton', 'Mabton', '', 46.2148500, -119.9967100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146417, 'Machias', 'Machias', 'Machias,Rudd', 47.9814900, -122.0459600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146418, 'Maltby', 'Maltby', 'Maltby,Yew', 47.8051000, -122.1131800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146419, 'Manchester', 'Manchester', 'Manchester,Манчестер', 47.5559300, -122.5448600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146420, 'Manson', 'Manson', '', 47.8848600, -120.1584100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146421, 'Maple Valley', 'Maple Valley', 'Maple Valley,Maplevalley,Mejpl Vali,Mejpul Vali,feng shu gu,mabl faly,meipurubare,mpl wly  washyngtn,Мейпъл Вали,Мејпл Вали,مابل فالي,مپل ولی، واشینگتن,メイプルバレー,楓樹谷', 47.3927200, -122.0464100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146422, 'Maplewood', 'Maplewood', '', 47.4017600, -122.5570700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146423, 'Marietta', 'Marietta', 'Lummi,Marietta', 48.7870500, -122.5804500, 'US', '2006-01-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146424, 'Martha Lake', 'Martha Lake', '', 47.8509300, -122.2393000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146425, 'Marysville', 'Marysville', 'Merisvil,ma li si wei er,marys wyl  washyngtn,marysfyly,mearizubiru,melijeubil,myryzwl,Мерисвил,ماريسفيلي,ماریس ویل، واشینگتن,میریزول,میریزویل، واشنگٹن,メアリーズビル,马里斯维尔,메리즈빌', 48.0517600, -122.1770800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146426, 'Mattawa', 'Mattawa', '', 46.7379100, -119.9028200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146427, 'McCleary', 'McCleary', '', 47.0531500, -123.2654300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146428, 'McMillin', 'McMillin', 'Lime Kiln,McMillan,McMillin', 47.1398200, -122.2365100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146429, 'Mead', 'Mead', '', 47.7673900, -117.3549400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146430, 'Meadow Glade', 'Meadow Glade', '', 45.7584500, -122.5603800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146431, 'Meadowdale', 'Meadowdale', 'Browns Bay,Haines Wharf,Meadowdale', 47.8528700, -122.3334700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146432, 'Medical Lake', 'Medical Lake', '', 47.5729400, -117.6821600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146433, 'Medina', 'Medina', 'Eastland,Medajna,Medina,Medina Heights,Mudina,mai de na,mdyna  washyngtn,Медајна,Медина,Мъдина,مدینا، واشینگتن,مدینہ، واشنگٹن,麦地那', 47.6209300, -122.2276200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146434, 'Mercer Island', 'Mercer Island', 'Merser Ajland,Mursur Ajland,masaairando,mo se dao,mrsraylnd  washyngtn,myrsyr ayland,Мерсер Ајланд,Мърсър Айланд,مرسرآیلند، واشینگتن,ميرسير آيلاند,マーサーアイランド,默瑟島', 47.5706500, -122.2220700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146435, 'Midland', 'Midland', '', 47.1670400, -122.4048400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146436, 'Mill Creek', 'Mill Creek', 'Mil Krijk,Mil Krik,mi er ke li ke,mirukuriku,myl kryk,myl kryk  washyngtn,Мил Крийк,Мил Крик,ميل كريك,میل کریک، واشینگتن,ミルクリーク,米尔克里克', 47.8601000, -122.2043000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146437, 'Mill Plain', 'Mill Plain', '', 45.6429000, -122.4939800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146438, 'Millwood', 'Millwood', 'Millwood,Woodward''s', 47.6812800, -117.2827100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146439, 'Milton', 'Milton', 'Mil''ton,Мильтон', 47.2481600, -122.3129000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146440, 'Minnehaha', 'Minnehaha', '', 45.6590100, -122.6487100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146441, 'Mirrormont', 'Mirrormont', '', 47.4623200, -121.9956700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146442, 'Monroe', 'Monroe', 'Monro,Monroe,Park Place,men luo,meonlo,monro,mwnrw,mwnrw  washyngtn,Монро,مونرو,مونرو، واشینگتن,モンロー,门罗,먼로', 47.8553800, -121.9709600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146443, 'Montesano', 'Montesano', 'Montesejno,Montusejnou,meng te sa nuo,mwntsanw  washyngtn,mwntysanw,Монтесејно,Монтъсейноу,مونتسانو، واشینگتن,مونتيسانو,蒙特萨诺', 46.9812100, -123.6026600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146444, 'Morton', 'Morton', '', 46.5584400, -122.2751000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146445, 'Moses Lake', 'Moses Lake', 'MWH,Moses Lake,Mouzus Lejk,Moziz Lejk,Neppel,mo xi hu shi,mojiseuleikeu,mozesureiku,mwss lyk  washyngtn,mwsys lyk,Мозиз Лејк,Моузъс Лейк,مؤسس لیک، واشینگتن,موسيس ليك,モーゼスレイク,摩西湖市,모지스레이크', 47.1301400, -119.2780800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146446, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,Maunt Vurnun,Maunt-Vernon,fu nong shan,maunteubeoneon,mauntobanon,mwnt fyrnwn,mwnt wrnwn  washyngtn,Маунт Вернон,Маунт Върнън,Маунт-Вернон,ماؤنٹ ورنن، واشنگٹن,مونت فيرنون,مونت ورنون، واشینگتن,マウントバーノン,弗农山,마운트버넌', 48.4212200, -122.3340500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146447, 'Mount Vista', 'Mount Vista', '', 45.7342800, -122.6328800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146448, 'Mountlake Terrace', 'Mountlake Terrace', 'Mauntlejk Teras,mang te lai ke tai lei si,mauntoreikuterasu,mwntlyk tras  washyngtn,mwntlyk tyras,Маунтлейк Терас,Маунтлејк Терас,مونتليك تيراس,مونتلیک تراس، واشینگتن,マウントレイクテラス,芒特莱克泰勒斯', 47.7881500, -122.3087400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146449, 'Mukilteo', 'Mukilteo', 'Makiltio,Muckilteo,Muckiltoe,Muckiltoo,Muckleteo,Mukilteo,Mukultio,ma ke er di ao,mukiruteo,mwkyltw,mwkyltyw  washyngtn,Макилтио,Мъкълтио,موكيلتو,موکیلتئو، واشینگتن,ムキルテオ,马科尔蒂奥', 47.9445400, -122.3045800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146450, 'Napavine', 'Napavine', '', 46.5745500, -122.9081800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146451, 'Navy Yard City', 'Navy Yard City', '', 47.5534300, -122.6645800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146452, 'Newcastle', 'Newcastle', 'Njukasl,Njukasul,niu ka si er,nywkasl  washyngtn,Њукасл,Нюкасъл,نیوکاسل، واشینگتن,纽卡斯尔', 47.5389900, -122.1556800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146453, 'Newport', 'Newport', '', 47.5712100, -122.1806800, 'US', '2010-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146454, 'Newport', 'Newport', 'N''juport,Njuport,nywbwrt,nywpwrt  washyngtn,xin gang,Њупорт,Ньюпорт,Нюпорт,نيوبورت,نیوپورت، واشینگتن,نیوپورٹ، واشنگٹن,新港', 48.1796300, -117.0432600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146455, 'Nooksack', 'Nooksack', 'Nooksachk,Nooksacht,Nooksack,Nooksahk,Nooksak,Nuksak,nugsaeg,nuo ke sai ke,nwk sak  washyngtn,nwksak,Нуксак,نوكساك,نوک ساک، واشینگتن,诺克塞克,눅색', 48.9276200, -122.3215500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146456, 'Normandy Park', 'Normandy Park', '', 47.4362100, -122.3406800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146457, 'North Bend', 'North Bend', 'Mountain View,Nort Bend,North Bend,Northbend,Snoqualmie,South Fork,bei wan shi,nwrt bnd  washyngtn,Норт Бенд,نورت بند، واشینگتن,北灣市', 47.4956600, -121.7867800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146458, 'North Creek', 'North Creek', '', 47.8195400, -122.1762400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146459, 'North Puyallup', 'North Puyallup', '', 47.2067700, -122.2823400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146460, 'North Yelm', 'North Yelm', '', 46.9631500, -122.6029000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146461, 'Oak Harbor', 'Oak Harbor', 'ODW,Oak Harbor,Oakharbor,Ouk Kharbor,Ouk Kharbur,awk harbwr,awk harbwr  washyngtn,okuhaba,xiang gang shi,Оук Харбор,Оук Харбър,أوك هاربور,اوک هاربور، واشینگتن,オークハーバー,橡港市', 48.2931600, -122.6432200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146462, 'Ocean Park', 'Ocean Park', '', 46.4917700, -124.0520800, 'US', '2014-11-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146463, 'Ocean Shores', 'Ocean Shores', 'Oushan Shors,Oushun Shors,awshn shwrz,awshn shwrz  washyngtn,yang bin shi,Оушан Шорс,Оушън Шорс,أوشن شورز,اوشن شورز، واشینگتن,洋濱市', 46.9737000, -124.1562900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146464, 'Okanogan', 'Okanogan', 'Alma,Okanogan,Oukanogan,ao ka nuo gen,awkanwgan  washyngtn,awkanwghan,Оканоган,Оуканоган,أوكانوغان,اوکانوگان، واشینگتن,奥卡诺根', 48.3612600, -119.5833900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146465, 'Olympia', 'Olympia', 'Gorad Alimpija,Marshville,OLM,Olimpeje,Olimpi,Olimpia,Olimpija,Olimpėjė,Olympia,ao lin pi ya,awlmbya,awlmpya,awlmpya  washyngtn,olampiya,olimpiya,ollimpia,orinpia,Ολύμπια,Горад Алімпія,Олимпи,Олимпия,Олимпија,Олімпія,Օլիմպիա,אולימפיה,أولمبيا,اولمپیا,اولمپیا، واشنگٹن,اولمپیا، واشینگتن,ऑलिंपिया,ओलम्पिया,ஒலிம்பியா,オリンピア,奧林匹亞,올림피아', 47.0378700, -122.9007000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146466, 'Omak', 'Omak', 'Epley,OMK,Omak,Oumak,ao ma ke,awmak,awmak  washyngtn,Омак,Оумак,أوماك,اوماک، واشینگتن,奥马克', 48.4109900, -119.5275500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146467, 'Opportunity', 'Opportunity', '', 47.6499500, -117.2399100, 'US', '2011-10-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146468, 'Orchards', 'Orchards', '', 45.6665100, -122.5609300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146469, 'Oroville', 'Oroville', 'Oro,Orovil,Oroville,ao luo wei er,awrwfyl,awrwwyl  washyngtn,Оровил,أوروفيل,اوروویل، واشینگتن,奥罗维尔', 48.9390500, -119.4356200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146470, 'Orting', 'Orting', 'Gunson''s Prairie,Orting,ao ting,awrtyng  washyngtn,awrtyngh,Ортинг,أورتينغ,اورتینگ، واشینگتن,奥廷', 47.0978800, -122.2042800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146471, 'Othello', 'Othello', 'Otello,Otelo,ao sai luo,atllw  washyngtn,awthylw,Отело,أوثيلو,اتللو، واشینگتن,奧賽羅', 46.8259700, -119.1752900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146472, 'Pacific', 'Pacific', '', 47.2645500, -122.2501200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146473, 'Parkland', 'Parkland', '', 47.1553800, -122.4340100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146474, 'Parkwood', 'Parkwood', '', 47.5331500, -122.6101400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146475, 'Pasco', 'Pasco', 'PSC,Pasko,Paskou,Pesko,baskw,pa si ke,paskw  washyngtn,pasuko,Паско,Паскоу,Песко,باسكو,پاسکو، واشنگٹن,پاسکو، واشینگتن,پاسکو،واشنگٹن,パスコ,帕斯科', 46.2395800, -119.1005700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146476, 'Point Roberts', 'Point Roberts', 'Pojnt Roberts,Poynt Roberts,luo bo ci jiao,pointeu lobeocheu,pointorobatsu,Појнт Робертс,ポイントロバーツ,罗伯茨角,포인트 로버츠', 48.9853800, -123.0779700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146477, 'Pomeroy', 'Pomeroy', 'Pomeroj,Poumroj,bo mo luo yi,bwmyrwy,pamrwy  washyngtn,pomeoloi,Померој,Поумрой,بوميروي,پامروی، واشینگتن,波默罗伊,포머로이', 46.4748700, -117.6026900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146478, 'Port Angeles', 'Port Angeles', 'CLM,Cherbourg,Port Andzeles,Port Andzhelis,Port Angeles,an ji li si gang,bwrt anjlws,poteuaenjelleseu,potoenjerusu,pwrt anjls  washyngtn,Порт Анджелис,Порт Анџелес,بورت أنجلوس,پورت آنجلس، واشینگتن,ポートエンジェルス,安吉利斯港,포트앤젤레스', 48.1181500, -123.4307400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146479, 'Port Ludlow', 'Port Ludlow', 'Dos-la-latl,Port Ludlow,Sna-nul-kwo', 47.9253700, -122.6834900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146480, 'Port Orchard', 'Port Orchard', 'Port Orchard,Sidney,Ter-cha-duk,ao cha de gang,bwrt bstan,potoochado,pwrt awrchard  washyngtn,Порт Орчард,بورت بستان,پورت اورچارد، واشینگتن,ポートオーチャード,奥查德港', 47.5403700, -122.6362500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146481, 'Port Townsend', 'Port Townsend', 'Port Taunsend,Port Taunsund,Port Townsend,Port Townshend,TWD,bwrt tawnsnd,pwrt tawnznd  washyngtn,tang sen gang,Порт Таунсенд,Порт Таунсънд,بورت تاونسند,پورت تاونزند، واشینگتن,湯森港', 48.1170400, -122.7604500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146482, 'Poulsbo', 'Poulsbo', 'PUL,Polsbo,Polzbou,bo er si bo,bwlsbw,pwlsbw  washyngtn,Ползбоу,Полсбо,بولسبو,پولسبو، واشینگتن,波尔斯波', 47.7359300, -122.6465400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146483, 'Prairie Ridge', 'Prairie Ridge', '', 47.1376000, -122.1487300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146484, 'Prosser', 'Prosser', 'Colonel Cook''s Ferry,Cook''s Ferry,Proser,Prosser,Prosser Falls,Prosur,Yakima Falls,brwsr,prasr  washyngtn,pu luo se,purossa,Просер,Просър,بروسر,پراسر، واشینگتن,プロッサー,普羅瑟', 46.2068000, -119.7689200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146485, 'Pullman', 'Pullman', 'PUW,Pullman,Pulman,Three Forks,bwlman,pu er man,puruman,pwlmn  washyngtn,Пулман,بولمان,پولمن، واشینگتن,プルマン,普尔曼', 46.7312700, -117.1796200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146486, 'Purdy', 'Purdy', '', 47.3889900, -122.6254100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146487, 'Puyallup', 'Puyallup', 'Franklin,Meekersville,Pjualup,Pujallap,Puyallup,bwyalwb,pi a la pu,pwyalap  washyngtn,pyuaelleob,pyuarappu,Пуйаллап,Пюалъп,Пјуалуп,بويالوب,پویالاپ، واشینگتن,ピュアラップ,皮阿拉普,퓨앨럽', 47.1853800, -122.2929000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146488, 'Quincy', 'Quincy', 'Kuinsi,Kvinsi,kun xi,kwynsy,kwyynsy  washyngtn,Квинси,Куинси,كوينسي,کوئنسی، واشنگٹن,کوئینسی، واشینگتن,昆西', 47.2343000, -119.8525500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146489, 'Rainier', 'Rainier', 'Rejnir,Rejniur,lei ni er,rynyr  washyngtn,rynyyr,Рейниър,Рејнир,رينيير,رینیر، واشینگتن,雷尼尔', 46.8881500, -122.6884600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146490, 'Ravensdale', 'Ravensdale', '', 47.3523200, -121.9837300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146491, 'Raymond', 'Raymond', 'Rejmond,Rejmund,lin feng,rymwnd,rymwnd  washyngtn,Реймънд,Рејмонд,ريموند,ریمنڈ، واشنگٹن,ریموند، واشینگتن,林峰', 46.6864900, -123.7329400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146492, 'Redmond', 'Redmond', 'Melrose,Redmond,Redmund,Salmonberg,ledeumeondeu,lei de meng de,rdmwnd,redomondo,rydmwnd  washntn,Редмонд,Редмънд,ردموند,ريدموند، واشنطن,ریڈمونڈ,レドモンド,雷德蒙德,레드먼드', 47.6739900, -122.1215100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146493, 'Renton', 'Renton', 'Black River Bridge,RNT,Renton,Rentun,lenteon,lun dun,renton,rntwn  washyngtn,ryntwn,Рентон,Рентън,Ռենտոն,رنتون، واشینگتن,رينتون,رینٹن، واشنگٹن,レントン,伦顿,렌턴', 47.4828800, -122.2170700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146494, 'Republic', 'Republic', 'Repablik,Ripublik,lei pa bu li ke,rybablk,rypablyk  washyngtn,Репаблик,Рипъблик,ريبابلك,ریپابلیک، واشینگتن,雷帕布利克', 48.6482200, -118.7378100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146495, 'Richland', 'Richland', 'RLD,Richland,Richlend,li qi lan,ritchirando,rychlnd  washyngtn,rytshland,ryzlnd,Ричланд,Ричленд,Річленд,ריצלנד,ريتشلاند,رچلینڈ، واشنگٹن,ریچلند، واشینگتن,リッチランド,里奇兰', 46.2856900, -119.2844600, 'US', '2017-05-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146496, 'Ridgefield', 'Ridgefield', 'Ridgefield,Ridzfild,Ridzhfijld,Union Ridge,li qi fei er de,rydjfyld,ryj fyld  washyngtn,Риджфийлд,Риџфилд,ريدجفيلد,ریج فیلد، واشینگتن,里奇菲尔德', 45.8151100, -122.7426000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146497, 'Riverbend', 'Riverbend', '', 47.4664900, -121.7503900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146498, 'Riverton', 'Riverton', '', 47.4842700, -122.2945700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146499, 'Ritzville', 'Ritzville', 'Ricvil,Ritsvil,li ci wei er,rytz wyl  washyngtn,rytzfyl,Рицвил,ريتزفيل,ریتز ویل، واشینگتن,里茨维尔', 47.1275500, -118.3799900, 'US', '2017-06-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146500, 'Rochester', 'Rochester', 'Key,Rochester,Рочестер', 46.8217700, -123.0962500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146501, 'Rocky Point', 'Rocky Point', '', 47.5928700, -122.6684800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146502, 'Rosedale', 'Rosedale', '', 47.3314900, -122.6523500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146503, 'Royal City', 'Royal City', 'Red Rock,Royal,Royal City', 46.9009700, -119.6305900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146504, 'Salmon Creek', 'Salmon Creek', '', 45.7106700, -122.6489900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146505, 'Sammamish', 'Sammamish', 'Samamish,sam mamysh  washyngtn,samamisshu,samamysh,se ma mi shen,Самамиш,سام مامیش، واشینگتن,ساماميش,サマミッシュ,瑟马米什', 47.6417700, -122.0804000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146506, 'SeaTac', 'SeaTac', 'Siatak,Sitak,shitakku,sitaeg,sy tk  washyngtn,sytak,xi ta ke,Сиатак,Ситак,سيتاك,سی تک، واشینگتن,シータック,西塔科,시택', 47.4484600, -122.2921700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146507, 'Seabeck', 'Seabeck', '', 47.6395400, -122.8284900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146508, 'Seattle', 'Seattle', 'Gorad Siehtl,SEA,Seatl,Seattle,Seattlum,Siatl,Siatul,Siehtl,Sietl,Sietla,Sietlas,Sijetl,Siyaatil,Séatl,ciyattil,shiatoru,si''aitala,siaeteul,sietʼli,siyatal,siyatala,syatl,xi ya tu,Σιάτλ,Горад Сіэтл,Сиатъл,Сиетл,Сиэтл,Сијетл,Сієтл,Սիեթլ,סיאטל,سياتل,سیئٹل,سیاتل,سیاٹل,सिअ‍ॅटल,सीऐटल,সিয়াটল,சியாட்டில்,ಸಿಯಾಟಲ್,ซีแอตเทิล,სიეტლი,ስያትል,ស៊ីតថល,シアトル,西雅圖,시애틀', 47.6062100, -122.3320700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146509, 'Sedro-Woolley', 'Sedro-Woolley', 'Sedro Woolley,Sedro Wooly,Sedro-Wooley,Sedro-Woolley,Sidro-Vuli,Sidrou-Uli,sdrw-wwly  washyngtn,sedorouri,shi de luo-wu li,sydrw-waly,Сидро-Вули,Сидроу-Ули,سدرو-وولی، واشینگتن,سيدرو-والي,セドロウーリー,世德羅-伍利', 48.5038900, -122.2361100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146510, 'Selah', 'Selah', 'Selah,Sila,Wenas,slah,slah  washyngtn,xi la,Сила,سلاه,سلاه، واشینگتن,細拉', 46.6540200, -120.5300700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146511, 'Sequim', 'Sequim', 'SQV,Seguin,Sequim,Skuim,Skvim,shi kui en,skwyym  washyngtn,sukuimu,sykym,Сквим,Скуим,سيكيم,سکوئیم، واشینگتن,スクイム,史魁恩', 48.0796300, -123.1023400, 'US', '2017-06-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146512, 'Shelton', 'Shelton', 'SHN,Shelton,Sheltun,sheruton,shltwn  washyngtn,shyltwn,syelteon,xue er dun,Шелтон,Шелтън,شلتون، واشینگتن,شيلتون,シェルトン,雪爾頓,셸턴', 47.2150900, -123.1007100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146513, 'Shoreline', 'Shoreline', 'Shorlajn,an xian shi,shoarain,shwrlayn  washyngtn,shwrlyn,syolain,Шорлайн,Шорлајн,شورلائن، واشنگٹن,شورلاین، واشینگتن,شورلين,ショアライン,岸線市,쇼라인', 47.7556500, -122.3415200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146514, 'Silverdale', 'Silverdale', 'Goldendale,Silverdale,Silverdejl,Силвердејл', 47.6445400, -122.6948700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146515, 'Sisco Heights', 'Sisco Heights', '', 48.1153800, -122.0970800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146516, 'Smokey Point', 'Smokey Point', '', 48.1523200, -122.1826400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146517, 'Snohomish', 'Snohomish', 'Cadyville,Snohomish,Snohomish City,Snokhomish,Snokhoumish,asnwhwmysh  washyngtn,si nuo ke mi xi,snwhwmysh,Снохомиш,Снохоумиш,اسنوهومیش، واشینگتن,سنوهوميش,斯诺克米西', 47.9128800, -122.0981800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146518, 'Snoqualmie', 'Snoqualmie', 'Sno-qual-mie,Snokvolmi,Snoqualme,Snoqualmie,Snoukuolmi,asnakwalmy  washyngtn,si nuo kua er mi,snwqwwlmy,Снокволми,Сноукуолми,סנוקוולמי,اسناکوالمی، واشینگتن,斯诺夸尔米', 47.5287100, -121.8253900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146519, 'Soap Lake', 'Soap Lake', '', 47.3893100, -119.4905900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146520, 'South Bend', 'South Bend', 'Saut Bend,South Bend,Southbend,nan ben de,sawth bynd,swt bnd  washyngtn,Саут Бенд,ساوث بيند,سوت بند، واشینگتن,南本德', 46.6631500, -123.8046100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146521, 'South Hill', 'South Hill', '', 47.1412100, -122.2701200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146522, 'Southworth', 'Southworth', '', 47.5120400, -122.5018000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146523, 'Spanaway', 'Spanaway', 'Lake Park,Lakepark,Spanaway', 47.1039900, -122.4345700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146524, 'Spokane', 'Spokane', 'GEG,Gorad Spakan,Spocanum,Spokan,Spokane,Spokane Falls,Spokein,Spoken,aspwkn,sbwkyn,seupokaen,si bo kan,spwkyn,spwqyyn,supoken,Σποκέιν,Горад Спакан,Спокан,Спокен,Սպոքեն,ספוקיין,اسپوکن,سبوكين,سپوکین,سپوکین، واشنگٹن,スポケーン,スポーケン,斯波坎,스포캔', 47.6596600, -117.4290800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146525, 'Spokane Valley', 'Spokane Valley', 'Spokan Vali,Spoken Vali,aspwkyn wly  washyngtn,sbwkan faly,seupokaenbaelli,si bo kan gu,spwkyn wyly,Спокан Вали,Спокен Вали,اسپوکین ولی، واشینگتن,سبوكان فالي,سپوکین ویلی,سپوکین ویلی، واشنگٹن,斯波坎谷,스포캔밸리', 47.6732300, -117.2393700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146526, 'Stanwood', 'Stanwood', 'Centerville,Stanud,Stanvud,Stanwood,astn wwd  washyngtn,si tan wu de,stanwwd,Станвуд,Стануд,استن وود، واشینگتن,ستانوود,斯坦伍德', 48.2412100, -122.3707100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146527, 'Steilacoom', 'Steilacoom', 'Chelakoom,Chilacoom,Steilacoom,Stilakam,Stilakum,Tail-a-koom,Tchil-ae-cum,stylakwm,Стилакам,Стилакум,ستيلاكوم', 47.1698200, -122.6026300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146528, 'Stevenson', 'Stevenson', 'Stevenson,Stevenson''s Spur,Stivenson,Stivunsun,astywnsan  washyngtn,shi di wen sen,styfnswn,Стивенсон,Стивънсън,استیونسان، واشینگتن,ستيفنسون,史蒂文森', 45.6956700, -121.8845200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146529, 'Sudden Valley', 'Sudden Valley', '', 48.7228900, -122.3465500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146530, 'Sultan', 'Sultan', '', 47.8626000, -121.8165100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146531, 'Sumas', 'Sumas', 'Sumas,Sumas City,su ma si,sumaseu,swmas,swmas  washyngtn,Сумас,سوماس,سوماس، واشینگتن,苏马斯,수마스', 49.0001200, -122.2648800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146532, 'Summit', 'Summit', '', 47.1617700, -122.3570700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146533, 'Sumner', 'Sumner', 'Samner,Sumnur,sa mu na,samnr  washyngtn,swmnr,Самнер,Съмнър,سامنر، واشینگتن,سومنر,萨姆纳', 47.2031600, -122.2404000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146534, 'Sunnyside', 'Sunnyside', 'Holy City,Sanisajd,Sunisajd,Sunnyside,sang ni sai de,sanisaido,sany sayd  washyngtn,sanysayd,seonisaideu,Санисајд,Сънисайд,سانيسايد,سانی ساید، واشینگتن,サニーサイド,桑尼賽德,서니사이드', 46.3237400, -120.0086500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146535, 'Sunnyslope', 'Sunnyslope', '', 47.4729000, -120.3367400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146536, 'Suquamish', 'Suquamish', 'Bartow,Suquamish', 47.7312100, -122.5523600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146537, 'Tacoma', 'Tacoma', 'Chebaulip,Commencement City,Gorad Takoma,Puyallup,T''kope,T''kopt,TIW,Tacoma,Takoma,Takouma,da jin ma,ta ke ma,takoma,takwma,takwma  washyngtn,teokoma,tqwmh,Τακόμα,Горад Такома,Такома,Такоума,טקומה,تاكوما,تاکوما، واشینگتن,ٹاکوما,ٹاکوما، واشنگٹن,タコマ,塔科马,打金麻,터코마', 47.2528800, -122.4442900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146538, 'Tanner', 'Tanner', '', 47.4753800, -121.7462200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146539, 'Tenino', 'Tenino', 'Tenajno,te nai nuo,tnynw  washyngtn,tynynw,Тенайно,Тенајно,تنینو، واشینگتن,تينينو,特奈诺', 46.8567700, -122.8529100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146540, 'Terrace Heights', 'Terrace Heights', '', 46.6062400, -120.4397900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146541, 'Three Lakes', 'Three Lakes', '', 47.9448200, -122.0115200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146542, 'Tieton', 'Tieton', '', 46.7020700, -120.7553500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146543, 'Tonasket', 'Tonasket', 'Tenasket,Tonasket,Tonaskot,Tunaskit,tuo na si ji te,twnaskt  washyngtn,twnaskyt,Тонаскет,Тънаскит,توناسكيت,توناسکت، واشینگتن,托纳斯基特', 48.7051500, -119.4395000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146544, 'Toppenish', 'Toppenish', 'Topenish,Topinish,Toppenish,ta ben ni xu,topenisi,twbynysh,twpnysh  washyngtn,Топениш,توبينيش,توپنیش، واشینگتن,塔本尼許,토페니시', 46.3773500, -120.3086700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146545, 'Town and Country', 'Town and Country', '', 47.7273900, -117.4216100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146546, 'Tracyton', 'Tracyton', '', 47.6089800, -122.6551400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146547, 'Trentwood', 'Trentwood', '', 47.6965600, -117.2107600, 'US', '2011-10-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146548, 'Tukwila', 'Tukwila', 'Takvila,Tukuila,ta ke wei la,takkuu~ira,takwyla  washyngtn,twkwyla,Таквила,Тъкуила,تاکویلا، واشینگتن,توكويلا,タックウィラ,塔克維拉', 47.4739900, -122.2609600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146549, 'Tulalip', 'Tulalip', '', 48.0684300, -122.2918100, 'US', '2011-06-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146550, 'Tulalip Bay', 'Tulalip Bay', '', 48.0373200, -122.3101400, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146551, 'Tumwater', 'Tumwater', 'Des Chutes,Falls River,New Market,Spa-kwatl,Tamvoter,Tumuoter,Tumuotur,Tumvoter,Tumwater,Tumwater Falls,ta mu wo te,tam watr  washyngtn,tamuu~ota,twmwatyr,Тамвотер,Тумвотер,Тумуотер,Тъмуотър,تام واتر، واشینگتن,تومواتير,タムウォーター,塔姆沃特', 47.0073200, -122.9093100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146552, 'Union Gap', 'Union Gap', 'Junion Gap,Juniun Gap,Union Gap,Yakima,Yakima City,lian meng xia,ywnyn gp  washyngtn,ywnywn ghab,Јунион Гап,Юниън Гап,يونيون غاب,یونین گپ، واشینگتن,联盟峡', 46.5573500, -120.4750600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146553, 'University Place', 'University Place', 'Belmarlow,Juniversiti Plejs,Junivursiti Plejs,University Place,da xue cheng,yunibashitipuresu,ywnyfyrsyty blys,ywnywrsyty plys  washyngtn,Јуниверсити Плејс,Юнивърсити Плейс,يونيفيرسيتي بليس,یونیورسیتی پلیس، واشینگتن,ユニバーシティプレース,大學城', 47.2356500, -122.5504000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146554, 'Vancouver', 'Vancouver', 'Alashikash,Camp Vancouver,Columbia Barracks,Columbia City,Fort Vancouver,Predloga:Zascitenovand,Predloga:Zaščitenovand,Template:Vandalism,Van''kouver,Vancouver,Vancouver Barracks,Vancouver City,Vankuver,Vankuveris,Vankuvur,baenkubeo,bankuba,fankwfr,wen ge hua,wnkwwr  washyngtn,wnqwbr,Βανκούβερ,Ванкувер,Ванкувър,ונקובר,فانكوفر,ونکوور، واشینگتن,وینکوور، واشنگٹن,แวนคูเวอร์,バンクーバー,溫哥華,밴쿠버', 45.6387300, -122.6614900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146555, 'Vashon', 'Vashon', 'Vashon,Vashon Island,Vashonuv ostrov,Vashonův ostrov,wshn  washyngtn,Вашон,وشن، واشینگتن', 47.4473200, -122.4598500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146556, 'Veradale', 'Veradale', 'Vera,Veradale', 47.6499500, -117.2073800, 'US', '2011-10-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146557, 'Venersborg', 'Venersborg', 'Alpine,Bells Mountain,The Colony,Venersbord,Venersborg', 45.7737300, -122.4245400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146558, 'Waitsburg', 'Waitsburg', 'Delta,Wait''s Crossing,Wait''s Mill,Waitsburg', 46.2704200, -118.1532900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146559, 'Walla Walla', 'Walla Walla', 'ALW,Steptoe City,Steptoeville,Uola Uola,Vola Vola,Walla Walla,Walla Walla City,wa la wa la,wala wala,wala wala  washyngtn,wallawalla,warawara,Вола Вола,Уола Уола,والا والا,والا والا، واشینگتن,ワラワラ,瓦拉瓦拉,왈라왈라', 46.0645800, -118.3430200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146560, 'Waller', 'Waller', '', 47.2006600, -122.3692900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146561, 'Walnut Grove', 'Walnut Grove', '', 45.6678900, -122.5989900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146562, 'Wapato', 'Wapato', 'Simcoe,Uopatou,Vopato,Wapato,wa pa tuo,wabatw,wapatw  washyngtn,Вопато,Уопатоу,واباتو,واپاتو، واشینگتن,瓦帕托', 46.4476300, -120.4203400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146563, 'Warden', 'Warden', '', 46.9676400, -119.0397300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146564, 'Warm Beach', 'Warm Beach', 'Birmingham,Warm Beach', 48.1706500, -122.3646000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146565, 'Washougal', 'Washougal', 'Parker''s Landing,Point Vancouver,Uoshugal,Voshugal,Washougal,Washoughally Camp,wa xiu ge,washugaru,washwgal  washyngtn,washwghal,Вошугал,Уошугал,واشوغال,واشوگال، واشینگتن,ワシューガル,瓦休戈', 45.5826200, -122.3534200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146566, 'Waterville', 'Waterville', 'Jumper''s Flat,Uoturvil,Votervil,Waterville,wo te wei er,wwtrfyl,Вотервил,Уотървил,ووترفيل,沃特維爾', 47.6470800, -120.0711800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146567, 'Wauna', 'Wauna', '', 47.3789900, -122.6426300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146568, 'Wenatchee', 'Wenatchee', 'EAT,Uenachi,Venachi,Wenache,Wenatche,Wenatchee,wanatchi,wei na qi,wnatchy  washyngtn,wyntatshy,Веначи,Уеначи,وناتچی، واشینگتن,وينتاتشي,ワナッチー,韦纳奇', 47.4234600, -120.3103500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146569, 'West Lake Sammamish', 'West Lake Sammamish', '', 47.5776000, -122.1012300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146570, 'West Lake Stevens', 'West Lake Stevens', '', 47.9934300, -122.1018000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146571, 'West Longview', 'West Longview', '', 46.1678900, -122.9990000, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146572, 'West Pasco', 'West Pasco', '', 46.2454100, -119.1827900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146573, 'West Richland', 'West Richland', 'Enterprise,Heminger City,Uest Richland,Vest Richland,West Richland,u~esutoritchirando,weseuteulichillaendeu,wst rychlnd  washyngtn,wyst rytshland,xi li qi lan,Вест Ричланд,Уест Ричланд,مغربی رچلینڈ، واشنگٹن,وست ریچلند، واشینگتن,ويست ريتشلاند,ウェストリッチランド,西里奇兰,웨스트리칠랜드', 46.3043000, -119.3614100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146574, 'West Valley', 'West Valley', '', 46.5920700, -120.6050700, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146575, 'West Wenatchee', 'West Wenatchee', '', 47.4437400, -120.3534100, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146576, 'Westport', 'Westport', 'Chehalis City,Damon,Fort Chehalis,Peterson''s Point,Uestport,Vestport,Westport,wst pwrt  washyngtn,wystbwrt,xi gang shi,Вестпорт,Уестпорт,وست پورت، واشینگتن,ويستبورت,西港市', 46.8900900, -124.1040600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146577, 'White Center', 'White Center', '', 47.5173200, -122.3548500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146578, 'White Salmon', 'White Salmon', 'Uajt Salmun,Vajt Samon,huai te sa meng,wayt salman  washyngtn,wayt slmwn,Вајт Самон,Уайт Салмън,وايت سلمون,وایت سالمان، واشینگتن,怀特萨蒙', 45.7276200, -121.4864600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146579, 'Winlock', 'Winlock', '', 46.4912200, -122.9379000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146580, 'Bainbridge Island', 'Bainbridge Island', 'Bainbridge,Bainbridge Island,Bejnbridz Ajland,Bejnbridzh Ajland,City of Bainbridge Island,Ile de Bainbridge,Ostriv Bejnbridzh,Ostrov Bejnbridzh,Winslow,ban bu li zhi dao,bayn brydj ayslnd  washyngtn,beinburijjiairando,bynbryj ayland,Île de Bainbridge,Бейнбридж Айланд,Бејнбриџ Ајланд,Остров Бейнбридж,Острів Бейнбрідж,باین بریدج ایسلند، واشینگتن,بينبريج آيلاند,ベインブリッジアイランド,班布里治島', 47.6262100, -122.5212400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146581, 'Wollochet', 'Wollochet', 'Berg,Bergs Landing,Wollochet', 47.2687100, -122.5840200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146582, 'Woodinville', 'Woodinville', 'Udinvil,Vudinvil,uddinbiru,wu ding wei er,wwdanfyl,wwdynwyl  washyngtn,Вудинвил,Удинвил,وودإنفيل,وودینویل، واشینگتن,ウッディンビル,伍丁維爾', 47.7542700, -122.1634600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146583, 'Woodland', 'Woodland', 'Udland,Vudland,lin de shi,udeullaendeu,wwd lnd  washyngtn,wwdland,Вудланд,Удланд,وود لند، واشینگتن,وودلاند,ووڈلینڈ، واشنگٹن,林地市,우들랜드', 45.9045600, -122.7439900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146584, 'Woods Creek', 'Woods Creek', '', 47.8787100, -121.8984600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146585, 'Woodway', 'Woodway', '', 47.7962100, -122.3829100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146586, 'Yacolt', 'Yacolt', '', 45.8659500, -122.4062100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146587, 'Yakima', 'Yakima', 'Jakima,Jakimo,North Yakima,YKM,Yakima,ya ji ma,yakima,yakyma,yakyma  washyngtn,Јакимо,Якима,Якіма,יאקימה,ياكيما,یاکیما,یاکیما، واشینگتن,یکما، واشنگٹن,ヤキマ,雅基馬,야키마', 46.6020700, -120.5059000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146588, 'Yarrow Point', 'Yarrow Point', 'Yarrow,Yarrow Point', 47.6462100, -122.2173500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146589, 'Yelm', 'Yelm', 'Jelm,ye mu,ylm,ylm  washyngtn,Јелм,Йелм,يلم,یلم، واشنگٹن,یلم، واشینگتن,耶姆', 46.9420400, -122.6059600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146590, 'Zillah', 'Zillah', 'Zila,jilla,jira,qi la,zylah,zylah  washyngtn,Зила,زيلاه,زیلاه، واشینگتن,ジラ,齊拉,질라', 46.4020700, -120.2620000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146591, 'Afton', 'Afton', 'AFO,Aftan,Afton,aftwn,aftwn  waywmyng,afuton,ya fu dun,Афтан,Афтон,أفتون,افتون، وایومینگ,アフトン,雅富顿', 42.7249300, -110.9318700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146592, 'Arapahoe', 'Arapahoe', '', 42.9621800, -108.4898300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146593, 'Bar Nunn', 'Bar Nunn', 'Bar Nan,Bar-Nann,ba na en,bar nwn,bar nwn  waywmyng,Бар Нан,Бар-Нанн,بار نون,بار نون، وایومینگ,巴纳恩', 42.9135800, -106.3433600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146594, 'Basin', 'Basin', 'Bejsin,basyn,bei sen,besun,bysn  waywmyng,Бейсин,Бейсін,Бејсин,باسين,بیسن، وایومینگ,ベースン,贝森', 44.3799600, -108.0389900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146595, 'Buffalo', 'Buffalo', 'BYG,Baffalo,Bufalo,Buffalo,bfylw  wayywmng,bwfalw,bwfalw  waywmyng,shui niu,Баффало,Буфало,Буффало,Бъфало,بفیلو، وائیومنگ,بوفالو,بوفالو، وایومینگ,水牛', 44.3483100, -106.6989400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146596, 'Casper', 'Casper', 'CPR,Kasper,Kaspur,ka si po,kaeseupeo,kasbr,kspr  waywmyng,kyasupa,kyspr  wayywmng,qspr,Каспер,Каспър,קספר,كاسبر,کسپر، وایومینگ,کیسپر، وائیومنگ,キャスパー,卡斯珀,캐스퍼', 42.8666300, -106.3130800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146597, 'Cheyenne', 'Cheyenne', 'CYS,Cheyenna,Cheyenne,Gorad Shaen,Hell on Wheels,Saien,Saiena,Sajenas,Sajens,Sayen,Shaen,Shaenn,Shajen,Shajenn,ce''ini,ceyen,sayana,seyen,shaian,shayan,shayn,shayn  waywmyng,shayn  wayywmng,syaien,xia yan,Šaiena,Šajenas,Šajens,Σαϊέν,Горад Шаен,Шаен,Шайен,Шайенн,Шаєнн,Шајен,Շայեն,שאיין,شايان,شاین,شاین، وائیومنگ,شاین، وایومینگ,चेइनी,शायान,शेयेन्,செயென்,シャイアン,夏延,샤이엔', 41.1399800, -104.8202500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146598, 'Cody', 'Cody', 'COD,Kodi,Koudi,ke di,kodi,kwdy,kwdy  waywmyng,Коди,Коді,Коуди,كودي,کودی، وایومینگ,کوڈی، وائیومنگ,コーディ,科迪', 44.5263400, -109.0565300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146599, 'Douglas', 'Douglas', 'DGW,Daglas,Duglas,daglas  waywmyng,dao ge la si,dwghlas,Даглас,Дуглас,Дъглас,داگلاس، وایومینگ,دوغلاس,ڈگلس، وائیومنگ,道格拉斯', 42.7596900, -105.3822100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146600, 'Ethete', 'Ethete', '', 43.0249600, -108.7726200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146601, 'Evanston', 'Evanston', 'EVW,Ehvanston,Evanston,Evanstun,ai wen si dun,awnstwn  waywmyng,ayfanstwn,ebansuton,ebeonseuteon,Еванстон,Еванстън,Эванстон,إيفانستون,اونستون، وایومینگ,ایوانزٹن، وائیومنگ,エバンストン,埃文斯顿,에번스턴', 41.2682800, -110.9632400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146602, 'Evansville', 'Evansville', 'Ehvansvill,Эвансвилл', 42.8599700, -106.2683600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146603, 'Fort Washakie', 'Fort Washakie', 'Camp Brown,Fort Washakie', 43.0063500, -108.8823500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146604, 'Gillette', 'Gillette', 'Donkey Town,Dzhilet,Dzhillett,Dzilet,GCC,Gillette,Rocky Pile,gylt,ji lie,jiretto,jylt  waywmyng,jylyt,Џилет,Джилет,Джиллетт,Джіллетт,גילט,جيليت,جیلت، وایومینگ,جیلیٹ، وائیومنگ,ジレット,吉列', 44.2910900, -105.5022200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146605, 'Glenrock', 'Glenrock', 'Deer Creek Station,Glenrock,Glenrok,Mercedes,Nuttall,Nuttell,ge lun luo ke,ghlynrwk,glnrwk  waywmyng,Гленрок,Ґленрок,غلينروك,گلنروک، وایومینگ,格伦罗克', 42.8613600, -105.8722300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146606, 'Green River', 'Green River', 'Green River,Greenriver,Grijn Rivur,Grin River,Grin-River,ghryn ryfr,gryn rywr  waywmyng,gryn rywr  wayywmng,lu he,Грийн Ривър,Грин Ривер,Грин-Ривер,Ґрін-Рівер,غرين ريفر,گرین ریور، وائیومنگ,گرین ریور، وایومینگ,グリーン・リバー,绿河', 41.5285800, -109.4662500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146607, 'Greybull', 'Greybull', 'GEY,Grejbal,Grejbull,ge lei bo er,ghrybwl,grybwl  waywmyng,Грейбулл,Грејбал,Ґрейбулл,غريبول,گریبول، وایومینگ,格雷伯尔', 44.4891200, -108.0562100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146608, 'Guernsey', 'Guernsey', '', 42.2696900, -104.7416300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146609, 'Hoback', 'Hoback', '', 43.2818700, -110.7838100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146610, 'Jackson', 'Jackson', 'Dzekson,Dzhekson,JAC,Jackson,Teton,jaegseun,jakswn,jie ke xun,jkswn  waywmyng,jyksn  wywmng,Џексон,Джексон,جاكسون,جکسون، وایومینگ,جیکسن، ویومنگ,杰克逊,잭슨', 43.4799300, -110.7624300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146611, 'Kemmerer', 'Kemmerer', 'Kemerur,Kemmerer,kai mo lei,kmrr,kmrr  waywmyng,Кемерър,Кеммерер,كمرر,کمرر، وایومینگ,凯默勒', 41.7924500, -110.5376700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146612, 'Lander', 'Lander', 'Camp Brown,LND,Lander,Lender,Lendur,Push Root,lan de,landr,lndr  waywmyng,Ландер,Лендер,Лендър,لاندر,لانڈیر، وایومنگ,لندر، وایومینگ,兰德', 42.8330100, -108.7306700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146613, 'Laramie', 'Laramie', 'Gem City,LAR,Larami,Laramie,la lei mi,laeleomi,laramy,laramy  waywmng,laramy  waywmyng,rarami,Ларами,Ларамі,לאראמי,لارامي,لارامی، وایومنگ,لارامی، وایومینگ,ララミー,拉勒米,래러미', 41.3113700, -105.5911000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146614, 'Lovell', 'Lovell', 'Lovel,Lovell,POY,lawl  waywmyng,luo fu er,lwfyl,Ловел,Ловелл,لاول، وایومینگ,لوفيل,洛弗尔', 44.8374500, -108.3895600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146615, 'Lusk', 'Lusk', 'Lask,la si ke,lask,lwsk  waywmyng,Ласк,لاسك,لوسک، وایومینگ,拉斯克', 42.7624700, -104.4521700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146616, 'Lyman', 'Lyman', 'Lyman,Owen', 41.3274500, -110.2929300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146617, 'Marbleton', 'Marbleton', '', 42.5535500, -110.1093200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146618, 'Mills', 'Mills', '', 42.8405200, -106.3658600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146619, 'Moorcroft', 'Moorcroft', 'Moorcraft,Moorcroft', 44.2633100, -104.9502500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146620, 'Moose Wilson Road', 'Moose Wilson Road', '', 43.5252100, -110.8446600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146621, 'Mountain View', 'Mountain View', 'Mauntin Vju,Mauntin-V''ju,Mauntin-Vju,Mountain View,Mountainview,mang ting wei you,mawntn fyw,mawntn wyw  waywmyng,Маунтин Вју,Маунтин-Вью,Маунтін-Вю,ماؤنٹین ویو، وائیومنگ,ماونتن فيو,ماونتن ویو، وایومینگ,芒廷维尤', 41.2688400, -110.3398800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146622, 'Newcastle', 'Newcastle', 'ECS,N''jukasl,Njukasl,Njukasul,niu ka si er,nyukaeseul,nywkasl,nywkasl  waywmyng,Њукасл,Ньюкасл,Нюкасъл,نيوكاسل,نیوکاسل، وایومینگ,纽卡斯尔,뉴캐슬', 43.8547000, -104.2049400, 'US', '2017-05-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146623, 'North Rock Springs', 'North Rock Springs', '', 41.6435800, -109.2656800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146624, 'Pine Bluffs', 'Pine Bluffs', 'Pine Bluffs,Pinebluff,Rock Ranch', 41.1819300, -104.0691200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146625, 'Pinedale', 'Pinedale', 'PWY,Pajndejl,bayndyl,pai en,pyndal  waywmyng,Пайндейл,Пајндејл,باينديل,پیندال، وایومینگ,派恩', 42.8666100, -109.8609900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146626, 'Powell', 'Powell', 'Camp Colter,POY,Pauehll,Pauel,Pauell,Pauul,Powell,bao wei er,bawl,pawl  waywmyng,pawl  wayywmng,Пауел,Пауелл,Пауъл,Пауэлл,باول,پاول، وائیومنگ,پاول، وایومینگ,鲍威尔', 44.7538400, -108.7573500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146627, 'Rafter J Ranch', 'Rafter J Ranch', '', 43.4260400, -110.7990900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146628, 'Ranchettes', 'Ranchettes', '', 41.2185900, -104.7902500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146629, 'Rawlins', 'Rawlins', 'RWL,Rolins,Rolinz,luo lin si,ralynz  wayywmng,rwlynz,rwlynz  waywmyng,Ролинс,Ролінз,رالینز، وائیومنگ,رولينز,رولینز، وایومینگ,羅林斯', 41.7910700, -107.2386600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146630, 'Riverton', 'Riverton', 'RIW,Riverton,Rivurtun,li fu dun,ryfrtwn,rywrtwn  waywmyng,Ривертон,Ривъртън,Рівертон,ريفرتون,ریورتون، وایومینگ,ریورٹن، وائیومنگ,里弗顿', 43.0249600, -108.3801000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146631, 'Rock Springs', 'Rock Springs', 'RKS,Rok Springs,Rok-Springs,luo ke si pu lin,rak aspryngz  waywmyng,rak sprngz  wayywmng,rokkusupuringusu,Рок Спрингс,Рок-Спрингс,Рок-Спрінґс,راک اسپرینگز، وایومینگ,راک سپرنگز، وائیومنگ,ロックスプリングス,罗克斯普林', 41.5874600, -109.2029000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146632, 'Saratoga', 'Saratoga', 'Place of Magic Water,SAA,Saratoga,asrtwwga  waywmyng,sa la tuo jia,saratwgha,Саратога,Саратоґа,اسرتووگا، وایومینگ,ساراتوغا,萨拉托加', 41.4549600, -106.8064300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146633, 'Sheridan', 'Sheridan', 'Hoxomahoevehoeno,Hoxómâhoévehoéno,SHR,Sheridan,shrydn  waywmyng,shyrydan,xie li deng,Шеридан,شریدن، وایومینگ,شيريدان,شیئرڈن، وائیومنگ,谢里登', 44.7971900, -106.9561800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146634, 'Sleepy Hollow', 'Sleepy Hollow', '', 44.2410900, -105.4222200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146635, 'South Greeley', 'South Greeley', '', 41.0969300, -104.8063600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146636, 'South Park', 'South Park', '', 43.4221500, -110.7932600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146637, 'Sundance', 'Sundance', 'SUC,Sandehns,Sandens,Sundance,sandansu,sandns  waywmyng,sheng dan si,sndans,Санденс,Сандэнс,ساندنس، وایومینگ,صندانس,サンダンス,圣丹斯', 44.4063700, -104.3757800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146638, 'Thermopolis', 'Thermopolis', 'THP,Termopolis,se mo bo li si,thyrmwbwlys,trmwpwlys  waywmyng,Термополис,Термополіс,ترموپولیس، وایومینگ,ثيرموبوليس,瑟莫波利斯', 43.6460700, -108.2120400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146639, 'Torrington', 'Torrington', 'TOR,Torington,Toringtun,Torrington,tryngtwn  waywmyng,tuo lin dun,twrynghtwn,Торингтон,Торингтън,Торрингтон,Торрінґтон,ترینگتون، وایومینگ,تورينغتون,ٹورنگٹن، وائیومنگ,托林顿', 42.0624600, -104.1843900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146640, 'Upton', 'Upton', 'Irontown,Merino,Upton', 44.0997000, -104.6280200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146641, 'Wheatland', 'Wheatland', 'EAN,Gilchrist,Uitlend,Vitland,Vitlend,Wheatland,hui te lan,u~itorando,wytland,wytlnd  waywmyng,Витланд,Вітленд,Уитленд,ويتلاند,ویتلند، وایومینگ,ویٹلینڈ، وائیومنگ,ウィートランド,惠特兰', 42.0540700, -104.9529500, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146642, 'Wilson', 'Wilson', 'Uilson,Уилсон', 43.5007600, -110.8752100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146643, 'Worland', 'Worland', 'Uehrlend,Uorlend,Vorland,Vorlend,WRL,wo lan,wrland,wwrlnd  waywmyng,Ворланд,Ворленд,Уорленд,Уэрленд,ورلاند,وورلند، وایومینگ,وورلینڈ، وائیومنگ,沃兰', 44.0169000, -107.9553700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146644, 'Wright', 'Wright', 'Rajt,Райт', 43.7512400, -105.4920100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146645, 'Vineyard', 'Vineyard', '', 40.2970400, -111.7467000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146646, 'Fruitdale', 'Fruitdale', '', 42.4220600, -123.3081100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146647, 'Gold Beach', 'Gold Beach', 'Ellensburg,GOL,Gold Beach,Gold Bich,Gold Bijch,Gould Bich,Yan-shuu-chit''-dvn,ge er de bi qi,ghwld bytsh,gld bych  awrgn,goldeubichi,gorudobichi,Голд Бийч,Голд Бич,Гоулд Бич,غولد بيتش,گلد بیچ، اورگن,ゴールドビーチ,戈尔德比奇,골드비치', 42.4073300, -124.4217700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146648, 'American Fork', 'American Fork', 'American Fork,Amerikan Fork,Amerikan-Fork,Lake City,McArthurville,amrykan fwrk,amrykn fwrk  ywta,ya mei li jia fu ke,Американ Форк,Американ-Форк,آمریکن فورک، یوتا,أمريكان فورك,امیریکن فورک، یوٹاہ,亚美利加福克', 40.3769000, -111.7957600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146649, 'Palouse', 'Palouse', 'Palouse,Palouse City,Palusiidi', 46.9101700, -117.0757300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146650, 'Craig', 'Craig', 'CGA,Craig,Craig City,Craig Millar,Fish Egg,Krejg,ke lei ge,krega,kryg  alaska,krygh,Крейг,Крејг,كريغ,کریگ، آلاسکا,क्रेग,克雷格', 55.4763900, -133.1483300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146651, 'Haines', 'Haines', 'Chilcoot,Chilkat,Chilkoot,Daschu,Deshu,Dtehshuh,Gejns,HNS,Haines,Haines Mission,Khajns,Khejns,Kutkwutlu,Willard Mission,hai en si,he''insa,hynz,hynz  alaska,Гейнс,Хајнс,Хейнс,هينز,هینز، آلاسکا,हेइन्स,海恩斯', 59.2359500, -135.4453300, 'US', '2015-10-21', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146652, 'Kahalu‘u', 'Kahalu''u', 'Kahalu''u,Kahaluu,Kahalu‘u', 21.4575900, -157.8443100, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146653, 'Kahuku', 'Kahuku', 'Ka-huku,Kahuku', 21.6804800, -157.9523700, 'US', '2015-06-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146654, 'Kahului', 'Kahului', 'Kakhului,Kakhuluj,OGG,kafurui,kahulu''i,Кахулуи,Кахулуї,Кахулуј,קאהולואי,کاہولوی، ہوائی,कहुलुइ,カフルイ', 20.8895300, -156.4743200, 'US', '2015-03-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146655, 'Kailua', 'Kailua', 'Kailua,Kajlua,Lanikai,kai lu a,kailuhuva,kairua,Кајлуа,کائلوا، ہونولولو کاؤنٹی، ہوائی,कैलुहुवा,カイルア,凱盧阿', 21.4024100, -157.7405400, 'US', '2015-02-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146656, 'Kailua-Kona', 'Kailua-Kona', 'KOA,Kailau,Kailua,Kailua Kona,Kailua-Kona,Kairua,Kajlua,Kajlua-Kona,Kayakakoua,kailuva,kairua・kona,Каилуа-Кона,Кайлуа-Кона,Кајлуа,कैलुवा,カイルア・コナ', 19.6401600, -155.9991200, 'US', '2016-03-20', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146657, 'Kalāheo', 'Kalaheo', 'Homestead,Homesteads,Kalaheo,Kalāheo', 21.9241600, -159.5268600, 'US', '2015-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146658, 'Kalaoa', 'Kalaoa', '', 19.7286100, -155.9816700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146659, 'Kaneohe', 'Kaneohe', 'Kane''ohe,Kaneohe,Kāne‘ohe,NGF', 21.3999400, -157.7989500, 'US', '2016-06-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146660, 'Kapa‘a', 'Kapa''a', 'Kapaa', 22.0752100, -159.3189500, 'US', '2015-05-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146661, 'Kapaau', 'Kapaau', 'Kapa''au,Kapaau,Kapa‘au', 20.2338900, -155.8019400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146662, 'Kaunakakai', 'Kaunakakai', '', 21.0936300, -157.0261300, 'US', '2015-05-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146663, 'Kea‘au', 'Kea''au', 'Kea''au,Keaau,Kea‘au,Nine Miles,Olaa', 19.6226500, -155.0374400, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146664, 'Kealakekua', 'Kealakekua', 'Karacacooa,Karakakoa,Karakakoua,Ke-ala-ke-kua,Kealakeakua,Kealakekua', 19.5208300, -155.9225000, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146665, 'Kekaha', 'Kekaha', 'BKH', 21.9668600, -159.7118600, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146666, 'Kēōkea', 'Keokea', 'Keokea', 20.7071100, -156.3544600, 'US', '2015-05-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146667, 'Kīhei', 'Kihei', 'Kihei', 20.7646200, -156.4457800, 'US', '2015-05-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146668, 'Kīlauea', 'Kilauea', 'Kilauea', 22.2120800, -159.4134200, 'US', '2015-05-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146669, 'Koloa', 'Koloa', 'Koloa,Kōloa', 21.9069000, -159.4699400, 'US', '2016-07-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146670, 'Kualapu‘u', 'Kualapu''u', 'Kualapu''u,Kualapuu,Kualapu‘u', 21.1530600, -157.0367700, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146671, 'Kurtistown', 'Kurtistown', '', 19.6036100, -155.0572200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146672, 'Lahaina', 'Lahaina', 'Lahaina,Lakhajna,Lele,Lāhainā,Rahaina,laha''ina,rahaina,Лахајна,لاہاینا، ہوائی,लाहाइना,ラハイナ', 20.8742900, -156.6766300, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146673, 'Lā‘ie', 'La''ie', 'La''ie,Laie,Lā‘ie', 21.6454700, -157.9225000, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146674, 'Lanai City', 'Lanai City', 'LNY,Lana''i City,Lanai,Lanai City,Lāna‘i City', 20.8275700, -156.9239900, 'US', '2016-10-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146675, 'Lawai', 'Lawai', 'Lawa''i,Lawai,Lawa‘i', 21.9215900, -159.5037600, 'US', '2016-09-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146676, 'Leilani Estates', 'Leilani Estates', '', 19.4697200, -154.9177800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146677, 'Leilani Estates', 'Leilani Estates', '', 19.4675000, -154.9172200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146678, 'Lihue', 'Lihue', 'LIH,Lihu''e,Lihue,Lihu‘e,Likhue,Likhueh,Līhuʻe,li hu ai,lihue,lihyu,rifue,Лихуе,Лихуэ,ליהואה,लिह्यु,リフエ,利胡埃,리후에,리휴', 21.9812100, -159.3721000, 'US', '2017-07-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146679, 'Mā‘ili', 'Ma''ili', 'Ma''ili,Maili,Mā‘ili', 21.4162900, -158.1753100, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146680, 'Mākaha', 'Makaha', 'Makaha', 21.4662700, -158.2103700, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146681, 'Mākaha Valley', 'Makaha Valley', 'Makaha Valley', 21.4758300, -158.1991800, 'US', '2013-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146682, 'Makakilo City', 'Makakilo City', 'Makakilo,Makakilo City', 21.3469400, -158.0858300, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146683, 'Makawao', 'Makawao', 'Makauao,Makavao,maka''ova,Макавао,Макауао,मकाओवा', 20.8569400, -156.3130600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146684, 'Maunawili', 'Maunawili', '', 21.3727800, -157.7705600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146685, 'Mililani Town', 'Mililani Town', 'Mililani', 21.4500000, -158.0011100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146686, 'Mokulēia', 'Mokuleia', 'HDH,Mokuleia,Mokuleia Station,Mokulēia', 21.5796700, -158.1531300, 'US', '2017-06-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146687, 'Mountain View', 'Mountain View', 'Mauna Hu''ihu''i,Mauna Hu‘ihu‘i,Maunahu''ihu''i,Maunahu‘ihu‘i,Mauntin-V''ju,Mountain View,Mountainview,Маунтин-Вью', 19.5558300, -155.1080600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146688, 'Nānākuli', 'Nanakuli', 'Nanaikapono,Nanakuli,Nanakuli Station,Nānākuli', 21.3936200, -158.1542900, 'US', '2015-03-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146689, 'Nanawale Estates', 'Nanawale Estates', '', 19.5061100, -154.9119400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146690, 'Nanawale Estates', 'Nanawale Estates', '', 19.5069400, -154.9133300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146691, '‘Ōma‘o', '''Oma''o', '''Oma''o,Omao,‘Ōma‘o', 21.9258100, -159.4881800, 'US', '2015-05-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146692, 'Orchidlands Estates', 'Orchidlands Estates', '', 19.5608400, -155.0152700, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146693, 'Pāhala', 'Pahala', 'Pahaha,Pahala,Pāhala', 19.2029700, -155.4786000, 'US', '2015-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146694, 'Paia', 'Paia', 'Orpheum Village,Pa''ia,Paia,Pa‘ia', 20.9033300, -156.3694400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146695, 'Pāpa‘ikou', 'Papa''ikou', 'Papa''ikou,Papaikou,Pāpa‘ikou', 19.7871800, -155.0932600, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146696, 'Pearl City', 'Pearl City', '', 21.3973400, -157.9751600, 'US', '2015-05-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146697, 'Pepeekeo', 'Pepeekeo', 'Pepe''ekeo,Pepeekeo,Pepe‘ekeo', 19.8336100, -155.1072200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146698, 'Princeville', 'Princeville', '', 22.2175800, -159.4788800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146699, 'Puhi', 'Puhi', '', 21.9688800, -159.4001200, 'US', '2015-03-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146700, 'Pukalani', 'Pukalani', '', 20.8366700, -156.3366700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146701, 'Punalu‘u', 'Punalu''u', 'Punalu''u,Punaluu,Punaluu Park,Punalu‘u', 21.5704500, -157.8755700, 'US', '2013-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146702, 'Punaluu', 'Punaluu', '', 21.5738900, -157.8786100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146703, 'Pupukea', 'Pupukea', 'Pupukea,Pūpūkea', 21.6545600, -158.0606500, 'US', '2014-09-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146704, 'Village Park', 'Village Park', '', 21.3980600, -158.0302800, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146705, 'Volcano', 'Volcano', 'Volcano Village', 19.4427600, -155.2339800, 'US', '2014-08-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146706, 'Wahiawā', 'Wahiawa', 'Wahiawa', 21.5027900, -158.0246400, 'US', '2015-02-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146707, 'Waialua', 'Waialua', 'Puuiki,Waalua,Waialua,Waialua Farmlands,Waialua Mill,Waiarua,Wairua', 21.5768800, -158.1315400, 'US', '2015-10-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146708, 'Waialua', 'Waialua', '', 21.1002800, -156.7613900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146709, 'Waianae', 'Waianae', 'Waeanae,Wai''anae,Waianae,Waianai,Wainae,Wai‘anae', 21.4362100, -158.1863000, 'US', '2015-05-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146710, 'Waikapū', 'Waikapu', 'Waikapu', 20.8580600, -156.5069400, 'US', '2015-06-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146711, 'Waikoloa', 'Waikoloa', 'WKL,Waikoloa,Waikoloa Village', 19.9394200, -155.7893100, 'US', '2013-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146712, 'Waikoloa Village', 'Waikoloa Village', '', 19.9325000, -155.8277800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146713, 'Wailea', 'Wailea', '', 20.6897300, -156.4419000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146714, 'Wailua', 'Wailua', '', 22.0527100, -159.3378100, 'US', '2016-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146715, 'Wailua', 'Wailua', '', 20.8486100, -156.1363900, 'US', '2006-01-17', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146716, 'Wailuku', 'Wailuku', 'Vajluku,huai lu ku,vailuku,Вајлуку,وائلوکو، ہوائی,वैलुकु,怀卢库', 20.8913300, -156.5060400, 'US', '2015-05-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146717, 'Waimalu', 'Waimalu', '', 21.4047200, -157.9433300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146718, 'Waimanalo', 'Waimanalo', 'BLW,Waimanalo,Waimanalo Town,Waimanalo Village,Waimanolo', 21.3461400, -157.7238000, 'US', '2015-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146719, 'Waimānalo Beach', 'Waimanalo Beach', 'Waimanalo,Waimanalo Beach,Waimānalo Beach', 21.3340700, -157.7000300, 'US', '2015-02-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146720, 'Waimea', 'Waimea', 'Owaimea,Vaimea,Vajmija,Waimea,Whymea,Wymoa,vaimiya,waimea,Ваимеа,Вајмија,वैमिया,ワイメア', 21.9570700, -159.6689300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146721, 'Waimea', 'Waimea', 'Kamuela,MUE,Waimea,Waimea - Bis Island', 20.0232300, -155.6728800, 'US', '2016-01-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146722, 'Wainaku', 'Wainaku', 'Wainaku,Wainaku Landing,Wainaku Mill', 19.7447200, -155.0950000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146723, 'Waipahu', 'Waipahu', 'Vajpakhu,vaipahu,waipafu,Вајпаху,ואיפאהו,وائپاہو، ہوائی,वैपाहु,ワイパフ', 21.3866700, -158.0091700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146724, 'Waipio', 'Waipio', 'Waipio', 21.4182300, -157.9990600, 'US', '2015-02-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146725, 'Waipi‘o Acres', 'Waipi''o Acres', 'Waipi''o Acres,Waipio Acres,Waipi‘o Acres', 21.4648500, -158.0133100, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146726, 'Whitmore Village', 'Whitmore Village', 'Whitmore,Whitmore City,Whitmore Village', 21.5142900, -158.0246400, 'US', '2015-02-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146727, '‘Ele‘ele', '''Ele''ele', 'Eleele', 21.9073800, -159.5832200, 'US', '2015-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146728, '‘Ewa Beach', '''Ewa Beach', '''Ewa Beach,Ewa Beach,‘Ewa Beach', 21.3155600, -158.0072200, 'US', '2014-10-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146729, '‘Ewa Gentry', '''Ewa Gentry', '''Ewa Gentry,Ewa Gentry,‘Ewa Gentry', 21.3399900, -158.0303900, 'US', '2015-05-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146730, '‘Ewa Villages', '''Ewa Villages', '''Ewa Villages,Ewa Villages,‘Ewa Villages', 21.3412700, -158.0397000, 'US', '2015-05-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146731, 'Fern Acres', 'Fern Acres', '', 19.5122200, -155.0802800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146732, 'Hālawa', 'Halawa', 'Halawa', 21.3794400, -157.9216700, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146733, 'Hālawa Heights', 'Halawa Heights', 'Halawa Heights,Hālawa Heights', 21.3784800, -157.9138800, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146734, 'Hale‘iwa', 'Hale''iwa', 'Hale''iwa,Haleiwa,Hale‘iwa', 21.5928400, -158.1033900, 'US', '2017-06-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146735, 'Hana', 'Hana', 'HNM,Hana,Hāna', 20.7580600, -155.9902800, 'US', '2016-12-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146736, 'Hanamā‘ulu', 'Hanama''ulu', 'Hanamaulu', 21.9977300, -159.3591800, 'US', '2015-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146737, 'Hanapēpē', 'Hanapepe', 'Hanapepe', 21.9073300, -159.5944000, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146738, 'Hanapēpē Heights', 'Hanapepe Heights', 'Hanapepe Heights,Hanapēpē Heights', 21.9163300, -159.5899500, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146739, 'Hau‘ula', 'Hau''ula', 'Hau''ula,Hauula,Hau‘ula', 21.6076000, -157.9086800, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146740, 'Hawaiian Beaches', 'Hawaiian Beaches', '', 19.5430600, -154.9158300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146741, 'Hawaiian Acres', 'Hawaiian Acres', '', 19.5380600, -155.0522200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146742, 'Hawaiian Paradise Park', 'Hawaiian Paradise Park', '', 19.5933300, -154.9730600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146743, 'Hawaiian Ocean View', 'Hawaiian Ocean View', '', 19.0686100, -155.7650000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146744, 'Hāwī', 'Hawi', 'Hawi,Howi,Hāwī', 20.2412200, -155.8335100, 'US', '2015-05-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146745, 'He‘eia', 'He''eia', 'He''eia,Heeia,He‘eia', 21.4305400, -157.8161100, 'US', '2015-05-27', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146746, 'Hilo', 'Hilo', 'Baie de Hilo,Chilo,Hido,Hilas,Hilo,ITO,Khilo,hillo,hilo,hiro,hylw,xi lu,xi luo,Χίλο,Хило,Хіло,הילו,ہیلو، ہوائی,हिलो,ヒロ,希洛,希路,힐로', 19.7299100, -155.0907300, 'US', '2015-02-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146747, 'Hōlualoa', 'Holualoa', 'Holualoa', 19.6197900, -155.9483100, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146748, 'Honalo', 'Honalo', '', 19.5463900, -155.9319400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146749, 'Honoka‘a', 'Honoka''a', 'Honoka''a,Honokaa,Honoka‘a', 20.0793100, -155.4669100, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146750, 'Honolulu', 'Honolulu', 'Anorourou,Chonoloulou,Gana-Rura,Gana-ruru,Ganaruro,Ganaruru,Gonolulu,Gorad Ganalulu,HNL,Hana-Rura,Hana-Ruru,Hana-ruru,Honoloulou,Honolulu,Honolulú,Honolúlú,Honoruru,Khonolulu,Than-hiong-san,Thàn-hiông-sân,hanalulu,hanululu,honalulu,honollullu,honolulu,honoruru,hwnwlwlw,tan xiang shan,Χονολουλού,Гонолулу,Горад Ганалулу,Хонолулу,Һонолулу,Հոնոլուլու,האנאלולו,הונולולו,هونولولو,ہwnwlwlw  ہwayy,ہونولولو,ہونولولو، ہوائی,हानलूलू,होनालुलु,होनोलुलु,होनोलूलू,হনুলুলু,ହନଲୁଲୁ,ஹொனலுலு,ಹೊನೊಲುಲು,โฮโนลูลู,ཧོ་ནོ་ལུ་ལུ།,ဟိုနိုလူလူမြို့,ჰონოლულუ,ሆኖሉሉ,ホノルル,檀香山,호놀룰루', 21.3069400, -157.8583300, 'US', '2012-06-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146751, '‘Aiea', '''Aiea', '''Aiea,Aiae,Aiea,‘Aiea', 21.3822200, -157.9336100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146752, '‘Āhuimanu', '''Ahuimanu', '''Ahuimanu,Ahuimanu,‘Āhuimanu', 21.4447200, -157.8377800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146753, 'Iroquois Point', 'Iroquois Point', '', 21.3277600, -157.9830100, 'US', '2015-02-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146754, 'Ka‘a‘awa', 'Ka''a''awa', 'Kaaawa', 21.5544500, -157.8510300, 'US', '2015-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146755, 'Kā‘anapali', 'Ka''anapali', 'Ka''anapali,Kaanapali,Kā‘anapali', 20.9288100, -156.6942200, 'US', '2013-03-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146756, 'Kaanapali Landing', 'Kaanapali Landing', 'Kaanapali Landing', 20.9309000, -156.6877800, 'US', '2008-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146757, 'Ainaloa', 'Ainaloa', '', 19.5269400, -154.9930600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146758, 'Anahola', 'Anahola', '', 22.1422600, -159.3138800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146759, 'Captain Cook', 'Captain Cook', '', 19.4969400, -155.9216700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146760, 'Butte', 'Butte', '', 61.5422200, -149.0333300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146761, 'Chevak', 'Chevak', 'Cev''aq,Chevak,New Chevak,VAK', 61.5277800, -165.5863900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146762, 'Cohoe', 'Cohoe', '', 60.3686100, -151.3063900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146763, 'College', 'College', '', 64.8569400, -147.8027800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146764, 'Cordova', 'Cordova', 'CDV,Kordova,ke er duo wa,kodoba,kordobha,kwrdwfa,kwrdwwa  alaska,Кордова,كوردوفا,کوردووا، آلاسکا,कोर्दोभा,コードバ,科尔多瓦', 60.5432000, -145.7586700, 'US', '2017-06-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146765, 'Diamond Ridge', 'Diamond Ridge', '', 59.6761100, -151.5575000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146766, 'Dillingham', 'Dillingham', 'Ah-lek-nug-uk,Chogium,Chogiung,Curyuk,Curyung,DLG,Dilingkham,Dillingham,Dillingkhem,Dillinkhehm,Kanakanak,Ke-ek-sel-hak,Nelsonville,Nushagak,Snag Point,di lin e mu,dilingahyama,dylyngham  alaska,dylynjham,Дилингхам,Диллингхем,Диллинхэм,Діллінгхем,ديلينجهام,دیلینگهام، آلاسکا,ڈیلینگہیم، الاسکا,डिलिङ्गह्याम,迪林厄姆', 59.0397200, -158.4575000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146767, 'Dutch Harbor', 'Dutch Harbor', 'DUT,datchihaba,ダッチハーバー', 53.8898000, -166.5422000, 'US', '2011-04-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146768, 'Eagle River', 'Eagle River', '', 61.3213900, -149.5677800, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146769, 'Ester', 'Ester', 'Berry,Discovery,Ehster,Ester,Ester City,Esther,astr  alaska,estara,Естер,Эстер,استر، آلاسکا,एस्टर', 64.8472200, -148.0144400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146770, 'Fairbanks', 'Fairbanks', 'Barnettes Cache,FAI,Fairbanks,Fehrbanks,Fehrbenks,Ferbanks,Ferbenks,Ferbenksa,Feurbanks,Feyrbanks,Fērbenksa,feabankusu,fei er ban ke si,frbnks,fyrbanks,fyyr bynks  alaska,peeobaengkeuseu,pherabamksa,pheyarabyanksa,pyyrbnqs,Фербанкс,Фербенкс,Феърбанкс,Фэрбанкс,Фэрбенкс,פיירבנקס,فربنکس,فيربانكس,فیئر بینکس، الاسکا,फेयरब्याङ्क्स,फेरबँक्स,ფერბენკსი,フェアバンクス,費爾班克斯,페어뱅크스', 64.8377800, -147.7163900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146771, 'Fritz Creek', 'Fritz Creek', '', 59.7361100, -151.2952800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146772, 'Gateway', 'Gateway', '', 61.5727800, -149.2408300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146773, 'Girdwood', 'Girdwood', 'Girdwood,Girwood,Gridwood', 60.9425000, -149.1663900, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146774, 'Healy', 'Healy', 'Dry Creek,Healey Fork,Healy,Healy Fork', 63.8569400, -148.9661100, 'US', '2014-10-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146775, 'Homer', 'Homer', 'Gomer,HOM,Khomer,he ma,homa,homara,hwmr,hwmyr,mylr lndyng  alaska,Гомер,Хомер,הומר,میلر لندینگ، آلاسکا,هومير,ہومر، الاسکا,होमर,ホーマー,荷马', 59.6425000, -151.5494000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146776, 'Hooper Bay', 'Hooper Bay', 'Askeenac,Askinaghamiut,Askinak,Askinuk,HPB,Hooper Bay,Khuper Bej,Khuper-Bej,Naparagamuit,Napareyaramiut,Naparyaar,Naparyaraq,hu po wan,hupara be,hupeobei,hwbr bay,hwpr by  alaska,Хупер Беј,Хупер-Бей,هوبر باي,هوپر بی، آلاسکا,हूपर बे,胡珀湾,후퍼베이', 61.5311100, -166.0966700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146777, 'Houston', 'Houston', 'Houston,Houston Siding,Kh''juston,Хьюстон', 61.6302800, -149.8180600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146778, 'Kalifornsky', 'Kalifornsky', 'Kalifonski,Kalifonsky,Kalifornsky,Unhghenesditnu', 60.4183300, -151.2900000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146779, 'Kenai', 'Kenai', 'De Pawlofsk,ENA,Fort Kenai,Fort Nicholas,Kenai,Kenai Redoute,Kenaj,Kenay,Kinaj,Pavlovskaya,Redaute Saint Nikolaus,Redut Svataya Nikolaya,Saint Nicholas Fort,ji nai,kena''i,kinai,knay  alaska,kynay,kynayy  alaska,Кенай,Кинај,קנאי,كيناي,کنای، آلاسکا,کینائی، الاسکا,केनाइ,キナイ,基奈', 60.5544400, -151.2583300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146780, 'King Cove', 'King Cove', 'KVC,King Cove,King Cove Cannery,King''s Cove', 55.0608700, -162.3185300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146781, 'Kodiak', 'Kodiak', 'ADQ,Gavan Saint Pavla,Gorad Kadz''jak,Kad''jak,Kadiak,Kodiak,Kodiak uhartea,Kodijak,Paul''s Harbor,Pauls Harbor,Pavlovsk Gavan,Pavlovsky Gavan,Saint Paul,Saint Paul Harbor,Seleniye Pavlovskoy,Seleniye Pavlovskoy Gavani,Sun''aq,ke di ya ke,kodiaeg,kodiakku,kodiyaka,kwdyak,kwdyak  alaska,Горад Кадзьяк,Кадьяк,Кодијак,קודיאק,كودياك,کودیاک، آلاسکا,کوڈیاک، الاسکا,कोदियाक,コディアック,科迪亚克,코디액', 57.7900000, -152.4072200, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146782, 'Kotzebue', 'Kotzebue', 'Kee-kik-tag-ameut,Kigaktowruk,Kikikhtagyut,Kikiktagamute,Kikiktaruk,Kikitak,Kikitaruk,Kikitaruk Mission,Kocebu,Kotzebue,Kotzobue,OTZ,Qikiqtagruk,Qikiqtaġruk,ke ce bu,kotjebyu,kwtzabyw  alaska,kwtzbyw,Коцебу,كوتزبيو,کوتزابیو، الاسکا,کوتزه‌بیو، آلاسکا,कोत्जेब्यु,科策布', 66.8984600, -162.5980900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146783, 'Lazy Mountain', 'Lazy Mountain', '', 61.6261100, -148.9455600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146784, 'Meadow Lakes', 'Meadow Lakes', '', 61.6247200, -149.6011100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146785, 'Nikiski', 'Nikiski', 'Nikishka,Nikishka Number Two,Nikiski,Nikiski Wharf,North Kenai', 60.6902800, -151.2888900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146786, 'Nome', 'Nome', 'Anvil City,Citnacuaq,Nom,Nome,Nome City,Noum,OME,Sitnasuaq,nom,noma,nome,nomu,nuo mu,nwm,nwm  alaska,nwmy,Ном,Ноум,נום,نوم، آلاسکا,نوم، الاسکا,نومي,नोम,नोमे,ノーム,诺姆,놈', 64.5011100, -165.4063900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146787, 'North Pole', 'North Pole', 'Nort Pol,Nort-Poul,bei ji,nartha pola,nosuporu,nwrth bwl,nwrth pwl  alaska,Норт Пол,Норт-Поул,نورث بول,نورث پول، آلاسکا,नर्थ पोल,ノースポール,北极', 64.7511100, -147.3494400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146788, 'Palmer', 'Palmer', 'Farmington,PAQ,Palmer,Palmer Siding,Warton,balmr,pa er mo,palmara,palmr  alaska,pama,pamr  alaska,Палмер,פאלמר,بالمر,پالمر، آلاسکا,پامر، الاسکا,पाल्मर,パーマー,帕尔默', 61.5994100, -149.1145600, 'US', '2017-05-29', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146789, 'Prudhoe Bay', 'Prudhoe Bay', 'PUO,Prudhoe Bay,SCC', 70.2552800, -148.3372200, 'US', '2017-06-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146790, 'Ridgeway', 'Ridgeway', '', 60.5319400, -151.0852800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146791, 'Sand Point', 'Sand Point', 'Qagun Tayagungin,SDP,Sand Point,Sand Pojnt,Sand-Pojnt,Sandpoint,sand bwynt,sang de bo yin te,snd pwynt  alaska,syanda po''inta,Санд Појнт,Санд-Пойнт,ساند بوينت,سند پوینت، آلاسکا,स्यान्ड पोइन्ट,桑德波因特', 55.3365500, -160.4988000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146792, 'Seward', 'Seward', 'Qutalleq,S''juard,SWD,Seward,Sivard,Sivod,sevarda,su e de,suwado,swward  alaska,syueodeu,syward,Сивод,Сьюард,سووارد، آلاسکا,سيوارد,سیویرڈ، الاسکا,सेवार्द,スワード,苏厄德,슈어드', 60.1042600, -149.4435000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146793, 'Soldotna', 'Soldotna', 'Kenai Junction,SXQ,Soldatna,Soldotna,soldotna,suo er duo te na,swldwtna,swldwtna  alaska,Солдотна,سولدوتنا,سولدوتنا، آلاسکا,سولڈاٹنا، الاسکا,सोल्दोत्ना,索尔多特纳', 60.4877800, -151.0583300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146794, 'Sterling', 'Sterling', 'Naptowne,Sterling,Стерлинг', 60.5372200, -150.7647200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146795, 'Tanaina', 'Tanaina', '', 61.6269400, -149.4280600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146796, 'Tok', 'Tok', 'TKJ,Tok,Tok Junction,toka,twk  alaska,Ток,توک، آلاسکا,तोक', 63.3366700, -142.9855600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146797, 'Unalaska', 'Unalaska', 'Analaska,Gavanskoe,Gavanskoe Selenie,Gavanskoi,Il''lyuulyug,Iliuliuk,Iliuliuk Village,Iljljuljuk,Illiouliouk,Illoolook,Illyulyuk,Iluulax,Iluulux,Iluulux̂,Isola di Unalaska,Oonalaska,Ounalaska,Unalashka,Unalashkae,Unalaska,Unalaška,Unaljaska,awnalaska,eoneollaeseuka seom,unalashka,unalaska,unarasuka,wu na la si ka,Аналаска,Уналаска,Уналашкæ,Уналашка,Уналяска,אנאלסקה,أونالاسكا,उनालस्का,ウナラスカ,乌纳拉斯卡,어널래스카 섬', 53.8736100, -166.5366700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146798, 'Valdez', 'Valdez', 'Copper City,Old Valdez,Suacit,VDZ,Valdes,Valdez,Valdiz,barudizu,bhaldeja,faldyz,wa er di ci,waldyz  alaska,waldz  alaska,Валдиз,Валдіз,فالديز,والدز، آلاسکا,والدیز، الاسکا,भाल्देज,バルディーズ,瓦尔迪兹', 61.1308300, -146.3483300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146799, 'Wasilla', 'Wasilla', 'Uasilla,Vasila,Vasilla,WWA,Washila,Wasilla,Wassila,vasila,vasilla,wa xi la,washira,wasilla,wasyla,wysyla  alaska,Васила,Василла,Васілла,Уасилла,ואסילה,واسيلا,واسیلا,ویسیلا، الاسکا,वासिला,वासिल्ला,ワシラ,瓦西拉,와실라', 61.5809000, -149.4415000, 'US', '2017-07-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146800, 'Willow', 'Willow', 'WOW,Willow,Willow Creek,Willow Station', 61.7472200, -150.0375000, 'US', '2014-04-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146801, 'Akutan', 'Akutan', 'Achan-ingiiga,Akutan,KQA,a ku tan,akutana,akwtan,akwtan  alaska,Акутан,آکوتان، آلاسکا,أكوتان,अकुतान,阿库坦', 54.1335000, -165.7768600, 'US', '2017-05-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146802, 'Anchorage', 'Anchorage', 'ANC,Alaska City,An''koreitz,Anchorage,Ancoraria,Angits,Ankoric,Ankoridz,Ankoridza,Ankoridzas,Ankoridzh,Ankoridž,Ankoridža,Ankoridžas,Ankorij,Ankuridzh,Brownville,Dgheyay Kaq'',Enkoridz,Gorad Ankorydzh,Kisagvik,Kisaġvik,Port Woodrow,Qatuk''e''usht,Ship Creek,Tan,Ves Dnaghildeqt,Woodrow,aengkeoliji,amkareja,an ke la zhi,ancorage byuro,ankarej,ankarejji,ankwryj,aynkrayj  alaska,enkarej,enkoreja,ʼnqwrg,Ανκορέιτζ,Анкоридж,Анкъридж,Горад Анкорыдж,Енкориџ,Անքորեջ շրջան,אנקורג,أنكوريج,انکوریج,اینکرایج، الاسکا,अँकरेज,एंकोरेज,অ্যাংকারিজ,আন্চোরগে ব্যুরো,ஏங்கரெஜ்,ആങ്കറേജ്,ანკორიჯი,アンカレッジ,安克拉治,앵커리지', 61.2180600, -149.9002800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146803, 'Anchor Point', 'Anchor Point', '', 59.7766700, -151.8313900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146804, 'Badger', 'Badger', '', 64.8000000, -147.5333300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146805, 'Barrow', 'Barrow', 'BRW,Barou,Barrou,Barrow,Borrou,Mis Barrou,Utqiagvik,Utqiaġvik,ba luo,baelo,baro,barw,barw  alaska,byaro,byrw  alaska,Бароу,Барроу,Мис Барроу,بارو,بارو، آلاسکا,بیرو، الاسکا,ब्यारो,バロー,巴羅,배로', 71.2905800, -156.7887200, 'US', '2017-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146806, 'Bear Creek', 'Bear Creek', '', 60.1641700, -149.3950000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146807, 'Bethel', 'Bethel', 'BET,Betel,Bethel,Mamterilleq,Mamtrelich,Mumtreekhlagamute,Mumtrekhlagamute,Mumtrekkhlogamute,Mumtrelega,Mumtrelegamut,Uuyarmiut,beseol,beseru,bethela,bo te li,btl  alaska,bythl,Бетел,בתאל,بتل، آلاسکا,بيثل,बेथेल,ベセル,伯特利,베설', 60.7922200, -161.7558300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146808, 'Big Lake', 'Big Lake', 'BGQ', 61.5213900, -149.9544400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146809, 'Milton', 'Milton', 'City of Milton,Milton', 34.1321600, -84.3006700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146810, 'Johns Creek', 'Johns Creek', 'City of Johns Creek,Dzons Krik,Johns Creek,janz kryk  jarjya,janz kryk  jwrjya,jonseukeulig,jwnz kryk,Џонс Крик,جانز کریک، جارجیا,جانز کریک، جورجیا,جونز كريك,존스크릭', 34.0289300, -84.1985800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146811, 'Grant-Valkaria', 'Grant-Valkaria', 'Grant,Grant-Valkaria,Town of Grant-Valkaria,Valkaria', 27.9398000, -80.5710400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146812, 'Helena-West Helena', 'Helena-West Helena', 'Helena,Helena-West Helena,Khelena-Vest Khelena,West Helena,herena=u~esutoherena,hlna wst hlna,hylyna wyst hylana,Хелена-Вест Хелена,هلنا وست هلنا,هيلينا ويست هيلانا,ヘレナ＝ウェストへレナ', 34.5291000, -90.5900000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146813, 'Summerset', 'Summerset', 'City of Summerset,Summerset', 44.1899800, -103.3438400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146814, 'Columbus', 'Columbus', 'City of Columbus,Columbus,Kolumbus,Колумбус', 45.2652200, -93.0501500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146815, 'Cutler Bay', 'Cutler Bay', 'Cutler Bay,Cutler Ridge,Katler Bej,Katler-Bej,Lakes by the Bay,Town of Cutler Bay,ka te lei wan,katlara rija,katlr by  flwryda,kwtlr bay,Катлер Беј,Катлер-Бей,كوتلر باي,کاتلر بی، فلوریدا,कट्लर रीज,卡特勒湾', 25.5783000, -80.3377000, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146816, 'Alafaya', 'Alafaya', '', 28.5641000, -81.2114000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146817, 'New Fairview', 'New Fairview', 'Fairview,New Fairview', 33.0991700, -97.4463900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146818, 'Cobb Island', 'Cobb Island', '', 38.2584600, -76.8438600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146819, 'St Johnsbury', 'St Johnsbury', '', 44.4252600, -72.0151200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146820, 'Dayton', 'Dayton', '', 43.5497200, -70.5755500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146821, 'Stevenson Ranch', 'Stevenson Ranch', '', 34.3904800, -118.5737200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146822, 'Eastchester', 'Eastchester', '', 40.9575400, -73.8097600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146823, 'Holly Lake Ranch', 'Holly Lake Ranch', '', 32.7133600, -95.1975600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146824, 'Village of Campton Hills', 'Village of Campton Hills', 'Campton Hills', 41.9366000, -88.3975000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146825, 'Fort Bragg', 'Fort Bragg', 'FBG,Fort Brag,Fort Bragg,Fort Bregg,Fort-Brehgg,Ft. Bragg,fwrt brg,poteu beulaegeu,Форт Браг,Форт Брегг,Форт-Брэгг,פורט בראג,فورت برگ,포트 브래그', 35.1390000, -79.0060300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146826, 'Kapolei', 'Kapolei', 'JRF,Kapolei,Kapolej,kaporei,Каполей,Каполеј,کاپولئی، ہوائی,カポレイ', 21.3355500, -158.0582000, 'US', '2017-03-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146827, 'Elko New Market', 'Elko New Market', 'City of Elko New Market,Elko New Market', 44.5647200, -93.3269400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146828, 'South Blooming Grove', 'South Blooming Grove', 'South Blooming Grove,South Blooming Grove Village,Village of South Blooming Grove', 41.3733700, -74.1784300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146829, 'Dewey-Humboldt', 'Dewey-Humboldt', 'Dewey,Dewey-Humboldt,Humboldt,Town of Dewey-Humboldt', 34.5300000, -112.2422200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146830, 'City of Milford (balance)', 'City of Milford (balance)', '', 41.2237400, -73.0616400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146831, 'Peppermill Village', 'Peppermill Village', 'Carmody Hills-Pepper Mill Village,Pepper Mill Village,Peppermill Village', 38.8947200, -76.8865400, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146832, 'Boulevard Gardens', 'Boulevard Gardens', '', 26.1232600, -80.1799700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146833, 'High Point', 'High Point', '', 28.5468700, -82.5246800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146834, 'Roosevelt Gardens', 'Roosevelt Gardens', '', 26.1408700, -80.1802700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146835, 'Butte-Silver Bow (Balance)', 'Butte-Silver Bow (Balance)', 'Butte-Silver Bow,Butte-Silver Bow (Balance)', 45.9019400, -112.6570800, 'US', '2013-03-08', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146836, 'City of Sammamish', 'City of Sammamish', '', 47.6044400, -122.0376800, 'US', '2014-09-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146837, 'Bayview', 'Bayview', '', 38.0070200, -122.3187800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146838, 'Las Maravillas', 'Las Maravillas', '', 34.7381500, -106.6685400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146839, 'Monterey Park', 'Monterey Park', '', 34.7589800, -106.6408500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146840, 'Peaceful Valley', 'Peaceful Valley', '', 48.9381500, -122.1473300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146841, 'Rancho Tehama Reserve', 'Rancho Tehama Reserve', '', 40.0156900, -122.4007200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146842, 'Rio Communities', 'Rio Communities', '', 34.6495900, -106.7340300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146843, 'Silver Firs', 'Silver Firs', '', 47.8660200, -122.1551000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146844, 'Verde Village', 'Verde Village', 'Cottonwood-Verde Village', 34.7105000, -112.0115200, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146845, 'Vineyard', 'Vineyard', '', 38.4644900, -121.3469200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146846, 'Chattahoochee Hills', 'Chattahoochee Hills', 'Chattahoochee Hill Country,Chattahoochee Hills', 33.5506300, -84.7604900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146847, 'Desert Edge', 'Desert Edge', '', 33.9241700, -116.4413900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146848, 'Fox Chase', 'Fox Chase', 'Fox Chase,Foxchase', 40.3955700, -75.9621600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146849, 'Saint Augustine South', 'Saint Augustine South', '', 29.8424900, -81.3144800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146850, 'Captains Cove', 'Captains Cove', '', 37.9899600, -75.4227200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146851, 'Weston Lakes', 'Weston Lakes', '', 29.6832400, -95.9357100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146852, 'North Castle', 'North Castle', '', 41.1400000, -73.6838900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146853, 'Saddle Brooke', 'Saddle Brooke', '', 32.5347200, -110.8736100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146854, 'Conning Towers-Nautilus Park', 'Conning Towers-Nautilus Park', 'Conning Towers-Nautilus Park,Conning Towers-Nautilus Park CDP,Conning Towers-Nautilus Park Census Designated Place', 41.3854800, -72.0687700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146855, 'Deep River Center', 'Deep River Center', 'Deep River Center,Deep River Center CDP', 41.3822100, -72.4386200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146856, 'Essex Village', 'Essex Village', 'Essex Village,Essex Village CDP', 41.3554400, -72.3910100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146857, 'Guilford Center', 'Guilford Center', 'Guilford Center,Guilford Center CDP', 41.2815600, -72.6761900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146858, 'Madison Center', 'Madison Center', 'Madison Center,Madison Center CDP', 41.2792500, -72.6004800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146859, 'New Hartford Center', 'New Hartford Center', 'New Hartford Center,New Hartford Center CDP', 41.8799600, -72.9753000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146860, 'Northwest Harwinton', 'Northwest Harwinton', 'Northwest Harwinton,Northwest Harwinton CDP', 41.7768500, -73.0792200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146861, 'Old Saybrook Center', 'Old Saybrook Center', 'Old Saybrook Center,Old Saybrook Center CDP', 41.2915000, -72.3652800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146862, 'Oxoboxo River', 'Oxoboxo River', 'Oxoboxo River,Oxoboxo River CDP', 41.4439100, -72.1250200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146863, 'Plainfield Village', 'Plainfield Village', 'Plainfield Village,Plainfield Village CDP', 41.6768600, -71.9248900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146864, 'Simsbury Center', 'Simsbury Center', 'Simsbury Center,Simsbury Center CDP', 41.8808800, -72.8111600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146865, 'Wallingford Center', 'Wallingford Center', 'Wallingford Center,Wallingford Center CDP', 41.4498700, -72.8189200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146866, 'Westbrook Center', 'Westbrook Center', 'Westbrook Center,Westbrook Center CDP', 41.2799700, -72.4425400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146867, 'Woodbury Center', 'Woodbury Center', 'Woodbury Center,Woodbury Center CDP', 41.5445300, -73.2047600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146868, 'Acushnet Center', 'Acushnet Center', 'Acushnet Center,Acushnet Center CDP', 41.6850800, -70.9064200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146869, 'Green Harbor-Cedar Crest', 'Green Harbor-Cedar Crest', 'Green Harbor-Cedar Crest,Green Harbor-Cedar Crest CDP', 42.0749500, -70.6584300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146870, 'Harwich Center', 'Harwich Center', 'Harwich Center,Harwich Center CDP', 41.6923500, -70.0693800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146871, 'Hillsborough', 'Hillsborough', 'Hillsboro,Hillsborough,Hillsborough CDP', 43.1141000, -71.8992000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146872, 'Tilton-Northfield', 'Tilton-Northfield', 'Tilton-Northfield,Tilton-Northfield CDP,Tilton-Northfield Census Designated Place', 43.4430000, -71.5936400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146873, 'Barrington', 'Barrington', 'Barrington,Barrington CDP', 41.7342400, -71.3192900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146874, 'Newport East', 'Newport East', 'Newport East,Newport East CDP', 41.5157900, -71.2875200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146875, 'Wakefield-Peacedale', 'Wakefield-Peacedale', 'Wakefield-Peacedale,Wakefield-Peacedale CDP', 41.4460600, -71.5004000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146876, 'West Warwick', 'West Warwick', 'West Warwick,West Warwick CDP', 41.6796400, -71.5217800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146877, 'Mansfield Center', 'Mansfield Center', 'Mansfield Center,Mansfield Center CDP', 42.0226200, -71.2180800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146878, 'Marion Center', 'Marion Center', 'Marion Center,Marion Center CDP', 41.7042400, -70.7628600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146879, 'Mattapoisett Center', 'Mattapoisett Center', 'Mattapoisett Center,Mattapoisett Center CDP', 41.6659500, -70.8072000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146880, 'Middleborough Center', 'Middleborough Center', 'Middleborough Center,Middleborough Center CDP', 41.8946000, -70.9261800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146881, 'Millis-Clicquot', 'Millis-Clicquot', 'Millis-Clicquot,Millis-Clicquot CDP', 42.1648000, -71.3544200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146882, 'Monson Center', 'Monson Center', 'Monson Center,Monson Center CDP', 42.0989800, -72.3048100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146883, 'Northwest Harwich', 'Northwest Harwich', 'Northwest Harwich,Northwest Harwich CDP', 41.6902900, -70.1025000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146884, 'Norton Center', 'Norton Center', 'Norton Center,Norton Center CDP', 41.9725400, -71.1853500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146885, 'Ocean Bluff-Brant Rock', 'Ocean Bluff-Brant Rock', 'Ocean Bluff-Brant Rock,Ocean Bluff-Brant Rock CDP', 42.1023400, -70.6573600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146886, 'Bethlehem Village', 'Bethlehem Village', 'Bethlehem Village,Bethlehem Village CDP', 41.6401000, -73.2030800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146887, 'Branford Center', 'Branford Center', 'Branford Center,Branford Center CDP', 41.2773800, -72.8151100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146888, 'Central Waterford', 'Central Waterford', 'Central Waterford,Central Waterford CDP,Central Waterford Census Designated Place', 41.3450400, -72.1294800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146889, 'Cheshire Village', 'Cheshire Village', 'Cheshire Village,Cheshire Village CDP', 41.5026000, -72.8995200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146890, 'Chester Center', 'Chester Center', 'Chester Center,Chester Center CDP', 41.4013200, -72.4527000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146891, 'Fairview-Ferndale', 'Fairview-Ferndale', 'Fairview-Ferndale,Fairview-Ferndale CDP', 40.7803700, -76.5752800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146892, 'Fort Belvoir', 'Fort Belvoir', 'DAA,Fort Belvar,Fort Belvoir,Fort Belvoir CDP,Fort Belvor,fwrt blwwar,Форт Белвар,Форт Белвор,فورت بلووار', 38.7119000, -77.1458900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146893, 'Fort Drum', 'Fort Drum', 'Fort Dram,Fort Drum,Fort Drum CDP,de la mu bao,Форт Драм,德拉姆堡', 44.0584300, -75.7618900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146894, 'Fort Lee', 'Fort Lee', 'Fort Lee,Fort Lee CDP,Ft. Lee', 37.2469400, -77.3344200, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146895, 'Fort Meade', 'Fort Meade', 'FME,Fort George Meade,Fort Meade,Fort Meade CDP', 39.1081500, -76.7432300, 'US', '2013-04-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146896, 'Aberdeen Proving Ground', 'Aberdeen Proving Ground', 'Aberdeen Proving Ground,Aberdeen Proving Ground CDP', 39.4668600, -76.1306600, 'US', '2016-12-12', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146897, 'Andrews AFB', 'Andrews AFB', 'ADW,Andrews AFB,Andrews AFB CDP,Andrews AFB Census Designated Place,Andrews Air Force Base,Andrews Air Force Base CDP,Andrews Air Force Base Census Designated Place', 38.8053100, -76.8746000, 'US', '2014-04-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146898, 'Ashton-Sandy Spring', 'Ashton-Sandy Spring', 'Ashton-Sandy Spring,Ashton-Sandy Spring CDP', 39.1497600, -77.0050400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146899, 'Beaverdam Lake-Salisbury Mills', 'Beaverdam Lake-Salisbury Mills', 'Beaverdam Lake-Salisbury Mills,Beaverdam Lake-Salisbury Mills CDP', 41.4416200, -74.1162900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146900, 'Bel Air North', 'Bel Air North', 'Bel Air North,Bel Air North CDP', 39.5542900, -76.3730900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146901, 'Bel Air South', 'Bel Air South', 'Bel Air South,Bel Air South CDP', 39.5050600, -76.3197700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146902, 'Brittany Farms-Highlands', 'Brittany Farms-Highlands', 'Brittany Farms-Highlands,Brittany Farms-Highlands CDP,Brittany Farms-Highlands Census Designated Place', 40.2690100, -75.2140100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146903, 'Carmel Hamlet', 'Carmel Hamlet', 'Carmel Hamlet,Carmel Hamlet CDP', 41.4148500, -73.6852400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146904, 'Carnot-Moon', 'Carnot-Moon', 'Carnot-Moon,Carnot-Moon CDP', 40.5185600, -80.2173600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146905, 'Cecil-Bishop', 'Cecil-Bishop', 'Cecil-Bishop,Cecil-Bishop CDP', 40.3181900, -80.1933100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146906, 'Coeymans', 'Coeymans', 'Coeymans,Coeymans CDP', 42.4749100, -73.7956200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146907, 'Conneaut Lakeshore', 'Conneaut Lakeshore', 'Conneaut Lakeshore,Conneaut Lakeshore CDP', 41.6271100, -80.3100800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146908, 'Cortland West', 'Cortland West', 'Cortland West,Cortland West CDP', 42.5943100, -76.2258700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146909, 'Dover Base Housing', 'Dover Base Housing', 'Dover Base Housing,Dover Base Housing CDP', 39.1176300, -75.4839300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146910, 'Dunkirk', 'Dunkirk', 'Dunkirk,Dunkirk CDP', 38.7156000, -76.6729700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146911, 'East Hampton North', 'East Hampton North', 'East Hampton North,East Hampton North CDP', 40.9727600, -72.1891100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146912, 'McGuire AFB', 'McGuire AFB', 'McGuire AFB,McGuire AFB CDP,McGuire AFB Census Designated Place', 40.0397700, -74.5817400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146913, 'Moorestown-Lenola', 'Moorestown-Lenola', 'Moorestown-Lenola,Moorestown-Lenola CDP', 39.9659100, -74.9644100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146914, 'Mount Gay-Shamrock', 'Mount Gay-Shamrock', 'Mount Gay-Shamrock,Mount Gay-Shamrock CDP', 37.8385700, -82.0297000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146915, 'Mount Vernon', 'Mount Vernon', 'Maunt Vernon,Mount Vernon,Mount Vernon CDP,Маунт Вернон,ماؤنٹ ورنن، ورجینیا', 38.7191900, -77.1072600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146916, 'Naval Academy', 'Naval Academy', 'Naval Academy,Naval Academy CDP', 38.9856800, -76.4877400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146917, 'New Castle Northwest', 'New Castle Northwest', 'New Castle Northwest,New Castle Northwest CDP', 41.0220800, -80.3568200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146918, 'North Ballston Spa', 'North Ballston Spa', 'North Ballston Spa,North Ballston Spa CDP', 43.0196900, -73.8510900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146919, 'Northeast Ithaca', 'Northeast Ithaca', 'Northeast Ithaca,Northeast Ithaca CDP', 42.4703200, -76.4622800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146920, 'Northwest Harborcreek', 'Northwest Harborcreek', 'Northwest Harborcreek,Northwest Harborcreek CDP', 42.1494400, -79.9946300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146921, 'Northwest Ithaca', 'Northwest Ithaca', 'Northwest Ithaca,Northwest Ithaca CDP', 42.4705900, -76.5414500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146922, 'Paramount-Long Meadow', 'Paramount-Long Meadow', 'Paramount-Long Meadow,Paramount-Long Meadow CDP', 39.6804200, -77.6929000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146923, 'Plattsburgh West', 'Plattsburgh West', 'Plattsburgh West,Plattsburgh West CDP', 44.6831500, -73.5029500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146924, 'Pymatuning Central', 'Pymatuning Central', 'Pymatuning Central,Pymatuning Central CDP', 41.5854600, -80.4796000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146925, 'Quantico Station', 'Quantico Station', 'Quantico Station,Quantico Station CDP,Quantico Station Census Designated Place', 38.5226300, -77.3183400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146926, 'Remsenburg-Speonk', 'Remsenburg-Speonk', 'Remsenburg-Speonk,Remsenburg-Speonk CDP', 40.8264200, -72.6967300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146927, 'Rising Sun-Lebanon', 'Rising Sun-Lebanon', 'Rising Sun-Lebanon,Rising Sun-Lebanon CDP', 39.0997700, -75.5048800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146928, 'Rosendale Village', 'Rosendale Village', 'Rosendale,Rosendale Hamlet,Rosendale Village,Rosendale Village CDP,Rosendale Village Census Designated Place,Rosendejl Khamlet,Росендејл Хамлет', 41.8503800, -74.0737900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146929, 'Leisure World', 'Leisure World', 'Leisure World,Rossmoor CDP,Rossmoor Census Designated Place', 39.1023000, -77.0689800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146930, 'Fountainhead-Orchard Hills', 'Fountainhead-Orchard Hills', 'Fountainhead-Orchard Hills,Fountainhead-Orchard Hills CDP', 39.6863600, -77.7190100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146931, 'Friendship Village', 'Friendship Village', 'Friendship Village,Friendship Village CDP,Friendship Village Census Designated Place', 38.9632200, -77.0900200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146932, 'Glens Falls North', 'Glens Falls North', 'Glens Falls North,Glens Falls North CDP', 43.3350600, -73.6825100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146933, 'Greenport West', 'Greenport West', 'Greenport West,Greenport West CDP', 41.1017800, -72.3719500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146934, 'Guilford', 'Guilford', 'Guilford,Guilford CDP', 39.9154100, -77.6010500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146935, 'Holiday City South', 'Holiday City South', 'Holiday City South,Holiday City South CDP', 39.9532400, -74.2377800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146936, 'Holiday City-Berkeley', 'Holiday City-Berkeley', 'Holiday City-Berkeley,Holiday City-Berkeley CDP', 39.9638000, -74.2780300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146937, 'Homeacre-Lyndora', 'Homeacre-Lyndora', 'Homeacre-Lyndora,Homeacre-Lyndora CDP', 40.8720600, -79.9206000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146938, 'Horseheads North', 'Horseheads North', 'Horseheads North,Horseheads North CDP', 42.1927800, -76.8078200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146939, 'Huntingtown', 'Huntingtown', 'Huntingtown,Huntingtown CDP', 38.6116500, -76.6186500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146940, 'Jamestown West', 'Jamestown West', 'Jamestown West,Jamestown West CDP', 42.0885100, -79.2811000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146941, 'Jefferson Valley-Yorktown', 'Jefferson Valley-Yorktown', 'Jefferson Valley-Yorktown,Jefferson Valley-Yorktown CDP', 41.3179700, -73.8006600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146942, 'Lebanon South', 'Lebanon South', 'Lebanon South,Lebanon South CDP', 40.3280400, -76.4064400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146943, 'Leisure Village West-Pine Lake Park', 'Leisure Village West-Pine Lake Park', 'Leisure Village West-Pine Lake Park,Leisure Village West-Pine Lake Park CDP', 40.0041600, -74.2662900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146944, 'Leith-Hatfield', 'Leith-Hatfield', 'Leith-Hatfield,Leith-Hatfield CDP', 39.8774400, -79.7313300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146945, 'Lynnwood-Pricedale', 'Lynnwood-Pricedale', 'Lynnwood-Pricedale,Lynnwood-Pricedale CDP', 40.1307100, -79.8513500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146946, 'Saugerties South', 'Saugerties South', 'Saugerties South,Saugerties South CDP', 42.0613900, -73.9506700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146947, 'Setauket-East Setauket', 'Setauket-East Setauket', 'Setauket-East Setauket,Setauket-East Setauket CDP', 40.9306400, -73.1017900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146948, 'Shanor-Northvue', 'Shanor-Northvue', 'Shanor-Northvue,Shanor-Northvue CDP', 40.9104500, -79.9156200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146949, 'South Park Township', 'South Park Township', 'South Park Township,South Park Township CDP', 40.2986400, -79.9940500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146950, 'Village Green-Green Ridge', 'Village Green-Green Ridge', 'Village Green-Green Ridge,Village Green-Green Ridge CDP', 39.8636300, -75.4254800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146951, 'Weissport East', 'Weissport East', 'Weissport East,Weissport East CDP', 40.8369700, -75.6864300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146952, 'Whitesboro-Burleigh', 'Whitesboro-Burleigh', 'Whitesboro-Burleigh,Whitesboro-Burleigh CDP', 39.0430500, -74.8653800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146953, 'Whittingham', 'Whittingham', 'Whittingham,Whittingham CDP', 40.3298200, -74.4451100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146954, 'Wickerham Manor-Fisher', 'Wickerham Manor-Fisher', 'Wickerham Manor-Fisher,Wickerham Manor-Fisher CDP', 40.1774900, -79.9068400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146955, 'Wilson-Conococheague', 'Wilson-Conococheague', 'Wilson-Conococheague,Wilson-Conococheague CDP', 39.6535100, -77.8315700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146956, 'Woodside East', 'Woodside East', 'Woodside East,Woodside East CDP', 39.0675600, -75.5374800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146957, 'Fort Leonard Wood', 'Fort Leonard Wood', 'Fort Leonard Wood,Fort Leonard Wood CDP,TBN,フォート・レオナード・ウッド', 37.7057300, -92.1571700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146958, 'Fort Riley North', 'Fort Riley North', 'Fort Riley North,Fort Riley North CDP,Fort Riley North Census Designated Place', 39.1108100, -96.8139200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146959, 'Grand Forks Air Force Base', 'Grand Forks Air Force Base', 'Grand Forks Air Force Base,Grand Forks Air Force Base CDP', 47.9549300, -97.3866400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146960, 'Granville South', 'Granville South', 'Granville South,Granville South CDP', 40.0520700, -82.5416600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146961, 'Grissom Air Force Base', 'Grissom Air Force Base', 'Grissom Air Force Base,Grissom Air Force Base CDP', 40.6575300, -86.1475500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146962, 'K. I. Sawyer Air Force Base', 'K. I. Sawyer Air Force Base', 'K. I. Sawyer Air Force Base,K. I. Sawyer Air Force Base CDP,K. I. Sawyer Air Force Base Census Designated Place', 46.3465100, -87.3863200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146963, 'Legend Lake', 'Legend Lake', 'Legend Lake,Legend Lake CDP', 44.8909500, -88.5440600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146964, 'Level Park-Oak Park', 'Level Park-Oak Park', 'Level Park-Oak Park,Level Park-Oak Park CDP', 42.3641800, -85.2665000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146965, 'Manitou Beach-Devils Lake', 'Manitou Beach-Devils Lake', 'Manitou Beach-Devils Lake,Manitou Beach-Devils Lake CDP', 41.9756500, -84.2861600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146966, 'Minot Air Force Base', 'Minot Air Force Base', 'Minot Air Force Base,Minot Air Force Base CDP', 48.4208700, -101.3391400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146967, 'Montrose-Ghent', 'Montrose-Ghent', 'Montrose-Ghent,Montrose-Ghent CDP', 41.1538000, -81.6437800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146968, 'North Spearfish', 'North Spearfish', 'North Spearfish,North Spearfish CDP', 44.5122200, -103.8939000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146969, 'Offutt Air Force Base', 'Offutt Air Force Base', 'Offutt Air Force Base,Offutt Air Force Base CDP', 41.1202400, -95.9209500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146970, 'Scott Air Force Base', 'Scott Air Force Base', 'Scott AFB,Scott Air Force Base,Scott Air Force Base CDP,Scottova letecka zakladna,Scottova letecká základna,Vazdukhoplovna baza Skot,paygah nyrw hwayy skat,seukos gong-gun giji,sukotto kong jun ji de,Ваздухопловна база Скот,Пойгоҳи Нерӯи Ҳавоии Скот,پایگاه نیرو هوایی سکات,スコット空軍基地,스콧 공군 기지', 38.5427000, -89.8503500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146971, 'Shorewood-Tower Hills-Harbert', 'Shorewood-Tower Hills-Harbert', 'Shorewood-Tower Hills-Harbert,Shorewood-Tower Hills-Harbert CDP', 41.8816900, -86.6140900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146972, 'Barnes Lake-Millers Lake', 'Barnes Lake-Millers Lake', 'Barnes Lake-Millers Lake,Barnes Lake-Millers Lake CDP', 43.1795600, -83.3123000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146973, 'Champion Heights', 'Champion Heights', 'Champion Heights,Champion Heights CDP', 41.2899900, -80.8459500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146974, 'Comstock Northwest', 'Comstock Northwest', 'Comstock Northwest,Comstock Northwest CDP', 42.3218200, -85.5175900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146975, 'West Bloomfield Township', 'West Bloomfield Township', 'Municipio de West Bloomfield,West Bloomfield,West Bloomfield Township,West Bloomfield Township CDP,Xa West Bloomfield,Xã West Bloomfield,bldt wyst blwmfyld,بلدة ويست بلومفيلد,ویسٹ بلوم فیلڈ ٹاؤن شپ، مشی گن,ウェスト・ブルームフィールド', 42.5689100, -83.3835600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146976, 'Whiteman Air Force Base', 'Whiteman Air Force Base', 'Base de la Fuerza Aerea Whiteman,Base de la Fuerza Aérea Whiteman,Uajtmen,Vazdukhoplovna baza Vajtman,Whiteman AFB,Whiteman Air Force Base,Whiteman Air Force Base CDP,Whitemanova letecka zakladna,Whitemanova letecká základna,Ваздухопловна база Вајтман,Пойгоҳ нерӯ ҳаво воит‌ман,Уайтмен,پایگاه هوایی وایت‌من', 38.7301800, -93.5589500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146977, 'Wright-Patterson AFB', 'Wright-Patterson AFB', 'Wright-Patterson AFB,Wright-Patterson AFB CDP,Wright-Patterson AFB Census Designated Place', 39.8111300, -84.0573100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146978, 'Dade City North', 'Dade City North', 'Dade City North,Dade City North CDP', 28.3833400, -82.1938900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146979, 'De Land Southwest', 'De Land Southwest', 'De Land Southwest,De Land Southwest CDP,De Land Southwest Census Designated Place', 29.0077000, -81.3112900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146980, 'East Bronson', 'East Bronson', 'East Bronson,East Bronson CDP', 29.4592800, -82.5904000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146981, 'East Lake-Orient Park', 'East Lake-Orient Park', 'East Lake-Orient Park,East Lake-Orient Park CDP', 27.9826900, -82.3787800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146982, 'Eglin Air Force Base', 'Eglin Air Force Base', 'Eglin Air Force Base,Eglin Air Force Base CDP', 30.4590700, -86.5502600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146983, 'Fort Campbell North', 'Fort Campbell North', 'Camp Campbell,Fort Campbell North,Fort Campbell North CDP', 36.6542900, -87.4605600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146984, 'Fort Knox', 'Fort Knox', 'FTK,Fort Knox,Fort Knox CDP,Ft. Knox', 37.8911300, -85.9636300, 'US', '2013-05-31', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146985, 'Fort Pierce North', 'Fort Pierce North', 'Fort Pierce North,Fort Pierce North CDP', 27.4736400, -80.3593000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146986, 'Fort Pierce South', 'Fort Pierce South', 'Fort Pierce South,Fort Pierce South CDP', 27.4096200, -80.3548300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146987, 'Fort Polk North', 'Fort Polk North', 'Fort Polk North,Fort Polk North CDP', 31.1030200, -93.1791300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146988, 'Fort Polk South', 'Fort Polk South', 'Fort Polk South,Fort Polk South CDP', 31.0511000, -93.2157800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146989, 'Fort Rucker', 'Fort Rucker', 'Fort Raker,Fort Rucker,Fort Rucker CDP,Fort-Raker,fwr rkr,fwrt rakr  alabama,pharta rukara,Форт Ракер,Форт-Ракер,فور ركر,فورت راکر، آلاباما,फर्ट रुकर', 31.3428200, -85.7153800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146990, 'Fort Stewart', 'Fort Stewart', 'Fort Stewart,Fort Stewart CDP', 31.8721700, -81.6100100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146991, 'Four Corners', 'Four Corners', 'Four Corners,Four Corners CDP', 28.3328700, -81.6473800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146992, 'Greater Northdale', 'Greater Northdale', 'Greater Northdale,Greater Northdale CDP,Greater Northdale Census Designated Place', 28.1054500, -82.5259400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146993, 'Hutchinson Island South', 'Hutchinson Island South', 'Hutchinson Island South,Hutchinson Island South CDP', 27.2994900, -80.2204500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146994, 'Inverness Highlands North', 'Inverness Highlands North', 'Inverness Highlands North,Inverness Highlands North CDP', 28.8642000, -82.3768800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146995, 'Inverness Highlands South', 'Inverness Highlands South', 'Inverness Highlands South,Inverness Highlands South CDP', 28.8005500, -82.3371000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146996, 'Bellair-Meadowbrook Terrace', 'Bellair-Meadowbrook Terrace', 'Bellair-Meadowbrook Terrace,Bellair-Meadowbrook Terrace CDP', 30.1788100, -81.7434100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146997, 'Candler-McAfee', 'Candler-McAfee', 'Candler-McAfee,Candler-McAfee CDP', 33.7267200, -84.2724600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146998, 'Cocoa West', 'Cocoa West', 'Cocoa West,Cocoa West CDP', 28.3594200, -80.7710900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(146999, 'Columbus Air Force Base', 'Columbus Air Force Base', 'Columbus Air Force Base,Columbus Air Force Base CDP', 33.6323900, -88.4515300, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147000, 'Samsula-Spruce Creek', 'Samsula-Spruce Creek', 'Samsula-Spruce Creek,Samsula-Spruce Creek CDP', 29.0493200, -81.0619200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147001, 'Selmont-West Selmont', 'Selmont-West Selmont', 'Selmont-West Selmont,Selmont-West Selmont CDP', 32.3784300, -87.0074000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147002, 'Slater-Marietta', 'Slater-Marietta', 'Slater-Marietta,Slater-Marietta CDP', 35.0347200, -82.4926500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147003, 'Southeast Arcadia', 'Southeast Arcadia', 'Southeast Arcadia,Southeast Arcadia CDP', 27.1862900, -81.8521000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147004, 'Tyndall Air Force Base', 'Tyndall Air Force Base', 'Tyndall Air Force Base,Tyndall Air Force Base CDP', 30.0853500, -85.6073100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147005, 'Underwood-Petersville', 'Underwood-Petersville', 'Underwood-Petersville,Underwood-Petersville CDP', 34.8769500, -87.6971700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147006, 'University', 'University', 'University,University CDP', 28.0738900, -82.4390200, 'US', '2015-05-13', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147007, 'Vero Beach South', 'Vero Beach South', 'Vero Beach South,Vero Beach South CDP', 27.6163800, -80.4130800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147008, 'Watts Mills', 'Watts Mills', 'Watts Mills,Watts Mills CDP', 34.5164100, -81.9858000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147009, 'West End-Cobb Town', 'West End-Cobb Town', 'West End-Cobb Town,West End-Cobb Town CDP', 33.6525000, -85.8742000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147010, 'Zephyrhills North', 'Zephyrhills North', 'Zephyrhills North,Zephyrhills North CDP', 28.2517200, -82.1655700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147011, 'Zephyrhills South', 'Zephyrhills South', 'Zephyrhills South,Zephyrhills South CDP', 28.2149200, -82.1887300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147012, 'Zephyrhills West', 'Zephyrhills West', 'Zephyrhills West,Zephyrhills West CDP', 28.2308100, -82.2055600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147013, 'Kendall West', 'Kendall West', 'Kendall West,Kendall West CDP', 25.7065000, -80.4388000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147014, 'Kings Bay Base', 'Kings Bay Base', 'Kings Bay Base,Kings Bay Base CDP', 30.7983600, -81.5658900, 'US', '2014-08-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147015, 'Lake Mack-Forest Hills', 'Lake Mack-Forest Hills', 'Lake Mack-Forest Hills,Lake Mack-Forest Hills CDP', 29.0007400, -81.4239700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147016, 'Lake Murray of Richland', 'Lake Murray of Richland', 'Lake Murray of Richland,Lake Murray of Richland CDP', 34.1204800, -81.2645000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147017, 'Lake Norman of Catawba', 'Lake Norman of Catawba', 'Lake Norman of Catawba,Lake Norman of Catawba CDP', 35.5804300, -81.0165400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147018, 'Meridian Station', 'Meridian Station', 'Meridian Station,Meridian Station CDP', 32.5504900, -88.6184900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147019, 'Monarch Mill', 'Monarch Mill', 'Monarch Mill,Monarch Mill CDP', 34.7161000, -81.5850000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147020, 'Nassau Village-Ratliff', 'Nassau Village-Ratliff', 'Nassau Village-Ratliff,Nassau Village-Ratliff CDP', 30.5111100, -81.8092500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147021, 'New Port Richey East', 'New Port Richey East', 'New Port Richey East,New Port Richey East CDP', 28.2602700, -82.6926100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147022, 'North Weeki Wachee', 'North Weeki Wachee', 'North Weeki Wachee,North Weeki Wachee CDP', 28.5501400, -82.5588800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147023, 'Oak Grove', 'Oak Grove', 'Oak Grove,Oak Grove CDP', 33.9809000, -81.1428600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147024, 'Palm River-Clair Mel', 'Palm River-Clair Mel', 'Palm River-Clair Mel,Palm River-Clair Mel CDP', 27.9238600, -82.3793900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147025, 'Redstone Arsenal', 'Redstone Arsenal', 'Redston Arsenal,Redstone Arsenal,Redstone Arsenal CDP,Redstoun-Arsenal,Redstounskij arsenal,rdstwn arsnal  alabama,redastona arsenala,reddosuton bing qi chang,rydstwn arsnal,Редстон Арсенал,Редстоун-Арсенал,Редстоунский арсенал,ردستون آرسنال، آلاباما,ريدستون أرسنال,रेडस्टोन आर्सेनल,レッドストーン兵器廠', 34.6838700, -86.6476400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147026, 'Robins Air Force Base', 'Robins Air Force Base', 'Base de la Fuerza Aerea Robins,Base de la Fuerza Aérea Robins,Pojgoҳi Nerui Ҳavoii Robinz,Robins Air Force Base,Robins Air Force Base CDP,Robinsova letecka zakladna,Robinsova letecká základna,Vazdukhoplovna baza Robins,paygah nyrw hwayy rabynz,rabinsa e epha bi,Ваздухопловна база Робинс,Пойгоҳи Нерӯи Ҳавоии Робинз,پایگاه نیرو هوایی رابینز,रबिन्स ए एफ बी', 32.6091100, -83.5844400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147027, 'Clarkston Heights-Vineland', 'Clarkston Heights-Vineland', 'Clarkston Heights-Vineland,Clarkston Heights-Vineland CDP', 46.3874200, -117.0830000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147028, 'Air Force Academy', 'Air Force Academy', 'Air Force Academy,Air Force Academy CDP', 38.9942500, -104.8637500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147029, 'Alamosa East', 'Alamosa East', 'Alamosa East,Alamosa East CDP', 37.4773500, -105.8421700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147030, 'Antelope Valley-Crestview', 'Antelope Valley-Crestview', 'Antelope Valley-Crestview,Antelope Valley-Crestview CDP', 44.2248800, -105.4740900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147031, 'Aptos Hills-Larkin Valley', 'Aptos Hills-Larkin Valley', 'Aptos Hills-Larkin Valley,Aptos Hills-Larkin Valley CDP', 36.9606400, -121.8340400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147032, 'Arden-Arcade', 'Arden-Arcade', 'Arden-Arcade,Arden-Arcade CDP,Arden-Arkejd,aden''akedo,ardena''arkeda,Арден-Аркејд,आर्डेनआर्केड,アーデンアーケード', 38.6025000, -121.3785400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147033, 'Ault Field', 'Ault Field', 'Ault Field,Ault Field CDP,Ault Field Census Designated Place', 48.3381200, -122.6744100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147034, 'Bangor Trident Base', 'Bangor Trident Base', 'Bangor Trident Base,Bangor Trident Base CDP,Bangor Trident Base Census Designated Place', 47.7227400, -122.7144600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147035, 'Beale Air Force Base', 'Beale Air Force Base', 'Beale Air Force Base,Beale Air Force Base CDP', 39.1091700, -121.3544400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147036, 'Bertsch-Oceanview', 'Bertsch-Oceanview', 'Bertsch-Oceanview,Bertsch-Oceanview CDP', 41.7525000, -124.1587500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147037, 'Village of Oak Creek (Big Park)', 'Village of Oak Creek (Big Park)', 'Big Park CDP,Big Park Census Designated Place,Village of Oak Creek (Big Park)', 34.7809000, -111.7622700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147038, 'Black Point-Green Point', 'Black Point-Green Point', 'Black Point-Green Point,Black Point-Green Point CDP', 38.1154700, -122.5131800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147039, 'Bonadelle Ranchos-Madera Ranchos', 'Bonadelle Ranchos-Madera Ranchos', 'Bonadelle Ranchos-Madera Ranchos,Bonadelle Ranchos-Madera Ranchos CDP', 36.9846700, -119.8746300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147040, 'Bonner-West Riverside', 'Bonner-West Riverside', 'Bonner-West Riverside,Bonner-West Riverside CDP', 46.8766900, -113.8867800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147041, 'Bret Harte', 'Bret Harte', 'Bret Harte,Bret Harte CDP', 37.6020700, -121.0051900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147042, 'Bryn Mawr-Skyway', 'Bryn Mawr-Skyway', 'Bryn Mawr-Skyway,Bryn Mawr-Skyway CDP', 47.4943000, -122.2409200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147043, 'Camp Pendleton North', 'Camp Pendleton North', 'Camp Pendleton North,Camp Pendleton North CDP', 33.3146500, -117.3160300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147044, 'Camp Pendleton South', 'Camp Pendleton South', 'Camp Pendleton South,Camp Pendleton South CDP', 33.2284400, -117.3792900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147045, 'Cannon Air Force Base', 'Cannon Air Force Base', 'Cannon Air Force Base,Cannon Air Force Base CDP', 34.3968900, -103.3244400, 'US', '2013-06-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147046, 'Casa de Oro-Mount Helix', 'Casa de Oro-Mount Helix', 'Casa de Oro-Mount Helix,Casa de Oro-Mount Helix CDP', 32.7639700, -116.9687700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147047, 'Cascade-Chipita Park', 'Cascade-Chipita Park', 'Cascade-Chipita Park,Cascade-Chipita Park CDP', 38.9435400, -105.0023700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147048, 'Central Heights-Midland City', 'Central Heights-Midland City', 'Central Heights-Midland City,Central Heights-Midland City CDP', 33.4037200, -110.8154100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147049, 'Challenge-Brownsville', 'Challenge-Brownsville', 'Challenge-Brownsville,Challenge-Brownsville CDP', 39.4644700, -121.2633800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147050, 'Edwards Air Force Base', 'Edwards Air Force Base', 'Base de la Fuerza Aerea Edwards,Base de la Fuerza Aérea Edwards,EDW,Edvards,Edwards AFB,Edwards Air Force Base,Edwards Air Force Base CDP,Edwards Aire Armadaren basea,Edwards legitamaszpont,Edwards légitámaszpont,Edwardsova letecka zakladna,Edwardsova letecká základna,Ehdvards,Vojna zrakoplovna baza Edwards,ai de hua ci kong jun ji de,edeuwojeu gong-gun giji,edowazu kong jun ji de,paygah nyrwy hwayy adwardz,Едвардс,Эдвардс,בסיס חיל האוויר אדוארדס,پایگاه نیروی هوایی ادواردز,エドワーズ空軍基地,爱德华兹空军基地,에드워즈 공군 기지', 34.9163700, -117.9353500, 'US', '2013-11-16', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147051, 'El Cerro Mission', 'El Cerro Mission', 'El Cerro Mission,El Cerro Mission Census Designated Place,El Cerro-Monterey Park CDP', 34.7622700, -106.6445000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147052, 'Erlands Point-Kitsap Lake', 'Erlands Point-Kitsap Lake', 'Erlands Point-Kitsap Lake,Erlands Point-Kitsap Lake CDP', 47.5971900, -122.7022500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147053, 'Fairchild Air Force Base', 'Fairchild Air Force Base', 'Base de la Fuerza Aerea Fairchild,Base de la Fuerza Aérea Fairchild,Fairchild AFB,Fairchild Air Force Base,Fairchild Air Force Base CDP,Fairchildova letecka zakladna,Fairchildova letecká základna,Vazdukhoplovna baza Ferchajld,paygah nyrwy hwayy fyrchayld,Ваздухопловна база Ферчајлд,Пойгоҳи нерӯе ҳаво фирчоилд,پایگاه نیروی هوایی فیرچایلد', 47.6187900, -117.6482600, 'US', '2013-06-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147054, 'Lucas Valley-Marinwood', 'Lucas Valley-Marinwood', 'Lucas Valley-Marinwood,Lucas Valley-Marinwood CDP', 38.0401100, -122.5755000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147055, 'Malmstrom Air Force Base', 'Malmstrom Air Force Base', 'Malmstrom Air Force Base,Malmstrom Air Force Base CDP', 47.5054900, -111.1830200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147056, 'Maple Heights-Lake Desire', 'Maple Heights-Lake Desire', 'Maple Heights-Lake Desire,Maple Heights-Lake Desire CDP', 47.4441300, -122.0973600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147057, 'March Air Force Base', 'March Air Force Base', 'March Air Force Base,March Air Force Base CDP,March Air Force Base Census Designated Place', 33.8920900, -117.2631000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147058, 'Marietta-Alderwood', 'Marietta-Alderwood', 'Marietta-Alderwood,Marietta-Alderwood CDP', 48.7896500, -122.5536900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147059, 'McChord Air Force Base', 'McChord Air Force Base', 'McChord Air Force Base,McChord Air Force Base CDP', 47.1339700, -122.4915700, 'US', '2013-05-03', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147060, 'Fetters Hot Springs-Agua Caliente', 'Fetters Hot Springs-Agua Caliente', 'Fetters Hot Springs-Agua Caliente,Fetters Hot Springs-Agua Caliente CDP', 38.3214000, -122.4868200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147061, 'Florence-Graham', 'Florence-Graham', 'Florence-Graham,Florence-Graham CDP', 33.9677200, -118.2443800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147062, 'Fort Bliss', 'Fort Bliss', 'Fort Bliss,Fort Bliss CDP', 31.8135700, -106.4122400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147063, 'Fort Hood', 'Fort Hood', 'Fort Hood,Fort Hood CDP', 31.1348900, -97.7756100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147064, 'Fort Lewis', 'Fort Lewis', 'Base de la Fuerza Aerea McChord,Base de la Fuerza Aérea McChord,Fort L''juis,Fort Lewis,Fort Lewis CDP,Fort Luis,Fuorto Lewis,McChord Air Force Base,fwrt lwys  washntn,Форт Луис,Форт Льюїс,فورت لويس، واشنطن', 47.1078700, -122.5769400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147065, 'Fox Farm-College', 'Fox Farm-College', 'Fox Farm-College,Fox Farm-College CDP', 41.1120300, -104.7854600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147066, 'Garden Home-Whitford', 'Garden Home-Whitford', 'Garden Home-Whitford,Garden Home-Whitford CDP', 45.4640000, -122.7589100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147067, 'Gold Canyon', 'Gold Canyon', 'Gold Camp CDP,Gold Camp Census Designated Place,Gold Canyon', 33.3714500, -111.4369100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147068, 'Gunbarrel', 'Gunbarrel', 'Gunbarrel,Gunbarrel CDP', 40.0633500, -105.1710700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147069, 'Heber-Overgaard', 'Heber-Overgaard', 'Geber-Overgaard,Heber,Heber-Overgaard,Heber-Overgaard CDP,Khiber-Overgard,hebara''obaragarda,Гебер-Оверґаард,Хибер-Овергард,हेबरओबरगार्द', 34.4141400, -110.5695600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147070, 'Helena Valley Northeast', 'Helena Valley Northeast', 'Helena Valley Northeast,Helena Valley Northeast CDP', 46.6988200, -111.9520700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147071, 'Helena Valley Northwest', 'Helena Valley Northwest', 'Helena Valley Northwest,Helena Valley Northwest CDP', 46.7289400, -112.0627500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147072, 'Helena Valley Southeast', 'Helena Valley Southeast', 'Helena Valley Southeast,Helena Valley Southeast CDP', 46.6152700, -111.9215600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147073, 'Helena Valley West Central', 'Helena Valley West Central', 'Helena Valley West Central,Helena Valley West Central CDP', 46.6629100, -112.0604400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147074, 'Helena West Side', 'Helena West Side', 'Helena West Side,Helena West Side CDP', 46.5967200, -112.1130400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147075, 'Highlands-Baywood Park', 'Highlands-Baywood Park', 'Highlands-Baywood Park,Highlands-Baywood Park CDP', 37.5227200, -122.3450600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147076, 'Hilmar-Irwin', 'Hilmar-Irwin', 'Hilmar-Irwin,Hilmar-Irwin CDP', 37.4045400, -120.8504200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147077, 'Holloman Air Force Base', 'Holloman Air Force Base', 'Holloman Air Force Base,Holloman Air Force Base CDP', 32.8482700, -106.0997700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147078, 'Idyllwild-Pine Cove', 'Idyllwild-Pine Cove', 'Idyllwild-Pine Cove,Idyllwild-Pine Cove CDP,a''idilava''ildapa''ina kobha,ai de huai-song shu wan,आइडिलवाइल्डपाइन कोभ,愛德懷-松樹灣', 33.7442900, -116.7258700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147079, 'Inglewood-Finn Hill', 'Inglewood-Finn Hill', 'Inglewood-Finn Hill,Inglewood-Finn Hill CDP', 47.7204900, -122.2316700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147080, 'La Crescenta-Montrose', 'La Crescenta-Montrose', 'La Crescenta-Montrose,La Crescenta-Montrose CDP,La Kresenta-Montrouz,la kres''senta montaroja,Ла Кресента-Монтроуз,ला क्रेस्सेन्टा मोन्टरोज', 34.2321600, -118.2352900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147081, 'Lackland Air Force Base', 'Lackland Air Force Base', 'Lackland Air Force Base,Lackland Air Force Base CDP', 29.3866300, -98.6179700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147082, 'Lagunitas-Forest Knolls', 'Lagunitas-Forest Knolls', 'Lagunitas-Forest Knolls,Lagunitas-Forest Knolls CDP', 38.0179300, -122.6912400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147083, 'Lake Marcel-Stillwater', 'Lake Marcel-Stillwater', 'Lake Marcel-Stillwater,Lake Marcel-Stillwater CDP', 47.6926300, -121.9151300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147084, 'Lake Morton-Berrydale', 'Lake Morton-Berrydale', 'Lake Morton-Berrydale,Lake Morton-Berrydale CDP', 47.3325100, -122.1028600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147085, 'Lakeland North', 'Lakeland North', 'Lakeland North,Lakeland North CDP', 47.3334300, -122.2769500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147086, 'Lakeland South', 'Lakeland South', 'Lakeland South,Lakeland South CDP', 47.2784300, -122.2832600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147087, 'Larkfield-Wikiup', 'Larkfield-Wikiup', 'Larkfield-Wikiup,Larkfield-Wikiup CDP', 38.5134200, -122.7509400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147088, 'Laughlin Air Force Base', 'Laughlin Air Force Base', 'Laughlin Air Force Base,Laughlin Air Force Base CDP', 29.3566300, -100.7835300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147089, 'Leadville North', 'Leadville North', 'Leadville North,Leadville North CDP', 39.2576000, -106.3013800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147090, 'LeChee', 'LeChee', 'LeChee,LeChee CDP', 36.8621100, -111.4406300, 'US', '2015-06-25', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147091, 'Lemoore Station', 'Lemoore Station', 'Lemoore Station,Lemoore Station CDP', 36.2632600, -119.9047600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147092, 'Dixon Lane-Meadow Creek', 'Dixon Lane-Meadow Creek', 'Dixon Lane-Meadow Creek,Dixon Lane-Meadow Creek CDP', 37.3863900, -118.4152700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147093, 'East Hill-Meridian', 'East Hill-Meridian', 'East Hill-Meridian,East Hill-Meridian CDP', 47.4105200, -122.1736900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147094, 'Sierra Vista Southeast', 'Sierra Vista Southeast', 'Sierra Vista Southeast,Sierra Vista Southeast CDP', 31.4538500, -110.2163700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147095, 'Skyline-Ganipa', 'Skyline-Ganipa', 'Skyline-Ganipa,Skyline-Ganipa CDP', 35.0327900, -107.6139600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147096, 'Smith Valley', 'Smith Valley', 'Smith Valley,Smith Valley CDP', 38.7842100, -119.3442500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147097, 'South Wenatchee', 'South Wenatchee', 'South Wenatchee,South Wenatchee CDP', 47.3901200, -120.2895800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147098, 'Moses Lake North', 'Moses Lake North', 'Moses Lake North,Moses Lake North CDP', 47.1943300, -119.3171900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147099, 'Nellis Air Force Base', 'Nellis Air Force Base', 'Nellis Air Force Base,Nellis Air Force Base CDP', 36.2460700, -115.0572100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147100, 'New Kingman-Butler', 'New Kingman-Butler', 'New Kingman-Butler,New Kingman-Butler CDP', 35.2650400, -114.0322600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147101, 'North Lakeport', 'North Lakeport', 'North Lakeport,North Lakeport CDP', 39.0883100, -122.9053800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147102, 'Oatfield', 'Oatfield', 'Oatfield,Oatfield CDP', 45.4141800, -122.6000700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147103, 'Ohkay Owingeh', 'Ohkay Owingeh', 'Ohkay Owingeh,Ohkay Owingeh CDP', 36.0508200, -106.0689700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147104, 'Oroville East', 'Oroville East', 'Oroville East,Oroville East CDP', 39.5112600, -121.4751900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147105, 'Otis Orchards-East Farms', 'Otis Orchards-East Farms', 'Otis Orchards,Otis Orchards-East Farms,Otis Orchards-East Farms CDP', 47.7098800, -117.0797500, 'US', '2015-08-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147106, 'Poplar-Cotton Center', 'Poplar-Cotton Center', 'Poplar-Cotton Center,Poplar-Cotton Center CDP', 36.0563500, -119.1491900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147107, 'Port Angeles East', 'Port Angeles East', 'Port Angeles East,Port Angeles East CDP', 48.1066700, -123.3717200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147108, 'Port Hadlock-Irondale', 'Port Hadlock-Irondale', 'Port Hadlock-Irondale,Port Hadlock-Irondale CDP', 48.0327300, -122.7852900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147109, 'Roseburg North', 'Roseburg North', 'Roseburg North,Roseburg North CDP', 43.2645200, -123.3033100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147110, 'Security-Widefield', 'Security-Widefield', 'Security-Widefield,Security-Widefield CDP', 38.7472800, -104.7143900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147111, 'Tsaile', 'Tsaile', 'Tsaile,Tsaile CDP', 36.3033000, -109.2156600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147112, 'Union Hill-Novelty Hill', 'Union Hill-Novelty Hill', 'Union Hill-Novelty Hill,Union Hill-Novelty Hill CDP', 47.6788700, -122.0283300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147113, 'Valencia West', 'Valencia West', 'Valencia West,Valencia West CDP', 32.1323800, -111.1141400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147114, 'Vandenberg Air Force Base', 'Vandenberg Air Force Base', 'Vandenberg Air Force Base,Vandenberg Air Force Base CDP', 34.7483000, -120.5181700, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147115, 'View Park-Windsor Hills', 'View Park-Windsor Hills', 'View Park-Windsor Hills,View Park-Windsor Hills CDP', 33.9955100, -118.3483500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147116, 'Vincent', 'Vincent', 'Vincent,Vincent CDP', 34.0983600, -117.9238300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147117, 'Walla Walla East', 'Walla Walla East', 'Walla Walla East,Walla Walla East CDP', 46.0518400, -118.3040300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147118, 'West Clarkston-Highland', 'West Clarkston-Highland', 'West Clarkston-Highland,West Clarkston-Highland CDP', 46.4028700, -117.0639500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147119, 'West Haven-Sylvan', 'West Haven-Sylvan', 'West Haven-Sylvan,West Haven-Sylvan CDP', 45.5161300, -122.7680900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147120, 'West Modesto', 'West Modesto', 'West Modesto,West Modesto CDP', 37.6175400, -121.0391400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147121, 'West Pleasant View', 'West Pleasant View', 'West Pleasant View,West Pleasant View CDP', 39.7325600, -105.1785200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147122, 'West Side Highway', 'West Side Highway', 'West Side Highway,West Side Highway CDP', 46.1839900, -122.9171500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147123, 'West Whittier-Los Nietos', 'West Whittier-Los Nietos', 'West Whittier-Los Nietos,West Whittier-Los Nietos CDP', 33.9760000, -118.0690900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147124, 'Westhaven-Moonstone', 'Westhaven-Moonstone', 'Westhaven-Moonstone,Westhaven-Moonstone CDP', 41.0448900, -124.1023900, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147125, 'Whetstone', 'Whetstone', 'Whetstone,Whetstone CDP', 31.7010500, -110.3398700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147126, 'Yosemite Valley', 'Yosemite Valley', 'Yosemite Valley,Yosemite Valley CDP', 37.7407500, -119.5778800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147127, 'Summerlin South', 'Summerlin South', 'Summerlin South,Summerlin South CDP', 36.1170800, -115.3300100, 'US', '2012-12-24', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147128, 'Sunnyside-Tahoe City', 'Sunnyside-Tahoe City', 'Sunnyside-Tahoe City,Sunnyside-Tahoe City CDP', 39.1502300, -120.1612000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147129, 'Taft Mosswood', 'Taft Mosswood', 'Taft Mosswood,Taft Mosswood CDP', 37.9138500, -121.2831600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147130, 'Tamalpais-Homestead Valley', 'Tamalpais-Homestead Valley', 'Tamalpais-Homestead Valley,Tamalpais-Homestead Valley CDP', 37.8783400, -122.5362500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147131, 'Tanglewilde-Thompson Place', 'Tanglewilde-Thompson Place', 'Tanglewilde-Thompson Place,Tanglewilde-Thompson Place CDP,Tanglewilde-Thompson Place Census Designated Place', 47.0511600, -122.7808100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147132, 'Haiku-Pauwela', 'Haiku-Pauwela', 'Haiku-Pauwela,Haiku-Pauwela CDP', 20.9218700, -156.3050800, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147133, 'Hickam Field', 'Hickam Field', 'Hickam Field,Hickam Housing,Hickam Housing CDP', 21.3396700, -157.9601800, 'US', '2015-02-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147134, 'Honaunau-Napoopoo', 'Honaunau-Napoopoo', 'Honaunau-Napoopoo,Honaunau-Napoopoo CDP', 19.4562700, -155.8646600, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147135, 'Kahaluu-Keauhou', 'Kahaluu-Keauhou', 'Kahaluu-Keauhou,Kahaluu-Keauhou CDP', 19.5718100, -155.9617200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147136, 'Marine Corps Base Hawaii - MCBH', 'Marine Corps Base Hawaii - MCBH', 'Kaneohe Station,Kaneohe Station CDP,Marine Corps Base Hawaii - MCBH', 21.4433600, -157.7498100, 'US', '2015-02-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147137, 'Makakilo', 'Makakilo', 'Makakilo,Makakilo City CDP,Makakilo City Census Designated Place', 21.3523700, -158.0865500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147138, 'Napili-Honokowai', 'Napili-Honokowai', 'Napili-Honokowai,Napili-Honokowai CDP', 20.9753300, -156.6782600, 'US', '2015-08-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147139, 'Schofield Barracks', 'Schofield Barracks', 'Schofield Barracks,Schofield Barracks CDP', 21.4983700, -158.0651500, 'US', '2015-03-22', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147140, 'Royal Kunia', 'Royal Kunia', 'Royal Kunia,Village Park CDP,Village Park Census Designated Place', 21.3939200, -158.0267000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147141, 'Waihee-Waiehu', 'Waihee-Waiehu', 'Waihee-Waiehu,Waihee-Waiehu CDP', 20.9302200, -156.5045800, 'US', '2016-06-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147142, 'Wailua Homesteads', 'Wailua Homesteads', 'Wailua Homesteads,Wailua Homesteads CDP', 22.0724400, -159.3767700, 'US', '2016-02-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147143, 'Deltana', 'Deltana', 'Deltana,Deltana CDP', 63.8721700, -145.2177300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147144, 'Eielson Air Force Base', 'Eielson Air Force Base', 'Eielson Air Force Base,Eielson Air Force Base CDP', 64.6632700, -147.0544200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147145, 'Farm Loop', 'Farm Loop', 'Farm Loop,Farm Loop CDP', 61.6389100, -149.1421500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147146, 'Fishhook', 'Fishhook', 'Fishhook,Fishhook CDP', 61.7440200, -149.2361300, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147147, 'Knik-Fairview', 'Knik-Fairview', 'Knik-Fairview,Knik-Fairview CDP', 61.5126200, -149.6001200, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147148, 'Kodiak Station', 'Kodiak Station', 'Kodiak Station,Kodiak Station CDP', 57.7658700, -152.6000400, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147149, 'Lakes', 'Lakes', 'Lakes,Lakes CDP', 61.6071300, -149.3086100, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147150, 'Salcha', 'Salcha', 'Salcha,Salcha CDP', 64.5239900, -146.9021000, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147151, 'Sutton-Alpine', 'Sutton-Alpine', 'Sutton-Alpine,Sutton-Alpine CDP', 61.7778900, -148.7645000, 'US', '2015-08-07', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147152, 'Y', 'Y', 'Y,Y CDP,Y Census Designated Place', 62.1612900, -149.8507500, 'US', '2011-05-14', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147153, 'National Harbor', 'National Harbor', '', 38.7826400, -77.0150600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147154, 'San Tan Valley', 'San Tan Valley', '', 33.1911000, -111.5280000, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147155, 'Carlisle-Rockledge', 'Carlisle-Rockledge', '', 34.1144500, -86.1240700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147156, 'Emerald Mountain', 'Emerald Mountain', '', 32.4479300, -86.0942900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147157, 'Highland Lakes', 'Highland Lakes', '', 33.3983800, -86.6513000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147158, 'Farmers Loop', 'Farmers Loop', '', 64.9082200, -147.6986600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147159, 'Avenue B and C', 'Avenue B and C', '', 32.7190400, -114.6600500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147160, 'Centennial Park', 'Centennial Park', '', 36.9538100, -112.9813200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147161, 'Donovan Estates', 'Donovan Estates', '', 32.7093500, -114.6782200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147162, 'Golden Shores', 'Golden Shores', '', 34.7818800, -114.4777500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147163, 'North Fork', 'North Fork', '', 34.0016700, -109.9635500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147164, 'Scenic', 'Scenic', '', 36.7935900, -114.0127500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147165, 'Six Shooter Canyon', 'Six Shooter Canyon', '', 33.3667800, -110.7746000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147166, 'Valle Vista', 'Valle Vista', '', 35.4108800, -113.8627100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147167, 'Acalanes Ridge', 'Acalanes Ridge', '', 37.9047200, -122.0785700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147168, 'Fruitridge Pocket', 'Fruitridge Pocket', '', 38.5326500, -121.4558100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147169, 'Meadowbrook', 'Meadowbrook', '', 33.7257800, -117.2850900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147170, 'Monument Hills', 'Monument Hills', '', 38.6642900, -121.8756600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147171, 'Old Fig Garden', 'Old Fig Garden', '', 36.7988500, -119.8051500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147172, 'Red Corral', 'Red Corral', '', 38.4116500, -120.6055200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147173, 'Sun Village', 'Sun Village', '', 34.5595200, -117.9567600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147174, 'Upper Bear Creek', 'Upper Bear Creek', '', 39.6238500, -105.4178000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147175, 'Connerton', 'Connerton', '', 28.3144100, -82.4753900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147176, 'Flagler Estates', 'Flagler Estates', '', 29.6455300, -81.4570000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147177, 'Greenbriar', 'Greenbriar', '', 28.0112800, -82.7527200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147178, 'Heritage Pines', 'Heritage Pines', '', 28.4252200, -82.6211100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147179, 'Horizon West', 'Horizon West', '', 28.4338300, -81.6227000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147180, 'Island Walk', 'Island Walk', '', 26.2509900, -81.7110100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147181, 'Key Vista', 'Key Vista', '', 28.1947000, -82.7703800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147182, 'Meadow Oaks', 'Meadow Oaks', '', 28.3461900, -82.6028400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147183, 'Midway', 'Midway', '', 30.4064800, -87.0055300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147184, 'Nocatee', 'Nocatee', '', 30.0832000, -81.4028300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147185, 'Oakleaf Plantation', 'Oakleaf Plantation', '', 30.1708300, -81.8354900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147186, 'Pasadena Hills', 'Pasadena Hills', '', 28.2800100, -82.2243800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147187, 'Quail Ridge', 'Quail Ridge', '', 28.3490500, -82.5553200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147188, 'Verona Walk', 'Verona Walk', '', 26.0841200, -81.6798500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147189, 'Viera East', 'Viera East', '', 28.2623400, -80.7144900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147190, 'Viera West', 'Viera West', '', 28.2450400, -80.7338000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147191, 'Henderson', 'Henderson', '', 32.0081300, -81.2588700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147192, 'East Honolulu', 'East Honolulu', '', 21.2890600, -157.7173400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147193, 'Ocean Pointe', 'Ocean Pointe', '', 21.3106600, -158.0363800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147194, 'The Galena Territory', 'The Galena Territory', '', 42.3934300, -90.3258200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147195, 'Smithville-Sanders', 'Smithville-Sanders', '', 39.0596900, -86.5107700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147196, 'McConnell AFB', 'McConnell AFB', 'McConnell AFB,McConnell AFB Census Designated Place', 37.6300700, -97.2586900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147197, 'Fairwood', 'Fairwood', '', 38.9566500, -76.7777200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147198, 'Marlboro Village', 'Marlboro Village', '', 38.8305400, -76.7696500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147199, 'Queenland', 'Queenland', 'Queenland,Queenland Census Designated Place', 38.8052400, -76.7912600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147200, 'Summerfield', 'Summerfield', '', 38.9045400, -76.8683000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147201, 'LaBarque Creek', 'LaBarque Creek', '', 38.4170100, -90.6798900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147202, 'Old Jamestown', 'Old Jamestown', '', 38.8349400, -90.2851100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147203, 'East Valley', 'East Valley', '', 38.9434000, -119.6992300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147204, 'Topaz Ranch Estates', 'Topaz Ranch Estates', '', 38.7356500, -119.5007900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147205, 'East Franklin', 'East Franklin', '', 40.4933000, -74.4711000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147206, 'Franklin Center', 'Franklin Center', '', 40.5315300, -74.5414100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147207, 'Upper Pohatcong', 'Upper Pohatcong', '', 40.6774700, -75.1558000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147208, 'Vernon Center', 'Vernon Center', '', 41.1887900, -74.5040500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147209, 'Keeler Farm', 'Keeler Farm', '', 32.3160700, -107.7602300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147210, 'West Hammond', 'West Hammond', '', 36.6807100, -108.0492100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147211, 'Fort Covington Hamlet', 'Fort Covington Hamlet', '', 44.9717800, -74.5075700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147212, 'Merritt Park', 'Merritt Park', '', 41.5384800, -73.8723800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147213, 'Northchase', 'Northchase', '', 34.3078200, -77.8774900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147214, 'Eagleview', 'Eagleview', '', 40.0593800, -75.6807600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147215, 'Mowbray Mountain', 'Mowbray Mountain', '', 35.2753600, -85.2224600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147216, 'Tellico Village', 'Tellico Village', '', 35.6832100, -84.2551800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147217, 'Lantana', 'Lantana', '', 33.0907300, -97.1241600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147218, 'Las Palmas II', 'Las Palmas II', '', 26.2017100, -97.7376000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147219, 'Paloma Creek', 'Paloma Creek', '', 33.2253000, -96.9374200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147220, 'Paloma Creek South', 'Paloma Creek South', '', 33.2113600, -96.9355400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147221, 'Providence', 'Providence', '', 33.2334000, -96.9615800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147222, 'Savannah', 'Savannah', '', 33.2260300, -96.9078600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147223, 'Travis Ranch', 'Travis Ranch', '', 32.8035600, -96.4734700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147224, 'Silver Summit', 'Silver Summit', '', 40.7414400, -111.4877500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147225, 'Boswell''s Corner', 'Boswell''s Corner', '', 38.5054100, -77.3726300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147226, 'Kings Park West', 'Kings Park West', '', 38.8144300, -77.2958200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147227, 'Loudoun Valley Estates', 'Loudoun Valley Estates', '', 38.9808100, -77.5079000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147228, 'Southern Gateway', 'Southern Gateway', '', 38.3450700, -77.5035200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147229, 'Bothell East', 'Bothell East', '', 47.8063100, -122.1842700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147230, 'Bothell West', 'Bothell West', '', 47.8052700, -122.2406400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147231, 'Bunk Foss', 'Bunk Foss', '', 47.9617100, -122.0944100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147232, 'Crocker', 'Crocker', '', 47.0809100, -122.1038300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147233, 'Eastmont', 'Eastmont', '', 47.8974000, -122.1815400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147234, 'Klahanie', 'Klahanie', '', 47.5709700, -122.0083900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147235, 'Larch Way', 'Larch Way', '', 47.8429000, -122.2527500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147236, 'Mill Creek East', 'Mill Creek East', '', 47.8360200, -122.1876600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147237, 'Monroe North', 'Monroe North', '', 47.8822500, -121.9872900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147238, 'North Fort Lewis', 'North Fort Lewis', '', 47.1213100, -122.5945200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147239, 'Prairie Heights', 'Prairie Heights', '', 47.1493300, -122.1053000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147240, 'Summit View', 'Summit View', '', 47.1363200, -122.3520200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147241, 'Wilderness Rim', 'Wilderness Rim', '', 47.4469700, -121.7685700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147242, 'Matheny', 'Matheny', '', 36.1706600, -119.3515800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147243, 'Patterson Tract', 'Patterson Tract', '', 36.3795200, -119.2956000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147244, 'Teviston', 'Teviston', '', 35.9289400, -119.2783100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147245, 'Hidden Spring', 'Hidden Spring', 'Hidden Spring,Hidden Spring Census Designated Place', 43.7221600, -116.2509300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147246, 'Circle D-KC Estates', 'Circle D-KC Estates', 'Circle D-KC Estates', 30.1610000, -97.2347300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147247, 'University Park', 'University Park', '60484', 41.4429800, -87.6836000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147248, 'Rio Vista', 'Rio Vista', 'Rio Vista,Río Vista,li ao wei si ta,riyo bhista,ryw fysta,ryw wysta  kalyfrnya,Рио Виста,ريو فيستا,ریو ویستا، کالیفرنیا,रियो भिस्टा,里奥维斯塔', 38.1638900, -121.6958300, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147249, 'Lyme Town Offices', 'Lyme Town Offices', '', 43.8152500, -72.1494200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147250, 'Shorewood Forest', 'Shorewood Forest', '', 41.4631500, -87.1447200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147251, 'Woodlake', 'Woodlake', '', 37.4210600, -77.6793100, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147252, 'Cordry Sweetwater Lakes', 'Cordry Sweetwater Lakes', '', 39.3046400, -86.1183700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147253, 'Dove Valley', 'Dove Valley', '', 39.5777100, -104.8294000, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147254, 'Doe Valley', 'Doe Valley', '', 37.9566500, -86.1165300, 'US', '2011-05-15', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147255, 'Enchanted Hills', 'Enchanted Hills', '', 35.3367600, -106.5929600, 'US', '2011-06-04', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147256, 'Oak Cliff Place', 'Oak Cliff Place', '', 29.9271200, -95.6267200, 'US', '2011-07-11', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147257, 'West Hills', 'West Hills', '', 34.1973100, -118.6439800, 'US', '2011-09-26', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147258, 'Beech Mountain Lakes', 'Beech Mountain Lakes', '', 41.0415800, -75.9354500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147259, 'The Hideout', 'The Hideout', '', 41.4273600, -75.3525500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147260, 'Wallenpaupack Lake Estates', 'Wallenpaupack Lake Estates', '', 41.3989800, -75.2740200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147261, 'Penn Estates', 'Penn Estates', '', 41.0375000, -75.2395600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147262, 'Sierra View', 'Sierra View', '', 41.0120700, -75.4590000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147263, 'Pine Ridge', 'Pine Ridge', '', 41.1459800, -74.9911600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147264, 'The Acreage', 'The Acreage', '', 26.7940400, -80.2674900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147265, 'Eastvale', 'Eastvale', 'Istvejl,ayst wyl  kalyfrnya,aystfal,dong gu,Иствејл,إيستفال,ایست ویل، کالیفرنیا,东谷', 33.9635800, -117.5641800, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147266, 'Oak Hill', 'Oak Hill', '', 38.9258000, -77.4015600, 'US', '2012-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147267, 'Beaver Dam Lake', 'Beaver Dam Lake', '', 41.4474300, -74.1146300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147268, 'Contra Costa Centre', 'Contra Costa Centre', '', 37.9275200, -122.0578600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147269, 'Belmont Estates', 'Belmont Estates', '', 38.4527100, -78.9197900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147270, 'Siesta Acres', 'Siesta Acres', '', 28.7579900, -100.4901900, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147271, 'West Greenwich', 'West Greenwich', 'u~esutogurinijji,wyst ghryntsh,ويست غرينتش,ویسٹ گرینچ، روڈ آئلینڈ,ウェストグリニッジ', 41.6370000, -71.6600400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147272, 'Bridgewater', 'Bridgewater', 'Bridgewater', 40.6007900, -74.6481500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147273, 'Warren Township', 'Warren Township', 'Warren,Warren Township', 40.6082200, -74.5180300, 'US', '2012-05-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147274, 'Limestone', 'Limestone', '', 41.1323700, -87.9684000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147275, 'Castle Pines North', 'Castle Pines North', '', 39.4717400, -104.8948200, 'US', '2012-06-05', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147276, 'Fairfield Heights', 'Fairfield Heights', '', 39.8286100, -86.3822400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147277, 'South Kingstown', 'South Kingstown', 'sausukingusutaun,sawth kynghstawn,جنوبی کنگز ٹاؤن، روڈ آئلینڈ,ساوث كينغستاون,サウスキングスタウン', 41.4471800, -71.5249400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147278, 'La Porte', 'La Porte', 'La Port,LaPorte,Ла Порт', 41.6077400, -86.7138900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147279, 'Notre Dame', 'Notre Dame', 'Notre Dejm,nwtr dam dw lak,Нотре Дејм,نوتر دام دو لاك', 41.7001900, -86.2379300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147280, 'Randolph', 'Randolph', 'Randol''f Taunship,Randolph Township,randwlf  nywjrsy,Рандольф Тауншип,راندولف، نیوجرسی,رینڈولف ٹاؤن شپ، نیو جرسی', 40.8482900, -74.5814800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147281, 'Hobart', 'Hobart', '', 44.4992500, -88.1498600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147282, 'Mount Pleasant', 'Mount Pleasant', '', 42.6974300, -87.8557700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147283, 'Western Lake', 'Western Lake', '', 32.6233800, -97.8115500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147284, 'Star Valley Ranch', 'Star Valley Ranch', 'Star Valley Ranch,Town of Star Valley Ranch', 42.9713900, -110.9555600, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147285, 'Shaw Heights', 'Shaw Heights', '', 39.8525000, -105.0430600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147286, 'Northdale', 'Northdale', '', 28.0939000, -82.5056100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147287, 'Lake Stickney', 'Lake Stickney', '', 47.8765500, -122.2621400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147288, 'Phoenix Lake', 'Phoenix Lake', '', 38.0059400, -120.3070200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147289, 'Picnic Point', 'Picnic Point', '', 47.8811100, -122.3284000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147290, 'Roma', 'Roma', 'Roma,rma  tgzas,rwma,Рома,رما، تگزاس,روما', 26.4052600, -99.0158100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147291, 'Tanglewilde', 'Tanglewilde', '', 47.0515000, -122.7824100, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147292, 'Tiki Island', 'Tiki Island', '', 29.2970900, -94.9170900, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147293, 'Waterford', 'Waterford', 'Central Waterford,Vaterford,Voterford,sentrala vatarapharda,Ватерфорд,Вотерфорд,واٹرفورڈ، کنیکٹیکٹ,सेन्ट्रल वाटरफर्ड', 41.3417000, -72.1359700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147294, 'Devens', 'Devens', '', 42.5447000, -71.6131800, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147295, 'Lake Holiday', 'Lake Holiday', '', 41.6129200, -88.6720900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147296, 'Prestbury', 'Prestbury', '', 41.7832900, -88.4176400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147297, 'Lake Camelot', 'Lake Camelot', '', 40.6306500, -89.7421000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147298, 'Heritage Lake', 'Heritage Lake', '', 40.5474500, -89.3258100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147299, 'Twin Lakes', 'Twin Lakes', '', 38.2492700, -78.4437800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147300, 'Heritage Lake', 'Heritage Lake', '', 39.7277900, -86.7102200, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147301, 'Watchtower', 'Watchtower', '', 41.6377600, -74.2602700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147302, 'Cherry Creek', 'Cherry Creek', '', 39.6345500, -104.8828600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147303, 'Holly Hills', 'Holly Hills', '', 39.6675700, -104.9179700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147304, 'Inverness', 'Inverness', '', 39.5773800, -104.8613500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147305, 'Lake Panorama', 'Lake Panorama', '', 41.7110500, -94.3905900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147306, 'Lake Lakengren', 'Lake Lakengren', '', 39.6884300, -84.6934700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147307, 'Apple Valley', 'Apple Valley', '', 40.4389000, -82.3539100, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147308, 'Quail Creek', 'Quail Creek', '', 28.7764000, -97.0823200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147309, 'Meadowbrook', 'Meadowbrook', '', 37.4488200, -77.4735300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147310, 'Plum Creek', 'Plum Creek', '', 37.1298400, -80.5006000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147311, 'Woodburn', 'Woodburn', '', 38.8474500, -77.2360500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147312, 'Big Bass Lake', 'Big Bass Lake', '', 41.2538300, -75.4764400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147313, 'Toftrees', 'Toftrees', '', 40.8260400, -77.8811000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147314, 'Lake Latonka', 'Lake Latonka', '', 41.2903900, -80.1812900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147315, 'Buckhorn', 'Buckhorn', '', 38.4521600, -120.5285400, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147316, 'Silver Lakes', 'Silver Lakes', '', 34.7455800, -117.3409800, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147317, 'Spring Valley Lake', 'Spring Valley Lake', '', 34.4936400, -117.2683200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147318, 'Hide-A-Way Lake', 'Hide-A-Way Lake', '', 30.5649200, -89.6402000, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147319, 'Tunica Resorts', 'Tunica Resorts', '', 34.8361300, -90.3472300, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147320, 'Colony Park', 'Colony Park', '', 40.3468300, -75.9824000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147321, 'Greenfields', 'Greenfields', '', 40.3599000, -75.9519900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147322, 'Rome', 'Rome', '', 44.2206000, -89.8084300, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147323, 'Farley', 'Farley', '', 37.0463400, -88.5685600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147324, 'Lincoln', 'Lincoln', 'Linkol''n,lynkwln,rinkan,Лінкольн,لنکن، رہوڈ آئی لینڈ,لينكولن,リンカーン', 41.9211100, -71.4350000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147325, 'Kula', 'Kula', '', 20.7909400, -156.3269500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147326, 'Ko Olina', 'Ko Olina', '', 21.3399300, -158.1256200, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147327, 'Firing Range', 'Firing Range', '', 33.4375200, -82.6906800, 'US', '2013-07-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147328, 'West Warrenton', 'West Warrenton', '', 33.4121700, -82.6751700, 'US', '2013-07-06', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147329, 'Johnston', 'Johnston', 'Dzhonston,jonsuton,jwnstwn,Джонстон,جانسٹن، روڈ آئلینڈ,جونستون,ジョンストン', 41.8218600, -71.5067500, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147330, 'Hill Air Force Base', 'Hill Air Force Base', '', 41.1111800, -111.9771200, 'US', '2016-10-19', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147331, 'Elmendorf Air Force Base', 'Elmendorf Air Force Base', '', 61.2570300, -149.6313900, 'US', '2013-09-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147332, 'Hot Springs National Park', 'Hot Springs National Park', '', 34.5317000, -93.0637700, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147333, 'Dixiana', 'Dixiana', '', 33.7402100, -86.6493800, 'US', '2013-09-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147334, 'Shoal Creek', 'Shoal Creek', '', 33.4307600, -86.6109200, 'US', '2013-09-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147335, 'Little Rock Air Force Base', 'Little Rock Air Force Base', '', 34.8914900, -92.1595500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147336, 'Cranberry Township', 'Cranberry Township', '', 40.6849600, -80.1071400, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147337, 'Williamsburg', 'Williamsburg', '', 37.2734400, -76.7414800, 'US', '2014-07-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147338, 'Woodstock', 'Woodstock', '', 44.3749400, -70.6084900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147339, 'St Marys', 'St Marys', '', 30.7567700, -81.5717300, 'US', '2014-08-30', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147340, 'Laurel Hill', 'Laurel Hill', '', 38.7166300, -77.2368600, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147341, 'Harrison', 'Harrison', '', 44.2277600, -88.3359100, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147342, 'Pantops', 'Pantops', '', 38.0337900, -78.4550700, 'US', '2017-03-10', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147343, 'Decatur', 'Decatur', '', 42.6343300, -89.4115500, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147344, 'Pryor Creek', 'Pryor Creek', '', 36.3086200, -95.3177700, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147345, 'Silver Lake', 'Silver Lake', '', 34.0866800, -118.2702300, 'US', '2015-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147346, 'Echo Park', 'Echo Park', '', 34.0780800, -118.2606600, 'US', '2015-02-18', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147347, 'Sugarcreek Police Dept', 'Sugarcreek Police Dept', '', 40.5025300, -81.6417600, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147348, 'Scotts Mill', 'Scotts Mill', '', 35.7266600, -78.8839000, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147349, 'Maine', 'Maine', '', 45.0271600, -89.6903900, 'US', '2017-05-23', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147350, 'Plainview', 'Plainview', '', 36.1773100, -83.7953400, 'US', '2017-03-09', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147351, 'Allenstown', 'Allenstown', '', 43.1567300, -71.4047800, 'US', '2017-05-28', 236);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147352, 'Young', 'Young', 'Jang,Jangas,Yang,Young,iangi,yang ge,yang  arwgwyh,Янг,Յանգ,یانگ، اروگوئه,ینگ، یوراگوئے,იანგი,楊格', -32.6984400, -57.6269300, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147353, 'Villa Sara', 'Villa Sara', 'Villa Sara', -33.2534000, -54.4194700, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147354, 'Villa del Carmen', 'Villa del Carmen', 'Carmen,Carmen del Durazno,Pueblo de Nuestra Senora del Carmen,Pueblo de Nuestra Señora del Carmen,Pueblo del Carmen,Villa del Carmen', -33.2500000, -56.0166700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147355, 'Vichadero', 'Vichadero', 'Poblado Vichadero,VCH,Vichadero,Vicheadero', -31.8000000, -54.7166700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147356, 'Vergara', 'Vergara', 'Vergara', -32.9333300, -53.9500000, 'UY', '2012-02-02', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147357, 'Velázquez', 'Velazquez', 'Pueblo Velazquez,Pueblo Velázquez,Velasquez,Velazquez,Velázquez', -34.0363100, -54.2805400, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147358, '25 de Mayo', '25 de Mayo', '25 de Mayo,Isla Mala,Veinticinco de Mayo', -34.1891700, -56.3394400, 'UY', '2015-02-16', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147359, '25 de Agosto', '25 de Agosto', '25 de Agosto,Veinticinco de Agosto', -34.4116700, -56.4022200, 'UY', '2015-02-16', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147360, 'Tupambaé', 'Tupambae', 'Tupambae,Tupambaé', -32.8333300, -54.7666700, 'UY', '2015-02-13', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147361, 'Trinidad', 'Trinidad', 'Porongos,Trinidad,Trinidadas,Villa de Porongos,Villa de Trinidad,Villa de la Santisima Trinidad,Villa de la Santísima Trinidad,Villa de la Trinidad,te li ni da,teulinidadeu,torinida,trynydad  arwgwyh,Тринидад,Тринідад,Տրինիդադ,ترینیداد، اروگوئه,ترینیداد، یوراگوئے,ტრინიდადი,トリニダ,特立尼達,트리니다드', -33.5165000, -56.8995700, 'UY', '2013-08-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147362, 'Trinidad', 'Trinidad', '', -33.5388900, -56.8886100, 'UY', '2006-01-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147363, 'Treinta y Tres', 'Treinta y Tres', 'TYT,Treinta i Tresas,Treinta y Tres,Trejnta i Tres,Trejnta-i-Tres,Treynta i Tres,Villa de Treinta y Tres,san shi san ren cheng,teuleintaiteuleseu,trynta ay trs,trynta y trys,Трейнта и Трес,Трейнта-и-Трес,Трейнта-і-Трес,Տրեյնտա ի Տրես,ترینتا ای ترس,ترینتا ی تریس,ტრეინტა-ი-ტრესი,トレインタ・イ・トレス,三十三人城,트레인타이트레스', -33.2333300, -54.3833300, 'UY', '2017-03-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147364, 'Tranqueras', 'Tranqueras', 'Paso Tranqueras,Tranqueras', -31.2000000, -55.7500000, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147365, 'Tomás Gomensoro', 'Tomas Gomensoro', 'Tomas Gomensoro,Tomás Gomensoro', -30.4287000, -57.4360900, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147366, 'Toledo', 'Toledo', 'Toledo', -34.7380700, -56.0946900, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147367, 'Tarariras', 'Tarariras', 'J. Suarez,J. Suárez,Joaquin Suarez,Joaquín Suárez,Suarez,Suárez,Tarariras', -34.2655500, -57.6186600, 'UY', '2015-06-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147368, 'Tala', 'Tala', 'Tala', -34.3434900, -55.7637500, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147369, 'Tacuarembó', 'Tacuarembo', 'San Fructuoso,TAW,Tacuarembo,Tacuarembó,Takuarembo,Villa de San Fructuoso,Villa de Tacuarembo,ta kua lun bo,takkuvarimpo,takuarenbo,takwalembo,takwarmbw,takwarymbw,Такуарембо,Տակուարեմբո,تاکوآرمبو,تاکواریمبو,தக்குவாறிம்போ,ტაკუარემბო,タクアレンボー,塔夸伦博,타콰렘보', -31.7169400, -55.9811100, 'UY', '2017-03-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147370, 'Villa Soriano', 'Villa Soriano', 'Santo Domingo de Soriano,Soriano,Villa Soriano,Villa de Soriano', -33.3981100, -58.3217700, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147371, 'Solís de Mataojo', 'Solis de Mataojo', 'Solis,Solis Grande,Solis de Mataojo,Solís,Solís Grande,Solís de Mataojo', -34.5995100, -55.4680800, 'UY', '2014-12-28', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147372, 'Soca', 'Soca', 'Doctor Francisco Soca,Doctor Soca,Francisco Soca,Mosquitos,Soca', -34.6843200, -55.7020000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147373, 'Sauce', 'Sauce', 'Sauce', -34.5709000, -56.0816000, 'UY', '2016-08-11', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147374, 'Sarandí Grande', 'Sarandi Grande', 'Sarandi,Sarandi Grande,Sarandí,Sarandí Grande,Villa Sarandi,Villa Sarandí', -33.7333300, -56.3333300, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147375, 'Sarandí del Yi', 'Sarandi del Yi', 'Sarandi del Yi,Sarandí del Yi', -33.3500000, -55.6333300, 'UY', '2012-02-02', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147376, 'Santiago Vázquez', 'Santiago Vazquez', 'Santiago,Santiago Vazquez,Santiago Vázquez', -34.7902800, -56.3500000, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147377, 'Santa Rosa', 'Santa Rosa', 'Santa Rosa', -34.4981900, -56.0379500, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147378, 'Santa Lucía', 'Santa Lucia', 'San Juan Bautista,Santa Lucia,Santa Lucía', -34.4533300, -56.3905600, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147379, 'Santa Clara de Olimar', 'Santa Clara de Olimar', 'Olimar Santa Clara,Pueblo Olimar,Santa Clara,Santa Clara de Olimar,Santa Clara del Olimar', -32.9166700, -54.9666700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147380, 'Santa Catalina', 'Santa Catalina', 'Santa Catalina', -33.7910000, -57.4882400, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147381, 'Santa Bernardina', 'Santa Bernardina', 'Santa Bernardina', -33.3666700, -56.4833300, 'UY', '2012-05-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147382, 'San Ramón', 'San Ramon', 'San Ramon,San Ramón', -34.2915500, -55.9557100, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147383, 'San José de Mayo', 'San Jose de Mayo', 'Ciudad de San Jose,Ciudad de San José,San Chose de Majas,San Jose,San Jose de Mayo,San José,San José de Mayo,San Khose de Majo,San Xose de Mayo,San-Khose-de-Majo,san khwzh dmayw,san-khose-de-maio,sanhosedemayo,sheng he sai de ma yue,Сан Хосе де Майо,Сан-Хосе-де-Майо,Սան Խոսե դե Մայո,سان خوزه دمایو,سان خوسے دے ماجو,სან-ხოსე-დე-მაიო,聖何塞德馬約,산호세데마요', -34.3375000, -56.7136100, 'UY', '2012-01-16', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147384, 'San Javier', 'San Javier', 'Colonia San Javier,San Javier,San Khav''er,Сан Хавьер', -32.6652300, -58.1332000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147385, 'San Jacinto', 'San Jacinto', 'San Jacinto', -34.5446500, -55.8715100, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147386, 'San Félix', 'San Felix', 'San Felix,San Félix', -32.3333300, -58.1333300, 'UY', '2012-05-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147387, 'San Carlos', 'San Carlos', 'San Carlos,San Karlos,San Karlosas,San-Karlos,Villa de San Carlos,san karlws  arwgwyh,sankaleulloseu,sheng ka luo si,Сан-Карлос,Սան Կարլոս,سان کارلوس، اروگوئه,سان کارلوس، یوراگوئے,სან-კარლოსი,聖卡洛斯,산카를로스', -34.7912300, -54.9182400, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147388, 'San Bautista', 'San Bautista', 'San Bautista', -34.4401600, -55.9586100, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147389, 'San Antonio', 'San Antonio', 'San Antonio', -34.4513000, -56.0803600, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147390, 'Salto', 'Salto', 'Ciudad del Salto,STY,Sal''to,Salta,Saltas,Salto,sa er tuo,sal to,salato,salto,saltw  arwgwyh,saltw  awrwghway,saruto,sltw,Салто,Сальто,Սալտո,סלטו,سالتو، أوروغواي,سالتو، اروگوئه,سالتو، یوراگوئے,साल्तो,সালতো,ซัลโต,სალტო,サルト,萨尔托,살토', -31.3833300, -57.9666700, 'UY', '2012-02-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147391, 'Rosario', 'Rosario', 'Rosario,Villa del Rosario,luo sa li ao,rwzaryw  arwgwyh,Росарио,Ռոսարիո,روزاریو، اروگوئه,روساریو، یوراگوئے,羅薩里奧', -34.3166700, -57.3500000, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147392, 'Rodríguez', 'Rodriguez', 'Concordia,Rodriguez,Rodríguez', -34.3810000, -56.5379700, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147393, 'Rocha', 'Rocha', 'Ciudad de Rocha,Roca,Rocha,Roča,locha,luo qia,rocha,rwcha,Роча,Ռոչա,روچا,روچا، یوراگوئے,როჩა,ロチャ,羅恰,로차', -34.4833300, -54.3333300, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147394, 'Rivera', 'Rivera', 'RVY,Rivera,Villa de Rivera,li wei la,libela,ri be ra,ribera,rivera,rybrh,ryfyra,rywra,rywyra,Ривера,Рівера,Ռիվերա,ריברה,ريفيرا,ریورا,ریویرا,রিবেরা,รีเบรา,რივერა,リベラ,里韦拉,리베라', -30.9053400, -55.5507600, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147395, 'Río Branco', 'Rio Branco', 'Artigas,La Cuchilla,Rio Branco,Rio Branko,Rio-Branko,Río Branco,li ao bu lan ke,liobeulangko,ryw brankw  arwgwyh,Рио-Бранко,Ռիո Բրանկո,ریو برانکو، اروگوئه,ریو برانکو، یوراگوئے,里奧布蘭科,리오브랑코', -32.5980200, -53.3858300, 'UY', '2013-03-07', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147396, 'Rafael Perazza', 'Rafael Perazza', 'Rafael Perazza', -34.5233500, -56.7971000, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147397, 'Quebracho', 'Quebracho', 'Quebracho', -31.9352600, -57.9014000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147398, 'Punta del Este', 'Punta del Este', 'PDP,Pounta ntel Este,Punta del Este,Punta del Estė,Punta del'' Ehste,Punta-del''-Ehste,Punta-del''-Este,Punte del Este,ai si te jiao cheng,pun ta del xe s te,puntadel-eseute,pwnta dl asth,Πούντα ντελ Έστε,Пунта дел Есте,Пунта дель Эсте,Пунта-дель-Есте,Пунта-дель-Эсте,פונטה דל אסטה,پونتا دل استه,پونتا دیل ایستے,ปุนตาเดลเอสเต,プンタ・デル・エステ,埃斯特角城,푼타델에스테', -34.9474700, -54.9338200, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147399, 'Progreso', 'Progreso', 'Ingeniero Eduardo Garcia de Zuniga,Ingeniero Eduardo García de Zúñiga,Progreso', -34.6673700, -56.2175800, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147400, 'Estación Porvenir', 'Estacion Porvenir', 'Estacion Porvenir,Estación Porvenir,Porvenir', -32.3665300, -57.8591500, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147401, 'Piriápolis', 'Piriapolis', 'Piriapolis,pi li ya bo li si,pyryaplys,pyryapwlys,Пириаполис,پیریاپلیس,پیریاپولیس,皮里亞波利斯', -34.8628700, -55.2747100, 'UY', '2015-03-26', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147402, 'Piedras Coloradas', 'Piedras Coloradas', 'Piedras Coloradas', -32.3718300, -57.6090100, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147403, 'Paysandú', 'Paysandu', 'Ciudad de Paysandu,Ciudad de Paysandú,Gorad Pajsandu,PDU,Paisandu,Pajsandu,Paysandu,Paysandú,pai sang du,paisando~u,paisandu,payasandu,paysandw,piy san du,Горад Пайсанду,Пайсанду,Պայսանդու,پایساندو,পায়সান্দু,ไปย์ซันดู,პაისანდუ,パイサンドゥー,派桑杜,파이산두', -32.3213900, -58.0755600, 'UY', '2017-03-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147404, 'Paso de los Toros', 'Paso de los Toros', 'Paso de los Toros,Paso-de-los-Toros,Santa Isabel,pa suo de luo si tuo luo si,Пасо-де-лос-Торос,Պասո դե լոս Տորոս,پاسو د لوس‌تروس,پاسو دے لوس توروس,帕索德洛斯托羅斯', -32.8166700, -56.5166700, 'UY', '2015-02-13', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147405, 'Paso de Carrasco', 'Paso de Carrasco', 'Paso de Carrasco', -34.8602800, -56.0522200, 'UY', '2013-04-04', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147406, 'Pando', 'Pando', 'Pando,Villa de Pando,Пандо', -34.7171600, -55.9584000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147407, 'Pan de Azúcar', 'Pan de Azucar', 'Pan de Azucar,Pan de Azúcar', -34.7787000, -55.2358200, 'UY', '2014-12-21', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147408, 'Palmitas', 'Palmitas', 'Palmitas', -33.5071900, -57.8007900, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147409, 'Ombúes de Lavalle', 'Ombues de Lavalle', 'Colonia Ombues de Lavalle,Colonia Ombúes de Lavalle,Ombues de Lavalle,Ombúes de Lavalle', -33.9378300, -57.8095900, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147410, 'Nuevo Berlín', 'Nuevo Berlin', 'Nuevo Berlin,Nuevo Berlín', -32.9771100, -58.0516600, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147411, 'Nueva Palmira', 'Nueva Palmira', 'Nuehva-Pal''mira,Nueva Palmira,nwywa palmyra,xin pa er mi la,Нуэва-Пальмира,نوئوا پالمیرا,نویوا پالمیرا,新帕爾米拉', -33.8699900, -58.4079600, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147412, 'Nueva Helvecia', 'Nueva Helvecia', 'Nuehva-Ehl''vesija,Nueva Elvesia,Nueva Helvecia,nwywa hlwka,xin ai er wei xi ya,Нуэва-Эльвесия,Նուեվա Էլվեսիա,نوئوا هلوکا,نویوا ہیلویسیا,新埃爾韋西亞', -34.3000000, -57.2333300, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147413, 'Montevideo', 'Montevideo', 'Ciudad de Montevideo,Gorad Mantehvideha,MVD,Montebideo,Montevidejas,Montevideo,Montevideu,Montevidiejos,Montevidéu,Montevidėjas,Montevídeó,Muntivideu,Muntividew,Muntividèu,Muntividëw,Urbs Montis Videi,mantibhiri''o,meantevidiyea,meng de wei de ya,meng te wei duo,montebide''o,montebide-o,montebideo,montevide''o,montevidi''o,montevidiyo,montevitiyo,mwntfydw,mwnth wydyw,mwntybydyw,mxn te wi de xo,Μοντεβιδέο,Горад Мантэвідэа,Монтевидео,Монтевідео,Մոնտևիդեո,מאנטעווידעא,מונטווידאו,مونتفيدو,مونته ویدئو,مونته‌ویدئ,مونته‌ویدئو,مونتیبیدیو,مونتېۋىدېئو,मोण्टेवीडियो,मोन्तेविदेओ,মোন্তেবিদেও,ਮੋਂਤੇਵੀਦਿਓ,ମଣ୍ଟିଭିଡ଼ିଓ,மொண்டேவீடியோ,മൊണ്ടേവീഡിയോ,มอนเตวิเดโอ,མཱོན་ཊི་ཝི་ཌོ།,မွန်တီဗစ်ဒီအိုမြို့,მონტევიდეო,ሞንቴቪዴዎ,モンテビデオ,蒙得维的亚,蒙特維多,몬테비데오', -34.9032800, -56.1881600, 'UY', '2013-09-16', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147414, 'Montes', 'Montes', 'Montes', -34.4933900, -55.5621900, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147415, 'Minas de Corrales', 'Minas de Corrales', 'Corrales,Minas de Corrales', -31.5833300, -55.4666700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147416, 'Minas', 'Minas', 'Ciudad de Minas,Lavalleja,Minas,Minasas,mi na si,minaseu,minasi,minasu,mynas  arwgwyh,Минас,Мінас,Մինաս,میناس، اروگوئه,میناس، یوراگوئے,მინასი,ミナス,米納斯,미나스', -34.3758900, -55.2377100, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147651, 'Vatican City', 'Vatican City', 'Citta del Vaticano,Città del Vaticano,Ciudad del Vaticano,Etat de la Cite du Vatican,Staat Vatikanstadt,Staat der Vatikanstadt,Vatican,Vatican City,Vatican City State,Vaticano,Vatikan,Vatikanas,Vatikanstaden,Vatikanstadt,État de la Cité du Vatican,Ватикан', 41.9026800, 12.4541400, 'VA', '2016-12-28', 98);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147652, 'Port Elizabeth', 'Port Elizabeth', 'BQU,Port Elizabeth,Port-Elisabeth', 13.0110200, -61.2354800, 'VC', '2014-04-17', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147653, 'Layou', 'Layou', 'Layou', 13.2017500, -61.2701400, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147654, 'Kingstown', 'Kingstown', 'Gorad Kingstaun,Kin''nkstaoun,Kingstaun,Kingstauna,Kingstaunas,Kingstauno,Kingstaŭno,Kingstown,Kinqstaun,SVD,jin si dui,khing s thawn,kigasata''una,kincutavun,kingsata''una,kingseutaun,kingusutaun,kynghstawn,kyngztawn,Κίνγκσταουν,Κινγκστάουν,Горад Кінгстаўн,Кингстаун,Киҥстаун,Кінгстаун,קינגסטאון,كينغستاون,کنگز ٹاؤن,کینگزتاون,किंग्सटाउन,ਕਿੰਗਸਟਾਊਨ,கிங்சுடவுன்,คิงส์ทาวน์,ཁིན་སི་ཐོན།,კინგსტაუნი,ኪንግስታውን,キングスタウン,金斯敦,킹스타운', 13.1552700, -61.2274200, 'VC', '2016-10-28', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147655, 'Georgetown', 'Georgetown', 'Georgetown', 13.2805400, -61.1185000, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147656, 'Chateaubelair', 'Chateaubelair', 'Chateaubelair,Richmond,Richmond Town', 13.2906900, -61.2404300, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147657, 'Byera Village', 'Byera Village', 'Byera Village', 13.2563600, -61.1195400, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147658, 'Biabou', 'Biabou', 'Baiabu,Biabou', 13.1943000, -61.1390400, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147659, 'Barrouallie', 'Barrouallie', 'Barawally,Barroualie,Barrouallie,Barrualli,Princes Town', 13.2367600, -61.2727500, 'VC', '2016-10-27', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147660, 'Kingstown Park', 'Kingstown Park', '', 13.1592400, -61.2316100, 'VC', '2016-10-28', 191);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147417, 'Migues', 'Migues', 'Migues,Miguez', -34.4875900, -55.6279300, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147418, 'Mercedes', 'Mercedes', 'Ciudad de Mercedes,Mercedes,Mersedes,Mersedesas,mei sai de si,meleusedeseu,mersedesa,mersedesi,merusedesu,mrsds  arwgwyh,Μερσέδες,Мерседес,Մերսեդես,مرسدس، اروگوئه,میرسیدیس، یوراگوئے,মের্সেদেস,მერსედესი,メルセデス,梅塞德斯,메르세데스', -33.2524000, -58.0304700, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147419, 'Melo', 'Melo', 'Ciudad de Melo,MLZ,Mel,Melas,Melo,mei luo,mello,melo,mero,mlw  arwgwyh,Мел,Мело,Մելո,ملو، اروگوئه,میلو، یوراگوئے,মেলো,მელო,メロ,梅洛,멜로', -32.3702800, -54.1675000, 'UY', '2015-10-05', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147420, 'Mariscala', 'Mariscala', 'La Mariscala,Mariscala', -34.0408500, -54.7773200, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147421, 'Maldonado', 'Maldonado', 'Mal''donado,Maldonadas,Maldonado,San Fernando de Maldonado,ma er duo na duo,maldonado,maldwnadw  arwgwyh,marudonado,Малдонадо,Мальдонадо,Մալդոնադո,مالدونادو، اروگوئه,مالدونادو، یوراگوئے,მალდონადო,マルドナド,馬爾多納多,말도나도', -34.9000000, -54.9500000, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147422, 'Los Cerrillos', 'Los Cerrillos', 'Cerrillos,Los Cerrillos', -34.6050000, -56.3563900, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147423, 'Libertad', 'Libertad', 'Liberfad,Libertad', -34.6345900, -56.6173900, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147424, 'Las Toscas', 'Las Toscas', '', -34.7333300, -55.7166700, 'UY', '2006-01-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147425, 'Las Piedras', 'Las Piedras', 'Las Pedras,Las Piedras,Las Piedrasas,Las Pjedras,Las-P''edras,Piedras,San Isidrio,Villa de las Piedras,la si bi de la si,lasa piyedrasa,laseupiedeulaseu,Лас Пиедрас,Лас-Пьедрас,Լաս Պեդրաս,لاس پیڈراس، یوراگوئے,لاس‌پیدراس، اروگوئه,লাস পিয়েদ্রাস,ლას-პიედრასი,ラス・ピエドラス,拉斯彼德拉斯,라스피에드라스', -34.7302000, -56.2191500, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147426, 'Las Piedras', 'Las Piedras', '', -30.2620400, -57.5817400, 'UY', '2012-02-22', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147427, 'Lascano', 'Lascano', 'Lascano,Lazcano', -33.6723500, -54.2065000, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147428, 'La Paz', 'La Paz', 'La Paz', -34.7603100, -56.2259000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147429, 'La Paloma', 'La Paloma', 'La Paloma,Puerto de la Paloma', -34.6626800, -54.1645200, 'UY', '2014-04-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147430, 'La Paloma', 'La Paloma', 'La Paloma', -32.7166700, -55.6000000, 'UY', '2012-05-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147431, 'La Floresta', 'La Floresta', 'Floresta,La Floresta', -34.7557200, -55.6814100, 'UY', '2011-08-10', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147432, 'Juan L. Lacaze', 'Juan L. Lacaze', 'J.L. Lacaze,Juan L. Lacaze,Juan Lacaze,Pueblo Juan L. Lacaze', -34.4188800, -57.4528500, 'UY', '2016-06-04', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147433, 'José Pedro Varela', 'Jose Pedro Varela', 'J.P. Varela,Jose P. Varela,Jose Pedro Varela,José P. Varela,José Pedro Varela', -33.4545100, -54.5358600, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147434, 'José Enrique Rodó', 'Jose Enrique Rodo', 'Drabble,Drable,E. Robo,J.E. Rodo,Jose Enrique Rodo,José Enrique Rodó,Rodo', -33.6961800, -57.5315300, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147435, 'José Batlle y Ordóñez', 'Jose Batlle y Ordonez', 'Batlle y Ordonez,Batlle y Ordoñez,Jose Batlle y Ordonez,José Batlle y Ordóñez', -33.4666700, -55.1166700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147436, 'Joaquín Suárez', 'Joaquin Suarez', 'J. Suarez,Joaquin Suarez,Joaquín Suárez,Pueblo Joaquin Suarez,Pueblo Joaquín Suárez,Suarez,Suárez', -34.7350100, -56.0347000, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147437, 'Juanicó', 'Juanico', 'Joanico,Joanicó,Juanico,Juanicó', -34.5945400, -56.2533400, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147438, 'Isidoro Noblía', 'Isidoro Noblia', '', -31.8333300, -54.1666700, 'UY', '2006-01-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147439, 'Guichón', 'Guichon', 'Guichon,Guichón', -32.3584600, -57.1977800, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147440, 'Fray Bentos', 'Fray Bentos', 'FZB,Frai Bentosas,Fraj Bentos,Fraj-Bentos,Fray Bentos,Frej Bentos,Independencia,Villa Fray Bentos,Villa Independencia,Villa de Fray Bentos,fray bntws,fray byntws,fu lai ben tuo si,peulaibentoseu,Фрай Бентос,Фрай-Бентос,Фрей Бентос,Ֆրայ Բենտոս,فرای بنتوس,فرای بینتوس,ფრაი-ბენტოსი,弗賴本托斯,프라이벤토스', -33.1219400, -58.3030600, 'UY', '2017-07-21', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147441, 'Florida', 'Florida', 'Ciudad de la Florida,Florida,Флорида', -34.0955600, -56.2141700, 'UY', '2012-02-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147442, 'Florencio Sánchez', 'Florencio Sanchez', 'Florencio Sanchez,Florencio Sánchez', -33.8778500, -57.3716600, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147443, 'Empalme Olmos', 'Empalme Olmos', 'Empalme Olmos,Estacion Olmos,Estación Olmos,Olmos', -34.6975300, -55.8926800, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147444, 'Ecilda Paullier', 'Ecilda Paullier', 'Ecilda Paullier,Santa Ecilda', -34.3577800, -57.0488300, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147445, 'Durazno', 'Durazno', 'DZO,Duranzo,Durasnas,Durasno,Durazno,do~urasuno,du la si nuo,dulaseuno,durasno,dwrasnw,dwraznw,Дурасно,Դուրասնո,دورازنو,دوراسنو,დურასნო,ドゥラスノ,杜拉斯諾,두라스노', -33.3805600, -56.5236100, 'UY', '2015-10-05', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147446, 'Dolores', 'Dolores', 'Dolores,Doloresas,doloresi,duo luo lei si,dwlwrs  arwgwyh,Долорес,Դոլորես,دولورس، اروگوئه,دولوریس، یوراگوئے,დოლორესი,多洛雷斯', -33.5300900, -58.2170100, 'UY', '2012-09-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147447, 'Dieciocho de Julio', 'Dieciocho de Julio', '18 de Julio,Dieciocho de Julio,Diez y Ocho de Julio,Pueblo 18 de Julia', -33.6821600, -53.5532500, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147448, 'Delta del Tigre', 'Delta del Tigre', '', -34.7648800, -56.3645000, 'UY', '2015-02-13', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147449, 'Curtina', 'Curtina', 'Curtina,San Maximo,San Máximo', -32.1500000, -56.1166700, 'UY', '2012-01-18', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147450, 'Villa Constitución', 'Villa Constitucion', 'Constitucion,Constitución,Constitution,Pueblo Constitucion,Pueblo Constitución,Villa Constitucion,Villa Constitución', -31.0691300, -57.8494600, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147451, 'Colonia del Sacramento', 'Colonia del Sacramento', 'CYR,Ciudad de la Colonia del Sacramento,Colonia,Colonia del Sacramento,Colonia do Sacramento,Colônia do Sacramento,Kolonia del Sakramento,Kolonia ntel Sakramento,Kolonija,Kolonija del Sakramentas,Kolonija del Sakramento,Kolonija del'' Sakramento,Kolonija-del''-Sakramento,La Ciudad de Colonia,Sacramento,Sakramento koloniyasi,Sakramento koloniyası,cakramento kutiyerrap pakuti,ke luo ni ya·de er·sha jia mian du,kolloniadelsakeulamento,koloniya dela sakramento,kwlwnya dl sakramntw,kwlwnya dyl sakramyntw,qwlwnyh dl sqrmntw,Κολόνια ντελ Σακραμέντο,Колония дел Сакраменто,Колония дель Сакраменто,Колония-дель-Сакраменто,Колонија дел Сакраменто,Колонія-дель-Сакраменто,Կոլոնիա դել Սակրամենտո,קולוניה דל סקרמנטו,کولونیا دل ساکرامنتو,کولونیا دیل ساکرامینتو,কোলোনিয়া দেল সাক্রামেন্তো,சாக்ரமெந்தோ குடியேற்றப் பகுதி,კოლონია-დელ-საკრამენტო,コロニア・デル・サクラメント,科洛尼亞·德爾·沙加緬度,콜로니아델사크라멘토', -34.4626200, -57.8397600, 'UY', '2015-12-09', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147452, 'Chui', 'Chui', 'Chuj,Chuy,chwy,Чуй,Չույ,چوی', -33.6979200, -53.4592600, 'UY', '2016-06-22', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147453, 'Alejandro Gallinal', 'Alejandro Gallinal', 'Alejandro Gallinal,Cerro Colorado', -33.8625200, -55.5426400, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147454, 'Cebollatí', 'Cebollati', 'Cebollati,Cebollatí,Pueblo Cebollati,Pueblo Cebollatí', -33.2670300, -53.7942500, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147455, 'Casupá', 'Casupa', 'Casupa,Casupá,Estacion Casupa,Estación Casupá', -34.0999400, -55.6481100, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147456, 'Castillos', 'Castillos', 'Castillos,Palmara de Castillos,Pueblo de San Vicente de Castillos,San Vicente de Castillos', -34.1987100, -53.8591900, 'UY', '2014-12-21', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147457, 'Carmelo', 'Carmelo', 'Carmelo,Karmelas,Karmelo,Las Viboras,Las Víboras,ka mei luo,karmlw  arwgwyh,Кармело,Կարմելո,کارملو، اروگوئه,კარმელო,卡梅洛', -34.0002300, -58.2840200, 'UY', '2014-04-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147458, 'Carlos Reyles', 'Carlos Reyles', '', -33.0166700, -56.4833300, 'UY', '2006-01-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147459, 'Cardona', 'Cardona', 'Cardona', -33.8704900, -57.3695400, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147460, 'Cardal', 'Cardal', 'Cardal', -34.2905600, -56.3888900, 'UY', '2013-04-04', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147461, 'Canelones', 'Canelones', 'Canelones,Guadalupe,Villa de Canelones', -34.5227800, -56.2777800, 'UY', '2015-10-05', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147462, 'Blanquillo', 'Blanquillo', '', -32.7666700, -55.6333300, 'UY', '2006-01-17', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147463, 'Bella Unión', 'Bella Union', 'BUV,Bel''ja Union,Bel''ja-Un''on,Belja Unionas,Bella Union,Bella Unión,Belya Ownon,Santa Rosa,Santa Rosa del Cuareim,bei ya wu ni weng,bla ywnywn,bya awnyn,Белья Уніон,Белья-Уньон,Բելյա Ունոն,بلا یونیون,بیا اونین,貝亞烏尼翁', -30.2596600, -57.5991900, 'UY', '2017-03-13', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147464, 'Belén', 'Belen', 'Belen,Belén', -30.7871600, -57.7757700, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147465, 'Baltasar Brum', 'Baltasar Brum', 'Baltasar Brum,Cabellos,Estacion Isla Cabello,Estacion Isla de Cabello,Estación Isla Cabello,Estación Isla de Cabello,Isla Cabello,Isla Cabellos,Isla de Cabellos,Pueblo Isla Cabellos', -30.7190500, -57.3259600, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147466, 'Atlántida', 'Atlantida', 'Atlantida,Atlántida,Gorad Atlantyda,Playa Atlantida,Playa Atlántida,a te lan di da,atlantyda  arwgwyh,Атлантида,Горад Атлантыда,Ատլանտիդա,آتلانتیدا، اروگوئه,اتلانتیدا، یوراگوئے,阿特蘭蒂達', -34.7719000, -55.7584000, 'UY', '2011-08-10', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147467, 'Artigas', 'Artigas', 'ATI,Artigas,Artigasas,San Eugenio,a di jia si,aleutigaseu,artygas  arwgwyh,arutigasu,Αρτίγας,Артигас,Արտիգաս,آرتیگاس، اروگوئه,آرتیگاس، یوراگوئے,არტიგასი,アルティガス,阿蒂加斯,아르티가스', -30.4000000, -56.4666700, 'UY', '2012-02-14', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147468, 'Aiguá', 'Aigua', 'Aigua,Aiguá,Pueblo de Aigua,Pueblo de Aiguá', -34.2049800, -54.7566500, 'UY', '2015-09-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147469, 'Aguas Corrientes', 'Aguas Corrientes', 'Aguas Corrientes', -34.5219400, -56.3936100, 'UY', '2012-02-02', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147470, 'Aceguá', 'Acegua', 'Acegua,Aceguá', -31.8666700, -54.2000000, 'UY', '2012-02-02', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147471, 'Puntas de Valdéz', 'Puntas de Valdez', 'Puntas de Valdez,Puntas de Valdéz', -34.5855000, -56.7009700, 'UY', '2015-12-06', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147472, 'Colonia Nicolich', 'Colonia Nicolich', 'Colonia Nicolich', -34.8151600, -56.0243500, 'UY', '2015-11-08', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147473, 'Barra de Carrasco', 'Barra de Carrasco', 'Barra de Carrasco', -34.8772200, -56.0297200, 'UY', '2012-01-20', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147474, 'Pajas Blancas', 'Pajas Blancas', 'Pajas Blancas', -34.8016700, -56.3341700, 'UY', '2012-02-29', 238);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147475, 'Nukus', 'Nukus', 'Gorad Nukus,NCU,Noekis,Nokis,Noukous,Nukus,Nukusas,Nökis,nkws,nu ku si,nu kus,nukuseu,nukusu,nwkws,nwkys,nwqws,Горад Нукус,Нукус,Нүкіс,Նուկուս,נוקוס,نؤکیس,نكوص,نوکوس,นูกุส,ヌクス,努库斯,누쿠스', 42.4530600, 59.6102800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147476, 'Mŭynoq', 'Muynoq', 'Muinak,Mujnak,Muynak,Muynoq,Mŭynoq,Муйнак', 43.7683300, 59.0213900, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147477, 'Qanliko‘l', 'Qanliko`l', 'Leninabad,Leninobod,Qanliko`l,Qanliko‘l,Qanlikul,Qanlikŭl', 42.8395000, 59.0009300, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147478, 'Khŭjayli', 'Khujayli', 'Khodzheili,Khodzhejli,Khodzheyli,Khojeili,Khujayli,Khŭjayli,Ходжейли', 42.4004300, 59.4600500, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147479, 'Kegeyli Shahar', 'Kegeyli Shahar', 'Kegayli,Kegeyli,Kegeyli Shahar', 42.7766700, 59.6077800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147480, 'Qozonketkan', 'Qozonketkan', 'Kazanketken,Qozonketkan', 43.0190700, 59.3642500, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147481, 'Oltinko‘l', 'Oltinko`l', 'Altynkul'',Altynkul’,Oltinko`l,Oltinko‘l,Oltinkul,Oltinkŭl', 43.0687400, 58.9037200, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147482, 'Oqmang‘it', 'Oqmang`it', 'Akmangit,Oqmang`it,Oqmanghit,Oqmang‘it', 42.5988900, 59.5344400, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147483, 'Qo‘ng‘irot Shahri', 'Qo`ng`irot Shahri', 'Gorod Kungrad,Qo`ng`irot Shahri,Qo‘ng‘irot Shahri,Qunghirot Shahri,Qŭnghirot Shahri', 43.0520700, 58.8459600, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147484, 'Xo‘jayli Shahri', 'Xo`jayli Shahri', 'Gorod Khodzheyli,Khujayli Shahri,Khŭjayli Shahri,Xo`jayli Shahri,Xo‘jayli Shahri', 42.4088100, 59.4454400, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147485, 'Chimboy Shahri', 'Chimboy Shahri', 'Chimboy Shahri,Gorod Chimbay', 42.9295200, 59.7819900, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147486, 'Mo‘ynoq Shahri', 'Mo`ynoq Shahri', 'Gorod Muynak,Mo`ynoq Shahri,Mo‘ynoq Shahri,Muynoq Shahri,Mŭynoq Shahri', 43.7787700, 59.0303900, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147487, 'Shumanay Shahri', 'Shumanay Shahri', 'Gorod Shumanay,Shumanay Shahri', 42.6343300, 58.9306000, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147488, 'Zomin', 'Zomin', 'Saamin,Zaamin,Zomin,Зомин', 39.9605600, 68.3958300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147489, 'Nishon Tumani', 'Nishon Tumani', 'Nishon Tumani,Yangi-Nishan,Yangi-Nishon', 38.6939500, 65.6751200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147490, 'Urgut', 'Urgut', 'Urgut,Ургут', 39.4022200, 67.2430600, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147491, 'Mug‘lon Shahar', 'Mug`lon Shahar', 'Mug`lon Shahar,Mughlon,Muglon,Mug‘lon Shahar,Ul''yanovsk,Ul’yanovsk', 38.9187800, 65.4121700, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147492, 'Tirmiz', 'Tirmiz', 'Termez,Termiz,Tirmiz,tai er mei zi,trmdh,trmz,Термез,טרמז,ترمذ,ترمز,泰尔梅兹', 37.2241700, 67.2783300, 'UZ', '2011-07-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147493, 'Sho‘rchi', 'Sho`rchi', 'Chourtchi,Dzhalair,Kul''-Tepe,Kul’-Tepe,Sho`rchi,Sho‘rchi,Shurchi,Shŭrchi', 37.9994400, 67.7875000, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147494, 'Shahrisabz', 'Shahrisabz', 'Chakhrisabz,Sachrisabz,Sachrizabz,Sahrisabz,Sahrisabzas,Schachrissjabs,Sehr-i-Sebz,Shahri-i-Sabz,Shahrisabz,Shakhrisab,Shakhrisabz,Shakhrisabzs,Shakhrisyabz,Sjachrisabz,Xahrisabz,sakhrisabjako etihasika kendra,sha he li sa bu zi,shafurisabusu,shahrisabzi,shhrsbz,Ŝahrisabz,Şehr-i-Sebz,Šachrizabz,Šahrisabz,Šahrisabzas,Шахрисаб,Шахрисабз,שאחריסאבז,شهرسبز,شهری‌سبز,شہر سبز,शख्रिसब्जको एतिहासिक केन्द्र,შაჰრისაბზი,シャフリサブス,沙赫里薩布茲', 39.0577800, 66.8341700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147495, 'Shohimardon', 'Shohimardon', 'Khamzaabad,Kurort Khamza-Abad,Kurort Shakhimardan,Shakhimardan,Shakimardan,Shaymardan,Shohimardon,Шахимардан', 39.9832200, 71.8051200, 'UZ', '2012-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147496, 'Samarqand', 'Samarqand', 'SKD,Samarcanda,Samarcande,Samarkand,Samarkanda,Samarkandas,Samarkando,Samarqand,Semerkant,Semerqend,sa ma er han,samaleukanteu,samarukando,smrqnd,Самарканд,סמרקנד,سمرقند,サマルカンド,撒馬爾罕,撒马尔罕,사마르칸트', 39.6541700, 66.9597200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147497, 'Romiton', 'Romiton', 'Kal''ty-Mauri,Kal’ty-Mauri,Ramitan,Rometan,Romitan,Romiton', 39.9294400, 64.3794400, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147498, 'Qarshi', 'Qarshi', 'Bek Budi,KSQ,Karaki,Karchi,Karshi,Karshy,Karsi,Karsio,Karsis,Karsji,Karszy,Karŝio,Karşi,Karši,Karšis,Karși,Kharsh khot,Qarshi,Qarsi,Qarši,ka er xi,kaleusi,karasi,karushi,nkhshb,qarshy,qrshy,qrsy,Карши,Каршы,Карші,Харш хот,Қарсы,Կարշի,קרשי,قارشی,قرشي,قرشی,نخشب,ਕਾਰਸ਼ੀ,カルシ,卡爾希,카르시', 38.8605600, 65.7890500, 'UZ', '2013-05-12', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147499, 'Muborak', 'Muborak', 'Maburek,Mubarek,Muborak,Муборак', 39.2552800, 65.1527800, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147500, 'Yangi Mirishkor', 'Yangi Mirishkor', 'Mirichkar,Mirishkor,Yangi Mirishkor', 38.8514300, 65.2778900, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147501, 'Kitob', 'Kitob', 'Kitab,Kitob,Китоб', 39.0842500, 66.8331800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147502, 'Kattaqo‘rg‘on', 'Kattaqo`rg`on', 'Kattakurgan,Kattaqo`rg`on,Kattaqo‘rg‘on,Kattaqurghon,Kattaqŭrghon', 39.8988900, 66.2561100, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147503, 'Koson', 'Koson', 'Kasan,Kassan,Koson,Косон', 39.0375000, 65.5850000, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147504, 'Qorovulbozor', 'Qorovulbozor', 'Karaulbazar,Qorovulbozor,Qorowulbozor', 39.5005600, 64.7936100, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147505, 'Karakul’', 'Karakul''', 'Kara Kal,Karakul'',Karakul’,Qorakul,Qorakŭl,Stantslya-Karakul,Каракуль', 39.5333300, 63.8333300, 'UZ', '2013-03-13', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147506, 'Qorako’l', 'Qorako''l', 'Karakul'',Karakul’,Qorako''l,Qorako’l,Qorakul,Qorakŭl,Stantsiya Karakul'',Stantsiya Karakul’', 39.4994400, 63.8538900, 'UZ', '2015-07-25', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147507, 'Kogon', 'Kogon', 'Kagan,Kogon,Novaya Bukhara,Каган', 39.7227800, 64.5516700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147508, 'Ishtixon', 'Ishtixon', 'Ishtihon,Ishtikhon,Ishtixon,Ishtykhan', 39.9663900, 66.4861100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147509, 'G‘uzor', 'G`uzor', 'G`uzor,Ghuzor,Gusar,Guzar,G‘uzor', 38.6208300, 66.2480600, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147510, 'Galaosiyo', 'Galaosiyo', 'Galaasiya,Galaassiya,Galaosiyo,Gallya-Asiya,Gallya-Assiya', 39.8577800, 64.4483300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147511, 'Juma', 'Juma', 'Dzhuma,Juma', 39.7161100, 66.6641700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147512, 'Jomboy', 'Jomboy', 'Dzhambay,Jomboy,Khashdala,Khoshdala', 39.6988900, 67.0933300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147513, 'Denov', 'Denov', 'Dehnan,Denan,Denau,Denov,Denow,Deynau,Денов', 38.2674600, 67.8988600, 'UZ', '2016-09-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147514, 'Daxbet', 'Daxbet', 'Dagbid,Dagbit,Dakhbed,Dakhbet,Daxbet', 39.7638900, 66.9125000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147515, 'Chiroqchi', 'Chiroqchi', 'Chirakchi,Chirakchya,Chiroqchi', 39.0336100, 66.5722200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147516, 'Chelak', 'Chelak', 'Chelak,Chelek,Payaryk', 39.9202800, 66.8611100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147517, 'Charxin', 'Charxin', 'Charkhin,Charxin,Чархин', 39.6966700, 66.7686100, 'UZ', '2017-07-13', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147518, 'Bulung’ur', 'Bulung''ur', 'Bulung''ur,Bulunghur,Bulung’ur,Krasnogvardeiskoye,Krasnogvardeysk,Krasnogvardeyskaya,Krasnogvardeyskoye,Krasnogvardskiy,Rostovtsevo', 39.7647200, 67.2713900, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147519, 'Bukhara', 'Bukhara', 'BHK,Bochara,Bokhara,Bouchara,Boukhara,Bucara,Buchara,Buhar,Buhara,Buharo,Buhhaara,Buhāra,Bujara,Bujará,Bukhaara,Bukhar,Bukhara,Bukharà,Bukhoro,Buxara,Buxoro,Buĥaro,Gorad Bukhara,Staraya Bukhara,bkhara,bkhary,bu ha la,buhala,buhara,bukhara,bukharako etihasika kendra,bwkhara,bwkrh,pukara,Μπουχάρα,Бухар,Бухара,Бухоро,Бұхара,Горад Бухара,בוכרה,بخارا,بخارى,بوخارا,बुखराको एतिहासिक केन्द्र,बुख़ारा,बुखारा,বুখারা,ਬੁਖਾਰਾ,புகாரா,ബുഖാറ,ბუხარა,ブハラ,布哈拉,부하라', 39.7747200, 64.4286100, 'UZ', '2014-05-28', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147520, 'Beshkent', 'Beshkent', 'Beshkent,Bish-Kent,Бешкент', 38.8213900, 65.6530600, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147521, 'Boysun', 'Boysun', 'Baisuk,Baisun,Baysun,Bojsun,Boysun,Бойсун', 38.2083500, 67.2066400, 'UZ', '2016-09-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147522, 'Olot', 'Olot', 'Alat,Alata,Olot', 39.4150000, 63.8033300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147523, 'Oqtosh', 'Oqtosh', 'Aktash,Oqtosh', 39.9213900, 65.9252800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147524, 'Qorovulbozor Shahri', 'Qorovulbozor Shahri', 'Gorod Karaulbazar,Qorovulbozor Shahri,Qorowulbozor Shahri', 39.5030800, 64.8114200, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147525, 'Qorashina', 'Qorashina', 'Karashina,Qorashina', 38.3418500, 66.5634200, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147526, 'Shahrisabz Shahri', 'Shahrisabz Shahri', 'Gorod Shakhrisabz,Shahrisabz Shahri', 39.0520600, 66.8208300, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147527, 'Koson Shahri', 'Koson Shahri', 'Gorod Kasan,Koson Shahri', 39.0447200, 65.5908200, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147528, 'Kitob Shahri', 'Kitob Shahri', 'Gorod Kitab,Kitob Shahri', 39.1225100, 66.8757000, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147529, 'Muborak Shahri', 'Muborak Shahri', 'Gorod Mubarek,Muborak Shahri', 39.2577800, 65.1567400, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147530, 'Beshkent Shahri', 'Beshkent Shahri', 'Beshkent Shahri,Gorod Beshkent', 38.8110700, 65.6424600, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147531, 'G‘uzor Shahri', 'G`uzor Shahri', 'G`uzor Shahri,Ghuzor Shahri,Gorod Guzar,G‘uzor Shahri', 38.6259600, 66.2451500, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147532, 'Qamashi Shahri', 'Qamashi Shahri', 'Gorod Kamashi,Qamashi Shahri', 38.8199800, 66.4644100, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147533, 'Chiroqchi Shahri', 'Chiroqchi Shahri', 'Chiroqchi Shahri,Gorod Chirakchi', 39.0272700, 66.5808300, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147534, 'Yakkabog‘ Shahri', 'Yakkabog` Shahri', 'Gorod Yakkabag,Yakkabog` Shahri,Yakkabogh Shahri,Yakkabog‘ Shahri', 38.9766400, 66.6886700, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147535, 'Yangi-Nishon Shahri', 'Yangi-Nishon Shahri', 'Gorod Yangi-Nishan,Yangi-Nishon Shahri', 38.6450100, 65.6895200, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147536, 'Ravon', 'Ravon', 'Ravan,Ravon,Rawon', 39.9772400, 71.1346700, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147537, 'Zafar', 'Zafar', 'Almazar,Olmazor,Vrevskiy,Zafar,Зафар', 40.9833300, 68.9000000, 'UZ', '2013-11-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147538, 'Yozyovon', 'Yozyovon', 'Yaz"yavan,Yaz”yavan,Yozyovon,Yozyowon', 40.6613900, 71.7436100, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147539, 'Yaypan', 'Yaypan', 'Bazar-Yaypan,Jajpan,Yaipan,Yaypan,Яйпан', 40.3758300, 70.8155600, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147540, 'Yangiyŭl', 'Yangiyul', 'Jangijul'',Kaunchi,Янгиюль', 41.1120200, 69.0471000, 'UZ', '2010-03-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147541, 'Yangiyer', 'Yangiyer', 'Jangier,Ungi-Yere,Yangier,Yangiyer,Янгиер', 40.2750000, 68.8225000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147542, 'Yangirabot', 'Yangirabot', 'Yangirabad,Yangirabod,Yangirabot', 40.0253900, 65.9609500, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147543, 'Yangiqo‘rg‘on', 'Yangiqo`rg`on', 'Yangikurgan,Yangiqo`rg`on,Yangiqo‘rg‘on,Yangiqurghon,Yangiqŭrghon', 41.1947400, 71.7238500, 'UZ', '2017-07-04', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147544, 'Yangiqo‘rg‘on', 'Yangiqo`rg`on', 'Yangikurgan,Yangiqo`rg`on,Yangiqo‘rg‘on,Yangiqurghon,Yangiqŭrghon', 40.5538900, 71.1466700, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147545, 'Yangiobod', 'Yangiobod', 'Jangiabad,Yangiabad,Янгиабад', 41.1191900, 70.0940600, 'UZ', '2010-07-29', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147546, 'Vodil', 'Vodil', 'Vodil,Vuadil'',Vuadil’,Wodil', 40.1742400, 71.7301300, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147547, 'Wobkent', 'Wobkent', 'Vabkend,Vabkent,Wobkent', 40.0302800, 64.5150000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147548, 'Uychi', 'Uychi', 'Uichi,Ujchi,Uychi,Уйчи', 41.0807300, 71.9233100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147549, 'Ŭrtaowul', 'Urtaowul', 'Urtaaul,Urtaowul,Ŭrtaowul', 41.1866700, 69.1452800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147550, 'Urganch', 'Urganch', 'Novo-Urgench,Ourguentch,UGC,Urganch,Urgench,Urgentj,Yrgench,uleugenchi,urugenchi,Ургенч,ウルゲンチ,우르겐치', 41.5500000, 60.6333300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147551, 'Dashtobod', 'Dashtobod', 'Dashtobod,Ul''yanovo,Ul’yanovo', 40.1269400, 68.4944400, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147552, 'Uchqŭrghon Shahri', 'Uchqurghon Shahri', 'Gorod Uchkurgan,Uchkurgan,Uchqurghon,Uchqurghon Shahri,Uchqŭrghon,Uchqŭrghon Shahri', 41.1137100, 72.0791500, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147553, 'Uchko‘prik', 'Uchko`prik', 'Imeni Molotova,Molotovo,Uchko`prik,Uchko‘prik,Uchkuprik,Uchkupryuk', 40.5422200, 71.0608300, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147554, 'Tŭytepa', 'Tuytepa', 'Toi-Tjube,Toi-Tyube,Tojtepa,Toy-Tyube,Toytepa,Tuytepa,Tŭytepa,Тойтепа', 41.0321000, 69.3625300, 'UZ', '2010-10-16', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147555, 'To‘rqao‘rg‘on', 'To`rqao`rg`on', 'To`rqao`rg`on,To‘rqao‘rg‘on,Turagurghon,Turakurgan,Tyurya-Kurgan,Tŭragŭrghon', 40.9998400, 71.5116200, 'UZ', '2016-04-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147556, 'Toshloq', 'Toshloq', 'Tashlak,Toshloq', 40.4772200, 71.7677800, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147557, 'Tashkent', 'Tashkent', 'Daskent,Daşkent,Daşkənd,Gorad Tashkent,Lithopolis,TAS,Ta.kent,Tachkent,Tachkènt,Taixkent,Taschkent,Tashken,Tashkend,Tashkent,Tashkent osh,Tashkenti,Tasjkent,Taskende,Taskent,Taskenta,Taskentas,Taskento,Taszkent,Taxkent,Taŝkento,Taşkent,Taškent,Taškenta,Taškentas,Tașkent,Tochkent,Toshkand,Toshkent,Toshkent shahri,ta shen gan,tasakada,tasakanda,tasakhanda,tashknd,tashqnd,tashukento,taskanda,taskanr,taskantu,taskent,tasyukenteu,thach khen t,tshqnd,tsqnt,Τασκένδη,Горад Ташкент,Ташкен,Ташкент,Ташкент ош,Тошканд,Տաշքենդ,טאשקענט,טשקנט,تاشقند,تاشكند,تاشكەنت,تاشکند,تاشکەند,طشقند,ताशकन्द,ताश्कंद,তাশখন্দ,ਤਾਸ਼ਕੰਦ,தாஷ்கந்து,తాష్కెంట్,ತಾಷ್ಕೆಂಟ್,താഷ്കന്റ്,ทาชเคนต์,ཐ་ཧྲི་ཀན།,ტაშკენტი,ታሽኬንት,タシュケント,塔什干,타슈켄트', 41.2646500, 69.2162700, 'UZ', '2012-04-29', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147558, 'Toshbuloq', 'Toshbuloq', 'Tashbulak,Toshbuloq', 40.9161700, 71.5781900, 'UZ', '2016-04-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147559, 'Tomdibuloq', 'Tomdibuloq', 'Tamdy,Tamdybulak,Tomdibulog,Tomdibuloq', 41.7508000, 64.6171100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147560, 'Taxtako‘pir', 'Taxtako`pir', 'Takhta-Kusyr,Takhtakupir,Takhtakupyr,Takhtakŭpir,Taxtako`pir,Taxtako‘pir,Tazta-Kupir', 43.0117100, 60.3011100, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147561, 'Sirdaryo', 'Sirdaryo', 'Sidare,Sirdaryo,Ssyr-Darja,Syr-Dar''inskiy,Syr-Darjinskaja,Syr-Dar’inskiy,Syr-Novorossiyskiy,Syr-Novorossliski,Syrdar''inskaja,Syrdar''ya,Syrdar’ya,Сырдарьинская', 40.8436100, 68.6616700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147562, 'Showot', 'Showot', 'Shakh-abad,Shavat,Shovot,Showot', 41.6558300, 60.3025000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147563, 'Shahrixon', 'Shahrixon', 'Imeni Stalina,Moskovskiy,Shahrikhon,Shahrixon,Shakhrikhan,Stalino', 40.7133100, 72.0570600, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147564, 'Shofirkon', 'Shofirkon', 'Baumana,Khodzha-arif,Shafirkan,Shafrikan,Shafrikent,Shofirkon', 40.1200000, 64.5013900, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147565, 'Salor', 'Salor', 'Chirchik,Salar,Salor', 41.3722200, 69.3816700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147566, 'Rishton', 'Rishton', 'Imeni Kuybysheva,Kuibyshev,Kuybishewo,Kuybyshe,Kuybyshev,Kuybyshevo,Richtan,Rishdan,Rishtan,Rishton,Ristan,Ristanas,Riştan,Rištanas,li shen dun,rishitan,rshtwn  azbkstan,ryshtan,Риштан,رشتون، ازبکستان,ریشتان,リシタン,里什頓', 40.3566700, 71.2847200, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147567, 'Qŭshkŭpir', 'Qushkupir', 'Kosh Kunir,Koshkupyr,Qushkupir,Qŭshkŭpir', 41.5350000, 60.3455600, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147568, 'Qo‘qon', 'Qo`qon', 'Kokand,Kokandas,Qo''qon,Qo`qon,Qoʻqon,Qo‘qon,Quqon,Qŭqon,kokando,kokanteu,Коканд,コーカンド,코칸트', 40.5286100, 70.9425000, 'UZ', '2012-04-29', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147569, 'Piskent', 'Piskent', 'Piskent,Pskent', 40.8972200, 69.3505600, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147570, 'Poytug‘', 'Poytug`', 'Baytok,Pajtug,Paytok,Paytug,Poytug`,Poytugh,Poytug‘,Пайтуг', 40.8977000, 72.2449000, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147571, 'Payshanba', 'Payshanba', 'Pajshanba,Payshanba,Payshmba,Пайшанба', 40.0077800, 66.2369400, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147572, 'Parkent', 'Parkent', 'Parkent', 41.2944400, 69.6763900, 'UZ', '2016-03-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147573, 'Pop', 'Pop', 'Pap,Pop,Поп', 40.8736100, 71.1088900, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147574, 'Paxtakor', 'Paxtakor', 'Pakhtakor,Paxtakor', 40.3152800, 67.9544400, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147575, 'Paxtaobod', 'Paxtaobod', 'Kokankishlak,Koran-Kishlak,Pakhtaabad,Pakhtaobod,Paxtaobod,Quqonqishloq,Qŭqonqishloq', 40.9293600, 72.4968700, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147576, 'Olmaliq', 'Olmaliq', 'Almalik,Almalyk,Almalykas,Almalık,Ałmałyk,Olmaliq,a er ma lei ke,almallikeu,almalyq,almalyq  azbkstan,arumariku,yalmalyq,Алмалик,Алмалык,Олмалиқ,آلمالیق,آلمالیق، ازبکستان,ئالمالیق,アルマリク,阿尔马雷克,알말리크', 40.8447200, 69.5983300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147577, 'Ohangaron', 'Ohangaron', 'Akhangaran,Akhangaron,Kurama,Ohangaron,Okhangaron', 40.9063900, 69.6383300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147578, 'Nurota', 'Nurota', 'Nurata,Nurota,Нурота', 40.5613900, 65.6886100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147579, 'Novyy Turtkul’', 'Novyy Turtkul''', 'Novyy Turtkul'',Novyy Turtkul’', 41.5500000, 61.0166700, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147580, 'Navoiy', 'Navoiy', 'Kermene,Kermine,NVI,Nava,Navoi,Navoiy,Navojis,Navojo,Navoy,Navoï,Nawayi,Nawayı,Nawoi,Nawoiy,Nazoy,Nevai,na wo yi,naboi,navo''i,navu~ai,nwawy,nwayy,nwayy  azbkstan,Навои,Навої,نوائی,نواوي,نوایی,نوایی، ازبکستان,نەڤایی,नवोई,ਨਵੋਈ,ナヴァーイー,纳沃伊,나보이', 40.0844400, 65.3791700, 'UZ', '2013-03-30', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147581, 'Navbahor', 'Navbahor', 'Chirkay,Gorskiy,Gorskoye,Navbahor,Navbakhor,Nawbahor', 40.4810400, 70.7709300, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147582, 'Namangan', 'Namangan', 'Gorad Namangan,NMA,Namangan,Namanganas,Namangano,Namangán,Nemengan,na ma ngkan,na man gan,namagana,namang-gan,namangan,nmngan,nmnkan,nmnqan,Горад Наманган,Наманган,Наманған,نمنقان,نمنكان,نمنگان,ਨਮਾਗਾਨ,นามางกาน,ナマンガン,納曼干,나망간', 40.9983000, 71.6725700, 'UZ', '2017-02-05', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147583, 'Marhamat', 'Marhamat', 'Marhamat,Markhamat,Markhamat Vtoroy,Myan-Tyube,Russkoe Selo,Russkoye Selo,Мархамат', 40.5023600, 72.3264600, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147584, 'Marhamat', 'Marhamat', 'Marhamat,Markhamat,Markhamat Pervyy,Мархамат', 40.4804800, 72.3138800, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147585, 'Marg‘ilon', 'Marg`ilon', 'Marg`ilon,Margelan,Marghilon,Margilan,Marg‘ilon,Маргилан', 40.4723700, 71.7246300, 'UZ', '2015-12-05', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147586, 'Manghit', 'Manghit', 'Manga,Manghit,Mangit,Mangyt', 42.1155600, 60.0597200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147587, 'Asaka', 'Asaka', 'Asaka,Asake,Assake,Leninsk,Zelensk,Асака', 40.6415300, 72.2386800, 'UZ', '2015-12-05', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147588, 'Qiziltepa', 'Qiziltepa', 'Kizil-Tepe,Kyzyl Tepe,Kyzyltepa,Qiziltepa', 40.0330600, 64.8500000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147589, 'Kuyganyor', 'Kuyganyor', 'Kujgan-Jar,Kujganjar,Kuygan-Yar,Kuyganyar,Kuyganyor,Куйган-Яр,Куйганяр', 40.8544400, 72.3073400, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147590, 'Quvasoy', 'Quvasoy', 'Kubasay,Kuvasa,Kuvasay,Kuwassai,Quvasoy,Quwasoy', 40.2972100, 71.9802600, 'UZ', '2015-11-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147591, 'Qo‘rg‘ontepa', 'Qo`rg`ontepa', 'Kurgan Tyube,Kurgan-Tepe,Kurgantepa,Kyzyl-Tepa,Qo`rg`ontepa,Qo‘rg‘ontepa,Qurghontepa,Qŭrghontepa', 40.7319200, 72.7617700, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147592, 'Yangi Marg‘ilon', 'Yangi Marg`ilon', 'Gorchakovo,Komsomol''skiy,Komsomol’skiy,Stantsiya Gorchakovo,Yangi Marg`ilon,Yangi Marg‘ilon', 40.4272200, 71.7188900, 'UZ', '2015-12-05', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147593, 'Kirguli', 'Kirguli', 'Kirgili,Kirguli', 40.4355300, 71.7672100, 'UZ', '2015-11-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147594, 'Qibray', 'Qibray', 'Kibrai,Kibray,Qibray', 41.3897200, 69.4650000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147595, 'Xo‘jaobod', 'Xo`jaobod', 'Khodzhaabad,Khodzhavat,Khodzhiabad,Khoji-Abad,Khujaobod,Khŭjaobod,Kojo-Abad,Xo`jaobod,Xo‘jaobod', 40.6688600, 72.5600200, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147596, 'Khiwa', 'Khiwa', 'Chiva,Chiwa,Hiiva,Hiva,Jiva,Khiva,Khivà,Khiwa,Khorezm,Xiva,khywa,khywh,khywt,Ĥiva,Хива,خيوة,خیوا,خیوه', 41.3783300, 60.3638900, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147597, 'Hamza', 'Hamza', 'Hamza,Imeni Khamzy Khakimzade,Khamza,Khamza Khakimzada,Khamzy Khakimzade,Vannovskiy', 40.4276200, 71.5053400, 'UZ', '2015-12-05', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147598, 'Haqqulobod', 'Haqqulobod', 'Haqqulobod,Khakkulabad,Khakulabad,Naron,Naryn', 40.9166700, 72.1166700, 'UZ', '2010-08-09', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147599, 'Kosonsoy', 'Kosonsoy', 'Kasansay,Kassan-Sai,Kassansay,Kosonsoy', 41.2494400, 71.5473800, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147600, 'Qorao‘zak', 'Qorao`zak', 'Karauzak,Karauzyak,Qorao`zak,Qorao‘zak,Qorauzak,Qoraŭzak', 43.0220700, 60.0170100, 'UZ', '2016-10-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147601, 'Konimex', 'Konimex', 'Kanimekh,Kenimech,Kenimekh,Konimekh,Konimex', 40.2759300, 65.1451100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147602, 'Jizzax', 'Jizzax', 'Cizzak,Dishsak,Djizak,Djizaks,Dzhizak,Dzhizzak,Dzizakas,Dzjizak,Dzyzak,Dżyzak,Džizakas,Gizaho,Jizak,Jizzakh,Jizzaq,Jizzax,Zhyzak,dzyzq,ji zha ke,jijaheu,jizafu,jizakha,jyzakh,jyzk,jyzkh,Ĝizaĥo,Джизак,Джиззак,Жызак,Жызақ,דזיזק,جيزاخ,جيزك,جیزخ,جیزک,ਜਿਜ਼ਾਖ,ジザフ,吉扎克,지자흐', 40.1158300, 67.8422200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147603, 'Iskandar', 'Iskandar', 'Iskandar,Iskander,Искандар', 41.5538900, 69.7008300, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147604, 'Hazorasp', 'Hazorasp', 'Hazorasp,Khazarasp', 41.3194400, 61.0741700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147605, 'Gurlan', 'Gurlan', 'Gurlan,Gurlek,Gurlen,Гурлан', 41.8447200, 60.3919400, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147606, 'Guliston', 'Guliston', 'Golodnaya Step'',Golodnaya Step’,Gorad Gulistan,Goulistan,Guelistan,Gulistan,Gulistanas,Gulistano,Guliston,Gülistan,Mirzachul'',Mirzachul’,glstan  azbkstan,gu li si tan,gulisatona,gulistona,gulliseutan,gurisutan,gwlstan,gwlystan,Горад Гулістан,Гулистан,Гулистон,Գուլիստան,گلستان، ازبکستان,گولستان,گولیستان,گوڵستان، ئۆزبەکستان,गुलिस्तोन,ਗੁਲੀਸਤੋਨ,グリスタン,古利斯坦,굴리스탄', 40.4897200, 68.7841700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147607, 'Ghijduwon', 'Ghijduwon', 'Akmal''-Abad,Akmal’-Abad,Ghijduwon,Gidzhduvan,Gijduvan,Gijduvon,Gizhduvan,Gydzh-Duvan,Gydzha-Dovan', 40.1000000, 64.6833300, 'UZ', '2012-03-02', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147608, 'Gazli', 'Gazli', 'Gazli', 40.1333300, 63.4500000, 'UZ', '2016-03-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147609, 'G‘azalkent', 'G''azalkent', 'G`azalkent,Gasalkent,Gazalkent,Ghazalkent,G‘azalkent,Газалкент', 41.5580600, 69.7708300, 'UZ', '2012-05-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147610, 'Gagarin', 'Gagarin', 'Erjar,Gagarin,Yerzhar,Гагарин', 40.6619400, 68.1722200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147611, 'Fergana', 'Fergana', 'FEG,Farg''ona,Farghana,Farghona,Farghāna,Fargona,Fargʻona,Fergan,Fergana,Fergano,Ferganá,Ferghana,Fernkana,Fərqanə,Gorad Fergana,Novyy Margelan,Skobelev,Skobelevo,fei er gan na,ferugana,frghanh,frghanh‎,frghant,fyrghana,peleugana,prgnh,Φεργκάνα,Горад Фергана,Фарғона,Фергана,Ֆերգանա,פרגנה,فرغانة,فرغانه,فرغانه‎,فرغانہ,فیرغانا,فەرغانە,ഫെർഗാന,フェルガナ,费尔干纳,페르가나', 40.3842100, 71.7843200, 'UZ', '2014-03-27', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147612, 'Amir Timur', 'Amir Timur', 'Amir Timur,Eski Toshkent,Eski-Tashkent,Iski-Tashkent', 41.0194400, 68.9408300, 'UZ', '2013-08-11', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147613, 'Dŭstlik', 'Dustlik', 'Dustlik,Dŭstlik', 40.5247200, 68.0358300, 'UZ', '2016-09-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147614, 'Dang‘ara', 'Dang`ara', 'Dang`ara,Danghara,Dang‘ara', 40.5838900, 70.9144400, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147615, 'Chust', 'Chust', 'Chust,Chust Shahri,Tschust,Чуст', 41.0032900, 71.2379100, 'UZ', '2017-07-04', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147616, 'Chirchiq', 'Chirchiq', 'Chirchik,Chirchiq,Circig,Circik,Circikas,Tchirtchik,Tjirtjik,Tschirtschik,chileuchikeu,chiruchiku,chyrchyq,chyrchyq  azbkstan,qi er qi ke,Çirçig,Čirčikas,Чирчик,Чирчиқ,چیرچیق,چیرچیق، ازبکستان,チルチク,奇爾奇克,치르치크', 41.4688900, 69.5822200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147617, 'Chinoz', 'Chinoz', 'Chinaz,Chinoz,Cinaz,Tschin,Чиноз', 40.9363300, 68.7612800, 'UZ', '2016-09-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147618, 'Kyzyldzhar', 'Kyzyldzhar', 'Chimgan,Kyzyldzhar,Shimgan,Чимган', 41.5666700, 70.0166700, 'UZ', '2013-03-13', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147619, 'Chortoq', 'Chortoq', 'Chartak,Chertak,Chortoq', 41.0692400, 71.8237200, 'UZ', '2016-04-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147620, 'Buloqboshi', 'Buloqboshi', 'Bulakbashi,Buloqbashi,Buloqboshi', 40.6290700, 72.5021200, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147621, 'Bo‘ka', 'Bo`ka', 'Bo`ka,Bo‘ka,Buka,Bŭka', 40.8110800, 69.1941700, 'UZ', '2016-09-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147622, 'Beshrabot', 'Beshrabot', 'Besh-Rabad,Beshrabot,Beshravat', 40.1976100, 65.3352700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147623, 'Beshariq', 'Beshariq', 'Beshariq,Besharyk,Besharykskogo,Imeni Kirova,Kirovo,Kirowo,Бешарыкского', 40.4358300, 70.6102800, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147624, 'Beruniy', 'Beruniy', 'Beruni,Berunij,Beruniy,Biruni,Biruniy,Shabbaz,Shchabbaz,Sheikh Abaz Vali,Беруний', 41.6911100, 60.7525000, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147625, 'Bektemir', 'Bektemir', 'Bektemir,Kolkhoz Imeni Akhunbabayeva,Бектемир', 41.2097200, 69.3341700, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147626, 'Bekobod', 'Bekobod', 'Bagevat,Begovat,Begowat,Bekabad,Bekabadas,Bekobod,Bigovat,Bïgovat,bei ke bo de,bekabado,byk abad,Бекабад,Бекобод,Բեկաբադ,بیک آباد,بیک‌آباد، ازبکستان,بێکاباد,ベカバード,貝科博德', 40.2208300, 69.2697200, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147627, 'Baliqchi', 'Baliqchi', 'Baliqchi,Balykchi', 40.9049900, 71.8473700, 'UZ', '2016-04-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147628, 'Bag‘dod', 'Bag`dod', 'Bag`dod,Bagdad,Baghdod,Bag‘dod,Serovo', 40.4630600, 71.2122200, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147629, 'Angren', 'Angren', 'Angren,Angrenas,Angrenshakhtstroy,Turk,Turn,an ge lian,ang-geulen,angrn  azbkstan,anguren,Ангрен,آنگرن، ازبکستان,ئانگرێن,アングレン,安格連,앙그렌', 41.0166700, 70.1436100, 'UZ', '2012-01-17', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147630, 'Andijon', 'Andijon', 'AZN,Andican,Andidzhan,Andijan,Andijon,Andiján,Andisjan,Andizan,Andizhan,Andizhan - Andijon,Andizjan,Andiżan,Andižan,an ji yan,andijan,ztnjan,Андижан,ظةنجان,アンディジャン,安集延,안디잔', 40.7820600, 72.3442400, 'UZ', '2017-02-20', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147631, 'Oltinko‘l', 'Oltinko`l', 'Altynkul'',Altynkul’,Oltinko`l,Oltinko‘l,Oltinkul,Oltinkŭl', 40.8010400, 72.1730600, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147632, 'Oltiariq', 'Oltiariq', 'Altyaryk,Oltiariq', 40.3919400, 71.4741700, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147633, 'Oxunboboyev', 'Oxunboboyev', 'Akhunbabayev,Okhunboboyew,Ologhjat,Oxunboboyev,Sufi-Kashlak,Sufia,Sufikishlak,Sufix', 40.7198400, 72.6428200, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147634, 'Oqoltin', 'Oqoltin', 'Akaltyn,Komsomolabad,Oqoltin', 40.7464900, 71.7003100, 'UZ', '2016-04-10', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147635, 'Quva', 'Quva', 'Kuva,Quva,Quwa,Кува', 40.5220400, 72.0729200, 'UZ', '2015-09-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147636, 'Beruniy Shahri', 'Beruniy Shahri', 'Beruniy Shahri,Gorod Beruni', 41.6990400, 60.7550100, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147637, 'To‘rtko‘l Shahri', 'To`rtko`l Shahri', 'Gorod Turtkul'',Gorod Turtkul’,To`rtko`l Shahri,To‘rtko‘l Shahri,Turtkul Shahri,Tŭrtkŭl Shahri', 41.5605500, 61.0018000, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147638, 'Bo‘ston Shahri', 'Bo`ston Shahri', 'Bo`ston Shahri,Bo‘ston Shahri,Buston Shahri,Bŭston Shahri,Gorod Bustan', 41.8460700, 60.9474400, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147639, 'Mang‘it Shahri', 'Mang`it Shahri', 'Gorod Mangit,Mang`it Shahri,Manghit Shahri,Mang‘it Shahri', 42.1221500, 60.0627600, 'UZ', '2016-10-08', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147640, 'Navoiy', 'Navoiy', 'Gorod Navoi,Kermine,Navoi,Navoiy,Navoiy Shahri,Nawoiy Shahri', 40.1000000, 65.3666700, 'UZ', '2016-01-07', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147641, 'Uchquduq Shahri', 'Uchquduq Shahri', 'Gorod Uchkuduk,Uchquduq Shahri', 42.1500100, 63.5522100, 'UZ', '2014-05-29', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147642, 'Karmana Shahri', 'Karmana Shahri', 'Gorod Karmana,Karmana Shahri', 40.1378200, 65.3754500, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147643, 'Qiziltepa Shahri', 'Qiziltepa Shahri', 'Gorod Kyzyltepa,Qiziltepa Shahri', 40.0254000, 64.8288500, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147644, 'Nurota Shahri', 'Nurota Shahri', 'Gorod Nurata,Nurota Shahri', 40.5676200, 65.6794700, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147645, 'Kosonsoy Shahri', 'Kosonsoy Shahri', 'Gorod Kasansay,Kosonsoy Shahri', 41.2632700, 71.5423900, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147646, 'Chortoq Shahri', 'Chortoq Shahri', 'Chortoq Shahri,Gorod Chartak', 41.0770300, 71.8177200, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147647, 'Haqqulobod', 'Haqqulobod', 'Gorod Khakkulabad,Haqqulobod,Haqqulobod Shahri,Khakkulabad', 40.9163400, 72.1205800, 'UZ', '2016-08-03', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147648, 'Pop Shahri', 'Pop Shahri', 'Gorod Pap,Pop Shahri', 40.8764200, 71.1022000, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147649, 'Tŭragŭrghon Shahri', 'Turagurghon Shahri', 'Gorod Turakurgan,Turagurghon Shahri,Tŭragŭrghon Shahri', 41.0033400, 71.5105600, 'UZ', '2012-01-19', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147650, 'Langar', 'Langar', 'Karakushchi,Langar', 40.5205000, 71.6601500, 'UZ', '2015-12-06', 239);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147661, 'La Asunción', 'La Asuncion', 'La Asuncion,La Asunción,La-Asuns''on,Ла-Асунсьон', 11.0333300, -63.8627800, 'VE', '2016-01-22', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147662, 'Caricuao', 'Caricuao', 'Caricuao', 10.4333700, -66.9831300, 'VE', '2012-01-12', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147663, 'Tocuyito', 'Tocuyito', '', 10.1086100, -68.0793000, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147664, 'El Chaparro', 'El Chaparro', '', 9.1517700, -65.0168800, 'VE', '2012-01-05', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147665, 'Anaco', 'Anaco', 'AAO,Anaco', 9.4388900, -64.4727800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147666, 'Santa Cruz de Guacas', 'Santa Cruz de Guacas', '', 7.4432900, -71.3013900, 'VE', '2012-02-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147667, 'El Real', 'El Real', '', 8.4352500, -69.9963300, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147668, 'Puerto Vivas', 'Puerto Vivas', '', 7.5000500, -71.8444600, 'VE', '2012-02-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147669, 'La Mula', 'La Mula', '', 8.5708400, -70.3752400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147670, 'Los Guasimitos', 'Los Guasimitos', '', 8.6643500, -70.2321600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147671, 'Alto Barinas', 'Alto Barinas', '', 8.5931000, -70.2261000, 'VE', '2006-01-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147672, 'Zea', 'Zea', '', 8.3762800, -71.7818500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147673, 'Zaraza', 'Zaraza', 'Zaraza,sa la sa,Зараза,薩拉薩', 9.3502900, -65.3245200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147674, 'Yumare', 'Yumare', '', 10.5973200, -68.6724500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147675, 'Yaritagua', 'Yaritagua', '', 10.0800000, -69.1261100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147676, 'Yaracal', 'Yaracal', '', 10.9709900, -68.5443500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147677, 'Yaguaraparo', 'Yaguaraparo', '', 10.5691600, -62.8269300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147678, 'Villa de Cura', 'Villa de Cura', '', 10.0386300, -67.4893800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147679, 'Villa Bruzual', 'Villa Bruzual', 'Turen,Turén,Villa Bruzual', 9.3327800, -69.1208300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147680, 'Las Casitas del Vegon de Nutrias', 'Las Casitas del Vegon de Nutrias', 'Vegon,Vegon de Nutrias,Vegón,Vegón de Nutrias', 8.2370400, -69.4183000, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147681, 'Valle de La Pascua', 'Valle de La Pascua', 'VDP,Val''e-de-La-Paskua,Valle de La Pascua,Valle de Pascua,Валье-де-Ла-Паскуа', 9.2155400, -66.0073400, 'VE', '2017-05-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147682, 'Valle de Guanape', 'Valle de Guanape', 'El Valle de Guanape,Valle de Guanape', 9.9099900, -65.6740500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147683, 'Valera', 'Valera', 'VLV,Valera,ba lai la,valera,Валера,ვალერა,巴莱拉', 9.3177800, -70.6036100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147684, 'Valencia', 'Valencia', 'Balenzia,Gorad Valensija,VLN,Valencia,Valencio,Valens,Valensi,Valensia,Valensii,Valensija,Valensiya,Valentia,Valentzia,Valincia,Valência,ba lun xi ya,balainsi''a,ballensia,barenshia,blnsyt,valensia,walnsya  wnzwyla,wlnsyh,Валенс,Валенси,Валенсия,Валенсија,Валенсія,Горад Валенсія,Վալենսիա,ולנסיה,بلنسية,والنسیا، ونزوئلا,والیںسیا، کارابوبو,ਬਾਲੈਂਸੀਆ,ვალენსია,バレンシア,巴伦西亚,발렌시아', 10.1620200, -68.0076500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147685, 'Urumaco', 'Urumaco', 'Urumaco', 11.1991300, -70.2549900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147686, 'Ureña', 'Urena', 'Urena,Ureña', 7.9168900, -72.4418800, 'VE', '2012-10-22', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147687, 'Uracoa', 'Uracoa', 'Uracoa', 8.9996000, -62.3516400, 'VE', '2012-10-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147688, 'Urachiche', 'Urachiche', '', 10.1591700, -69.0111100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147689, 'Upata', 'Upata', 'Upata', 8.0086100, -62.3988900, 'VE', '2012-10-16', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147690, 'Umuquena', 'Umuquena', 'Omuquema,Omuquena,Umuquena,Unuquena', 8.2658800, -72.0637100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147691, 'Turmero', 'Turmero', 'Turmeras,Turmero,trmrw,tu er mei luo,Турмеро,ترمرو,ტურმერო,圖爾梅羅', 10.2285600, -67.4742100, 'VE', '2015-01-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147692, 'Tucupita', 'Tucupita', 'TUV,Tucupita,Tukupita,Тукупита', 9.0580600, -62.0500000, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147693, 'Tucupido', 'Tucupido', '', 9.2749600, -65.7715300, 'VE', '2012-01-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147694, 'Tucaní', 'Tucani', '', 8.9700300, -71.2727700, 'VE', '2012-01-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147695, 'Tucacas', 'Tucacas', 'Tucacas', 10.7906000, -68.3257700, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147696, 'Trujillo', 'Trujillo', 'Truchiljas,Trujillo,te lu xi e,teuluhiyo,trwkhyw  trwkhyw,تروخیو، تروخیو,ტრუხილიო,特魯希略,트루히요', 9.3658300, -70.4369400, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147697, 'Tovar', 'Tovar', 'Municipio Tovar,Tovar Municipality,tuo wa er shi,托瓦爾市', 8.3320400, -71.7511800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147698, 'Torunos', 'Torunos', '', 8.5001500, -70.0805600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147699, 'Torondoy', 'Torondoy', '', 9.0311500, -71.0140600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147700, 'Tocópero', 'Tocopero', 'Tocopero,Tocópero', 11.4989700, -69.2589200, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147701, 'Tinaquillo', 'Tinaquillo', 'di na ji yue,蒂納基約', 9.9186100, -68.3047200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147702, 'Tinaco', 'Tinaco', 'Tinaco', 9.6987100, -68.4334800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147703, 'Timotes', 'Timotes', 'Timotes', 8.9822400, -70.7392600, 'VE', '2012-10-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147704, 'Tía Juana', 'Tia Juana', '', 10.2583800, -71.3686500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147705, 'Táriba', 'Tariba', '', 7.8188000, -72.2242700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147706, 'Tabay', 'Tabay', 'Tabai,Tabaj,Tabay,Табай', 8.6311000, -71.0784300, 'VE', '2012-10-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147707, 'Soledad', 'Soledad', 'La Soledad,Soledad', 8.1628100, -63.5658400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147708, 'Socopó', 'Socopo', '', 8.2306200, -70.8219800, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147709, 'Siquisique', 'Siquisique', '', 10.5702700, -69.7030200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147710, 'Sinamaica', 'Sinamaica', 'Sinamaica', 11.0865600, -71.8559500, 'VE', '2014-09-28', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147711, 'Seboruco', 'Seboruco', '', 8.1451400, -72.0733200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147712, 'Sarare', 'Sarare', 'Sarare', 9.7812900, -69.1633000, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147713, 'Santo Domingo', 'Santo Domingo', '', 8.8605200, -70.6948000, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147714, 'San Timoteo', 'San Timoteo', '', 9.8000000, -71.0666700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147715, 'Santa Teresa', 'Santa Teresa', 'Santa Teresa', 10.2340900, -66.6630800, 'VE', '2012-02-02', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147716, 'Santa Rosa', 'Santa Rosa', '', 8.4403300, -69.7010500, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147717, 'Santa Rita', 'Santa Rita', '', 10.5364200, -71.5110400, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147718, 'Santa María de Ipire', 'Santa Maria de Ipire', '', 8.8155600, -65.3225000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147719, 'Santa María de Caparo', 'Santa Maria de Caparo', '', 7.7141200, -71.4646600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147720, 'Santa Lucía', 'Santa Lucia', '', 8.1015500, -69.7775200, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147721, 'Santa Isabel', 'Santa Isabel', '', 9.6321700, -70.8075900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147722, 'Santa Inés', 'Santa Ines', '', 8.2624100, -69.8979500, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147723, 'Santa Elena de Uairén', 'Santa Elena de Uairen', 'SNV,Santa Elena,Santa Elena de Guairen,Santa Elena de Guairén,Santa Elena de Uairen,Santa Elena de Uairén,Santa-Elena-de-Uajren,Санта-Елена-де-Уайрен', 4.6022600, -61.1102500, 'VE', '2014-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147724, 'Santa Elena de Arenales', 'Santa Elena de Arenales', '', 8.8192400, -71.4656400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147725, 'Santa Cruz', 'Santa Cruz', 'Santa Cruz,Santa Cruz de Mora,Santa Cruz de Tovar', 8.3982300, -71.6412600, 'VE', '2012-01-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147726, 'Santa Cruz de Bucaral', 'Santa Cruz de Bucaral', 'Santa Cruz,Santa Cruz de Bucaral', 10.8195300, -69.2777600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147727, 'Santa Cruz', 'Santa Cruz', '', 10.1800000, -67.5118400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147728, 'Santa Catalina', 'Santa Catalina', '', 7.9240800, -68.9174500, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147729, 'Santa Bárbara', 'Santa Barbara', '', 9.6088600, -63.6100300, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147730, 'Santa Bárbara', 'Santa Barbara', 'SBB', 7.8134800, -71.1778800, 'VE', '2017-05-05', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147731, 'Santa Apolonia', 'Santa Apolonia', 'Santa Apolonia,Santa Polonia', 9.4713900, -71.0141900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147732, 'Santa Ana', 'Santa Ana', '', 11.0690800, -63.9242000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147733, 'Santa Ana', 'Santa Ana', '', 9.3056000, -64.6547800, 'VE', '2012-01-05', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147734, 'Santa Ana', 'Santa Ana', '', 8.1169700, -72.0217400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147735, 'San Simón', 'San Simon', '', 8.3507800, -71.8502800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147736, 'San Silvestre', 'San Silvestre', '', 8.2758500, -70.1102700, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147737, 'San Rafael de Onoto', 'San Rafael de Onoto', 'San Rafael,San Rafael de Onoto', 9.6774200, -68.9734400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147738, 'San Rafael de Carvajal', 'San Rafael de Carvajal', 'Carvajal', 9.3033900, -70.5853200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147739, 'San Rafael de Canaguá', 'San Rafael de Canagua', 'Banco de Canagua,Canagua,Canaguá,San Rafael de Canagua,San Rafael de Canaguá', 8.0266700, -70.0086100, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147740, 'San Pablo', 'San Pablo', '', 10.2482800, -68.8445100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147741, 'San Mateo', 'San Mateo', '', 10.2130200, -67.4236500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147742, 'San Mateo', 'San Mateo', '', 9.7392000, -64.5496000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147743, 'San Luis', 'San Luis', '', 11.1203400, -69.6839700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147744, 'San Juan de Manapiare', 'San Juan de Manapiare', 'San Juan de Manapiare', 5.3171800, -66.0486200, 'VE', '2012-10-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147745, 'San Juan de los Morros', 'San Juan de los Morros', 'San Juan de Los Morros,San Juan de los Moros,San Juan de los Morros', 9.9115200, -67.3538100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147746, 'San Juan de Colón', 'San Juan de Colon', 'Colon,Colón,San Juan De Colon,San Juan de Colon,San Juan de Colón', 8.0312500, -72.2605300, 'VE', '2012-10-22', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147747, 'San Juan Bautista', 'San Juan Bautista', 'San Juan,San Juan Bautista', 11.0111700, -63.9440600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147748, 'San José de Barlovento', 'San Jose de Barlovento', 'San Jose,San José', 10.3012500, -65.9905300, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147749, 'San José de Guanipa', 'San Jose de Guanipa', 'El Tigrito,San Jose de Guanipa,San José de Guanipa', 8.8872400, -64.1651200, 'VE', '2012-01-05', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147750, 'San José de Aerocuar', 'San Jose de Aerocuar', 'San Jose,San Jose de Areocuar,San José,San José de Areocuar', 10.5997300, -63.3285200, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147751, 'San Joaquín', 'San Joaquin', 'San Joaquin,San Joaquín', 10.2630000, -67.7857900, 'VE', '2012-05-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147752, 'San Francisco de Yare', 'San Francisco de Yare', 'San Francisco de Yare', 10.1779300, -66.7464900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147753, 'San Francisco', 'San Francisco', '', 10.5536300, -71.7036400, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147754, 'San Fernando de Atabapo', 'San Fernando de Atabapo', 'San Fernando Atabapo,San Fernando de Atabapo', 4.0495600, -67.7003200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147755, 'San Felipe', 'San Felipe', 'SNF,San Felipe,San Felipė,San-Felipe,sanpellipe,sheng fei li pei,Сан-Фелипе,Сан-Феліпе,سان فیلیپے، جاراکوئی,სან-ფელიპე,聖費利佩,산펠리페', 10.3399100, -68.7424700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147756, 'San Diego', 'San Diego', '', 10.2598200, -67.9533000, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147757, 'San Cristóbal', 'San Cristobal', 'Gorad San-Krystobal'',SCI,San Cristobal,San Cristóbal,San Kristobal,San Kristobalis,San-Kristobal'',san krystwbal,san krystwbal  tachyra,sankeuliseutobal,sheng ke li si tuo wa er,Горад Сан-Крыстобаль,Сан Кристобал,Сан-Кристобаль,Сан-Крістобаль,سان كريستوبال,سان کریستوبال، تاچیرا,სან-კრისტობალი,聖克里斯托瓦爾,산크리스토발', 7.7669400, -72.2250000, 'VE', '2017-04-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147758, 'San Casimiro', 'San Casimiro', '', 10.0016900, -67.0146400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147759, 'San Carlos de Río Negro', 'San Carlos de Rio Negro', 'San Carlos,San Carlos de Rio Negro,San Carlos de Río Negro', 1.9166700, -67.0666700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147760, 'San Carlos del Zulia', 'San Carlos del Zulia', 'Del Zulia,San Carlos,San Carlos del Zulia', 9.0000300, -71.9135200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147761, 'San Carlos', 'San Carlos', 'San Carlos,San Karlosas,san karlws  kwkhydys,sankaleulloseu,sheng ka luo si,سان کارلوس، کوخیدیس,სან-კარლოსი,聖卡洛斯,산카를로스', 9.6612400, -68.5826800, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147762, 'Sanare', 'Sanare', '', 9.7514500, -69.6531800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147763, 'San Antonio del Táchira', 'San Antonio del Tachira', 'SVZ,San Antonio,San Antonio del Tachira,San Antonio del Táchira', 7.8145400, -72.4431000, 'VE', '2017-02-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147764, 'San Antonio de Los Altos', 'San Antonio de Los Altos', '', 10.3885300, -66.9517900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147765, 'San Antonio del Golfo', 'San Antonio del Golfo', '', 10.4415500, -63.7896100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147766, 'San Antonio', 'San Antonio', 'Aldea San Antonio,San Antonio', 7.9637800, -68.4338400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147767, 'Sabaneta', 'Sabaneta', '', 8.7532600, -69.9351600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147768, 'Sabana Grande', 'Sabana Grande', '', 9.4028000, -70.7976200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147769, 'Sabana de Parra', 'Sabana de Parra', '', 10.1211100, -69.0363900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147770, 'Sabana de Mendoza', 'Sabana de Mendoza', '', 9.4351300, -70.7761200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147771, 'Rubio', 'Rubio', 'Rubio,Рубио', 7.7013100, -72.3556900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147772, 'La Villa del Rosario', 'La Villa del Rosario', 'Rosario,Villa del Rosario,Росарио', 10.3258000, -72.3134300, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147773, 'Río Chico', 'Rio Chico', 'Rio Chico,Río Chico', 10.3204300, -65.9778200, 'VE', '2012-10-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147774, 'Río Caribe', 'Rio Caribe', 'Caribe,Rio Caribe,Río Caribe', 10.6971000, -63.1096500, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147775, 'Quiriquire', 'Quiriquire', '', 9.9795000, -63.2199100, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147776, 'Quíbor', 'Quibor', 'Quibor,Quíbor', 9.9286600, -69.6201000, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147777, 'Queniquea', 'Queniquea', 'Queniquea,ke ni ke a,克尼克阿', 7.9171700, -72.0155700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147778, 'Quebrada Seca', 'Quebrada Seca', '', 8.7001500, -70.3194100, 'VE', '2012-02-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147779, 'Punto Fijo', 'Punto Fijo', 'LSP,Punto Fijo,peng tuo fei huo,პუნტო-ფიხო,蓬托菲霍', 11.6956000, -70.1995700, 'VE', '2016-11-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147780, 'Punta de Piedras', 'Punta de Piedras', 'Punta de Piedras,Punta de las Piedras', 10.9013000, -64.0969600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147781, 'Punta de Piedra', 'Punta de Piedra', 'Puerto Piedras,Punta Piedra,Punta de Piedra', 7.6175900, -71.4916400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147782, 'Punta de Mata', 'Punta de Mata', 'Punta de Mata,Punta de Mota', 9.6913100, -63.6092100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147783, 'Punta Cardón', 'Punta Cardon', 'Cardon,Cordon,El Cardon,El Cardón,Puerto Cardon,Punta Cardon,Punta Cardón,Punta-Kardon,Пунта-Кардон', 11.6580600, -70.2150000, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147784, 'Puerto Píritu', 'Puerto Piritu', 'Puerto Piritu,Puerto Píritu', 10.0613000, -65.0420700, 'VE', '2012-10-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147785, 'Puerto La Cruz', 'Puerto La Cruz', 'Puehrto La Kruz,Puehrto-la-Krus,Puerto Cruz,Puerto La Krus,Puerto de La Cruz,Puerto la Cruz,Puerto la Krusas,bwyrtw la krwz,la ke lu si gang,Пуерто Ла Крус,Пуэрто Ла Круз,Пуэрто-ла-Крус,بويرتو لا كروز,პუერტო-ლა-კრუსი,拉克魯斯港', 10.2166700, -64.6166700, 'VE', '2012-10-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147786, 'Puerto de Nutrias', 'Puerto de Nutrias', 'Puerto Nutrias,Puerto de Nutrias', 8.0728100, -69.3024600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147787, 'Puerto Cumarebo', 'Puerto Cumarebo', 'Cumarebo,Puerto Cumarebo', 11.4878300, -69.3522200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147788, 'Puerto Cabello', 'Puerto Cabello', 'PBL,Portus Cabellensis,Puehrto-Kabel''o,Puerto Cabello,Puerto Kabeljas,Puerto Kabello,Puerto-Kabel''jo,ka bei e gang,pueleutokabeyo,Пуерто Кабелло,Пуерто-Кабельйо,Пуэрто-Кабельо,პუერტო-კაბელიო,卡貝略港,푸에르토카베요', 10.4705100, -68.0295800, 'VE', '2016-04-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147789, 'Puerto Ayacucho', 'Puerto Ayacucho', 'PYH,Pouerto Agiakoutso,Puehrto-Ajakucho,Puerto Ajakucas,Puerto Ajakučas,Puerto Ayacucho,a ya ku qiao gang,pueleutoayakucho,pwyr to xi xa kucho,pwyrtw ajakwchw,Πουέρτο Αγιακούτσο,Пуэрто-Аякучо,پویرتو اجاکوچو,ปวยร์โตไออากูโช,პუერტო-აიაკუჩო,阿亞庫喬港,푸에르토아야쿠초', 5.6604900, -67.5834300, 'VE', '2016-04-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147790, 'Pueblo Nuevo', 'Pueblo Nuevo', 'El Chivo,Pueblo Nuevo', 8.9645400, -71.6088800, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147791, 'Pueblo Llano', 'Pueblo Llano', '', 8.9148500, -70.6591900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147792, 'Pregonero', 'Pregonero', 'Pregonero', 8.0190900, -71.7659500, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147793, 'Porlamar', 'Porlamar', 'PMV,Porlamar,Porlamaras,bo la ma er,Порламар,პორლამარი,波拉马尔', 10.9577100, -63.8697100, 'VE', '2016-07-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147794, 'Píritu', 'Piritu', '', 11.3738900, -69.1372200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147795, 'Píritu', 'Piritu', '', 10.0389100, -65.0297500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147796, 'Píritu', 'Piritu', '', 9.3708300, -69.2102800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147797, 'Petare', 'Petare', 'Petare,Petarė,pei ta lei,petale,petare,Петаре,პეტარე,ペタレ,佩塔雷,페타레', 10.4722600, -66.8015500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147798, 'Pedregal', 'Pedregal', '', 11.0203700, -70.1205900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147799, 'Pedraza La Vieja', 'Pedraza La Vieja', 'Pedraza La Vieja,Pedraza la Vieja', 7.9168000, -71.0593400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147800, 'Pedernales', 'Pedernales', 'PDZ', 9.9710000, -62.2520000, 'VE', '2017-05-05', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147801, 'Pariaguán', 'Pariaguan', '', 8.8435700, -64.7105300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147802, 'Paraíso de Chabasquén', 'Paraiso de Chabasquen', 'Chabasquen,Paraiso,Paraiso de Chabasquen,Paraiso de Chavasquen,Paraíso de Chabasquén,Paraíso de Chavasquén', 9.4336500, -69.9475400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147803, 'La Plaza Paraguachi', 'La Plaza Paraguachi', 'La Plaza de Paraguachi,Paraguachi', 11.1078300, -63.8553700, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147804, 'Papelón', 'Papelon', '', 8.9410900, -69.4602100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147805, 'Pampatar', 'Pampatar', 'Pampatar,Panpatar,Pompatar', 11.0012500, -63.7934300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147806, 'Pampanito', 'Pampanito', '', 9.4103700, -70.5011600, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147807, 'Pampán', 'Pampan', '', 9.4447500, -70.4775900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147808, 'Palo Negro', 'Palo Negro', '', 10.1738900, -67.5419400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147809, 'Palmira', 'Palmira', '', 7.8360700, -72.2275800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147810, 'Palmasola', 'Palmasola', '', 9.2333300, -66.7166700, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147811, 'Ospino', 'Ospino', '', 9.2967300, -69.4554600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147812, 'Ortiz', 'Ortiz', 'Ortiz', 9.6216800, -67.2904700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147813, 'Onoto', 'Onoto', '', 9.5971400, -65.1935000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147814, 'Ocumare del Tuy', 'Ocumare del Tuy', 'Ocumare,Ocumare del Tuy', 10.1164900, -66.7760900, 'VE', '2012-10-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147815, 'Ocumare de la Costa', 'Ocumare de la Costa', 'Ocumare de la Costa', 10.4612700, -67.7687200, 'VE', '2012-10-16', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147816, 'Obispos', 'Obispos', '', 8.6070100, -70.1048900, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147817, 'Nueva Bolivia', 'Nueva Bolivia', '', 9.1417600, -71.0912000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147818, 'Nirgua', 'Nirgua', '', 10.1552600, -68.5663000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147819, 'Naguanagua', 'Naguanagua', 'Naguanagua', 10.2600000, -68.0186100, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147820, 'Mucumpiz', 'Mucumpiz', '', 8.4166700, -71.1333300, 'VE', '2006-01-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147821, 'Mucuchíes', 'Mucuchies', 'Mucuchies,Mucuchíes,Mucuhies', 8.7489900, -70.9141800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147822, 'Motatán', 'Motatan', '', 9.3900200, -70.5911900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147823, 'Morón', 'Moron', '', 10.4888900, -68.2002800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147824, 'Monte Carmelo', 'Monte Carmelo', '', 9.1858300, -70.8156100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147825, 'Montalbán', 'Montalban', '', 10.2129800, -68.3267400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147826, 'Mirimire', 'Mirimire', '', 11.1602000, -68.7260400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147827, 'Miranda', 'Miranda', '', 10.1498700, -68.3941800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147828, 'Michelena', 'Michelena', 'Michelena', 7.9549000, -72.2432200, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147829, 'Mérida', 'Merida', 'Emerita,Gorad Meryda,MRD,Meria,Merida,Meridae,Merido,Méria,Mérida,Santiago de los Caballeros de Merida,Santiago de los Caballeros de Mérida,mardt,mei li da shi,melida,merida,mryda,mrydh,myryda  myryda,Μέριδα,Горад Мерыда,Меридæ,Мерида,Меріда,Մերիդա,מערידא,מרידה,ماردة,مریدا,میریدا، میریدا,მერიდა,ሜሪዳ፣ ቬኔዝዌላ,メリダ,梅里達市,메리다', 8.5897200, -71.1561100, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147830, 'Mene de Mauroa', 'Mene de Mauroa', 'El Mene,Mene Mauroa,Mene de Mauroa,Mene de Maurua', 10.6815600, -71.0367800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147831, 'Masparrito', 'Masparrito', '', 9.0019400, -70.3013900, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147832, 'Maroa', 'Maroa', 'Maroa', 2.7186100, -67.5599200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147833, 'Maripa', 'Maripa', 'Mariapa,Maripa', 7.4158400, -65.1903400, 'VE', '2015-10-28', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147834, 'Marigüitar', 'Mariguitar', 'Mariguita,Mariguitar,Marigüita,Marigüitar', 10.4471600, -63.9044900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147835, 'Mariara', 'Mariara', '', 10.2964400, -67.7181300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147836, 'Maracay', 'Maracay', 'MYC,Maracay,Marakai,Marakaj,Marakajo,Marakajus,Marakay,ma la kai,malakai,marakai,marakay,Μαρακάι,Маракай,ماراکای,მარაკაი,マラカイ,马拉凯,마라카이', 10.2353500, -67.5911300, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147837, 'Maracaibo', 'Maracaibo', 'Gorad Marakajba,MAR,Maracaibo,Marakaibas,Marakaibo,Marakaimpo,Marakajbo,Marakaybo,Marakaypu,ma la kai bo,ma ra ki bo,malakaibo,maraka''ibo,marakaibo,marakaybw,Μαρακάιμπο,Горад Маракайба,Маракаибо,Маракайбо,Մարակայբո,מרקאיבו,ماراكايبو,माराकाईबो,ਮਾਰਾਕਾਈਬੋ,มาราไกโบ,მარაკაიბო,マラカイボ,马拉开波,마라카이보', 10.6666300, -71.6124500, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147838, 'Maporal', 'Maporal', '', 7.6450000, -70.4198500, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147839, 'Mamporal', 'Mamporal', 'Mamporal,Manporal', 10.3646100, -66.1304400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147840, 'Maiquetía', 'Maiquetia', 'Maiquetia,Maiquetía', 10.5962100, -66.9548500, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147841, 'Machiques', 'Machiques', 'Machiques', 10.0607700, -72.5521200, 'VE', '2014-08-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147842, 'Los Teques', 'Los Teques', 'Los Tekes,Los Tekesas,Los Teques,Los-Tekes,loseutekeseu,luo si te ke si,lws tykys,Λος Τέκες,Лос Текес,Лос-Текес,لوس تیکیس,ლოს-ტეკესი,ロス・テケス,洛斯特克斯,로스테케스', 10.3444700, -67.0432500, 'VE', '2013-08-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147843, 'Los Rastrojos', 'Los Rastrojos', 'Los Rastrojos,Rastrojo,Rastrojos', 10.0258800, -69.2416600, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147844, 'Los Guayos', 'Los Guayos', 'Guayos,Los Guayos', 10.1802600, -67.9377000, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147845, 'Los Dos Caminos', 'Los Dos Caminos', 'Dos Caminos,Los Dos Caminos', 10.4938900, -66.8286300, 'VE', '2012-01-15', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147846, 'Lobatera', 'Lobatera', 'Lobatera', 7.9293000, -72.2468300, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147847, 'Libertad', 'Libertad', 'Lagunitas,Lagunítas,Libertad', 9.3556200, -68.6917700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147848, 'Libertad', 'Libertad', '', 8.3265100, -69.6297700, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147849, 'Capacho Viejo', 'Capacho Viejo', 'Libertad', 7.8285300, -72.3190700, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147850, 'La Yuca', 'La Yuca', '', 8.7310900, -70.1807200, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147851, 'La Victoria', 'La Victoria', 'La Victoria,La Viktorija,la wei duo li ya,la wyktwrya  aragwa,لا ویکتوریا، اراگوا,ლა-ვიქტორია,拉維多利亞', 10.2184400, -67.3301700, 'VE', '2012-10-25', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147852, 'La Vela de Coro', 'La Vela de Coro', '', 11.4620900, -69.5659100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147853, 'Veguitas', 'Veguitas', 'La Veguita,Veguita,Veguitas', 8.8239100, -69.9958100, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147854, 'La Unión', 'La Union', '', 8.2157300, -67.7665300, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147855, 'Las Vegas', 'Las Vegas', '', 9.5372700, -68.6296000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147856, 'Las Tejerías', 'Las Tejerias', 'Las Tejerias,Las Tejerías,Tejerias', 10.2523700, -67.1847200, 'VE', '2012-10-12', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147857, 'Las Mercedes', 'Las Mercedes', '', 9.1101700, -66.3971800, 'VE', '2012-01-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147858, 'La Quebrada', 'La Quebrada', 'La Quebrada', 9.1546200, -70.5760400, 'VE', '2012-10-23', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147859, 'La Plata', 'La Plata', '', 10.3202500, -71.2721000, 'VE', '2012-08-30', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147860, 'La Luz', 'La Luz', '', 8.3941900, -69.8235800, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147861, 'Lagunillas', 'Lagunillas', '', 10.1300800, -71.2594600, 'VE', '2011-10-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147862, 'Lagunillas', 'Lagunillas', '', 8.5128600, -71.3878900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147863, 'La Guaira', 'La Guaira', 'LAG,La Guaira,La Guayra,La Gvaira,La-Guajra,la gua yi la,la gwayra,la-guaira,lagwaila,ra・guaira,Ла-Гуайра,لا گوایرا,ლა-გუაირა,ラ・グアイラ,拉瓜伊拉,라과이라', 10.5990100, -66.9346000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147864, 'La Esmeralda', 'La Esmeralda', '', 3.1666700, -65.5500000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147865, 'La Cruz de Taratara', 'La Cruz de Taratara', 'La Cruz,La Cruz de Tarara,La Cruz de Taratara', 11.0639500, -69.7131000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147866, 'La Concepción', 'La Concepcion', '', 10.6191900, -71.8381400, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147867, 'Chameta', 'Chameta', 'Chameta,La Chameta', 8.1002300, -70.9067100, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147868, 'Caramuca', 'Caramuca', 'Caramuca,Coramuca,La Caramuca', 8.5970800, -70.3205600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147869, 'La Azulita', 'La Azulita', 'La Azulita', 8.7131500, -71.4441700, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147870, 'Juan Griego', 'Juan Griego', '', 11.0817200, -63.9654900, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147871, 'Jacura', 'Jacura', '', 11.0741700, -68.8560400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147872, 'Irapa', 'Irapa', '', 10.5696800, -62.5810200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147873, 'Higuerote', 'Higuerote', 'HGE,Higuerote', 10.4810600, -66.1008300, 'VE', '2016-06-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147874, 'Güiria', 'Gueiria', 'GUI', 10.5780600, -62.2977100, 'VE', '2017-05-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147875, 'Güigüe', 'Guigue', '', 10.0852800, -67.7791700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147876, 'Guayabal', 'Guayabal', '', 8.0007700, -67.3973200, 'VE', '2012-01-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147877, 'Guatire', 'Guatire', 'Guatire,gua di lei,guatire,gwatile,Гуатире,Гуатіре,გუატირე,グアティレ,瓜蒂雷,과티레', 10.4762000, -66.5426600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147878, 'Guasipati', 'Guasipati', '', 7.4770200, -61.8966600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147879, 'Guarenas', 'Guarenas', 'Guarenas', 10.4673600, -66.6066300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147880, 'Guaraque', 'Guaraque', '', 8.1534700, -71.7356300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147881, 'Guanta', 'Guanta', '', 10.2344800, -64.5955200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147882, 'Guanarito', 'Guanarito', '', 8.6962500, -69.2083200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147883, 'Guanare', 'Guanare', 'GUQ,Guanare,Gvanare,Gvanarė,gua na lei,guanare,gwanale,Гуанаре,گوانارے,გუანარე,グアナレ,瓜納雷,과나레', 9.0418300, -69.7420600, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147884, 'Guama', 'Guama', '', 10.2703200, -68.8213100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147885, 'Guadarrama', 'Guadarrama', '', 8.5350800, -68.0492300, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147886, 'Guacara', 'Guacara', 'Guacara', 10.2260900, -67.8770000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147887, 'Farriar', 'Farriar', '', 10.4696700, -68.5585700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147888, 'Encontrados', 'Encontrados', '', 9.0608500, -72.2341300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147889, 'El Vigía', 'El Vigia', 'El Vigia,El Vigía,VIG', 8.6136600, -71.6528400, 'VE', '2016-02-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147890, 'El Valle del Espíritu Santo', 'El Valle del Espiritu Santo', 'El Valle,El Valle del Espiritu Santo,El Valle del Espíritu Santo,Espiritu Santo', 10.9828300, -63.8831000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147891, 'El Toro', 'El Toro', '', 10.9542300, -71.6484300, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147892, 'El Tocuyo', 'El Tocuyo', 'Ehl''-Tokujo,El Tocuyo,El''-Tokujo,Tocuyo,ai er tuo ku yue,Ель-Токуйо,Эль-Токуйо,埃爾托庫約', 9.7873400, -69.7937000, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147893, 'El Tigre', 'El Tigre', 'ELX,El Tigre,El Tigrė,ai er di ge lei,eltigeule,xel ti ker,เอลตีเกร,ელ-ტიგრე,埃爾蒂格雷,엘티그레', 8.8875200, -64.2454400, 'VE', '2013-11-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147894, 'El Sombrero', 'El Sombrero', '', 9.3863000, -67.0581800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147895, 'El Socorro', 'El Socorro', 'El Socorro,Socorro', 8.9935200, -65.7424700, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147896, 'El Regalo', 'El Regalo', 'El Regalo,La Palmita', 8.4345500, -69.1767000, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147897, 'San Rafael del Piñal', 'San Rafael del Pinal', 'El Pinal,El Piñal', 7.5298700, -71.9592200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147898, 'El Pilar', 'El Pilar', 'El Pilar', 10.5333300, -63.1500000, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147899, 'El Paradero', 'El Paradero', '', 9.7723300, -70.6154400, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147900, 'El Pao', 'El Pao', 'El Pao,Pao', 9.6375200, -68.1288400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147901, 'El Palmer', 'El Palmer', '', 8.0333300, -61.8833300, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147902, 'Elorza', 'Elorza', 'EOZ,Elorza,Paso del Viento', 7.0608800, -69.4976500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147903, 'El Limón', 'El Limon', 'El Limon,El Limonas,El Limón,ai er li meng,el-limoni,ელ-ლიმონი,埃爾利蒙', 10.3058900, -67.6321200, 'VE', '2012-10-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147904, 'El Hatillo', 'El Hatillo', 'El Hatillo,El Hatillo Municipality,Municipio El Hatillo,Pueblo el Hatillo,ai er a di yue shi,el-atiyo si,eruatijo shi,ელ-ატილიოს მუნიციპალიტეტი,エルアティジョ市,埃爾阿蒂約市,엘아티요 시', 10.4299400, -66.8161000, 'VE', '2012-10-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147905, 'El Dividive', 'El Dividive', 'Dividive,Dividivi,El Dividive', 9.4744700, -70.7338500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147906, 'El Corozo', 'El Corozo', '', 10.1206100, -71.0442200, 'VE', '2012-08-30', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147907, 'El Corozo', 'El Corozo', 'Corozo,Corozo Pando,El Corozo', 8.5675000, -70.3577800, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147908, 'El Consejo', 'El Consejo', '', 10.2371700, -67.2714100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147909, 'El Cobre', 'El Cobre', 'El Cobre', 8.0356600, -72.0555100, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147910, 'El Cantón', 'El Canton', 'Canton,Cantón,El Canton,El Cantón', 7.4772900, -71.2956000, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147911, 'El Baúl', 'El Baul', '', 8.9621600, -68.2955400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147912, 'Ejido', 'Ejido', 'Egido,Ehkhido,Ejido,Эхидо', 8.5466500, -71.2408700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147913, 'Duaca', 'Duaca', 'Duaca', 10.2858600, -69.1622700, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147914, 'Dolores', 'Dolores', '', 8.2862300, -69.5663300, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147915, 'Dabajuro', 'Dabajuro', 'Dabajuro', 11.0227300, -70.6776900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147916, 'Curiapo', 'Curiapo', '', 8.5809400, -60.9975500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147917, 'Curbatí', 'Curbati', '', 8.4544300, -70.5544100, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147918, 'Cúpira', 'Cupira', 'Cupira,Cúpira', 10.1612800, -65.7001300, 'VE', '2012-10-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147919, 'Cumanacoa', 'Cumanacoa', '', 10.2501300, -63.9191800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147920, 'Cumaná', 'Cumana', 'CUM,Cumana,Cumaná,Gorad Kumana,Kumana,ku ma na,kumana,kwmana,Горад Кумана,Кумана,کومانا,กูมานา,კუმანა,クマナ,庫馬納,쿠마나', 10.4539700, -64.1825600, 'VE', '2015-04-24', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147921, 'Cúa', 'Cua', 'Cua,Cúa,Kua,Куа', 10.1589200, -66.8857500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147922, 'Coro', 'Coro', 'CZE,Coro,Corum,Koro,Koro shaary,Santa Ana de Coro,Santa Ana de Koras,Santa-Ana-de-Koro,kolo,koro,qwrw,santa ana dy kwrw,sheng an na de ke luo,Коро,Коро шаары,Санта-Ана-де-Коро,קורו,سانتا آنا دي كورو,سانتا آنا دے کورو,სანტა-ანა-დე-კორო,コロ,聖安娜德科羅,코로', 11.4045000, -69.6734400, 'VE', '2014-05-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147923, 'Concepción', 'Concepcion', '', 10.8000000, -71.7666700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147924, 'Coloncito', 'Coloncito', '', 8.3256300, -72.0895100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147925, 'Cojedes', 'Cojedes', 'Cojedes,Kokhedes,Кохедес', 9.6223200, -68.9180500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147926, 'Cocorote', 'Cocorote', '', 10.3197800, -68.7838600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147927, 'Clarines', 'Clarines', 'Clarines', 9.9399100, -65.1651700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147928, 'Ciudad Ojeda', 'Ciudad Ojeda', 'Ciudad Ojeda,Ciudat Ojeda,Siudad Ocheda,ao he da cheng,siudad-okheda,სიუდად-ოხედა,奧赫達城', 10.1963500, -71.3081800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147929, 'Ciudad Guayana', 'Ciudad Guayana', 'CGU,Cidade Guaiana,Ciudad Guayana,Ciudad Guiana,Ciudat Guayana,Guayana,Guayana City,PZO,S''judad-Guajana,San Felix de Guayana,San Félix de Guayana,San Tome,San Tome de Guayana,San Tomé,San Tomé de Guayana,Santo Tome de Guayana,Santo Tomo,Santo Tomé de Guayana,Sijudad Gvajana,Siudad Guajana,Sjudad Guajan,gui ya na cheng,shiudaguayana,siudad-guaiana,siudadeugwayana,Сиудад Гуаяна,Сијудад Гвајана,Сьюдад-Гуаяна,סיודד גואיאנה,სიუდად-გუაიანა,シウダーグアヤナ,圭亞那城,시우다드과야나', 8.3512200, -62.6410200, 'VE', '2016-03-23', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147930, 'Ciudad De Nutrias', 'Ciudad De Nutrias', 'Ciudad De Nutrias,Nutrias', 8.0953500, -69.3079800, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147931, 'Ciudad Bolivia', 'Ciudad Bolivia', '', 8.3530400, -70.5712100, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147932, 'Ciudad Bolívar', 'Ciudad Bolivar', 'Angostura,Bolivar,Bolivar llaqta,Bolívar,Bolívar llaqta,CBL,Ciudad Bolivar,Ciudad Bolívar,Gorad S''judad-Balivar,S''judad-Bolivar,Siudad Bolivar,Siudad Bolivaras,Syudad Bolivar,Syudad Bolívar,Ziuda Bolivar,Ziudá Bolívar,bo li wa er cheng,si''udada bolivara,siudad-bolivari,siudadeubollibaleu,sywdad bwlywar,Горад Сьюдад-Балівар,Сиудад Боливар,Сьюдад-Боливар,Сьюдад-Болівар,سیوداد بولیوار,सिउदाद बोलिवर,სიუდად-ბოლივარი,シウダ・ボリバル,玻利瓦尔城,시우다드볼리바르', 8.1292300, -63.5408600, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147933, 'Churuguara', 'Churuguara', 'Churuguara,Churugura', 10.8137000, -69.5378200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147934, 'Chivacoa', 'Chivacoa', 'Chivacoa', 10.1602800, -68.8950000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147935, 'Chichiriviche', 'Chichiriviche', 'Chichiriviche', 10.9333000, -68.2771600, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147936, 'Chejendé', 'Chejende', '', 9.6189200, -70.3569600, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147937, 'Charallave', 'Charallave', '', 10.2424700, -66.8572300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147938, 'Chaguaramas', 'Chaguaramas', 'Chaguaramas,Chaguaramos', 9.3385500, -66.2525500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147939, 'Chacao', 'Chacao', 'Chacao,Municipio Chacao,cha kao shi,chakao shi,chakao si,ჩაკაოს მუნიციპალიტეტი,チャカオ市,查考市,차카오 시', 10.4959800, -66.8534700, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147940, 'Tacarigua', 'Tacarigua', 'Central Tacarigua,Central Tacariqua,Tacarigua', 10.0862100, -67.9198200, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147941, 'Caucagüito', 'Caucaguito', 'Caucaguita,Caucaguito,Caucagüito', 10.4866600, -66.7379900, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147942, 'Caucagua', 'Caucagua', '', 10.2831000, -66.3759100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147943, 'Catia La Mar', 'Catia La Mar', 'Catia La Mar,Catia de la Mar', 10.6038300, -67.0303400, 'VE', '2012-10-12', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147944, 'Casigua El Cubo', 'Casigua El Cubo', 'CUV,Casigua,Casigua El Cubo,Colina', 8.7449300, -72.5196700, 'VE', '2013-03-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147945, 'Casanay', 'Casanay', 'Casanay', 10.5036900, -63.4155300, 'VE', '2012-10-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147946, 'Carúpano', 'Carupano', 'CUP,Carupano,Carúpano,Karupanas,ka lu pa nuo,კარუპანო,卡魯帕諾', 10.6651600, -63.2538700, 'VE', '2016-02-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147947, 'Carrizal', 'Carrizal', 'Carrizal,Carrizales,Karrisal'',Каррисаль', 10.3498500, -66.9863200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147948, 'Carora', 'Carora', 'Carora,VCR', 10.1755400, -70.0827500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147949, 'Caripito', 'Caripito', 'Carapito,Caripito', 10.1102600, -63.0963300, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147950, 'Cariaco', 'Cariaco', 'Cariaco', 10.4957300, -63.5539900, 'VE', '2012-10-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147951, 'Carache', 'Carache', '', 9.6287200, -70.2285500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147952, 'Caracas', 'Caracas', 'CCS,Caracae,Caracas,Caraques,Gorad Karakas,Karakas,Karakasa,Karakasas,Karakaso,ka la ka si,ka raka s,kalakaseu,karakas,karakasa,karakasu,karakkas,kraks,Καράκας,Горад Каракас,Каракас,Կարակաս,קאראקאס,קראקס,كاراكاس,کاراکاس,کراکس,काराकास,কারাকাস,ਕਾਰਾਕਾਸ,કારાકાસ,କାରାକାସ,கரகஸ்,ಕರಾಕಸ್,കാരക്കാസ്,การากัส,ཁ་ར་ཁ་སི,ကရာကက်စ်မြို့,კარაკასი,ካራካስ,カラカス,卡拉卡斯,카라카스', 10.4880100, -66.8791900, 'VE', '2015-06-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147953, 'Caraballeda', 'Caraballeda', 'Caraballeda', 10.6111900, -66.8521500, 'VE', '2012-11-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147954, 'Capitanejo', 'Capitanejo', '', 8.0117100, -71.0045800, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147955, 'Canape Capatárida', 'Canape Capatarida', '', 11.1755000, -70.6207200, 'VE', '2016-07-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147956, 'Cantaura', 'Cantaura', 'Cantaura,Cantura', 9.3057100, -64.3584100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147957, 'Campo Elías', 'Campo Elias', 'Campo Elias,Campo Elías,El Morro', 9.3934700, -70.0603500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147958, 'Camatagua', 'Camatagua', '', 9.7876200, -66.9061900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147959, 'Camaguán', 'Camaguan', '', 8.1065500, -67.6072400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147960, 'Calderas', 'Calderas', '', 8.9142600, -70.4474500, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147961, 'Calabozo', 'Calabozo', 'CLZ,Calabozo,Kalabosas,ka la wo suo,კალაბოსო,卡拉沃索', 8.9241600, -67.4292900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147962, 'Caicara', 'Caicara', 'Caicara,Caicara de Maturin,Caicara de Maturín', 9.8175500, -63.6133100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147963, 'Cagua', 'Cagua', 'Cagua', 10.1863400, -67.4593500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147964, 'Cabure', 'Cabure', '', 11.1500000, -69.6088900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147965, 'Cabudare', 'Cabudare', 'Cabudare', 10.0288900, -69.0894400, 'VE', '2012-10-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147966, 'Cabimas', 'Cabimas', 'CBS,Cabimas,Caramas,Kabimas,Kabimasas,ka wei ma si,kabymas,Кабимас,كابيماس,კაბიმასი,卡維馬斯', 10.3882800, -71.4399300, 'VE', '2012-01-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147967, 'Bum Bum', 'Bum Bum', 'Bum Bum,Bumbun,Bumbún', 8.2766400, -70.7666400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147968, 'Bruzual', 'Bruzual', 'Bruzual', 8.0505200, -69.3325700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147969, 'Boraure', 'Boraure', '', 10.2493300, -68.7695000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147970, 'Boconoíto', 'Boconoito', '', 8.8465900, -69.9803200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147971, 'Boconó', 'Bocono', 'Bocono,Boconó,bo ke nuo,博科諾', 9.2538500, -70.2510500, 'VE', '2015-06-20', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147972, 'Boca de Uchire', 'Boca de Uchire', 'Boca de Uchire,Uchire', 10.1315200, -65.4211500, 'VE', '2012-10-09', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147973, 'Boca del Río', 'Boca del Rio', '', 10.9675700, -64.1805000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147974, 'Biscucuy', 'Biscucuy', 'Biscucuy,Bisoucuy', 9.3594400, -69.9839000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147975, 'Biruaca', 'Biruaca', 'Biruaca', 7.8448300, -67.5167900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147976, 'Betijoque', 'Betijoque', '', 9.3756800, -70.7313100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147977, 'Bejuma', 'Bejuma', '', 10.1730900, -68.2588700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147978, 'Baruta', 'Baruta', 'Baruta,Nuestra Senora del Rosario de Baruta,Nuestra Señora del Rosario de Baruta', 10.4339800, -66.8766200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147979, 'Barrancas', 'Barrancas', '', 8.7686800, -70.1122000, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147980, 'Barquisimeto', 'Barquisimeto', 'BRM,Barkisimetas,Barkisimeto,Barquisimeto,Barquisimetum,Barquisimito,Gorad Barkisimeta,ba ji xi mei tuo,baleukisimeto,barkysymtw,barukishimeto,brqysymtw,Баркисимето,Баркісімето,Горад Баркісімета,ברקיסימטו,بارکیسیمتو,ბარკისიმეტო,バルキシメト,巴基西梅托,바르키시메토', 10.0647000, -69.3570300, 'VE', '2016-02-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147981, 'Barinitas', 'Barinitas', '', 8.7622200, -70.4111100, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147982, 'Barinas', 'Barinas', 'BNS,Barinas,Barinas llaqta,Barinasas,Ijoloti Barinas,ba li na si,balinaseu,barinasi,barynas,barynas  barynas,Μπαρίνας,Баринас,Барінас,Иёлоти Баринас,باريناس,باریناس، باریناس,ბარინასი,巴里納斯,바리나스', 8.6226100, -70.2074900, 'VE', '2013-08-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147983, 'Barcelona', 'Barcelona', 'BLA,Barcelona,Barcelono,Barselona,Gorad Barselona,Varkeloni,ba sai luo na,baleusellona,barselona,barslwna  wnzwyla,barslwna  wynyzwyla,baruserona,Βαρκελώνη,Барселона,Горад Барселона,بارسلونا، ونزوئلا,بارسلونا، وینیزویلا,ဘာစီလိုနာမြို့၊ ဗင်နီဇွဲလား,ბარსელონა,バルセロナ,巴塞羅那,바르셀로나', 10.1362500, -64.6861800, 'VE', '2016-01-07', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147984, 'Barbacoas', 'Barbacoas', 'Barbacoas', 9.4785500, -66.9745800, 'VE', '2012-10-12', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147985, 'Bailadores', 'Bailadores', 'Bailadores,Bajladores,bai la duo lei si,Байладорес,拜拉多雷斯', 8.2526400, -71.8280500, 'VE', '2012-12-27', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147986, 'Bachaquero', 'Bachaquero', '', 9.9620900, -71.1237700, 'VE', '2012-08-30', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147987, 'Aroa', 'Aroa', '', 10.4386100, -68.8941700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147988, 'Arismendi', 'Arismendi', '', 8.4797400, -68.3699600, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147989, 'Aricagua', 'Aricagua', '', 8.2234300, -71.1370500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147990, 'Araya', 'Araya', 'Araya', 10.5797300, -64.2582600, 'VE', '2012-10-26', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147991, 'Araure', 'Araure', 'Araure', 9.5600900, -69.2147500, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147992, 'Arauquita', 'Arauquita', 'Araquita,Arauquita', 8.7083300, -69.6572200, 'VE', '2012-02-04', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147993, 'Aragua de Barcelona', 'Aragua de Barcelona', 'Aragua,Aragua de Barcelona', 9.4558800, -64.8292800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147994, 'Altamira', 'Altamira', '', 8.8235900, -70.5024400, 'VE', '2012-01-31', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147995, 'Altagracia de Orituco', 'Altagracia de Orituco', '', 9.8600500, -66.3813900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147996, 'Aguasay', 'Aguasay', 'Aguasay,Agusay', 9.4248900, -63.7307700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147997, 'Acarigua', 'Acarigua', 'AGV,Acarigua,Acarígua,Akarigua,Akarigva,a ka li gua,akaligwa,akarigua,akarygwa,Акаригуа,Акарігуа,اکاریگوا,აკარიგუა,アカリグア,阿卡里瓜,아카리과', 9.5545100, -69.1956400, 'VE', '2012-10-18', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147998, 'Abejales', 'Abejales', 'Abejales,Los Avejales', 7.6224100, -71.5101700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(147999, 'Las Mesas', 'Las Mesas', '', 8.1645400, -72.1655600, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148000, 'San José de Bolívar', 'San Jose de Bolivar', '', 7.9113900, -71.9719400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148001, 'Santa Rita', 'Santa Rita', '', 10.2069600, -67.5388400, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148002, 'San Josecito', 'San Josecito', '', 7.6599700, -72.2195800, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148003, 'Cordero', 'Cordero', 'Cordero', 7.8559100, -72.1807500, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148004, 'Sierra Imataca', 'Sierra Imataca', '', 8.4555000, -62.4289100, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148005, 'San José de Guaribe', 'San Jose de Guaribe', '', 9.8602500, -65.8130600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148006, 'Maturín', 'Maturin', 'MUN,Maturin,Maturinas,Maturín,ma tu lin,matulin,matwryn,Матурин,Матурін,ماتورين,ماتورین,მატურინი,馬圖林,마투린', 9.7456900, -63.1832300, 'VE', '2013-11-10', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148007, 'Temblador', 'Temblador', '', 9.0071600, -62.6421600, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148008, 'Palmasola', 'Palmasola', '', 10.5936300, -68.5442200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148009, 'Delicias', 'Delicias', '', 7.5650500, -72.4475400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148010, 'La Fría', 'La Fria', 'LFR,La Fria,La Fría', 8.2152300, -72.2488800, 'VE', '2013-12-01', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148011, 'La Grita', 'La Grita', 'La Grita,la ge li ta,la gryta,لا گریتا,拉格里塔', 8.1321900, -71.9833700, 'VE', '2012-10-19', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148012, 'Capacho Nuevo', 'Capacho Nuevo', 'Independencia', 7.8240900, -72.3090000, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148013, 'La Tendida', 'La Tendida', '', 8.5075700, -71.8316600, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148014, 'Agua Blanca', 'Agua Blanca', 'Agua Blanca', 9.6614600, -69.1075200, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148015, 'El Playón', 'El Playon', 'El Playon,El Playón,Santa Rosalia', 9.0985700, -69.0491400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148016, 'Arapuey', 'Arapuey', '', 9.2593400, -70.9524800, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148017, 'Macapo', 'Macapo', '', 9.8260200, -68.4389900, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148018, 'El Cafetal', 'El Cafetal', '', 10.4694100, -66.8306300, 'VE', '2011-10-13', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148019, 'Caucaguita', 'Caucaguita', '', 10.3578200, -66.8025200, 'VE', '2011-10-13', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148020, 'La Dolorita', 'La Dolorita', '', 10.4883000, -66.7860800, 'VE', '2011-10-13', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148021, 'Guasdualito', 'Guasdualito', 'GDO,Guasdalito,Guasdualito', 7.2424100, -70.7323500, 'VE', '2013-05-16', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148022, 'San Fernando de Apure', 'San Fernando de Apure', 'SFD,San Fernando,San Fernando Apure,San Fernando de Apure', 7.8878200, -67.4723600, 'VE', '2017-05-06', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148023, 'San Juan de Payara', 'San Juan de Payara', 'San Juan de Payara', 7.6456000, -67.6067400, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148024, 'San Sebastián', 'San Sebastian', '', 9.9410800, -67.1718300, 'VE', '2015-06-17', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148025, 'Lecherías', 'Lecherias', '', 10.1976900, -64.6940700, 'VE', '2012-01-03', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148026, 'Santa Cruz de los Taques', 'Santa Cruz de los Taques', '', 11.8235000, -70.2563700, 'VE', '2012-01-08', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148027, 'Independencia', 'Independencia', '', 10.3343200, -68.7551200, 'VE', '2012-01-11', 241);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148028, 'Road Town', 'Road Town', 'Gorad Rod-Taun,Road Town,Rod Taunas,Rod-Taun,Rod-Tauno,Rod-Taŭno,Roount Taoun,Roud Taun,lodeutaun,luo de cheng,rodotaun,rotu tavun,rwd tawn,Ρόουντ Τάουν,Горад Род-Таўн,Род-Таун,Роуд Таун,רואוד טאון,رود تاون,روڈ ٹاون,ரோடு டவுன்,როუდ-ტაუნი,ロードタウン,罗德城,로드타운', 18.4269300, -64.6207900, 'VG', '2014-04-09', 243);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148655, 'Vaiusu', 'Vaiusu', 'Vaiasa,Vaiusu', -13.8267800, -171.7933300, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148656, 'Vailima', 'Vailima', 'Vailima', -13.8641700, -171.7612600, 'WS', '2015-08-30', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148657, 'Vailoa', 'Vailoa', 'Vailoa', -13.7555100, -172.3069800, 'WS', '2013-06-30', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148658, 'Solosolo', 'Solosolo', 'Solosolo', -13.8750400, -171.6418100, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148659, 'Siusega', 'Siusega', '', -13.8443200, -171.8139700, 'WS', '2006-01-17', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148660, 'Satapuala', 'Satapuala', 'Satapuala', -13.8353500, -171.9796300, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148661, 'Samamea', 'Samamea', 'Samamea,Spitzerberg', -13.9337500, -171.5312200, 'WS', '2013-05-05', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148662, 'Safotulafai', 'Safotulafai', 'Safatulafei,Safotulafai,Safotulafei', -13.6714700, -172.1776800, 'WS', '2013-05-05', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148663, 'Safotu', 'Safotu', 'Safotu', -13.4513200, -172.4017700, 'WS', '2012-12-10', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148664, 'Nofoali‘i', 'Nofoali`i', '', -13.8217000, -171.9587300, 'WS', '2006-01-17', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148665, 'Mulifanua', 'Mulifanua', 'Mulifanua', -13.8318300, -172.0360200, 'WS', '2013-08-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148666, 'Matavai', 'Matavai', '', -14.0320800, -171.6476800, 'WS', '2006-01-17', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148667, 'Malie', 'Malie', 'Malie', -13.8004400, -171.8469000, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148668, 'Lufilufi', 'Lufilufi', 'Lufilufi', -13.8744900, -171.5985700, 'WS', '2013-05-05', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148669, 'Lotofagā', 'Lotofaga', 'Lotofaga,Lotofagā,Lotofanga', -13.9764300, -171.8578100, 'WS', '2012-01-18', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148670, 'Leulumoega', 'Leulumoega', 'Leulumoega,Leulumoenga', -13.8229700, -171.9612700, 'WS', '2013-05-05', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148671, 'Gataivai', 'Gataivai', 'Gaitavai,Gataivai', -13.7736000, -172.3880200, 'WS', '2012-12-08', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148672, 'Fasito‘outa', 'Fasito`outa', 'Fasito`outa,Fasitouta,Fasito‘outa', -13.8116300, -171.9406300, 'WS', '2012-01-18', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148673, 'Faleula', 'Faleula', 'Faleula,Falula', -13.7945700, -171.8312600, 'WS', '2012-01-18', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148674, 'Falefa', 'Falefa', 'Falefa,Falifa,Naneivi,Sagapolu,Sanonu', -13.8869500, -171.5880500, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148675, 'Apia', 'Apia', 'APW,Apia,Apiae,Apija,Apio,Apiya,Apía,Gorad Apija,a pi ya,abya,api''a,apia,apiya,appiya,apya,xa pi xa,΄Aπια,Απία,Апиæ,Апиа,Апия,Апија,Апіа,Горад Апія,אפיה,آپیا,أبيا,आपिया,ਆਪੀਆ,ஆப்பியா,അപിയ,อาปีอา,ཨ་པི་ཡ།,აპია,አፒያ,アピア,阿皮亚,阿皮亞,아피아', -13.8333300, -171.7666600, 'WS', '2010-08-16', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148676, 'A’opo', 'A''opo', 'A''opo,A’opo', -13.5397500, -172.5193100, 'WS', '2013-05-05', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148677, 'Afenga', 'Afenga', 'Afega,Afenga', -13.7972600, -171.8530800, 'WS', '2012-12-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148678, 'Asau', 'Asau', 'AAU,Asau', -13.5196300, -172.6378400, 'WS', '2013-08-11', 192);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148644, 'Sola', 'Sola', 'SLH,Sola', -13.8761100, 167.5516700, 'VU', '2017-01-04', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148645, 'Port-Vila', 'Port-Vila', 'Bila,Fila,Port Fila,Port Vila,Port-Vila,VLI,Vila,poteubilla,potobira,pwrt wylh,wei la gang,Βίλα,Порт Вила,Порт-Вила,פורט וילה,ፖርት ቪላ,ポートビラ,維拉港,포트빌라', -17.7338100, 168.3218800, 'VU', '2016-06-28', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148646, 'Port-Olry', 'Port-Olry', 'Port-Olry', -15.0417500, 167.0726500, 'VU', '2014-08-15', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148647, 'Norsup', 'Norsup', 'NUS,Norsoup,Norsup,Norsuup', -16.0653600, 167.3971400, 'VU', '2013-06-10', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148648, 'Luganville', 'Luganville', 'Gorad Luganvil,Ljuganvil'',Louganville,Luganvil,Luganvilis,Luganvill,Luganville,Luganville Bay,SON,Santo,lu gan wei er,luganbil,lwgnwwyl,ruganbiru,Горад Луганвіл,Луганвил,Луганвилл,Люганвиль,לוגנוויל,ルーガンビル,卢甘维尔,루간빌', -15.5198900, 167.1623500, 'VU', '2014-08-18', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148649, 'Lakatoro', 'Lakatoro', 'Lakatoro,Лакаторо', -16.0999200, 167.4163600, 'VU', '2012-03-31', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148650, 'Isangel', 'Isangel', 'Isangel,Исангел', -19.5416700, 169.2816700, 'VU', '2017-01-04', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148651, 'Saratamata', 'Saratamata', '', -15.2903100, 167.9667900, 'VU', '2013-07-10', 240);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148032, 'Yên Vinh', 'Yen Vinh', '', 18.6666700, 105.6666700, 'VN', '2012-06-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148033, 'Yên Thành', 'Yen Thanh', 'Yen Thanh,Yên Thành', 18.9985600, 105.4711600, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148034, 'Yên Ninh', 'Yen Ninh', 'Yen Ninh,Yên Ninh', 20.1839600, 106.0612100, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148035, 'Thị Trấn Yên Minh', 'Thi Tran Yen Minh', 'Thi Tran Yen Minh,Thị Trấn Yên Minh,Yen Minh,Yên Minh', 23.1179200, 105.1415900, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148036, 'Yến Lạc', 'Yen Lac', 'Yen Lac,Yên Lạc,Yến Lạc', 22.2369300, 106.1814900, 'VN', '2012-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148037, 'Yên Lạc', 'Yen Lac', 'Yen Lac,Yên Lac,Yên Lạc', 21.2364600, 105.5729700, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148038, 'Yên Châu', 'Yen Chau', 'Muong Vat,Yen Chau,Yên Châu', 21.0458400, 104.3010100, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148039, 'Yên Bái', 'Yen Bai', 'Jenbaj,Yen Bai,Yen Bay,Yên Bái,Йенбай', 21.7228800, 104.9113000, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148040, 'Cai Doi Vam', 'Cai Doi Vam', 'Cai Doi Vam,Cái Đôi Vàm,Xom Cai Doi Vam,Xóm Cái Đôi Vàm', 8.8570700, 104.8119900, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148041, 'Trảng Bom', 'Trang Bom', 'Trang Bom,Trảng Bom,Xa Trang Bom,Xã Trảng Bôm', 10.9535800, 107.0058900, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148042, 'Gia Ray', 'Gia Ray', 'Gia Ray,Xa Gia Ray,Xã Gia Ray', 10.9261500, 107.4017200, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148043, 'Vũng Tàu', 'Vung Tau', 'Cap-Saint-Jacques,Cape Saint James,Saint James,VTG,Ville du Cap,Vung Tau,Vungtau,Vũng Tàu,Xa Vung Tau,bungttau,buntau,tou dun shi,Вунгтау,ブンタウ,頭 頓市,붕따우', 10.3459900, 107.0842600, 'VN', '2016-03-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148044, 'Vũng Liêm', 'Vung Liem', 'Vung Liem,Vũng Liêm', 10.0957600, 106.1854800, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148045, 'Vụ Bản', 'Vu Ban', 'Vi Ban,Vi Bản,Vu Ban,Vụ Bản', 20.4642000, 105.4434800, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148046, 'Võ Xu', 'Vo Xu', 'Vo Xu,Võ Xu,Xo Xu,Xõ Xu', 11.1869100, 107.5602500, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148047, 'Vị Thanh', 'Vi Thanh', 'Duc Long,Vi Tanh,Vi Thanh,Vị Thanh,Đức Long', 9.7844900, 105.4701200, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148048, 'Vĩnh Yên', 'Vinh Yen', 'Vieh Yen,Vinh Yen,Vĩnh Yên,Yen', 21.3089100, 105.6048900, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148049, 'Thị Trấn Vĩnh Tuy', 'Thi Tran Vinh Tuy', 'Thi Tran Vinh Tuy,Thị Trấn Vĩnh Tuy,Vinh Tuy,Vĩnh Tuy', 22.2744100, 104.8909100, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148050, 'Vĩnh Thuận', 'Vinh Thuan', 'Vinh Thuan,Vĩnh Thuận', 9.5080200, 105.2574700, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148051, 'Vĩnh Thạnh', 'Vinh Thanh', 'Vinh Thanh,Vinh Thinh,Vĩnh Thạnh', 14.1088400, 108.7838100, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148052, 'Vĩnh Long', 'Vinh Long', 'Vinh Long,Vĩnh Long,XVL', 10.2536900, 105.9722000, 'VN', '2017-04-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148053, 'Vĩnh Lộc', 'Vinh Loc', 'Nhan Lo,Vinh Loc,Vĩnh Lộc', 20.0543800, 105.6156700, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148054, 'Vĩnh Châu', 'Vinh Chau', 'Vinh Chau,Vĩnh Châu', 9.3243900, 105.9800600, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148055, 'Vĩnh Bình', 'Vinh Binh', 'Hoa Dong,Vinh Binh,Vinh Loi,Vĩnh Bình', 10.3449800, 106.5805600, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148056, 'Vinh', 'Vinh', 'VII,Vin,Vin'',Vinh,Vinis,bin,fynh,rong shi,vu~in,wiy,wyn,wyn  wytnam,Вин,Винь,Вінь,וין,فينه,وین، ویتنام,وینہ,วิญ,ヴィン,荣市,빈', 18.6733700, 105.6923200, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148057, 'Việt Trì', 'Viet Tri', 'Viet Tri,Vietri,Việt Trì', 21.3227400, 105.4019800, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148058, 'Văn Quan', 'Van Quan', 'Van Quan,Văn Quan', 21.8651600, 106.5392500, 'VN', '2015-01-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148059, 'Vạn Giã', 'Van Gia', 'Van Gia,Van Ninh,Vạn Giã,Vạn Ninh', 12.6920300, 109.2206900, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148060, 'Vân Đình', 'Van Dinh', 'Van Dinh,Vân Đình', 20.7351400, 105.7723600, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148061, 'Văn Điển', 'Van Dien', 'Van Dien,Văn Điển', 20.9463000, 105.8450000, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148062, 'Vân Canh', 'Van Canh', 'Van Canh,Vân Canh', 13.6194500, 108.9980500, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148063, 'Thành Phố Uông Bí', 'Thanh Pho Uong Bi', 'Thanh Pho Uong Bi,Thành Phố Uông Bí,Uong Bi,Uông Bí', 21.0343300, 106.7704900, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148064, 'Tuy Phước', 'Tuy Phuoc', 'Trung Tin,Trung Tín,Tuy Phuoc,Tuy Phươc,Tuy Phước', 13.8273800, 109.1665100, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148065, 'Tuy Hòa', 'Tuy Hoa', 'Chau Thanh,TBB,Thanh pho Tuy Hoa,Thuy Hoa,Thành phố Tuy Hòa,Toy Hoa,Tuikhoa,Tuy Hoa,Tuy Hòa,sui he shi,to~uihoa,Туихоа,トゥイホア,綏和市', 13.0954600, 109.3209400, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148066, 'Thành Phố Tuyên Quang', 'Thanh Pho Tuyen Quang', 'Thanh Pho Tuyen Quang,Thành Phố Tuyên Quang,Tuyen Kang,Tuyen Kwang,Tuyen Quang,Tuyên Quang', 21.8235600, 105.2142400, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148067, 'Hòa Bình', 'Hoa Binh', 'Cua Rao,Cus Rao,Hoa Binh,Hòa Bình,Kua Rao,Tuong Duong,Tương Dương', 19.2639300, 104.4723200, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148068, 'Tư Nghĩa', 'Tu Nghia', 'La Ha,La Hà,Tu Nghia,Tư Nghĩa', 15.0845100, 108.8260000, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148069, 'Thị Trấn Trùng Khánh', 'Thi Tran Trung Khanh', 'Thi Tran Trung Khanh,Thị Trấn Trùng Khánh,Trung Khanh,Trung Khanh Phu,Trùng Khánh,Trùng Khánh Phủ', 22.8351400, 106.5249600, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148070, 'Tri Tôn', 'Tri Ton', 'Tri Ton,Tri Tôn', 10.4202000, 105.0007300, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148071, 'Trà Vinh', 'Tra Vinh', 'Phu Vinh,Phú Vinh,Tra Vin,Tra Vinh,Trà Vinh', 9.9471900, 106.3422500, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148072, 'Trà Ôn', 'Tra On', 'Tra On,Trà Ôn', 9.9626100, 105.9216800, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148073, 'Trảng Bàng', 'Trang Bang', 'Trang Bang,Trảng Bàng', 11.0298700, 106.3575100, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148074, 'Thị Trấn Trạm Tấu', 'Thi Tran Tram Tau', 'Tham Tau,Thi Tran Tram Tau,Thị Trấn Trạm Tấu,Tram Tau,Trạm Tấu', 21.4665900, 104.3796600, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148075, 'Trà My', 'Tra My', 'Hau Duc,Hậu Đúc,Tien Tra,Tiên Trà,Tra Mi,Tra My,Trà Mi,Trà My', 15.3396500, 108.2206500, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148076, 'Tràm Chim', 'Tram Chim', 'Tram Chim,Tràm Chim', 10.6700100, 105.5646900, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148077, 'Trà Cú', 'Tra Cu', 'Huong Tra Cu,Hương Trà Cú,Tra Cu,Trà Cú', 9.6977400, 106.2583400, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148078, 'Trà Bồng', 'Tra Bong', 'Tra Bong,Tra Xuan,Trà Bồng,Trà Xuân', 15.2556900, 108.5172200, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148079, 'Tĩnh Gia', 'Tinh Gia', 'Tinh Gia,Tĩnh Gia', 19.4464500, 105.7786100, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148080, 'Tiểu Cần', 'Tieu Can', 'Tieu Can,Tiểu Cần', 9.8116600, 106.1906700, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148081, 'Tiên Phước', 'Tien Phuoc', 'Phuoc An,Phước An,Tien Ky,Tien Phuoc,Tiên Kỳ,Tiên Phước', 15.4881900, 108.3073600, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148082, 'Thủ Thừa', 'Thu Thua', 'Cho Thu Thua,Thu Thua,Thủ Thừa', 10.6023200, 106.4020700, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148083, 'Thường Xuân', 'Thuong Xuan', 'Thuong Xuan,Thường Xuân', 19.9029400, 105.3472300, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148084, 'Thủ Đức', 'Thu Duc', 'Thu Duc,Thủ Đức', 10.8486300, 106.7720900, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148085, 'Thủ Dầu Một', 'Thu Dau Mot', 'Phu Cuong,Phú Cường,Thu Dau Mot,Thủ Dầu Một,Tkhuzaumot,thu seiwhmt,to~uzaumotto,tu long mu shi she,tujeoumos,tw dayw mwt,Тхузаумот,تو دائو موت,تھو داو مؤت,ถูเสิ่วหมต,トゥーザウモット,土龍木市社,투저우못', 10.9804000, 106.6519000, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148086, 'Thọ Xuân', 'Tho Xuan', 'Quan Phu,Tho Xuan,Thọ Xuân', 19.9313300, 105.5217900, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148087, 'Thốt Nốt', 'Thot Not', 'Tho Not,Thot Not,Thốt Nốt', 10.2721300, 105.5338000, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148088, 'Thới Lai', 'Thoi Lai', 'Thoi Lai,Thới Lai', 10.0652200, 105.5586300, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148089, 'Thới Bình', 'Thoi Binh', 'Thoi Binh,Thot Binh,Thới Bình', 9.3558400, 105.0992900, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148090, 'Ái Tử', 'Ai Tu', 'Ai Tu,Thon Ai Tu,Thôn Ái Tử,Ái Tử', 16.7688600, 107.1650400, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148091, 'Thị Trấn Thất Khê', 'Thi Tran That Khe', 'That Ke,That Khe,Thi Tran That Khe,Thất Khê,Thị Trấn Thất Khê', 22.2552500, 106.4735900, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148092, 'Than Uyên', 'Than Uyen', 'Muong Than,Than Huyen,Than Uven,Than Uvên,Than Uyen,Than Uyên', 21.9590700, 103.8800100, 'VN', '2015-02-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148093, 'Phú Lộc', 'Phu Loc', 'Huyen Thanh Tri,Huyện Thạnh Trị,Phu Loc,Phú Lộc,Thanh Tr,Thạnh Tr', 9.4283800, 105.7411100, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148094, 'Thanh Sơn', 'Thanh Son', 'Huyen Thanh Son,Huyện Thanh Sơn,Thanh Son,Thanh Sơn', 21.1986700, 105.1789200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148095, 'Thạnh Phú', 'Thanh Phu', 'Huong Thanh Phu,Hương Thạnh Phú,Phu,Phú,Thanh Phu,Thạnh Phú', 9.9482700, 106.5162900, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148096, 'Ho Chi Minh City', 'Ho Chi Minh City', 'Cathair Ho Chi Minh,Cidade de Ho Chi Minh,Ciudad Ho Chi Minh,HCMC,HCMV,Ho Chi Minh,Ho Chi Minh City,Ho Chi Minh Ville,Ho Chi Minh-borg,Ho Chi Minh-byen,Ho Chi Minhin kaupunki,Ho Chi Minhstad,Ho Ci Minovo Mesto,Ho Si Minh-varos,Ho Si Minh-város,Ho Či Minovo Město,Ho-Chi-Minh-Stadt,Ho-Chi-Minh-Ville,Ho-Ci-Min-urbo,Ho-Ĉi-Min-urbo,HoChiMinh City,Hociminovo Mesto,Hosimina,Hosiminh,Hočiminovo Mesto,Hošimina,Hošiminh,Hô Chi Minh Ville,Hô-Chi-Minh-Ville,Hồ Chí Minhin kaupunki,Khoshimin,Kota Ho Chi Minh,Kota Hồ Chí Minh,SGN,Sai Gon,Saigon,Saïgon,Sài Gòn,TPHCM,Thanh pho Ho Chi Minh,Thành phố Hồ Chí Minh,hochimin,hochimin shi,hojjimin si,hu zhi ming shi,hw z''y myn syty,mdynt hw tshy mynh,saigon,saygwn,Хошимин,הו צ''י מין סיטי,سايگون,مدينة هو تشي مينه,サイゴン,ホーチミン,ホーチミン市,胡志明市,호찌민 시,호치민', 10.8230200, 106.6296500, 'VN', '2017-06-15', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148097, 'Thanh Nê', 'Thanh Ne', 'Thanh Ne,Thanh Nê', 20.3881000, 106.4383400, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148098, 'Thanh Hóa', 'Thanh Hoa', 'THD,Than" Hoa,Thanh Hoa,Thanh Hóa,Than” Hoa', 19.8000000, 105.7666700, 'VN', '2012-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148099, 'Thanh Chương', 'Thanh Chuong', 'Thanh Chuong,Thanh Chương', 18.7787700, 105.3335600, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148100, 'Thanh Bình', 'Thanh Binh', 'Thanh Binh,Thanh Bình', 10.5619000, 105.4841100, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148101, 'Thành Phố Thái Nguyên', 'Thanh Pho Thai Nguyen', 'Taj-Nguen,Thai Nguyen,Thanh Pho Thai Nguyen,Thành Phố Thái Nguyên,Thái Nguyên,Тай-Нгуен', 21.5942200, 105.8481700, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148102, 'Thành Phố Thái Bình', 'Thanh Pho Thai Binh', 'Kua Loc,Taibinh,Thai Bin,Thai Binh,Thanh Pho Thai Binh,Thành Phố Thái Bình,Thái Bình', 20.4500000, 106.3400200, 'VN', '2013-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148103, 'Kim Tân', 'Kim Tan', 'Kim Tan,Kim Tân,Thach Thanh,Thạch Thành', 20.1305300, 105.6745400, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148104, 'Thạch Hà', 'Thach Ha', 'Thach Ha,Thạch Hà', 18.3678800, 105.8612200, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148105, 'Tây Ninh', 'Tay Ninh', 'Gorad Tehjnin'',Tai nin,Tay Ninh,Tehjnin'',Tei Nin,Tây Ninh,Vilojati Tej Nin,tainin,tay nynha,tteoinin,xi ning shi,Вилояти Тей Нин,Горад Тэйнінь,Тэйнинь,تای نینها,تاے ننہ,タイニン,西寧市,떠이닌', 11.3100400, 106.0982800, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148106, 'Tây Hồ', 'Tay Ho', 'Tay Ho,Tây Hồ', 21.0689500, 105.8105300, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148107, 'Tây Đằng', 'Tay Dang', 'Huyen Ba Vi,Huyện Ba Vì,Tay Dang,Tây Dắng,Tây Dằng,Tây Đằng', 21.1980900, 105.4221700, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148108, 'Đầm Dơi', 'GJam Doi', 'Dam Doi,Tan Long,Tân Long,Xom Tan Long,Đầm Dơi', 8.9921400, 105.1960200, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148109, 'Tân Kỳ', 'Tan Ky', 'Tan Ky,Tân Kỳ', 19.0475600, 105.2680700, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148110, 'Tánh Linh', 'Tanh Linh', 'Lac Tanh,Lạc Tánh,Tanh Linh,Thanh Linh,Tánh Linh,Xa Lac Tanh,Xã Lạc Tánh', 11.0842100, 107.6809500, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148111, 'Tân Hiệp', 'Tan Hiep', 'Ben Tranh,Tan Hiep,Tân Hiệp', 10.4490500, 106.3438600, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148112, 'Tân Hiệp', 'Tan Hiep', 'Tan Hiep,Tân Hiệp', 10.1170900, 105.2857800, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148113, 'Tân Châu', 'Tan Chau', 'Tan Chau,Tân Châu', 10.7983200, 105.2388700, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148114, 'Tân An', 'Tan An', 'Tan,Tan Am,Tan An,Tân An,Тан', 10.5358900, 106.4136600, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148115, 'Tam Kỳ', 'Tam Ky', 'Tam Ky,Tam Kỳ,Tanky', 15.5736400, 108.4740300, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148116, 'Trai Ngau', 'Trai Ngau', 'Tam Dao,Tam Đảo,Trai Ngau', 21.3932400, 105.6144100, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148117, 'Tam Bình', 'Tam Binh', 'Tam Binh,Tam Bình', 10.0481100, 106.0001700, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148118, 'Thị Trấn Tà Lùng', 'Thi Tran Ta Lung', 'Ta Lung,Thi Tran Ta Lung,Thị Trấn Tà Lùng,Tà Lùng', 22.4979000, 106.5669000, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148119, 'Sơn Tịnh', 'Son Tinh', 'Son Tinh,Sơn Tịnh', 15.1585600, 108.7958200, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148120, 'Sơn Tây', 'Son Tay', 'Son Tay,Son-Taj,Sontai,Sơn Tây,Сон-Тай', 21.1405300, 105.5068600, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148121, 'Sơn Hà', 'Son Ha', 'La Lang,Le Lang,Son Ha,Sơn Hà', 15.0419300, 108.4697300, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148122, 'Sơn Dương', 'Son Duong', 'Dong Chau,Huyen Son Duong,Huyên Sơn Dương,Son Duong,Sơn Dương,Thuong Chau,Thượng Châu', 21.6967600, 105.3990100, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148123, 'Sơn La', 'Son La', 'SQH,Son La,Son La Chau,Son Lu,Son-La,Sơn La,Thanh Pho Son La,Thành Phố Sơn La,shan luo shi,Сон-Ла,山羅市', 21.3256000, 103.9188200, 'VN', '2013-06-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148124, 'Sông Mã', 'Song Ma', 'Ban Na Nhiu,Bản Na Nhiu,Song Ma,Sông Mã', 21.0509100, 103.7498700, 'VN', '2015-01-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148125, 'Sông Cầu', 'Song Cau', 'Bong Cau,Bông Cầu,Song Cau,Song Ka,Song Ko,Songkau,Sông Cầu', 13.4556000, 109.2234800, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148126, 'Sóc Trăng', 'Soc Trang', 'Khanh Hong,Khanh Hung,Khánh Hưng,SOA,Shokchang,Soc Trang,Sok Trang,Sóc Trăng,Шокчанг', 9.5999500, 105.9719300, 'VN', '2017-04-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148127, 'Thị Trấn Sìn Hồ', 'Thi Tran Sin Ho', 'Sin Ho,Sinh Ho,Sinh Hồ,Thi Tran Sin Ho,Thị Trấn Sìn Hồ,Tsin Ho,Tsin Hô,Tsinh Ho,Tsinh Hô', 22.3664700, 103.2343800, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148128, 'Si Ma Cai', 'Si Ma Cai', 'Ngam Pang,Si Ma Cai,Si Ma Kai,Sin Ma Kai,Sin Ma Kay', 22.6951000, 104.2785700, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148129, 'Sa Pá', 'Sa Pa', 'Chapa,Shapa,Шапа', 22.3402300, 103.8441500, 'VN', '2011-11-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148130, 'Sa Dec', 'Sa Dec', 'Sa Dec,Sa Đéc,Sadek', 10.2908500, 105.7563500, 'VN', '2017-03-12', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148131, 'Rạch Giá', 'Rach Gia', 'Gorad Rac''zja,Lit-ka-su,Li̍t-ka-sṳ,Rach Gia,Rach Zhia,Racza,Racža,Rat''zja,Rạch Giá,VKG,Zhac Zhja,di shi shi,lagja,racha gya,rakkuza,rch gya,sak sa,Горад Рацьзя,Жаћ Жја,Ратьзя,راچا گیا,رچ گیآ,สักซ้า,ラックザー,迪石市,락자', 10.0124500, 105.0809100, 'VN', '2017-02-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148132, 'Mường Chiên', 'Muong Chien', 'Muong Chien,Mường Chiên,Quinh Nhai,Quynh Nhai,Quỳnh Nhai', 21.8424000, 103.5660800, 'VN', '2013-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148133, 'Quỳnh Côi', 'Quynh Coi', 'Quynh Coi,Quỳnh Côi', 20.6619200, 106.3274400, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148134, 'Qui Nhon', 'Qui Nhon', 'Ki N''on,Ki N’on,Kin-hon,Kuinjon,Kwinhon,Qui Nhan,Qui Nhon,Qui Nhơn,Quinn Yan,Quinton,Quy Nhon,Quy Nhơn,UIH,gui ren shi,kku-inyeon,kuinyon,Куинён,クイニョン,歸仁市,꾸이년', 13.7764800, 109.2236700, 'VN', '2013-06-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148135, 'Quỳ Hợp', 'Quy Hop', 'Qui Hop,Quy Hop,Quì Hợp,Quỳ Hợp', 19.3254600, 105.1825100, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148136, 'Oui Dat', 'Oui Dat', 'Oui Dat,Qui Dat,Qui Đạt,Quy Dat,Quy Đạt', 17.8045900, 105.9704400, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148137, 'Quỳ Châu', 'Quy Chau', 'Ke Bon,Phu Qui Chau,Qui Chau,Quy Chau,Quí Châu,Quỳ Châu,Qùy Chau', 19.5520600, 105.0938700, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148138, 'Quế Sơn', 'Que Son', 'Dong Phu,Que Son,Quế Sơn,Đông Phú', 15.6735600, 108.2201000, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148139, 'Kim Sơn', 'Kim Son', 'Kim Son,Kim Sơn,Que Phong,Quế Phong', 19.6040900, 104.9190300, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148140, 'Quan Hóa', 'Quan Hoa', 'Quan Hoa,Quan Hóa', 20.3848100, 105.1002400, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148141, 'Quảng Yên', 'Quang Yen', 'Kang Yen,Kwang Yen,Quang Yen,Quảng Yên', 20.9421000, 106.8027000, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148142, 'Thị Trấn Quảng Uyên', 'Thi Tran Quang Uyen', 'Quang Uyen,Quảng Uyên,Thi Tran Quang Uyen,Thị Trấn Quảng Uyên', 22.6949900, 106.4423500, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148143, 'Ba Đồn', 'Ba Don', 'Ba Don,Ba Đồn,Quang Trach,Quảng Trach', 17.7535300, 106.4235500, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148144, 'Quán Hàu', 'Quan Hau', 'Quan Hau,Quang Ninh,Quán Hàu,Quảng Ninh', 17.4043800, 106.6407200, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148145, 'Quảng Ngãi', 'Quang Ngai', 'Kang Ngei,Kong-ngi-su,Kuangngaj,Kvang Ngaj,Kwang Ngai,Kóng-ngi-sṳ,Quang Ngai,Quảng Ngãi,Thanh pho Quang Ngai,Thành phố Quảng Ngãi,Vilojati Kuang Ngaj,guang yi shi,kkwang-eung-ai,kuangai,kwang ngay,Вилояти Куанг Нгай,Кванг Нгај,Куангнгай,کوانگ نگای,クアンガイ,廣義市,꽝응아이', 15.1204700, 108.7923200, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148146, 'Plei Kần', 'Plei Kan', 'Plei Can,Plei Cần,Plei Kan,Plei Kần,Polei Kan,Pơlei Kan', 14.7049500, 107.6862000, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148147, 'Pleiku', 'Pleiku', 'Gia Lai,PXU,Play Cu,Play Ku,Plei Cu,Pleiku,Plejku,Plây Cu,Plây Ku,Po-loi-ku,Pô-lòi-kú,Tinh Pleiku,Tỉnh Pleiku,bo lai gu shi,pel yku,plykw,ppeullaeikku,pureiku,Плеику,Плейку,پلیکو,เปล็ยกู,プレイク,波來古市,쁠래이꾸', 13.9833300, 108.0000000, 'VN', '2012-01-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148148, 'Phù Yên', 'Phu Yen', 'Phu Yen,Phù Yên', 21.2633100, 104.6443900, 'VN', '2015-02-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148149, 'Phú Vang', 'Phu Vang', 'Phu Vang,Phú Vang', 16.4391100, 107.7143800, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148150, 'Phú Túc', 'Phu Tuc', 'Ban Ba M''La,Ban Ba M’La,Phu Tuc,Phú Túc', 13.1968200, 108.6904300, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148151, 'Phủ Thông', 'Phu Thong', 'Phu Thong,Phủ Thông', 22.2731400, 105.8794300, 'VN', '2012-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148152, 'Phú Thọ', 'Phu Tho', 'Pho Tho,Phu Tho,Phu To,Phú Thọ,Thi Xa Phu Tho,Thị Xã Phú Thọ', 21.3996300, 105.2222100, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148153, 'Dương Đông', 'Duong GJong', 'Duong Dong,Duong-Dong,Dương Dông,Xom Duong Dong,Дуонг-Донг', 10.2171600, 103.9592900, 'VN', '2013-05-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148154, 'Phú Phong', 'Phu Phong', 'Phu Phong,Phú Phong', 13.9096400, 108.9190300, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148155, 'Phước An', 'Phuoc An', 'Phuoc An,Phước An', 12.7129800, 108.3014800, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148156, 'Phù Ninh', 'Phu Ninh', 'Ninh hiep,Phu Ninh,Phù Ninh', 21.0833300, 105.9500000, 'VN', '2016-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148157, 'Phụng Hiệp', 'Phung Hiep', 'Cay Duong,Cây Dương,Phung Hiep,Phung Niep,Phuong Heip,Phụng Hiệp', 9.7797200, 105.7338000, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148158, 'Phù Mỹ', 'Phu My', 'Phu My,Phù Mỹ', 14.1718200, 109.0488800, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148159, 'Thành Phố Phủ Lý', 'Thanh Pho Phu Ly', 'Fu Li,Ha-Nam,Phu Ly,Phu-li,Phủ Lý,Thanh Pho Phu Ly,Thành Phố Phủ Lý', 20.5453100, 105.9122100, 'VN', '2013-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148160, 'Phú Lộc', 'Phu Loc', 'Cao Doi Xa,Cao Đôi Xa,Phu Loc,Phú Lộc,Quan Phu Loc,Quan Phú Lộc', 16.2803500, 107.8589800, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148161, 'Phú Khương', 'Phu Khuong', '', 11.2833300, 106.1333300, 'VN', '2006-01-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148162, 'Phúc Yên', 'Phuc Yen', 'Phuc Yen,Phúc Yên', 21.2369500, 105.7048300, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148163, 'Phù Cát', 'Phu Cat', 'Ngo May,Ngô Mây,Phu Cat,Phù Cát', 14.0031600, 109.0580400, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148164, 'Phong Thổ', 'Phong Tho', 'Muong So,Phong Tho,Phong Thổ', 22.5443300, 103.2977600, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148165, 'Phong Điền', 'Phong Dien', 'Phong Dien,Phong Điền', 16.5832100, 107.3643800, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148166, 'Phong Điền', 'Phong Dien', 'Phong Dien,Phong Điền', 9.9975300, 105.6673000, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148167, 'Thị Trấn Phố Lu', 'Thi Tran Pho Lu', 'Pho Lu,Phu-Lu,Phố Lu,Thi Tran Pho Lu,Thị Trấn Phố Lu', 22.3191800, 104.1871900, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148168, 'Phố Châu', 'Pho Chau', 'Cho Pho,Pho Chau,Phố Châu', 18.5133500, 105.4241100, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148169, 'Bến Sung', 'Ben Sung', 'Ben Sung,Bến Sung,Pho Ben Sung,Pho Beu Sung,Phố Bến Sung', 19.6314100, 105.5781500, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148170, 'Phát Diệm', 'Phat Diem', 'Fak Diem,Phat Diem,Phát Diệm', 20.0905400, 106.0832300, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148171, 'Phan Thiết', 'Phan Thiet', 'Fan Thiet,Fant''et,Fanthit,Fantiet,Phan Thiet,Phan Thiết,Phan Tiet,Xa Phan Thiet,pan qie,Фантьет,潘切', 10.9288900, 108.1020800, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148172, 'Phan Rang-Tháp Chàm', 'Phan Rang-Thap Cham', 'PHA,Phan Rang,Phan Rang- Thap Cham,Phan Rang-Thap Cham,Phan Rang-Tháp Chàm,Phan Ranh', 11.5643200, 108.9885800, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148173, 'Ô Môn', 'O Mon', 'O Mon,Phong Phu,Phong Phú,Ô Môn', 10.1097400, 105.6231800, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148174, 'Thị Trấn Nước Hai', 'Thi Tran Nuoc Hai', 'Hoa An,Nouc Hai,Nuoc Hai,Nước Hai,Thi Tran Nuoc Hai,Thị Trấn Nước Hai', 22.7373800, 106.1521600, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148175, 'Núi Đèo', 'Nui Deo', 'Nui Deo,Núi Đèo', 20.9156900, 106.6744000, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148176, 'Ninh Hòa', 'Ninh Hoa', 'Ninh Hoa,Ninh Hòa', 12.4918700, 109.1249500, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148177, 'Ninh Giang', 'Ninh Giang', 'Ninh Giang,Vinh-Ninh', 20.7308300, 106.3978900, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148178, 'Thành Phố Ninh Bình', 'Thanh Pho Ninh Binh', 'Nin Bin,Nin'' Bin'',Ninbinh,Ninh Binh,Ninh Bình,Thanh Pho Ninh Binh,Thành Phố Ninh Bình,Нинь Бинь', 20.2580900, 105.9796500, 'VN', '2016-02-12', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148179, 'Như Quỳnh', 'Nhu Quynh', 'Nhu Quynh,Như Quỳnh,Phu Quynh', 20.9816700, 105.9848600, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148180, 'Nho Quan', 'Nho Quan', 'Nho Quan,Pho Nho Quan,Phu Nho Quan,Phủ Nho Quan', 20.3227900, 105.7518900, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148181, 'Nhơn Trạch', 'Nhon Trach', 'Nhon Trach,Nhơn Trạch,Phu Thanh', 10.7229400, 106.8834100, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148182, 'Nha Trang', 'Nha Trang', 'Gorad Njachang,INhatrang,Kanh-Hoa,NHA,Nacana,Nga-tsong-su,Ngà-tsông-sṳ,Nha Trang,Niacangas,Niačangas,Nja Chang,Njachang,nateulang,nha tranj,nha trng,nyachan,nyajjang,ya cang,ya zhuang,ya zhuang shi,Ņačana,Ња Чанг,Горад Нячанг,Ня Чанг,Нячанг,نها ترانج,نها ترنگ,ญาจาง,ニャチャン,芽庄市,芽莊,芽莊市,나트랑,냐짱', 12.2450700, 109.1943200, 'VN', '2017-07-31', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148183, 'Nhà Bè', 'Nha Be', 'Lazaret,Nha Be,Nha Bè,Nhà Bè', 10.6967200, 106.7403200, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148184, 'Nhà Bàng', 'Nha Bang', 'Nh Bang,Nh Bàng,Nha Ban,Nha Bang,Nhà Bàng', 10.6250200, 105.0085400, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148185, 'Thị Trấn Nguyên Bình', 'Thi Tran Nguyen Binh', 'Nguyen Binh,Nguyên Bình,Thi Tran Nguyen Binh,Thị Trấn Nguyên Bình', 22.6499500, 105.9598500, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148186, 'Ngô Đồng', 'Ngo Dong', 'Ngo Dong,Ngô Dong,Ngô Đồng', 20.2829600, 106.4434700, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148187, 'Ngọc Lặc', 'Ngoc Lac', 'Huong Ngoc Lac,Hương Ngọc Lac,Ngoc Lac,Ngọc Lac,Ngọc Lặc', 20.0918900, 105.3676100, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148188, 'Tiền Hải', 'Tien Hai', 'Ngoai De,Ngoại Đê,Tien Hai,Tiền Hải', 20.4055700, 106.5036500, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148189, 'Nghi Xuân', 'Nghi Xuan', 'Nghi Xuan,Nghi Xuân,Uy Vien', 18.6620600, 105.7557500, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148190, 'Quán Hành', 'Quan Hanh', 'Nghi Loc,Nghi Lộc,Quan Hanh,Quán Hành', 18.7792700, 105.6459700, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148191, 'Nghĩa Hành', 'Nghia Hanh', 'Cho Chua,Chợ Chùa,Nghia Hanh,Nghĩa Hành', 15.0456800, 108.7772400, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148192, 'Nga Sơn', 'Nga Son', 'Nga Son,Nga Sơn', 20.0072200, 105.9704400, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148193, 'Vân Tùng', 'Van Tung', 'Ngan Son,Ngân Sơn,Van Tung,Vân Tùng', 22.4308200, 105.9968700, 'VN', '2012-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148194, 'Thị Trấn Ngải Giao', 'Thi Tran Ngai Giao', 'Ngai Giao,Ngải Giao,Thi Tran Ngai Giao,Thị Trấn Ngải Giao', 10.6471000, 107.2457700, 'VN', '2012-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148195, 'Thị Trấn Na Sầm', 'Thi Tran Na Sam', 'Na Cha,Na Cham,Na Sam,Na Sầm,Thi Tran Na Sam,Thị Trấn Na Sầm', 22.0563900, 106.6151000, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148196, 'Thành Phố Nam Định', 'Thanh Pho Nam Dinh', 'Nam Din,Nam Dinh,Nam GJinh,Nam Định,Namdin'',Thanh Pho Nam Dinh,Thành Phố Nam Định,Намдинь', 20.4338900, 106.1772900, 'VN', '2014-05-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148197, 'Nam Đàn', 'Nam Dan', 'Nam Dan,Nam Đàn', 18.6979900, 105.4988100, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148198, 'Năm Căn', 'Nam Can', 'Nam Ca,Nam Can,Năm Că,Năm Căn', 8.7589900, 104.9928500, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148199, 'Mỹ Xuyên', 'My Xuyen', 'My Xuyen,Mỹ Xuyên', 9.5600600, 105.9898400, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148200, 'Mỹ Tho', 'My Tho', 'Mitho,My Tho,Mỹ Tho', 10.3600400, 106.3599600, 'VN', '2012-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148201, 'Mỹ Thọ', 'My Tho', 'My Tho,Mỹ Thọ', 10.4426700, 105.6950800, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148202, 'Mỹ Lộc', 'My Loc', 'My Loc,Mỹ Lộc', 20.4411100, 106.1023800, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148203, 'Thạnh Mỹ', 'Thanh My', 'My Hiep,Mỹ Hiệp,Thanh My,Thạnh Mỹ', 15.7488900, 107.8367800, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148204, 'Mường Nhé', 'Muong Nhe', 'Muong Nhe,Muong Nhie,Mường Nhié,Mường Nhé', 22.1923600, 102.4579000, 'VN', '2012-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148205, 'Thị Trấn Mường Khương', 'Thi Tran Muong Khuong', 'Muong Khuong,Mường Khương,Thi Tran Muong Khuong,Thị Trấn Mường Khương', 22.7614100, 104.1215600, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148206, 'Mường Lát', 'Muong Lat', 'Gian Canh,Muong Lat,Mường Lát', 20.5291500, 104.6013800, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148207, 'Mù Cang Chải', 'Mu Cang Chai', 'Mu Cang Chai,Mù Cang Chải', 21.8512500, 104.0895400, 'VN', '2015-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148208, 'Móng Cái', 'Mong Cai', 'Mon Cay,Mon Gay,Mong Cai,Monkai,Móng Cái,Wangchieh', 21.5247100, 107.9661900, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148209, 'Mộ Đức', 'Mo Duc', 'Mo Duc,Mộ Đức', 14.9551300, 108.8858600, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148210, 'Mộc Châu', 'Moc Chau', 'Moc Chau,Mộc Châu,Na Bo', 20.8519900, 104.6217700, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148211, 'Mỏ Cày', 'Mo Cay', 'Mo Cay,Mỏ Cày', 10.1331200, 106.3351900, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148212, 'Minh Lương', 'Minh Luong', 'Minh Hoa,Minh Hòa,Minh Luong,Minh Lương', 9.9024800, 105.1595000, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148213, 'Minh Long', 'Minh Long', 'Ming Long,Minh Long,Poste de Minh Long', 14.9321800, 108.7032800, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148214, 'Thị Trấn Mèo Vạc', 'Thi Tran Meo Vac', 'Meo Vac,Mieu Vac,Mieu Yac,Mèo Vạc,Thi Tran Meo Vac,Thị Trấn Mèo Vạc', 23.1641100, 105.4099300, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148215, 'Ma Đa Gui', 'Ma Da Gui', 'Ma Da Gui,Ma Đa Gui,Madagui', 11.3870200, 107.5350800, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148216, 'Long Xuyên', 'Long Xuyen', 'Cholong Xuyen,Chơlong Xuyen,Long Swiyen,Long Xuyen,Long Xuyên,Long-Shuyen', 10.3863900, 105.4351800, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148217, 'Long Thành', 'Long Thanh', 'Long Thanh,Long Thành', 10.7890900, 106.9502900, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148218, 'Long Phú', 'Long Phu', 'Bang Long,Bàng Long,Huong Long Phu,Hương Long Phú,Long Phu,Long Phú', 9.6102500, 106.1188100, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148219, 'Long Mỹ', 'Long My', 'Long My,Long Mỹ', 9.6814100, 105.5722600, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148220, 'Lộc Ninh', 'Loc Ninh', 'Loc Nin'',Loc Ninh,Loc Nin’,Lok Nin,Lộc Ninh', 11.8447600, 106.5907300, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148221, 'Lộc Bình', 'Loc Binh', 'Loc Binh,Loc Rinh,Lok-binh,Lộc Bình', 21.7587300, 106.9233500, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148222, 'Lien De', 'Lien De', 'Lien De,Lieu De,Lieu Đê,Liễu Đề', 20.2209500, 106.1874700, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148223, 'Liên Hương', 'Lien Huong', 'Lien Huong,Liên Hương,Long Huong', 11.2276100, 108.7236600, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148224, 'Kiến Giang', 'Kien Giang', 'Kien Giang,Kiến Giang,Le Thuy,Let Thuy,Lệ Thủy,Tan Hau,Tân Hậu', 17.2232800, 106.7901100, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148225, 'Lấp Vò', 'Lap Vo', 'Lap Vo,Lấp Vò', 10.3616100, 105.5192400, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148226, 'Lao Chải', 'Lao Chai', 'Lao Chai,Lao Chaj,Lao Chải,Lao Tchay,Лао Чай', 22.3137700, 103.8684400, 'VN', '2016-02-12', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148227, 'Lào Cai', 'Lao Cai', 'Lao Cai,Lao Cai Lalawigan,Lao Kaj,Lao Kay,Laokai,Laokaj,Laokajus,Lo-kie-su,Lào Cai,Ló-kiê-sṳ,Vilojati Lao Kai,hla wkay,lao jie shi,laokkai,law kayy,layw kay,raokai,Вилояти Лао Каи,Лао Кај,Лаокай,لائو کای,لاو کائی,หล่าวกาย,ラオカイ,老街市,라오까이', 22.4855600, 103.9706600, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148228, 'Thành Phố Lạng Sơn', 'Thanh Pho Lang Son', 'Lang Son,Lạng Sơn,Thanh Pho Lang Son,Thành Phố Lạng Sơn', 21.8526400, 106.7610100, 'VN', '2014-04-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148229, 'Thị Trấn Phước Bửu', 'Thi Tran Phuoc Buu', 'Ap Phuoc Buu,Lang Phuoc Buu,Làng Phước Bửu,Phuoc Buu,Thi Tran Phuoc Buu,Thị Trấn Phước Bửu', 10.5347200, 107.4020200, 'VN', '2012-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148230, 'Lũng Hồ', 'Lung Ho', 'Lang Ho,Lung Ho,Làng Ho,Lũng Hồ', 22.9847900, 105.2398300, 'VN', '2012-06-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148231, 'Lang Chánh', 'Lang Chanh', 'Huong Lang Chanh,Hương Lang Chánh,Lang Chanh,Lang Chieng Trai,Lang Chánh,Làng Chiêng Trai', 20.1561100, 105.2422300, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148232, 'Lai Vung', 'Lai Vung', 'Lai Vung', 10.2870100, 105.6617000, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148233, 'Lái Thiêu', 'Lai Thieu', 'Lai Thieu,Lái Thiêu', 10.9051200, 106.6994900, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148234, 'Lai Cách', 'Lai Cach', 'Lai Cach,Lai Cách', 20.9325200, 106.2475600, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148235, 'La Gi', 'La Gi', 'La Ghi,La Gi,Lag,Lagi', 10.6599300, 107.7720600, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148236, 'Lắk', 'Lak', 'Don Lac,Lac Thien,Lak,Lạc Thiện,Lắk,Poste du Lac,Toa Quan Truong Lac Thien,Toà Quận Trưởng Lạc Thiện', 12.4108600, 108.1768200, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148237, 'Lạc Dương', 'Lac Duong', 'Binh Ninh,Lac Duong,Lạc Dương', 12.0040500, 108.4190500, 'VN', '2015-04-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148238, 'Mường Xén', 'Muong Xen', 'Ky Son,Kỳ Sơn,Muong Sen,Muong Xen,Muong Xén,Mường Xén', 19.3979500, 104.1523900, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148239, 'Kỳ Anh', 'Ky Anh', 'Ky Anh,Kỳ Anh', 18.0624300, 106.2983200, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148240, 'Kon Tum', 'Kon Tum', 'Cong Tum,Công Tum,Kon Tum,Tinh Kontum,Tỉnh Kontum', 14.3545100, 108.0075900, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148241, 'Kinh Môn', 'Kinh Mon', 'Kinh Mon,Kinh Môn,Phu-Kinh-Mon', 20.9896200, 106.5551000, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148242, 'Kim Bài', 'Kim Bai', 'Kim Bai,Kim Bài', 20.8526500, 105.7696300, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148243, 'Kiên Lương', 'Kien Luong', 'Kien Luong,Kiên Lương', 10.2862400, 104.6461600, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148244, 'Khe Sanh', 'Khe Sanh', 'Huong Hoa,Khe Sanh', 16.6282500, 106.7388400, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148245, 'Thị Trấn Khánh Yên', 'Thi Tran Khanh Yen', 'Khanh Yen,Khanh Yen Thuong,Khánh Yên Thượng,Muong Xac,Mương Xác,Thi Tran Khanh Yen,Thị Trấn Khánh Yên', 22.0893500, 104.2514900, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148246, 'Kẻ Sặt', 'Ke Sat', 'Ke Sat,Kẻ Sặt', 20.9100700, 106.1477100, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148247, 'Kế Sách', 'Ke Sach', 'Ke Sach,Kế Sách', 9.7674300, 105.9857400, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148248, 'Hữu Lũng', 'Huu Lung', 'Huu Lung,Hữu Lũng,Lang Met', 21.5056000, 106.3445900, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148249, 'Hương Trà', 'Huong Tra', 'Huong Tra,Hương Trà', 16.5253900, 107.4755000, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148250, 'Hương Khê', 'Huong Khe', 'Huong Khe,Hương Khê,Thuong Thach', 18.1766900, 105.7001900, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148251, 'Hương Canh', 'Huong Canh', 'Huang Canh,Huong Canh,Hương Canh', 21.2788200, 105.6469700, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148252, 'Hưng Yên', 'Hung Yen', 'Hong-Yen,Hung Yen,Hưng Yên', 20.6463700, 106.0511200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148253, 'Huế', 'Hue', 'Choue,HUI,Hue,Huje,Hujė,Hué,Huế,Khjue,Khjueh,Khue,Sun-fa-su,Sun-fa-sṳ,Thanh pho Hue,Thành phố Huế,fue,hue,hwyh,shun hua,shun hua shi,we,Χουέ,Хуе,Хюе,Хюэ,הואה,هوئه,ہوائے,เว้,ჰუე,フエ,順化,順化市,顺化市,후에', 16.4619000, 107.5954600, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148254, 'Hồ Xá', 'Ho Xa', 'Ho Xa,Hồ Xá,Vinh Linh,Vĩnh Linh', 17.0683600, 107.0052000, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148255, 'Bình Long', 'Binh Long', 'An Loc,An Lôc,Binh Long,Bình Long,Hon Quan,Hớn Quản', 11.6471100, 106.6058600, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148256, 'Thành Phố Hạ Long', 'Thanh Pho Ha Long', 'Ha Long,Hon Cay,Hon Gai,Hon Gay,Hon Goi,Hong Gai,Honggay,Hạ Long,Hồng Gai,Khalong,Thanh Pho Ha Long,Thành Phố Hạ Long,xia long shi,Халонг,下龙市', 20.9504500, 107.0733600, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148257, 'Ngoc Hon Doc', 'Ngoc Hon Doc', 'Hon Dat,Hòn Đất,Ngoc Hon Doc,Xom Hon Dat,Xóm Hòn Đất', 10.1846200, 104.9295900, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148258, 'Hội An', 'Hoi An', 'Cidade Antiga de Hoi An,Faifo,Faifoh,Faifoo,Feifu,Hoi An,Hojanas,Hôi An,Hội An,Khoj An,Khoj An'',Khojan,ho''i ena pracina sahara,hoi-ani,hoian,hui an,hui an shi,hwy an,hx yxan,Хой Ань,Хойан,Хоян,Хој Ан,הוי אן,هوي أن,ہؤئی آن,होइ एन प्राचीन सहर,ฮอยอัน,ჰოი-ანი,ホイアン,會安,會安市,호이안', 15.8794400, 108.3350000, 'VN', '2015-03-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148259, 'Hóc Môn', 'Hoc Mon', 'Hoc Mon,Hóc Môn', 10.8891000, 106.5953300, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148260, 'Hòa Vang', 'Hoa Vang', 'Hoa Vang,Hòa Vang', 15.9876400, 108.1389300, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148261, 'Hòa Mạc', 'Hoa Mac', 'Hoa Mac,Hoa Mao,Hòa Mạc', 20.6417300, 105.9890000, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148262, 'Hoài Ân', 'Hoai An', 'Hoai An,Hoài Ân,Tang Bat Ho,Tăng Bạt Hổ', 14.3635200, 108.9647600, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148263, 'Thành Phố Hòa Bình', 'Thanh Pho Hoa Binh', 'Hao Binh,Hoa Bin,Hoa Binh,Hòa Bình,Thanh Pho Hoa Binh,Thành Phố Hòa Bình', 20.8171700, 105.3375900, 'VN', '2013-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148264, 'Doug An', 'Doug An', 'Dong An,Doug An,Hiep Duc,Hiệp Đức,Tan An,Tân An', 15.5822400, 108.1142200, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148265, 'Hà Tĩnh', 'Ha Tinh', 'Ha Thin,Ha Tin,Ha Tinh,Ho-tshin-su,Hà Tĩnh,Hò-tshin-sṳ,Kha Tin,Khatin'',Province de Ha Tinh,Province de Hà Tĩnh,ha tiy,ha tyn,hattin,he jing shi,Ха Тин,Хатинь,ها تین,ہا تنہ,ห่าติ๋ญ,河靜市,하띤', 18.3428200, 105.9056900, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148266, 'Hà Tiên', 'Ha Tien', 'Ha Tien,Hà Tiên,Khat''en,Хатьен', 10.3831000, 104.4875300, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148267, 'Hanoi', 'Hanoi', 'Anoi,Anoy,Anòy,Gorad Khanoj,HAN,Ha Noi,Ha Nui,Hanoi,Hanoj,Hanoja,Hanojo,Hanojus,Hanoy,Hanoí,Hanoï,Hanòi,Hanói,Ho-nui-su,Hà Nội,Hò-nui-sṳ,Keicho,Khanoj,hano''i,hanoi,hanoy,hanwy,hanxy,he nei,he nei shi,hyanaya,khanwy,Ανόι,Горад Ханой,Ханой,Ханој,Հանոյ,האנוי,خانوي,هانوى,هانوي,هانوی,ھانۆی,ہنوئی,हनोई,হ্যানয়,ਹਨੋਈ,ହାନୋଇ,ஹனோய்,ಹಾನೊಯ್,හැනෝයි,ฮานอย,ཧེ་ནོ།,ဟနွိုင်းမြို့,ჰანოი,ሀኖይ,ទីក្រុងហានូយ,Ḥanoi,ハノイ,河內,河內市,하노이', 21.0245000, 105.8411700, 'VN', '2013-12-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148268, 'Thị Trấn Thanh Nhật', 'Thi Tran Thanh Nhat', 'Ha Lang,Hạ Lang,Thi Tran Thanh Nhat,Thị Trấn Thanh Nhật', 22.6874900, 106.6700400, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148269, 'Hà Lam', 'Ha Lam', 'Ha Lam,Hà Lam', 15.7387100, 108.3506200, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148270, 'Haiphong', 'Haiphong', 'HPH,Hai Phong,Haiphong,Hajfong,Hải Phòng,Khajfon,hai fang shi,haifon,hayfwngh,hi fxng,Хайфон,هايفونغ,ไฮฟอง,ハイフォン,海防市', 20.8648100, 106.6834500, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148271, 'Hải Lăng', 'Hai Lang', 'Hai Lang,Hải Lăng,Thon Dien Sanh,Thôn Diên Sanh', 16.6934700, 107.2512400, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148272, 'Thành Phố Hải Dương', 'Thanh Pho Hai Duong', 'Hai Doong,Hai Duong,Hai dzung,Hai-Doung,Haidong,Haidöng,Hải Dương,Khajzyong,Thanh Pho Hai Duong,Thành Phố Hải Dương,Хайзыонг', 20.9409900, 106.3330200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148273, 'Hạ Hòa', 'Ha Hoa', 'Ha Hoa,Hạ Hoa,Hạ Hòa', 21.5630200, 105.0051200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148274, 'Thành Phố Hà Giang', 'Thanh Pho Ha Giang', 'Ha Giang,Hà Giang,Thanh Pho Ha Giang,Thành Phố Hà Giang', 22.8233300, 104.9835700, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148275, 'Hà Đông', 'Ha Dong', 'Ha Dong,Hà Đông', 20.9713600, 105.7787600, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148276, 'Gò Quao', 'Go Quao', 'Go Quao,Gò Quao,Kien Hung,Kiên Hưng', 9.7332000, 105.2739300, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148277, 'Giồng Riềng', 'Giong Rieng', 'Giong Rieng,Giồng Riềng,Kien Binh,Kiên Bình', 9.9097400, 105.3143300, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148278, 'Gio Linh', 'Gio Linh', 'Gio Lin,Gio Linh', 16.9248000, 107.0843800, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148279, 'Gia Nghĩa', 'Gia Nghia', 'Gia Nghia,Gia Nghĩa,Nghia Duc,Nghiã Đức,Quang Duc', 12.0042300, 107.6907400, 'VN', '2014-04-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148280, 'Duy Xuyên', 'Duy Xuyen', 'Duy Xuyen,Duy Xuyên,Nam Phuoc,Nam Phước', 15.8289800, 108.2595600, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148281, 'Đưc Trọng', 'GJuc Trong', 'Duc Trong,Dyk Trong,Lien Nghia,Liên Nghĩa,Đưc Trọng,Дык Тронг', 11.7355900, 108.3733000, 'VN', '2017-02-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148282, 'Đức Thọ', 'Duc Tho', 'Duc Tho,Đưc Thọ,Đức Thọ', 18.5395700, 105.5830200, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148283, 'Đức Phong', 'Duc Phong', 'Bu Dang,Bù Đăng,Duc Phong,Đức Phong', 11.8134600, 107.2443300, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148284, 'Pho Duc', 'Pho Duc', 'Duc Pho,Pho Duc,Đức Phổ', 14.8135500, 108.9593100, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148285, 'Tram de Dak Mil', 'Tram de Dak Mil', 'Dak Mil,Duc Lap,Duc Minh,Tram de Dak Mil,Đắk Mil,Đức Lập,Đức Minh', 12.4495700, 107.6223700, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148286, 'La Hai', 'La Hai', 'Dong Xuan,La Hai,Đồng Xuân', 13.3773200, 109.1080700, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148287, 'Don Luan', 'Don Luan', 'Ap Dong Xoai,Don Luan,Dong Xoa,Dong Xoai,Dong Xoi,Dồng Xoài,Đồng Xoài,Ấp Đồng Xoài', 11.5349500, 106.8832400, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148288, 'Thị Trấn Đồng Văn', 'Thi Tran GJong Van', 'Dong Van,Dong Vang,Dồng Văn,Thi Tran GJong Van,Thị Trấn Đồng Văn', 23.2784100, 105.3629100, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148289, 'Đồng Mỏ', 'Dong Mo', 'Dong Mo,Đồng Mỏ', 21.6570100, 106.5783200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148290, 'Thị Trấn Đông Khê', 'Thi Tran GJong Khe', 'Dong Khe,Thi Tran GJong Khe,Thị Trấn Đông Khê,Ðông Khê', 22.4293900, 106.4319400, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148291, 'Kwang Binh', 'Kwang Binh', 'Dong Hoi,Dongkhoj,GJong Hoi,Kwang Binh,tong hai shi,Đồng Hới,Донгхой,同 海 市', 17.4688500, 106.6222600, 'VN', '2014-05-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148292, 'Ðông Hà', 'Dong Ha', 'Dong Ha,Dong Na,GJong Ha,Thi Xa Dong Ha,Thi Xã Ðòng Hà,Ðông Hà,Đông Hà', 16.8162500, 107.1003100, 'VN', '2010-11-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148293, 'Anh Son', 'Anh Son', 'Anh Son,Cho Do Luong,Cho Dô Lương,Do Luong,Đô Lương', 18.9696100, 105.0550500, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148294, 'Đoan Hùng', 'Doan Hung', 'Doan Hung,Huyen Doan Hung,Huyện Đoan Hùng,Phu Doan,Đoan Hùng', 21.6225400, 105.1846200, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148295, 'Đình Lập', 'Dinh Lap', 'Dinh Lap,Đình Lập', 21.5463300, 107.0981200, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148296, 'Di Linh', 'Di Linh', 'Di Linh,Djiring,Djring,Jiring', 11.5815300, 108.0764100, 'VN', '2014-04-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148297, 'Diên Khánh', 'Dien Khanh', 'Dien Khanh,Diên Khánh,Kanh-Hoa,Kank Hoa,Khan'' Hoa,Khanh Hoa,Khan’ Hoa', 12.2549000, 109.0933200, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148298, 'Diễn Châu', 'Dien Chau', 'Dien Chau,Diễn Châu,Phu Dien,Phu Dien Chau', 18.9765200, 105.6003400, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148299, 'Dien Bien Phu', 'Dien Bien Phu', 'D''enb''enfu,D''enbenfu,DIN,Dien Bien Phu,Dienbienfu,Dienbjenfu,Dijen Bijen Fu,Diên Biên Phu,GJien Bien Phu,Thien-pien-fu,Thièn-piên-fú,deiy n beiyn fu,dian bian fu,dienbienfu,dienbienpu,dyn byn fw,dyyn byyn fw,Ðiện Biên Phủ,Điện Biên Phủ,Диенбиенфу,Дијен Бијен Фу,Дьенбьенфу,Дьєнбєнфу,دیئن بیئن فو,دیئن بیئن پھو,دین بین فو,เดียนเบียนฟู,ດຽນບຽນຟູ,ディエンビエンフー,奠邊府,디엔비엔푸', 21.3860200, 103.0230100, 'VN', '2013-06-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148300, 'Quang Nam', 'Quang Nam', 'Dien Ban,Kwang Nam,Quang Nam,Vinh Dien,Vĩnh Điện,Điện Bàn', 15.8885300, 108.2544700, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148301, 'Giemdiem', 'Giemdiem', 'Diem Dien,Diêm Điền,Diễm Điên,Giemdiem', 20.5583200, 106.5688200, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148302, 'Dĩ An', 'Di An', 'Di An,Dĩ An', 10.9068200, 106.7694000, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148303, 'Dầu Tiếng', 'Dau Tieng', 'Dau Tieng,Dầu Tiếng,Quan Dau Tieng,Tri Tam,Tri Tâm,Xom Dau Tieng', 11.2741000, 106.3587900, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148304, 'Phuoc Tho', 'Phuoc Tho', 'Phuoc Tho,Thi Tran Dat Do,Thị Trấn Đất Đỏ,Xa Phuoc Tho,Xã Phước Thọ', 10.4909300, 107.2701400, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148305, 'Da Nang', 'Da Nang', 'DAD,Da Nang,Danang,GJa Nang,Tourane,Turan,danan,danang,xian gang,Đà Nẵng,Да Нанг,ダナン,岘港,峴港,다낭', 16.0677800, 108.2208300, 'VN', '2017-06-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148306, 'Ðà Lạt', 'Da Lat', 'DLI,Da Lat,Da lat,Dalat,Ðà Lạt,Далат', 11.9464600, 108.4419300, 'VN', '2013-06-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148307, 'Đắk Song', 'Dak Song', 'Dak Song,Dao Thong,Xuong Cua May Dak Song,Xưởng Cưa Máy Dak Song,Đak Song,Đắk Song', 12.2551800, 107.6092400, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148308, 'Đại Lộc', 'Dai Loc', 'Ai Nghia,Dai Loc,Ái Nghĩa,Đại Lộc', 15.8821400, 108.1209200, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148309, 'Đắk Tô', 'Dak To', 'Dac To,Dak To,Dak Tô,Quan Dak To,Quận Dak To,Đắc Tô,Đắk Tô', 14.6609200, 107.8389000, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148310, 'Củng Sơn', 'Cung Son', 'Cung Son,Củng Sơn,Son Hoa,Sơn Hòa', 13.0499800, 108.9789500, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148311, 'Củ Chi', 'Cu Chi', 'Cu Chi,Củ Chi,Ku-Chi,Ку-Чи', 10.9733300, 106.4932500, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148312, 'Cờ Đỏ', 'Co Do', 'Co Do,Cờ Đỏ', 10.0937700, 105.4291600, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148313, 'Côn Sơn', 'Con Son', 'Con Son,Con Son City,Côn Sơn,Kon-Shon,Phu Hai City,Poulo Condore,Pulo Condore,Thi-xa Con-son,Thị-xã Côn-sơn,Кон-Шон', 8.6864100, 106.6082400, 'VN', '2016-03-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148314, 'Con Cuông', 'Con Cuong', 'Con Cuong,Con Cuông', 19.0499600, 104.8812400, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148315, 'Chúc Sơn', 'Chuc Son', 'Chuc Son,Chúc Sơn', 20.9237500, 105.7015500, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148316, 'Chũ', 'Chu', 'Chu,Chũ', 21.3737900, 106.5664900, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148317, 'Chơn Thành', 'Chon Thanh', 'Ap Chon Thanh,Chon Thanh,Chơn Thành,Thanh Ghon,Ấp Chơn Thành', 11.4282100, 106.6353600, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148318, 'Chợ Mới', 'Cho Moi', 'Cho Moi,Chợ Mới', 21.8837400, 105.7728100, 'VN', '2012-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148319, 'Chợ Mới', 'Cho Moi', 'Cho Moi,Chợ Mới', 10.5512300, 105.4044100, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148320, 'Chợ Lách', 'Cho Lach', 'Cho Lach,Cholac,Chơ Lách,Chợ Lách', 10.2603200, 106.1189200, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148321, 'Giồng Trôm', 'Giong Trom', 'Cho Giong Trom,Chợ Giồng Trôm,Giomtrom,Giong Trom,Giồng Trôm', 10.1502100, 106.5060600, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148322, 'Chợ Gạo', 'Cho Gao', 'Cho Gao,Chợ Gạo', 10.3498400, 106.4634000, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148323, 'Chợ Chu', 'Cho Chu', 'Cho Chu,Chợ Chu', 21.9072400, 105.6421900, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148324, 'Chí Thạnh', 'Chi Thanh', 'Chi Thanh,Chi Thank,Chí Thạnh,Chí Thậnk', 13.3084500, 109.2152200, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148325, 'Chi Nê', 'Chi Ne', 'Chi Ne,Chi Nê', 20.4905600, 105.7780000, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148326, 'Huyện Chiêm Hóa', 'Huyen Chiem Hoa', 'Chiem Hoa,Chiêm Hóa,Huyen Chiem Hoa,Huyện Chiêm Hóa', 22.1441300, 105.2727700, 'VN', '2012-06-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148327, 'Cho Dok', 'Cho Dok', 'Angiang,Chau Doc,Chau Phu,Chau Phú,Chaudok,Cho Dok,Châu Đốc', 10.7000000, 105.1166700, 'VN', '2013-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148328, 'Cầu Kè', 'Cau Ke', 'Cau Ke,Cầu Kè,Huong Cau Ke,Hương Cầu Kè,Tam Can', 9.8724000, 106.0549700, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148329, 'Cầu Giát', 'Cau Giat', 'Cau Giat,Cầu Giát,Quynh Luu', 19.1460000, 105.6308900, 'VN', '2013-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148330, 'Cát Bà', 'Cat Ba', 'Apowan,Cac Ba,Cat Ba,Cát Bà,Kat Ba,Pho Cac Ba,Pho Cat Ba,Кат Ба', 20.7277900, 107.0481900, 'VN', '2014-01-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148331, 'Cao Thượng', 'Cao Thuong', 'Cao Thuong,Cao Thượng', 21.3870700, 106.1293100, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148332, 'Cao Lãnh', 'Cao Lanh', 'Cao Lanh,Cao Lãnh,Phong Thanh', 10.4601700, 105.6329400, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148333, 'Thành Phố Cao Bằng', 'Thanh Pho Cao Bang', 'Cao Bang,Cao Bằng,Cao Pang,Kao Bang,Kao banh,Kaobang,Thanh Pho Cao Bang,Thành Phố Cao Bằng,Каобанг', 22.6656800, 106.2578600, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148334, 'Cần Thơ', 'Can Tho', 'Can Tho,Cần Thơ,Kan Tho,VCA,kanto,qin ju shi,カントー,芹苴市', 10.0371100, 105.7882500, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148335, 'Cần Giờ', 'Can Gio', 'Can Gio,Can Thanh,Cần Giờ,Cần Thạnh', 10.4111500, 106.9547400, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148336, 'Cần Đước', 'Can Duoc', 'Can Duoc,Cần Đước', 10.5096600, 106.6030800, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148337, 'Cần Giuộc', 'Can Giuoc', 'Can Duoc,Can Gioc,Can Giuoc,Cần Duộc,Cần Giuộc', 10.6085700, 106.6713500, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148338, 'Cẩm Xuyên', 'Cam Xuyen', 'Cam Xuyen,Cẩm Xuyên', 18.2502900, 106.0013200, 'VN', '2013-11-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148339, 'Cẩm Thủy', 'Cam Thuy', 'Cam Thuy,Cẩm Thủy,Huong Cam Thuy,Hương Cẩm Thủy', 20.2086600, 105.4695000, 'VN', '2015-07-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148340, 'Cam Ranh', 'Cam Ranh', 'Cam Linh,Cam Ranh Port,Kamran'',Thon Cam Ranh,Thôn Cam Ranh,Камрань', 11.9214400, 109.1591300, 'VN', '2010-01-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148341, 'Cẩm Phả Mines', 'Cam Pha Mines', '', 21.0166700, 107.3000000, 'VN', '2006-01-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148342, 'Cẩm Phả', 'Cam Pha', 'Cam Pha,Cẩm Phả', 21.0100400, 107.2734500, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148343, 'Cam Lộ', 'Cam Lo', 'Cam Lo,Cam Lộ,Thon Cam Lo,Thôn Cam Lộ', 16.8079700, 106.9940500, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148344, 'Cam Ranh', 'Cam Ranh', 'Ba Ngoi,Cam Lam,Cam Lâm,Cam Ranh,Can Lam', 11.9273200, 109.1608200, 'VN', '2014-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148345, 'Cà Mau', 'Ca Mau', 'CAH,Ca Mau,Camo,Cu Mau,Cà Mau,Kamao,Kamau,Quan Long,Quang Long,Song Kualon,Камау', 9.1768200, 105.1524200, 'VN', '2017-04-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148346, 'Cái Tàu Hạ', 'Cai Tau Ha', 'Ai Tau Ha,Cai Tau Ha,Cao Tao Ha,Cái Tàu Hạ', 10.2597300, 105.8704400, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148347, 'Cái Răng', 'Cai Rang', 'Cai Rang,Chau Thanh,Châu Thành,Cái Răng', 10.0009000, 105.7509500, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148348, 'Cái Nước', 'Cai Nuoc', 'Cai Nuoc,Cái Nước', 8.9423100, 105.0141100, 'VN', '2014-09-30', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148349, 'Cái Nhum', 'Cai Nhum', 'Cai Nhum,Cái Nhum,Minh Duc,Minh Đúc', 10.1741200, 106.1105100, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148350, 'Buôn Trấp', 'Buon Trap', 'Ban Trap,Buon Trap,Buôn Trăp,Buôn Trấp', 12.4847800, 108.0298200, 'VN', '2015-02-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148351, 'Buôn Ma Thuột', 'Buon Ma Thuot', 'BMV,Ban Me Thaut,Ban Me Thnot,Ban Me Thot,Ban Me Thout,Ban Me Thuot,Ban Mê Thuột,Ban-me-Thurt,Benmethout,Buon Ma Thuot,Buon Me Thuot,Buôn Ma Thuột,Buôn Mê Thuột,Lac Giao,Lạc Giao,Me Thuot,Metuotas', 12.6674700, 108.0377500, 'VN', '2013-06-29', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148352, 'Hoàn Lão', 'Hoan Lao', 'Bo Trach,Bố Trạch,Hoan Lao,Hoàn Lão', 17.5843600, 106.5342500, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148353, 'Bồng Sơn', 'Bong Son', 'Bong Son,Bồng Sơn,Hoai Nhon,Hoài Nhon', 14.4290700, 109.0156000, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148354, 'Bù Đốp', 'Bu Dop', 'Bo Duc,Bu Dop,Bô Dức,Bù Đốp,Quan Ba Duc,Quan Bo Duc,Quận Bá Đức,Quận Bố Đức,Xa Phuoc Loc,Xã Phươc Lộc', 11.9548600, 106.8001800, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148355, 'Bình Thủy', 'Binh Thuy', 'Binh Thuy,Bình Thủy', 10.0743100, 105.7397400, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148356, 'Bình Sơn', 'Binh Son', 'Binh Son,Bình Sơn,Chau O,Châu Ổ', 15.2977600, 108.7612400, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148357, 'Bình Gia', 'Binh Gia', 'Binh Gia,Bình Gia,Pho Binh Gia,Phố Bình Gia', 21.9609400, 106.3644800, 'VN', '2015-01-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148358, 'Bình Đại', 'Binh Dai', 'Binh Dai,Bình Đại', 10.1896400, 106.6914900, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148359, 'Tân Túc', 'Tan Tuc', 'Binh Chanh,Bình Chánh,Tan Tuc,Tân Túc', 10.6954100, 106.5912800, 'VN', '2014-12-02', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148360, 'Bỉm Sơn', 'Bim Son', 'Bien Son,Bim Son,Biên Sơn,Bỉm Sơn', 20.0780600, 105.8602800, 'VN', '2012-01-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148361, 'Biên Hòa', 'Bien Hoa', 'Bia Hoa,Bien Hoa,Biên Hòa', 10.9446900, 106.8243200, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148362, 'Bến Tre', 'Ben Tre', 'Ben Tre,Bến Tre,Truc Giang,Trúc Giang', 10.2414700, 106.3758500, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148363, 'Bến Cầu', 'Ben Cau', 'Ap Ben Cau,Ben Cau,Bến Cầu,Hieu Thien', 11.1105100, 106.1792400, 'VN', '2014-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148364, 'Ba Tri', 'Ba Tri', 'Ba Tri', 10.0442700, 106.5902000, 'VN', '2014-09-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148365, 'Ba Tơ', 'Ba To', 'Ba To,Ba Tơ', 14.7636000, 108.7322300, 'VN', '2014-01-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148366, 'Thị Trấn Phố Ràng', 'Thi Tran Pho Rang', 'Bao Yen,Bảo Yên,Lang Pho Rang,Làng Pho Rang,Thi Tran Pho Rang,Thị Trấn Phố Ràng', 22.2342900, 104.4764300, 'VN', '2013-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148367, 'Bảo Lộc', 'Bao Loc', 'Ap Thanh Tam,Ban Lao,Bao Loc,Baolok,Blao,Bảo Lộc,Cong Hinh,Баолок,Ấp Thánh Tâm', 11.5479800, 107.8077200, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148368, 'Thị Trấn Bảo Lạc', 'Thi Tran Bao Lac', 'Bao Lac,Bảo Lạc,Thi Tran Bao Lac,Thị Trấn Bảo Lạc', 22.9492400, 105.6804600, 'VN', '2013-03-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148369, 'Bẩn Yên Nhân', 'Ban Yen Nhan', 'Ban Yen Nhan,Bẩn Yên Nhân,My Hao,Mỹ Hào', 20.9365300, 106.0571100, 'VN', '2013-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148370, 'Ít Ong', 'It Ong', 'Ban Hit Ong,Ban It Ong,Bản It Ong,It Ong,Ít Ong', 21.5175000, 104.0270100, 'VN', '2013-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148371, 'Thị Trấn Thuận Châu', 'Thi Tran Thuan Chau', 'Ban Chieng Ly,Ban Dhieng Ly,Bản Chiêng Lý,Thi Tran Thuan Chau,Thuan Chau,Thị Trấn Thuận Châu', 21.4384900, 103.6900000, 'VN', '2013-06-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148372, 'Bắc Yên', 'Bac Yen', 'Bac Yen,Bắc Yên', 21.2462600, 104.4328100, 'VN', '2015-02-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148373, 'Bắc Sơn', 'Bac Son', 'Bac Son,Bắc Sơn', 21.8999900, 106.3207700, 'VN', '2015-01-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148374, 'Bắc Ninh', 'Bac Ninh', 'Bac Ninh,Bacht Ninh,Bak Nin,Bak Ninh,Bắc Ninh', 21.1860800, 106.0763100, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148375, 'Thành phố Bạc Liêu', 'Thanh pho Bac Lieu', 'Bac Lieu,Bac-Lien,Bach Lieu,Bak Lieu,Bạc Liêu,Thanh pho Bac Lieu,Thành phố Bạc Liêu,Vinh Loi,Vĩnh Lợi', 9.2941400, 105.7277600, 'VN', '2012-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148376, 'Bắc Hà', 'Bac Ha', 'Bac Ha,Bắc Hà,Pa Kha', 22.5391100, 104.2930500, 'VN', '2014-12-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148377, 'Bắc Giang', 'Bac Giang', 'Bac Giang,Bakziangas,Bakzjang,Bắc Giang,Pet-kong,Pet-kông,Phu Lang Thong,Phu Lang Thuong,Phu Long Thuong,Thuong,Vilojati Bak Giang,bagjang,bak gyang,bak zyang,bakuzan,bei jiang shi,Бакзянг,Вилояти Бак Гианг,باک زیانگ,باک گیانگ,バクザン,北江市,박장', 21.2730700, 106.1946000, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148378, 'Bắc Kạn', 'Bac Kan', 'Bac Can,Bac Kan,Bak Kan,Bắc Cạn,Bắc Kạn', 22.1470100, 105.8348100, 'VN', '2012-09-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148379, 'Tân Trụ', 'Tan Tru', 'Ap Tan Thuan,Tan Tru,Tân Trụ,Ấp Tân Thuận', 10.5127100, 106.5076200, 'VN', '2014-12-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148380, 'Ấp Tân Ngãi', 'Ap Tan Ngai', 'Ap Tan Ngai,Thanh Ngai,Thanh Ngãi,Ấp Tân Ngãi', 10.2333300, 106.2833300, 'VN', '2013-05-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148381, 'An Hòa', 'An Hoa', '', 10.2969300, 105.7443500, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148382, 'An Nhơn', 'An Nhon', 'An Nhon,An Nhơn,Bhin-Dinh,Bin Din,Binh Dinh', 13.8857900, 109.1082300, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148383, 'An Lão', 'An Lao', 'An Lao,An Lão', 14.6124100, 108.8899000, 'VN', '2014-02-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148384, 'An Dương', 'An Duong', 'An Duong,An Dương', 20.8638200, 106.6133000, 'VN', '2013-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148385, 'An Châu', 'An Chau', 'An Chau,An Châu', 21.3346500, 106.8493400, 'VN', '2012-08-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148386, 'An Biên', 'An Bien', 'An Bien,An Biên', 9.8153200, 105.0636600, 'VN', '2014-08-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148387, 'A Lưới', 'A Luoi', 'A Luoi,A Lưới', 16.2722800, 107.2338500, 'VN', '2013-12-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148388, 'Quận Bảy', 'Quan Bay', 'Phu My,Phú Mỹ,Quan 7,Quan Bay,Quận 7,Quận Bảy', 10.7118000, 106.7364300, 'VN', '2014-12-03', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148389, 'Tam Điệp', 'Tam Diep', 'Tam Diep,Tam Điệp', 20.1563500, 105.9173700, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148390, 'Châu Thành', 'Chau Thanh', 'Chau Thanh,Châu Thành,Huong Chau Thanh,Hương Châu Thành', 9.8698900, 106.3493900, 'VN', '2014-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148391, 'Uyen Hung', 'Uyen Hung', '', 11.0841600, 106.7883400, 'VN', '2011-07-19', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148392, 'Yên Lập', 'Yen Lap', 'Huyen Yen Lap,Huyện Yên Lập,Yen Lap,Yên Lập', 21.3470500, 105.0573900, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148393, 'Thanh Ba', 'Thanh Ba', 'Huyen Thanh Hoa,Huyện Thanh Hòa,Thanh Ba', 21.4988100, 105.1410400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148394, 'Sông Thao', 'Song Thao', 'Huyen Song Thao,Huyện Sông Thao,Song Thao,Sông Thao', 21.4213000, 105.1337400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148395, 'Hưng Hóa', 'Hung Hoa', 'Hung Hoa,Huyen Tam Thanh,Huyện Tam Thanh,Hưng Hóa', 21.2548700, 105.2953000, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148396, 'Phong Châu', 'Phong Chau', 'Huyen Phong Chau,Huyện Phong Châu,Phong Chau,Phong Châu', 21.4068000, 105.3122800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148397, 'Thị Trấn Tân Yên', 'Thi Tran Tan Yen', 'Tan Yen,Thi Tran Tan Yen,Thị Trấn Tân Yên,Tân Yên', 22.0655000, 105.0345000, 'VN', '2013-05-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148398, 'Tân Việt', 'Tan Viet', 'Tan Viet,Tân Việt', 22.8640700, 105.4590500, 'VN', '2012-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148399, 'Pác Miầu', 'Pac Miau', 'Bao Lam,Bảo Lâm,Pac Miau,Pac Mieu,Pác Miầu,Păc Miều', 22.8296800, 105.4933400, 'VN', '2015-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148400, 'Lập Thạch', 'Lap Thach', 'Lap Thach,Lập Thạch', 21.4153900, 105.4608100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148401, 'An Châu', 'An Chau', 'An Chau,An Châu', 10.4455900, 105.3862200, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148402, 'Núi Sập', 'Nui Sap', 'Nui Sap,Núi Sập', 10.2647800, 105.2667600, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148403, 'Tầm Vu', 'Tam Vu', 'Tam Vu,Tầm Vu', 10.4411400, 106.4679300, 'VN', '2014-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148404, 'Gia Bình', 'Gia Binh', 'Gia Binh,Gia Bình', 21.0593800, 106.1746800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148405, 'Thứa', 'Thua', 'Thua,Thứa', 21.0193700, 106.2004400, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148406, 'Chờ', 'Cho', 'Cho,Chờ', 21.1949100, 105.9547100, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148407, 'Phố Mới', 'Pho Moi', 'Pho Moi,Phố Mới', 21.1532800, 106.1516400, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148408, 'Hồ', 'Ho', 'Ho,Hồ', 21.0630800, 106.0857000, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148409, 'Lim', 'Lim', 'Lim', 21.1438800, 106.0201800, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148410, 'Cung Kiệm', 'Cung Kiem', 'Cung Kiem,Cung Kiệm', 21.1869700, 106.1607600, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148411, 'Thị Trấn Gành Hào', 'Thi Tran Ganh Hao', 'Thi Tran Ganh Hao,Thị Trấn Gành Hào', 9.0318300, 105.4211500, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148412, 'Thị Trấn Ngan Dừa', 'Thi Tran Ngan Dua', 'Thi Tran Ngan Dua,Thị Trấn Ngan Dừa', 9.5670300, 105.4501900, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148413, 'Thị Trấn Phước Long', 'Thi Tran Phuoc Long', 'Thi Tran Phuoc Long,Thị Trấn Phước Long', 9.4375300, 105.4621700, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148414, 'Thị Trấn Giá Rai', 'Thi Tran Gia Rai', 'Thi Tran Gia Rai,Thị Trấn Giá Rai', 9.2378900, 105.4552400, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148415, 'Thị Trấn Hòa Bình', 'Thi Tran Hoa Binh', 'Thi Tran Hoa Binh,Thị Trấn Hòa Bình', 9.2847100, 105.6291600, 'VN', '2012-07-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148416, 'Cái Dầu', 'Cai Dau', '', 10.5742800, 105.2400500, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148417, 'Cầu Gồ', 'Cau Go', 'Cau Go,Cầu Gồ', 21.4767900, 106.1265300, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148418, 'Đồi Ngô', 'GJoi Ngo', 'GJoi Ngo,Đồi Ngô', 21.3062600, 106.3867300, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148419, 'Neo', 'Neo', 'Neo', 21.2004800, 106.2473900, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148420, 'Bích Động', 'Bich GJong', 'Bich GJong,Bích Động', 21.2742100, 106.1006900, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148421, 'Thắng', 'Thang', 'Thang,Thắng', 21.3550500, 105.9834400, 'VN', '2012-08-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148422, 'Bộc Bố', 'Boc Bo', 'Boc Bo,Bộc Bố', 22.6120600, 105.6670700, 'VN', '2012-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148423, 'Bằng Lũng', 'Bang Lung', 'Bang Lung,Bằng Lũng', 22.1577700, 105.5955900, 'VN', '2012-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148424, 'Thị Trấn Long Điền', 'Thi Tran Long GJien', 'Thi Tran Long GJien,Thị Trấn Long Điền', 10.4855700, 107.2122600, 'VN', '2012-11-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148425, 'Mường Chà', 'Muong Cha', 'Muong Cha,Mường Chà,Thi Tran Muong Cha,Thị Trấn Mường Chà', 21.7617200, 103.0978300, 'VN', '2015-12-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148426, 'Thị Trấn Tủa Chùa', 'Thi Tran Tua Chua', 'Thi Tran Tua Chua,Thị Trấn Tủa Chùa', 21.8577100, 103.3426000, 'VN', '2012-11-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148427, 'Điện Biên Đông', 'Dien Bien Dong', 'Dien Bien Dong,Điện Biên Đông', 21.2967300, 103.2200900, 'VN', '2015-04-09', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148428, 'Thị Trấn Điện Biên', 'Thi Tran GJien Bien', 'Thi Tran GJien Bien,Thị Trấn Điện Biên', 21.2596000, 103.0344000, 'VN', '2012-11-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148429, 'Tam Đường', 'Tam Duong', 'Tam Duong,Tam Đường', 22.3181200, 103.6261900, 'VN', '2015-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148430, 'Lai Châu', 'Lai Chau', 'Lai Chau,Lai Châu,Muang Lay', 22.3964400, 103.4582400, 'VN', '2015-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148431, 'Thị Trấn Mường Tè', 'Thi Tran Muong Te', 'Thi Tran Muong Te,Thị Trấn Mường Tè', 22.3806700, 102.8201100, 'VN', '2013-02-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148432, 'Thị Trấn Tam Sơn', 'Thi Tran Tam Son', 'Thi Tran Tam Son,Thị Trấn Tam Sơn', 23.0674000, 104.9892600, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148433, 'Thị Trấn Vị Xuyên', 'Thi Tran Vi Xuyen', 'Thi Tran Vi Xuyen,Thị Trấn Vị Xuyên', 22.6676200, 104.9819100, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148434, 'Thị Trấn Việt Lâm', 'Thi Tran Viet Lam', 'Thi Tran Viet Lam,Thị Trấn Việt Lâm', 22.6248600, 104.9598800, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148435, 'Thị Trấn Việt Quang', 'Thi Tran Viet Quang', 'Thi Tran Viet Quang,Thị Trấn Việt Quang', 22.4150900, 104.8068200, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148436, 'Yên Phú', 'Yen Phu', 'Yen Phu,Yên Phú', 22.7322300, 105.3714500, 'VN', '2015-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148437, 'Thị Trấn Vinh Quang', 'Thi Tran Vinh Quang', 'Thi Tran Vinh Quang,Thị Trấn Vinh Quang', 22.7408500, 104.6795600, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148438, 'Yên Bình', 'Yen Binh', 'Yen Binh,Yên Bình', 22.4098900, 104.5794900, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148439, 'Thị Trấn Thông Nông', 'Thi Tran Thong Nong', 'Thi Tran Thong Nong,Thị Trấn Thông Nông', 22.7841000, 105.9832000, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148440, 'Thị Trấn Xuân Hoà', 'Thi Tran Xuan Hoa', 'Thi Tran Xuan Hoa,Thị Trấn Xuân Hoà', 22.9024300, 106.0773700, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148441, 'Thị Trấn Hùng Quốc', 'Thi Tran Hung Quoc', 'Thi Tran Hung Quoc,Thị Trấn Hùng Quốc', 22.8289800, 106.3233500, 'VN', '2013-03-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148442, 'Thị Trấn Cao Lộc', 'Thi Tran Cao Loc', 'Thi Tran Cao Loc,Thị Trấn Cao Lộc', 21.8665000, 106.7683300, 'VN', '2013-05-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148443, 'Thị Trấn Vĩnh Lộc', 'Thi Tran Vinh Loc', 'Thi Tran Vinh Loc,Thị Trấn Vĩnh Lộc', 22.1436000, 105.2719200, 'VN', '2013-05-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148444, 'Sơn Thịnh', 'Son Thinh', 'Son Thinh,Sơn Thịnh,Van Chan,Văn Chấn', 21.5625200, 104.5948000, 'VN', '2013-05-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148445, 'Cổ Phúc', 'Co Phuc', 'Co Phuc,Cổ Phúc', 21.7558500, 104.8276800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148446, 'Thị Trấn Yên Thế', 'Thi Tran Yen The', 'Thi Tran Yen The,Thị Trấn Yên Thế', 22.1107500, 104.7674800, 'VN', '2013-05-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148447, 'Thị Trấn Na Hang', 'Thi Tran Na Hang', 'Na Hang,Thi Tran Na Hang,Thị Trấn Na Hang', 22.3491700, 105.3824100, 'VN', '2013-06-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148448, 'Bình Minh', 'Binh Minh', 'Binh Minh,Bình Minh,Cai Von,Cái Vồn', 10.0682100, 105.8222100, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148449, 'An Phú', 'An Phu', 'An Phu,An Phú', 10.8159100, 105.0903800, 'VN', '2013-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148450, 'Phú Mỹ', 'Phu My', 'Phu My,Phú Mỹ', 10.5923600, 105.3557300, 'VN', '2013-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148451, 'Thị Trấn Phú Mỹ', 'Thi Tran Phu My', 'Thi Tran Phu My,Thị Trấn Phú Mỹ', 10.6036000, 107.0540000, 'VN', '2013-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148452, 'Bát Xát', 'Bat Xat', 'Bat Xat,Bát Xát,Thi Tran Bat Xat,Thị Trấn Bát Xát', 22.5431100, 103.8898900, 'VN', '2015-02-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148453, 'Hát Lót', 'Hat Lot', 'Hat Lot,Hát Lót,Thi Tran Hat Lot,Thị Trấn Hát Lót', 21.1973300, 104.1059500, 'VN', '2015-06-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148454, 'Quảng Xương', 'Quang Xuong', 'Quang Xuong,Quảng Xương', 19.7294800, 105.7827300, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148455, 'Nông Cống', 'Nong Cong', 'Nong Cong,Nông Cống', 19.6240300, 105.6494100, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148456, 'Quan Sơn', 'Quan Son', 'Quan Son,Quan Sơn', 20.2590900, 104.9452100, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148457, 'Yên Cát', 'Yen Cat', 'Yen Cat,Yên Cát', 19.6632700, 105.4285400, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148458, 'Bút Sơn', 'But Son', 'But Son,Bút Sơn', 19.8579700, 105.8548200, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148459, 'Cành Nàng', 'Canh Nang', 'Canh Nang,Cành Nàng', 20.3480300, 105.2288100, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148460, 'Hậu Lộc', 'Hau Loc', 'Hau Loc,Hậu Lộc', 19.9144400, 105.8861500, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148461, 'Triệu Sơn', 'Trieu Son', 'Trieu Son,Triệu Sơn', 19.8191300, 105.6039200, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148462, 'Quán Lào', 'Quan Lao', 'Quan Lao,Quán Lào', 19.9715300, 105.6510600, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148463, 'Hà Trung', 'Ha Trung', 'Ha Trung,Hà Trung', 20.0128500, 105.8532200, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148464, 'Rừng Thông', 'Rung Thong', 'Rung Thong,Rừng Thông', 19.8190600, 105.7327900, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148465, 'Vạn Hà', 'Van Ha', 'Van Ha,Vạn Hà', 19.8865900, 105.6787900, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148466, 'Đà Bắc', 'Da Bac', 'Da Bac,Đà Bắc', 20.8771400, 105.2541700, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148467, 'Mường Khến', 'Muong Khen', 'Muong Khen,Mường Khến', 20.6144100, 105.2794800, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148468, 'Hàng Trạm', 'Hang Tram', 'Hang Tram,Hàng Trạm', 20.3947200, 105.6224000, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148469, 'Bo', 'Bo', 'Bo', 20.6726400, 105.5362500, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148470, 'Lương Sơn', 'Luong Son', 'Luong Son,Lương Sơn', 20.8714800, 105.5256800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148471, 'Kỳ Sơn', 'Ky Son', 'Ky Son,Kỳ Sơn', 20.8866800, 105.3524400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148472, 'Cao Phong', 'Cao Phong', 'Cao Phong', 20.7044600, 105.3206300, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148473, 'Me', 'Me', 'Me', 20.3469700, 105.8361500, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148474, 'Thiên Tồn', 'Thien Ton', 'Thien Ton,Thiên Tồn', 20.2990500, 105.9519800, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148475, 'Yên Thịnh', 'Yen Thinh', 'Yen Thinh,Yên Thịnh', 20.1624500, 106.0069700, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148476, 'Xuân Trường', 'Xuan Truong', 'Xuan Truong,Xuân Trường', 20.2922700, 106.3327500, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148477, 'Yên Định', 'Yen Dinh', 'Yen Dinh,Yên Định', 20.2014500, 106.2957800, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148478, 'Lâm', 'Lam', 'Lam,Lâm', 20.3277300, 106.0120800, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148479, 'Gôi', 'Goi', 'Goi,Gôi', 20.3333500, 106.0782600, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148480, 'Nam Giang', 'Nam Giang', 'Nam Giang', 20.3332200, 106.1775400, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148481, 'Cổ Lễ', 'Co Le', 'Co Le,Cổ Lễ', 20.3233600, 106.2658400, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148482, 'Quế', 'Que', 'Que,Quế', 20.5806400, 105.8726600, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148483, 'Vĩnh Trụ', 'Vinh Tru', 'Vinh Tru,Vĩnh Trụ', 20.5602000, 106.0281200, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148484, 'Bình Mỹ', 'Binh My', 'Binh My,Bình Mỹ', 20.4912100, 106.0095500, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148485, 'Thanh Lưu', 'Thanh Luu', 'Thanh Liem,Thanh Liêm,Thanh Luu,Thanh Lưu', 20.4739800, 105.9526800, 'VN', '2015-07-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148486, 'Hưng Hà', 'Hung Ha', 'Hung Ha,Hưng Hà', 20.5904000, 106.2244500, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148487, 'Vũ Thư', 'Vu Thu', 'Vu Thu,Vũ Thư', 20.4367100, 106.2911600, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148488, 'Đông Hưng', 'Dong Hung', 'Dong Hung,Đông Hưng', 20.5565100, 106.3553200, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148489, 'Thành Phố Bà Rịa', 'Thanh Pho Ba Ria', 'Thanh Pho Ba Ria,Thành Phố Bà Rịa', 10.4962900, 107.1684100, 'VN', '2013-08-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148490, 'Thị Trấn Tuần Giáo', 'Thi Tran Tuan Giao', 'Thi Tran Tuan Giao,Thị Trấn Tuần Giáo', 21.5899200, 103.4217900, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148491, 'Mường Ảng', 'Muong Ang', 'Muong Ang,Mường Ảng,Thi Tran Muong Ang,Thị Trấn Mường Ảng', 21.5199300, 103.2229400, 'VN', '2015-12-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148492, 'An Lão', 'An Lao', 'An Lao,An Lão', 20.8229400, 106.5557500, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148493, 'Tiên Lãng', 'Tien Lang', 'Tien Lang,Tiên Lãng', 20.7246400, 106.5539100, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148494, 'Núi Đối', 'Nui Doi', 'Nui Doi,Núi Đối', 20.7507800, 106.6689400, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148495, 'Quảng Hà', 'Quang Ha', 'Quang Ha,Quảng Hà', 21.4506000, 107.7559200, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148496, 'Trới', 'Troi', 'Troi,Trới', 21.0314100, 106.9910100, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148497, 'Cô Tô', 'Co To', 'Co To,Cô Tô', 20.9726800, 107.7657800, 'VN', '2013-08-10', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148498, 'Thanh Miện', 'Thanh Mien', 'Thanh Mien,Thanh Miện', 20.7871400, 106.2462300, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148499, 'Nam Sách', 'Nam Sach', 'Nam Sach,Nam Sách', 20.9920500, 106.3361300, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148500, 'Gia Lộc', 'Gia Loc', 'Gia Loc,Gia Lộc', 20.8678300, 106.3000000, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148501, 'Tứ Kỳ', 'Tu Ky', 'Tu Ky,Tứ Kỳ', 20.8191400, 106.4066100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148502, 'Thanh Hà', 'Thanh Ha', 'Thanh Ha,Thanh Hà', 20.8981600, 106.4261200, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148503, 'Phú Thái', 'Phu Thai', 'Phu Thai,Phú Thái', 20.9627800, 106.5095000, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148504, 'Đu', 'Du', 'Du,Đu', 21.7384700, 105.7038800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148505, 'Hương Sơn', 'Huong Son', 'Huong Son,Hương Sơn', 21.4601400, 105.9781400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148506, 'Chùa Hang', 'Chua Hang', 'Chua Hang,Chùa Hang', 21.6238400, 105.8416800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148507, 'Thanh Thủy', 'Thanh Thuy', 'Thanh Thuy,Thanh Thủy', 21.1754800, 105.2838800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148508, 'Lâm Thao', 'Lam Thao', 'Lam Thao,Lâm Thao', 21.3201000, 105.2915600, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148509, 'Mê Linh', 'Me Linh', 'Me Linh,Mê Linh', 21.1831000, 105.7204100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148510, 'Vĩnh Tường', 'Vinh Tuong', 'Vinh Tuong,Vĩnh Tường', 21.2165000, 105.5124900, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148511, 'Hợp Hòa', 'Hop Hoa', 'Hop Hoa,Hợp Hòa', 21.3752500, 105.5425600, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148512, 'Văn Giang', 'Van Giang', 'Van Giang,Văn Giang', 20.9430100, 105.9311900, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148513, 'Yên Mỹ', 'Yen My', 'Yen My,Yên Mỹ', 20.8855700, 106.0356000, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148514, 'Khoái Châu', 'Khoai Chau', 'Khoai Chau,Khoái Châu', 20.8391200, 105.9775500, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148515, 'Lương Bằng', 'Luong Bang', 'Luong Bang,Lương Bằng', 20.7400300, 106.0599800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148516, 'Ân Thi', 'An Thi', 'An Thi,Ân Thi', 20.8183500, 106.0911800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148517, 'Trần Cao', 'Tran Cao', 'Tran Cao,Trần Cao', 20.7295200, 106.1797100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148518, 'Vương', 'Vuong', 'Vuong,Vương', 20.7011000, 106.1175100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148519, 'Liên Quan', 'Lien Quan', 'Lien Quan,Liên Quan', 21.0572300, 105.5791900, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148520, 'Phúc Thọ', 'Phuc Tho', 'Phuc Tho,Phúc Thọ', 21.1034500, 105.5455100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148521, 'Phùng', 'Phung', 'Phung,Phùng', 21.0890200, 105.6590100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148522, 'Trôi', 'Troi', 'Troi,Trôi', 21.0695300, 105.7064600, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148523, 'Quốc Oai', 'Quoc Oai', 'Quoc Oai,Quốc Oai', 20.9901900, 105.6408800, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148524, 'Thường Tín', 'Thuong Tin', 'Thuong Tin,Thường Tín', 20.8687400, 105.8612500, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148525, 'Phú Xuyên', 'Phu Xuyen', 'Phu Xuyen,Phú Xuyên', 20.7454900, 105.9136300, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148526, 'Đại Nghĩa', 'Dai Nghia', 'Dai Nghia,Đại Nghĩa', 20.6866700, 105.7447100, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148527, 'Sóc Sơn', 'Soc Son', 'Soc Son,Sóc Sơn', 21.2578200, 105.8489400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148528, 'Đông Anh', 'Dong Anh', 'Dong Anh,Đông Anh', 21.1396200, 105.8492600, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148529, 'Cầu Diễn', 'Cau Dien', 'Cau Dien,Cầu Diễn', 21.0392900, 105.7665900, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148530, 'Trâu Quỳ', 'Trau Quy', 'Trau Quy,Trâu Quỳ', 21.0195100, 105.9369400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148531, 'Cầu Giấy', 'Cau Giay', 'Cau Giay,Cầu Giấy', 21.0322800, 105.8007300, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148532, 'Thanh Xuân', 'Thanh Xuan', 'Thanh Xuan,Thanh Xuân', 20.9947200, 105.7997700, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148533, 'Đống Đa', 'Dong Da', 'Dong Da,Đống Đa', 21.0200900, 105.8309700, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148534, 'Hoàn Kiếm', 'Hoan Kiem', 'Hoan Kiem,Hoàn Kiếm', 21.0285700, 105.8506400, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148535, 'Hai BàTrưng', 'Hai BaTrung', 'Hai BaTrung,Hai BàTrưng', 21.0134100, 105.8477200, 'VN', '2013-09-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148536, 'Hưng Nguyên', 'Hung Nguyen', 'Hung Nguyen,Hưng Nguyên', 18.6716500, 105.6288200, 'VN', '2013-10-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148537, 'Vũ Quang', 'Vu Quang', 'Vu Quang,Vũ Quang', 18.3838500, 105.5059000, 'VN', '2013-11-14', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148538, 'Nghèn', 'Nghen', 'Nghen,Nghèn', 18.4511900, 105.7796900, 'VN', '2015-05-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148539, 'Đồng Lê', 'Dong Le', 'Dong Le,Đồng Lê', 17.8838900, 106.0253600, 'VN', '2013-12-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148540, 'Krông Klang', 'Krong Klang', 'Krong Klang,Krông Klang', 16.6890600, 106.8874000, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148541, 'Khe Tre', 'Khe Tre', 'Khe Tre', 16.1691000, 107.7179300, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148542, 'Sịa', 'Sia', 'Sia,Sịa', 16.5745200, 107.5106600, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148543, 'Thanh Khê', 'Thanh Khe', 'Thanh Khe,Thanh Khê', 16.0706000, 108.1910200, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148544, 'Cẩm Lệ', 'Cam Le', 'Cam Le,Cẩm Lệ', 16.0177100, 108.2038100, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148545, 'Sơn Trà', 'Son Tra', 'Son Tra,Sơn Trà', 16.0606800, 108.2325600, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148546, 'Liên Chiểu', 'Lien Chieu', 'Lien Chieu,Liên Chiểu', 16.0727200, 108.1581500, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148547, 'Ngũ Hành Sơn', 'Ngu Hanh Son', 'Ngu Hanh Son,Ngũ Hành Sơn', 16.0161800, 108.2533500, 'VN', '2013-12-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148548, 'Prao', 'Prao', 'Prao', 15.9243800, 107.6481400, 'VN', '2014-01-18', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148549, 'Khâm Đức', 'Kham Duc', 'Kham Duc,Khâm Đức', 15.4450800, 107.7933700, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148550, 'Núi Thành', 'Nui Thanh', 'Nui Thanh,Núi Thành', 15.4319400, 108.6594600, 'VN', '2014-01-18', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148551, 'Phú Ninh', 'Phu Ninh', 'Phu Ninh,Phú Ninh', 15.5547300, 108.4114200, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148552, 'Tây Trà', 'Tay Tra', 'Tay Tra,Tây Trà', 15.1694800, 108.3599800, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148553, 'Lý Sơn', 'Ly Son', 'Ly Son,Lý Sơn', 15.3719800, 109.1189100, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148554, 'Đắk Glei', 'Dak Glei', 'Dak Glei,Đắk Glei', 15.0864200, 107.7357700, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148555, 'Sa Thầy', 'Sa Thay', 'Sa Thay,Sa Thầy', 14.4137700, 107.7933900, 'VN', '2014-01-18', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148556, 'Đắk Hà', 'Dak Ha', 'Dak Ha,Đắk Hà', 14.5134500, 107.9210200, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148557, 'Đắk Rve', 'Dak Rve', 'Dak Rve,Đắk Rve', 14.5071700, 108.2473000, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148558, 'Kon Plông', 'Kon Plong', 'Kon Plong,Kon Plông', 14.6006400, 108.2908800, 'VN', '2014-01-18', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148559, 'Đăk Đoa', 'Dak Doa', 'Dak Doa,Đak Đoa,Đăk Đoa', 13.9950100, 108.1120700, 'VN', '2014-02-16', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148560, 'K Bang', 'K Bang', 'K Bang', 14.1445300, 108.5990800, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148561, 'Kông Chro', 'Kong Chro', 'Kong Chro,Kông Chro', 13.7753200, 108.5255800, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148562, 'Ia Pa', 'Ia Pa', 'Ia Pa', 13.5336100, 108.4552900, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148563, 'A Yun Pa', 'A Yun Pa', 'A Yun Pa', 13.4002500, 108.4350300, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148564, 'Chư Sê', 'Chu Se', 'Chu Se,Chư Sê', 13.6915300, 108.0802300, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148565, 'Chư Prông', 'Chu Prong', 'Chu Prong,Chư Prông', 13.7568400, 107.8862400, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148566, 'Chư Ty', 'Chu Ty', 'Chu Ty,Chư Ty', 13.8050700, 107.6961000, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148567, 'Ia Kha', 'Ia Kha', 'Ia Kha', 13.9624200, 107.8448400, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148568, 'Phú Hòa', 'Phu Hoa', 'Phu Hoa,Phú Hòa', 14.1000500, 107.9689600, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148569, 'Kon Dơng', 'Kon Dong', 'Kon Dong,Kon Dơng', 14.0388600, 108.2501100, 'VN', '2014-02-17', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148570, 'Hai Riêng', 'Hai Rieng', 'Hai Rieng,Hai Riêng', 12.9790800, 108.8973200, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148571, 'Ea Súp', 'Ea Sup', 'Ea Sup,Ea Súp', 13.0661600, 107.8854600, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148572, 'Ea Drăng', 'Ea Drang', 'Ea Drang,Ea Drăng', 13.2045000, 108.2102900, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148573, 'Krông Năng', 'Krong Nang', 'Krong Nang,Krông Năng', 12.9517000, 108.3442500, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148574, 'Quảng Phú', 'Quang Phu', 'Quang Phu,Quảng Phú', 12.8196500, 108.0773800, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148575, 'Ea Kar', 'Ea Kar', 'Ea Kar', 12.8081600, 108.4490100, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148576, 'Krông Kmar', 'Krong Kmar', 'Krong Kmar,Krông Kmar', 12.5045000, 108.3328800, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148577, 'M’Đrăk', 'M''Drak', 'M''Drak,M’Đrăk', 12.7462400, 108.7428100, 'VN', '2014-03-11', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148578, 'Khánh Vĩnh', 'Khanh Vinh', 'Khanh Vinh,Khánh Vĩnh', 12.2835500, 108.9047000, 'VN', '2014-04-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148579, 'Tô Hạp', 'To Hap', 'To Hap,Tô Hạp', 12.0058200, 108.9486800, 'VN', '2014-04-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148580, 'Cam Lâm', 'Cam Lam', 'Cam Lam,Cam Lâm', 12.0539800, 109.1600400, 'VN', '2014-04-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148581, 'Ea T’ling', 'Ea T''ling', 'Ea T''ling,Ea T’ling', 12.5890400, 107.8957800, 'VN', '2014-04-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148582, 'Đắk Mâm', 'Dak Mam', 'Dak Mam,Đắk Mâm', 12.4578900, 107.8624600, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148583, 'Đinh Văn', 'GJinh Van', 'Din'' Van,Dinh Van,Đinh Văn,Динь Ван', 11.7862400, 108.2428200, 'VN', '2014-06-27', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148584, 'Thạnh Mỹ', 'Thanh My', 'Thanh My,Thạnh Mỹ', 11.7616500, 108.4947300, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148585, 'Lộc Thắng', 'Loc Thang', 'Loc Thang,Lộc Thắng', 11.6283600, 107.8350800, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148586, 'Đồng Nai', 'Dong Nai', 'Dong Nai,Đồng Nai', 11.5798100, 107.3651800, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148587, 'Đạ Tẻh', 'Da Teh', 'Da Teh,Đạ Tẻh', 11.5114800, 107.4909200, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148588, 'Bác Ái', 'Bac Ai', 'Bac Ai,Bác Ái', 11.8410400, 108.9031600, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148589, 'Tân Sơn', 'Tan Son', 'Tan Son,Tân Sơn', 11.7752100, 108.7848000, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148590, 'Phước Dân', 'Phuoc Dan', 'Phuoc Dan,Phước Dân', 11.5269600, 108.9299600, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148591, 'Khánh Hải', 'Khanh Hai', 'Khanh Hai,Khánh Hải', 11.5910500, 109.0405200, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148592, 'Chợ Lầu', 'Cho Lau', 'Cho Lau,Chợ Lầu', 11.2215800, 108.5070700, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148593, 'Ma Lâm', 'Ma Lam', 'Ma Lam,Ma Lâm', 11.0729700, 108.1299700, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148594, 'Thuận Nam', 'Thuan Nam', 'Thuan Nam,Thuận Nam', 10.8500400, 107.8786400, 'VN', '2014-05-01', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148595, 'Phú Quý', 'Phu Quy', 'Phu Quy,Phú Quý', 10.5166000, 108.9329200, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148596, 'Tân Phú', 'Tan Phu', 'Tan Phu,Tân Phú', 11.2722100, 107.4365500, 'VN', '2014-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148597, 'Vĩnh An', 'Vinh An', 'Vinh An,Vĩnh An', 11.0890100, 107.0351600, 'VN', '2014-06-06', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148598, 'Thống Nhất', 'Thong Nhat', 'Thong Nhat,Thống Nhất', 10.9505500, 107.1457100, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148599, 'Long Khánh', 'Long Khanh', 'Long Khanh,Long Khánh', 10.9265500, 107.2478300, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148600, 'Tân Phú', 'Tan Phu', 'Tan Phu,Tân Phú', 11.4511900, 106.8681100, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148601, 'Tân Châu', 'Tan Chau', 'Tan Chau,Tân Châu', 11.5520200, 106.1724500, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148602, 'Tân Biên', 'Tan Bien', 'Tan Bien,Tân Biên', 11.5444100, 106.0116100, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148603, 'Châu Thành', 'Chau Thanh', 'Chau Thanh,Châu Thành', 11.3116700, 106.0295000, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148604, 'Hòa Thành', 'Hoa Thanh', 'Hoa Thanh,Hòa Thành', 11.2869600, 106.1293600, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148605, 'Gò Dầu', 'Go Dau', 'Go Dau,Gò Dầu', 11.0885000, 106.2634600, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148606, 'Dương Minh Châu', 'Duong Minh Chau', 'Duong Minh Chau,Dương Minh Châu', 11.3841400, 106.2307800, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148607, 'Tân Hưng', 'Tan Hung', 'Tan Hung,Tân Hưng', 10.8347600, 105.6613500, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148608, 'Vĩnh Hưng', 'Vinh Hung', 'Vinh Hung,Vĩnh Hưng', 10.8906700, 105.7849500, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148609, 'Tân Thạnh', 'Tan Thanh', 'Tan Thanh,Tân Thạnh', 10.6066600, 106.0471400, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148610, 'Thạnh Hóa', 'Thanh Hoa', 'Thanh Hoa,Thạnh Hóa', 10.6574400, 106.1808100, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148611, 'Đông Thành', 'Dong Thanh', 'Dong Thanh,Đông Thành', 10.8922100, 106.3061400, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148612, 'Hậu Nghĩa', 'Hau Nghia', 'Hau Nghia,Hậu Nghĩa', 10.8943400, 106.3969500, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148613, 'Mỹ Phước', 'My Phuoc', 'My Phuoc,Mỹ Phước', 10.4771100, 106.1925600, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148614, 'Tân Hòa', 'Tan Hoa', 'Tan Hoa,Tân Hòa', 10.3190600, 106.7112800, 'VN', '2014-06-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148615, 'Thứ Mười Một', 'Thu Muoi Mot', 'Thu Muoi Mot,Thứ Mười Một', 9.6114400, 104.9465000, 'VN', '2014-08-07', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148616, 'Sa Rài', 'Sa Rai', 'Sa Rai,Sa Rài', 10.8701600, 105.4658300, 'VN', '2014-08-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148617, 'Long Hồ', 'Long Ho', 'Long Ho,Long Hồ', 10.1928100, 106.0122900, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148618, 'Duyên Hải', 'Duyen Hai', 'Duyen Hai,Duyên Hải', 9.6349700, 106.4923700, 'VN', '2014-08-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148619, 'Châu Thành', 'Chau Thanh', 'Chau Thanh,Châu Thành', 10.3012200, 106.3570100, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148620, 'Vĩnh Thạnh', 'Vinh Thanh', 'Vinh Thanh,Vĩnh Thạnh', 10.2226300, 105.3984100, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148621, 'Nàng Mau', 'Nang Mau', 'Nang Mau,Nàng Mau', 9.7512900, 105.5344800, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148622, 'Ngã Bảy', 'Nga Bay', 'Nga Bay,Ngã Bảy', 9.8137100, 105.8209600, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148623, 'Ngã Sáu', 'Nga Sau', 'Nga Sau,Ngã Sáu', 9.9230300, 105.8054200, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148624, 'Một Ngàn', 'Mot Ngan', 'Mot Ngan,Một Ngàn', 9.9240200, 105.6296400, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148625, 'Cù Lao Dung', 'Cu Lao Dung', 'Cu Lao Dung,Cù Lao Dung', 9.6731400, 106.1487400, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148626, 'Châu Thành', 'Chau Thanh', 'Chau Thanh,Châu Thành', 9.7007000, 105.9020200, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148627, 'Huỳnh Hữu Nghĩa', 'Huynh Huu Nghia', 'Huynh Huu Nghia,Huỳnh Hữu Nghĩa', 9.6353700, 105.8116500, 'VN', '2014-09-08', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148628, 'U Minh', 'U Minh', 'U Minh', 9.4128600, 104.9735300, 'VN', '2014-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148629, 'Trần Văn Thời', 'Tran Van Thoi', 'Tran Van Thoi,Trần Văn Thời', 9.0771300, 104.9791400, 'VN', '2014-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148630, 'Ngọc Hiển', 'Ngoc Hien', 'Ngoc Hien,Ngọc Hiển', 8.6572400, 105.0602100, 'VN', '2014-10-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148631, 'Quận Hai', 'Quan Hai', 'Quan 2,Quan Hai,Quận 2,Quận Hai', 10.7915600, 106.7494800, 'VN', '2014-10-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148632, 'Quận Chín', 'Quan Chin', 'Quan 9,Quan Chin,Quận 9,Quận Chín', 10.8397000, 106.7709300, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148633, 'Quận Bốn', 'Quan Bon', 'Quan 4,Quan Bon,Quận 4,Quận Bốn', 10.7668400, 106.7057400, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148634, 'Quận Sáu', 'Quan Sau', 'Quan 6,Quan Sau,Quận 6,Quận Sáu', 10.7468000, 106.6490300, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148635, 'Quận Năm', 'Quan Nam', 'Quan 5,Quan Nam,Quận 5,Quận Năm', 10.7556700, 106.6674500, 'VN', '2014-10-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148636, 'Quận Một', 'Quan Mot', 'Quan 1,Quan Mot,Quận 1,Quận Một', 10.7806900, 106.6994400, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148637, 'Quận Phú Nhuận', 'Quan Phu Nhuan', '', 10.7947500, 106.6763000, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148638, 'Quận Tân Phú', 'Quan Tan Phu', '', 10.7837900, 106.6370400, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148639, 'Quận Mười Một', 'Quan Muoi Mot', 'Quan 11,Quan Muoi Mot,Quận 11,Quận Mười Một', 10.7638300, 106.6435500, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148640, 'Quận Mười', 'Quan Muoi', 'Quan 10,Quan Muoi,Quận 10,Quận Mười', 10.7682300, 106.6663200, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148641, 'Quận Ba', 'Quan Ba', 'Quan 3,Quan Ba,Quận 3,Quận Ba', 10.7749400, 106.6862800, 'VN', '2014-10-05', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148642, 'Quận Bình Thạnh', 'Quan Binh Thanh', '', 10.8032500, 106.6966600, 'VN', '2014-12-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148643, 'Hoàng Sa', 'Hoang Sa', '', 16.6665700, 112.7254100, 'VN', '2017-04-04', 242);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148029, 'Charlotte Amalie', 'Charlotte Amalie', 'Amalienborg,Amalienburg,Carlota Amalia,Carlotamalio,Charlotte Amalia,Charlotte Amalie,Charlotte Amalie pa Dei amerikanske Jomfruoyane,Charlotte Amalie på Dei amerikanske Jomfruøyane,Di Dorp,Dorp,Gorad Sharlota-Amalija,Het Dorp,Saint Thomas,Saint Thomas City,Sanct Thomas,Sarlot Amali,Sarlote Amalija,Sarlotta Amaliya,Savan,Scharlotte Amelia,Sharlot Amali,Sharlota Amalija,Sharlotta-Amalija,Tap House,Tap Hus,Taphuis,Taphus,Taphuus,Taphys,Tappus,Wirtshaus,Zapfhaus,charlxttxa mali,sarlata ameli,sharlwt amaly,srlwt ʼmʼly,syalleos-amallie,xia luo te a ma li ya,Ĉarlotamalio,Şarlotta Amaliya,Šarlotė Amalija,Σαρλότ Αμαλί,Горад Шарлота-Амалія,Шарлот Амали,Шарлота Амалия,Шарлота Амалија,Шарлотта-Амалия,Шарлотта-Амалія,שרלוט אמאלי,شارلوت آمالی,شارلوت أمالي,شارلٹ ایملی,शार्लट आमेली,ชาร์ลอตต์อะมาลี,შარლოტა-ამალია,シャーロット・アマリー,夏洛特阿马利亚,샬럿아말리에', 18.3419000, -64.9307000, 'VI', '2016-06-22', 244);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148030, 'Cruz Bay', 'Cruz Bay', 'Christiansbye,Creuse Bay,Crux Bay,Cruxbay,Cruz Bay,Cruz Bay Village,Cruz Village,Cruzbay,SJF', 18.3313400, -64.7937500, 'VI', '2016-06-22', 244);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148031, 'Saint Croix', 'Saint Croix', 'Agay,Ay Ay,Ay-Ay,Ayay,Cibuguiera,Cibuquiera,Eylandet Saint Croix,L''Isle de Sainte Croix,STX,Sainte Croix,Sanct Croix,Sancta Crux,Santa Cruz,St Croix,The Quiet Virgin', 17.7275100, -64.7469800, 'VI', '2016-06-22', 244);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148652, 'Leava', 'Leava', 'Leava,Sigave,Sigavé,Singave', -14.2933300, -178.1583300, 'WF', '2016-12-03', 245);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148653, 'Mata-Utu', 'Mata-Utu', 'Gorad Mata-Utu,Mata Utu,Mata''utu,Mata-Outou,Mata-Utu,Matauto,Matautu,Matâutu,Matāʻutu,ma ta wu tu,mata-atw,mata-awtw,mata-utu,mata-xu tu,matauto~u,matautu,Μάτα-Ούτου,Горад Мата-Уту,Мата-Уту,ماتا-اتو,ماتا-اوتو,மாதா-உது,มาตา-อูตู,მატა-უტუ,マタウトゥ,马塔乌图,마타우투', -13.2816300, -176.1745300, 'WF', '2014-08-19', 245);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148654, 'Alo', 'Alo', 'Alo,Malae,Ono', -14.3109600, -178.1109400, 'WF', '2015-09-30', 245);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148679, 'Zvečan', 'Zvecan', 'Zaccan,Zvecan,Zvechan,Zveçan,Zvečan,Звечан', 42.9075000, 20.8402800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148680, 'Zubin Potok', 'Zubin Potok', 'Zubin Potok,Zubin Potoku,Zubinpotok,Зубин Поток', 42.9144400, 20.6897200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148681, 'Vushtrri', 'Vushtrri', 'Vicianum,Vicitirin,Vuchitrn,Vucitern,Vuciterne,Vucitrn,Vushtrri,Vuçitërn,Vuçitërnë,Vučitrn,Vıçıtırın,Вучитрн', 42.8230600, 20.9675000, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148682, 'Vitina', 'Vitina', 'Viti,Vitina,Витина', 42.3213900, 21.3583300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148683, 'Ferizaj', 'Ferizaj', 'Ferezaj,Ferizaj,Ferizovik,Urosevac,Uroshevac,Uroševac,Урошевац', 42.3705600, 21.1552800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148684, 'Suva Reka', 'Suva Reka', 'Lumthate,Lumthatë,Suha Reka,Suhareka,Suhareke,Suharekë,Suharjeka,Sukareke,Sukarekë,Suva Reka,Suva Reki,Theranda,Thëranda,Сува Река', 42.3586100, 20.8250000, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148685, 'Štrpce', 'Strpce', 'Shterpce,Shtrpce,Shtërpcë,Strice,Strpce,Štrice,Štrpce,Штрпце', 42.2394400, 21.0272200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148686, 'Shtime', 'Shtime', 'Shtime,Shtimle,Stimle,Stimlja,Stimlje,Ştimle,Štimlja,Štimlje,Штимље', 42.4330600, 21.0397200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148687, 'Srbica', 'Srbica', 'Skenderaj,Skënderaj,Srbica,Србица', 42.7466700, 20.7886100, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148688, 'Irzniq', 'Irzniq', 'Irzniq,Irzniqi,Rrezar,Rrezari,Rrezniq,Rrznic,Rrznić,Rrëzniq,Rznic,Rznić,Рзнић', 42.5200000, 20.3472200, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148689, 'Ranilug', 'Ranilug', 'Ranillug,Ranillugu,Ranilug,Ranllug,Ранилуг', 42.4922200, 21.5988900, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148690, 'Prizren', 'Prizren', 'Perzeren,Perzerin,Prizren,Prizrena,Prizrenas,Prizreni,Përzeren,bryzrn,peulijeulen,pryzrn,pu li ci lun,purizuren,Πρίζρεν,Призрен,Приꙁрѣнь,Прізрен,بريزرن,پریزرن,プリズレン,普里兹伦,프리즈렌', 42.2138900, 20.7397200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148691, 'Pristina', 'Pristina', 'Gorad Pryshcina,PRN,Prestena,Prishhina,Prishtina,Prishtinae,Prishtine,Prishtinë,Prisjtina,Pristin,Pristina,Pristine,Pristino,Pristína,Prisztina,Prixtina,Priŝtino,Priştina,Priştine,Prištin,Priština,Priștina,Prìstina,Prėštėna,bryshtyna,peulisyutina,phrich ti na,piristina,prisatina,pristina,pryshtyna,prystynh,prysٹyna,pu li shen di na,purishutina,Πρίστινα,Горад Прышціна,Приштинæ,Приштина,Прищина,Պրիշտինա,פרישטינה,بريشتينا,پریسٹینا,پریشتینا,प्रिस्टिना,ਪ੍ਰਿਸ਼ਤੀਨਾ,பிரிஸ்டினா,พริชตีนา,པི་རི་སི་ཊི་ན།,პრიშტინა,プリシュティナ,普里什蒂納,普里什蒂纳,프리슈티나', 42.6727200, 21.1668800, 'XK', '2015-02-25', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148692, 'Prilep', 'Prilep', 'Arrnjet,Arrnjeti,Perlep,Prejlep,Prejlepi,Prelep,Prilep,Prilip,Përlep,Прилеп', 42.5075000, 20.3177800, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148693, 'Podujeva', 'Podujeva', 'Besiana,Besiane,Besianë,Podjeve,Podjevë,Podujeva,Podujeve,Podujevo,Podujevë,Podujevó', 42.9105600, 21.1930600, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148694, 'Peqan', 'Peqan', 'Pecane,Peqan,Pećane,Recan,Reçan,Пећане', 42.3836100, 20.8219400, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148695, 'Pejë', 'Peje', 'Pec,Pecas,Pech,Pegia,Peja,Peje,Pejë,Peć,Pečas,Picaria,Πέγια,Печ,Пећ', 42.6591300, 20.2882800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148696, 'Partesh', 'Partesh', 'Partes,Partesh,Parteshi,Parteš,Партеш', 42.4019400, 21.4336100, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148697, 'Pagaruša', 'Pagarusa', 'Pagarusa,Pagarusha,Pagarushe,Pagarushë,Pagaruša,Пагаруша', 42.4200000, 20.7422200, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148698, 'Orahovac', 'Orahovac', 'Orahovac,Orakhovac,Rahavec,Rahovec,Rahoveci,Ораховац', 42.3994400, 20.6547200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148699, 'Obiliq', 'Obiliq', 'Gllaboder,Kastriot,Obilic,Obiliq,Obilić,Обилић', 42.6869400, 21.0702800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149039, 'Pamandzi', 'Pamandzi', 'DZA,Pamandzi', -12.7967400, 45.2793800, 'YT', '2014-01-05', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149040, 'Mamoudzou', 'Mamoudzou', 'Mambutzou,Mamoudzou,Mamoutzou,Mamudzu,Mamutzu,Мамудзу', -12.7823400, 45.2287800, 'YT', '2017-01-11', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149041, 'Dzaoudzi', 'Dzaoudzi', 'DZA,Dzaoudzi,Dzaoudzi-Labattoir,Zaudzi,zao de ji,zauji,ザウジ,藻德济', -12.7833900, 45.2569300, 'YT', '2014-08-19', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149042, 'Dembeni', 'Dembeni', 'Debenay,Debeney', -12.8436000, 45.1843600, 'YT', '2013-08-08', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149043, 'Acoua', 'Acoua', 'Accua,Acoua,Acua', -12.7239100, 45.0581900, 'YT', '2017-01-11', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149044, 'Bandraboua', 'Bandraboua', 'Bandraboua,M''Gombani', -12.7044000, 45.1223100, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149045, 'Mtsamboro', 'Mtsamboro', 'M''Zamboro,Mtsamboro,M’Zamboro', -12.6998200, 45.0689400, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149046, 'M''Tsangamouji', 'M''Tsangamouji', 'Mtsamgamouji', -12.7594400, 45.0836100, 'YT', '2013-08-08', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149047, 'Tsingoni', 'Tsingoni', 'Tsingoni', -12.7872200, 45.1027800, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149048, 'Koungou', 'Koungou', 'Kongo,Koungou', -12.7336100, 45.2041700, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149049, 'Ouangani', 'Ouangani', 'Ouangani', -12.8463900, 45.1361100, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149050, 'Chiconi', 'Chiconi', 'Chiconi', -12.8333300, 45.1105600, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149051, 'Sada', 'Sada', 'Sada', -12.8505500, 45.1020500, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149052, 'Bandrélé', 'Bandrele', 'Bandrele,Bandrélé', -12.9127600, 45.1925600, 'YT', '2017-01-11', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149053, 'Chirongui', 'Chirongui', 'Chirongui', -12.9319400, 45.1483300, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149054, 'Bouéni', 'Boueni', 'Boueni,Bouéni', -12.9025000, 45.0761100, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149055, 'Kani Kéli', 'Kani Keli', 'Kani Keli,Kani Kéli', -12.9536100, 45.1033300, 'YT', '2012-02-07', 143);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149056, 'Roodepoort', 'Roodepoort', 'Roodepoort,Roodeport-Maraisburg', -26.1625000, 27.8725000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149057, 'Zoar', 'Zoar', 'Zoar', -33.4956000, 21.4437300, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149058, 'Zeerust', 'Zeerust', 'Zeerust', -25.5369500, 26.0751200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149059, 'Zastron', 'Zastron', 'Zastron', -30.3022500, 27.0839500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149060, 'Wolmaransstad', 'Wolmaransstad', 'Wolmaransstad,Wolmaranstad', -27.1974000, 25.9831100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149061, 'White River', 'White River', 'White River,Witrivier', -25.3317700, 31.0116600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149062, 'Witbank', 'Witbank', 'EMalahleni,Ehmalakhleni,Emalahleni,Gorad Ehmalakhleni,Vitbank,Vitbankas,Witbank,wei te ban ke,Вітбанк,Горад Эмалахлені,Эмалахлени,وٹبینک,威特班克', -25.8713300, 29.2332300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149063, 'Winburg', 'Winburg', 'Winburg', -28.5180500, 27.0093300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149064, 'Willowmore', 'Willowmore', '', -33.2926500, 23.4895400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149065, 'Williston', 'Williston', 'Williston', -31.3404800, 20.9154400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149066, 'Whittlesea', 'Whittlesea', 'Whittlesea', -32.1758800, 26.8243700, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149067, 'Westonaria', 'Westonaria', 'Vestonarija,Westonaria,Вестонария', -26.3190500, 27.6486000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149068, 'Wesselsbron', 'Wesselsbron', 'Wesselsbron', -27.8549000, 26.3658300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149069, 'Welkom', 'Welkom', 'Velkom,Velkomas,WEL,Welkom,u~erukomu,wei er ke mu,Велком,Վելկոմ,ウェルコム,韋爾科姆', -27.9774200, 26.7350600, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149070, 'Wartburg', 'Wartburg', 'Wartburg', -29.4318400, 30.5756700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149071, 'Warrenton', 'Warrenton', 'Warrenton', -28.1139600, 24.8475300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149072, 'Warmbaths', 'Warmbaths', 'Warmbad,Warmbaths', -24.8833300, 28.2833300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149073, 'Arniston', 'Arniston', 'Arniston,Waenhuiskrans', -34.6673900, 20.2308600, 'ZA', '2016-05-01', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149074, 'Vryheid', 'Vryheid', 'VYD,Vryheid', -27.7695200, 30.7916500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149075, 'Vryburg', 'Vryburg', 'Frejburg,Frejburga,VRU,Vryburg,fu lei bao,Фрейбург,Фрейбурга,弗雷堡', -26.9565900, 24.7284000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149076, 'Vredefort', 'Vredefort', 'Vredefort', -27.0080500, 27.3646000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149077, 'Vrede', 'Vrede', 'Vrede', -27.4257300, 29.1658500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149078, 'Volksrust', 'Volksrust', 'Volkrust,Volksrust', -27.3654100, 29.8817500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149079, 'Virginia', 'Virginia', 'Virdzhinija,Virginia,Вирджиния', -28.1039100, 26.8659300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149080, 'Villiers', 'Villiers', 'Villiers', -27.0302600, 28.6006100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149081, 'Viljoenskroon', 'Viljoenskroon', 'Viljoenskroon', -27.2084100, 26.9485500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149082, 'Victoria West', 'Victoria West', 'Victoria West,Victoria-Wes', -31.4036400, 23.1146100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149083, 'Vereeniging', 'Vereeniging', 'Feriniging,Ferinikhing,Vereeniging,Vereniging,Verenigingas,ferinihingu,fu li ni xin,peleinihing,wrynygyng,Веренигинг,Феринихинг,Ферінігінг,ورینیگینگ,フェリーニヒング,弗里尼欣,페레이니힝', -26.6731300, 27.9261500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149084, 'Ventersdorp', 'Ventersdorp', 'Ventersdorp', -26.3140100, 26.8222300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149085, 'Ventersburg', 'Ventersburg', 'Ventersburg', -28.0856100, 27.1381400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149086, 'Vanderbijlpark', 'Vanderbijlpark', 'Fanderbajpark,Fanderbejlpark,Vanderbijlpark,fan de bai er pa ke,fandrbyjlbark,phandarabilaparka,wandrbjlpark,wndrbyjlprk,Фандербајпарк,Фандербейлпарк,فاندربيجلبارك,واندربجلپارک,وندربیجلپرک,फांडरबीलपार्क,范德拜爾帕克', -26.7117100, 27.8379500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149087, 'Utrecht', 'Utrecht', 'Utrecht', -27.6586200, 30.3216600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149088, 'Upington', 'Upington', 'Apington,UTN,Upington,eopingteon,wu ping tong,Апингтон,烏平通,어핑턴', -28.4477600, 21.2561200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149089, 'Mthatha', 'Mthatha', 'Mthatha,UTT,Umtata,umutata,wu mu ta ta,Умтата,متھاتھا,ウムタタ,烏姆塔塔', -31.5889300, 28.7844300, 'ZA', '2015-04-24', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149090, 'Umkomaas', 'Umkomaas', 'Umkomaas', -30.2067400, 30.7977600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149091, 'Ulundi', 'Ulundi', 'Owlundi,ULD,Ulundi,ullundi,urundi,wu lun di,Улунди,Улунді,Ուլունդի,ウルンディ,烏倫迪,울룬디', -28.3352300, 31.4161700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149092, 'Uitenhage', 'Uitenhage', 'Ehjtenkhakhe,Ejtenkhakhe,Jutunkhakh,Uitenhage,awytnhag,oitenhahe,Ейтенхахе,Эйтенхахе,Ютънхах,اویتنهاگ,オイテンハーヘ', -33.7575700, 25.3971000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149093, 'Tzaneen', 'Tzaneen', 'LTA,Tzaneen,cha nen,zanyn,Тзанеен,زانین,察嫩', -23.8332200, 30.1635100, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149094, 'Tugela Ferry', 'Tugela Ferry', 'Tugela Ferry', -28.7464900, 30.4512600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149095, 'Trompsburg', 'Trompsburg', 'Trompsburg', -30.0336300, 25.7804100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149096, 'Thulamahashi', 'Thulamahashi', '', -24.7245900, 31.1993900, 'ZA', '2011-04-19', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149097, 'Thohoyandou', 'Thohoyandou', 'THY,Thohoyandou,Thohoyanḓou,Tkhokhojandou,suo he yan du,Тхохояндоу,تھوہویانڈو,索赫燕杜', -22.9456400, 30.4849700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149098, 'Theunissen', 'Theunissen', 'Tenissen,Theunissen,Тениссен', -28.4109800, 26.7010700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149099, 'Thabazimbi', 'Thabazimbi', 'Thabazimbi', -24.5916500, 27.4115500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149100, 'Thaba Nchu', 'Thaba Nchu', 'TCU,Thaba Nchu,Thabantsjoe', -29.2093200, 26.8389800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149101, 'Tembisa', 'Tembisa', 'Tembisa', -25.9963600, 28.2268000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149102, 'Taung', 'Taung', 'Taung,Taungs', -27.5311300, 24.7865900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149103, 'Tarkastad', 'Tarkastad', 'Tarkastad', -32.0089300, 26.2593500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149104, 'Swellendam', 'Swellendam', 'Republiken Swellendam,Shvelendam,Svellendam,Swellendam,si wei lun dan,Свеллендам,Швелендам,斯韋倫丹', -34.0226200, 20.4417100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149105, 'Sundumbili', 'Sundumbili', '', -29.1337100, 31.3975200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149106, 'Stutterheim', 'Stutterheim', 'Stutterheim', -32.5707600, 27.4239600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149107, 'Stilfontein', 'Stilfontein', 'Stilfontein', -26.8449300, 26.7682900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149108, 'Stanger', 'Stanger', 'KwaDukuza,Stanger,Stanger Station', -29.3281600, 31.2895400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149109, 'Standerton', 'Standerton', 'Standerston,Standerton', -26.9336600, 29.2415200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149110, 'Springs', 'Springs', 'Springs', -26.2500000, 28.4000000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149111, 'Soweto', 'Soweto', 'Mpanzaville,Souehto,Soueto,Sovetas,Soveto,Soweto,sou~eto,soweto,suo wei tuo,swwtw,swytw,Σοβέτο,Совето,Соуэто,סווטו,سويتو,სოვეტო,ソウェト,索韦托,소웨토', -26.2678100, 27.8584900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149112, 'Somerset East', 'Somerset East', 'Somerset East,Somerset-Oos', -32.7217300, 25.5880400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149113, 'Siyabuswa', 'Siyabuswa', 'Siyabuswa', -25.1131900, 29.0445400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149114, 'Senekal', 'Senekal', 'Senekal', -28.3197100, 27.6208200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149115, 'Secunda', 'Secunda', 'Secunda,Sekunda,ZEC,Секунда', -26.5500000, 29.1666700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149116, 'Scottburgh', 'Scottburgh', 'Scottburg,Scottburgh,Scottsburgh', -30.2866600, 30.7531600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149117, 'Schweizer-Reneke', 'Schweizer-Reneke', 'Schweizer-Reineke,Schweizer-Reneke', -27.1887100, 25.3293100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149118, 'Sasolburg', 'Sasolburg', 'Sasolburg', -26.8135800, 27.8169500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149119, 'Rustenburg', 'Rustenburg', 'Restenberha,Rjustenburg,Rustemburg,Rustemburgo,Rustenburg,Rustenburgas,lei si teng bao,luseutenbeogeu,rastnbrg,rstnbwrg,rus then beirk,rustenabarga,rusutenburuku,rwstnbrgh,Рустенбург,Рюстенбург,רסטנבורג,راستنبرگ,رسٹنبرگ,روستنبرغ,روسٹنبرگ,रुस्टेनबर्ग,รุสเทนเบิร์ก,ሩስተንበርግ,ルステンブルク,勒斯滕堡,루스텐버그', -25.6675600, 27.2420800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149120, 'Riversdale', 'Riversdale', 'Riversdal,Riversdale', -34.0934500, 21.2572500, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149121, 'Ritchie', 'Ritchie', 'Ritchie', -29.0380100, 24.6027800, 'ZA', '2014-04-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149122, 'Richmond', 'Richmond', 'Richmond', -29.8719600, 30.2723500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149123, 'Richards Bay', 'Richards Bay', 'RCB,Ricardusbaia,Richards Bay,Richards Bej,Richards-Bej,Richardsbaai,Ричардс Беј,Ричардс-Бей', -28.7830100, 32.0376800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149124, 'Reitz', 'Reitz', 'Reitz', -27.8013800, 28.4272600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149125, 'Randfontein', 'Randfontein', 'Randfontejn,lan de fang tan,Рандфонтейн,蘭德方坦', -26.1844000, 27.7020300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149126, 'Qumbu', 'Qumbu', '', -31.1630400, 28.8705600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149127, 'Queenstown', 'Queenstown', 'EKomani,Kuinstaun,Kvinstaun,Queenstown,UTW,kun shi dui,Квинстаун,Куинстаун,昆士敦', -31.8975600, 26.8753300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149128, 'Queensdale', 'Queensdale', '', -31.8710100, 26.9786200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149129, 'Prince Albert', 'Prince Albert', 'Prince Albert,Prins Albert', -33.2247600, 22.0267300, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149130, 'Prieska', 'Prieska', 'PRK,Prieska', -29.6680300, 22.7425100, 'ZA', '2014-11-08', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149131, 'Pretoria', 'Pretoria', 'E-Pitoli,Gorad Prehtoryja,IPitoli,PRY,Pitoli,Praetoria,Pretori,Pretoria,Pretoria/Pole tou Akroteriou,Pretoriae,Pretorii,Pretorija,Pretorio,Pretoriya,Pretoriye,Pretoriä,Pretoría,Pretòria,Pretória,Prétoriye,Pta,Tshwane,bi lei tuo li ya,brytwrya,peulitolia,phri thx reiy,pirittoriya,pritori''a,pritoriya,pritteariya,prtwrya,prtwryh,pu li tuo li ya,puretoria,Πρετόρια,Πρετόρια/Πόλη του Ακρωτηρίου,Горад Прэторыя,Претори,Претория,Преторија,Преторія,Պրետորիա,פרטוריה,بريتوريا,پرتوریا,پریٹوریا,پرێتۆریا,प्रिटोरिया,ਪ੍ਰਿਟੋਰੀਆ,பிரிட்டோரியா,ప్రిటోరియా,പ്രിട്ടോറിയ,พริทอเรีย,ཕི་རི་ཐོ་རི་ཡ།,პრეტორია,ፕሪቶሪያ,プレトリア,普利托里亞,比勒陀利亞,프리토리아', -25.7448600, 28.1878300, 'ZA', '2016-07-17', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149132, 'Mokopane', 'Mokopane', 'Mokopane,Potgietersrus,Potgietersrust,Potgitersrus,mo ke pa nei,Мокопане,Потгитерсрус,莫科帕內', -24.1943600, 29.0097400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149133, 'Potchefstroom', 'Potchefstroom', 'PCF,Pochefstrum,Potchefstroom,Potchefstrum,bo qie fu si te lu mu,peaccephestrum,pocephastruma,pochefusutorumu,pochepeuseuteulom,Потчефструм,Почефструм,पॉचेफस्ट्रूम,പൊച്ചെഫെസ്ട്രൂം,ポチェフストルーム,波切夫斯特魯姆,포체프스트롬', -26.7166700, 27.1000000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149134, 'Postmasburg', 'Postmasburg', 'Postmasburg', -28.3339200, 23.0654100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149135, 'Port Shepstone', 'Port Shepstone', 'Port Shepstone,Port-Shepston,xie pu si dui gang,Порт-Шепстон,謝普斯敦港', -30.7413700, 30.4549900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149136, 'Port Saint John’s', 'Port Saint John''s', 'JOH,Port Saint John''s,Port Saint John’s,Umzimvubu', -31.6229100, 29.5447700, 'ZA', '2017-07-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149137, 'Port Elizabeth', 'Port Elizabeth', 'Gorad Port-Ehlizabet,IBhayi,Ibhayi,PLZ,Port Elisabeth,Port Elizabet,Port Elizabetas,Port Elizabeth,Port Elizampeth,Port-Ehlizabet,Port-Elizabet,Portelizabeta,Porto Elizabeth,Portus Elisabethae,Puerto Elizabeth,bwrt alyzabyth,phxrt xe li sabeth,porta elijhabetha,porta elizabetha,poteuellijabeseu,pwrt alyzabt,yi li sha bai gang,Πορτ Ελίζαμπεθ,Горад Порт-Элізабет,Порт Елизабет,Порт-Елізабет,Порт-Элизабет,פורט אליזבת,بورت إليزابيث,پورت الیزابت,پورٹ الزبتھ,पोर्ट एलिज़ाबेथ,पोर्ट एलिझाबेथ,พอร์ตเอลิซาเบท,პორტ-ელიზაბეთი,ፖርት ኤልሳቤጥ,ポート・エリザベス,伊莉莎白港,포트엘리자베스', -33.9179900, 25.5700700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149138, 'Port Alfred', 'Port Alfred', 'AFD,Kowie,Port Alfred,Port-Al''fred,The Kowie,ai er fu lei de gang,Порт-Альфред,艾尔弗雷德港', -33.5860100, 26.8832900, 'ZA', '2016-01-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149139, 'Pongola', 'Pongola', 'Pongola', -27.3780800, 31.6190400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149140, 'Plettenberg Bay', 'Plettenberg Bay', 'Formosa,PBZ,Plettenberg,Plettenberg Bay,Plettenbergbaai', -34.0527400, 23.3716000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149141, 'Piet Retief', 'Piet Retief', 'Piet Retief', -27.0070600, 30.8132300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149142, 'Polokwane', 'Polokwane', 'Gorad Palakvaneh,PTG,Petriburgum,Pietersburg,Polokouane,Polokvane,Polokvanė,Polokwane,bo luo ke wa ni,bwlwkwan,pho lokhe wn,polakvani,pollokwane,polokvane,porokuwane,pwlwkwyn,Πολοκουάνε,Горад Палакванэ,Полокване,פולוקוואנה,بولوكوان,پولوکوانے,پولوکوین,पोलक्वानी,पोलोक्वाने,โพโลเควน,ፖሎክዋኔ,ポロクワネ,波羅克瓦尼,폴로콰네', -23.9044900, 29.4688500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149143, 'Pietermaritzburg', 'Pietermaritzburg', 'Gorad Pitehrmarycburg,Maritzburg,Mokokotlofo,PZB,Petromaritzburgum,Pietermaritsburg,Pietermaritzburg,Pitermaricburg,Pitermaricburgas,Piturmaricburg,bi de ma li ci bao,bytrmarytzbrgh,pi texr ma rits beirk,pitamarittsubagu,pitaramairitsabarga,pitaramaritjhabarga,piteomalicheubeogeu,pytrmarytsbrg,Горад Пітэрмарыцбург,Питермарицбург,Питърмарицбург,Пітермаріцбург,بيترماريتزبرغ,پیترماریتسبرگ,پیٹرماریٹزبرگ,پیٹرومیرٹبرگ,पीटरमारित्झबर्ग,पीटरमैरिट्सबर्ग,ปีเตอร์มาริตซ์เบิร์ก,ピーターマリッツバーグ,彼得马里茨堡,피터마리츠버그', -29.6167900, 30.3927800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149144, 'Phuthaditjhaba', 'Phuthaditjhaba', 'Phutaditjhaba,Phuthaditjhaba', -28.5242300, 28.8158200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149145, 'Phalaborwa', 'Phalaborwa', 'PHW,Palabora,Palaborva,Phalaborwa,Pkhalaborva,pa la bo lu wa,Палаборва,Пхалаборва,帕拉博魯瓦', -23.9429900, 31.1410700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149146, 'Petrusville', 'Petrusville', 'Petrusville', -30.0811300, 24.6593000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149147, 'Peddie', 'Peddie', '', -33.2005900, 27.1138500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149148, 'Paulpietersburg', 'Paulpietersburg', 'Paulpietersburg', -27.4242600, 30.8168900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149149, 'Parys', 'Parys', 'Paris,Parys,Парис', -26.9033000, 27.4572700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149150, 'Pampierstad', 'Pampierstad', 'Pampierstad,Pampierstat', -27.7832400, 24.6876800, 'ZA', '2016-07-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149151, 'Oudtshoorn', 'Oudtshoorn', 'OUH,Oudskhorn,Oudtshoorn,ao ci hu en,Оудсхорн,奧茨胡恩', -33.6004700, 22.1995500, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149152, 'Orkney', 'Orkney', 'Eastleigh,Orknejskie,Orkney,Оркнейские', -26.9802300, 26.6727200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149153, 'Orania', 'Orania', 'Orani,Orania,Oranija,Orânia,Орани,Орания,Оранія', -29.8138100, 24.4120500, 'ZA', '2017-04-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149154, 'Orange Farm', 'Orange Farm', '', -26.4833300, 27.8666700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149155, 'Modimolle', 'Modimolle', 'Modimolle,Nylstroom', -24.7000000, 28.4000000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149156, 'Noupoort', 'Noupoort', 'Naauwpoort,Noupoort', -31.1873600, 24.9499100, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149157, 'Nongoma', 'Nongoma', 'Nongoma', -27.9096800, 31.6481700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149158, 'Nkowakowa', 'Nkowakowa', 'Nkowakowa', -23.8878200, 30.2870800, 'ZA', '2014-04-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149159, 'Nkandla', 'Nkandla', 'Nkandhla,Nkandla', -28.6207000, 31.0906700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149160, 'Nigel', 'Nigel', 'Najdzhel,Nigel,Найджел', -26.4313800, 28.4771300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149161, 'Newcastle', 'Newcastle', 'NCS,Newcastle', -27.7579600, 29.9318000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149162, 'Nelspruit', 'Nelspruit', 'Mbombela,NLP,Naspoti,Nel''sprjujt,Nelspreyt,Nelsprojt,Nelspruit,mbombela,nei er si pu lei te,nels pirt,nelsapru''ita,nelseupeulu-iteu,nerusupuroito,nlsprwyt,nlspryyt,nylsbrwyt,nylsprwyt,Мбомбела,Нелспройт,Нелспруит,Нельспрюйт,נלספרייט,نلسپرویت,نيلسبرويت,نیلسپرویت,नेल्सप्रूइत,म्बोम्बेला,เนลสไปรต์,ኔልስፕሩዊት,ネルスプロイト,内尔斯普雷特,넬스프루이트', -25.4744800, 30.9703300, 'ZA', '2013-03-02', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149163, 'Ndwedwe', 'Ndwedwe', 'Ndwedwe,Ndwedwe Magistracy', -29.5168600, 30.9268700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149164, 'Mutale', 'Mutale', '', -22.4697200, 30.8753300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149165, 'Muldersdriseloop', 'Muldersdriseloop', '', -26.0367300, 27.8379800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149166, 'Mtubatuba', 'Mtubatuba', 'DUK,Mtubatuba', -28.4178900, 32.1848300, 'ZA', '2017-07-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149167, 'Mpumalanga', 'Mpumalanga', 'Mpumalanga', -29.8129200, 30.6364600, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149168, 'Mpophomeni', 'Mpophomeni', 'Mpophomeni', -29.5682200, 30.1861800, 'ZA', '2014-04-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149169, 'Mount Frere', 'Mount Frere', 'Kwabhaca,Mount Frere', -30.9017300, 28.9923800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149170, 'Mount Ayliff', 'Mount Ayliff', 'Maxesibeni,Mount Alyff,Mount Ayliff', -30.8082100, 29.3664400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149171, 'Mossel Bay', 'Mossel Bay', 'MZY,Mossel Bay,Mossel-Bej,Mosselbaai,Mosul Bej,Teluk Mossel,mo sai er bei,Моссел-Бей,Мосъл Бей,莫塞爾貝', -34.1830700, 22.1460500, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149172, 'Mooirivier', 'Mooirivier', 'Mooi River,Mooirivier', -29.2082400, 29.9946000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149173, 'Mondlo', 'Mondlo', 'Mondlo', -27.9829900, 30.7176900, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149174, 'Molteno', 'Molteno', 'Molteno', -31.3967500, 26.3624600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149175, 'Mogwase', 'Mogwase', '', -25.2774800, 27.2160500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149176, 'Modderfontein', 'Modderfontein', '', -26.0890900, 28.1653400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149177, 'Mmabatho', 'Mmabatho', 'MBD,Mabatho,Mbabatho,Mmabatho', -25.8500000, 25.6333300, 'ZA', '2013-05-08', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149178, 'Mkuze', 'Mkuze', 'MZQ,Mkusi,Mkuze,Mkuzi', -27.6164100, 32.0386100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149179, 'Middelburg', 'Middelburg', 'Middelburg', -31.4928500, 25.0063300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149180, 'Middelburg', 'Middelburg', 'Middelberg,Middelburg,mi de er bao,Мидделбург,米德爾堡', -25.7750700, 29.4648200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149181, 'Meyerton', 'Meyerton', 'Meyerton', -26.5598700, 28.0195000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149182, 'Melmoth', 'Melmoth', 'Melmoth', -28.5866400, 31.3978300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149183, 'Matatiele', 'Matatiele', 'Matatiele', -30.3435700, 28.8116100, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149184, 'Marquard', 'Marquard', 'Marquard', -28.6644900, 27.4304800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149185, 'Margate', 'Margate', 'Berkleys,MGH,Margate,Margate No. 4', -30.8636000, 30.3705200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149186, 'Marble Hall', 'Marble Hall', 'Marble Hall', -24.9662700, 29.2906800, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149187, 'Mankoeng', 'Mankoeng', '', -23.9000000, 29.8166700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149188, 'Makapanstad', 'Makapanstad', 'Makapaanstad,Makapaanstat,Makapanstad', -25.2437300, 28.1262000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149189, 'Mahikeng', 'Mahikeng', 'Mafeking,Mafikeng,Mafikengas,Mahikeng,mafikengu,Мафикенг,マフィケング', -25.8652200, 25.6442100, 'ZA', '2013-06-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149190, 'Maclear', 'Maclear', 'Maclear', -31.0710400, 28.3518300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149191, 'Mabopane', 'Mabopane', 'Mabopane', -25.4976800, 28.1006500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149192, 'Lydenburg', 'Lydenburg', 'Lydenburg,Mashishing,lai deng bao,raidenbagu,Машишинг,ライデンバーグ,萊登堡', -25.0959800, 30.4439300, 'ZA', '2014-11-08', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149193, 'Louis Trichardt', 'Louis Trichardt', 'LCD,Louis Trichardt,Luis-Trichard,lu yi te li ha te,Луис-Тричард,لوئی ٹرشارٹ,ルイス・トリハート,路易特里哈特', -23.0438500, 29.9031900, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149194, 'Lichtenburg', 'Lichtenburg', 'Lichtenburg,Likhtenburge,Лихтенбурге', -26.1520000, 26.1596800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149195, 'Libode', 'Libode', 'Libode', -31.5433100, 29.0164000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149196, 'Lebowakgomo', 'Lebowakgomo', 'Lebowakgomo', -24.2000000, 29.5000000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149197, 'Laingsburg', 'Laingsburg', 'Laingsburg', -33.1949500, 20.8587200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149198, 'Ladysmith', 'Ladysmith', 'LAY,Ladysmith', -28.5587400, 29.7789600, 'ZA', '2014-11-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149199, 'Lady Grey', 'Lady Grey', 'Lady Grey', -30.7108400, 27.2161300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149200, 'Lady Frere', 'Lady Frere', '', -31.7031200, 27.2329000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149201, 'Ladybrand', 'Ladybrand', 'Ladybrand', -29.1944800, 27.4573900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149202, 'Ladismith', 'Ladismith', 'Ladismith', -33.4933100, 21.2675500, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149203, 'KwaMbonambi', 'KwaMbonambi', '', -28.5982700, 32.0894000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149204, 'Kutloanong', 'Kutloanong', '', -27.8333300, 26.7500000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149205, 'Kuruman', 'Kuruman', 'KMH,Kuruman,khuru man,ku lu man,Куруман,คุรุมาน,庫魯曼', -27.4524000, 23.4324600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149206, 'Kruisfontein', 'Kruisfontein', 'Kruisfontein', -34.0033300, 24.7314200, 'ZA', '2016-03-10', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149207, 'Krugersdorp', 'Krugersdorp', 'Krjugersdorp,Krjugersdorpa,Krugersdorp,Krugersdorpas,ke lu ge si duo pu,Крюгерсдорп,Крюгерсдорпа,克魯格斯多普', -26.0857700, 27.7751500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149208, 'Kroonstad', 'Kroonstad', 'Kroonstad,Krunstad,ke long si ta de,krwnstad,Крунстад,کرونستاد,克龍斯塔德', -27.6503600, 27.2348800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149209, 'Kriel', 'Kriel', 'Kriel', -26.2739100, 29.2253000, 'ZA', '2016-03-10', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149210, 'Koster', 'Koster', 'Koster', -25.8630100, 26.8975600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149211, 'Koppies', 'Koppies', 'Kopjes,Koppies', -27.2417900, 27.5742200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149212, 'Komga', 'Komga', 'Komga,Komgha', -32.5770400, 27.8920000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149213, 'Komatipoort', 'Komatipoort', 'KOF,Komatipoort', -25.4332100, 31.9547800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149214, 'Kokstad', 'Kokstad', 'Kokstad', -30.5472300, 29.4241200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149215, 'Koffiefontein', 'Koffiefontein', 'Koffiefontein', -29.4066100, 25.0030900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149216, 'Knysna', 'Knysna', 'De Nysna,Knajsno,Knisna,Knysna,Najsna,ke ni si na,knysna,Книсна,Найсна,كنيسنا,克尼斯納', -34.0362700, 23.0471300, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149217, 'Klerksdorp', 'Klerksdorp', 'Gorad Klerksdorp,KXE,Klerksdorp,ke lai ke si duo pu,Горад Клерксдорп,Клерксдорп,克萊克斯多普', -26.8521300, 26.6667200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149218, 'Kirkwood', 'Kirkwood', 'Kirkwood', -33.3982900, 25.4427900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149219, 'Kimberley', 'Kimberley', 'Gorad Kimberli,KIM,Kimberley,Kimberli,Kimberlis,Kimburli,jin bo li,kimbarali,kimbeolli,kinbari,kmbrly  shmaly kyp,kymbrly,qymbrly,Горад Кімберлі,Кимберли,Кимбърли,Кімберлі,קימברלי,كيمبرلي,کمبرلی، شمالی کیپ,کمبرلے,کیمبرلی,किम्बरली,キンバリー,金伯利,킴벌리', -28.7322600, 24.7623200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149220, 'Kathu', 'Kathu', 'Kathu', -27.6956900, 23.0492900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149221, 'Kareedouw', 'Kareedouw', 'Kareedouw,Karreedouw', -33.9528000, 24.2905300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149222, 'Kakamas', 'Kakamas', 'Kakamas', -28.7734100, 20.6147000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149223, 'Jozini', 'Jozini', '', -27.4296000, 32.0665800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149224, 'Johannesburg', 'Johannesburg', 'EGoli,Giochanesmpournk,Gorad Joganesburg,IGoli,IJohannesburg,Ioannesburgum,JNB,Jo''anna,Joanesburgo,Joburg,Jog''annesburg,Jogannesburg,Johanesburgas,Johanesburgo,Johannesarborg,Johannesbourg,Johannesburg,Johannesburga,Johannesburgo,Johannesburgu,Jokhanesburg,Jokhanezburg,Jokhannesburg,J·ohanesbôrg,Jóhannesarborg,Xohanesburgo,Yohannesburg,Yohannesburq,Yohannésburg,Yok-hon-ni-su-pau,Yok-hon-nì-sṳ̂-páu,Yoxannesburg,cohannes beirk,iohanesburgi,johanisabaraga,johannesbarga,johansabarga,jokanasperk,jwhansbrgh,yohaneseubeogeu,yohanesuburugu,yue han nei si bao,yue han ni si bao,ywhnsbwrg,zhwhansbwrg,Γιοχάνεσμπουργκ,Јоханезбург,Јоханесбург,Горад Ёганесбург,Йоганнесбург,Йогьаннесбург,Йоханесбург,Йоханнесбург,Յոհաննեսբուրգ,יאהאנעסבורג,יוהנסבורג,جوهانسبرغ,جوہانسبرگ,جۆھانسبێرگ,ژوهانسبورگ,یوہانس برگ,जोहन्नेस्बर्ग,जोहान्सबर्ग,ਜੋਹਾਨਿਸਬਰਗ,ஜோகானஸ்பேர்க்,ജൊഹാനസ്‌ബർഗ്,โจฮันเนสเบิร์ก,ဂျိုဟန္နက်စဗတ်မြို့,იოჰანესბურგი,ጆሃንስበርግ,ヨハネスブルグ,約翰尼斯堡,约翰内斯堡,요하네스버그', -26.2022700, 28.0436300, 'ZA', '2015-06-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149225, 'Jeffrey’s Bay', 'Jeffrey''s Bay', 'Jeffrey''s Bay,Jeffreysbaai,Jeffrey’s Bay', -34.0504500, 24.9076800, 'ZA', '2015-12-14', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149226, 'Jansenville', 'Jansenville', '', -32.9430600, 24.6721800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149227, 'Jan Kempdorp', 'Jan Kempdorp', 'Andalusia,Jan Kemp,Jan Kempdorp', -27.9224600, 24.8305100, 'ZA', '2012-01-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149228, 'Jane Furse', 'Jane Furse', 'Jane Furse,Jane Furse Settlement', -24.7602100, 29.8699300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149229, 'Izingolweni', 'Izingolweni', 'Izingolweni,Zingolweni', -30.7840900, 30.1229400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149230, 'Ixopo', 'Ixopo', 'Ixopo', -30.1500000, 30.0833300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149231, 'Impendle', 'Impendle', 'Impendhle,Impendhle Location,Impendle,Mpendle', -29.6004900, 29.8656100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149232, 'Ilinge', 'Ilinge', '', -31.9767600, 27.0426700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149233, 'Howick', 'Howick', 'Howick', -29.4779500, 30.2305700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149234, 'Hopetown', 'Hopetown', 'Hopetown', -29.6246400, 24.0851800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149235, 'Hoopstad', 'Hoopstad', 'Hoopstad', -27.8327300, 25.9083300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149236, 'Hoedspruit', 'Hoedspruit', 'HDS,Hoedspruit', -24.3512200, 30.9533200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149237, 'Hluhluwe', 'Hluhluwe', 'HLW,Hluhluwe', -28.0189500, 32.2676200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149238, 'Hlabisa', 'Hlabisa', 'Hiabisa,Hlabisa', -28.1451900, 31.8771900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149239, 'Himeville', 'Himeville', 'Himeville', -29.7467500, 29.5136100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149240, 'Hennenman', 'Hennenman', 'Hennenman', -27.9765400, 27.0242300, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149241, 'Hendrina', 'Hendrina', 'Hendrina', -26.1588100, 29.7152800, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149242, 'Heilbron', 'Heilbron', 'Heilbron', -27.2811500, 27.9709000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149243, 'Heidelberg', 'Heidelberg', 'Gejdel''berg,Heidelberg,Heidelburg,Гейдельберг', -26.5047600, 28.3592100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149244, 'Hartswater', 'Hartswater', 'Hartswater', -27.7496400, 24.7971200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149245, 'Harrismith', 'Harrismith', '42nd Hill,Garrismit,HRS,Harrismith,Гаррисмит', -28.2727600, 29.1294600, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149246, 'Harding', 'Harding', 'Harding', -30.5764300, 29.8840100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149247, 'Groblershoop', 'Groblershoop', 'Groblershoop,Sternham', -28.8953100, 21.9837800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149248, 'Groblersdal', 'Groblersdal', 'Groblersdal', -25.1684300, 29.3941200, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149249, 'Greytown', 'Greytown', 'Greytown', -29.0641500, 30.5927900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149250, 'Grahamstown', 'Grahamstown', 'Grahamstad,Grahamstown,Grehkhehmstaun,IRhini,ge la han zhen,geuleieomseutaun,gurahamuzutaun,Грэхэмстаун,グラハムズタウン,格拉罕鎮,그레이엄스타운', -33.3042200, 26.5327600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149251, 'Graaff-Reinet', 'Graaff-Reinet', 'Graaf Reinet,Graaff Reinet,Graaff-Reinet,Khraff-Rejnet,ge la fu-li nei te,gurafu=raine,Храфф-Рейнет,グラーフ＝ライネ,格拉夫-里內特', -32.2521500, 24.5307500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149252, 'Glencoe', 'Glencoe', 'Glencoe', -28.1782700, 30.1470200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149253, 'Giyani', 'Giyani', 'GIY,Giyane,Giyani', -23.3024600, 30.7186800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149254, 'Germiston', 'Germiston', 'Dzhermiston,Germiston,jie mi si dun,Гермистон,Джермистон,Джермістон,جرمسٹن,傑米斯頓', -26.2348100, 28.1766500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149255, 'George', 'George', 'Dzhordzh,GRJ,George,jarj tavun,joji,qiao zhi,Джордж,ஜார்ஜ் டவுன்,ジョージ,喬治,조지', -33.9630000, 22.4617300, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149256, 'Ga-Rankuwa', 'Ga-Rankuwa', 'Ga-Rankuwa', -25.6169200, 27.9947100, 'ZA', '2012-01-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149257, 'Ganyesa', 'Ganyesa', 'Ganyesa,Genesa,Genyesa', -26.5961300, 24.1761200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149258, 'Ga-Kgapane', 'Ga-Kgapane', 'Ga-Kgapane,Gakgapane', -23.6437800, 30.2232400, 'ZA', '2013-03-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149259, 'Frankfort', 'Frankfort', '', -27.2788800, 28.4969600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149260, 'Fort Beaufort', 'Fort Beaufort', 'Fort Beaufort,Fort-Bofort,bo fu te gang,Форт-Бофорт,فورٹ بیوفورٹ,博福特港', -32.7747700, 26.6337600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149261, 'Fochville', 'Fochville', 'Fochville', -26.4886200, 27.4938700, 'ZA', '2012-01-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149262, 'Flagstaff', 'Flagstaff', 'Flagstaff,Siphaqeni', -31.0804200, 29.4952200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149263, 'Ficksburg', 'Ficksburg', 'FCB,Ficksburg,fei ke si bao,菲克斯堡', -28.8720000, 27.8750600, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149264, 'Estcourt', 'Estcourt', 'Estcourt,ai si te ke te,埃斯特科特', -29.0126900, 29.8661900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149265, 'eSikhawini', 'eSikhawini', 'Esikhawini Township,eSikhawini', -28.8709700, 31.8996100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149266, 'Eshowe', 'Eshowe', 'Eshowe', -28.8864900, 31.4699000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149267, 'Ermelo', 'Ermelo', 'Ehrmelo,Ermelo,ai er mo luo,Эрмело,埃爾默洛', -26.5333300, 29.9833300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149268, 'Empangeni', 'Empangeni', 'EMG,Empangeni', -28.7619700, 31.8932900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149269, 'eMbalenhle', 'eMbalenhle', 'eMbalenhle', -26.5333300, 29.0666700, 'ZA', '2014-04-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149270, 'Elliot', 'Elliot', 'Elliot', -31.3333300, 27.8500000, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149271, 'Ekuvukeni', 'Ekuvukeni', 'Ekuvukeni', -28.4675200, 30.1551300, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149272, 'Edenvale', 'Edenvale', 'Edenvale', -26.1409500, 28.1524700, 'ZA', '2017-01-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149273, 'East London', 'East London', 'Buffalo City,ELS,EMonti,East London,Gorad Ist-Londan,Ist-London,Istochni London,Iztochen London,Londinium Orientale,Oos Londen,Oos-Londen,Orient-Londono,Tung Lun-tun,Tûng Lùn-tûn,Yst Londonas,ayst lndn,dong lun dui,iseuteuleondeon,ista landana,Іст-Лондон,Горад Іст-Лондан,Източен Лондон,Ист-Лондон,Источни Лондон,איסט לונדון,إيست لندن,ایسٹ لندن,ईस्ट लंडन,イースト・ロンドン,東倫敦,이스트런던', -33.0152900, 27.9116200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149274, 'Durban', 'Durban', 'DUR,Durban,Durbana,Durbanas,Durbano,Durbanum,EThekwini,Gorad Durban,ITheku,Ntermpan,Port Natal,Thekong,daban,darabana,darban,darbana,de ban,de xr ban,deoban,die bin,drbn,durbani,dwrban,dyrban,tarpan,Ντέρμπαν,Горад Дурбан,Дурбан,Дърбан,Դուրբան,דרבן,دوربان,ديربان,ڈربن,डरबन,डर्बन,ਡਰਬਨ,டர்பன்,డర్బన్,ಡರ್ಬನ್,ഡർബൻ,เดอร์บัน,ဒါဘန်မြို့,დურბანი,ደርባን,ダーバン,德班,爹濱,더반', -29.8579000, 31.0292000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149275, 'Dundee', 'Dundee', 'Dandi,Dundee,Данди', -28.1667800, 30.2337100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149276, 'Duiwelskloof', 'Duiwelskloof', 'Duivelskloof,Duiwelskloof,Duweiskloof', -23.6933900, 30.1400200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149277, 'Driefontein', 'Driefontein', '', -27.0177000, 30.4497900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149278, 'Douglas', 'Douglas', 'Douglas', -29.0553100, 23.7743000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149279, 'Dordrecht', 'Dordrecht', 'Dordrecht', -31.3720000, 27.0487800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149280, 'Dewetsdorp', 'Dewetsdorp', 'Dewetsdorp', -29.5827400, 26.6651100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149281, 'De Rust', 'De Rust', 'De Rust', -33.4903500, 22.5352300, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148737, 'Daḩasuways', 'Dahasuways', 'Dahasuhiss,Dahasuways,Dahāsūhiss,Daḩasuways,Dha Sohis,dhswys,دحسويس', 15.7238900, 50.7294400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148738, 'Ash Shiḩr', 'Ash Shihr', 'Al-Shihr,Ash Shahar,Ash Shaḩar,Ash Shihr,Ash Shiḩr,Escier,Seer,Shihr,Shiḩr,alshhr,الشحر', 14.7602600, 49.6053700, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148739, 'Al Ghaylah', 'Al Ghaylah', 'Al Ghaylah,alghylt,الغيلة', 14.5958300, 45.5833300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148740, 'Judaydah', 'Judaydah', 'Al Judaydah,Judaydah,Suq al Jadidah,Sūq al Jadīdah,aljdydt,jdydt,swq aljdydt,الجديدة,جديدة,سوق الجديدة', 15.0751200, 45.2996200, 'YE', '2015-02-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148741, 'Ḑawrān', 'Dawran', 'Dawran,Zuran,Z̧ūrān,dwran,ضوران,Ḑawrān', 13.7743600, 44.4419600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148742, 'Najd al Jumā‘ī', 'Najd al Juma`i', 'Najd al Juma`i,Najd al Juma`iy,Najd al Jumā‘iy,Najd al Jumā‘ī,نجد الجماعي', 13.9158100, 44.3241400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148743, 'Z̧almah al ‘Ulyā', 'Zalmah al `Ulya', 'Zalmah al `Ulya,Zalmat Hubaysh,Zalmat Ḩubaysh,Zulmah,Z̧almah al ‘Ulyā,Z̧almat Ḩubaysh,Z̧ulmah,zlmt hbysh,ظلمة العليا,ظلمة حبيش', 14.1023000, 44.0940400, 'YE', '2015-08-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148744, 'Sūq ar Rubū‘', 'Suq ar Rubu`', 'Ar Rubu` Bani Suwayd,Ar Rubū‘ Banī Suwayd,Rub` `Ufmah,Rub` `Utmah,Rubu` `Utmah,Rubū‘ ‘Utmah,Rub‘ ‘Ufmah,Rub‘ ‘Utmah,Suq ar Rubu`,Sūq ar Rubū‘,ربع عتمة,سوق الربوع', 14.5115500, 44.0151100, 'YE', '2015-08-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148745, 'Ash Shuqayrah', 'Ash Shuqayrah', 'Ash Shuqayra'',Ash Shuqayrah,Ash Shuqayrā’,At Turays,alshqyrt,altrys,التريس,الشقيرة', 13.1345200, 43.7863600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148746, 'Mashra‘ah', 'Mashra`ah', 'Al Masaliyah,Al Masaliyah Mashra`ah,Al Masālīyah,Al Masālīyah Mashra‘ah,Mashra`ah,Mashra‘ah,مشرعة', 13.5323500, 43.9958700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148747, 'Ar Rawnah', 'Ar Rawnah', 'Ar Rawnah,alrwnt,الرونة', 13.7563800, 43.8028600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148748, 'Ar Ramādī', 'Ar Ramadi', 'Ar Ramadi,Ar Ramādī,alrmady,الرمادي', 13.9564100, 43.7845700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148749, 'Al Aḩad', 'Al Ahad', 'Al Ahad,Al Aḩad,alahd,الأحد', 14.2583300, 43.6416700, 'YE', '2014-06-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148750, 'Aḑ Ḑil‘', 'Ad Dil`', 'Ad Dil`,Aḑ Ḑil‘,الضلع', 14.6719900, 43.8182700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148751, 'Sūq Şirwāḩ', 'Suq Sirwah', 'As Suq,As Sūq,Markaz Sirwah,Markaz Şirwāh,Sarwah,Sarwāḩ,Sirwah,Suq Sirwah,Sūq Şirwāḩ,alswq,mrkz srwah,srwah,swq srwah,Şarwāḩ,Şirwāḩ,السوق,سوق صرواح,صرواح,مركز صرواح', 15.4493300, 45.0189100, 'YE', '2015-02-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148752, 'Majzar', 'Majzar', 'Majzar,mjzr,مجزر', 15.8500000, 44.7750000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148753, 'Bidbadah', 'Bidbadah', 'Bid Bidah,Bidbadah,bdbdt,بدبدة', 15.4250000, 44.7000000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148754, 'Matwaḩ', 'Matwah', 'Matwah,Matwaḩ,mtwh,متوح', 15.0676000, 43.6421300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148755, 'Şuwayr', 'Suwayr', 'Suwayr,swyr,Şuwayr,صوير', 16.1818000, 43.6098600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148756, 'Waḑarah', 'Wadarah', 'Wadarah,Wazrah,Waz̧rah,Waḑarah,wdrt,وضرة', 15.7107300, 43.4832100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148757, 'Al Mirwāḩ', 'Al Mirwah', 'Al Marawih,Al Marāwiḩ,Al Mirwah,Al Mirwāḩ,almrwah,المرواح', 15.4722300, 43.4293900, 'YE', '2016-01-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148758, 'Sūq Shamar', 'Suq Shamar', 'Suq Shamar,Sūq Shamar,swq shmr,سوق شمر', 15.8850000, 43.3680600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148759, 'Mustabā’', 'Mustaba''', 'Mustaba'',Mustabā’,Suq Khamis Mustaba,Sūq Khamīs Mustabā,مستباء', 16.2281600, 43.2489500, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148760, 'An Naz̧īr', 'An Nazir', 'An Nadir,An Nazir,An Naz̧īr,An Naḑīr,Razih,Rāziḩ,alnzyr,النظير', 16.9091600, 43.2622600, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148761, 'Aţ Ţawīlah', 'At Tawilah', 'At Tawilah,Aţ Ţawīlah,Et-Tawilah,Eṭ-Ṭawīlah,Tawila,Tawilah,Tawīlah,Tuwiia,altwylt,الطويلة', 15.4938900, 43.7477800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148762, 'Zinjibār', 'Zinjibar', 'Az Zanjabar,Az Zanjabār,Zanjibar,Zinjibar,Zinjibār,Zmjibar,znjbar,زنجبار', 13.1287100, 45.3807300, 'YE', '2013-08-08', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148763, 'Zarājah', 'Zarajah', 'Garaaz,Zaraja,Zarajah,Zarājah,zrajt,زراجة', 14.8669200, 44.3786800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148764, 'Az Zāhir', 'Az Zahir', 'Az Zahir,Az Zāhir,Zahir,alzahr,الزاهر', 13.9666700, 45.4833300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148765, 'Zabīd', 'Zabid', 'Zabid,Zabīd,Zebid,zbyd,Забид,زبيد', 14.1951000, 43.3151800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148766, 'Yufrus', 'Yufrus', 'Yafrus,Yifrus,Yufrus,yfrs,يفرس', 13.4552900, 43.9470400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148767, 'Yarīm', 'Yarim', 'Jarim,Yarim,Yarīm,Yerim,yrym,Ярим,يريم', 14.2980400, 44.3779500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148768, 'Washḩah', 'Washhah', 'Markaz al Muqawamah,Markaz al Muqāwamah,Washhah,Washḩah,wshht,وشحة', 16.3077400, 43.4106600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148769, 'Wa‘lān', 'Wa`lan', 'Wa`lan,Walan,Walān,Wa‘lān,وعلان', 15.0702100, 44.2764100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148770, 'Dhī Jalāl', 'Dhi Jalal', 'Dhi Jalal,Dhī Jalāl,Wa`lan,Wa‘lān,dhy jlal,ذي جلال', 13.6237800, 44.7075400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148771, '‘Usaylān', '`Usaylan', '`Asailan,`Usaylan,عسيلان,‘Asailān,‘Usaylān', 15.0320100, 45.8283200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148772, '‘Ubāl', '`Ubal', 'Abal,Obal,`Ubal,عبال,‘Ubāl', 14.9880800, 43.5444400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148773, 'Thamūd', 'Thamud', 'Thamud,Thamūd,thmwd,ثمود', 17.2924500, 49.9194700, 'YE', '2017-05-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148774, 'Tarīm', 'Tarim', 'Tarim,Tarīm,Terim,Terīm,trym,تريم', 16.0569400, 48.9988900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148775, 'Ta‘izz', 'Ta`izz', 'TAI,Ta''izz,Ta`izz,Taiz,Taizz,Ta‘izz,Таиз,تعز', 13.5795200, 44.0209100, 'YE', '2017-01-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148776, 'As Suwaydā', 'As Suwayda', 'As Suwayda,As Suwayda'',As Suwaydā,As Suwaydā’,Suwayda,Suwaydā,alswyda,السويدا,السويداء', 13.7869400, 45.2304000, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148777, 'Al ‘Anān', 'Al `Anan', 'Al `Anan,Al ‘Anān,Bart al `Inan,Barţ al ‘Inān,Suq al Ghinan,Suq al `Inan,Sūq al Ghinān,Sūq al ‘Inān,العنان,برط العنان,سوق العنان', 16.7218900, 44.3125200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148778, 'Abs', 'Abs', 'Abs,EAB,Mutayyin,Suq `Abs,Sūq ‘Abs,`Abs,عبس,‘Abs', 16.0029500, 43.1972500, 'YE', '2017-04-24', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148779, 'Şīf', 'Sif', 'Sif,syf,Şīf,صيف', 15.3138900, 48.3300000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148780, 'Shiḩan as Suflá', 'Shihan as Sufla', 'Shihan,Shihan as Sufla,Shiḩan,Shiḩan as Suflá,shhn alsfly,شحن السفلى', 17.7699900, 52.4892500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148781, 'Shibām', 'Shibam', 'Shibam,Shibām,shbam,شبام', 15.5094300, 43.9044500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148782, 'Ash Sharyah', 'Ash Sharyah', 'Ash Sharyah,Sharyah,alshryt,الشرية', 14.3565900, 45.0224400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148783, 'Sharas', 'Sharas', 'Sharas,Suq Shiras,Sūq Shiras,shrs,شرس', 15.7123300, 43.6492500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148784, 'Shahārat al Ghīs', 'Shaharat al Ghis', 'Hajera,Sahara,Shahara,Shaharah,Shaharat al Ghis,Shahārah,Shahārat al Ghīs,Shiharah,Shihārah,shhart,shhart alghys,Šahâra,شهارة,شهارة الغيس', 16.1841100, 43.7022800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148785, 'Sayyān', 'Sayyan', 'Saiyan,Saiyān,Sayyan,Sayyān,Seijan,Seijân,Sian,Siryan,Siryān,syan,سيان', 15.1717700, 44.3244200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148786, 'Sayḩūt', 'Sayhut', 'Saihut,Sayhut,Sayḩūt,syhwt,سيحوت', 15.2105600, 51.2455600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148787, 'Şanā’', 'Sana''', 'Sana'',Şanā’,صناء', 15.4000000, 47.7666700, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148788, 'Sanaa', 'Sanaa', 'SAH,San"o,San''a,San''a'',San''ah,San`a'',Sana,Sana''a,Sanaa,Sanaà,Sanaá,Saná,San’ah,sa na,sana,sanua,Şan‘ā'',Şan‘ā’,Σάνα,Сана,Санъо,צנעא,صنعاء,ሳና,サヌア,萨那,사나', 15.3547200, 44.2066700, 'YE', '2015-06-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148789, 'Saḩar', 'Sahar', 'Sahar,Saḩar', 15.3158600, 44.3085800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148790, 'Sāh', 'Sah', 'Sah,Sāh,Sāḩ,sah,ساه', 15.5772200, 48.8505600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148791, 'Sa''dah', 'Sa''dah', 'SYE,Sa''dah,Sa`da,Sa`dah,Saada,Sa‘da,Sa’dah,Şa‘dah,صعده', 16.9402100, 43.7639300, 'YE', '2013-11-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148792, 'Riḩāb', 'Rihab', 'Rihab,Riḩāb,rhab,رحاب', 14.2276200, 44.1881400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148793, 'Radā‘', 'Rada`', 'Rada`,Radā‘,Reda`,Redā‘,Rida`,Ridā‘,رداع', 14.4151000, 44.8370900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148794, 'Ar Raydah', 'Ar Raydah', 'Ar Raydah,Raida,Raidat al Abdul-Wadud,Raydat Al `Abd al Wadud,Raydat Ibn `Abd al Wadud,Raydat Ibn ‘Abd al Wadūd,Raydat Āl ‘Abd al Wadūd,alrydt,الريدة', 15.0350000, 50.4791700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148795, 'Raydah', 'Raydah', 'Raydah,Ridah,Rīdah,rydt,ريدة', 15.8142100, 44.0408500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148796, 'Ruḑūm', 'Rudum', 'Rudum,Ruḑūm,rdwm,رضوم', 14.0851000, 47.7431400, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148797, 'Qalansīyah', 'Qalansiyah', 'Kallansiya,Qalansiya,Qalansiyah,Qalansiyyah,Qalansyah,Qalansīyah,Qulansiyah,qlnsyt,قلنسية', 12.6895800, 53.4870900, 'YE', '2015-04-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148798, 'Qishn', 'Qishn', 'IHN,Qishn,qshn,قشن', 15.4240900, 51.6783600, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148799, 'Qa‘ţabah', 'Qa`tabah', 'Ka`taba,Kataba,Ka‘ṭaba,Qa`taba,Qa`tabah,Qa‘taba,Qa‘ţabah,قعطبة', 13.8549300, 44.7058000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148800, 'Nişāb', 'Nisab', 'An Nisab,An Nisāb,Ansab,Anşāb,Nisab,Nişāb,nsab,نصاب', 14.5074300, 46.4934900, 'YE', '2016-08-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148801, 'Al Musaymīr', 'Al Musaymir', 'Al Musaymir,Al Musaymīr,Musaymar,Musaymir,Museimir,Museimīr,Musemir,almsymyr,المسيمير', 13.4438900, 44.6152800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148802, 'Mukayrās', 'Mukayras', 'Makayris,Mukairas,Mukairās,Mukayras,Mukayris,Mukayrās,Mukeiras,UKR,mkyras,مكيراس', 13.9442700, 45.6707400, 'YE', '2017-02-10', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148803, 'Mūdīyah', 'Mudiyah', 'Mudiyah,Mūdīyah,mwdyt,مودية', 13.9284000, 46.0825400, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148804, 'Markaz Mudhaykirah', 'Markaz Mudhaykirah', 'Markaz Mudhaykirah,Mudhaykharah,Mudhaykhirah,mdykhrt,mrkz mdhykhrt,مديخرة,مركز مذيخرة', 13.8895300, 43.9688000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148805, 'Minwakh', 'Minwakh', 'Manwakh,Minwakh,mnwkh,منوخ', 16.8003500, 48.1085400, 'YE', '2017-01-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148806, 'Mayfa‘ah', 'Mayfa`ah', 'Asba`un,Aşba‘ūn,MFY,Maifa''ah,Maifa’ah,Mayfa`ah,Mayfa`ah al Qadimah,Mayfa‘ah,Mayfa‘ah al Qadīmah,ميفعة,ميفعة القديمة', 14.2753300, 47.5841400, 'YE', '2017-02-09', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148807, 'Maidi', 'Maidi', 'Maidi,Maydi,Maydī,Medi,Midi,Mēdi,Mīdī,mydy,ميدي', 16.3210100, 42.8129900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148808, 'Mawza‘', 'Mawza`', 'Mawdha`,Mawdha‘,Mawz`ah,Mawza`,Mawza`ah,Mawza‘,Mawza‘ah,Mawz‘ah,Musa,Muse,Mūsá,موزع', 13.2683100, 43.5099300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148809, 'Māwiyah', 'Mawiyah', 'Mavia,Mawiah,Mawiya,Mawiyah,Māwiyah,Māwīah,mawyt,ماوية', 13.5829500, 44.3476800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148810, 'Al Jawl', 'Al Jawl', 'Al Jawl,Masna`ah,Maşna‘ah,aljwl,الجول', 14.4562500, 48.2806600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148811, 'Ma''rib', 'Ma''rib', 'MYN,Magreb,Mar`rib,Marib,Мариб', 15.4625300, 45.3258100, 'YE', '2017-02-10', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148812, 'Manākhah', 'Manakhah', 'Manaha,Manakah,Manakhah,Manākah,Manākhah,Menacha,Menakha,Menâcha,mnakht,مناخة', 15.0742200, 43.7415600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148813, 'Milāḩ', 'Milah', 'Malah,Mallah,Mallaḩ,Malāḩ,Milah,Milāḩ,mlah,ملاح', 14.4161700, 44.7862200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148814, 'Al Malāḩīţ', 'Al Malahit', 'Al Malahit,Al Malāḩīţ,Malahit,Malāhit,Suq al Malahit,Sūq al Malāḩīţ,almlahyt,الملاحيط', 16.7684800, 43.2758200, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148815, 'Al Māfūd', 'Al Mafud', 'Al Mafud,Al Māfūd,Mafud,Māfūd,almafwd,المافود', 15.3426400, 47.2521700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148816, 'Mafḩaq', 'Mafhaq', 'Mafhag,Mafhaq,Mafhaqa,Mafḥag,Mafḩaq,Mefhak,mfhq,مفحق', 15.1016200, 43.9030400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148817, 'Al Madīd', 'Al Madid', 'Al Madid,Al Madīd,Madid,Madīd,almdyd,المديد', 15.6445300, 44.4733700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148818, 'Ma‘bar', 'Ma`bar', 'Ma`bar,Maber,Ma‘bar,معبر', 14.7939500, 44.2935400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148819, 'Al Ma‘allā’', 'Al Ma`alla''', 'Al Ma`alla,Al Ma`alla'',Al Ma‘alla,Al Ma‘allā’,Al Mu`ala'',Al Mu‘alā’,Ma`ala,Ma`alah,Ma`allah,Maalla,Ma‘ala,Ma‘alah,Ma‘allah,المعلاء', 12.7898700, 45.0024400, 'YE', '2015-11-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148820, 'Lawdar', 'Lawdar', 'Al-Ghudr,LDR,Laudar,Lawdar,Lodar,lwdr,لودر', 13.8828200, 45.8685900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148821, 'Laḩij', 'Lahij', 'Al Hawtah,Al Ḩawţah,Lahaj,Lahej,Lahij,Lahj,Lakhydzh,Laḩij,alhwtt,lhj,Лахыдж,الحوطة,لحج', 13.0566700, 44.8819400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148822, 'Kuḩlān ‘Affār', 'Kuhlan `Affar', 'Kuhlan,Kuhlan `Affar,Kuḩlān,Kuḩlān ‘Affār,كحلان عفار', 15.7330900, 43.7190200, 'YE', '2014-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148823, 'Ku‘aydinah', 'Ku`aydinah', 'Bani Manawis,Banī Manāwis,Ku`aydinah,Ku‘aydinah,كعيدنة', 15.8210400, 43.3372000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148824, 'Crater', 'Crater', 'Crater,Kraytar,Sayrah,Sirah,krytr,syrt,Şayrah,Şīrah,صيرة,كريتر', 12.7752200, 45.0386200, 'YE', '2015-04-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148825, 'Kitāf', 'Kitaf', 'Kitaf,Kitāf,ktaf,كتاف', 17.0316500, 44.1090500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148826, 'Kilmia', 'Kilmia', 'Kilmia', 12.1857600, 52.2333200, 'YE', '2011-02-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148827, 'Khawr Maksar', 'Khawr Maksar', 'Khawr Maksar,Khormaksar,Khur Maksar,Khūr Maksar,khwr mksr,خور مكسر', 12.8122700, 45.0333700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148828, 'Khawrah', 'Khawrah', 'Khaurah,Khawrah,khwrt,خورة', 14.4320100, 46.1543500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148829, 'Khamir', 'Khamir', 'Hamir,Hamr,H̱amr,Khamir,Khamr,khmr,خمر', 15.9879200, 43.9536200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148830, 'Juban', 'Juban', 'Giuban,Giubān,Juban,Jubn,Jubun,jbn,جبن', 14.0116400, 44.8746000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148831, 'Jiḩānah', 'Jihanah', 'Jihanah,Jiḩānah,jhant,جحانة', 15.2262800, 44.4824400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148832, 'Jiblah', 'Jiblah', 'Jibla,Jiblah,Jible,Jilah,Jīlah,jblt,جبلة', 13.9216200, 44.1466800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148833, 'Jawf al Maqbābah', 'Jawf al Maqbabah', 'Al Jawf,Al Jouf,Al-Jauf,Jawf,Jawf Umm Maqbabah,Jawf Umm Maqbābah,Jawf al Maqbabah,Jawf al Maqbābah,Jawf am Maqbabah,Jawf am Maqbābah', 13.8378300, 45.8348800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148834, 'Ja‘ār', 'Ja`ar', 'Gia`ar,Gia‘ar,Ja`ar,Ja‘ār,Ji`ar,Ji‘ār,Khanfar,جعار', 13.2230000, 45.3055900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148835, 'Ibb', 'Ibb', 'Ibas,Ibb,ab,ibbu,ibeu,yi bo,Ібб,Ибб,איב,إب,اب,イッブ,伊卜,이브', 13.9666700, 44.1833300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148836, 'Ḩūth', 'Huth', 'Huth,hwth,حوث,Ḩūth', 16.2311400, 43.9685400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148837, 'As Salāsil', 'As Salasil', 'As Salasil,As Salāsil,Husun al-Salasil,Husun as Salasil,alslasl,السلاسل,Ḥuṣūn al-Salāsil,Ḩuşūn as Salāsil', 16.4795900, 48.8315300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148838, 'Al ‘Abr', 'Al `Abr', 'Al `Abr,Al ‘Abr,Hisn al `Abr,Husn al Abr,Husnei Abr,العبر,Ḩişn al ‘Abr', 16.1377000, 47.2354500, 'YE', '2017-06-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148839, 'Ḩays', 'Hays', 'Hais,Haiz,Hays,hys,حيس,Ḥais,Ḩays', 13.9317000, 43.4831000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148840, 'Ḩayfān', 'Hayfan', 'Hayfan,Hefan,Hifan,Hīfān,hyfan,حيفان,Ḩayfān', 13.3177800, 44.2801100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148841, 'Ḩawf', 'Hawf', 'Hauf,Hawf,hwf,حوف,Ḩawf', 16.6338300, 53.0336800, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148842, 'Ḩaşwayn', 'Haswayn', 'Haswayn,Huswain,hswyn,حصوين,Ḩaşwayn', 15.5904900, 52.1007700, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148843, 'Ḩarīb', 'Harib', 'Darb Al `Ali,Darb al `Alt,Darb al ‘Alt,Darb Āl ‘Alī,Harib,hryb,حريب,Ḩarīb', 14.9315600, 45.5035600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148844, 'Ḩaraḑ', 'Harad', 'Harad,Haradh,Hard Wadi Sulayman,hrd,حرض,Ḩaraḑ,Ḩarḑ Wādī Sulaymān', 16.4096500, 43.0588300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148845, 'Ḩammām ‘Alī', 'Hammam `Ali', 'Hammam `Ali,Hamman `Ali,Hamman ‘Alī,حمام علي,Ḩammām ‘Alī', 14.6637100, 44.1476300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148846, 'Ḩajjah', 'Hajjah', 'Hage,Haggah,Haggiah,Hajja,Hajjah,Hajje,Khadzh,hjt,Хадж,حجة,Ḥage,Ḥaggah,Ḥaggiah,Ḩajjah', 15.6942500, 43.6058200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148847, 'Madīnat Lab‘ūs', 'Madinat Lab`us', 'Hajar al Ab`us,Hajar al Ab‘ūs,Madinat Lab`us,Madīnat Lab‘ūs,مدينة لبعوس', 13.8666700, 45.2500000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148848, 'Hadibu', 'Hadibu', 'Bilad-as-Sulyan,Hadibo,Hadiboh,Hadibu,Hadīboh,Hudaybu,Khadibo,Tamarida,Tamaridah,Tamarīdah,Tamrida,hdybw,Хадибо,حديبو,Ḩadībū,Ḩudaybū', 12.6488100, 54.0189500, 'YE', '2015-12-11', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148849, 'Ḩabīl al Jabr', 'Habil al Jabr', 'Habil Jabar,Habil Jabr,Habil al Jabr,hbyl aljbr,حبيل الجبر,Ḩabīl Jabar,Ḩabīl Jabr,Ḩabīl al Jabr', 13.6042200, 44.9857800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148850, 'Al Ḩabīlayn', 'Al Habilayn', 'Al Habilayn,Al Ḩabīlayn,Habilai,Habilayn,alhbylyn,الحبيلين', 13.5200200, 44.8507600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148851, 'Ḩabbān', 'Habban', 'Habban,hban,حبان,Ḩabbān', 14.3541100, 47.0764900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148852, 'Ḩabābah', 'Hababah', 'Hababah,hbabt,حبابة,Ḩabābah', 15.5441800, 43.8756300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148853, 'Ghayl Bā Wazīr', 'Ghayl Ba Wazir', 'Ghail Ba Wazir,Ghail Bā Wazīr,Ghayl Ba Wazir,Ghayl Bā Wazīr,Gheil Ba Wazir,Gheil Bā Wazir,ghyl ba wzyr,غيل با وزير', 14.7761100, 49.3661100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148854, 'Dhubāb', 'Dhubab', 'Dhubab,Dhubāb,Dubab,Dubāb,Kafr Dubah,Kafr Dubáh,dhbab,ذباب', 12.9430500, 43.4102500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148855, 'Dhī Nā‘im', 'Dhi Na`im', 'Dhi Na`im,Dhī Nā‘im,ذي ناعم', 14.1057400, 45.4480700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148856, 'Dhaybīn', 'Dhaybin', 'Dhaybin,Dhaybīn,Dhi Bayn,Dhi Bin,Dhubayn,Dhī Bayn,Dhī Bīn,Di Bin,dhy byn,dhybyn,ذي بين,ذيبين,Ḏī Bīn', 15.9771200, 44.1291700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148857, 'Dhī as Sufāl', 'Dhi as Sufal', 'Dhi Sifal,Dhi Sufal,Dhi as Sufal,Dhi es-Sifal,Dhī Sifal,Dhī Sufāl,Dhī as Sufāl,Dhī es-Sifāl,dhy alsfal,dhy sfal,ذي السفال,ذي سفال', 13.8344600, 44.1146900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148858, 'Dhamār', 'Dhamar', 'DMR,Damar,Dhamar,Dhamār,dhmar,ذمار', 14.5427400, 44.4051400, 'YE', '2017-02-10', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148859, 'Ḑawrān ad Daydah', 'Dawran ad Daydah', 'Dawran,Dawran ad Daydah,Dhoran,Dhuran,Dhūrān,Doran,dwrtn aldydt,ضورتن الديدة,Ḑawrān,Ḑawrān ad Daydah', 14.7392700, 44.2066400, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148860, 'Dār an Naşr', 'Dar an Nasr', 'Dar an Nasr,Dār an Nasr,Dār an Naşr,dar alnsr,دار النصر', 13.5582100, 44.0163500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148861, 'Burūm', 'Burum', 'Burum,Burūm,brwm,بروم', 14.3636100, 48.9797200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148862, 'Bayt ‘Adhāqah', 'Bayt `Adhaqah', 'Bayt `Adhaqah,Bayt `Idhaqah,Bayt ‘Adhāqah,Bayt ‘Idhāqah,Idha,بيت عذاقة', 15.6157600, 43.7022800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148863, 'As Sūq al Jadīd', 'As Suq al Jadid', 'As Suq al Jadid,As Sūq al Jadīd,Bayt Hirash,Bayt Hirāsh,Suq Bayt Harrash,Sūq Bayt Harrāsh,alswq aljdyd,السوق الجديد', 15.8249600, 44.0620400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148864, 'Bayt al Faqīh', 'Bayt al Faqih', 'Bait al Faqih,Bait al Faqīh,Bayt al Fakih Ibn `Udjayl,Bayt al Fakih al-Saghir,Bayt al Fakīh Ibn ‘Udjayl,Bayt al Fakīh al-Saghīr,Bayt al Faqih,Bayt al Faqīh,Bayt al-Fakih,Bayt al-Fakīh,Beit Faqih,Beit el-Faqih,Beit el-Faqīh,Beit-el-Fakih,byt alfqyh,بيت الفقيه', 14.5163500, 43.3244600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148865, 'Bayḩān', 'Bayhan', 'Al-Kasab,Al-Kaṣāb,BHN,Baihan al-Qasab,Baiḥān al-Qaṣāb,Bayhan,Bayhan Qasab,Bayhan al Qasab,Bayhan al Qisab,Bayhan al Quisab,Bayḩān,Bayḩān al Qaşāb,Bayḩān al Qişāb,Beiha al Qasab,Beihan,Beihan Qasab,Beihā al Qasāb,Beuhan,Hisn `Abd Allah,Suq `Abd Allab,Sūq ‘Abd Allāb,byhan,بيحان,Ḥiṣn ‘Abd Allāh', 14.8006700, 45.7188900, 'YE', '2017-02-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148866, 'Banī Ḩujjāj', 'Bani Hujjaj', 'Bani Hajjaj,Bani Hujjaj,Banī Ḩajjāj,Banī Ḩujjāj', 15.4168300, 43.3193000, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148867, 'Banī Bakr', 'Bani Bakr', 'Bani Bakk,Bani Bakr,Bani Baq,Banī Bakk,Banī Bakr,Banī Baq,bny bkr,بني بكر', 13.9333300, 45.2666700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148868, 'Bājil', 'Bajil', 'Badjil,Bagil,Bajil,Bâdjil,Bāgil,Bājil,bajl,باجل', 15.0589800, 43.2873100, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148869, 'Az Zuhrah', 'Az Zuhrah', 'Az Zuhrah,Az Zurah,Ez-Zohrah,Zahira,Zahire,Zohra,alzhrt,الزهرة', 15.7237700, 42.9958200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148870, 'Az Zaydīyah', 'Az Zaydiyah', 'Az Zadiyah,Az Zadīyah,Az Zaydiyah,Az Zaydīyah,Ez-Zaidiyyah,Zaida,Zaidiya,Zaidīya,Zaydiyah,Zaydīyah,Zeidie,Zeidiya,alzydyt,الزيدية', 15.3304900, 43.0063300, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148871, 'Az Zāhir', 'Az Zahir', 'Al Zahir,Az Zahir,Az Zāhir,alzahr,الزاهر', 16.3173300, 44.4950500, 'YE', '2015-02-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148872, 'Al Ḩajab', 'Al Hajab', 'Ain,Al Hajab,Al Ḩajab,`Ayn,alhjb,الحجب,عين,‘Ayn', 14.8519200, 45.5290400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148873, 'Al ‘Awābil', 'Al `Awabil', 'Abawil,Al `Awabil,Al ‘Awābil,`Awabil,العوابل,عوابل,‘Awābil', 13.8375500, 44.8643100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148874, 'At Turbah', 'At Turbah', 'At Turbah,altrbt,التربة', 13.2127000, 44.1241500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148875, 'Al Tuḩaytā’', 'Al Tuhayta''', 'Al Tuhayta'',Al Tuḩaytā’,At Tahaytha,At Taḩaythā,At Tuhayta,At Tuhaytah,At Tuhaytha,At Tuḩayta,At Tuḩaytah,At Tuḩaythā,Tahaite,التحيتاء', 14.1835600, 43.2263700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148876, 'At Tawāhī', 'At Tawahi', 'At Tawahi,At Tawāhī,Steamer Point,Streamer Point,Tawahi,Tawajih,Tawayih,Tawayih Town,Tawāhī,Tawāyih,altwahy,التواهي', 12.7847100, 44.9802000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148877, 'Ataq', 'Ataq', '''Ataq,AXK,Ataq,Attak,Attaq,`Ataq,عتق,‘Ataq,‘Atāq', 14.5376700, 46.8318700, 'YE', '2013-08-08', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148878, 'As Sūdah', 'As Sudah', 'As Sauda,As Sawda'',As Sawdā’,As Sudah,As Sūdah,Es-Sudah,Es-Sūdah,Sawda'',Sawdā’,Suda,Sudah,Sūdah,alswdt,السودة', 15.9586100, 43.7808300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148879, 'As Sayyānī', 'As Sayyani', 'Al Sayyan`,Al Sayyan‘,As Sayamin,As Sayani,As Sayyani,As Sayyānī,As Sayāmin,As Sayānī,alsyany,السياني', 13.8426600, 44.1739500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148880, 'Aş Şawma‘ah', 'As Sawma`ah', 'Al-Sauma''ah,Al-Sauma’ah,As Sawma`ah,Aş Şawma‘ah,Saum''a,Saum’a,الصومعة', 14.0850500, 45.8010100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148881, 'Al Bilād', 'Al Bilad', 'Al Bilad,Al Bilād,Al-Saum,As Sawm,As Som,alblad,البلاد', 16.1380600, 49.2916700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148882, 'As Sawādīyah', 'As Sawadiyah', 'Al Sawadiyyah,Al Sawādiyyah,As Sawadiyah,As Sawādīyah,As Suwadi,As Suwadiyah,As Suwādī,As Suwādīyah,Sawadi,Suwadi,alswadyt,السوادية', 14.3011300, 45.2214800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148883, 'Aş Şalīf', 'As Salif', 'As Salif,Aş Şalīf,Salif,Saliff,alslyf,Şalīf,الصليف', 15.3075500, 42.6710700, 'YE', '2015-12-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148884, 'Said', 'Said', 'Al Said,As Sa`id,Aş Şa‘īd,Said,الصعيد', 14.3301100, 46.8729200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148885, 'Aş Şafaqayn', 'As Safaqayn', 'As Safaqayn,As Safqayn,Aş Şafaqayn,Aş Şafqayn,alsfqyn,الصفقين', 15.3792200, 43.4204600, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148886, 'As Saddah', 'As Saddah', 'As Saddah,Sadda,Sauda,alsdt,السدة', 14.1221000, 44.4213900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148887, 'Ash Shaykh ‘Uthmān', 'Ash Shaykh `Uthman', 'Ash Shaykh `Uthman,Ash Shaykh ‘Uthmān,Shaikh Othman,Shakh `Uthman,Shakh ‘Uthman,Shaykh `Uthman,Shaykh ‘Uthmān,Sheikh `Othman,Sheikh ‘Othman,Shekh Othman,Shāikh Othmān,الشيخ عثمان', 12.8767800, 44.9930900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148888, 'Ash Shaţţ', 'Ash Shatt', 'Am Shat,Am Shatt,Am Shaţţ,Ash Shatt,Ash Shaţţ,alsht,am sht,أم شط,الشط', 12.8935700, 44.0357100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148889, 'Ash Shāhil', 'Ash Shahil', 'Ash Shahil,Ash Shāhil,alshahl,الشاهل', 15.8665600, 43.4049500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148890, 'Ash Shaghādirah', 'Ash Shaghadirah', 'Ash Sha`adirah,Ash Shafadirah,Ash Shafādirah,Ash Shaghadirah,Ash Shaghādirah,Ash Sha‘ādirah,alshghadrt,الشغادرة', 15.6200000, 43.5205600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148891, 'Asdās', 'Asdas', 'Asdas,Asdās,asdas,أسداس', 15.7660100, 45.0815100, 'YE', '2014-06-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148892, 'Marbāţ', 'Marbat', 'Al Robat,Al-Rubat,Al-Rubāṭ,Ar Ribat,Ar Ribāţ,Ar Rubat,Ar Rubāţ,Marbat,Marbāţ,alrbat,mrbat,الرباط,مرباط', 14.2056700, 46.3881100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148893, 'Ar Rawḑah', 'Ar Rawdah', 'Ar Raudha,Ar Rawdah,Ar Rawḑah,Rauda,Raudha,Rauḍa,Rawdah,Rawḑah,alrwdt,الروضة', 15.4325100, 44.2239900, 'YE', '2014-03-14', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148894, 'Ar Rawḑah', 'Ar Rawdah', 'Al-Raudah,Ar Rawdah,Ar Rawḑah,RXA,alrwdt,الروضة', 14.4672500, 47.2763800, 'YE', '2017-02-09', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148895, 'An Nādirah', 'An Nadirah', 'An Nadirah,An Nādirah,alnadrt,النادرة', 14.0962800, 44.4755900, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148896, '‘Amrān', '''Amran', '`Amran,`Umran,عمران,‘Amrān,‘Umrān', 15.6594000, 43.9438500, 'YE', '2013-08-08', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148897, '‘Amd', '`Amd', '`Amd,عمد,‘Amd', 15.3000000, 47.9833300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148898, 'Al Wuday‘', 'Al Wuday`', 'Al Wuday`,Al Wuday‘,Am Wuday`,Am Wuthia,Am Wuḑay‘,Umm Wuday`,Umm Wuḑay‘,أم وضيع,الوضيع', 13.7721000, 46.0178500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148899, 'Al ‘Udayn', 'Al `Udayn', 'Al `Udain,Al `Udayn,Al ‘Udain,Al ‘Udayn,El-`Udein,El-‘Udein,Udain,`Udayn,العدين,‘Udayn', 13.9691800, 43.9967300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148900, 'Al Qurḩ', 'Al Qurh', 'Al Qurh,Al Qurḩ,alqrh,القرح', 16.7333300, 51.4833300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148901, 'Al Qanāwiş', 'Al Qanawis', 'Al Qanawis,Al Qanāwiş,alqnaws,القناوص', 15.4928500, 43.1343000, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148902, 'Al Qaflah', 'Al Qaflah', 'Al Qaflah,Al Qiflah,alqflt,القفلة', 16.3189700, 43.7679200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148903, 'Qaryat al Qābil', 'Qaryat al Qabil', 'Al Qabil,Al Qābil,Qabil,Qaryat al Qabil,Qaryat al Qābil,Qābil,qryt alqabl,قرية القابل', 15.4503300, 44.1276800, 'YE', '2014-03-14', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148904, 'Āl Ma‘ūdah', 'Al Ma`udah', 'Al Hukumah,Al Hukūmah,Al Ma`udah,Al Qa`,Al Qā‘,At taffah,Aţ ţaffah,Qaryat Al Ma`udah,Qaryat Āl Ma‘ūdah,alhkwmt,altft,Āl Ma‘ūdah,ال معوضة,الحكومة,الطفة', 14.2105500, 45.3873200, 'YE', '2012-02-28', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148905, 'Al Munīrah', 'Al Munirah', 'Al Munayrah,Al Munirah,Al Munīrah,Manaru,Munayrah,Munera,almnyrt,المنيرة', 15.3225100, 42.9300500, 'YE', '2015-12-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148906, 'Al Mukallā', 'Al Mukalla', 'Al Mukalla,Al Mukallā,Al''-Mukalla,Al-Mukalla,MKX,Mukalla,RIY,almkla,Аль-Мукалла,المكلا', 14.5424800, 49.1242400, 'YE', '2017-02-10', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148907, 'Al Misrākh', 'Al Misrakh', 'Al Misrah,Al Misrakh,Al Misrākh,Al Misrākḩ,Al Misrāḩ,almsrakh,المسراخ', 13.4605900, 44.0204300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148908, 'Al Milāḩ', 'Al Milah', 'Al Milah,Al Milāḩ,almlah,الملاح', 13.4261100, 44.8255600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148909, 'Al Mighlāf', 'Al Mighlaf', 'Al Mighlaf,Al Mighlāf,almghlaf,المغلاف', 15.2877200, 43.1891000, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148910, 'Markaz al Marīr', 'Markaz al Marir', 'Al Marir,Al Marīr,El-Marir,El-Marīr,Marir,Markaz al Marir,Markaz al Marīr,mrkz almryr,مركز المرير', 13.9817800, 43.5954700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148911, 'Al Marāwi‘ah', 'Al Marawi`ah', 'Al Marawi`ah,Al Marāwi‘ah,El Marawa`ah,El Marāwa‘ah,Maraw''ah,Marawa,Marawa''ah,Marawi`ah,Marāwa’ah,Marāwi‘ah,Marāw’ah,Murawa`ah,Murāwa‘ah,المراوعة', 14.8306900, 43.1539100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148912, 'Al Manşūrīyah', 'Al Mansuriyah', 'Al Mansuriah,Al Mansuriyah,Al Mansuriyyah,Al Manşūrīah,Al Manşūrīyah,Al Manşūrīyyah,El-Mansuriyyah,El-Manşūriyyah,Mansuriya,Mansuriyah,Manşurīyah,almnswryt,المنصورية', 14.6856000, 43.2992200, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148913, 'Al Manşūrah', 'Al Mansurah', 'Al Mansura,Al Mansurah,Al Mansuri,Al Manşūrah,Al Manşūrī,almnswrt,المنصورة', 12.8601900, 44.9816600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148914, 'Al Makhādir', 'Al Makhadir', 'Al Makhadir,Al Makhādir,El-Makhadir,El-Makhādir,Makhadar,Mekhader,almkhadr,المخادر', 14.1222400, 44.1979700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148915, 'Al Maḩwīt', 'Al Mahwit', 'Al Mahwit,Al Maḩwīt,El-Mahwit,El-Maḩwīt,Mahwait,Mahweit,Mahwit,Maḩwīt,almhwyt,المحويت', 15.4700700, 43.5448100, 'YE', '2013-08-11', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148916, 'Al Maḩfid', 'Al Mahfid', 'Al Mahfaz,Al Mahfid,Al Mahfidh,Al Maḩfaz̧,Al Maḩfid,Al Maḩfidh,Al-Mahfad,Mahfad,Mahfid,Mahfidh,Maḥfid,almhfd,المحفد', 14.0584700, 46.9132900, 'YE', '2012-02-01', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148917, 'Al Maḩābishah', 'Al Mahabishah', 'Al Mahabishah,Al Maḩābishah,El-Mahabishah,El-Maḥābishah,Mahabeshe', 15.9475800, 43.4358700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148918, 'Al Luḩayyah', 'Al Luhayyah', 'Al Luhayyah,Al Luḩayyah,Al-Luhayya,Al-Luḥayya,El-Loheyyah,El-Loḥeyyah,Lahiyah,Laḩīyah,Loheiya,Lohisa,Luhaiya,allhyt,اللحية', 15.7030900, 42.6909300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148919, 'Kirsh', 'Kirsh', 'Al Kirsh,Kirsh,krsh,كرش', 13.3647300, 44.4904600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148920, 'Al Khawkhah', 'Al Khawkhah', 'Al Khawhah,Al Khawkah,Al Khawkhah,Khauha,Khaukhan,Khokha,alkhwkht,الخوخة', 13.8071000, 43.2493000, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148921, 'Al Jurbah', 'Al Jurbah', 'Al Jurbah,Jurba,aljrbt,الجربة', 13.7915000, 45.1589400, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148922, 'Al Jarrāḩī', 'Al Jarrahi', 'Al Jarrahi,Al Jarrāḩī,El-Giarrahi,El-Giarrāḥī,Jerahi,Suq al Jarrahi,Sūq al Jarrāḩī,aljrahy,الجراحي', 14.1325400, 43.3884500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148923, 'Al Ḩusayn', 'Al Husayn', 'Al Husain,Al Husayn,Al Husen,Al Ḩusayn,alhsyn,الحصين', 13.7919900, 44.7688600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148924, 'Ḩurayḑah', 'Huraydah', 'Al Huraydah,Al Ḩurayḑah,Al-Huraidah,Huraidha,Huraydah,hrydt,حريضة,Ḩurayḑah', 15.5986100, 48.1827800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148925, 'Al Ḩudaydah', 'Al Hudaydah', 'Al Hudaydah,Al Ḩudaydah,El-Hodeidah,El-Ḥodeidah,HOD,Hodaidah,Hodeida,Hudaida,Hudaydah,alhdydt,hdydh,الحديدة,حدیده,Ḩudaydah', 14.7978100, 42.9545200, 'YE', '2017-01-31', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148926, 'Al Ḩazm', 'Al Hazm', 'Al Hazm,Al Ḩazm,El-Hazm,El-Ḥazm,Hazm,Hazm al Jawf,alhzm,الحزم,Ḩazm al Jawf', 16.1640600, 44.7769200, 'YE', '2013-08-11', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148927, 'Al Qaţan', 'Al Qatan', 'Al Hawtah,Al Qatan,Al Qatn,Al Qaţan,Al Qaţn,Al Ḩawţah,Al-Hautah,Hauta,Qatan,Qaţan,alqtn,القطن', 15.8405600, 48.4555600, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148928, 'Al Ḩarf', 'Al Harf', 'Al Harf,Al Ḩarf,alhrf,الحرف', 16.3639500, 44.0942100, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148929, 'Ḩajar al Mashā’ikh', 'Hajar al Masha''ikh', 'Al Hajar,Al Hayr,Al Ḩajar,Al Ḩayr,Al-Hair,Al-Ḥair,Hajar al Masha''ikh,hjr almshaykh,حجر المشائخ,Ḩajar al Mashā’ikh', 16.1395100, 47.8323000, 'YE', '2017-06-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148930, 'Al Ghayz̧ah', 'Al Ghayzah', 'AAY,Al Ghaydah,Al Ghayzah,Al Ghayz̧ah,Al Ghayḑah,Ghaidha,al-Ghaida,alghydt,alghyzt,الغيضة,الغيظة', 16.2078700, 52.1760500, 'YE', '2017-02-09', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148931, 'Al Burayqah', 'Al Burayqah', 'Al Burayqah,Bir Burayqah,Buraikha,Bureika,albryqt,البريقة', 12.7394400, 44.8841700, 'YE', '2014-03-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148932, 'Al Bayda', 'Al Bayda', 'Al Bayda,Al Bayda'',Al Bayḑā’,Al Beidha,Al-Baida,Al-Baidhah,Al-Baidā,BYD,Beida,Beidha,البيضاء', 13.9852300, 45.5727200, 'YE', '2017-04-24', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148933, 'Al Bāţinah', 'Al Batinah', 'Al Batinah,Al Bāţinah,albatnt,الباطنة', 15.4833300, 48.4333300, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148934, 'Al ‘Āqir', 'Al `Aqir', 'Al `Aqir,Al ‘Āqir,Am `Aqir,Am ‘Āqir,العاقر', 14.5681600, 45.9115600, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148935, 'Aḩwar', 'Ahwar', 'Ahwar,Aḩwar,ahwr,أحور', 13.5201900, 46.7136700, 'YE', '2014-06-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148936, 'Ad Durayhimī', 'Ad Durayhimi', 'Ad Dayr Bahmi,Ad Dayr Bahmī,Ad Dayr Fahmi,Ad Dayr Fahmī,Ad Durayhimi,Ad Durayhimī,Al Durayhami,aldryhmy,الدريهمي', 14.6370200, 43.0550500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148937, 'Ad Dīs ash Sharqīyah', 'Ad Dis ash Sharqiyah', 'Ad Dis,Ad Dis ash Sharqiyah,Ad Dīs,Ad Dīs ash Sharqīyah,Dis,Dīs,aldys alshrqyt,الديس الشرقية', 14.9084000, 49.9484700, 'YE', '2016-02-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148938, 'Ad Dimnah', 'Ad Dimnah', 'Ad Dimnah,aldmnt,الدمنة', 13.4539800, 44.1816800, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148939, 'Ad Dann', 'Ad Dann', 'Ad Dan,Ad Dann,Dann,Dun,aldn,الدن', 14.3518000, 43.8527500, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148940, 'Az̧ Z̧alī‘ah', 'Az Zali`ah', 'Ad Dali`ah,Ad Dalī‘ah,Al-Dali`ah,Al-Dalī‘ah,Az Zali`ah,Az̧ Z̧alī‘ah,Dhula,Dhula''a,Dhula’a,الظليعة', 15.0166700, 48.0166700, 'YE', '2012-01-16', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148941, 'Dhalie', 'Dhalie', 'Ad Dali`,Adh Dhala`,Adh Dhāla‘,Aḑ Ḑāli‘,DHL,Dali`,Dhala,Dhalie,الضالع,Ḑāli‘', 13.6957200, 44.7313700, 'YE', '2017-02-09', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148942, 'Dhahi', 'Dhahi', 'Ad Dahi,Aḑ Ḑaḩī,Dhahi,Ed-Dahi,Eḍ-Ḍaḥī,aldhy,الضحي', 15.2151800, 43.0702000, 'YE', '2016-01-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148943, 'Markaz Bilād aţ Ţa‘ām', 'Markaz Bilad at Ta`am', 'Markaz Bilad at Ta`am,Markaz Bilād aţ Ţa‘ām,مركز بلاد الطعام', 14.8336100, 43.5363900, 'YE', '2012-02-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148944, 'Al Jum‘ah', 'Al Jum`ah', 'Al Jum`ah,Al Jum‘ah,الجمعة', 14.7377900, 43.9648900, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148945, 'Al Ḩadīyah', 'Al Hadiyah', 'Al Hadiyah,Al Ḩadīyah,alhdyt,الحدية', 14.5263800, 43.5704500, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148946, 'Kusmah', 'Kusmah', 'Kusmah,ksmt,كسمة', 14.5817500, 43.6367600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148947, 'Al Jabīn', 'Al Jabin', '', 14.7038900, 43.5991700, 'YE', '2015-04-04', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148948, 'Riqāb', 'Riqab', 'Riqab,Riqāb,rqab,رقاب', 14.8859700, 43.4649100, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148949, 'As Sukhnah', 'As Sukhnah', 'As Sukhnah,Sukhnah,alskhnt,السخنة', 14.7940800, 43.4362000, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148950, 'Ar Rujum', 'Ar Rujum', 'Ar Rujum,Rujum,alrjm,الرجم', 15.4577600, 43.6322600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148951, 'Al Khamīs', 'Al Khamis', 'Al Khamis,Al Khamīs,Khamis Bani Sa`d,Khamīs Banī Sa‘d,alkhmys,الخميس,خميس بني سعد', 15.1853300, 43.5112200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148952, 'Al ‘Urr', 'Al `Urr', 'Al `Urr,Al ‘Urr,العر', 15.2464800, 43.8883600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148953, 'Al Maghrabah', 'Al Maghrabah', 'Al Maghrabah,almghrbt,المغربة', 15.8772200, 43.6666700, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148954, 'Aş Şarārah', 'As Sararah', 'As Sararah,Aş Şarārah,alsrart,الصرارة', 15.7944900, 43.8699700, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148955, 'An Nāşirah', 'An Nasirah', 'An Nasirah,An Nāşirah,alnasrt,الناصرة', 15.7727700, 43.8090200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148956, 'Mabyan', 'Mabyan', 'Mabyan,mbyn,مبين', 15.7377300, 43.5570100, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148957, 'Matnah', 'Matnah', 'Matnah,mtnt,متنة', 15.2533300, 44.0247200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148958, 'Al Ḩayfah', 'Al Hayfah', 'Al Hayfah,Al Ḩayfah,alhyft,الحيفة', 15.7349400, 44.2378800, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148959, 'Bayt Marrān', 'Bayt Marran', 'Bayt Marran,Bayt Marrān,Beit Marran', 15.6931200, 44.2053000, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148960, 'Al Nashmah', 'Al Nashmah', 'Al Nashmah,Najd an Nashamah,alnshmt,njd alnshmt,النشمة,نجد النشمة', 13.3902800, 43.9683300, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148961, 'Al Ḩashwah', 'Al Hashwah', 'Al Hashwah,Al Ḩashwah,alhshwt,الحشوة', 16.9064100, 44.2762200, 'YE', '2012-02-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148962, 'Sāqayn', 'Saqayn', 'Saqayn,Sāqayn,saqyn,ساقين', 16.8770000, 43.5249900, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148963, 'Al Maḩjal', 'Al Mahjal', 'Al Mahjal,Al Maḩjal,Mahjil,Maḩjil,almhjl,المحجل', 16.7116900, 44.8476900, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148964, 'Rajūzah', 'Rajuzah', 'Rajuzah,Rajūzah,rjwzt,رجوزة', 16.7005600, 44.4145400, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148965, 'Al Khirāb', 'Al Khirab', 'Al Khirab,Al Khirāb,Kharab al Marashi,Kharāb al Marāshī,alkhrab,khrab almrashy,الخراب,خراب المراشي', 16.5544000, 44.2904800, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148966, 'Al Ḩumaydāt', 'Al Humaydat', 'Al Humaydat,Al Ḩumaydāt,alhmydat,الحميدات', 16.4844000, 44.4293400, 'YE', '2015-02-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148967, 'Al Madān', 'Al Madan', 'Al Madan,Al Madān,almdan,المدان', 16.2241300, 43.6438300, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148968, 'Al ‘Ashshah', 'Al `Ashshah', 'Al `Ashshah,Al ‘Ashshah,العشة', 16.2565200, 43.8547600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148969, 'Ḩişn Banī Sa‘d', 'Hisn Bani Sa`d', 'Hasan Bini Sa`d,Haşan Binī Sa‘d,Hisn Bani Sa`d,Hisn Bin Sa`d,حصن بني سعد,Ḩişn Banī Sa‘d,Ḩişn Bin Sa‘d', 16.2729300, 44.4772800, 'YE', '2015-02-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148970, 'Al Matūn', 'Al Matun', 'Al Matun,Al Matūn,Matun,Matūn,almtwn,المتون', 16.2306300, 44.5847600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148971, 'Al Maşlūb', 'Al Maslub', 'Al Maslub,Al Maşlūb,Maslub,Maşlūb,almslwb,المصلوب', 16.1827100, 44.6261300, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148972, 'Al Ghayl', 'Al Ghayl', 'Al Chalek,Al Ghayl,Ghayl,alghyl,الغيل', 16.1077400, 44.6800500, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148973, 'Al Jamīmah', 'Al Jamimah', 'Al Jamimah,Al Jamīmah,aljmymt,الجميمة', 16.0178700, 43.5964700, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148974, 'Ḩabūr', 'Habur', 'Habur,Habur Zulaymah,hbwr,حبور,Ḩabūr,Ḩabūr Z̧ulaymah', 16.0509700, 43.7069900, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148975, 'Ar Rawḑ', 'Ar Rawd', 'Ar Rawd,Ar Rawdah,Ar Rawḑ,Ar Rawḑah,alrwd,alrwdt,الروض,الروضة', 16.0614500, 44.8101200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148976, 'Ar Rubū‘', 'Ar Rubu`', 'Ar Rubu`,Ar Rubū‘,Dar Yahud,Dār Yahūd,Rubu` Bani Sha`b,Rubū‘ Banī Sha‘b,الربوع', 13.7802400, 43.8690100, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148977, 'Maqbanah', 'Maqbanah', 'Maqbanah,mqbnt,مقبنة', 13.6639400, 43.6873000, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148978, 'Ḑubāh', 'Dubah', 'Dubah,Zabah,Z̧abah,dbah,zbt,ضباه,ظبة,Ḑubah,Ḑubāh', 14.4905200, 44.1310800, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148979, 'Ar Raḑā‘ī', 'Ar Rada`i', 'Ar Rada`i,Ar Raḑā‘ī,alrdayy,الرضائي', 14.0170800, 44.3929900, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148980, 'Al Mayfa’ah', 'Al Mayfa''ah', 'Al Mayfa''ah,Al Mayfa’ah,الميفعة', 14.4639200, 44.5486600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148981, 'Ar Raḑmah', 'Ar Radmah', 'Ar Radmah,Ar Raḑmah,alrdmt,الرضمة', 14.2197300, 44.5865700, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148982, 'Ḩammām Damt', 'Hammam Damt', 'Damt,Hammam Damt,dmt,hmam dmt,حمام دمت,دمت,Ḩammām Damt', 14.0903100, 44.6700600, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148983, 'Zakhim', 'Zakhim', 'Zakhim,zkhm,زخم', 14.2949600, 44.6850400, 'YE', '2012-05-06', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148984, 'Maswarah', 'Maswarah', 'Maswarah,mswrt,مسورة', 14.3439900, 45.7262300, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148985, 'Ţawr al Bāḩah', 'Tawr al Bahah', 'Tawr al Bahah,twr albaht,Ţawr al Bāḩah,طور الباحة', 13.1817900, 44.2996600, 'YE', '2012-02-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148986, 'Kushar', 'Kushar', 'Kushar,kshr,كشر', 16.1552300, 43.4210200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148987, 'Aslam', 'Aslam', 'Aslam,aslm,أسلم', 16.0596100, 43.3274500, 'YE', '2014-06-05', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148988, 'Ḩaydān', 'Haydan', 'Haydan,hydan,حيدان,Ḩaydān', 16.7789900, 43.4337200, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148989, 'Al Miftāḩ', 'Al Miftah', 'Al Jubayl,Al Miftah,Al Miftāḩ,almftah,المفتاح', 15.9743100, 43.4638100, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148990, 'Aden', 'Aden', 'ADE,Adan,Adem,Aden,Aden khot,Aden shaary,Adena,Adenas,Adeno,Adén,Aidin,Anten,Cadan,Gorad Adehn,`Adan,adana,aden,edana,xeden,ya ding,Áden,Áidin,Ədən,Ɛaden,Άντεν,Аден,Аден хот,Аден шаары,Горад Адэн,Ադեն,עדן,عدن,अदन,एडन,เอเดน,အေဒင်မြို့,‘Adan,アデン,亚丁,亞丁,아덴', 12.7794400, 45.0366700, 'YE', '2012-01-19', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148991, 'Madghil', 'Madghil', 'Madghil,Madghil al Jid`an,Madghil al Jid‘ān,mdghl,مدغل,مدغل الجدعان', 15.5985800, 45.0401300, 'YE', '2015-02-07', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148992, 'Al Ḩarjah', 'Al Harjah', 'Al Harajah,Al Harjah,Al Ḩarajah,Al Ḩarjah,alhrjt,الحرجة', 15.4886900, 44.6657300, 'YE', '2015-06-08', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148993, 'Banī al ‘Awwām', 'Bani al `Awwam', 'Bani al `Awwam,Banī al ‘Awwām,بني العوام', 15.5811900, 43.5872700, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148994, 'Banī an Nahārī', 'Bani an Nahari', 'Bani an Nahari,Banī an Nahārī,bny alnhary,بني النهاري', 15.6398100, 43.5563300, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148995, 'Al Hijrah', 'Al Hijrah', 'Al Hijrah,Hijrat Qatabir,Hijrat Qaţābir,alhjrt,الهجرة', 17.2978800, 43.3871800, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148996, 'Sūq al Khamīs', 'Suq al Khamis', 'Suq al Khamis,Sūq al Khamīs,swq alkhmys,سوق الخميس', 17.1812600, 43.2881100, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148997, 'Al Mashāf', 'Al Mashaf', 'Al Mashaf,Al Mashāf,almshaf,المشاف', 16.8583600, 43.1978100, 'YE', '2012-02-29', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148998, 'Al Kharāb', 'Al Kharab', 'Al Kharab,Al Kharāb,alkhrab,الخراب', 16.9912900, 43.3388800, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148999, 'Al ‘Ayn', 'Al `Ayn', 'Al `Ayn,Al ‘Ayn,العين', 13.3300500, 44.0920800, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149000, 'Qaryat ad Da‘īs', 'Qaryat ad Da`is', 'Qaryat ad Da`is,Qaryat ad Da‘īs', 13.9877000, 44.2749000, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149001, 'Ḩazm al ‘Udayn', 'Hazm al `Udayn', 'Hazm al `Udayn,Ḩazm al ‘Udayn', 14.0274300, 44.0052600, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149002, 'An Najd', 'An Najd', 'An Najd,alnjd,النجد', 14.4215200, 45.2959600, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149003, 'Raḩabah al Kawlah', 'Rahabah al Kawlah', 'Al Kawlah Rahabah,Al Kawlah Raḩabah,Rahabah,Rahabah al Kawlah,Raḩabah,Raḩabah al Kawlah,rhbt,rhbt alkwlt,رحبة,رحبة الكولة', 14.8957400, 44.9891800, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149004, 'Al ‘Amūd', 'Al `Amud', 'Al `Amud,Al ‘Amūd,العمود', 14.7210300, 45.2067600, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149005, 'Al ‘Aqabah', 'Al `Aqabah', 'Al `Aqabah,Al ‘Aqabah,العقبة', 14.2717900, 44.7869900, 'YE', '2012-02-02', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149006, 'Al Qurayshīyah', 'Al Qurayshiyah', 'Al Qurayshiyah,Al Qurayshīyah,Sah al Qurayshiyah,Sāh al Qurayshīyah,alqryshyt,sah alqryshyt,القريشية,ساه القريشية', 14.5122000, 44.8535800, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149007, 'Ḩawrah', 'Hawrah', 'Az Zuhar Hawrah,Az̧ Z̧uhār Ḩawrah,Hawrah,hwrt,حورة,Ḩawrah', 13.3575100, 44.1458000, 'YE', '2012-01-21', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149008, 'Ash Shawātī', 'Ash Shawati', 'Ash Shawati,Ash Shawātī,alshwaty,الشواتي', 16.7831400, 43.8126500, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149009, 'Al Ḩamdī', 'Al Hamdi', 'Al Hamdi,Al Ḩamdī,alhmdy,الحمدي', 15.9472700, 48.7796500, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149010, 'At Taḩāluf', 'At Tahaluf', 'At Tahalif,At Tahaluf,At Taḩālif,At Taḩāluf,althalf,التحالف', 15.9378600, 48.7864100, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149011, 'Suḩayl Shibām', 'Suhayl Shibam', 'Suhayl Shibam,Suḩayl Shibām,shyl shbam,سحيل شبام', 15.9144800, 48.6386400, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149012, 'Al Khāniq', 'Al Khaniq', 'Al Khaniq,Al Khāniq,alkhanq,الخانق', 15.5025300, 44.1815800, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149013, 'Bi’r Ḩāt', 'Bi''r Hat', 'Bi''r Hat,Bi’r Ḩāt,byr hat,بئر حات', 17.3219700, 52.0956600, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149014, 'Ḩadādah', 'Hadadah', 'Hadadah,hdadt,حدادة,Ḩadādah', 13.1753500, 44.2746100, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149015, 'Rumāh', 'Rumah', 'Rimah,Rimāh,Rumah,Rumāh,rmah,rmat,رماة,رماه', 17.4553200, 50.5778900, 'YE', '2017-06-08', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149016, 'Rumāh', 'Rumah', 'Rumah,Rumāh,rmah,رماه', 17.4554700, 50.5777000, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149017, 'Al Shirūj', 'Al Shiruj', 'Al Shiruj,Al Shirūj,alshrwj,الشروج', 14.6852600, 47.7692600, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149018, 'Jawl al Majma‘', 'Jawl al Majma''', 'Jawl al Majma`,Jawl al Majma‘,جول المجمع', 14.9327800, 47.0276300, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149019, 'Sūq Sibāḩ', 'Suq Sibah', 'Suq Sibah,Sūq Sibāḩ,swq sbah,سوق سباح', 13.8143600, 45.3922900, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149020, 'Al Ḩazm', 'Al Hazm', 'Al Hazm,Al Ḩazm,alhzm,الحزم', 14.6891900, 45.6096200, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149021, 'Al Aqţa‘', 'Al Aqta''', 'Al Aqta`,Al Aqţa‘,الأقطع', 14.6621700, 45.3512300, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149022, 'Bāqim as Sūq', 'Baqim as Suq', 'Baqim,Baqim as Suq,Bāqim,Bāqim as Sūq,baqm,baqm alswq,باقم,باقم السوق', 17.3971300, 43.4774300, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149023, 'Maţarah', 'Matarah', 'Matarah,Maţarah,mtrt,مطرة', 15.5259100, 47.6333900, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149024, 'Khimār', 'Khimar', 'Khimar,Khimār,khaⁿmar - mʿmʿ,khmar,خمار,خًمار - معمع', 14.3198000, 46.7392200, 'YE', '2016-05-09', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149025, 'Ḩabīl ar Raydah', 'Habil ar Raydah', 'Habil ar Raydah,hbyl alrydt,حبيل الريدة,Ḩabīl ar Raydah', 13.6444000, 44.8509700, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149026, 'Al ‘Ulayb', 'Al ''Ulayb', 'Al `Ulayb,Al ‘Ulayb,العليب', 15.1474700, 49.0732500, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149027, 'Aţ Ţalḩ', 'At Talh', 'At Talh,Aţ Ţalḩ,altlh,الطلح', 15.1560000, 47.3990300, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149028, 'Sirār', 'Sirar', 'Sirar,Sirār,srar,سرار', 13.6377800, 45.3137100, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149029, 'Khayrān', 'Khayran', 'Khayran,Khayrān,khyran,خيران', 16.0219100, 43.3785900, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149030, 'Al Ḩuşūn', 'Al Husun', 'Al Husun,Al Markaz Al Jalal,Al Markaz Āl Jalāl,Al Ḩuşūn,alhswn,almrkz al jlal,الحصون,المركز ال جلال', 15.4739000, 45.3669100, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149031, 'Jayshān', 'Jayshan', 'Jayshan,Jayshān,jyshan,جيشان', 14.2520400, 46.1790500, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149032, 'Aş Şalw', 'As Salw', 'As Salw,Aş Şalw,alslw,الصلو', 13.3288700, 44.2170800, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149033, 'Raşad', 'Rasad', 'Rasad,Raşad,rsd,رصد', 13.7121500, 45.3031800, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149034, 'Saḩḩab', 'Sahhab', 'Sahab,Sahhab,Saḩab,Saḩḩab,Wadi Sahab,Wādī Saḩab,shb,سحب', 15.6022300, 44.0242000, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149035, 'Majz', 'Majz', 'Majadh,Majz,mjz,مجز', 17.0693900, 43.5750700, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149036, 'Al Mirwāḩ', 'Al Mirwah', 'Al Mirwah,Al Mirwāḩ,almrwah,المرواح', 15.4717100, 43.4294700, 'YE', '2016-06-22', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149037, 'AL-khashā upper', 'AL-khasha upper', 'alkhshʿt alʿlya,الخشعة العليا', 14.3404400, 46.7136500, 'YE', '2016-04-13', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149038, 'Al-Medy Village, قرية المدي', 'Al-Medy Village, qryt almdy', '', 14.4015200, 43.7917800, 'YE', '2016-05-26', 247);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148700, 'Novo Brdo', 'Novo Brdo', 'Artana,Artane,Artanë,Novaberd,Novo Brdo,Novoberda,Novoberde,Novobërda,Novobërdë,Novus Mons,Ново Брдо', 42.6159000, 21.4340500, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148701, 'Nishor', 'Nishor', 'Nishor,Nisor,Nišor,Нишор', 42.4238900, 20.8016700, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148702, 'Mamuša', 'Mamusa', 'Mamus,Mamusa,Mamusha,Mamushe,Mamushë,Mamuşa,Mamuša,Мамуша', 42.3308300, 20.7269400, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148703, 'Mališevo', 'Malisevo', 'Malisevo,Malisheve,Malishevo,Malishevë,Mališevo,Малишево', 42.4822200, 20.7458300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148704, 'Llazicë', 'Llazice', 'Llazice,Llazicë,Llozice,Llozicë,Lozica', 42.5552800, 20.7633300, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148705, 'Lumbardhi', 'Lumbardhi', 'Ljumbardh,Lumbarda,Lumbardh,Lumbardhe,Lumbardhi,Lumbardhë,Лумбарда', 42.5466700, 20.3466700, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148706, 'Lëbushë', 'Lebushe', 'Lebusha,Lebushe,Ljebuse,Ljebuše,Ljubusa,Ljubusha,Ljubuša,Lpushe,Lpushë,Lubushe,Lubushë,Lëbusha,Lëbushë,Љубуша', 42.5630600, 20.2908300, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148707, 'Lipljan', 'Lipljan', 'Lipjan,Liplan,Lipljan,Lipljane,Липљан', 42.5216700, 21.1258300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148708, 'Leshan', 'Leshan', 'Lesane,Leshan,Leshane,Leshtane,Lešane,Лешане', 42.3277800, 20.7811100, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148709, 'Leposaviq', 'Leposaviq', 'Albaniku,Leposavic,Leposavici,Leposaviq,Leposavić,Leposavići,Лепосавић', 43.1038900, 20.8027800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148710, 'Kosuriq', 'Kosuriq', 'Kosuric,Kosuriq,Kosurić,Косурић', 42.5702800, 20.4647200, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148711, 'Mitrovicë', 'Mitrovice', 'Kosovska Mitrovica,Mitrovica,Mitrovice,Mitrovicë,Косовска Митровица', 42.8833300, 20.8666700, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148712, 'Kamenica', 'Kamenica', 'Dardana,Dardane,Dardanë,Gurash,Kamenica,Kamenice,Kamenicë,Kosovska Kamenica,Каменица', 42.5780600, 21.5802800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148713, 'Kosovo Polje', 'Kosovo Polje', 'Fushe Kosove,Fushe-Kosova,Fushë Kosovë,Fushë-Kosova,Kosovo,Kosovo Pole,Kosovo Polje,Косово Поље', 42.6639400, 21.0961100, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148714, 'Klokot', 'Klokot', 'Kllokot,Kllotkot,Klokot,Klokot-Vrbovac,Клокот', 42.3713900, 21.3744400, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148715, 'Klina', 'Klina', 'Kliha,Klina,Kline,Klinë,Клина', 42.6216700, 20.5777800, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148716, 'Kačanik', 'Kacanik', 'Kacanik,Kacanikas,Kacaniku,Kachanik,Kaçanik,Kaçaniku,Kačanik,Kačanikas,Orhanye,ka cha ni ke,kachanyk,Качаник,Качанік,کاچانیک,卡查尼克', 42.2319400, 21.2594400, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148717, 'Junik', 'Junik', 'Junik,Јуник', 42.4758300, 20.2772200, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148718, 'Istok', 'Istok', 'Burim,Burimi,Istog,Istogu,Istok,Исток', 42.7808300, 20.4875000, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148719, 'Isniq', 'Isniq', 'Isniqi,Rrezari', 42.5575000, 20.3027800, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148720, 'Strellc i Epërm', 'Strellc i Eperm', 'Strallc i Eperm,Strallc i Epërm,Strellc i Eperm,Strellc i Epërm', 42.5784300, 20.2939800, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148721, 'Lluka e Eperme', 'Lluka e Eperme', 'Lluka e Eperme,Lluka e Epërme,Lluke e Eperme,Llukë e Epërme,Luka,Luka e Eperme,Luka e Epërme', 42.5450000, 20.3077800, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148722, 'Gjilan', 'Gjilan', 'Gilan,Gjilan,Gjilani,Gnilane,Gniljane,Gnjilane,Gnjilanė,Komuna e Gjilanit,Гњилане', 42.4604500, 21.4698600, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148723, 'Glogovac', 'Glogovac', 'Drenas,Drenasi,Gllogoc,Gllogoci,Gllogofc,Gllogovc,Glogovac,Glogovce,Глоговац', 42.6283300, 20.8938900, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148724, 'Gllogjan', 'Gllogjan', 'Fortesa,Glacani,Gladane,Glaçani,Glađane,Gllogjan,Gllogjani,Glodani,Glodjane,Glogjan,Glođani,Глођане', 42.5072200, 20.3627800, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148725, 'Dubova (Driloni)', 'Dubova (Driloni)', 'Driloni,Dubova,Dubove,Dubovë', 42.7119400, 20.3697200, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148726, 'Dranoc', 'Dranoc', 'Drenoc,Drenoci,Drenovac,Дреновац', 42.5155600, 20.2922200, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148727, 'Dragash', 'Dragash', 'Dagash,Dragas,Dragash,Dragashi,Dragaš,Sharr,Sharri,Драгаш', 42.0265000, 20.6533300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148728, 'Strellc i Ulët', 'Strellc i Ulet', 'Strellc i Poshtem,Strellc i Poshtëm', 42.5806300, 20.3161900, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148729, 'Gjinoc', 'Gjinoc', 'Dinovce,Dzinovce,Džinovce,Gjinoc,Gjinofc,Gjinovc,Ðinovce,Ђиновце', 42.3183300, 20.8186100, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148730, 'Hani i Elezit', 'Hani i Elezit', 'Deneral Jankovic,Dzeneral Jankovic,Dženeral Janković,Elez Han,Han i Elezit,Hani i Elezit,Jankovic,Ðeneral Janković,Ђенерал Јанковић', 42.1500000, 21.2966700, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148731, 'Deçan', 'Decan', 'Decan,Decani,Dekan,Deçan,Deçani,Декан', 42.5401800, 20.2879300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148732, 'Gjakovë', 'Gjakove', 'Gjakova,Gjakove,Gjakovë', 42.3802800, 20.4308300, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148733, 'Budakovo', 'Budakovo', 'Budakove,Budakovo,Budakovë,Butakove,Butakovë,Будаково', 42.3550000, 20.9250000, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148734, 'Papraqan', 'Papraqan', 'Papracane,Papraqan,Papraćane,Papračane,Prapacan,Prapacane,Prapacani,Prapaqan,Prapaqani,Prapaçan,Prapaçani,Prapaćan,Prapaćane,Папраћане,Прапаћане', 42.5527800, 20.3311100, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148735, 'Glanica', 'Glanica', 'Glanica,Gllanice,Gllanicë,Гланица', 42.5493300, 21.0633600, 'XK', '2015-02-22', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(148736, 'Lloqan', 'Lloqan', 'Llocan,Llocani,Lloqan,Lloqani,Lloçan,Lloçani,Locan,Locane,Loçan,Loćane,Лоћане', 42.5244400, 20.2808300, 'XK', '2015-02-15', NULL);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149282, 'Deneysville', 'Deneysville', 'Deneysville,Denysville', -26.8908000, 28.0970700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149283, 'Dendron', 'Dendron', '', -23.3666900, 29.3237100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149284, 'Delmas', 'Delmas', 'Del''mas,Delmas,Дельмас', -26.1466000, 28.6832200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149285, 'Delareyville', 'Delareyville', 'Delareyville', -26.6863800, 25.4590700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149286, 'De Aar', 'De Aar', 'De Aar,De-Ar,Gorad Deh-Ar,de a er,Горад Дэ-Ар,Де-Ар,Դե Աար,德阿爾', -30.6496600, 24.0123000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149287, 'Dannhauser', 'Dannhauser', 'Dannhauser', -28.0151000, 30.0565800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149288, 'Daniëlskuil', 'Danielskuil', 'Danielskuil,Daniëlskuil', -28.1887300, 23.5395100, 'ZA', '2013-04-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149289, 'Cullinan', 'Cullinan', 'Cullinan,Kullinan,Куллинан', -25.6708800, 28.5236400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149290, 'Creighton', 'Creighton', '', -30.0272000, 29.8395500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149291, 'Cradock', 'Cradock', 'CDO,Cradock,ke la duo ke,克拉多克', -32.1642200, 25.6191800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149292, 'Colesberg', 'Colesberg', 'Colesberg,Colesberg Dorp,Colesberg Town,ke er si bo ge,科爾斯伯格', -30.7199900, 25.0971800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149293, 'Cofimvaba', 'Cofimvaba', '', -32.0011500, 27.5804500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149294, 'Clocolan', 'Clocolan', 'Clocolan', -28.9136700, 27.5655500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149295, 'Christiana', 'Christiana', 'Christiana', -27.9140200, 25.1611100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149296, 'Carolina', 'Carolina', 'Carolina', -26.0692700, 30.1148900, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149297, 'Carnarvon', 'Carnarvon', 'Carnarvon', -30.9682700, 22.1330300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149298, 'Carletonville', 'Carletonville', 'Carletonville', -26.3609400, 27.3976700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149299, 'Camperdown', 'Camperdown', '', -29.7286800, 30.5425600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149300, 'Calitzdorp', 'Calitzdorp', 'Calitzdorp', -33.5275500, 21.6762000, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149301, 'Cala', 'Cala', '', -31.5235600, 27.6952000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149302, 'Butterworth', 'Butterworth', 'Battervorta,Butterworth,Gcuwa,UTE,Баттерворта', -32.3308300, 28.1498100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149303, 'Burgersfort', 'Burgersfort', 'Burgersfort', -24.6755400, 30.3287700, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149304, 'Burgersdorp', 'Burgersdorp', 'Burgersdorf,Burgersdorp,Burghersdorp', -30.9976600, 26.3286200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149305, 'Bultfontein', 'Bultfontein', '', -28.2875600, 26.1499600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149306, 'Bronkhorstspruit', 'Bronkhorstspruit', 'Bronkhorstspruit,Erasmus', -25.8101500, 28.7424800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149307, 'Brits', 'Brits', 'Britancy,Brits,bu li ci,Британцы,Бритс,布里茨', -25.6347300, 27.7802200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149308, 'Breyten', 'Breyten', 'Breyten,Breyton', -26.3017600, 29.9869600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149309, 'Bredasdorp', 'Bredasdorp', 'Bredasdorp,bu lei da si duo pu,Бредасдорп,布雷達斯多普', -34.5321500, 20.0403100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149310, 'Brandfort', 'Brandfort', 'Brandfort', -28.7000800, 26.4596800, 'ZA', '2012-07-11', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149311, 'Brakpan', 'Brakpan', 'Brakpan', -26.2365600, 28.3693800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149312, 'Botshabelo', 'Botshabelo', 'Botshabelo', -29.2673700, 26.7259500, 'ZA', '2016-08-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149313, 'Bothaville', 'Bothaville', 'Botavill'',Bothaville,Ботавилль', -27.3887000, 26.6170100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149314, 'Boshof', 'Boshof', 'Boshof', -28.5391400, 25.2396500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149315, 'Boksburg', 'Boksburg', 'Boksburg,Boksburgas,Боксбург,Բոկսբուրգ', -26.2119700, 28.2595800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149316, 'Bloemhof', 'Bloemhof', 'Bloemhof', -27.6468500, 25.6069700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149317, 'Bloemfontein', 'Bloemfontein', 'BFN,Bloemfontein,Blumfonteina,Blumfonteinas,Blumfontejn,Blumfonteyn,EBloemfontein,Gorad Blumfantehjn,IBloemfontein,Mangaung,Mploumphontein,balumaphontaina,beullumpontein,blum fxn then,blumafonatena,blumaphamtena,blumphanteyiൻ,blwmfwntn,blwmfwntyn,blwmpwntyyn,blwwmfۆntەyn,bu long fang dan,burumufonten,Μπλουμφοντέιν,Блумфонтейн,Блумфонтејн,Горад Блумфантэйн,Բլումֆոնթեյն,בלומפונטיין,بلوئمفونٹین,بلومفونتن,بلومفونتين,بلومفونٹین,بلوومفۆنتەین,ब्लूमफ़ोनटेन,ब्लूमफाँटेन,ਬਲੂਮਫੋਂਟੈਨ,ബ്ലൂംഫൗണ്ടെയിൻ,บลูมฟอนเทน,ბლუმფონტეინი,ብሉምፎንቴይን,ブルームフォンテーン,布隆方丹,블룸폰테인', -29.1210700, 26.2140000, 'ZA', '2016-08-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149318, 'Bizana', 'Bizana', '', -30.8590700, 29.8538400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149319, 'Bhisho', 'Bhisho', 'BIY,Bhisho,Bisho,Biso,Bišo,bhiso,bi shao,bisho,bisyo,byshw,Бишо,Бішо,بيشو,بھشو,بھیشو,भिशो,ビショ,比绍,비쇼', -32.8472100, 27.4421800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149320, 'Bethlehem', 'Bethlehem', 'Bethlehem,Vifleem,Вифлеем', -28.2307800, 28.3070700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149321, 'Bethal', 'Bethal', 'Bethal', -26.4579400, 29.4655300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149322, 'Bergville', 'Bergville', 'Bergville', -28.7312200, 29.3518700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149323, 'Berea', 'Berea', '', -29.8518500, 30.9933700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149324, 'Benoni', 'Benoni', 'Benoni,Бенони,Беноні,Բենոնի', -26.1884800, 28.3207800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149325, 'Belfast', 'Belfast', 'Belfast', -25.6899100, 30.0350400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149326, 'Beaufort West', 'Beaufort West', 'Beaufort West,Beaufort-Wes,Bofort-Uehst,xi bo fu te,Бофорт-Уэст,بیوفورٹ غربی,西博福特', -32.3567100, 22.5829500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149327, 'Barkly West', 'Barkly West', 'Barkly West,Barkly-Wes', -28.5353700, 24.5215100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149328, 'Barkly East', 'Barkly East', 'Barkley East,Barkly East,Barkly-Oos,dong ba ke li,東巴克利', -30.9683000, 27.5956700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149329, 'Barberton', 'Barberton', 'Barberton,ba bo dun,巴伯頓', -25.7884200, 31.0531900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149330, 'Ballito', 'Ballito', 'Ballitoville', -29.5389700, 31.2143900, 'ZA', '2017-01-13', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149331, 'Balfour', 'Balfour', 'Bal''fur,Balfour,Бальфур', -26.6633100, 28.5901600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149332, 'Ashton', 'Ashton', 'Ashton', -33.8313600, 20.0559500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149333, 'Apel', 'Apel', '', -24.4144500, 29.7499100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149334, 'Allanridge', 'Allanridge', 'Allanridge', -27.7543100, 26.6438200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149335, 'Aliwal North', 'Aliwal North', 'Aliwal North,Aliwal-Noord,alywal shmal,bei a li wa er,آلیوال شمال,北阿利瓦爾', -30.6936600, 26.7114100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149336, 'Alice', 'Alice', 'Alice,Ehlis,alys  kyp shrqy,Элис,الیس، کیپ شرقی', -32.7874900, 26.8344000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149337, 'Albertina', 'Albertina', 'Albertina,Albertinia,Albertiniahotel', -34.2054400, 21.5800100, 'ZA', '2016-03-09', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149338, 'Adelaide', 'Adelaide', 'Adelaide', -32.7074700, 26.2956400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149339, 'Ekangala', 'Ekangala', '', -25.6961900, 28.7491800, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149340, 'Midrand', 'Midrand', 'Midrand,Мидранд', -25.9895300, 28.1284300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149341, 'Centurion', 'Centurion', 'Centurion,Verwoerdburg,centurion,sencyuriyana,Центурион,सेंच्युरियन', -25.8589100, 28.1857700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149342, 'Worcester', 'Worcester', 'Gorad Vustehr,Vuster,Worcester,Worcester i Western Cape,usuta,wu si te,Вустер,Горад Вустэр,ウースター,伍斯特', -33.6465100, 19.4485200, 'ZA', '2013-03-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149343, 'Wellington', 'Wellington', 'Wellington', -33.6398100, 19.0112000, 'ZA', '2017-01-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149344, 'Vredendal', 'Vredendal', 'VRE,Vredendal', -31.6683300, 18.5011900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149345, 'Vredenburg', 'Vredenburg', 'Vredenburg', -32.9071900, 17.9899700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149346, 'Stellenbosch', 'Stellenbosch', 'Stellenbos,Stellenbosch,seutellenboseu,si tai lun bo si,suterenbosshu,Стелленбос,Սթելլենբոս,ステレンボッシュ,斯泰倫博斯,스텔렌보스', -33.9346200, 18.8667600, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149347, 'Springbok', 'Springbok', 'SBU,Springbok,Springbok Fontein,si pu lin bo ke,supuringubokku,Спрингбок,スプリングボック,斯普林博克', -29.6643400, 17.8865000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149348, 'Saldanha', 'Saldanha', 'Hoedjes Bay,Hoedjesbaai,Hoetjes Bay,SDB,Saldana,Saldanha,Салдана', -33.0116700, 17.9442000, 'ZA', '2017-01-27', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149349, 'Rosebank', 'Rosebank', '', -33.9555600, 18.4741700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149350, 'Robertson', 'Robertson', 'ROD,Robertson', -33.8034200, 19.8853700, 'ZA', '2017-01-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149351, 'Port Nolloth', 'Port Nolloth', 'Port Nolloth', -29.2518800, 16.8697000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149352, 'Pofadder', 'Pofadder', 'Pofadder,Theronsville', -29.1283000, 19.3949200, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149353, 'Piketberg', 'Piketberg', 'Piketberg,Piketburg,Piquetberg', -32.9032300, 18.7570400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149354, 'Paarl', 'Paarl', 'Paarl,pa a er,paru,Паарл,パール,帕阿爾', -33.7337800, 18.9752300, 'ZA', '2015-04-26', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149355, 'Moorreesburg', 'Moorreesburg', 'Moorreesburg', -33.1538800, 18.6603100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149356, 'Malmesbury', 'Malmesbury', '', -33.4608000, 18.7271400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149357, 'Lansdowne', 'Lansdowne', 'Lansdowne', -33.9873500, 18.4974600, 'ZA', '2013-09-07', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149358, 'Kraaifontein', 'Kraaifontein', 'Kraaifontein', -33.8480800, 18.7172300, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149359, 'Hermanus', 'Hermanus', 'Hermanus,he er ma nu si,赫爾馬努斯', -34.4187000, 19.2344600, 'ZA', '2013-03-04', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149360, 'Grabouw', 'Grabouw', 'Grabouw', -34.1515200, 19.0150900, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149361, 'Garies', 'Garies', 'Garies', -30.5622300, 17.9890500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149362, 'Constantia', 'Constantia', '', -34.0313900, 18.4183300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149363, 'Claremont', 'Claremont', '', -33.9805600, 18.4652800, 'ZA', '2013-03-15', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149364, 'Clanwilliam', 'Clanwilliam', 'Clanwilliam,Clanwillian', -32.1817300, 18.8921700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149365, 'Ceres', 'Ceres', 'Cerera,Ceres,sai lei si,Церера,塞雷斯', -33.3688900, 19.3109500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149366, 'Cape Town', 'Cape Town', 'Altepetl In Cabo,Ar Chab,CPT,Cape Toun,Cape Town,Cidade do Cabo,Cita del Cap,Citati du Capu,Citati dû Capu,Citta del Capo,Cittae do Cavo,Città del Capo,Cità del Cap,Ciuda del Cabu,Ciudad del Cabo,Ciudat do Cabo,Ciudá del Cabu,Ciutat del Cap,Civitas Capitis,El Cabo,Fokvaros,Fokváros,Gorad Kejptaun,Hoefdaborg,Hovdastadur,Höfðaborg,Høvdastaður,IKapa,Kaapstad,Kaapsted,Kaapstêd,Kab town,Kabe Urbe,Kaburbo,Kaepstad,Kapetown,Kapkaupunki,Kaplinn,Kapske Mesto,Kapske Misto,Kapské Mesto,Kapské Město,Kapstad,Kapstaden,Kapstadt,Kapsztad,Kapétown,Keip Taoun,Keiptaun,Keiptauna,Keiptaunas,Keiptauns,Kejptaun,Keyptaun,Keyptawn,Keýptaun,Le Cap,Li Kap,Lo Cap,Lurmutur Hiria,Lé Cap,Sita del Cao,Sita del Cap,Sità del Cao,Sità dël Cap,Tref y Penrhyn,Yvy akua Tava,Yvy akua Táva,hao wang jiao zhen,iKapa,kai pu dui,kai pu dun,keipeutaun,kep taun,kep tavun,kepa ta''una,kepata''una,keputaun,khep thawn,kyb tawn,kېp ټawn,Çittæ do Cavo,Κέιπ Τάουν,Горад Кейптаўн,Капске Місто,Кейптаун,Кејптаун,Քեյփթաուն,קאפשטאט,קייפטאון,كيب تاون,کیپ ٹاؤن,کیپ‌تاون,کېپ ټاون,کەیپ تاون,केपटाउन,केपताउन,কেপ টাউন,ਕੇਪਟਾਊਨ,કેપ ટાઉન,କେପ ଟାଉନ,கேப் டவுன்,కేప్ టౌన్,ಕೇಪ್ ಟೌನ್,കേപ് ടൗൺ,เคปทาวน์,ကိပ်တောင်းမြို့,კეიპტაუნი,ኬፕ ታውን,ケープタウン,好望角鎮,開普敦,케이프타운', -33.9258400, 18.4232200, 'ZA', '2016-08-06', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149367, 'Calvinia', 'Calvinia', 'Calvinia', -31.4706900, 19.7760100, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149368, 'Caledon', 'Caledon', 'Caledon', -34.2299700, 19.4265000, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149369, 'Bergvliet', 'Bergvliet', 'Bergvliet', -34.0474600, 18.4525000, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149370, 'Atlantis', 'Atlantis', 'Atlantida,Atlantis,Атлантида', -33.5666800, 18.4833500, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149371, 'Sunset Beach', 'Sunset Beach', '', -33.8539500, 18.4923100, 'ZA', '2016-11-26', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149372, 'Eden Glen', 'Eden Glen', 'Eden Glen,Edenglen', -26.1323000, 28.1685900, 'ZA', '2017-01-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149373, 'Rondebosch', 'Rondebosch', 'Rondebosch', -33.9633300, 18.4763900, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149374, 'Newlands', 'Newlands', 'Newlands', -33.9784600, 18.4481000, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149375, 'Bela-Bela', 'Bela-Bela', '', -24.8850000, 28.2941700, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149376, 'Lephalale', 'Lephalale', 'ELL,Ellisras,Lephalale,Lepkhalale,lai pa la lai,Лепхалале,萊帕拉萊', -23.6660700, 27.7447700, 'ZA', '2013-11-03', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149377, 'Musina', 'Musina', 'Messina,Musina,mu xi na,mushina,Мусина,ムシナ,穆西納', -22.3488100, 30.0407400, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149378, 'Midstream', 'Midstream', '', -25.9184900, 28.1988100, 'ZA', '2016-06-14', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149379, 'Mandeni', 'Mandeni', '', -29.1469100, 31.4140300, 'ZA', '2012-07-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149380, 'Retreat', 'Retreat', 'Retreat', -34.0551500, 18.4761700, 'ZA', '2013-08-18', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149381, 'Graskop', 'Graskop', '', -24.9317400, 30.8400800, 'ZA', '2017-01-02', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149382, 'Diepsloot', 'Diepsloot', '', -25.9331200, 28.0121300, 'ZA', '2014-04-08', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149383, 'Hardys Memories of Africa', 'Hardys Memories of Africa', '', -33.9053900, 20.7169000, 'ZA', '2015-05-31', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149384, 'Eastleigh', 'Eastleigh', '', -26.1296500, 28.1554100, 'ZA', '2017-01-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149385, 'Riverlea', 'Riverlea', '', -26.2119000, 27.9732200, 'ZA', '2016-07-28', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149386, 'Eden Glen Ext 60', 'Eden Glen Ext 60', '', -26.1259300, 28.1650000, 'ZA', '2017-01-12', 206);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149387, 'Nchelenge', 'Nchelenge', 'Nchelenge,Нчеленге', -9.3450600, 28.7339600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149388, 'Nakonde', 'Nakonde', '', -9.3421300, 32.7450000, 'ZM', '2016-06-04', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149389, 'Mpulungu', 'Mpulungu', 'Mpolungu,Mpulungu', -8.7623400, 31.1140500, 'ZM', '2012-04-23', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149390, 'Mporokoso', 'Mporokoso', 'Mpolokoso,Mporokoso', -9.3727300, 30.1250100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149391, 'Mbala', 'Mbala', 'Abercorn,MMQ,Mbala,Мбала', -8.8402400, 31.3658700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149392, 'Kawambwa', 'Kawambwa', 'Kawambwa,Kawamowa', -9.7915000, 29.0791300, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149393, 'Kaputa', 'Kaputa', '', -8.4688700, 29.6619300, 'ZM', '2011-04-18', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149394, 'Zambezi', 'Zambezi', 'BBZ,Balovale,Rio Zambeze,Sambesi,Sambesí,Zambesi,Zambeze,Zambezi,Zambezė,Zambèze,Zambézi,zan bi xi he,zanbeji chuan,zmbzy,Замбези,Замбезі,זמבזי,ザンベジ川,赞比西河', -13.5432300, 23.1046700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149395, 'Solwezi', 'Solwezi', 'SLI,Solouezi,Soluezi,Solvezi,Solvezis,Solwesi,Solwezi,sol-weji,soruu~eji,suo lu wei qi,swlwyzy,Σολουέζι,Солвези,Солвезі,Солуези,سولویزی,ソルウェジ,索盧韋齊,솔웨지', -12.1688000, 26.3893800, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149396, 'Sinazongwe', 'Sinazongwe', 'Sinasongwe,Sinazongwe', -17.2614000, 27.4617900, 'ZM', '2014-04-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149397, 'Siavonga', 'Siavonga', 'Chapvonga,Siavonga', -16.5381800, 28.7087600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149398, 'Sesheke', 'Sesheke', 'SJQ,Sesheke,Shesheke,Sisheke,Шешеке', -17.4759300, 24.2968400, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149399, 'Serenje', 'Serenje', 'Serenje', -13.2325100, 30.2352200, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149400, 'Senanga', 'Senanga', 'SXG,Senanga,Sinanga', -16.1166700, 23.2666700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149401, 'Samfya', 'Samfya', 'Samfya', -11.3649100, 29.5565200, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149402, 'Petauke', 'Petauke', 'Petauke', -14.2411700, 31.3197500, 'ZM', '2016-09-22', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149403, 'Nyimba', 'Nyimba', '', -14.5565600, 30.8149000, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149404, 'Ndola', 'Ndola', 'Gorad Ndola,NLA,Ndola,Ntola,en duo la,eundolla,ndola,ndora,ndwla,Ντόλα,Горад Ндола,Ндола,ندولا,ნდოლა,ンドラ,恩多拉,은돌라', -12.9586700, 28.6365900, 'ZM', '2015-06-03', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149405, 'Namwala', 'Namwala', 'Namwala', -15.7504200, 26.4383900, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149406, 'Nakambala', 'Nakambala', '', -15.8324400, 27.7799400, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149407, 'Mwinilunga', 'Mwinilunga', 'Mwinilunga,Wwinilunga', -11.7358400, 24.4292600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149408, 'Mwense', 'Mwense', '', -10.3844700, 28.6980000, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149409, 'Mungwi', 'Mungwi', '', -10.1732000, 31.3694200, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149410, 'Mumbwa', 'Mumbwa', 'Mumbwa', -14.9829300, 27.0619000, 'ZM', '2012-06-05', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149411, 'Mufumbwe', 'Mufumbwe', '', -13.6833300, 24.8000000, 'ZM', '2006-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149412, 'Mufulira', 'Mufulira', 'Mufulira,Mufulire,Муфулире', -12.5498200, 28.2407100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149413, 'Mpongwe', 'Mpongwe', '', -13.5091400, 28.1550400, 'ZM', '2011-04-18', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149414, 'Mpika', 'Mpika', 'Mpika,mupika,Мпика,ムピカ', -11.8343100, 31.4528700, 'ZM', '2016-06-04', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149415, 'Monze', 'Monze', 'Monze', -16.2833300, 27.4833300, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149416, 'Mongu', 'Mongu', 'MNR,Mongu,Mungu,Монгу', -15.2483500, 23.1274100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149417, 'Mkushi', 'Mkushi', 'Mkushi', -13.6201500, 29.3939000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149418, 'Mazabuka', 'Mazabuka', 'Mazabuka,Мазабука', -15.8560100, 27.7480000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149419, 'Mansa', 'Mansa', 'Fort Rosebery,MNS,Mansa,Mbila,Roseberry,man sa,mansa,mansa  zymbya,Манса,مانسا، زیمبیا,曼薩,만사', -11.1997600, 28.8943100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149420, 'Maamba', 'Maamba', 'Maamba', -17.3666700, 27.1500000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149421, 'Luwingu', 'Luwingu', 'Luingu,Luwingo,Luwingu', -10.2621000, 29.9271200, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149422, 'Lusaka', 'Lusaka', 'Gorad Lusaka,LUN,Lousaka,Louzaka,Lusaca,Lusak,Lusaka,Lusako,Lúsaka,Lûsaka,lu sa ka,lu sha ka,lucakka,lusaka,lwsaka,lwsqh,lwwsaka,rusaka,Λουσάκα,Горад Лусака,Лусака,Լուսակա,לוסאקא,לוסקה,لوساكا,لوساکا,لووساکا,لۇساكا,लुसाका,লুসাকা,ਲੁਸਾਕਾ,ଲୁସାକ,லுசாக்கா,ลูซากา,ལུ་ས་ཀ།,ლუსაკა,ሉሳካ,ルサカ,盧薩卡,路沙卡,루사카', -15.4066900, 28.2871300, 'ZM', '2011-10-27', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149423, 'Lundazi', 'Lundazi', 'Lundazi', -12.2929200, 33.1782000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149424, 'Lukulu', 'Lukulu', 'LXU,Lukulu', -14.3706700, 23.2419600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149425, 'Luanshya', 'Luanshya', 'Luansh''ja,Luansha,Luanshya,Luanshyo,Luansija,Luanšija,lu an xia,luansya,lwanshya,ruansha,Луанша,Луаншья,لوانشیا,ルアンシャ,盧安夏,루안샤', -13.1366700, 28.4166100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149426, 'Luangwa', 'Luangwa', 'Feira,Luangwa', -15.6166700, 30.4166700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149427, 'Livingstone', 'Livingstone', 'LVI,Livin''nkston,Livingston,Livingston shaary,Livingstonas,Livingstone,Livingstore,Livingstun,Maramba,li wen si dun,libingseuteon,lywwyngstwn,Λίβινγκστον,Ливингстон,Ливингстон шаары,Ливингстън,Марамба,ליווינגסטון,لیونگسٹون، زیمبیا,利文斯顿,리빙스턴', -17.8419400, 25.8542500, 'ZM', '2016-06-03', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149428, 'Limulunga', 'Limulunga', 'Limulunga', -15.0969100, 23.1375700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149429, 'Kitwe', 'Kitwe', 'KIW,Kitoue,Kitue,Kitve,Kitve-Nkana,Kitvė,Kitwe,Kitwe Nkana,Nkana-Kitwe,ji te wei,kiteuwe,kitou~e,kytwy,Κίτουε,Китве,Китве-Нкана,Китуе,Кітве,Կիտվե-Նկանա,كيتوي,کتوے,კიტვე,キトウェ,基特韦,키트웨', -12.8024300, 28.2132300, 'ZM', '2012-06-20', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149430, 'Kataba', 'Kataba', 'Kataba', -11.8833300, 29.7833300, 'ZM', '2013-05-05', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149431, 'Kasempa', 'Kasempa', 'Kasama,Kasempa', -13.4583600, 25.8338000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149432, 'Kasama', 'Kasama', 'Arcidiocesi di Kasama,KAA,Kasama,Kazama,ka sa ma,kasama,kasama  zymbya,Καζάμα,Касама,Կասամա,کاساما، زیمبیا,カサマ,卡薩馬,카사마', -10.2128900, 31.1808400, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149433, 'Kapiri Mposhi', 'Kapiri Mposhi', 'Kapiri Imposhi,Kapiri Mposhi', -13.9714700, 28.6698500, 'ZM', '2012-06-05', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149434, 'Kaoma', 'Kaoma', 'KMZ,Kaoma,Mankoya,Mankoye,Nankoya,Nunkoya', -14.7833300, 24.8000000, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149435, 'Kansanshi', 'Kansanshi', 'Kansanshi,Kansanshi Mine,Kansenshi', -12.0951400, 26.4272700, 'ZM', '2011-10-27', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149436, 'Kalulushi', 'Kalulushi', 'Kalulshi,Kalulushi', -12.8415100, 28.0947900, 'ZM', '2012-06-20', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149437, 'Kalengwa', 'Kalengwa', '', -13.4658600, 25.0027100, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149438, 'Kalabo', 'Kalabo', 'KLB,Kalabo', -14.9700500, 22.6813800, 'ZM', '2012-02-01', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149439, 'Kafue', 'Kafue', 'Kafe,Kafue,Кафе', -15.7691100, 28.1813600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149440, 'Kabwe', 'Kabwe', 'Broken Hill,Gorad Kabveh,Kabue,Kabve,Kabvė,Kabwe,QKE,ka bu wei,kabeuwe,kabuu~e,kabwy,Горад Кабвэ,Кабве,Кабуе,كابوي,کابوے,カブウェ,卡布韦,카브웨', -14.4469000, 28.4464400, 'ZM', '2011-10-20', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149441, 'Kabompo', 'Kabompo', 'Kabompo', -13.5926800, 24.2008100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149442, 'Isoka', 'Isoka', 'Isoka', -10.1606200, 32.6335300, 'ZM', '2016-06-04', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149443, 'Gwembe', 'Gwembe', 'Gwembe', -16.4975500, 27.6069100, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149444, 'Chongwe', 'Chongwe', '', -15.3291600, 28.6820400, 'ZM', '2011-03-06', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149445, 'Choma', 'Choma', 'Choma', -16.8088900, 26.9875000, 'ZM', '2017-05-07', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149446, 'Chipata', 'Chipata', 'CIP,Chipata,Cipata,Fort Jameson,Tsipata,chipata,chpata,qi pa ta,Čipata,Τσιπάτα,Чипата,چپاتا,奇帕塔,치파타', -13.6333300, 32.6500000, 'ZM', '2015-06-03', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149447, 'Chinsali', 'Chinsali', 'Chinsala,Chinsali', -10.5414200, 32.0816200, 'ZM', '2016-06-03', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149448, 'Chingola', 'Chingola', 'CGJ,Chingola,Cingola,ching-golla,chingora,chngwla,qin ge la,shynghwla,Čingola,Чингола,شينغولا,چنگولا,チンゴラ,欽戈拉,칭골라', -12.5289700, 27.8838200, 'ZM', '2016-10-16', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149449, 'Chililabombwe', 'Chililabombwe', 'Bancroft,Chilabombwe,Chiliabombwe,Chiliadomewe,Chililabombwe', -12.3647500, 27.8228600, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149450, 'Chibombo', 'Chibombo', 'Chibombo', -14.6568500, 28.0705700, 'ZM', '2014-03-03', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149451, 'Chambishi', 'Chambishi', 'Chambezi,Chambishi', -12.6324700, 28.0536700, 'ZM', '2011-10-20', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149452, 'Chama', 'Chama', 'Chama', -11.2130300, 33.1521000, 'ZM', '2016-06-04', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149453, 'Chadiza', 'Chadiza', 'Chadiza', -14.0677900, 32.4391700, 'ZM', '2012-01-17', 248);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149454, 'Zvishavane', 'Zvishavane', 'Shabani,Shavani,Zvishavane', -20.3267400, 30.0664800, 'ZW', '2014-05-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149455, 'Victoria Falls', 'Victoria Falls', 'Chutes Victoria,VFA,Victoria Falls', -17.9328500, 25.8306600, 'ZW', '2015-01-14', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149456, 'Shurugwi', 'Shurugwi', 'Churugwi,Salukwe,Selukwe,Shurugwi', -19.6701600, 30.0058900, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149457, 'Shangani', 'Shangani', '', -19.7833300, 29.3666700, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149458, 'Shamva', 'Shamva', 'Shamva,Tsambvi,Tsamvi', -17.3115900, 31.5756100, 'ZW', '2014-04-06', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149459, 'Rusape', 'Rusape', 'Rusape,Rusapi', -18.5278500, 32.1284300, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149460, 'Redcliff', 'Redcliff', 'Redcliff,Redcliffe,Rehdkliff,Рэдклифф', -19.0333300, 29.7833300, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149461, 'Raffingora', 'Raffingora', 'Raffingora', -17.0333300, 30.4333300, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149462, 'Plumtree', 'Plumtree', 'Plumtree', -20.4833300, 27.8166700, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149463, 'Penhalonga', 'Penhalonga', 'Penhalonga', -18.8911200, 32.6978100, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149464, 'Odzi', 'Odzi', 'Odzi', -18.9616700, 32.4055700, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149465, 'Nyazura', 'Nyazura', 'Inyazura,Nyazura,Nyazure', -18.7058700, 32.1679600, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149466, 'Nyanga', 'Nyanga', '', -18.2166700, 32.7500000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149467, 'Norton', 'Norton', 'Norton,Нортон', -17.8833300, 30.7000000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149468, 'Mvurwi', 'Mvurwi', 'Dawsons,Mvurwi,Umvukwes', -17.0333300, 30.8500000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149469, 'Mvuma', 'Mvuma', 'Muvumi,Mvuma,Umvuma', -19.2792400, 30.5282800, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149470, 'Mutoko', 'Mutoko', 'Mtoko,Mutoko', -17.3969900, 32.2267700, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149471, 'Mutare', 'Mutare', 'Gorad Mutareh,Mutare,Mutarė,Nyautare,UTA,Umtali,mu ta lei,mutale,Горад Мутарэ,Мутаре,穆塔雷,무타레', -18.9707000, 32.6708600, 'ZW', '2010-08-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149472, 'Murehwa', 'Murehwa', 'Mrewa,Murehwa,Murewa', -17.6432200, 31.7840000, 'ZW', '2014-05-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149473, 'Mount Darwin', 'Mount Darwin', 'Darwin,Fura,Mount Darwin,Mount Fura', -16.7725100, 31.5838100, 'ZW', '2014-04-06', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149474, 'Mhangura', 'Mhangura', 'Mangula,Mhangura', -16.8938700, 30.1682800, 'ZW', '2014-04-06', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149475, 'Mazowe', 'Mazowe', 'Mazowe', -17.5040400, 30.9738800, 'ZW', '2014-03-19', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149476, 'Masvingo', 'Masvingo', 'Fort Victoria,MVZ,Mashvingo,Masvingo,Nyanda,Машвинго', -20.0637300, 30.8276600, 'ZW', '2010-08-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149477, 'Mashava', 'Mashava', 'Mashaba,Mashava', -20.0366500, 30.4822500, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149478, 'Marondera', 'Marondera', 'Marandellas,Marondera', -18.1852700, 31.5519300, 'ZW', '2010-08-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149479, 'Macheke', 'Macheke', 'Macheke,Mucheki', -18.1390100, 31.8493300, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149480, 'Lupane', 'Lupane', 'Lupane,Lupani', -18.9314900, 27.8069600, 'ZW', '2010-08-13', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149481, 'Lalapanzi', 'Lalapanzi', 'Lalapansi,Lalapanzi', -19.3322500, 30.1776800, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149482, 'Kwekwe', 'Kwekwe', 'Hwe Hwe,Kvekve,Kvekvė,Kwekwe,Que Que,kui kui shi,kwekwe,kwykwy,kwyykwyy,Квекве,كويكوى,کوئیکوئی,奎奎市,퀘퀘', -18.9280900, 29.8148600, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149483, 'Karoi', 'Karoi', 'Karoi,Karoyi', -16.8099300, 29.6924700, 'ZW', '2015-04-24', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149484, 'Kariba', 'Kariba', 'KAB,Kariba,ka li ba,kaliba,karyba,Кариба,كاريبا,کاریبا، زمبابوے,卡里巴,카리바', -16.5166700, 28.8000000, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149485, 'Kamativi Mine', 'Kamativi Mine', 'Kamativi,Kamativi Mine,Kamitivi', -18.3156300, 27.0572900, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149486, 'Kadoma', 'Kadoma', 'Gatooma,Kadoma,Kadome,Katoma,ka duo ma,kadoma,Кадома,Кадоме,کادوما، زمبابوے,カドマ,卡多馬,카도마', -18.3332800, 29.9153400, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149487, 'Inyati', 'Inyati', 'Inyati', -19.6756300, 28.8468700, 'ZW', '2014-03-23', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149488, 'Insiza', 'Insiza', '', -19.7833300, 29.2000000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149489, 'Hwange', 'Hwange', 'Hvange,Hvangė,Khvange,WKI,Wange,Wankie,hwang-ge,wan ji,Хванге,萬基,황게', -18.3644600, 26.4987700, 'ZW', '2014-11-16', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149490, 'Headlands', 'Headlands', 'Headlands', -18.2773300, 32.0515000, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149491, 'Harare', 'Harare', 'Arare,Charare,Gorad Kharareh,HRE,Harare,Hararensis Urbs,Harareo,Hararė,Kharare,Salisbury,ha la lei,halale,harare,harary,hrarh,hrary,Χαράρε,Горад Харарэ,Хараре,Հարարե,הארארה,هارارى,هراره,هراري,ھارارې,ھەرارێ,ہرارے,हरारे,ਹਰਾਰੇ,ହାରାରେ,ஹராரே,ฮาราเร,ཧ་ར་རི།,ჰარარე,ሀራሬ,ハラレ,哈拉雷,하라레', -17.8277200, 31.0533700, 'ZW', '2015-06-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149492, 'Gweru', 'Gweru', 'GWE,Gveru,Gwelo,Gweru,Гверу', -19.4500000, 29.8166700, 'ZW', '2009-06-30', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149493, 'Gwanda', 'Gwanda', 'Gvanda,Jawunda,guan da,Гванда,گوانڈا,關達', -20.9333300, 29.0000000, 'ZW', '2009-06-30', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149494, 'Gokwe', 'Gokwe', 'Gokwe', -18.2047600, 28.9349000, 'ZW', '2012-05-05', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149495, 'Glendale', 'Glendale', 'Glendale', -17.3551400, 31.0671800, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149496, 'Filabusi', 'Filabusi', 'Emfelabuso,Filabusi', -20.5333300, 29.2850200, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149497, 'Esigodini', 'Esigodini', 'Esigodini,Essexvale', -20.2897900, 28.9226100, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149498, 'Dorowa Mining Lease', 'Dorowa Mining Lease', 'Dorowa,Dorowa Claims,Dorowa Mining Lease', -19.0666700, 31.7500000, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149499, 'Dete', 'Dete', 'Dete,Dett', -18.6166700, 26.8666700, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149500, 'Concession', 'Concession', 'Concession', -17.3833300, 30.9500000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149501, 'Chivhu', 'Chivhu', 'Chivhu,Enkeldoorn', -19.0211200, 30.8921800, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149502, 'Chirundu', 'Chirundu', 'Chirunda,Chirundo,Chirundu,Chirundu Township,Otto Beit Bridge', -16.0333300, 28.8500000, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149503, 'Chiredzi', 'Chiredzi', 'BFO,Chiredzi', -21.0500000, 31.6666700, 'ZW', '2013-05-08', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149504, 'Chipinge', 'Chipinge', 'CHJ,Chipinga,Chipinge', -20.1883300, 32.6236500, 'ZW', '2015-04-24', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149505, 'Chinhoyi', 'Chinhoyi', 'Chinhoyi,Chinkhoi,Chinkhoji,Chinoyi,Cinhojis,Sinoia,qi nuo yi,Činhojis,Чинхойи,Чинхої,Чинхоји,چینہوئی,奇諾伊', -17.3666700, 30.2000000, 'ZW', '2009-06-30', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149506, 'Chimanimani', 'Chimanimani', 'Chimanimani,Mandidzudzure,Melsetter', -19.8000000, 32.8666700, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149507, 'Chegutu', 'Chegutu', 'Cheguto,Chegutu,Hartley,New Hartley', -18.1302100, 30.1407400, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149508, 'Chakari', 'Chakari', 'Chakari,Shagari', -18.0629400, 29.8924600, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149509, 'Centenary', 'Centenary', 'Centenary', -16.7228900, 31.1146200, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149510, 'Bulawayo', 'Bulawayo', 'BUQ,Bulavajas,Bulavajo,Bulavejo,Bulawayo,Gorad Bulavajo,bu la wa yue,bullawayo,burawayo,Булавайо,Булавајо,Булавейо,Горад Булаваё,ブラワヨ,布拉瓦约,불라와요', -20.1500000, 28.5833300, 'ZW', '2010-08-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149511, 'Binga', 'Binga', 'Binga', -17.6202700, 27.3413900, 'ZW', '2012-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149512, 'Bindura', 'Bindura', 'Bindura,Bindura Town,Kimberley Reefs,Биндура', -17.3019200, 31.3305600, 'ZW', '2010-08-03', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149513, 'Beitbridge', 'Beitbridge', 'Bajtbridz,Bajtbridzh,Beitbridge,Beitbridzas,Beitbridžas,bei te qiao,Байтбридж,Бајтбриџ,بیٹبریج,貝特橋', -22.2166700, 30.0000000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149514, 'Beatrice', 'Beatrice', '', -18.2528300, 30.8473000, 'ZW', '2006-01-17', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149515, 'Banket', 'Banket', 'Banket,Banket Junction', -17.3833300, 30.4000000, 'ZW', '2013-03-12', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149516, 'Epworth', 'Epworth', 'Epworth', -17.8900000, 31.1475000, 'ZW', '2012-01-19', 249);
INSERT INTO `cities` (`id`, `name`, `asciiname`, `alternatenames`, `latitude`, `longitude`, `country_code`, `modification_date`, `country_id`) VALUES(149517, 'Chitungwiza', 'Chitungwiza', 'Chitungviza,Chitungwiza,Citungviza,Gorad Chytungviza,chytwngwyza,Čitungviza,Горад Чытунгвіза,Читунгвиза,Читунгвіза,چیتونگویزا', -18.0127400, 31.0755500, 'ZW', '2012-01-20', 249);

CREATE TABLE IF NOT EXISTS `continents` (
`id` int(10) unsigned NOT NULL,
  `name` varchar(255) NOT NULL
) AUTO_INCREMENT=8 DEFAULT CHARSET=utf8;

INSERT INTO `continents` (`id`, `name`) VALUES(1, 'Africa');
INSERT INTO `continents` (`id`, `name`) VALUES(2, 'Antarctica');
INSERT INTO `continents` (`id`, `name`) VALUES(3, 'Asia');
INSERT INTO `continents` (`id`, `name`) VALUES(4, 'Europe');
INSERT INTO `continents` (`id`, `name`) VALUES(5, 'North America');
INSERT INTO `continents` (`id`, `name`) VALUES(6, 'Oceania');
INSERT INTO `continents` (`id`, `name`) VALUES(7, 'South America');

CREATE TABLE IF NOT EXISTS `countries` (
`id` int(10) unsigned NOT NULL,
  `iso_3166_2` char(2) NOT NULL,
  `name` varchar(255) NOT NULL,
  `continent_id` int(10) unsigned NOT NULL
) AUTO_INCREMENT=250 DEFAULT CHARSET=utf8;

INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(1, 'AF', 'Afghanistan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(2, 'AX', 'Åland Islands', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(3, 'AL', 'Albania', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(4, 'DZ', 'Algeria', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(5, 'AS', 'American Samoa', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(6, 'AD', 'Andorra', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(7, 'AO', 'Angola', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(8, 'AI', 'Anguilla', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(9, 'AQ', 'Antarctica', 2);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(10, 'AG', 'Antigua and Barbuda', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(11, 'AR', 'Argentina', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(12, 'AM', 'Armenia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(13, 'AW', 'Aruba', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(14, 'AU', 'Australia', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(15, 'AT', 'Austria', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(16, 'AZ', 'Azerbaijan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(17, 'BS', 'Bahamas', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(18, 'BH', 'Bahrain', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(19, 'BD', 'Bangladesh', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(20, 'BB', 'Barbados', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(21, 'BY', 'Belarus', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(22, 'BE', 'Belgium', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(23, 'BZ', 'Belize', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(24, 'BJ', 'Benin', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(25, 'BM', 'Bermuda', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(26, 'BT', 'Bhutan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(27, 'BO', 'Bolivia, Plurinational State of', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(28, 'BQ', 'Bonaire, Sint Eustatius and Saba', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(29, 'BA', 'Bosnia and Herzegovina', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(30, 'BW', 'Botswana', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(31, 'BV', 'Bouvet Island', 2);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(32, 'BR', 'Brazil', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(33, 'IO', 'British Indian Ocean Territory', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(34, 'BN', 'Brunei Darussalam', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(35, 'BG', 'Bulgaria', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(36, 'BF', 'Burkina Faso', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(37, 'BI', 'Burundi', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(38, 'CV', 'Cabo Verde', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(39, 'KH', 'Cambodia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(40, 'CM', 'Cameroon', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(41, 'CA', 'Canada', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(42, 'KY', 'Cayman Islands', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(43, 'CF', 'Central African Republic', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(44, 'TD', 'Chad', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(45, 'CL', 'Chile', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(46, 'CN', 'China', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(47, 'CX', 'Christmas Island', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(48, 'CC', 'Cocos (Keeling) Islands', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(49, 'CO', 'Colombia', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(50, 'KM', 'Comoros', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(51, 'CG', 'Congo', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(52, 'CD', 'Congo, the Democratic Republic of the', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(53, 'CK', 'Cook Islands', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(54, 'CR', 'Costa Rica', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(55, 'CI', 'Côte d''Ivoire', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(56, 'HR', 'Croatia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(57, 'CU', 'Cuba', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(58, 'CW', 'Curaçao', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(59, 'CY', 'Cyprus', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(60, 'CZ', 'Czechia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(61, 'DK', 'Denmark', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(62, 'DJ', 'Djibouti', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(63, 'DM', 'Dominica', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(64, 'DO', 'Dominican Republic', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(65, 'EC', 'Ecuador', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(66, 'EG', 'Egypt', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(67, 'SV', 'El Salvador', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(68, 'GQ', 'Equatorial Guinea', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(69, 'ER', 'Eritrea', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(70, 'EE', 'Estonia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(71, 'ET', 'Ethiopia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(72, 'FK', 'Falkland Islands (Malvinas)', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(73, 'FO', 'Faroe Islands', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(74, 'FJ', 'Fiji', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(75, 'FI', 'Finland', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(76, 'FR', 'France', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(77, 'GF', 'French Guiana', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(78, 'PF', 'French Polynesia', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(79, 'TF', 'French Southern Territories', 2);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(80, 'GA', 'Gabon', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(81, 'GM', 'Gambia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(82, 'GE', 'Georgia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(83, 'DE', 'Germany', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(84, 'GH', 'Ghana', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(85, 'GI', 'Gibraltar', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(86, 'GR', 'Greece', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(87, 'GL', 'Greenland', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(88, 'GD', 'Grenada', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(89, 'GP', 'Guadeloupe', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(90, 'GU', 'Guam', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(91, 'GT', 'Guatemala', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(92, 'GG', 'Guernsey', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(93, 'GN', 'Guinea', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(94, 'GW', 'Guinea-Bissau', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(95, 'GY', 'Guyana', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(96, 'HT', 'Haiti', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(97, 'HM', 'Heard Island and McDonald Islands', 2);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(98, 'VA', 'Holy See (Vatican City State)', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(99, 'HN', 'Honduras', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(100, 'HK', 'Hong Kong', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(101, 'HU', 'Hungary', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(102, 'IS', 'Iceland', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(103, 'IN', 'India', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(104, 'ID', 'Indonesia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(105, 'IR', 'Iran, Islamic Republic of', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(106, 'IQ', 'Iraq', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(107, 'IE', 'Ireland', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(108, 'IM', 'Isle of Man', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(109, 'IL', 'Israel', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(110, 'IT', 'Italy', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(111, 'JM', 'Jamaica', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(112, 'JP', 'Japan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(113, 'JE', 'Jersey', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(114, 'JO', 'Jordan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(115, 'KZ', 'Kazakhstan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(116, 'KE', 'Kenya', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(117, 'KI', 'Kiribati', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(118, 'KP', 'Korea (the Democratic People''s Republic of)', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(119, 'KR', 'Korea (the Republic of)', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(120, 'KW', 'Kuwait', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(121, 'KG', 'Kyrgyzstan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(122, 'LA', 'Lao People''s Democratic Republic', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(123, 'LV', 'Latvia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(124, 'LB', 'Lebanon', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(125, 'LS', 'Lesotho', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(126, 'LR', 'Liberia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(127, 'LY', 'Libya', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(128, 'LI', 'Liechtenstein', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(129, 'LT', 'Lithuania', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(130, 'LU', 'Luxembourg', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(131, 'MO', 'Macao', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(132, 'MK', 'Macedonia, the former Yugoslav Republic of', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(133, 'MG', 'Madagascar', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(134, 'MW', 'Malawi', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(135, 'MY', 'Malaysia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(136, 'MV', 'Maldives', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(137, 'ML', 'Mali', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(138, 'MT', 'Malta', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(139, 'MH', 'Marshall Islands', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(140, 'MQ', 'Martinique', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(141, 'MR', 'Mauritania', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(142, 'MU', 'Mauritius', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(143, 'YT', 'Mayotte', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(144, 'MX', 'Mexico', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(145, 'FM', 'Micronesia, Federated States of', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(146, 'MD', 'Moldova, Republic of', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(147, 'MC', 'Monaco', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(148, 'MN', 'Mongolia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(149, 'ME', 'Montenegro', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(150, 'MS', 'Montserrat', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(151, 'MA', 'Morocco', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(152, 'MZ', 'Mozambique', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(153, 'MM', 'Myanmar', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(154, 'NA', 'Namibia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(155, 'NR', 'Nauru', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(156, 'NP', 'Nepal', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(157, 'NL', 'Netherlands', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(158, 'NC', 'New Caledonia', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(159, 'NZ', 'New Zealand', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(160, 'NI', 'Nicaragua', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(161, 'NE', 'Niger', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(162, 'NG', 'Nigeria', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(163, 'NU', 'Niue', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(164, 'NF', 'Norfolk Island', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(165, 'MP', 'Northern Mariana Islands', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(166, 'NO', 'Norway', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(167, 'OM', 'Oman', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(168, 'PK', 'Pakistan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(169, 'PW', 'Palau', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(170, 'PS', 'Palestine, State of', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(171, 'PA', 'Panama', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(172, 'PG', 'Papua New Guinea', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(173, 'PY', 'Paraguay', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(174, 'PE', 'Peru', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(175, 'PH', 'Philippines', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(176, 'PN', 'Pitcairn', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(177, 'PL', 'Poland', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(178, 'PT', 'Portugal', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(179, 'PR', 'Puerto Rico', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(180, 'QA', 'Qatar', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(181, 'RE', 'Réunion', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(182, 'RO', 'Romania', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(183, 'RU', 'Russian Federation', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(184, 'RW', 'Rwanda', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(185, 'BL', 'Saint Barthélemy', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(186, 'SH', 'Saint Helena, Ascension and Tristan da Cunha', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(187, 'KN', 'Saint Kitts and Nevis', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(188, 'LC', 'Saint Lucia', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(189, 'MF', 'Saint Martin (French part)', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(190, 'PM', 'Saint Pierre and Miquelon', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(191, 'VC', 'Saint Vincent and the Grenadines', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(192, 'WS', 'Samoa', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(193, 'SM', 'San Marino', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(194, 'ST', 'Sao Tome and Principe', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(195, 'SA', 'Saudi Arabia', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(196, 'SN', 'Senegal', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(197, 'RS', 'Serbia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(198, 'SC', 'Seychelles', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(199, 'SL', 'Sierra Leone', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(200, 'SG', 'Singapore', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(201, 'SX', 'Sint Maarten (Dutch part)', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(202, 'SK', 'Slovakia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(203, 'SI', 'Slovenia', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(204, 'SB', 'Solomon Islands', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(205, 'SO', 'Somalia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(206, 'ZA', 'South Africa', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(207, 'GS', 'South Georgia and the South Sandwich Islands', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(208, 'SS', 'South Sudan', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(209, 'ES', 'Spain', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(210, 'LK', 'Sri Lanka', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(211, 'SD', 'Sudan', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(212, 'SR', 'Suriname', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(213, 'SJ', 'Svalbard and Jan Mayen', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(214, 'SZ', 'Swaziland', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(215, 'SE', 'Sweden', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(216, 'CH', 'Switzerland', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(217, 'SY', 'Syrian Arab Republic', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(218, 'TW', 'Taiwan, Province of China', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(219, 'TJ', 'Tajikistan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(220, 'TZ', 'Tanzania, United Republic of', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(221, 'TH', 'Thailand', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(222, 'TL', 'Timor-Leste', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(223, 'TG', 'Togo', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(224, 'TK', 'Tokelau', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(225, 'TO', 'Tonga', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(226, 'TT', 'Trinidad and Tobago', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(227, 'TN', 'Tunisia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(228, 'TR', 'Turkey', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(229, 'TM', 'Turkmenistan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(230, 'TC', 'Turks and Caicos Islands', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(231, 'TV', 'Tuvalu', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(232, 'UG', 'Uganda', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(233, 'UA', 'Ukraine', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(234, 'AE', 'United Arab Emirates', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(235, 'GB', 'United Kingdom', 4);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(236, 'US', 'United States', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(237, 'UM', 'United States Minor Outlying Islands', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(238, 'UY', 'Uruguay', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(239, 'UZ', 'Uzbekistan', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(240, 'VU', 'Vanuatu', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(241, 'VE', 'Venezuela, Bolivarian Republic of', 7);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(242, 'VN', 'Viet Nam', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(243, 'VG', 'Virgin Islands, British', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(244, 'VI', 'Virgin Islands, U.S.', 5);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(245, 'WF', 'Wallis and Futuna', 6);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(246, 'EH', 'Western Sahara', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(247, 'YE', 'Yemen', 3);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(248, 'ZM', 'Zambia', 1);
INSERT INTO `countries` (`id`, `iso_3166_2`, `name`, `continent_id`) VALUES(249, 'ZW', 'Zimbabwe', 1);

CREATE TABLE IF NOT EXISTS `members` (
`id` int(10) unsigned NOT NULL,
  `gender` tinyint(3) unsigned NOT NULL,
  `look_for` tinyint(3) unsigned NOT NULL,
  `birthdate` date NOT NULL,
  `continent` tinyint(3) unsigned NOT NULL,
  `country` int(10) unsigned NOT NULL,
  `city` int(10) unsigned NOT NULL,
  `picture` varchar(255) NOT NULL,
  `description` varchar(255) NOT NULL,
  `non_smoker` tinyint(3) unsigned NOT NULL,
  `religion` tinyint(3) unsigned NOT NULL,
  `pseudonym` varchar(255) NOT NULL,
  `email` varchar(255) NOT NULL,
  `password` varchar(255) NOT NULL,
  `register_ip_address` varchar(255) NOT NULL,
  `register_state` varchar(255) NOT NULL,
  `register_city` varchar(255) NOT NULL,
  `register_trust` tinyint(3) unsigned NOT NULL,
  `timezone` varchar(255) NOT NULL,
  `last_connection` datetime NOT NULL
) DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `messages` (
`id` int(10) unsigned NOT NULL,
  `transmitter` int(10) unsigned NOT NULL,
  `recipient` int(10) unsigned NOT NULL,
  `date_time` datetime NOT NULL,
  `text` varchar(4096) NOT NULL,
  `in_response_to` int(10) unsigned NOT NULL
) DEFAULT CHARSET=utf8;


ALTER TABLE `continents`
 ADD PRIMARY KEY (`id`);

ALTER TABLE `countries`
 ADD PRIMARY KEY (`id`);

ALTER TABLE `members`
 ADD PRIMARY KEY (`id`), ADD UNIQUE KEY `pseudonym` (`pseudonym`), ADD UNIQUE KEY `email` (`email`);

ALTER TABLE `messages`
 ADD PRIMARY KEY (`id`);


ALTER TABLE `continents`
MODIFY `id` int(10) unsigned NOT NULL AUTO_INCREMENT,AUTO_INCREMENT=8;
ALTER TABLE `countries`
MODIFY `id` int(10) unsigned NOT NULL AUTO_INCREMENT,AUTO_INCREMENT=250;
ALTER TABLE `members`
MODIFY `id` int(10) unsigned NOT NULL AUTO_INCREMENT;
ALTER TABLE `messages`
MODIFY `id` int(10) unsigned NOT NULL AUTO_INCREMENT;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
